from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Com.Marshal
import win32more.Windows.Win32.UI.WindowsAndMessaging
@winfunctype('OLEAUT32.dll')
def BSTR_UserSize(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> UInt32: ...
@winfunctype('OLEAUT32.dll')
def BSTR_UserMarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> POINTER(Byte): ...
@winfunctype('OLEAUT32.dll')
def BSTR_UserUnmarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> POINTER(Byte): ...
@winfunctype('OLEAUT32.dll')
def BSTR_UserFree(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> Void: ...
@winfunctype('OLE32.dll')
def HWND_UserSize(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> UInt32: ...
@winfunctype('OLE32.dll')
def HWND_UserMarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HWND_UserUnmarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HWND_UserFree(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> Void: ...
@winfunctype('OLEAUT32.dll')
def BSTR_UserSize64(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> UInt32: ...
@winfunctype('OLEAUT32.dll')
def BSTR_UserMarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> POINTER(Byte): ...
@winfunctype('OLEAUT32.dll')
def BSTR_UserUnmarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> POINTER(Byte): ...
@winfunctype('OLEAUT32.dll')
def BSTR_UserFree64(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> Void: ...
@winfunctype('OLE32.dll')
def HWND_UserSize64(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> UInt32: ...
@winfunctype('OLE32.dll')
def HWND_UserMarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HWND_UserUnmarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HWND_UserFree64(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> Void: ...
@winfunctype('OLE32.dll')
def CLIPFORMAT_UserSize(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(UInt16)) -> UInt32: ...
@winfunctype('OLE32.dll')
def CLIPFORMAT_UserMarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(UInt16)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def CLIPFORMAT_UserUnmarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(UInt16)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def CLIPFORMAT_UserFree(param0: POINTER(UInt32), param1: POINTER(UInt16)) -> Void: ...
@winfunctype('OLE32.dll')
def HBITMAP_UserSize(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HBITMAP)) -> UInt32: ...
@winfunctype('OLE32.dll')
def HBITMAP_UserMarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HBITMAP)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HBITMAP_UserUnmarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HBITMAP)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HBITMAP_UserFree(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.Graphics.Gdi.HBITMAP)) -> Void: ...
@winfunctype('OLE32.dll')
def HDC_UserSize(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HDC)) -> UInt32: ...
@winfunctype('OLE32.dll')
def HDC_UserMarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HDC)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HDC_UserUnmarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HDC)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HDC_UserFree(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.Graphics.Gdi.HDC)) -> Void: ...
@winfunctype('OLE32.dll')
def HICON_UserSize(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON)) -> UInt32: ...
@winfunctype('OLE32.dll')
def HICON_UserMarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HICON_UserUnmarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HICON_UserFree(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON)) -> Void: ...
@winfunctype('ole32.dll')
def SNB_UserSize(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(POINTER(POINTER(UInt16)))) -> UInt32: ...
@winfunctype('ole32.dll')
def SNB_UserMarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(POINTER(POINTER(UInt16)))) -> POINTER(Byte): ...
@winfunctype('ole32.dll')
def SNB_UserUnmarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(POINTER(POINTER(UInt16)))) -> POINTER(Byte): ...
@winfunctype('ole32.dll')
def SNB_UserFree(param0: POINTER(UInt32), param1: POINTER(POINTER(POINTER(UInt16)))) -> Void: ...
@winfunctype('OLE32.dll')
def STGMEDIUM_UserSize(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.System.Com.STGMEDIUM)) -> UInt32: ...
@winfunctype('OLE32.dll')
def STGMEDIUM_UserMarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.System.Com.STGMEDIUM)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def STGMEDIUM_UserUnmarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.System.Com.STGMEDIUM)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def STGMEDIUM_UserFree(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.System.Com.STGMEDIUM)) -> Void: ...
@winfunctype('OLE32.dll')
def CLIPFORMAT_UserSize64(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(UInt16)) -> UInt32: ...
@winfunctype('OLE32.dll')
def CLIPFORMAT_UserMarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(UInt16)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def CLIPFORMAT_UserUnmarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(UInt16)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def CLIPFORMAT_UserFree64(param0: POINTER(UInt32), param1: POINTER(UInt16)) -> Void: ...
@winfunctype('OLE32.dll')
def HBITMAP_UserSize64(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HBITMAP)) -> UInt32: ...
@winfunctype('OLE32.dll')
def HBITMAP_UserMarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HBITMAP)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HBITMAP_UserUnmarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HBITMAP)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HBITMAP_UserFree64(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.Graphics.Gdi.HBITMAP)) -> Void: ...
@winfunctype('OLE32.dll')
def HDC_UserSize64(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HDC)) -> UInt32: ...
@winfunctype('OLE32.dll')
def HDC_UserMarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HDC)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HDC_UserUnmarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HDC)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HDC_UserFree64(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.Graphics.Gdi.HDC)) -> Void: ...
@winfunctype('OLE32.dll')
def HICON_UserSize64(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON)) -> UInt32: ...
@winfunctype('OLE32.dll')
def HICON_UserMarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HICON_UserUnmarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HICON_UserFree64(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON)) -> Void: ...
@winfunctype('ole32.dll')
def SNB_UserSize64(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(POINTER(POINTER(UInt16)))) -> UInt32: ...
@winfunctype('ole32.dll')
def SNB_UserMarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(POINTER(POINTER(UInt16)))) -> POINTER(Byte): ...
@winfunctype('ole32.dll')
def SNB_UserUnmarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(POINTER(POINTER(UInt16)))) -> POINTER(Byte): ...
@winfunctype('ole32.dll')
def SNB_UserFree64(param0: POINTER(UInt32), param1: POINTER(POINTER(POINTER(UInt16)))) -> Void: ...
@winfunctype('OLE32.dll')
def STGMEDIUM_UserSize64(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.System.Com.STGMEDIUM)) -> UInt32: ...
@winfunctype('OLE32.dll')
def STGMEDIUM_UserMarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.System.Com.STGMEDIUM)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def STGMEDIUM_UserUnmarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.System.Com.STGMEDIUM)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def STGMEDIUM_UserFree64(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.System.Com.STGMEDIUM)) -> Void: ...
@winfunctype('OLE32.dll')
def CoGetMarshalSizeMax(pulSize: POINTER(UInt32), riid: POINTER(Guid), pUnk: win32more.Windows.Win32.System.Com.IUnknown, dwDestContext: UInt32, pvDestContext: VoidPtr, mshlflags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('OLE32.dll')
def CoMarshalInterface(pStm: win32more.Windows.Win32.System.Com.IStream, riid: POINTER(Guid), pUnk: win32more.Windows.Win32.System.Com.IUnknown, dwDestContext: UInt32, pvDestContext: VoidPtr, mshlflags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('OLE32.dll')
def CoUnmarshalInterface(pStm: win32more.Windows.Win32.System.Com.IStream, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('OLE32.dll')
def CoMarshalHresult(pstm: win32more.Windows.Win32.System.Com.IStream, hresult: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('OLE32.dll')
def CoUnmarshalHresult(pstm: win32more.Windows.Win32.System.Com.IStream, phresult: POINTER(win32more.Windows.Win32.Foundation.HRESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('OLE32.dll')
def CoReleaseMarshalData(pStm: win32more.Windows.Win32.System.Com.IStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('OLE32.dll')
def CoGetStandardMarshal(riid: POINTER(Guid), pUnk: win32more.Windows.Win32.System.Com.IUnknown, dwDestContext: UInt32, pvDestContext: VoidPtr, mshlflags: UInt32, ppMarshal: POINTER(win32more.Windows.Win32.System.Com.Marshal.IMarshal)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('OLE32.dll')
def CoGetStdMarshalEx(pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, smexflags: UInt32, ppUnkInner: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('OLE32.dll')
def CoMarshalInterThreadInterfaceInStream(riid: POINTER(Guid), pUnk: win32more.Windows.Win32.System.Com.IUnknown, ppStm: POINTER(win32more.Windows.Win32.System.Com.IStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('OLEAUT32.dll')
def LPSAFEARRAY_UserSize(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(POINTER(win32more.Windows.Win32.System.Com.SAFEARRAY))) -> UInt32: ...
@winfunctype('OLEAUT32.dll')
def LPSAFEARRAY_UserMarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(POINTER(win32more.Windows.Win32.System.Com.SAFEARRAY))) -> POINTER(Byte): ...
@winfunctype('OLEAUT32.dll')
def LPSAFEARRAY_UserUnmarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(POINTER(win32more.Windows.Win32.System.Com.SAFEARRAY))) -> POINTER(Byte): ...
@winfunctype('OLEAUT32.dll')
def LPSAFEARRAY_UserFree(param0: POINTER(UInt32), param1: POINTER(POINTER(win32more.Windows.Win32.System.Com.SAFEARRAY))) -> Void: ...
@winfunctype('OLEAUT32.dll')
def LPSAFEARRAY_UserSize64(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(POINTER(win32more.Windows.Win32.System.Com.SAFEARRAY))) -> UInt32: ...
@winfunctype('OLEAUT32.dll')
def LPSAFEARRAY_UserMarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(POINTER(win32more.Windows.Win32.System.Com.SAFEARRAY))) -> POINTER(Byte): ...
@winfunctype('OLEAUT32.dll')
def LPSAFEARRAY_UserUnmarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(POINTER(win32more.Windows.Win32.System.Com.SAFEARRAY))) -> POINTER(Byte): ...
@winfunctype('OLEAUT32.dll')
def LPSAFEARRAY_UserFree64(param0: POINTER(UInt32), param1: POINTER(POINTER(win32more.Windows.Win32.System.Com.SAFEARRAY))) -> Void: ...
@winfunctype('OLE32.dll')
def HACCEL_UserSize(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HACCEL)) -> UInt32: ...
@winfunctype('OLE32.dll')
def HACCEL_UserMarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HACCEL)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HACCEL_UserUnmarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HACCEL)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HACCEL_UserFree(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HACCEL)) -> Void: ...
@winfunctype('OLE32.dll')
def HGLOBAL_UserSize(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.Foundation.HGLOBAL)) -> UInt32: ...
@winfunctype('OLE32.dll')
def HGLOBAL_UserMarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Foundation.HGLOBAL)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HGLOBAL_UserUnmarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Foundation.HGLOBAL)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HGLOBAL_UserFree(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.Foundation.HGLOBAL)) -> Void: ...
@winfunctype('OLE32.dll')
def HMENU_UserSize(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU)) -> UInt32: ...
@winfunctype('OLE32.dll')
def HMENU_UserMarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HMENU_UserUnmarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HMENU_UserFree(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU)) -> Void: ...
@winfunctype('OLE32.dll')
def HACCEL_UserSize64(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HACCEL)) -> UInt32: ...
@winfunctype('OLE32.dll')
def HACCEL_UserMarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HACCEL)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HACCEL_UserUnmarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HACCEL)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HACCEL_UserFree64(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HACCEL)) -> Void: ...
@winfunctype('OLE32.dll')
def HGLOBAL_UserSize64(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.Foundation.HGLOBAL)) -> UInt32: ...
@winfunctype('OLE32.dll')
def HGLOBAL_UserMarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Foundation.HGLOBAL)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HGLOBAL_UserUnmarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Foundation.HGLOBAL)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HGLOBAL_UserFree64(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.Foundation.HGLOBAL)) -> Void: ...
@winfunctype('OLE32.dll')
def HMENU_UserSize64(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU)) -> UInt32: ...
@winfunctype('OLE32.dll')
def HMENU_UserMarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HMENU_UserUnmarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HMENU_UserFree64(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU)) -> Void: ...
@winfunctype('OLE32.dll')
def HPALETTE_UserSize(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HPALETTE)) -> UInt32: ...
@winfunctype('OLE32.dll')
def HPALETTE_UserMarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HPALETTE)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HPALETTE_UserUnmarshal(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HPALETTE)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HPALETTE_UserFree(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.Graphics.Gdi.HPALETTE)) -> Void: ...
@winfunctype('OLE32.dll')
def HPALETTE_UserSize64(param0: POINTER(UInt32), param1: UInt32, param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HPALETTE)) -> UInt32: ...
@winfunctype('OLE32.dll')
def HPALETTE_UserMarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HPALETTE)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HPALETTE_UserUnmarshal64(param0: POINTER(UInt32), param1: POINTER(Byte), param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.HPALETTE)) -> POINTER(Byte): ...
@winfunctype('OLE32.dll')
def HPALETTE_UserFree64(param0: POINTER(UInt32), param1: POINTER(win32more.Windows.Win32.Graphics.Gdi.HPALETTE)) -> Void: ...
class IMarshal(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00000003-0000-0000-c000-000000000046}')
    @commethod(3)
    def GetUnmarshalClass(self, riid: POINTER(Guid), pv: VoidPtr, dwDestContext: UInt32, pvDestContext: VoidPtr, mshlflags: UInt32, pCid: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetMarshalSizeMax(self, riid: POINTER(Guid), pv: VoidPtr, dwDestContext: UInt32, pvDestContext: VoidPtr, mshlflags: UInt32, pSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def MarshalInterface(self, pStm: win32more.Windows.Win32.System.Com.IStream, riid: POINTER(Guid), pv: VoidPtr, dwDestContext: UInt32, pvDestContext: VoidPtr, mshlflags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def UnmarshalInterface(self, pStm: win32more.Windows.Win32.System.Com.IStream, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ReleaseMarshalData(self, pStm: win32more.Windows.Win32.System.Com.IStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DisconnectObject(self, dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMarshal2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.Marshal.IMarshal
    _iid_ = Guid('{000001cf-0000-0000-c000-000000000046}')
class IMarshalingStream(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IStream
    _iid_ = Guid('{d8f2f5e6-6102-4863-9f26-389a4676efde}')
    @commethod(14)
    def GetMarshalingContextAttribute(self, attribute: win32more.Windows.Win32.System.Com.CO_MARSHALING_CONTEXT_ATTRIBUTES, pAttributeValue: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
STDMSHLFLAGS = Int32
SMEXF_SERVER: win32more.Windows.Win32.System.Com.Marshal.STDMSHLFLAGS = 1
SMEXF_HANDLER: win32more.Windows.Win32.System.Com.Marshal.STDMSHLFLAGS = 2


make_ready(__name__)
