from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.ParentalControls
ARRAY_SEP_CHAR: UInt32 = 9
WPCCHANNEL: UInt32 = 16
WPC_SETTINGS_LOCATE: UInt32 = 20
WPC_SETTINGS_MODIFY: UInt32 = 21
WPC_APP_LAUNCH: UInt32 = 22
WPC_SYSTEM: UInt32 = 23
WPC_WEB: UInt32 = 24
WPCPROV_TASK_SettingChange: UInt32 = 1
WPCPROV_TASK_GameStart: UInt32 = 2
WPCPROV_TASK_UrlVisit: UInt32 = 3
WPCPROV_TASK_EmailReceived: UInt32 = 4
WPCPROV_TASK_EmailSent: UInt32 = 5
WPCPROV_TASK_MediaPlayback: UInt32 = 6
WPCPROV_TASK_IMInvitation: UInt32 = 7
WPCPROV_TASK_IMJoin: UInt32 = 8
WPCPROV_TASK_IMLeave: UInt32 = 9
WPCPROV_TASK_FileDownload: UInt32 = 10
WPCPROV_TASK_IMFeature: UInt32 = 11
WPCPROV_TASK_Custom: UInt32 = 13
WPCPROV_TASK_EmailContact: UInt32 = 14
WPCPROV_TASK_IMContact: UInt32 = 15
WPCPROV_TASK_AppBlocked: UInt32 = 16
WPCPROV_TASK_AppOverride: UInt32 = 17
WPCPROV_TASK_WebOverride: UInt32 = 18
WPCPROV_TASK_WebsiteVisit: UInt32 = 19
WPCPROV_TASK_Application: UInt32 = 20
WPCPROV_TASK_ComputerUsage: UInt32 = 21
WPCPROV_TASK_ContentUsage: UInt32 = 22
WPCPROV_KEYWORD_WPC: UInt32 = 16
WPCPROV_KEYWORD_ThirdParty: UInt32 = 32
WPCEVENT_SYS_SETTINGCHANGE_value: UInt32 = 1
WPCEVENT_GAME_START_value: UInt32 = 2
WPCEVENT_WEB_URLVISIT_value: UInt32 = 3
WPCEVENT_EMAIL_RECEIVED_value: UInt32 = 4
WPCEVENT_EMAIL_SENT_value: UInt32 = 5
WPCEVENT_MEDIA_PLAYBACK_value: UInt32 = 6
WPCEVENT_IM_INVITATION_value: UInt32 = 7
WPCEVENT_IM_JOIN_value: UInt32 = 8
WPCEVENT_IM_LEAVE_value: UInt32 = 9
WPCEVENT_WEB_FILEDOWNLOAD_value: UInt32 = 10
WPCEVENT_IM_FEATURE_value: UInt32 = 11
WPCEVENT_CUSTOM_value: UInt32 = 13
WPCEVENT_EMAIL_CONTACT_value: UInt32 = 14
WPCEVENT_IM_CONTACT_value: UInt32 = 15
WPCEVENT_SYSTEM_APPBLOCKED_value: UInt32 = 16
WPCEVENT_APPOVERRIDE_value: UInt32 = 17
WPCEVENT_WEBOVERRIDE_value: UInt32 = 18
WPCEVENT_WEB_WEBSITEVISIT_value: UInt32 = 19
WPCEVENT_APPLICATION_value: UInt32 = 20
WPCEVENT_COMPUTERUSAGE_value: UInt32 = 21
WPCEVENT_CONTENTUSAGE_value: UInt32 = 22
MSG_Keyword_WPC: Int32 = 268435461
MSG_Keyword_ThirdParty: Int32 = 268435462
MSG_Opcode_Locate: Int32 = 805306388
MSG_Opcode_Modify: Int32 = 805306389
MSG_Opcode_Launch: Int32 = 805306390
MSG_Opcode_System: Int32 = 805306391
MSG_Opcode_Web: Int32 = 805306392
MSG_Task_SettingChange: Int32 = 1879048193
MSG_Task_GameStart: Int32 = 1879048194
MSG_Task_UrlVisit: Int32 = 1879048195
MSG_Task_EmailReceived: Int32 = 1879048196
MSG_Task_EmailSent: Int32 = 1879048197
MSG_Task_MediaPlayback: Int32 = 1879048198
MSG_Task_IMInvitation: Int32 = 1879048199
MSG_Task_IMJoin: Int32 = 1879048200
MSG_Task_IMLeave: Int32 = 1879048201
MSG_Task_FileDownload: Int32 = 1879048202
MSG_Task_IMFeature: Int32 = 1879048203
MSG_Task_Custom: Int32 = 1879048205
MSG_Task_EmailContact: Int32 = 1879048206
MSG_Task_IMContact: Int32 = 1879048207
MSG_Task_AppBlocked: Int32 = 1879048208
MSG_Task_AppOverride: Int32 = 1879048209
MSG_Task_WebOverride: Int32 = 1879048210
MSG_Task_WebsiteVisit: Int32 = 1879048211
MSG_Task_Application: Int32 = 1879048212
MSG_Task_ComputerUsage: Int32 = 1879048213
MSG_Task_ContentUsage: Int32 = 1879048214
MSG_Publisher_Name: Int32 = -1879048191
MSG_Event_SettingChange: Int32 = -1342177279
MSG_Event_GameStart: Int32 = -1342177278
MSG_Event_UrlVisit: Int32 = -1342177277
MSG_Event_EmailReceived: Int32 = -1342177276
MSG_Event_EmailSent: Int32 = -1342177275
MSG_Event_MediaPlayback: Int32 = -1342177274
MSG_Event_IMInvitation: Int32 = -1342177273
MSG_Event_IMJoin: Int32 = -1342177272
MSG_Event_IMLeave: Int32 = -1342177271
MSG_Event_FileDownload: Int32 = -1342177270
MSG_Event_IMFeature: Int32 = -1342177269
MSG_Event_Custom: Int32 = -1342177267
MSG_Event_EmailContact: Int32 = -1342177266
MSG_Event_IMContact: Int32 = -1342177265
MSG_Event_AppBlocked: Int32 = -1342177264
MSG_Event_AppOverride: Int32 = -1342177263
MSG_Event_WebOverride: Int32 = -1342177262
MSG_Event_WebsiteVisit: Int32 = -1342177261
MSG_Event_Application: Int32 = -1342177260
MSG_Event_ComputerUsage: Int32 = -1342177259
MSG_Event_ContentUsage: Int32 = -1342177258
FACILITY_WPC: UInt32 = 2457
WPCPROV: Guid = Guid('{01090065-b467-4503-9b28-533766761087}')
class IWPCGamesSettings(ComPtr):
    extends: win32more.Windows.Win32.System.ParentalControls.IWPCSettings
    _iid_ = Guid('{95e87780-e158-489e-b452-bbb850790715}')
    @commethod(6)
    def IsBlocked(self, guidAppID: Guid, pdwReasons: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWPCProviderConfig(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bef54196-2d02-4a26-b6e5-d65af295d0f1}')
    @commethod(3)
    def GetUserSummary(self, bstrSID: win32more.Windows.Win32.Foundation.BSTR, pbstrUserSummary: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Configure(self, hWnd: win32more.Windows.Win32.Foundation.HWND, bstrSID: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RequestOverride(self, hWnd: win32more.Windows.Win32.Foundation.HWND, bstrPath: win32more.Windows.Win32.Foundation.BSTR, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWPCProviderState(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{50b6a267-c4bd-450b-adb5-759073837c9e}')
    @commethod(3)
    def Enable(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Disable(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWPCProviderSupport(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{41eba572-23ed-4779-bec1-8df96206c44c}')
    @commethod(3)
    def GetCurrent(self, pguidProvider: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWPCSettings(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8fdf6ca1-0189-47e4-b670-1a8a4636e340}')
    @commethod(3)
    def IsLoggingRequired(self, pfRequired: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetLastSettingsChangeTime(self, pTime: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetRestrictions(self, pdwRestrictions: POINTER(win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWPCWebSettings(ComPtr):
    extends: win32more.Windows.Win32.System.ParentalControls.IWPCSettings
    _iid_ = Guid('{ffccbdb8-0992-4c30-b0f1-1cbb09c240aa}')
    @commethod(6)
    def GetSettings(self, pdwSettings: POINTER(win32more.Windows.Win32.System.ParentalControls.WPCFLAG_WEB_SETTING)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def RequestURLOverride(self, hWnd: win32more.Windows.Win32.Foundation.HWND, pcszURL: win32more.Windows.Win32.Foundation.PWSTR, cURLs: UInt32, ppcszSubURLs: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pfChanged: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWindowsParentalControls(ComPtr):
    extends: win32more.Windows.Win32.System.ParentalControls.IWindowsParentalControlsCore
    _iid_ = Guid('{28b4d88b-e072-49e6-804d-26edbe21a7b9}')
    @commethod(7)
    def GetGamesSettings(self, pcszSID: win32more.Windows.Win32.Foundation.PWSTR, ppSettings: POINTER(win32more.Windows.Win32.System.ParentalControls.IWPCGamesSettings)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWindowsParentalControlsCore(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4ff40a0f-3f3b-4d7c-a41b-4f39d7b44d05}')
    @commethod(3)
    def GetVisibility(self, peVisibility: POINTER(win32more.Windows.Win32.System.ParentalControls.WPCFLAG_VISIBILITY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetUserSettings(self, pcszSID: win32more.Windows.Win32.Foundation.PWSTR, ppSettings: POINTER(win32more.Windows.Win32.System.ParentalControls.IWPCSettings)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetWebSettings(self, pcszSID: win32more.Windows.Win32.Foundation.PWSTR, ppSettings: POINTER(win32more.Windows.Win32.System.ParentalControls.IWPCWebSettings)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetWebFilterInfo(self, pguidID: POINTER(Guid), ppszName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
WPCFLAG_IM_FEATURE = Int32
WPCFLAG_IM_FEATURE_NONE: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = 0
WPCFLAG_IM_FEATURE_VIDEO: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = 1
WPCFLAG_IM_FEATURE_AUDIO: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = 2
WPCFLAG_IM_FEATURE_GAME: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = 4
WPCFLAG_IM_FEATURE_SMS: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = 8
WPCFLAG_IM_FEATURE_FILESWAP: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = 16
WPCFLAG_IM_FEATURE_URLSWAP: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = 32
WPCFLAG_IM_FEATURE_SENDING: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = -2147483648
WPCFLAG_IM_FEATURE_ALL: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_FEATURE = -1
WPCFLAG_IM_LEAVE = Int32
WPCFLAG_IM_LEAVE_NORMAL: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_LEAVE = 0
WPCFLAG_IM_LEAVE_FORCED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_LEAVE = 1
WPCFLAG_IM_LEAVE_CONVERSATION_END: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_IM_LEAVE = 2
WPCFLAG_ISBLOCKED = Int32
WPCFLAG_ISBLOCKED_NOTBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 0
WPCFLAG_ISBLOCKED_IMBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 1
WPCFLAG_ISBLOCKED_EMAILBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 2
WPCFLAG_ISBLOCKED_MEDIAPLAYBACKBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 4
WPCFLAG_ISBLOCKED_WEBBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 8
WPCFLAG_ISBLOCKED_GAMESBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 16
WPCFLAG_ISBLOCKED_CONTACTBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 32
WPCFLAG_ISBLOCKED_FEATUREBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 64
WPCFLAG_ISBLOCKED_DOWNLOADBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 128
WPCFLAG_ISBLOCKED_RATINGBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 256
WPCFLAG_ISBLOCKED_DESCRIPTORBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 512
WPCFLAG_ISBLOCKED_EXPLICITBLOCK: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 1024
WPCFLAG_ISBLOCKED_BADPASS: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 2048
WPCFLAG_ISBLOCKED_MAXHOURS: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 4096
WPCFLAG_ISBLOCKED_SPECHOURS: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 8192
WPCFLAG_ISBLOCKED_SETTINGSCHANGEBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 16384
WPCFLAG_ISBLOCKED_ATTACHMENTBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 32768
WPCFLAG_ISBLOCKED_SENDERBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 65536
WPCFLAG_ISBLOCKED_RECEIVERBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 131072
WPCFLAG_ISBLOCKED_NOTEXPLICITLYALLOWED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 262144
WPCFLAG_ISBLOCKED_NOTINLIST: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 524288
WPCFLAG_ISBLOCKED_CATEGORYBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 1048576
WPCFLAG_ISBLOCKED_CATEGORYNOTINLIST: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 2097152
WPCFLAG_ISBLOCKED_NOTKIDS: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 4194304
WPCFLAG_ISBLOCKED_UNRATED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 8388608
WPCFLAG_ISBLOCKED_NOACCESS: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = 16777216
WPCFLAG_ISBLOCKED_INTERNALERROR: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_ISBLOCKED = -1
WPCFLAG_LOGOFF_TYPE = Int32
WPCFLAG_LOGOFF_TYPE_LOGOUT: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_LOGOFF_TYPE = 0
WPCFLAG_LOGOFF_TYPE_RESTART: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_LOGOFF_TYPE = 1
WPCFLAG_LOGOFF_TYPE_SHUTDOWN: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_LOGOFF_TYPE = 2
WPCFLAG_LOGOFF_TYPE_FUS: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_LOGOFF_TYPE = 4
WPCFLAG_LOGOFF_TYPE_FORCEDFUS: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_LOGOFF_TYPE = 8
WPCFLAG_OVERRIDE = Int32
WPCFLAG_APPLICATION: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_OVERRIDE = 1
WPCFLAG_RESTRICTION = Int32
WPCFLAG_NO_RESTRICTION: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION = 0
WPCFLAG_LOGGING_REQUIRED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION = 1
WPCFLAG_WEB_FILTERED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION = 2
WPCFLAG_HOURS_RESTRICTED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION = 4
WPCFLAG_GAMES_BLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION = 8
WPCFLAG_APPS_RESTRICTED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION = 16
WPCFLAG_TIME_ALLOWANCE_RESTRICTED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION = 32
WPCFLAG_GAMES_RESTRICTED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_RESTRICTION = 64
WPCFLAG_VISIBILITY = Int32
WPCFLAG_WPC_VISIBLE: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_VISIBILITY = 0
WPCFLAG_WPC_HIDDEN: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_VISIBILITY = 1
WPCFLAG_WEB_SETTING = Int32
WPCFLAG_WEB_SETTING_NOTBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_WEB_SETTING = 0
WPCFLAG_WEB_SETTING_DOWNLOADSBLOCKED: win32more.Windows.Win32.System.ParentalControls.WPCFLAG_WEB_SETTING = 1
WPC_ARGS_APPLICATIONEVENT = Int32
WPC_ARGS_APPLICATIONEVENT_SERIALIZEDAPPLICATION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPLICATIONEVENT = 0
WPC_ARGS_APPLICATIONEVENT_DECISION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPLICATIONEVENT = 1
WPC_ARGS_APPLICATIONEVENT_PROCESSID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPLICATIONEVENT = 2
WPC_ARGS_APPLICATIONEVENT_CREATIONTIME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPLICATIONEVENT = 3
WPC_ARGS_APPLICATIONEVENT_TIMEUSED: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPLICATIONEVENT = 4
WPC_ARGS_APPLICATIONEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPLICATIONEVENT = 5
WPC_ARGS_APPOVERRIDEEVENT = Int32
WPC_ARGS_APPOVERRIDEEVENT_USERID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPOVERRIDEEVENT = 0
WPC_ARGS_APPOVERRIDEEVENT_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPOVERRIDEEVENT = 1
WPC_ARGS_APPOVERRIDEEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPOVERRIDEEVENT = 2
WPC_ARGS_APPOVERRIDEEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_APPOVERRIDEEVENT = 3
WPC_ARGS_COMPUTERUSAGEEVENT = Int32
WPC_ARGS_COMPUTERUSAGEEVENT_ID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_COMPUTERUSAGEEVENT = 0
WPC_ARGS_COMPUTERUSAGEEVENT_TIMEUSED: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_COMPUTERUSAGEEVENT = 1
WPC_ARGS_COMPUTERUSAGEEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_COMPUTERUSAGEEVENT = 2
WPC_ARGS_CONTENTUSAGEEVENT = Int32
WPC_ARGS_CONTENTUSAGEEVENT_CONTENTPROVIDERID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONTENTUSAGEEVENT = 0
WPC_ARGS_CONTENTUSAGEEVENT_CONTENTPROVIDERTITLE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONTENTUSAGEEVENT = 1
WPC_ARGS_CONTENTUSAGEEVENT_ID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONTENTUSAGEEVENT = 2
WPC_ARGS_CONTENTUSAGEEVENT_TITLE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONTENTUSAGEEVENT = 3
WPC_ARGS_CONTENTUSAGEEVENT_CATEGORY: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONTENTUSAGEEVENT = 4
WPC_ARGS_CONTENTUSAGEEVENT_RATINGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONTENTUSAGEEVENT = 5
WPC_ARGS_CONTENTUSAGEEVENT_DECISION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONTENTUSAGEEVENT = 6
WPC_ARGS_CONTENTUSAGEEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONTENTUSAGEEVENT = 7
WPC_ARGS_CONVERSATIONINITEVENT = Int32
WPC_ARGS_CONVERSATIONINITEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 0
WPC_ARGS_CONVERSATIONINITEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 1
WPC_ARGS_CONVERSATIONINITEVENT_ACCOUNTNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 2
WPC_ARGS_CONVERSATIONINITEVENT_CONVID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 3
WPC_ARGS_CONVERSATIONINITEVENT_REQUESTINGIP: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 4
WPC_ARGS_CONVERSATIONINITEVENT_SENDER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 5
WPC_ARGS_CONVERSATIONINITEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 6
WPC_ARGS_CONVERSATIONINITEVENT_RECIPCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 7
WPC_ARGS_CONVERSATIONINITEVENT_RECIPIENT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 8
WPC_ARGS_CONVERSATIONINITEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONINITEVENT = 9
WPC_ARGS_CONVERSATIONJOINEVENT = Int32
WPC_ARGS_CONVERSATIONJOINEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 0
WPC_ARGS_CONVERSATIONJOINEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 1
WPC_ARGS_CONVERSATIONJOINEVENT_ACCOUNTNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 2
WPC_ARGS_CONVERSATIONJOINEVENT_CONVID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 3
WPC_ARGS_CONVERSATIONJOINEVENT_JOININGIP: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 4
WPC_ARGS_CONVERSATIONJOINEVENT_JOININGUSER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 5
WPC_ARGS_CONVERSATIONJOINEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 6
WPC_ARGS_CONVERSATIONJOINEVENT_MEMBERCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 7
WPC_ARGS_CONVERSATIONJOINEVENT_MEMBER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 8
WPC_ARGS_CONVERSATIONJOINEVENT_SENDER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 9
WPC_ARGS_CONVERSATIONJOINEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONJOINEVENT = 10
WPC_ARGS_CONVERSATIONLEAVEEVENT = Int32
WPC_ARGS_CONVERSATIONLEAVEEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 0
WPC_ARGS_CONVERSATIONLEAVEEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 1
WPC_ARGS_CONVERSATIONLEAVEEVENT_ACCOUNTNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 2
WPC_ARGS_CONVERSATIONLEAVEEVENT_CONVID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 3
WPC_ARGS_CONVERSATIONLEAVEEVENT_LEAVINGIP: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 4
WPC_ARGS_CONVERSATIONLEAVEEVENT_LEAVINGUSER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 5
WPC_ARGS_CONVERSATIONLEAVEEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 6
WPC_ARGS_CONVERSATIONLEAVEEVENT_MEMBERCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 7
WPC_ARGS_CONVERSATIONLEAVEEVENT_MEMBER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 8
WPC_ARGS_CONVERSATIONLEAVEEVENT_FLAGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 9
WPC_ARGS_CONVERSATIONLEAVEEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CONVERSATIONLEAVEEVENT = 10
WPC_ARGS_CUSTOMEVENT = Int32
WPC_ARGS_CUSTOMEVENT_PUBLISHER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 0
WPC_ARGS_CUSTOMEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 1
WPC_ARGS_CUSTOMEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 2
WPC_ARGS_CUSTOMEVENT_EVENT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 3
WPC_ARGS_CUSTOMEVENT_VALUE1: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 4
WPC_ARGS_CUSTOMEVENT_VALUE2: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 5
WPC_ARGS_CUSTOMEVENT_VALUE3: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 6
WPC_ARGS_CUSTOMEVENT_BLOCKED: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 7
WPC_ARGS_CUSTOMEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 8
WPC_ARGS_CUSTOMEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_CUSTOMEVENT = 9
WPC_ARGS_EMAILCONTACTEVENT = Int32
WPC_ARGS_EMAILCONTACTEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 0
WPC_ARGS_EMAILCONTACTEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 1
WPC_ARGS_EMAILCONTACTEVENT_OLDNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 2
WPC_ARGS_EMAILCONTACTEVENT_OLDID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 3
WPC_ARGS_EMAILCONTACTEVENT_NEWNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 4
WPC_ARGS_EMAILCONTACTEVENT_NEWID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 5
WPC_ARGS_EMAILCONTACTEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 6
WPC_ARGS_EMAILCONTACTEVENT_EMAILACCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 7
WPC_ARGS_EMAILCONTACTEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILCONTACTEVENT = 8
WPC_ARGS_EMAILRECEIEVEDEVENT = Int32
WPC_ARGS_EMAILRECEIEVEDEVENT_SENDER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 0
WPC_ARGS_EMAILRECEIEVEDEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 1
WPC_ARGS_EMAILRECEIEVEDEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 2
WPC_ARGS_EMAILRECEIEVEDEVENT_SUBJECT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 3
WPC_ARGS_EMAILRECEIEVEDEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 4
WPC_ARGS_EMAILRECEIEVEDEVENT_RECIPCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 5
WPC_ARGS_EMAILRECEIEVEDEVENT_RECIPIENT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 6
WPC_ARGS_EMAILRECEIEVEDEVENT_ATTACHCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 7
WPC_ARGS_EMAILRECEIEVEDEVENT_ATTACHMENTNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 8
WPC_ARGS_EMAILRECEIEVEDEVENT_RECEIVEDTIME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 9
WPC_ARGS_EMAILRECEIEVEDEVENT_EMAILACCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 10
WPC_ARGS_EMAILRECEIEVEDEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILRECEIEVEDEVENT = 11
WPC_ARGS_EMAILSENTEVENT = Int32
WPC_ARGS_EMAILSENTEVENT_SENDER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 0
WPC_ARGS_EMAILSENTEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 1
WPC_ARGS_EMAILSENTEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 2
WPC_ARGS_EMAILSENTEVENT_SUBJECT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 3
WPC_ARGS_EMAILSENTEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 4
WPC_ARGS_EMAILSENTEVENT_RECIPCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 5
WPC_ARGS_EMAILSENTEVENT_RECIPIENT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 6
WPC_ARGS_EMAILSENTEVENT_ATTACHCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 7
WPC_ARGS_EMAILSENTEVENT_ATTACHMENTNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 8
WPC_ARGS_EMAILSENTEVENT_EMAILACCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 9
WPC_ARGS_EMAILSENTEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_EMAILSENTEVENT = 10
WPC_ARGS_FILEDOWNLOADEVENT = Int32
WPC_ARGS_FILEDOWNLOADEVENT_URL: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_FILEDOWNLOADEVENT = 0
WPC_ARGS_FILEDOWNLOADEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_FILEDOWNLOADEVENT = 1
WPC_ARGS_FILEDOWNLOADEVENT_VERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_FILEDOWNLOADEVENT = 2
WPC_ARGS_FILEDOWNLOADEVENT_BLOCKED: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_FILEDOWNLOADEVENT = 3
WPC_ARGS_FILEDOWNLOADEVENT_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_FILEDOWNLOADEVENT = 4
WPC_ARGS_FILEDOWNLOADEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_FILEDOWNLOADEVENT = 5
WPC_ARGS_GAMESTARTEVENT = Int32
WPC_ARGS_GAMESTARTEVENT_APPID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 0
WPC_ARGS_GAMESTARTEVENT_INSTANCEID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 1
WPC_ARGS_GAMESTARTEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 2
WPC_ARGS_GAMESTARTEVENT_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 3
WPC_ARGS_GAMESTARTEVENT_RATING: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 4
WPC_ARGS_GAMESTARTEVENT_RATINGSYSTEM: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 5
WPC_ARGS_GAMESTARTEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 6
WPC_ARGS_GAMESTARTEVENT_DESCCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 7
WPC_ARGS_GAMESTARTEVENT_DESCRIPTOR: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 8
WPC_ARGS_GAMESTARTEVENT_PID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 9
WPC_ARGS_GAMESTARTEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_GAMESTARTEVENT = 10
WPC_ARGS_IMCONTACTEVENT = Int32
WPC_ARGS_IMCONTACTEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 0
WPC_ARGS_IMCONTACTEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 1
WPC_ARGS_IMCONTACTEVENT_ACCOUNTNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 2
WPC_ARGS_IMCONTACTEVENT_OLDNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 3
WPC_ARGS_IMCONTACTEVENT_OLDID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 4
WPC_ARGS_IMCONTACTEVENT_NEWNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 5
WPC_ARGS_IMCONTACTEVENT_NEWID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 6
WPC_ARGS_IMCONTACTEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 7
WPC_ARGS_IMCONTACTEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMCONTACTEVENT = 8
WPC_ARGS_IMFEATUREEVENT = Int32
WPC_ARGS_IMFEATUREEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 0
WPC_ARGS_IMFEATUREEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 1
WPC_ARGS_IMFEATUREEVENT_ACCOUNTNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 2
WPC_ARGS_IMFEATUREEVENT_CONVID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 3
WPC_ARGS_IMFEATUREEVENT_MEDIATYPE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 4
WPC_ARGS_IMFEATUREEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 5
WPC_ARGS_IMFEATUREEVENT_RECIPCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 6
WPC_ARGS_IMFEATUREEVENT_RECIPIENT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 7
WPC_ARGS_IMFEATUREEVENT_SENDER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 8
WPC_ARGS_IMFEATUREEVENT_SENDERIP: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 9
WPC_ARGS_IMFEATUREEVENT_DATA: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 10
WPC_ARGS_IMFEATUREEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_IMFEATUREEVENT = 11
WPC_ARGS_MEDIADOWNLOADEVENT = Int32
WPC_ARGS_MEDIADOWNLOADEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 0
WPC_ARGS_MEDIADOWNLOADEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 1
WPC_ARGS_MEDIADOWNLOADEVENT_MEDIATYPE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 2
WPC_ARGS_MEDIADOWNLOADEVENT_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 3
WPC_ARGS_MEDIADOWNLOADEVENT_TITLE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 4
WPC_ARGS_MEDIADOWNLOADEVENT_PML: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 5
WPC_ARGS_MEDIADOWNLOADEVENT_ALBUM: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 6
WPC_ARGS_MEDIADOWNLOADEVENT_EXPLICIT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 7
WPC_ARGS_MEDIADOWNLOADEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 8
WPC_ARGS_MEDIADOWNLOADEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIADOWNLOADEVENT = 9
WPC_ARGS_MEDIAPLAYBACKEVENT = Int32
WPC_ARGS_MEDIAPLAYBACKEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 0
WPC_ARGS_MEDIAPLAYBACKEVENT_APPVERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 1
WPC_ARGS_MEDIAPLAYBACKEVENT_MEDIATYPE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 2
WPC_ARGS_MEDIAPLAYBACKEVENT_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 3
WPC_ARGS_MEDIAPLAYBACKEVENT_TITLE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 4
WPC_ARGS_MEDIAPLAYBACKEVENT_PML: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 5
WPC_ARGS_MEDIAPLAYBACKEVENT_ALBUM: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 6
WPC_ARGS_MEDIAPLAYBACKEVENT_EXPLICIT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 7
WPC_ARGS_MEDIAPLAYBACKEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 8
WPC_ARGS_MEDIAPLAYBACKEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_MEDIAPLAYBACKEVENT = 9
WPC_ARGS_SAFERAPPBLOCKED = Int32
WPC_ARGS_SAFERAPPBLOCKED_TIMESTAMP: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SAFERAPPBLOCKED = 0
WPC_ARGS_SAFERAPPBLOCKED_USERID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SAFERAPPBLOCKED = 1
WPC_ARGS_SAFERAPPBLOCKED_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SAFERAPPBLOCKED = 2
WPC_ARGS_SAFERAPPBLOCKED_RULEID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SAFERAPPBLOCKED = 3
WPC_ARGS_SAFERAPPBLOCKED_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SAFERAPPBLOCKED = 4
WPC_ARGS_SETTINGSCHANGEEVENT = Int32
WPC_ARGS_SETTINGSCHANGEEVENT_CLASS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SETTINGSCHANGEEVENT = 0
WPC_ARGS_SETTINGSCHANGEEVENT_SETTING: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SETTINGSCHANGEEVENT = 1
WPC_ARGS_SETTINGSCHANGEEVENT_OWNER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SETTINGSCHANGEEVENT = 2
WPC_ARGS_SETTINGSCHANGEEVENT_OLDVAL: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SETTINGSCHANGEEVENT = 3
WPC_ARGS_SETTINGSCHANGEEVENT_NEWVAL: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SETTINGSCHANGEEVENT = 4
WPC_ARGS_SETTINGSCHANGEEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SETTINGSCHANGEEVENT = 5
WPC_ARGS_SETTINGSCHANGEEVENT_OPTIONAL: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SETTINGSCHANGEEVENT = 6
WPC_ARGS_SETTINGSCHANGEEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_SETTINGSCHANGEEVENT = 7
WPC_ARGS_URLVISITEVENT = Int32
WPC_ARGS_URLVISITEVENT_URL: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_URLVISITEVENT = 0
WPC_ARGS_URLVISITEVENT_APPNAME: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_URLVISITEVENT = 1
WPC_ARGS_URLVISITEVENT_VERSION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_URLVISITEVENT = 2
WPC_ARGS_URLVISITEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_URLVISITEVENT = 3
WPC_ARGS_URLVISITEVENT_RATINGSYSTEMID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_URLVISITEVENT = 4
WPC_ARGS_URLVISITEVENT_CATCOUNT: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_URLVISITEVENT = 5
WPC_ARGS_URLVISITEVENT_CATEGORY: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_URLVISITEVENT = 6
WPC_ARGS_URLVISITEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_URLVISITEVENT = 7
WPC_ARGS_WEBOVERRIDEEVENT = Int32
WPC_ARGS_WEBOVERRIDEEVENT_USERID: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBOVERRIDEEVENT = 0
WPC_ARGS_WEBOVERRIDEEVENT_URL: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBOVERRIDEEVENT = 1
WPC_ARGS_WEBOVERRIDEEVENT_REASON: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBOVERRIDEEVENT = 2
WPC_ARGS_WEBOVERRIDEEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBOVERRIDEEVENT = 3
WPC_ARGS_WEBSITEVISITEVENT = Int32
WPC_ARGS_WEBSITEVISITEVENT_URL: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 0
WPC_ARGS_WEBSITEVISITEVENT_DECISION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 1
WPC_ARGS_WEBSITEVISITEVENT_CATEGORIES: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 2
WPC_ARGS_WEBSITEVISITEVENT_BLOCKEDCATEGORIES: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 3
WPC_ARGS_WEBSITEVISITEVENT_SERIALIZEDAPPLICATION: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 4
WPC_ARGS_WEBSITEVISITEVENT_TITLE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 5
WPC_ARGS_WEBSITEVISITEVENT_CONTENTTYPE: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 6
WPC_ARGS_WEBSITEVISITEVENT_REFERRER: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 7
WPC_ARGS_WEBSITEVISITEVENT_TELEMETRY: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 8
WPC_ARGS_WEBSITEVISITEVENT_CARGS: win32more.Windows.Win32.System.ParentalControls.WPC_ARGS_WEBSITEVISITEVENT = 9
WPC_MEDIA_EXPLICIT = Int32
WPC_MEDIA_EXPLICIT_FALSE: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_EXPLICIT = 0
WPC_MEDIA_EXPLICIT_TRUE: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_EXPLICIT = 1
WPC_MEDIA_EXPLICIT_UNKNOWN: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_EXPLICIT = 2
WPC_MEDIA_TYPE = Int32
WPC_MEDIA_TYPE_OTHER: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_TYPE = 0
WPC_MEDIA_TYPE_DVD: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_TYPE = 1
WPC_MEDIA_TYPE_RECORDED_TV: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_TYPE = 2
WPC_MEDIA_TYPE_AUDIO_FILE: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_TYPE = 3
WPC_MEDIA_TYPE_CD_AUDIO: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_TYPE = 4
WPC_MEDIA_TYPE_VIDEO_FILE: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_TYPE = 5
WPC_MEDIA_TYPE_PICTURE_FILE: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_TYPE = 6
WPC_MEDIA_TYPE_MAX: win32more.Windows.Win32.System.ParentalControls.WPC_MEDIA_TYPE = 7
WPC_SETTINGS = Int32
WPC_SETTINGS_WPC_EXTENSION_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 0
WPC_SETTINGS_WPC_EXTENSION_SILO: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 1
WPC_SETTINGS_WPC_EXTENSION_IMAGE_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 2
WPC_SETTINGS_WPC_EXTENSION_DISABLEDIMAGE_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 3
WPC_SETTINGS_WPC_EXTENSION_NAME: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 4
WPC_SETTINGS_WPC_EXTENSION_SUB_TITLE: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 5
WPC_SETTINGS_SYSTEM_CURRENT_RATING_SYSTEM: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 6
WPC_SETTINGS_SYSTEM_LAST_LOG_VIEW: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 7
WPC_SETTINGS_SYSTEM_LOG_VIEW_REMINDER_INTERVAL: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 8
WPC_SETTINGS_SYSTEM_HTTP_EXEMPTION_LIST: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 9
WPC_SETTINGS_SYSTEM_URL_EXEMPTION_LIST: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 10
WPC_SETTINGS_SYSTEM_FILTER_ID: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 11
WPC_SETTINGS_SYSTEM_FILTER_NAME: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 12
WPC_SETTINGS_SYSTEM_LOCALE: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 13
WPC_SETTINGS_ALLOW_BLOCK: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 14
WPC_SETTINGS_GAME_BLOCKED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 15
WPC_SETTINGS_GAME_ALLOW_UNRATED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 16
WPC_SETTINGS_GAME_MAX_ALLOWED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 17
WPC_SETTINGS_GAME_DENIED_DESCRIPTORS: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 18
WPC_SETTINGS_USER_WPC_ENABLED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 19
WPC_SETTINGS_USER_LOGGING_REQUIRED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 20
WPC_SETTINGS_USER_HOURLY_RESTRICTIONS: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 21
WPC_SETTINGS_USER_OVERRRIDE_REQUESTS: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 22
WPC_SETTINGS_USER_LOGON_HOURS: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 23
WPC_SETTINGS_USER_APP_RESTRICTIONS: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 24
WPC_SETTINGS_WEB_FILTER_ON: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 25
WPC_SETTINGS_WEB_DOWNLOAD_BLOCKED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 26
WPC_SETTINGS_WEB_FILTER_LEVEL: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 27
WPC_SETTINGS_WEB_BLOCKED_CATEGORY_LIST: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 28
WPC_SETTINGS_WEB_BLOCK_UNRATED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 29
WPC_SETTINGS_WPC_ENABLED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 30
WPC_SETTINGS_WPC_LOGGING_REQUIRED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 31
WPC_SETTINGS_RATING_SYSTEM_PATH: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 32
WPC_SETTINGS_WPC_PROVIDER_CURRENT: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 33
WPC_SETTINGS_USER_TIME_ALLOWANCE: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 34
WPC_SETTINGS_USER_TIME_ALLOWANCE_RESTRICTIONS: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 35
WPC_SETTINGS_GAME_RESTRICTED: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 36
WPC_SETTING_COUNT: win32more.Windows.Win32.System.ParentalControls.WPC_SETTINGS = 37
WindowsParentalControls = Guid('{e77cc89b-7401-4c04-8ced-149db35add04}')
WpcProviderSupport = Guid('{bb18c7a0-2186-4be0-97d8-04847b628e02}')
WpcSettingsProvider = Guid('{355dffaa-3b9f-435c-b428-5d44290bc5f2}')


make_ready(__name__)
