from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.DirectComposition
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.UI.Animation
UI_ANIMATION_SECONDS_EVENTUALLY: Int32 = -1
UI_ANIMATION_REPEAT_INDEFINITELY: Int32 = -1
UI_ANIMATION_REPEAT_INDEFINITELY_CONCLUDE_AT_END: Int32 = -1
UI_ANIMATION_REPEAT_INDEFINITELY_CONCLUDE_AT_START: Int32 = -2
UI_ANIMATION_SECONDS_INFINITE: Int32 = -1
class IUIAnimationInterpolator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7815cbba-ddf7-478c-a46c-7b6c738b7978}')
    @commethod(3)
    def SetInitialValueAndVelocity(self, initialValue: Double, initialVelocity: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetDuration(self, duration: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetDuration(self, duration: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetFinalValue(self, value: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def InterpolateValue(self, offset: Double, value: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def InterpolateVelocity(self, offset: Double, velocity: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetDependencies(self, initialValueDependencies: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES), initialVelocityDependencies: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES), durationDependencies: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationInterpolator2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ea76aff8-ea22-4a23-a0ef-a6a966703518}')
    @commethod(3)
    def GetDimension(self, dimension: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetInitialValueAndVelocity(self, initialValue: POINTER(Double), initialVelocity: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetDuration(self, duration: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetDuration(self, duration: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetFinalValue(self, value: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def InterpolateValue(self, offset: Double, value: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def InterpolateVelocity(self, offset: Double, velocity: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetPrimitiveInterpolation(self, interpolation: win32more.Windows.Win32.UI.Animation.IUIAnimationPrimitiveInterpolation, cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetDependencies(self, initialValueDependencies: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES), initialVelocityDependencies: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES), durationDependencies: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationLoopIterationChangeHandler2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{2d3b15a4-4762-47ab-a030-b23221df3ae0}')
    @commethod(3)
    def OnLoopIterationChanged(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2, id: UIntPtr, newIterationCount: UInt32, oldIterationCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9169896c-ac8d-4e7d-94e5-67fa4dc2f2e8}')
    @commethod(3)
    def CreateAnimationVariable(self, initialValue: Double, variable: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationVariable)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ScheduleTransition(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition, timeNow: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateStoryboard(self, storyboard: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def FinishAllStoryboards(self, completionDeadline: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def AbandonAllStoryboards(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Update(self, timeNow: Double, updateResult: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_UPDATE_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetVariableFromTag(self, object: win32more.Windows.Win32.System.Com.IUnknown, id: UInt32, variable: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationVariable)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetStoryboardFromTag(self, object: win32more.Windows.Win32.System.Com.IUnknown, id: UInt32, storyboard: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetStatus(self, status: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MANAGER_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetAnimationMode(self, mode: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def Pause(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Resume(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetManagerEventHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationManagerEventHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def SetCancelPriorityComparison(self, comparison: win32more.Windows.Win32.UI.Animation.IUIAnimationPriorityComparison) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def SetTrimPriorityComparison(self, comparison: win32more.Windows.Win32.UI.Animation.IUIAnimationPriorityComparison) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetCompressPriorityComparison(self, comparison: win32more.Windows.Win32.UI.Animation.IUIAnimationPriorityComparison) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def SetConcludePriorityComparison(self, comparison: win32more.Windows.Win32.UI.Animation.IUIAnimationPriorityComparison) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetDefaultLongestAcceptableDelay(self, delay: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def Shutdown(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationManager2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d8b6f7d4-4109-4d3f-acee-879926968cb1}')
    @commethod(3)
    def CreateAnimationVectorVariable(self, initialValue: POINTER(Double), cDimension: UInt32, variable: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateAnimationVariable(self, initialValue: Double, variable: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def ScheduleTransition(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2, timeNow: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateStoryboard(self, storyboard: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def FinishAllStoryboards(self, completionDeadline: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def AbandonAllStoryboards(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Update(self, timeNow: Double, updateResult: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_UPDATE_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetVariableFromTag(self, object: win32more.Windows.Win32.System.Com.IUnknown, id: UInt32, variable: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetStoryboardFromTag(self, object: win32more.Windows.Win32.System.Com.IUnknown, id: UInt32, storyboard: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def EstimateNextEventTime(self, seconds: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetStatus(self, status: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MANAGER_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SetAnimationMode(self, mode: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def Pause(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def Resume(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def SetManagerEventHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationManagerEventHandler2, fRegisterForNextAnimationEvent: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetCancelPriorityComparison(self, comparison: win32more.Windows.Win32.UI.Animation.IUIAnimationPriorityComparison2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def SetTrimPriorityComparison(self, comparison: win32more.Windows.Win32.UI.Animation.IUIAnimationPriorityComparison2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetCompressPriorityComparison(self, comparison: win32more.Windows.Win32.UI.Animation.IUIAnimationPriorityComparison2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def SetConcludePriorityComparison(self, comparison: win32more.Windows.Win32.UI.Animation.IUIAnimationPriorityComparison2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def SetDefaultLongestAcceptableDelay(self, delay: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def Shutdown(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationManagerEventHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{783321ed-78a3-4366-b574-6af607a64788}')
    @commethod(3)
    def OnManagerStatusChanged(self, newStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MANAGER_STATUS, previousStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MANAGER_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationManagerEventHandler2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f6e022ba-bff3-42ec-9033-e073f33e83c3}')
    @commethod(3)
    def OnManagerStatusChanged(self, newStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MANAGER_STATUS, previousStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MANAGER_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationPrimitiveInterpolation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bab20d63-4361-45da-a24f-ab8508846b5b}')
    @commethod(3)
    def AddCubic(self, dimension: UInt32, beginOffset: Double, constantCoefficient: Single, linearCoefficient: Single, quadraticCoefficient: Single, cubicCoefficient: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddSinusoidal(self, dimension: UInt32, beginOffset: Double, bias: Single, amplitude: Single, frequency: Single, phase: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationPriorityComparison(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{83fa9b74-5f86-4618-bc6a-a2fac19b3f44}')
    @commethod(3)
    def HasPriority(self, scheduledStoryboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard, newStoryboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard, priorityEffect: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_PRIORITY_EFFECT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationPriorityComparison2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5b6d7a37-4621-467c-8b05-70131de62ddb}')
    @commethod(3)
    def HasPriority(self, scheduledStoryboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2, newStoryboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2, priorityEffect: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_PRIORITY_EFFECT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationStoryboard(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a8ff128f-9bf9-4af1-9e67-e5e410defb84}')
    @commethod(3)
    def AddTransition(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddKeyframeAtOffset(self, existingKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME, offset: Double, keyframe: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def AddKeyframeAfterTransition(self, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition, keyframe: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def AddTransitionAtKeyframe(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition, startKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def AddTransitionBetweenKeyframes(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition, startKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME, endKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def RepeatBetweenKeyframes(self, startKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME, endKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME, repetitionCount: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def HoldVariable(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetLongestAcceptableDelay(self, delay: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Schedule(self, timeNow: Double, schedulingResult: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SCHEDULING_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Conclude(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def Finish(self, completionDeadline: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Abandon(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetTag(self, object: win32more.Windows.Win32.System.Com.IUnknown, id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetTag(self, object: POINTER(win32more.Windows.Win32.System.Com.IUnknown), id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetStatus(self, status: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetElapsedTime(self, elapsedTime: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def SetStoryboardEventHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboardEventHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationStoryboard2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ae289cd2-12d4-4945-9419-9e41be034df2}')
    @commethod(3)
    def AddTransition(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddKeyframeAtOffset(self, existingKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME, offset: Double, keyframe: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def AddKeyframeAfterTransition(self, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2, keyframe: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def AddTransitionAtKeyframe(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2, startKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def AddTransitionBetweenKeyframes(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2, startKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME, endKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def RepeatBetweenKeyframes(self, startKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME, endKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME, cRepetition: Double, repeatMode: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_REPEAT_MODE, pIterationChangeHandler: win32more.Windows.Win32.UI.Animation.IUIAnimationLoopIterationChangeHandler2, id: UIntPtr, fRegisterForNextAnimationEvent: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def HoldVariable(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetLongestAcceptableDelay(self, delay: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetSkipDuration(self, secondsDuration: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Schedule(self, timeNow: Double, schedulingResult: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SCHEDULING_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def Conclude(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Finish(self, completionDeadline: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def Abandon(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def SetTag(self, object: win32more.Windows.Win32.System.Com.IUnknown, id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetTag(self, object: POINTER(win32more.Windows.Win32.System.Com.IUnknown), id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetStatus(self, status: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetElapsedTime(self, elapsedTime: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetStoryboardEventHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboardEventHandler2, fRegisterStatusChangeForNextAnimationEvent: win32more.Windows.Win32.Foundation.BOOL, fRegisterUpdateForNextAnimationEvent: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationStoryboardEventHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3d5c9008-ec7c-4364-9f8a-9af3c58cbae6}')
    @commethod(3)
    def OnStoryboardStatusChanged(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard, newStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS, previousStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnStoryboardUpdated(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationStoryboardEventHandler2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bac5f55a-ba7c-414c-b599-fbf850f553c6}')
    @commethod(3)
    def OnStoryboardStatusChanged(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2, newStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS, previousStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnStoryboardUpdated(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTimer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6b0efad1-a053-41d6-9085-33a689144665}')
    @commethod(3)
    def SetTimerUpdateHandler(self, updateHandler: win32more.Windows.Win32.UI.Animation.IUIAnimationTimerUpdateHandler, idleBehavior: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_IDLE_BEHAVIOR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetTimerEventHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationTimerEventHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Enable(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Disable(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def IsEnabled(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetTime(self, seconds: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetFrameRateThreshold(self, framesPerSecond: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTimerClientEventHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bedb4db6-94fa-4bfb-a47f-ef2d9e408c25}')
    @commethod(3)
    def OnTimerClientStatusChanged(self, newStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_TIMER_CLIENT_STATUS, previousStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_TIMER_CLIENT_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTimerEventHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{274a7dea-d771-4095-abbd-8df7abd23ce3}')
    @commethod(3)
    def OnPreUpdate(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnPostUpdate(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def OnRenderingTooSlow(self, framesPerSecond: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTimerUpdateHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{195509b7-5d5e-4e3e-b278-ee3759b367ad}')
    @commethod(3)
    def OnUpdate(self, timeNow: Double, result: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_UPDATE_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetTimerClientEventHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationTimerClientEventHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def ClearTimerClientEventHandler(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTransition(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{dc6ce252-f731-41cf-b610-614b6ca049ad}')
    @commethod(3)
    def SetInitialValue(self, value: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetInitialVelocity(self, velocity: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def IsDurationKnown(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetDuration(self, duration: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTransition2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{62ff9123-a85a-4e9b-a218-435a93e268fd}')
    @commethod(3)
    def GetDimension(self, dimension: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetInitialValue(self, value: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetInitialVectorValue(self, value: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetInitialVelocity(self, velocity: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetInitialVectorVelocity(self, velocity: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def IsDurationKnown(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetDuration(self, duration: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTransitionFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{fcd91e03-3e3b-45ad-bbb1-6dfc8153743d}')
    @commethod(3)
    def CreateTransition(self, interpolator: win32more.Windows.Win32.UI.Animation.IUIAnimationInterpolator, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTransitionFactory2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{937d4916-c1a6-42d5-88d8-30344d6efe31}')
    @commethod(3)
    def CreateTransition(self, interpolator: win32more.Windows.Win32.UI.Animation.IUIAnimationInterpolator2, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTransitionLibrary(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ca5a14b1-d24f-48b8-8fe4-c78169ba954e}')
    @commethod(3)
    def CreateInstantaneousTransition(self, finalValue: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateConstantTransition(self, duration: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateDiscreteTransition(self, delay: Double, finalValue: Double, hold: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateLinearTransition(self, duration: Double, finalValue: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreateLinearTransitionFromSpeed(self, speed: Double, finalValue: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateSinusoidalTransitionFromVelocity(self, duration: Double, period: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CreateSinusoidalTransitionFromRange(self, duration: Double, minimumValue: Double, maximumValue: Double, period: Double, slope: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SLOPE, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CreateAccelerateDecelerateTransition(self, duration: Double, finalValue: Double, accelerationRatio: Double, decelerationRatio: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateReversalTransition(self, duration: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def CreateCubicTransition(self, duration: Double, finalValue: Double, finalVelocity: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateSmoothStopTransition(self, maximumDuration: Double, finalValue: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateParabolicTransitionFromAcceleration(self, finalValue: Double, finalVelocity: Double, acceleration: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTransitionLibrary2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{03cfae53-9580-4ee3-b363-2ece51b4af6a}')
    @commethod(3)
    def CreateInstantaneousTransition(self, finalValue: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateInstantaneousVectorTransition(self, finalValue: POINTER(Double), cDimension: UInt32, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateConstantTransition(self, duration: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateDiscreteTransition(self, delay: Double, finalValue: Double, hold: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreateDiscreteVectorTransition(self, delay: Double, finalValue: POINTER(Double), cDimension: UInt32, hold: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateLinearTransition(self, duration: Double, finalValue: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CreateLinearVectorTransition(self, duration: Double, finalValue: POINTER(Double), cDimension: UInt32, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CreateLinearTransitionFromSpeed(self, speed: Double, finalValue: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateLinearVectorTransitionFromSpeed(self, speed: Double, finalValue: POINTER(Double), cDimension: UInt32, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def CreateSinusoidalTransitionFromVelocity(self, duration: Double, period: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateSinusoidalTransitionFromRange(self, duration: Double, minimumValue: Double, maximumValue: Double, period: Double, slope: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SLOPE, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateAccelerateDecelerateTransition(self, duration: Double, finalValue: Double, accelerationRatio: Double, decelerationRatio: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def CreateReversalTransition(self, duration: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def CreateCubicTransition(self, duration: Double, finalValue: Double, finalVelocity: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def CreateCubicVectorTransition(self, duration: Double, finalValue: POINTER(Double), finalVelocity: POINTER(Double), cDimension: UInt32, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def CreateSmoothStopTransition(self, maximumDuration: Double, finalValue: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def CreateParabolicTransitionFromAcceleration(self, finalValue: Double, finalVelocity: Double, acceleration: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def CreateCubicBezierLinearTransition(self, duration: Double, finalValue: Double, x1: Double, y1: Double, x2: Double, y2: Double, ppTransition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def CreateCubicBezierLinearVectorTransition(self, duration: Double, finalValue: POINTER(Double), cDimension: UInt32, x1: Double, y1: Double, x2: Double, y2: Double, ppTransition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationVariable(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8ceeb155-2849-4ce5-9448-91ff70e1e4d9}')
    @commethod(3)
    def GetValue(self, value: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetFinalValue(self, finalValue: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetPreviousValue(self, previousValue: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetIntegerValue(self, value: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetFinalIntegerValue(self, finalValue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetPreviousIntegerValue(self, previousValue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetCurrentStoryboard(self, storyboard: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetLowerBound(self, bound: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetUpperBound(self, bound: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetRoundingMode(self, mode: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_ROUNDING_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetTag(self, object: win32more.Windows.Win32.System.Com.IUnknown, id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetTag(self, object: POINTER(win32more.Windows.Win32.System.Com.IUnknown), id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetVariableChangeHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationVariableChangeHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def SetVariableIntegerChangeHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationVariableIntegerChangeHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationVariable2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4914b304-96ab-44d9-9e77-d5109b7e7466}')
    @commethod(3)
    def GetDimension(self, dimension: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetValue(self, value: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetVectorValue(self, value: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetCurve(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetVectorCurve(self, animation: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetFinalValue(self, finalValue: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetFinalVectorValue(self, finalValue: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetPreviousValue(self, previousValue: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetPreviousVectorValue(self, previousValue: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetIntegerValue(self, value: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetIntegerVectorValue(self, value: POINTER(Int32), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetFinalIntegerValue(self, finalValue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetFinalIntegerVectorValue(self, finalValue: POINTER(Int32), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetPreviousIntegerValue(self, previousValue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetPreviousIntegerVectorValue(self, previousValue: POINTER(Int32), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetCurrentStoryboard(self, storyboard: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def SetLowerBound(self, bound: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetLowerBoundVector(self, bound: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def SetUpperBound(self, bound: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def SetUpperBoundVector(self, bound: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def SetRoundingMode(self, mode: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_ROUNDING_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def SetTag(self, object: win32more.Windows.Win32.System.Com.IUnknown, id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def GetTag(self, object: POINTER(win32more.Windows.Win32.System.Com.IUnknown), id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def SetVariableChangeHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationVariableChangeHandler2, fRegisterForNextAnimationEvent: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def SetVariableIntegerChangeHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationVariableIntegerChangeHandler2, fRegisterForNextAnimationEvent: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def SetVariableCurveChangeHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationVariableCurveChangeHandler2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationVariableChangeHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6358b7ba-87d2-42d5-bf71-82e919dd5862}')
    @commethod(3)
    def OnValueChanged(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable, newValue: Double, previousValue: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationVariableChangeHandler2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{63acc8d2-6eae-4bb0-b879-586dd8cfbe42}')
    @commethod(3)
    def OnValueChanged(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2, newValue: POINTER(Double), previousValue: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationVariableCurveChangeHandler2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{72895e91-0145-4c21-9192-5aab40eddf80}')
    @commethod(3)
    def OnCurveChanged(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationVariableIntegerChangeHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bb3e1550-356e-44b0-99da-85ac6017865e}')
    @commethod(3)
    def OnIntegerValueChanged(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable, newValue: Int32, previousValue: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationVariableIntegerChangeHandler2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{829b6cf1-4f3a-4412-ae09-b243eb4c6b58}')
    @commethod(3)
    def OnIntegerValueChanged(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2, newValue: POINTER(Int32), previousValue: POINTER(Int32), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
UIAnimationManager = Guid('{4c1fc63a-695c-47e8-a339-1a194be3d0b8}')
UIAnimationManager2 = Guid('{d25d8842-8884-4a4a-b321-091314379bdd}')
UIAnimationTimer = Guid('{bfcd4a0c-06b6-4384-b768-0daa792c380e}')
UIAnimationTransitionFactory = Guid('{8a9b1cdd-fcd7-419c-8b44-42fd17db1887}')
UIAnimationTransitionFactory2 = Guid('{84302f97-7f7b-4040-b190-72ac9d18e420}')
UIAnimationTransitionLibrary = Guid('{1d6322ad-aa85-4ef5-a828-86d71067d145}')
UIAnimationTransitionLibrary2 = Guid('{812f944a-c5c8-4cd9-b0a6-b3da802f228d}')
UI_ANIMATION_DEPENDENCIES = Int32
UI_ANIMATION_DEPENDENCY_NONE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES = 0
UI_ANIMATION_DEPENDENCY_INTERMEDIATE_VALUES: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES = 1
UI_ANIMATION_DEPENDENCY_FINAL_VALUE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES = 2
UI_ANIMATION_DEPENDENCY_FINAL_VELOCITY: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES = 4
UI_ANIMATION_DEPENDENCY_DURATION: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES = 8
UI_ANIMATION_IDLE_BEHAVIOR = Int32
UI_ANIMATION_IDLE_BEHAVIOR_CONTINUE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_IDLE_BEHAVIOR = 0
UI_ANIMATION_IDLE_BEHAVIOR_DISABLE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_IDLE_BEHAVIOR = 1
UI_ANIMATION_KEYFRAME = IntPtr
UI_ANIMATION_MANAGER_STATUS = Int32
UI_ANIMATION_MANAGER_IDLE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MANAGER_STATUS = 0
UI_ANIMATION_MANAGER_BUSY: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MANAGER_STATUS = 1
UI_ANIMATION_MODE = Int32
UI_ANIMATION_MODE_DISABLED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MODE = 0
UI_ANIMATION_MODE_SYSTEM_DEFAULT: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MODE = 1
UI_ANIMATION_MODE_ENABLED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MODE = 2
UI_ANIMATION_PRIORITY_EFFECT = Int32
UI_ANIMATION_PRIORITY_EFFECT_FAILURE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_PRIORITY_EFFECT = 0
UI_ANIMATION_PRIORITY_EFFECT_DELAY: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_PRIORITY_EFFECT = 1
UI_ANIMATION_REPEAT_MODE = Int32
UI_ANIMATION_REPEAT_MODE_NORMAL: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_REPEAT_MODE = 0
UI_ANIMATION_REPEAT_MODE_ALTERNATE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_REPEAT_MODE = 1
UI_ANIMATION_ROUNDING_MODE = Int32
UI_ANIMATION_ROUNDING_NEAREST: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_ROUNDING_MODE = 0
UI_ANIMATION_ROUNDING_FLOOR: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_ROUNDING_MODE = 1
UI_ANIMATION_ROUNDING_CEILING: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_ROUNDING_MODE = 2
UI_ANIMATION_SCHEDULING_RESULT = Int32
UI_ANIMATION_SCHEDULING_UNEXPECTED_FAILURE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SCHEDULING_RESULT = 0
UI_ANIMATION_SCHEDULING_INSUFFICIENT_PRIORITY: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SCHEDULING_RESULT = 1
UI_ANIMATION_SCHEDULING_ALREADY_SCHEDULED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SCHEDULING_RESULT = 2
UI_ANIMATION_SCHEDULING_SUCCEEDED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SCHEDULING_RESULT = 3
UI_ANIMATION_SCHEDULING_DEFERRED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SCHEDULING_RESULT = 4
UI_ANIMATION_SLOPE = Int32
UI_ANIMATION_SLOPE_INCREASING: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SLOPE = 0
UI_ANIMATION_SLOPE_DECREASING: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SLOPE = 1
UI_ANIMATION_STORYBOARD_STATUS = Int32
UI_ANIMATION_STORYBOARD_BUILDING: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS = 0
UI_ANIMATION_STORYBOARD_SCHEDULED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS = 1
UI_ANIMATION_STORYBOARD_CANCELLED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS = 2
UI_ANIMATION_STORYBOARD_PLAYING: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS = 3
UI_ANIMATION_STORYBOARD_TRUNCATED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS = 4
UI_ANIMATION_STORYBOARD_FINISHED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS = 5
UI_ANIMATION_STORYBOARD_READY: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS = 6
UI_ANIMATION_STORYBOARD_INSUFFICIENT_PRIORITY: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS = 7
UI_ANIMATION_TIMER_CLIENT_STATUS = Int32
UI_ANIMATION_TIMER_CLIENT_IDLE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_TIMER_CLIENT_STATUS = 0
UI_ANIMATION_TIMER_CLIENT_BUSY: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_TIMER_CLIENT_STATUS = 1
UI_ANIMATION_UPDATE_RESULT = Int32
UI_ANIMATION_UPDATE_NO_CHANGE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_UPDATE_RESULT = 0
UI_ANIMATION_UPDATE_VARIABLES_CHANGED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_UPDATE_RESULT = 1


make_ready(__name__)
