from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Graphics.Printing
import win32more.Windows.Graphics.Printing.OptionDetails
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class IPrintBindingOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintBindingOptionDetails'
    _iid_ = Guid('{c3f4cc98-9564-4f16-a055-a98b9a49e9d3}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintBorderingOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintBorderingOptionDetails'
    _iid_ = Guid('{4d73bc8f-fb53-4eb2-985f-1d91de0b7639}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintCollationOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCollationOptionDetails'
    _iid_ = Guid('{d6abb166-a5a6-40dc-acc3-739f28f1e5d3}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintColorModeOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintColorModeOptionDetails'
    _iid_ = Guid('{dba97704-f1d6-4843-a484-9b447cdcf3b6}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintCopiesOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCopiesOptionDetails'
    _iid_ = Guid('{42053099-4339-4343-898d-2c47b5e0c341}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintCustomItemDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCustomItemDetails'
    _iid_ = Guid('{5704b637-5c3a-449a-aa36-b3291b1192fd}')
    @winrt_commethod(6)
    def get_ItemId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_ItemDisplayName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_ItemDisplayName(self) -> WinRT_String: ...
    ItemDisplayName = property(get_ItemDisplayName, put_ItemDisplayName)
    ItemId = property(get_ItemId, None)
class IPrintCustomItemListOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails'
    _iid_ = Guid('{a5fafd88-58f2-4ebd-b90f-51e4f2944c5d}')
    @winrt_commethod(6)
    def AddItem(self, itemId: WinRT_String, displayName: WinRT_String) -> Void: ...
class IPrintCustomItemListOptionDetails2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails2'
    _iid_ = Guid('{c9d6353d-651c-4a39-906e-1091a1801bf1}')
    @winrt_commethod(6)
    def AddItem(self, itemId: WinRT_String, displayName: WinRT_String, description: WinRT_String, icon: win32more.Windows.Storage.Streams.IRandomAccessStreamWithContentType) -> Void: ...
class IPrintCustomItemListOptionDetails3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails3'
    _iid_ = Guid('{4fa1b53f-3c34-4868-a407-fc5eab259b21}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintCustomOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCustomOptionDetails'
    _iid_ = Guid('{e32bde1c-28af-4b90-95da-a3acf320b929}')
    @winrt_commethod(6)
    def put_DisplayName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_DisplayName(self) -> WinRT_String: ...
    DisplayName = property(get_DisplayName, put_DisplayName)
class IPrintCustomTextOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCustomTextOptionDetails'
    _iid_ = Guid('{2ad171f8-c8bd-4905-9192-0d75136e8b31}')
    @winrt_commethod(6)
    def put_MaxCharacters(self, value: UInt32) -> Void: ...
    @winrt_commethod(7)
    def get_MaxCharacters(self) -> UInt32: ...
    MaxCharacters = property(get_MaxCharacters, put_MaxCharacters)
class IPrintCustomTextOptionDetails2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCustomTextOptionDetails2'
    _iid_ = Guid('{cea70b54-b977-4718-8338-7ed2b0d86fe3}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintCustomToggleOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCustomToggleOptionDetails'
    _iid_ = Guid('{9db4d514-e461-4608-8ee9-db6f5ed073c6}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintDuplexOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintDuplexOptionDetails'
    _iid_ = Guid('{fcd94591-d4a4-44fa-b3fe-42e0ba28d5ad}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintHolePunchOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintHolePunchOptionDetails'
    _iid_ = Guid('{a6de1f18-482c-4657-9d71-8ddddbea1e1e}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintItemListOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails'
    _iid_ = Guid('{9a2257bf-fe61-43d8-a24f-a3f6ab7320e7}')
    @winrt_commethod(6)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    Items = property(get_Items, None)
class IPrintMediaSizeOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintMediaSizeOptionDetails'
    _iid_ = Guid('{6c8d5bcf-c0bf-47c8-b84a-628e7d0d1a1d}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintMediaTypeOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintMediaTypeOptionDetails'
    _iid_ = Guid('{f8c7000b-abf3-4abc-8e86-22abc5744a43}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintNumberOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintNumberOptionDetails'
    _iid_ = Guid('{4d01bbaf-645c-4de9-965f-6fc6bbc47cab}')
    @winrt_commethod(6)
    def get_MinValue(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_MaxValue(self) -> UInt32: ...
    MaxValue = property(get_MaxValue, None)
    MinValue = property(get_MinValue, None)
class IPrintOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails'
    _iid_ = Guid('{390686cf-d682-495f-adfe-d7333f5c1808}')
    @winrt_commethod(6)
    def get_OptionId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_OptionType(self) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_commethod(8)
    def put_ErrorText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_ErrorText(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def put_State(self, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_commethod(11)
    def get_State(self) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_commethod(12)
    def get_Value(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(13)
    def TrySetValue(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    ErrorText = property(get_ErrorText, put_ErrorText)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
class IPrintOrientationOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintOrientationOptionDetails'
    _iid_ = Guid('{46c38879-66e0-4da0-87b4-d25457824eb7}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintPageRangeOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintPageRangeOptionDetails'
    _iid_ = Guid('{5a19e4b7-2be8-4aa7-9ea5-defbe8713b4e}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintQualityOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintQualityOptionDetails'
    _iid_ = Guid('{2dd06ba1-ce1a-44e6-84f9-3a92ea1e3044}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintStapleOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintStapleOptionDetails'
    _iid_ = Guid('{d43175bd-9c0b-44e0-84f6-ceebce653800}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintTaskOptionChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionChangedEventArgs'
    _iid_ = Guid('{65197d05-a5ee-4307-9407-9acad147679c}')
    @winrt_commethod(6)
    def get_OptionId(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    OptionId = property(get_OptionId, None)
class IPrintTaskOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails'
    _iid_ = Guid('{f5720af1-a89e-42a6-81af-f8e010b38a68}')
    @winrt_commethod(6)
    def get_Options(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails]: ...
    @winrt_commethod(7)
    def CreateItemListOption(self, optionId: WinRT_String, displayName: WinRT_String) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintCustomItemListOptionDetails: ...
    @winrt_commethod(8)
    def CreateTextOption(self, optionId: WinRT_String, displayName: WinRT_String) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintCustomTextOptionDetails: ...
    @winrt_commethod(9)
    def add_OptionChanged(self, eventHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Printing.OptionDetails.PrintTaskOptionDetails, win32more.Windows.Graphics.Printing.OptionDetails.PrintTaskOptionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_OptionChanged(self, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(11)
    def add_BeginValidation(self, eventHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Printing.OptionDetails.PrintTaskOptionDetails, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_BeginValidation(self, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Options = property(get_Options, None)
    OptionChanged = event()
    BeginValidation = event()
class IPrintTaskOptionDetails2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails2'
    _iid_ = Guid('{53730a09-f968-4692-a177-c074597186db}')
    @winrt_commethod(6)
    def CreateToggleOption(self, optionId: WinRT_String, displayName: WinRT_String) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintCustomToggleOptionDetails: ...
class IPrintTaskOptionDetailsStatic(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetailsStatic'
    _iid_ = Guid('{135da193-0961-4b6e-8766-f13b7fbccd58}')
    @winrt_commethod(6)
    def GetFromPrintTaskOptions(self, printTaskOptions: win32more.Windows.Graphics.Printing.PrintTaskOptions) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintTaskOptionDetails: ...
class IPrintTextOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintTextOptionDetails'
    _iid_ = Guid('{ad75e563-5ce4-46bc-9918-ab9fad144c5b}')
    @winrt_commethod(6)
    def get_MaxCharacters(self) -> UInt32: ...
    MaxCharacters = property(get_MaxCharacters, None)
class PrintBindingOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintBindingOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintBindingOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintBindingOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintBindingOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintBindingOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintBorderingOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintBorderingOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintBorderingOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintBorderingOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintBorderingOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintBorderingOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintCollationOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintCollationOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCollationOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCollationOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCollationOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCollationOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintColorModeOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintColorModeOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintColorModeOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintColorModeOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintColorModeOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintColorModeOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintCopiesOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintCopiesOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_MinValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintNumberOptionDetails) -> UInt32: ...
    @winrt_mixinmethod
    def get_MaxValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintNumberOptionDetails) -> UInt32: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCopiesOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCopiesOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCopiesOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCopiesOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    MaxValue = property(get_MaxValue, None)
    MinValue = property(get_MinValue, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintCustomItemDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintCustomItemDetails'
    @winrt_mixinmethod
    def get_ItemId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ItemDisplayName(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ItemDisplayName(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemDetails) -> WinRT_String: ...
    ItemDisplayName = property(get_ItemDisplayName, put_ItemDisplayName)
    ItemId = property(get_ItemId, None)
class PrintCustomItemListOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintCustomItemListOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def put_DisplayName(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_overload
    @winrt_mixinmethod
    def AddItem(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails, itemId: WinRT_String, displayName: WinRT_String) -> Void: ...
    @AddItem.register
    @winrt_mixinmethod
    def AddItem(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails2, itemId: WinRT_String, displayName: WinRT_String, description: WinRT_String, icon: win32more.Windows.Storage.Streams.IRandomAccessStreamWithContentType) -> Void: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails3, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails3) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails3, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails3) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    DisplayName = property(get_DisplayName, put_DisplayName)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintCustomTextOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintCustomTextOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def put_DisplayName(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_MaxCharacters(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomTextOptionDetails, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_MaxCharacters(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomTextOptionDetails) -> UInt32: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomTextOptionDetails2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomTextOptionDetails2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomTextOptionDetails2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomTextOptionDetails2) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    DisplayName = property(get_DisplayName, put_DisplayName)
    ErrorText = property(get_ErrorText, put_ErrorText)
    MaxCharacters = property(get_MaxCharacters, put_MaxCharacters)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintCustomToggleOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintCustomToggleOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def put_DisplayName(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomToggleOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomToggleOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomToggleOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomToggleOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    DisplayName = property(get_DisplayName, put_DisplayName)
    ErrorText = property(get_ErrorText, put_ErrorText)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintDuplexOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintDuplexOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintDuplexOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintDuplexOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintDuplexOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintDuplexOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintHolePunchOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintHolePunchOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintHolePunchOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintHolePunchOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintHolePunchOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintHolePunchOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintMediaSizeOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintMediaSizeOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintMediaSizeOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintMediaSizeOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintMediaSizeOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintMediaSizeOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintMediaTypeOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintMediaTypeOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintMediaTypeOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintMediaTypeOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintMediaTypeOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintMediaTypeOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintOptionStates(Enum, UInt32):
    None_ = 0
    Enabled = 1
    Constrained = 2
class PrintOptionType(Enum, Int32):
    Unknown = 0
    Number = 1
    Text = 2
    ItemList = 3
    Toggle = 4
class PrintOrientationOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintOrientationOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOrientationOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOrientationOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOrientationOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOrientationOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintPageRangeOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintPageRangeOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintPageRangeOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintPageRangeOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintPageRangeOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintPageRangeOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintQualityOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintQualityOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintQualityOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintQualityOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintQualityOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintQualityOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintStapleOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintStapleOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintStapleOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintStapleOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintStapleOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintStapleOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintTaskOptionChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionChangedEventArgs
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintTaskOptionChangedEventArgs'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionChangedEventArgs) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    OptionId = property(get_OptionId, None)
class PrintTaskOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintTaskOptionDetails'
    @winrt_mixinmethod
    def get_Options(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails]: ...
    @winrt_mixinmethod
    def CreateItemListOption(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails, optionId: WinRT_String, displayName: WinRT_String) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintCustomItemListOptionDetails: ...
    @winrt_mixinmethod
    def CreateTextOption(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails, optionId: WinRT_String, displayName: WinRT_String) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintCustomTextOptionDetails: ...
    @winrt_mixinmethod
    def add_OptionChanged(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails, eventHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Printing.OptionDetails.PrintTaskOptionDetails, win32more.Windows.Graphics.Printing.OptionDetails.PrintTaskOptionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_OptionChanged(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_BeginValidation(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails, eventHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Printing.OptionDetails.PrintTaskOptionDetails, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_BeginValidation(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetPageDescription(self: win32more.Windows.Graphics.Printing.IPrintTaskOptionsCore, jobPageNumber: UInt32) -> win32more.Windows.Graphics.Printing.PrintPageDescription: ...
    @winrt_mixinmethod
    def get_DisplayedOptions(self: win32more.Windows.Graphics.Printing.IPrintTaskOptionsCoreUIConfiguration) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_mixinmethod
    def CreateToggleOption(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails2, optionId: WinRT_String, displayName: WinRT_String) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintCustomToggleOptionDetails: ...
    @winrt_classmethod
    def GetFromPrintTaskOptions(cls: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetailsStatic, printTaskOptions: win32more.Windows.Graphics.Printing.PrintTaskOptions) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintTaskOptionDetails: ...
    DisplayedOptions = property(get_DisplayedOptions, None)
    Options = property(get_Options, None)
    OptionChanged = event()
    BeginValidation = event()


make_ready(__name__)
