from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Direct3D
import win32more.Windows.Win32.Graphics.Direct3D12
import win32more.Windows.Win32.Graphics.Dxgi.Common
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.System.Com
D3D12_SHADER_COMPONENT_MAPPING_ALWAYS_SET_BIT_AVOIDING_ZEROMEM_MISTAKES: UInt32 = 4096
D3D12_DEFAULT_SHADER_4_COMPONENT_MAPPING: UInt32 = 5768
D3D12_16BIT_INDEX_STRIP_CUT_VALUE: UInt32 = 65535
D3D12_32BIT_INDEX_STRIP_CUT_VALUE: UInt32 = 4294967295
D3D12_8BIT_INDEX_STRIP_CUT_VALUE: UInt32 = 255
D3D12_APPEND_ALIGNED_ELEMENT: UInt32 = 4294967295
D3D12_ARRAY_AXIS_ADDRESS_RANGE_BIT_COUNT: UInt32 = 9
D3D12_CLIP_OR_CULL_DISTANCE_COUNT: UInt32 = 8
D3D12_CLIP_OR_CULL_DISTANCE_ELEMENT_COUNT: UInt32 = 2
D3D12_COMMONSHADER_CONSTANT_BUFFER_API_SLOT_COUNT: UInt32 = 14
D3D12_COMMONSHADER_CONSTANT_BUFFER_COMPONENTS: UInt32 = 4
D3D12_COMMONSHADER_CONSTANT_BUFFER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_COMMONSHADER_CONSTANT_BUFFER_HW_SLOT_COUNT: UInt32 = 15
D3D12_COMMONSHADER_CONSTANT_BUFFER_PARTIAL_UPDATE_EXTENTS_BYTE_ALIGNMENT: UInt32 = 16
D3D12_COMMONSHADER_CONSTANT_BUFFER_REGISTER_COMPONENTS: UInt32 = 4
D3D12_COMMONSHADER_CONSTANT_BUFFER_REGISTER_COUNT: UInt32 = 15
D3D12_COMMONSHADER_CONSTANT_BUFFER_REGISTER_READS_PER_INST: UInt32 = 1
D3D12_COMMONSHADER_CONSTANT_BUFFER_REGISTER_READ_PORTS: UInt32 = 1
D3D12_COMMONSHADER_FLOWCONTROL_NESTING_LIMIT: UInt32 = 64
D3D12_COMMONSHADER_IMMEDIATE_CONSTANT_BUFFER_REGISTER_COMPONENTS: UInt32 = 4
D3D12_COMMONSHADER_IMMEDIATE_CONSTANT_BUFFER_REGISTER_COUNT: UInt32 = 1
D3D12_COMMONSHADER_IMMEDIATE_CONSTANT_BUFFER_REGISTER_READS_PER_INST: UInt32 = 1
D3D12_COMMONSHADER_IMMEDIATE_CONSTANT_BUFFER_REGISTER_READ_PORTS: UInt32 = 1
D3D12_COMMONSHADER_IMMEDIATE_VALUE_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_COMMONSHADER_INPUT_RESOURCE_REGISTER_COMPONENTS: UInt32 = 1
D3D12_COMMONSHADER_INPUT_RESOURCE_REGISTER_COUNT: UInt32 = 128
D3D12_COMMONSHADER_INPUT_RESOURCE_REGISTER_READS_PER_INST: UInt32 = 1
D3D12_COMMONSHADER_INPUT_RESOURCE_REGISTER_READ_PORTS: UInt32 = 1
D3D12_COMMONSHADER_INPUT_RESOURCE_SLOT_COUNT: UInt32 = 128
D3D12_COMMONSHADER_SAMPLER_REGISTER_COMPONENTS: UInt32 = 1
D3D12_COMMONSHADER_SAMPLER_REGISTER_COUNT: UInt32 = 16
D3D12_COMMONSHADER_SAMPLER_REGISTER_READS_PER_INST: UInt32 = 1
D3D12_COMMONSHADER_SAMPLER_REGISTER_READ_PORTS: UInt32 = 1
D3D12_COMMONSHADER_SAMPLER_SLOT_COUNT: UInt32 = 16
D3D12_COMMONSHADER_SUBROUTINE_NESTING_LIMIT: UInt32 = 32
D3D12_COMMONSHADER_TEMP_REGISTER_COMPONENTS: UInt32 = 4
D3D12_COMMONSHADER_TEMP_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_COMMONSHADER_TEMP_REGISTER_COUNT: UInt32 = 4096
D3D12_COMMONSHADER_TEMP_REGISTER_READS_PER_INST: UInt32 = 3
D3D12_COMMONSHADER_TEMP_REGISTER_READ_PORTS: UInt32 = 3
D3D12_COMMONSHADER_TEXCOORD_RANGE_REDUCTION_MAX: UInt32 = 10
D3D12_COMMONSHADER_TEXCOORD_RANGE_REDUCTION_MIN: Int32 = -10
D3D12_COMMONSHADER_TEXEL_OFFSET_MAX_NEGATIVE: Int32 = -8
D3D12_COMMONSHADER_TEXEL_OFFSET_MAX_POSITIVE: UInt32 = 7
D3D12_CONSTANT_BUFFER_DATA_PLACEMENT_ALIGNMENT: UInt32 = 256
D3D12_CS_4_X_BUCKET00_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 256
D3D12_CS_4_X_BUCKET00_MAX_NUM_THREADS_PER_GROUP: UInt32 = 64
D3D12_CS_4_X_BUCKET01_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 240
D3D12_CS_4_X_BUCKET01_MAX_NUM_THREADS_PER_GROUP: UInt32 = 68
D3D12_CS_4_X_BUCKET02_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 224
D3D12_CS_4_X_BUCKET02_MAX_NUM_THREADS_PER_GROUP: UInt32 = 72
D3D12_CS_4_X_BUCKET03_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 208
D3D12_CS_4_X_BUCKET03_MAX_NUM_THREADS_PER_GROUP: UInt32 = 76
D3D12_CS_4_X_BUCKET04_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 192
D3D12_CS_4_X_BUCKET04_MAX_NUM_THREADS_PER_GROUP: UInt32 = 84
D3D12_CS_4_X_BUCKET05_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 176
D3D12_CS_4_X_BUCKET05_MAX_NUM_THREADS_PER_GROUP: UInt32 = 92
D3D12_CS_4_X_BUCKET06_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 160
D3D12_CS_4_X_BUCKET06_MAX_NUM_THREADS_PER_GROUP: UInt32 = 100
D3D12_CS_4_X_BUCKET07_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 144
D3D12_CS_4_X_BUCKET07_MAX_NUM_THREADS_PER_GROUP: UInt32 = 112
D3D12_CS_4_X_BUCKET08_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 128
D3D12_CS_4_X_BUCKET08_MAX_NUM_THREADS_PER_GROUP: UInt32 = 128
D3D12_CS_4_X_BUCKET09_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 112
D3D12_CS_4_X_BUCKET09_MAX_NUM_THREADS_PER_GROUP: UInt32 = 144
D3D12_CS_4_X_BUCKET10_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 96
D3D12_CS_4_X_BUCKET10_MAX_NUM_THREADS_PER_GROUP: UInt32 = 168
D3D12_CS_4_X_BUCKET11_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 80
D3D12_CS_4_X_BUCKET11_MAX_NUM_THREADS_PER_GROUP: UInt32 = 204
D3D12_CS_4_X_BUCKET12_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 64
D3D12_CS_4_X_BUCKET12_MAX_NUM_THREADS_PER_GROUP: UInt32 = 256
D3D12_CS_4_X_BUCKET13_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 48
D3D12_CS_4_X_BUCKET13_MAX_NUM_THREADS_PER_GROUP: UInt32 = 340
D3D12_CS_4_X_BUCKET14_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 32
D3D12_CS_4_X_BUCKET14_MAX_NUM_THREADS_PER_GROUP: UInt32 = 512
D3D12_CS_4_X_BUCKET15_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 16
D3D12_CS_4_X_BUCKET15_MAX_NUM_THREADS_PER_GROUP: UInt32 = 768
D3D12_CS_4_X_DISPATCH_MAX_THREAD_GROUPS_IN_Z_DIMENSION: UInt32 = 1
D3D12_CS_4_X_RAW_UAV_BYTE_ALIGNMENT: UInt32 = 256
D3D12_CS_4_X_THREAD_GROUP_MAX_THREADS_PER_GROUP: UInt32 = 768
D3D12_CS_4_X_THREAD_GROUP_MAX_X: UInt32 = 768
D3D12_CS_4_X_THREAD_GROUP_MAX_Y: UInt32 = 768
D3D12_CS_4_X_UAV_REGISTER_COUNT: UInt32 = 1
D3D12_CS_DISPATCH_MAX_THREAD_GROUPS_PER_DIMENSION: UInt32 = 65535
D3D12_CS_TGSM_REGISTER_COUNT: UInt32 = 8192
D3D12_CS_TGSM_REGISTER_READS_PER_INST: UInt32 = 1
D3D12_CS_TGSM_RESOURCE_REGISTER_COMPONENTS: UInt32 = 1
D3D12_CS_TGSM_RESOURCE_REGISTER_READ_PORTS: UInt32 = 1
D3D12_CS_THREADGROUPID_REGISTER_COMPONENTS: UInt32 = 3
D3D12_CS_THREADGROUPID_REGISTER_COUNT: UInt32 = 1
D3D12_CS_THREADIDINGROUPFLATTENED_REGISTER_COMPONENTS: UInt32 = 1
D3D12_CS_THREADIDINGROUPFLATTENED_REGISTER_COUNT: UInt32 = 1
D3D12_CS_THREADIDINGROUP_REGISTER_COMPONENTS: UInt32 = 3
D3D12_CS_THREADIDINGROUP_REGISTER_COUNT: UInt32 = 1
D3D12_CS_THREADID_REGISTER_COMPONENTS: UInt32 = 3
D3D12_CS_THREADID_REGISTER_COUNT: UInt32 = 1
D3D12_CS_THREAD_GROUP_MAX_THREADS_PER_GROUP: UInt32 = 1024
D3D12_CS_THREAD_GROUP_MAX_X: UInt32 = 1024
D3D12_CS_THREAD_GROUP_MAX_Y: UInt32 = 1024
D3D12_CS_THREAD_GROUP_MAX_Z: UInt32 = 64
D3D12_CS_THREAD_GROUP_MIN_X: UInt32 = 1
D3D12_CS_THREAD_GROUP_MIN_Y: UInt32 = 1
D3D12_CS_THREAD_GROUP_MIN_Z: UInt32 = 1
D3D12_CS_THREAD_LOCAL_TEMP_REGISTER_POOL: UInt32 = 16384
D3D12_DEFAULT_BLEND_FACTOR_ALPHA: Single = 1
D3D12_DEFAULT_BLEND_FACTOR_BLUE: Single = 1
D3D12_DEFAULT_BLEND_FACTOR_GREEN: Single = 1
D3D12_DEFAULT_BLEND_FACTOR_RED: Single = 1
D3D12_DEFAULT_BORDER_COLOR_COMPONENT: Single = 0
D3D12_DEFAULT_DEPTH_BIAS: Int32 = 0
D3D12_DEFAULT_DEPTH_BIAS_CLAMP: Single = 0
D3D12_DEFAULT_MAX_ANISOTROPY: UInt32 = 16
D3D12_DEFAULT_MIP_LOD_BIAS: Single = 0
D3D12_DEFAULT_MSAA_RESOURCE_PLACEMENT_ALIGNMENT: UInt32 = 4194304
D3D12_DEFAULT_RENDER_TARGET_ARRAY_INDEX: UInt32 = 0
D3D12_DEFAULT_RESOURCE_PLACEMENT_ALIGNMENT: UInt32 = 65536
D3D12_DEFAULT_SAMPLE_MASK: UInt32 = 4294967295
D3D12_DEFAULT_SCISSOR_ENDX: UInt32 = 0
D3D12_DEFAULT_SCISSOR_ENDY: UInt32 = 0
D3D12_DEFAULT_SCISSOR_STARTX: UInt32 = 0
D3D12_DEFAULT_SCISSOR_STARTY: UInt32 = 0
D3D12_DEFAULT_SLOPE_SCALED_DEPTH_BIAS: Single = 0
D3D12_DEFAULT_STENCIL_READ_MASK: UInt32 = 255
D3D12_DEFAULT_STENCIL_REFERENCE: UInt32 = 0
D3D12_DEFAULT_STENCIL_WRITE_MASK: UInt32 = 255
D3D12_DEFAULT_VIEWPORT_AND_SCISSORRECT_INDEX: UInt32 = 0
D3D12_DEFAULT_VIEWPORT_HEIGHT: UInt32 = 0
D3D12_DEFAULT_VIEWPORT_MAX_DEPTH: Single = 0
D3D12_DEFAULT_VIEWPORT_MIN_DEPTH: Single = 0
D3D12_DEFAULT_VIEWPORT_TOPLEFTX: UInt32 = 0
D3D12_DEFAULT_VIEWPORT_TOPLEFTY: UInt32 = 0
D3D12_DEFAULT_VIEWPORT_WIDTH: UInt32 = 0
D3D12_DESCRIPTOR_RANGE_OFFSET_APPEND: UInt32 = 4294967295
D3D12_DRIVER_RESERVED_REGISTER_SPACE_VALUES_END: UInt32 = 4294967287
D3D12_DRIVER_RESERVED_REGISTER_SPACE_VALUES_START: UInt32 = 4294967280
D3D12_DS_INPUT_CONTROL_POINTS_MAX_TOTAL_SCALARS: UInt32 = 3968
D3D12_DS_INPUT_CONTROL_POINT_REGISTER_COMPONENTS: UInt32 = 4
D3D12_DS_INPUT_CONTROL_POINT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_DS_INPUT_CONTROL_POINT_REGISTER_COUNT: UInt32 = 32
D3D12_DS_INPUT_CONTROL_POINT_REGISTER_READS_PER_INST: UInt32 = 2
D3D12_DS_INPUT_CONTROL_POINT_REGISTER_READ_PORTS: UInt32 = 1
D3D12_DS_INPUT_DOMAIN_POINT_REGISTER_COMPONENTS: UInt32 = 3
D3D12_DS_INPUT_DOMAIN_POINT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_DS_INPUT_DOMAIN_POINT_REGISTER_COUNT: UInt32 = 1
D3D12_DS_INPUT_DOMAIN_POINT_REGISTER_READS_PER_INST: UInt32 = 2
D3D12_DS_INPUT_DOMAIN_POINT_REGISTER_READ_PORTS: UInt32 = 1
D3D12_DS_INPUT_PATCH_CONSTANT_REGISTER_COMPONENTS: UInt32 = 4
D3D12_DS_INPUT_PATCH_CONSTANT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_DS_INPUT_PATCH_CONSTANT_REGISTER_COUNT: UInt32 = 32
D3D12_DS_INPUT_PATCH_CONSTANT_REGISTER_READS_PER_INST: UInt32 = 2
D3D12_DS_INPUT_PATCH_CONSTANT_REGISTER_READ_PORTS: UInt32 = 1
D3D12_DS_INPUT_PRIMITIVE_ID_REGISTER_COMPONENTS: UInt32 = 1
D3D12_DS_INPUT_PRIMITIVE_ID_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_DS_INPUT_PRIMITIVE_ID_REGISTER_COUNT: UInt32 = 1
D3D12_DS_INPUT_PRIMITIVE_ID_REGISTER_READS_PER_INST: UInt32 = 2
D3D12_DS_INPUT_PRIMITIVE_ID_REGISTER_READ_PORTS: UInt32 = 1
D3D12_DS_OUTPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D12_DS_OUTPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_DS_OUTPUT_REGISTER_COUNT: UInt32 = 32
D3D12_FLOAT16_FUSED_TOLERANCE_IN_ULP: Double = 0.6
D3D12_FLOAT32_MAX: Single = 3.4028235e+38
D3D12_FLOAT32_TO_INTEGER_TOLERANCE_IN_ULP: Single = 0.6
D3D12_FLOAT_TO_SRGB_EXPONENT_DENOMINATOR: Single = 2.4
D3D12_FLOAT_TO_SRGB_EXPONENT_NUMERATOR: Single = 1
D3D12_FLOAT_TO_SRGB_OFFSET: Single = 0.055
D3D12_FLOAT_TO_SRGB_SCALE_1: Single = 12.92
D3D12_FLOAT_TO_SRGB_SCALE_2: Single = 1.055
D3D12_FLOAT_TO_SRGB_THRESHOLD: Single = 0.0031308
D3D12_FTOI_INSTRUCTION_MAX_INPUT: Single = 2147483600.0
D3D12_FTOI_INSTRUCTION_MIN_INPUT: Single = -2147483600.0
D3D12_FTOU_INSTRUCTION_MAX_INPUT: Single = 4294967300.0
D3D12_FTOU_INSTRUCTION_MIN_INPUT: Single = 0
D3D12_GS_INPUT_INSTANCE_ID_READS_PER_INST: UInt32 = 2
D3D12_GS_INPUT_INSTANCE_ID_READ_PORTS: UInt32 = 1
D3D12_GS_INPUT_INSTANCE_ID_REGISTER_COMPONENTS: UInt32 = 1
D3D12_GS_INPUT_INSTANCE_ID_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_GS_INPUT_INSTANCE_ID_REGISTER_COUNT: UInt32 = 1
D3D12_GS_INPUT_PRIM_CONST_REGISTER_COMPONENTS: UInt32 = 1
D3D12_GS_INPUT_PRIM_CONST_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_GS_INPUT_PRIM_CONST_REGISTER_COUNT: UInt32 = 1
D3D12_GS_INPUT_PRIM_CONST_REGISTER_READS_PER_INST: UInt32 = 2
D3D12_GS_INPUT_PRIM_CONST_REGISTER_READ_PORTS: UInt32 = 1
D3D12_GS_INPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D12_GS_INPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_GS_INPUT_REGISTER_COUNT: UInt32 = 32
D3D12_GS_INPUT_REGISTER_READS_PER_INST: UInt32 = 2
D3D12_GS_INPUT_REGISTER_READ_PORTS: UInt32 = 1
D3D12_GS_INPUT_REGISTER_VERTICES: UInt32 = 32
D3D12_GS_MAX_INSTANCE_COUNT: UInt32 = 32
D3D12_GS_MAX_OUTPUT_VERTEX_COUNT_ACROSS_INSTANCES: UInt32 = 1024
D3D12_GS_OUTPUT_ELEMENTS: UInt32 = 32
D3D12_GS_OUTPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D12_GS_OUTPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_GS_OUTPUT_REGISTER_COUNT: UInt32 = 32
D3D12_HS_CONTROL_POINT_PHASE_INPUT_REGISTER_COUNT: UInt32 = 32
D3D12_HS_CONTROL_POINT_PHASE_OUTPUT_REGISTER_COUNT: UInt32 = 32
D3D12_HS_CONTROL_POINT_REGISTER_COMPONENTS: UInt32 = 4
D3D12_HS_CONTROL_POINT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_HS_CONTROL_POINT_REGISTER_READS_PER_INST: UInt32 = 2
D3D12_HS_CONTROL_POINT_REGISTER_READ_PORTS: UInt32 = 1
D3D12_HS_FORK_PHASE_INSTANCE_COUNT_UPPER_BOUND: UInt32 = 4294967295
D3D12_HS_INPUT_FORK_INSTANCE_ID_REGISTER_COMPONENTS: UInt32 = 1
D3D12_HS_INPUT_FORK_INSTANCE_ID_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_HS_INPUT_FORK_INSTANCE_ID_REGISTER_COUNT: UInt32 = 1
D3D12_HS_INPUT_FORK_INSTANCE_ID_REGISTER_READS_PER_INST: UInt32 = 2
D3D12_HS_INPUT_FORK_INSTANCE_ID_REGISTER_READ_PORTS: UInt32 = 1
D3D12_HS_INPUT_JOIN_INSTANCE_ID_REGISTER_COMPONENTS: UInt32 = 1
D3D12_HS_INPUT_JOIN_INSTANCE_ID_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_HS_INPUT_JOIN_INSTANCE_ID_REGISTER_COUNT: UInt32 = 1
D3D12_HS_INPUT_JOIN_INSTANCE_ID_REGISTER_READS_PER_INST: UInt32 = 2
D3D12_HS_INPUT_JOIN_INSTANCE_ID_REGISTER_READ_PORTS: UInt32 = 1
D3D12_HS_INPUT_PRIMITIVE_ID_REGISTER_COMPONENTS: UInt32 = 1
D3D12_HS_INPUT_PRIMITIVE_ID_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_HS_INPUT_PRIMITIVE_ID_REGISTER_COUNT: UInt32 = 1
D3D12_HS_INPUT_PRIMITIVE_ID_REGISTER_READS_PER_INST: UInt32 = 2
D3D12_HS_INPUT_PRIMITIVE_ID_REGISTER_READ_PORTS: UInt32 = 1
D3D12_HS_JOIN_PHASE_INSTANCE_COUNT_UPPER_BOUND: UInt32 = 4294967295
D3D12_HS_MAXTESSFACTOR_LOWER_BOUND: Single = 1
D3D12_HS_MAXTESSFACTOR_UPPER_BOUND: Single = 64
D3D12_HS_OUTPUT_CONTROL_POINTS_MAX_TOTAL_SCALARS: UInt32 = 3968
D3D12_HS_OUTPUT_CONTROL_POINT_ID_REGISTER_COMPONENTS: UInt32 = 1
D3D12_HS_OUTPUT_CONTROL_POINT_ID_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_HS_OUTPUT_CONTROL_POINT_ID_REGISTER_COUNT: UInt32 = 1
D3D12_HS_OUTPUT_CONTROL_POINT_ID_REGISTER_READS_PER_INST: UInt32 = 2
D3D12_HS_OUTPUT_CONTROL_POINT_ID_REGISTER_READ_PORTS: UInt32 = 1
D3D12_HS_OUTPUT_PATCH_CONSTANT_REGISTER_COMPONENTS: UInt32 = 4
D3D12_HS_OUTPUT_PATCH_CONSTANT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_HS_OUTPUT_PATCH_CONSTANT_REGISTER_COUNT: UInt32 = 32
D3D12_HS_OUTPUT_PATCH_CONSTANT_REGISTER_READS_PER_INST: UInt32 = 2
D3D12_HS_OUTPUT_PATCH_CONSTANT_REGISTER_READ_PORTS: UInt32 = 1
D3D12_HS_OUTPUT_PATCH_CONSTANT_REGISTER_SCALAR_COMPONENTS: UInt32 = 128
D3D12_IA_DEFAULT_INDEX_BUFFER_OFFSET_IN_BYTES: UInt32 = 0
D3D12_IA_DEFAULT_PRIMITIVE_TOPOLOGY: UInt32 = 0
D3D12_IA_DEFAULT_VERTEX_BUFFER_OFFSET_IN_BYTES: UInt32 = 0
D3D12_IA_INDEX_INPUT_RESOURCE_SLOT_COUNT: UInt32 = 1
D3D12_IA_INSTANCE_ID_BIT_COUNT: UInt32 = 32
D3D12_IA_INTEGER_ARITHMETIC_BIT_COUNT: UInt32 = 32
D3D12_IA_PATCH_MAX_CONTROL_POINT_COUNT: UInt32 = 32
D3D12_IA_PRIMITIVE_ID_BIT_COUNT: UInt32 = 32
D3D12_IA_VERTEX_ID_BIT_COUNT: UInt32 = 32
D3D12_IA_VERTEX_INPUT_RESOURCE_SLOT_COUNT: UInt32 = 32
D3D12_IA_VERTEX_INPUT_STRUCTURE_ELEMENTS_COMPONENTS: UInt32 = 128
D3D12_IA_VERTEX_INPUT_STRUCTURE_ELEMENT_COUNT: UInt32 = 32
D3D12_INTEGER_DIVIDE_BY_ZERO_QUOTIENT: UInt32 = 4294967295
D3D12_INTEGER_DIVIDE_BY_ZERO_REMAINDER: UInt32 = 4294967295
D3D12_KEEP_RENDER_TARGETS_AND_DEPTH_STENCIL: UInt32 = 4294967295
D3D12_KEEP_UNORDERED_ACCESS_VIEWS: UInt32 = 4294967295
D3D12_LINEAR_GAMMA: Single = 1
D3D12_MAJOR_VERSION: UInt32 = 12
D3D12_MAX_BORDER_COLOR_COMPONENT: Single = 1
D3D12_MAX_DEPTH: Single = 1
D3D12_MAX_LIVE_STATIC_SAMPLERS: UInt32 = 2032
D3D12_MAX_MAXANISOTROPY: UInt32 = 16
D3D12_MAX_MULTISAMPLE_SAMPLE_COUNT: UInt32 = 32
D3D12_MAX_POSITION_VALUE: Single = 3.4028236e+34
D3D12_MAX_ROOT_COST: UInt32 = 64
D3D12_MAX_SHADER_VISIBLE_DESCRIPTOR_HEAP_SIZE_TIER_1: UInt32 = 1000000
D3D12_MAX_SHADER_VISIBLE_DESCRIPTOR_HEAP_SIZE_TIER_2: UInt32 = 1000000
D3D12_MAX_SHADER_VISIBLE_SAMPLER_HEAP_SIZE: UInt32 = 2048
D3D12_MAX_TEXTURE_DIMENSION_2_TO_EXP: UInt32 = 17
D3D12_MAX_VIEW_INSTANCE_COUNT: UInt32 = 4
D3D12_MINOR_VERSION: UInt32 = 0
D3D12_MIN_BORDER_COLOR_COMPONENT: Single = 0
D3D12_MIN_DEPTH: Single = 0
D3D12_MIN_MAXANISOTROPY: UInt32 = 0
D3D12_MIP_LOD_BIAS_MAX: Single = 15.99
D3D12_MIP_LOD_BIAS_MIN: Single = -16
D3D12_MIP_LOD_FRACTIONAL_BIT_COUNT: UInt32 = 8
D3D12_MIP_LOD_RANGE_BIT_COUNT: UInt32 = 8
D3D12_MULTISAMPLE_ANTIALIAS_LINE_WIDTH: Single = 1.4
D3D12_NONSAMPLE_FETCH_OUT_OF_RANGE_ACCESS_RESULT: UInt32 = 0
D3D12_OS_RESERVED_REGISTER_SPACE_VALUES_END: UInt32 = 4294967295
D3D12_OS_RESERVED_REGISTER_SPACE_VALUES_START: UInt32 = 4294967288
D3D12_PACKED_TILE: UInt32 = 4294967295
D3D12_PIXEL_ADDRESS_RANGE_BIT_COUNT: UInt32 = 15
D3D12_PREVIEW_SDK_VERSION: UInt32 = 714
D3D12_PRE_SCISSOR_PIXEL_ADDRESS_RANGE_BIT_COUNT: UInt32 = 16
D3D12_PS_CS_UAV_REGISTER_COMPONENTS: UInt32 = 1
D3D12_PS_CS_UAV_REGISTER_COUNT: UInt32 = 8
D3D12_PS_CS_UAV_REGISTER_READS_PER_INST: UInt32 = 1
D3D12_PS_CS_UAV_REGISTER_READ_PORTS: UInt32 = 1
D3D12_PS_FRONTFACING_DEFAULT_VALUE: UInt32 = 4294967295
D3D12_PS_FRONTFACING_FALSE_VALUE: UInt32 = 0
D3D12_PS_FRONTFACING_TRUE_VALUE: UInt32 = 4294967295
D3D12_PS_INPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D12_PS_INPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_PS_INPUT_REGISTER_COUNT: UInt32 = 32
D3D12_PS_INPUT_REGISTER_READS_PER_INST: UInt32 = 2
D3D12_PS_INPUT_REGISTER_READ_PORTS: UInt32 = 1
D3D12_PS_LEGACY_PIXEL_CENTER_FRACTIONAL_COMPONENT: Single = 0
D3D12_PS_OUTPUT_DEPTH_REGISTER_COMPONENTS: UInt32 = 1
D3D12_PS_OUTPUT_DEPTH_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_PS_OUTPUT_DEPTH_REGISTER_COUNT: UInt32 = 1
D3D12_PS_OUTPUT_MASK_REGISTER_COMPONENTS: UInt32 = 1
D3D12_PS_OUTPUT_MASK_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_PS_OUTPUT_MASK_REGISTER_COUNT: UInt32 = 1
D3D12_PS_OUTPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D12_PS_OUTPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_PS_OUTPUT_REGISTER_COUNT: UInt32 = 8
D3D12_PS_PIXEL_CENTER_FRACTIONAL_COMPONENT: Single = 0.5
D3D12_RAW_UAV_SRV_BYTE_ALIGNMENT: UInt32 = 16
D3D12_RAYTRACING_AABB_BYTE_ALIGNMENT: UInt32 = 8
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BYTE_ALIGNMENT: UInt32 = 256
D3D12_RAYTRACING_INSTANCE_DESCS_BYTE_ALIGNMENT: UInt32 = 16
D3D12_RAYTRACING_MAX_ATTRIBUTE_SIZE_IN_BYTES: UInt32 = 32
D3D12_RAYTRACING_MAX_DECLARABLE_TRACE_RECURSION_DEPTH: UInt32 = 31
D3D12_RAYTRACING_MAX_GEOMETRIES_PER_BOTTOM_LEVEL_ACCELERATION_STRUCTURE: UInt32 = 16777216
D3D12_RAYTRACING_MAX_INSTANCES_PER_TOP_LEVEL_ACCELERATION_STRUCTURE: UInt32 = 16777216
D3D12_RAYTRACING_MAX_PRIMITIVES_PER_BOTTOM_LEVEL_ACCELERATION_STRUCTURE: UInt32 = 536870912
D3D12_RAYTRACING_MAX_RAY_GENERATION_SHADER_THREADS: UInt32 = 1073741824
D3D12_RAYTRACING_MAX_SHADER_RECORD_STRIDE: UInt32 = 4096
D3D12_RAYTRACING_SHADER_RECORD_BYTE_ALIGNMENT: UInt32 = 32
D3D12_RAYTRACING_SHADER_TABLE_BYTE_ALIGNMENT: UInt32 = 64
D3D12_RAYTRACING_TRANSFORM3X4_BYTE_ALIGNMENT: UInt32 = 16
D3D12_REQ_BLEND_OBJECT_COUNT_PER_DEVICE: UInt32 = 4096
D3D12_REQ_BUFFER_RESOURCE_TEXEL_COUNT_2_TO_EXP: UInt32 = 27
D3D12_REQ_CONSTANT_BUFFER_ELEMENT_COUNT: UInt32 = 4096
D3D12_REQ_DEPTH_STENCIL_OBJECT_COUNT_PER_DEVICE: UInt32 = 4096
D3D12_REQ_DRAWINDEXED_INDEX_COUNT_2_TO_EXP: UInt32 = 32
D3D12_REQ_DRAW_VERTEX_COUNT_2_TO_EXP: UInt32 = 32
D3D12_REQ_FILTERING_HW_ADDRESSABLE_RESOURCE_DIMENSION: UInt32 = 16384
D3D12_REQ_GS_INVOCATION_32BIT_OUTPUT_COMPONENT_LIMIT: UInt32 = 1024
D3D12_REQ_IMMEDIATE_CONSTANT_BUFFER_ELEMENT_COUNT: UInt32 = 4096
D3D12_REQ_MAXANISOTROPY: UInt32 = 16
D3D12_REQ_MIP_LEVELS: UInt32 = 15
D3D12_REQ_MULTI_ELEMENT_STRUCTURE_SIZE_IN_BYTES: UInt32 = 2048
D3D12_REQ_RASTERIZER_OBJECT_COUNT_PER_DEVICE: UInt32 = 4096
D3D12_REQ_RENDER_TO_BUFFER_WINDOW_WIDTH: UInt32 = 16384
D3D12_REQ_RESOURCE_SIZE_IN_MEGABYTES_EXPRESSION_A_TERM: UInt32 = 128
D3D12_REQ_RESOURCE_SIZE_IN_MEGABYTES_EXPRESSION_B_TERM: Single = 0.25
D3D12_REQ_RESOURCE_SIZE_IN_MEGABYTES_EXPRESSION_C_TERM: UInt32 = 2048
D3D12_REQ_RESOURCE_VIEW_COUNT_PER_DEVICE_2_TO_EXP: UInt32 = 20
D3D12_REQ_SAMPLER_OBJECT_COUNT_PER_DEVICE: UInt32 = 4096
D3D12_REQ_SUBRESOURCES: UInt32 = 30720
D3D12_REQ_TEXTURE1D_ARRAY_AXIS_DIMENSION: UInt32 = 2048
D3D12_REQ_TEXTURE1D_U_DIMENSION: UInt32 = 16384
D3D12_REQ_TEXTURE2D_ARRAY_AXIS_DIMENSION: UInt32 = 2048
D3D12_REQ_TEXTURE2D_U_OR_V_DIMENSION: UInt32 = 16384
D3D12_REQ_TEXTURE3D_U_V_OR_W_DIMENSION: UInt32 = 2048
D3D12_REQ_TEXTURECUBE_DIMENSION: UInt32 = 16384
D3D12_RESINFO_INSTRUCTION_MISSING_COMPONENT_RETVAL: UInt32 = 0
D3D12_RESOURCE_BARRIER_ALL_SUBRESOURCES: UInt32 = 4294967295
D3D12_RS_SET_SHADING_RATE_COMBINER_COUNT: UInt32 = 2
D3D12_SDK_VERSION: UInt32 = 614
D3D12_SHADER_IDENTIFIER_SIZE_IN_BYTES: UInt32 = 32
D3D12_SHADER_MAJOR_VERSION: UInt32 = 5
D3D12_SHADER_MAX_INSTANCES: UInt32 = 65535
D3D12_SHADER_MAX_INTERFACES: UInt32 = 253
D3D12_SHADER_MAX_INTERFACE_CALL_SITES: UInt32 = 4096
D3D12_SHADER_MAX_TYPES: UInt32 = 65535
D3D12_SHADER_MINOR_VERSION: UInt32 = 1
D3D12_SHIFT_INSTRUCTION_PAD_VALUE: UInt32 = 0
D3D12_SHIFT_INSTRUCTION_SHIFT_VALUE_BIT_COUNT: UInt32 = 5
D3D12_SIMULTANEOUS_RENDER_TARGET_COUNT: UInt32 = 8
D3D12_SMALL_MSAA_RESOURCE_PLACEMENT_ALIGNMENT: UInt32 = 65536
D3D12_SMALL_RESOURCE_PLACEMENT_ALIGNMENT: UInt32 = 4096
D3D12_SO_BUFFER_MAX_STRIDE_IN_BYTES: UInt32 = 2048
D3D12_SO_BUFFER_MAX_WRITE_WINDOW_IN_BYTES: UInt32 = 512
D3D12_SO_BUFFER_SLOT_COUNT: UInt32 = 4
D3D12_SO_DDI_REGISTER_INDEX_DENOTING_GAP: UInt32 = 4294967295
D3D12_SO_NO_RASTERIZED_STREAM: UInt32 = 4294967295
D3D12_SO_OUTPUT_COMPONENT_COUNT: UInt32 = 128
D3D12_SO_STREAM_COUNT: UInt32 = 4
D3D12_SPEC_DATE_DAY: UInt32 = 14
D3D12_SPEC_DATE_MONTH: UInt32 = 11
D3D12_SPEC_DATE_YEAR: UInt32 = 2014
D3D12_SPEC_VERSION: Double = 1.16
D3D12_SRGB_GAMMA: Single = 2.2
D3D12_SRGB_TO_FLOAT_DENOMINATOR_1: Single = 12.92
D3D12_SRGB_TO_FLOAT_DENOMINATOR_2: Single = 1.055
D3D12_SRGB_TO_FLOAT_EXPONENT: Single = 2.4
D3D12_SRGB_TO_FLOAT_OFFSET: Single = 0.055
D3D12_SRGB_TO_FLOAT_THRESHOLD: Single = 0.04045
D3D12_SRGB_TO_FLOAT_TOLERANCE_IN_ULP: Single = 0.5
D3D12_STANDARD_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_STANDARD_COMPONENT_BIT_COUNT_DOUBLED: UInt32 = 64
D3D12_STANDARD_MAXIMUM_ELEMENT_ALIGNMENT_BYTE_MULTIPLE: UInt32 = 4
D3D12_STANDARD_PIXEL_COMPONENT_COUNT: UInt32 = 128
D3D12_STANDARD_PIXEL_ELEMENT_COUNT: UInt32 = 32
D3D12_STANDARD_VECTOR_SIZE: UInt32 = 4
D3D12_STANDARD_VERTEX_ELEMENT_COUNT: UInt32 = 32
D3D12_STANDARD_VERTEX_TOTAL_COMPONENT_COUNT: UInt32 = 64
D3D12_SUBPIXEL_FRACTIONAL_BIT_COUNT: UInt32 = 8
D3D12_SUBTEXEL_FRACTIONAL_BIT_COUNT: UInt32 = 8
D3D12_SYSTEM_RESERVED_REGISTER_SPACE_VALUES_END: UInt32 = 4294967295
D3D12_SYSTEM_RESERVED_REGISTER_SPACE_VALUES_START: UInt32 = 4294967280
D3D12_TESSELLATOR_MAX_EVEN_TESSELLATION_FACTOR: UInt32 = 64
D3D12_TESSELLATOR_MAX_ISOLINE_DENSITY_TESSELLATION_FACTOR: UInt32 = 64
D3D12_TESSELLATOR_MAX_ODD_TESSELLATION_FACTOR: UInt32 = 63
D3D12_TESSELLATOR_MAX_TESSELLATION_FACTOR: UInt32 = 64
D3D12_TESSELLATOR_MIN_EVEN_TESSELLATION_FACTOR: UInt32 = 2
D3D12_TESSELLATOR_MIN_ISOLINE_DENSITY_TESSELLATION_FACTOR: UInt32 = 1
D3D12_TESSELLATOR_MIN_ODD_TESSELLATION_FACTOR: UInt32 = 1
D3D12_TEXEL_ADDRESS_RANGE_BIT_COUNT: UInt32 = 16
D3D12_TEXTURE_DATA_PITCH_ALIGNMENT: UInt32 = 256
D3D12_TEXTURE_DATA_PLACEMENT_ALIGNMENT: UInt32 = 512
D3D12_TILED_RESOURCE_TILE_SIZE_IN_BYTES: UInt32 = 65536
D3D12_TRACKED_WORKLOAD_MAX_INSTANCES: UInt32 = 32
D3D12_UAV_COUNTER_PLACEMENT_ALIGNMENT: UInt32 = 4096
D3D12_UAV_SLOT_COUNT: UInt32 = 64
D3D12_UNBOUND_MEMORY_ACCESS_RESULT: UInt32 = 0
D3D12_VIDEO_DECODE_MAX_ARGUMENTS: UInt32 = 10
D3D12_VIDEO_DECODE_MAX_HISTOGRAM_COMPONENTS: UInt32 = 4
D3D12_VIDEO_DECODE_MIN_BITSTREAM_OFFSET_ALIGNMENT: UInt32 = 256
D3D12_VIDEO_DECODE_MIN_HISTOGRAM_OFFSET_ALIGNMENT: UInt32 = 256
D3D12_VIDEO_DECODE_STATUS_MACROBLOCKS_AFFECTED_UNKNOWN: UInt32 = 4294967295
D3D12_VIDEO_ENCODER_AV1_INVALID_DPB_RESOURCE_INDEX: UInt32 = 255
D3D12_VIDEO_ENCODER_AV1_MAX_TILE_COLS: UInt32 = 64
D3D12_VIDEO_ENCODER_AV1_MAX_TILE_ROWS: UInt32 = 64
D3D12_VIDEO_ENCODER_AV1_SUPERRES_DENOM_MIN: UInt32 = 9
D3D12_VIDEO_ENCODER_AV1_SUPERRES_NUM: UInt32 = 8
D3D12_VIDEO_PROCESS_MAX_FILTERS: UInt32 = 32
D3D12_VIDEO_PROCESS_STEREO_VIEWS: UInt32 = 2
D3D12_VIEWPORT_AND_SCISSORRECT_MAX_INDEX: UInt32 = 15
D3D12_VIEWPORT_AND_SCISSORRECT_OBJECT_COUNT_PER_PIPELINE: UInt32 = 16
D3D12_VIEWPORT_BOUNDS_MAX: UInt32 = 32767
D3D12_VIEWPORT_BOUNDS_MIN: Int32 = -32768
D3D12_VS_INPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D12_VS_INPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_VS_INPUT_REGISTER_COUNT: UInt32 = 32
D3D12_VS_INPUT_REGISTER_READS_PER_INST: UInt32 = 2
D3D12_VS_INPUT_REGISTER_READ_PORTS: UInt32 = 1
D3D12_VS_OUTPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D12_VS_OUTPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D12_VS_OUTPUT_REGISTER_COUNT: UInt32 = 32
D3D12_WHQL_CONTEXT_COUNT_FOR_RESOURCE_LIMIT: UInt32 = 10
D3D12_WHQL_DRAWINDEXED_INDEX_COUNT_2_TO_EXP: UInt32 = 25
D3D12_WHQL_DRAW_VERTEX_COUNT_2_TO_EXP: UInt32 = 25
D3D12_WORK_GRAPHS_BACKING_MEMORY_ALIGNMENT_IN_BYTES: UInt32 = 8
D3D12_WORK_GRAPHS_MAX_NODE_DEPTH: UInt32 = 32
D3D12_SHADER_COMPONENT_MAPPING_MASK: UInt32 = 7
D3D12_SHADER_COMPONENT_MAPPING_SHIFT: UInt32 = 3
D3D12_FILTER_REDUCTION_TYPE_MASK: UInt32 = 3
D3D12_FILTER_REDUCTION_TYPE_SHIFT: UInt32 = 7
D3D12_FILTER_TYPE_MASK: UInt32 = 3
D3D12_MIN_FILTER_SHIFT: UInt32 = 4
D3D12_MAG_FILTER_SHIFT: UInt32 = 2
D3D12_MIP_FILTER_SHIFT: UInt32 = 0
D3D12_ANISOTROPIC_FILTERING_BIT: UInt32 = 64
LUID_DEFINED: UInt32 = 1
D3D12_PROTECTED_RESOURCES_SESSION_HARDWARE_PROTECTED: Guid = Guid('{62b0084e-c70e-4daa-a109-30ff8d5a0482}')
CLSID_D3D12Debug: Guid = Guid('{f2352aeb-dd84-49fe-b97b-a9dcfdcc1b4f}')
CLSID_D3D12Tools: Guid = Guid('{e38216b1-3c8c-4833-aa09-0a06b65d96c8}')
CLSID_D3D12DeviceRemovedExtendedData: Guid = Guid('{4a75bbc4-9ff4-4ad8-9f18-abae84dc5ff2}')
CLSID_D3D12SDKConfiguration: Guid = Guid('{7cda6aca-a03e-49c8-9458-0334d20e07ce}')
CLSID_D3D12DeviceFactory: Guid = Guid('{114863bf-c386-4aee-b39d-8f0bbb062955}')
D3D12_SHADING_RATE_X_AXIS_SHIFT: UInt32 = 2
D3D12_SHADING_RATE_VALID_MASK: UInt32 = 3
WKPDID_D3DAutoDebugObjectNameW: Guid = Guid('{d4902e36-757a-4942-9594-b6769afa43cd}')
DXGI_DEBUG_D3D12: Guid = Guid('{cf59a98c-a950-4326-91ef-9bbaa17bfd95}')
D3D12_INFO_QUEUE_DEFAULT_MESSAGE_COUNT_LIMIT: UInt32 = 1024
D3D_SHADER_REQUIRES_STENCIL_REF: UInt32 = 512
D3D_SHADER_REQUIRES_INNER_COVERAGE: UInt32 = 1024
D3D_SHADER_REQUIRES_TYPED_UAV_LOAD_ADDITIONAL_FORMATS: UInt32 = 2048
D3D_SHADER_REQUIRES_ROVS: UInt32 = 4096
D3D_SHADER_REQUIRES_VIEWPORT_AND_RT_ARRAY_INDEX_FROM_ANY_SHADER_FEEDING_RASTERIZER: UInt32 = 8192
D3D_SHADER_REQUIRES_WAVE_OPS: UInt32 = 16384
D3D_SHADER_REQUIRES_INT64_OPS: UInt32 = 32768
D3D_SHADER_REQUIRES_VIEW_ID: UInt32 = 65536
D3D_SHADER_REQUIRES_BARYCENTRICS: UInt32 = 131072
D3D_SHADER_REQUIRES_NATIVE_16BIT_OPS: UInt32 = 262144
D3D_SHADER_REQUIRES_SHADING_RATE: UInt32 = 524288
D3D_SHADER_REQUIRES_RAYTRACING_TIER_1_1: UInt32 = 1048576
D3D_SHADER_REQUIRES_SAMPLER_FEEDBACK: UInt32 = 2097152
D3D_SHADER_REQUIRES_ATOMIC_INT64_ON_TYPED_RESOURCE: UInt32 = 4194304
D3D_SHADER_REQUIRES_ATOMIC_INT64_ON_GROUP_SHARED: UInt32 = 8388608
D3D_SHADER_REQUIRES_DERIVATIVES_IN_MESH_AND_AMPLIFICATION_SHADERS: UInt32 = 16777216
D3D_SHADER_REQUIRES_RESOURCE_DESCRIPTOR_HEAP_INDEXING: UInt32 = 33554432
D3D_SHADER_REQUIRES_SAMPLER_DESCRIPTOR_HEAP_INDEXING: UInt32 = 67108864
D3D_SHADER_REQUIRES_WAVE_MMA: UInt32 = 134217728
D3D_SHADER_REQUIRES_ATOMIC_INT64_ON_DESCRIPTOR_HEAP_RESOURCE: UInt32 = 268435456
D3D_SHADER_REQUIRES_ADVANCED_TEXTURE_OPS: UInt32 = 536870912
D3D_SHADER_REQUIRES_WRITEABLE_MSAA_TEXTURES: UInt32 = 1073741824
D3D_SHADER_REQUIRES_SAMPLE_CMP_GRADIENT_OR_BIAS: UInt32 = 2147483648
D3D12ExperimentalShaderModels: Guid = Guid('{76f5573e-f13a-40f5-b297-81ce9e18933f}')
D3D12TiledResourceTier4: Guid = Guid('{c9c4725f-a81a-4f56-8c5b-c51039d694fb}')
@winfunctype('d3d12.dll')
def D3D12SerializeRootSignature(pRootSignature: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_DESC), Version: win32more.Windows.Win32.Graphics.Direct3D12.D3D_ROOT_SIGNATURE_VERSION, ppBlob: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob), ppErrorBlob: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d12.dll')
def D3D12CreateRootSignatureDeserializer(pSrcData: VoidPtr, SrcDataSizeInBytes: UIntPtr, pRootSignatureDeserializerInterface: POINTER(Guid), ppRootSignatureDeserializer: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d12.dll')
def D3D12SerializeVersionedRootSignature(pRootSignature: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VERSIONED_ROOT_SIGNATURE_DESC), ppBlob: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob), ppErrorBlob: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d12.dll')
def D3D12CreateVersionedRootSignatureDeserializer(pSrcData: VoidPtr, SrcDataSizeInBytes: UIntPtr, pRootSignatureDeserializerInterface: POINTER(Guid), ppRootSignatureDeserializer: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d12.dll')
def D3D12CreateDevice(pAdapter: win32more.Windows.Win32.System.Com.IUnknown, MinimumFeatureLevel: win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL, riid: POINTER(Guid), ppDevice: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d12.dll')
def D3D12GetDebugInterface(riid: POINTER(Guid), ppvDebug: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d12.dll')
def D3D12EnableExperimentalFeatures(NumFeatures: UInt32, pIIDs: POINTER(Guid), pConfigurationStructs: VoidPtr, pConfigurationStructSizes: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d12.dll')
def D3D12GetInterface(rclsid: POINTER(Guid), riid: POINTER(Guid), ppvDebug: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def D3D12MessageFunc(Category: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CATEGORY, Severity: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_SEVERITY, ID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID, pDescription: win32more.Windows.Win32.Foundation.PSTR, pContext: VoidPtr) -> Void: ...
class D3D12_AUTO_BREADCRUMB_NODE(Structure):
    pCommandListDebugNameA: POINTER(Byte)
    pCommandListDebugNameW: win32more.Windows.Win32.Foundation.PWSTR
    pCommandQueueDebugNameA: POINTER(Byte)
    pCommandQueueDebugNameW: win32more.Windows.Win32.Foundation.PWSTR
    pCommandList: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12GraphicsCommandList
    pCommandQueue: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12CommandQueue
    BreadcrumbCount: UInt32
    pLastBreadcrumbValue: POINTER(UInt32)
    pCommandHistory: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP)
    pNext: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_NODE)
class D3D12_AUTO_BREADCRUMB_NODE1(Structure):
    pCommandListDebugNameA: POINTER(Byte)
    pCommandListDebugNameW: win32more.Windows.Win32.Foundation.PWSTR
    pCommandQueueDebugNameA: POINTER(Byte)
    pCommandQueueDebugNameW: win32more.Windows.Win32.Foundation.PWSTR
    pCommandList: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12GraphicsCommandList
    pCommandQueue: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12CommandQueue
    BreadcrumbCount: UInt32
    pLastBreadcrumbValue: POINTER(UInt32)
    pCommandHistory: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP)
    pNext: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_NODE1)
    BreadcrumbContextsCount: UInt32
    pBreadcrumbContexts: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_BREADCRUMB_CONTEXT)
D3D12_AUTO_BREADCRUMB_OP = Int32
D3D12_AUTO_BREADCRUMB_OP_SETMARKER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 0
D3D12_AUTO_BREADCRUMB_OP_BEGINEVENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 1
D3D12_AUTO_BREADCRUMB_OP_ENDEVENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 2
D3D12_AUTO_BREADCRUMB_OP_DRAWINSTANCED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 3
D3D12_AUTO_BREADCRUMB_OP_DRAWINDEXEDINSTANCED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 4
D3D12_AUTO_BREADCRUMB_OP_EXECUTEINDIRECT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 5
D3D12_AUTO_BREADCRUMB_OP_DISPATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 6
D3D12_AUTO_BREADCRUMB_OP_COPYBUFFERREGION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 7
D3D12_AUTO_BREADCRUMB_OP_COPYTEXTUREREGION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 8
D3D12_AUTO_BREADCRUMB_OP_COPYRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 9
D3D12_AUTO_BREADCRUMB_OP_COPYTILES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 10
D3D12_AUTO_BREADCRUMB_OP_RESOLVESUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 11
D3D12_AUTO_BREADCRUMB_OP_CLEARRENDERTARGETVIEW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 12
D3D12_AUTO_BREADCRUMB_OP_CLEARUNORDEREDACCESSVIEW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 13
D3D12_AUTO_BREADCRUMB_OP_CLEARDEPTHSTENCILVIEW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 14
D3D12_AUTO_BREADCRUMB_OP_RESOURCEBARRIER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 15
D3D12_AUTO_BREADCRUMB_OP_EXECUTEBUNDLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 16
D3D12_AUTO_BREADCRUMB_OP_PRESENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 17
D3D12_AUTO_BREADCRUMB_OP_RESOLVEQUERYDATA: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 18
D3D12_AUTO_BREADCRUMB_OP_BEGINSUBMISSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 19
D3D12_AUTO_BREADCRUMB_OP_ENDSUBMISSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 20
D3D12_AUTO_BREADCRUMB_OP_DECODEFRAME: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 21
D3D12_AUTO_BREADCRUMB_OP_PROCESSFRAMES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 22
D3D12_AUTO_BREADCRUMB_OP_ATOMICCOPYBUFFERUINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 23
D3D12_AUTO_BREADCRUMB_OP_ATOMICCOPYBUFFERUINT64: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 24
D3D12_AUTO_BREADCRUMB_OP_RESOLVESUBRESOURCEREGION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 25
D3D12_AUTO_BREADCRUMB_OP_WRITEBUFFERIMMEDIATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 26
D3D12_AUTO_BREADCRUMB_OP_DECODEFRAME1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 27
D3D12_AUTO_BREADCRUMB_OP_SETPROTECTEDRESOURCESESSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 28
D3D12_AUTO_BREADCRUMB_OP_DECODEFRAME2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 29
D3D12_AUTO_BREADCRUMB_OP_PROCESSFRAMES1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 30
D3D12_AUTO_BREADCRUMB_OP_BUILDRAYTRACINGACCELERATIONSTRUCTURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 31
D3D12_AUTO_BREADCRUMB_OP_EMITRAYTRACINGACCELERATIONSTRUCTUREPOSTBUILDINFO: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 32
D3D12_AUTO_BREADCRUMB_OP_COPYRAYTRACINGACCELERATIONSTRUCTURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 33
D3D12_AUTO_BREADCRUMB_OP_DISPATCHRAYS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 34
D3D12_AUTO_BREADCRUMB_OP_INITIALIZEMETACOMMAND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 35
D3D12_AUTO_BREADCRUMB_OP_EXECUTEMETACOMMAND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 36
D3D12_AUTO_BREADCRUMB_OP_ESTIMATEMOTION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 37
D3D12_AUTO_BREADCRUMB_OP_RESOLVEMOTIONVECTORHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 38
D3D12_AUTO_BREADCRUMB_OP_SETPIPELINESTATE1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 39
D3D12_AUTO_BREADCRUMB_OP_INITIALIZEEXTENSIONCOMMAND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 40
D3D12_AUTO_BREADCRUMB_OP_EXECUTEEXTENSIONCOMMAND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 41
D3D12_AUTO_BREADCRUMB_OP_DISPATCHMESH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 42
D3D12_AUTO_BREADCRUMB_OP_ENCODEFRAME: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 43
D3D12_AUTO_BREADCRUMB_OP_RESOLVEENCODEROUTPUTMETADATA: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 44
D3D12_AUTO_BREADCRUMB_OP_BARRIER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 45
D3D12_AUTO_BREADCRUMB_OP_BEGIN_COMMAND_LIST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 46
D3D12_AUTO_BREADCRUMB_OP_DISPATCHGRAPH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 47
D3D12_AUTO_BREADCRUMB_OP_SETPROGRAM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_OP = 48
D3D12_AXIS_SHADING_RATE = Int32
D3D12_AXIS_SHADING_RATE_1X: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AXIS_SHADING_RATE = 0
D3D12_AXIS_SHADING_RATE_2X: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AXIS_SHADING_RATE = 1
D3D12_AXIS_SHADING_RATE_4X: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AXIS_SHADING_RATE = 2
D3D12_BACKGROUND_PROCESSING_MODE = Int32
D3D12_BACKGROUND_PROCESSING_MODE_ALLOWED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BACKGROUND_PROCESSING_MODE = 0
D3D12_BACKGROUND_PROCESSING_MODE_ALLOW_INTRUSIVE_MEASUREMENTS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BACKGROUND_PROCESSING_MODE = 1
D3D12_BACKGROUND_PROCESSING_MODE_DISABLE_BACKGROUND_WORK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BACKGROUND_PROCESSING_MODE = 2
D3D12_BACKGROUND_PROCESSING_MODE_DISABLE_PROFILING_BY_SYSTEM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BACKGROUND_PROCESSING_MODE = 3
D3D12_BARRIER_ACCESS = Int32
D3D12_BARRIER_ACCESS_COMMON: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 0
D3D12_BARRIER_ACCESS_VERTEX_BUFFER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 1
D3D12_BARRIER_ACCESS_CONSTANT_BUFFER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 2
D3D12_BARRIER_ACCESS_INDEX_BUFFER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 4
D3D12_BARRIER_ACCESS_RENDER_TARGET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 8
D3D12_BARRIER_ACCESS_UNORDERED_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 16
D3D12_BARRIER_ACCESS_DEPTH_STENCIL_WRITE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 32
D3D12_BARRIER_ACCESS_DEPTH_STENCIL_READ: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 64
D3D12_BARRIER_ACCESS_SHADER_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 128
D3D12_BARRIER_ACCESS_STREAM_OUTPUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 256
D3D12_BARRIER_ACCESS_INDIRECT_ARGUMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 512
D3D12_BARRIER_ACCESS_PREDICATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 512
D3D12_BARRIER_ACCESS_COPY_DEST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 1024
D3D12_BARRIER_ACCESS_COPY_SOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 2048
D3D12_BARRIER_ACCESS_RESOLVE_DEST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 4096
D3D12_BARRIER_ACCESS_RESOLVE_SOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 8192
D3D12_BARRIER_ACCESS_RAYTRACING_ACCELERATION_STRUCTURE_READ: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 16384
D3D12_BARRIER_ACCESS_RAYTRACING_ACCELERATION_STRUCTURE_WRITE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 32768
D3D12_BARRIER_ACCESS_SHADING_RATE_SOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 65536
D3D12_BARRIER_ACCESS_VIDEO_DECODE_READ: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 131072
D3D12_BARRIER_ACCESS_VIDEO_DECODE_WRITE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 262144
D3D12_BARRIER_ACCESS_VIDEO_PROCESS_READ: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 524288
D3D12_BARRIER_ACCESS_VIDEO_PROCESS_WRITE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 1048576
D3D12_BARRIER_ACCESS_VIDEO_ENCODE_READ: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 2097152
D3D12_BARRIER_ACCESS_VIDEO_ENCODE_WRITE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = 4194304
D3D12_BARRIER_ACCESS_NO_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS = -2147483648
class D3D12_BARRIER_GROUP(Structure):
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_TYPE
    NumBarriers: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        pGlobalBarriers: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GLOBAL_BARRIER)
        pTextureBarriers: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_BARRIER)
        pBufferBarriers: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BUFFER_BARRIER)
D3D12_BARRIER_LAYOUT = Int32
D3D12_BARRIER_LAYOUT_UNDEFINED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = -1
D3D12_BARRIER_LAYOUT_COMMON: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 0
D3D12_BARRIER_LAYOUT_PRESENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 0
D3D12_BARRIER_LAYOUT_GENERIC_READ: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 1
D3D12_BARRIER_LAYOUT_RENDER_TARGET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 2
D3D12_BARRIER_LAYOUT_UNORDERED_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 3
D3D12_BARRIER_LAYOUT_DEPTH_STENCIL_WRITE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 4
D3D12_BARRIER_LAYOUT_DEPTH_STENCIL_READ: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 5
D3D12_BARRIER_LAYOUT_SHADER_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 6
D3D12_BARRIER_LAYOUT_COPY_SOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 7
D3D12_BARRIER_LAYOUT_COPY_DEST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 8
D3D12_BARRIER_LAYOUT_RESOLVE_SOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 9
D3D12_BARRIER_LAYOUT_RESOLVE_DEST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 10
D3D12_BARRIER_LAYOUT_SHADING_RATE_SOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 11
D3D12_BARRIER_LAYOUT_VIDEO_DECODE_READ: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 12
D3D12_BARRIER_LAYOUT_VIDEO_DECODE_WRITE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 13
D3D12_BARRIER_LAYOUT_VIDEO_PROCESS_READ: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 14
D3D12_BARRIER_LAYOUT_VIDEO_PROCESS_WRITE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 15
D3D12_BARRIER_LAYOUT_VIDEO_ENCODE_READ: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 16
D3D12_BARRIER_LAYOUT_VIDEO_ENCODE_WRITE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 17
D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_COMMON: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 18
D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_GENERIC_READ: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 19
D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_UNORDERED_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 20
D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_SHADER_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 21
D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_COPY_SOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 22
D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_COPY_DEST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 23
D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_COMMON: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 24
D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_GENERIC_READ: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 25
D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_UNORDERED_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 26
D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_SHADER_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 27
D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_COPY_SOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 28
D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_COPY_DEST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 29
D3D12_BARRIER_LAYOUT_VIDEO_QUEUE_COMMON: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT = 30
class D3D12_BARRIER_SUBRESOURCE_RANGE(Structure):
    IndexOrFirstMipLevel: UInt32
    NumMipLevels: UInt32
    FirstArraySlice: UInt32
    NumArraySlices: UInt32
    FirstPlane: UInt32
    NumPlanes: UInt32
D3D12_BARRIER_SYNC = Int32
D3D12_BARRIER_SYNC_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 0
D3D12_BARRIER_SYNC_ALL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 1
D3D12_BARRIER_SYNC_DRAW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 2
D3D12_BARRIER_SYNC_INDEX_INPUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 4
D3D12_BARRIER_SYNC_VERTEX_SHADING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 8
D3D12_BARRIER_SYNC_PIXEL_SHADING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 16
D3D12_BARRIER_SYNC_DEPTH_STENCIL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 32
D3D12_BARRIER_SYNC_RENDER_TARGET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 64
D3D12_BARRIER_SYNC_COMPUTE_SHADING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 128
D3D12_BARRIER_SYNC_RAYTRACING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 256
D3D12_BARRIER_SYNC_COPY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 512
D3D12_BARRIER_SYNC_RESOLVE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 1024
D3D12_BARRIER_SYNC_EXECUTE_INDIRECT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 2048
D3D12_BARRIER_SYNC_PREDICATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 2048
D3D12_BARRIER_SYNC_ALL_SHADING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 4096
D3D12_BARRIER_SYNC_NON_PIXEL_SHADING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 8192
D3D12_BARRIER_SYNC_EMIT_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 16384
D3D12_BARRIER_SYNC_CLEAR_UNORDERED_ACCESS_VIEW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 32768
D3D12_BARRIER_SYNC_VIDEO_DECODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 1048576
D3D12_BARRIER_SYNC_VIDEO_PROCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 2097152
D3D12_BARRIER_SYNC_VIDEO_ENCODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 4194304
D3D12_BARRIER_SYNC_BUILD_RAYTRACING_ACCELERATION_STRUCTURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 8388608
D3D12_BARRIER_SYNC_COPY_RAYTRACING_ACCELERATION_STRUCTURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = 16777216
D3D12_BARRIER_SYNC_SPLIT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC = -2147483648
D3D12_BARRIER_TYPE = Int32
D3D12_BARRIER_TYPE_GLOBAL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_TYPE = 0
D3D12_BARRIER_TYPE_TEXTURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_TYPE = 1
D3D12_BARRIER_TYPE_BUFFER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_TYPE = 2
D3D12_BLEND = Int32
D3D12_BLEND_ZERO: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 1
D3D12_BLEND_ONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 2
D3D12_BLEND_SRC_COLOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 3
D3D12_BLEND_INV_SRC_COLOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 4
D3D12_BLEND_SRC_ALPHA: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 5
D3D12_BLEND_INV_SRC_ALPHA: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 6
D3D12_BLEND_DEST_ALPHA: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 7
D3D12_BLEND_INV_DEST_ALPHA: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 8
D3D12_BLEND_DEST_COLOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 9
D3D12_BLEND_INV_DEST_COLOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 10
D3D12_BLEND_SRC_ALPHA_SAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 11
D3D12_BLEND_BLEND_FACTOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 14
D3D12_BLEND_INV_BLEND_FACTOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 15
D3D12_BLEND_SRC1_COLOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 16
D3D12_BLEND_INV_SRC1_COLOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 17
D3D12_BLEND_SRC1_ALPHA: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 18
D3D12_BLEND_INV_SRC1_ALPHA: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 19
D3D12_BLEND_ALPHA_FACTOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 20
D3D12_BLEND_INV_ALPHA_FACTOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND = 21
class D3D12_BLEND_DESC(Structure):
    AlphaToCoverageEnable: win32more.Windows.Win32.Foundation.BOOL
    IndependentBlendEnable: win32more.Windows.Win32.Foundation.BOOL
    RenderTarget: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_TARGET_BLEND_DESC * 8
D3D12_BLEND_OP = Int32
D3D12_BLEND_OP_ADD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND_OP = 1
D3D12_BLEND_OP_SUBTRACT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND_OP = 2
D3D12_BLEND_OP_REV_SUBTRACT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND_OP = 3
D3D12_BLEND_OP_MIN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND_OP = 4
D3D12_BLEND_OP_MAX: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND_OP = 5
class D3D12_BOX(Structure):
    left: UInt32
    top: UInt32
    front: UInt32
    right: UInt32
    bottom: UInt32
    back: UInt32
class D3D12_BROADCASTING_LAUNCH_OVERRIDES(Structure):
    pLocalRootArgumentsTableIndex: POINTER(UInt32)
    pProgramEntry: POINTER(win32more.Windows.Win32.Foundation.BOOL)
    pNewName: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_ID)
    pShareInputOf: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_ID)
    pDispatchGrid: POINTER(UInt32)
    pMaxDispatchGrid: POINTER(UInt32)
    NumOutputOverrides: UInt32
    pOutputOverrides: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_OUTPUT_OVERRIDES)
class D3D12_BUFFER_BARRIER(Structure):
    SyncBefore: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC
    SyncAfter: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC
    AccessBefore: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS
    AccessAfter: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS
    pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource
    Offset: UInt64
    Size: UInt64
class D3D12_BUFFER_RTV(Structure):
    FirstElement: UInt64
    NumElements: UInt32
class D3D12_BUFFER_SRV(Structure):
    FirstElement: UInt64
    NumElements: UInt32
    StructureByteStride: UInt32
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BUFFER_SRV_FLAGS
D3D12_BUFFER_SRV_FLAGS = Int32
D3D12_BUFFER_SRV_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BUFFER_SRV_FLAGS = 0
D3D12_BUFFER_SRV_FLAG_RAW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BUFFER_SRV_FLAGS = 1
class D3D12_BUFFER_UAV(Structure):
    FirstElement: UInt64
    NumElements: UInt32
    StructureByteStride: UInt32
    CounterOffsetInBytes: UInt64
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BUFFER_UAV_FLAGS
D3D12_BUFFER_UAV_FLAGS = Int32
D3D12_BUFFER_UAV_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BUFFER_UAV_FLAGS = 0
D3D12_BUFFER_UAV_FLAG_RAW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BUFFER_UAV_FLAGS = 1
class D3D12_BUILD_RAYTRACING_ACCELERATION_STRUCTURE_DESC(Structure):
    DestAccelerationStructureData: UInt64
    Inputs: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BUILD_RAYTRACING_ACCELERATION_STRUCTURE_INPUTS
    SourceAccelerationStructureData: UInt64
    ScratchAccelerationStructureData: UInt64
class D3D12_BUILD_RAYTRACING_ACCELERATION_STRUCTURE_INPUTS(Structure):
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_TYPE
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAGS
    NumDescs: UInt32
    DescsLayout: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ELEMENTS_LAYOUT
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        InstanceDescs: UInt64
        pGeometryDescs: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_GEOMETRY_DESC)
        ppGeometryDescs: POINTER(POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_GEOMETRY_DESC))
class D3D12_BUILD_RAYTRACING_ACCELERATION_STRUCTURE_TOOLS_VISUALIZATION_HEADER(Structure):
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_TYPE
    NumDescs: UInt32
class D3D12_CACHED_PIPELINE_STATE(Structure):
    pCachedBlob: VoidPtr
    CachedBlobSizeInBytes: UIntPtr
D3D12_CLEAR_FLAGS = Int32
D3D12_CLEAR_FLAG_DEPTH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CLEAR_FLAGS = 1
D3D12_CLEAR_FLAG_STENCIL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CLEAR_FLAGS = 2
class D3D12_CLEAR_VALUE(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Color: Single * 4
        DepthStencil: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEPTH_STENCIL_VALUE
class D3D12_COALESCING_LAUNCH_OVERRIDES(Structure):
    pLocalRootArgumentsTableIndex: POINTER(UInt32)
    pProgramEntry: POINTER(win32more.Windows.Win32.Foundation.BOOL)
    pNewName: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_ID)
    pShareInputOf: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_ID)
    NumOutputOverrides: UInt32
    pOutputOverrides: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_OUTPUT_OVERRIDES)
D3D12_COLOR_WRITE_ENABLE = Int32
D3D12_COLOR_WRITE_ENABLE_RED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COLOR_WRITE_ENABLE = 1
D3D12_COLOR_WRITE_ENABLE_GREEN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COLOR_WRITE_ENABLE = 2
D3D12_COLOR_WRITE_ENABLE_BLUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COLOR_WRITE_ENABLE = 4
D3D12_COLOR_WRITE_ENABLE_ALPHA: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COLOR_WRITE_ENABLE = 8
D3D12_COLOR_WRITE_ENABLE_ALL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COLOR_WRITE_ENABLE = 15
D3D12_COMMAND_LIST_FLAGS = Int32
D3D12_COMMAND_LIST_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_FLAGS = 0
D3D12_COMMAND_LIST_SUPPORT_FLAGS = Int32
D3D12_COMMAND_LIST_SUPPORT_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_SUPPORT_FLAGS = 0
D3D12_COMMAND_LIST_SUPPORT_FLAG_DIRECT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_SUPPORT_FLAGS = 1
D3D12_COMMAND_LIST_SUPPORT_FLAG_BUNDLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_SUPPORT_FLAGS = 2
D3D12_COMMAND_LIST_SUPPORT_FLAG_COMPUTE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_SUPPORT_FLAGS = 4
D3D12_COMMAND_LIST_SUPPORT_FLAG_COPY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_SUPPORT_FLAGS = 8
D3D12_COMMAND_LIST_SUPPORT_FLAG_VIDEO_DECODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_SUPPORT_FLAGS = 16
D3D12_COMMAND_LIST_SUPPORT_FLAG_VIDEO_PROCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_SUPPORT_FLAGS = 32
D3D12_COMMAND_LIST_SUPPORT_FLAG_VIDEO_ENCODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_SUPPORT_FLAGS = 64
D3D12_COMMAND_LIST_TYPE = Int32
D3D12_COMMAND_LIST_TYPE_DIRECT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_TYPE = 0
D3D12_COMMAND_LIST_TYPE_BUNDLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_TYPE = 1
D3D12_COMMAND_LIST_TYPE_COMPUTE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_TYPE = 2
D3D12_COMMAND_LIST_TYPE_COPY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_TYPE = 3
D3D12_COMMAND_LIST_TYPE_VIDEO_DECODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_TYPE = 4
D3D12_COMMAND_LIST_TYPE_VIDEO_PROCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_TYPE = 5
D3D12_COMMAND_LIST_TYPE_VIDEO_ENCODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_TYPE = 6
D3D12_COMMAND_LIST_TYPE_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_TYPE = -1
D3D12_COMMAND_POOL_FLAGS = Int32
D3D12_COMMAND_POOL_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_POOL_FLAGS = 0
class D3D12_COMMAND_QUEUE_DESC(Structure):
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_TYPE
    Priority: Int32
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_QUEUE_FLAGS
    NodeMask: UInt32
D3D12_COMMAND_QUEUE_FLAGS = Int32
D3D12_COMMAND_QUEUE_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_QUEUE_FLAGS = 0
D3D12_COMMAND_QUEUE_FLAG_DISABLE_GPU_TIMEOUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_QUEUE_FLAGS = 1
D3D12_COMMAND_QUEUE_PRIORITY = Int32
D3D12_COMMAND_QUEUE_PRIORITY_NORMAL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_QUEUE_PRIORITY = 0
D3D12_COMMAND_QUEUE_PRIORITY_HIGH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_QUEUE_PRIORITY = 100
D3D12_COMMAND_QUEUE_PRIORITY_GLOBAL_REALTIME: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_QUEUE_PRIORITY = 10000
D3D12_COMMAND_RECORDER_FLAGS = Int32
D3D12_COMMAND_RECORDER_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_RECORDER_FLAGS = 0
class D3D12_COMMAND_SIGNATURE_DESC(Structure):
    ByteStride: UInt32
    NumArgumentDescs: UInt32
    pArgumentDescs: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDIRECT_ARGUMENT_DESC)
    NodeMask: UInt32
class D3D12_COMMON_COMPUTE_NODE_OVERRIDES(Structure):
    pLocalRootArgumentsTableIndex: POINTER(UInt32)
    pProgramEntry: POINTER(win32more.Windows.Win32.Foundation.BOOL)
    pNewName: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_ID)
    pShareInputOf: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_ID)
    NumOutputOverrides: UInt32
    pOutputOverrides: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_OUTPUT_OVERRIDES)
D3D12_COMPARISON_FUNC = Int32
D3D12_COMPARISON_FUNC_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC = 0
D3D12_COMPARISON_FUNC_NEVER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC = 1
D3D12_COMPARISON_FUNC_LESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC = 2
D3D12_COMPARISON_FUNC_EQUAL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC = 3
D3D12_COMPARISON_FUNC_LESS_EQUAL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC = 4
D3D12_COMPARISON_FUNC_GREATER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC = 5
D3D12_COMPARISON_FUNC_NOT_EQUAL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC = 6
D3D12_COMPARISON_FUNC_GREATER_EQUAL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC = 7
D3D12_COMPARISON_FUNC_ALWAYS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC = 8
class D3D12_COMPUTE_PIPELINE_STATE_DESC(Structure):
    pRootSignature: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12RootSignature
    CS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_BYTECODE
    NodeMask: UInt32
    CachedPSO: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CACHED_PIPELINE_STATE
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_FLAGS
D3D12_CONSERVATIVE_RASTERIZATION_MODE = Int32
D3D12_CONSERVATIVE_RASTERIZATION_MODE_OFF: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CONSERVATIVE_RASTERIZATION_MODE = 0
D3D12_CONSERVATIVE_RASTERIZATION_MODE_ON: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CONSERVATIVE_RASTERIZATION_MODE = 1
D3D12_CONSERVATIVE_RASTERIZATION_TIER = Int32
D3D12_CONSERVATIVE_RASTERIZATION_TIER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CONSERVATIVE_RASTERIZATION_TIER = 0
D3D12_CONSERVATIVE_RASTERIZATION_TIER_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CONSERVATIVE_RASTERIZATION_TIER = 1
D3D12_CONSERVATIVE_RASTERIZATION_TIER_2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CONSERVATIVE_RASTERIZATION_TIER = 2
D3D12_CONSERVATIVE_RASTERIZATION_TIER_3: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CONSERVATIVE_RASTERIZATION_TIER = 3
class D3D12_CONSTANT_BUFFER_VIEW_DESC(Structure):
    BufferLocation: UInt64
    SizeInBytes: UInt32
class D3D12_CPU_DESCRIPTOR_HANDLE(Structure):
    ptr: UIntPtr
D3D12_CPU_PAGE_PROPERTY = Int32
D3D12_CPU_PAGE_PROPERTY_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_PAGE_PROPERTY = 0
D3D12_CPU_PAGE_PROPERTY_NOT_AVAILABLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_PAGE_PROPERTY = 1
D3D12_CPU_PAGE_PROPERTY_WRITE_COMBINE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_PAGE_PROPERTY = 2
D3D12_CPU_PAGE_PROPERTY_WRITE_BACK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_PAGE_PROPERTY = 3
D3D12_CROSS_NODE_SHARING_TIER = Int32
D3D12_CROSS_NODE_SHARING_TIER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CROSS_NODE_SHARING_TIER = 0
D3D12_CROSS_NODE_SHARING_TIER_1_EMULATED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CROSS_NODE_SHARING_TIER = 1
D3D12_CROSS_NODE_SHARING_TIER_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CROSS_NODE_SHARING_TIER = 2
D3D12_CROSS_NODE_SHARING_TIER_2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CROSS_NODE_SHARING_TIER = 3
D3D12_CROSS_NODE_SHARING_TIER_3: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CROSS_NODE_SHARING_TIER = 4
D3D12_CULL_MODE = Int32
D3D12_CULL_MODE_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CULL_MODE = 1
D3D12_CULL_MODE_FRONT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CULL_MODE = 2
D3D12_CULL_MODE_BACK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CULL_MODE = 3
class D3D12_DEBUG_COMMAND_LIST_GPU_BASED_VALIDATION_SETTINGS(Structure):
    ShaderPatchMode: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_BASED_VALIDATION_SHADER_PATCH_MODE
D3D12_DEBUG_COMMAND_LIST_PARAMETER_TYPE = Int32
D3D12_DEBUG_COMMAND_LIST_PARAMETER_GPU_BASED_VALIDATION_SETTINGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_COMMAND_LIST_PARAMETER_TYPE = 0
class D3D12_DEBUG_DEVICE_GPU_BASED_VALIDATION_SETTINGS(Structure):
    MaxMessagesPerCommandList: UInt32
    DefaultShaderPatchMode: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_BASED_VALIDATION_SHADER_PATCH_MODE
    PipelineStateCreateFlags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_BASED_VALIDATION_PIPELINE_STATE_CREATE_FLAGS
class D3D12_DEBUG_DEVICE_GPU_SLOWDOWN_PERFORMANCE_FACTOR(Structure):
    SlowdownFactor: Single
D3D12_DEBUG_DEVICE_PARAMETER_TYPE = Int32
D3D12_DEBUG_DEVICE_PARAMETER_FEATURE_FLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_DEVICE_PARAMETER_TYPE = 0
D3D12_DEBUG_DEVICE_PARAMETER_GPU_BASED_VALIDATION_SETTINGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_DEVICE_PARAMETER_TYPE = 1
D3D12_DEBUG_DEVICE_PARAMETER_GPU_SLOWDOWN_PERFORMANCE_FACTOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_DEVICE_PARAMETER_TYPE = 2
D3D12_DEBUG_FEATURE = Int32
D3D12_DEBUG_FEATURE_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_FEATURE = 0
D3D12_DEBUG_FEATURE_ALLOW_BEHAVIOR_CHANGING_DEBUG_AIDS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_FEATURE = 1
D3D12_DEBUG_FEATURE_CONSERVATIVE_RESOURCE_STATE_TRACKING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_FEATURE = 2
D3D12_DEBUG_FEATURE_DISABLE_VIRTUALIZED_BUNDLES_VALIDATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_FEATURE = 4
D3D12_DEBUG_FEATURE_EMULATE_WINDOWS7: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_FEATURE = 8
class D3D12_DEPTH_STENCILOP_DESC(Structure):
    StencilFailOp: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STENCIL_OP
    StencilDepthFailOp: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STENCIL_OP
    StencilPassOp: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STENCIL_OP
    StencilFunc: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC
class D3D12_DEPTH_STENCILOP_DESC1(Structure):
    StencilFailOp: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STENCIL_OP
    StencilDepthFailOp: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STENCIL_OP
    StencilPassOp: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STENCIL_OP
    StencilFunc: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC
    StencilReadMask: Byte
    StencilWriteMask: Byte
class D3D12_DEPTH_STENCIL_DESC(Structure):
    DepthEnable: win32more.Windows.Win32.Foundation.BOOL
    DepthWriteMask: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEPTH_WRITE_MASK
    DepthFunc: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC
    StencilEnable: win32more.Windows.Win32.Foundation.BOOL
    StencilReadMask: Byte
    StencilWriteMask: Byte
    FrontFace: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEPTH_STENCILOP_DESC
    BackFace: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEPTH_STENCILOP_DESC
class D3D12_DEPTH_STENCIL_DESC1(Structure):
    DepthEnable: win32more.Windows.Win32.Foundation.BOOL
    DepthWriteMask: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEPTH_WRITE_MASK
    DepthFunc: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC
    StencilEnable: win32more.Windows.Win32.Foundation.BOOL
    StencilReadMask: Byte
    StencilWriteMask: Byte
    FrontFace: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEPTH_STENCILOP_DESC
    BackFace: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEPTH_STENCILOP_DESC
    DepthBoundsTestEnable: win32more.Windows.Win32.Foundation.BOOL
class D3D12_DEPTH_STENCIL_DESC2(Structure):
    DepthEnable: win32more.Windows.Win32.Foundation.BOOL
    DepthWriteMask: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEPTH_WRITE_MASK
    DepthFunc: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC
    StencilEnable: win32more.Windows.Win32.Foundation.BOOL
    FrontFace: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEPTH_STENCILOP_DESC1
    BackFace: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEPTH_STENCILOP_DESC1
    DepthBoundsTestEnable: win32more.Windows.Win32.Foundation.BOOL
class D3D12_DEPTH_STENCIL_FORMAT(Structure):
    DepthStencilFormat: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
class D3D12_DEPTH_STENCIL_VALUE(Structure):
    Depth: Single
    Stencil: Byte
class D3D12_DEPTH_STENCIL_VIEW_DESC(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DSV_DIMENSION
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DSV_FLAGS
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Texture1D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX1D_DSV
        Texture1DArray: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX1D_ARRAY_DSV
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX2D_DSV
        Texture2DArray: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX2D_ARRAY_DSV
        Texture2DMS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX2DMS_DSV
        Texture2DMSArray: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX2DMS_ARRAY_DSV
D3D12_DEPTH_WRITE_MASK = Int32
D3D12_DEPTH_WRITE_MASK_ZERO: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEPTH_WRITE_MASK = 0
D3D12_DEPTH_WRITE_MASK_ALL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEPTH_WRITE_MASK = 1
class D3D12_DESCRIPTOR_HEAP_DESC(Structure):
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_HEAP_TYPE
    NumDescriptors: UInt32
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_HEAP_FLAGS
    NodeMask: UInt32
D3D12_DESCRIPTOR_HEAP_FLAGS = Int32
D3D12_DESCRIPTOR_HEAP_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_HEAP_FLAGS = 0
D3D12_DESCRIPTOR_HEAP_FLAG_SHADER_VISIBLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_HEAP_FLAGS = 1
D3D12_DESCRIPTOR_HEAP_TYPE = Int32
D3D12_DESCRIPTOR_HEAP_TYPE_CBV_SRV_UAV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_HEAP_TYPE = 0
D3D12_DESCRIPTOR_HEAP_TYPE_SAMPLER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_HEAP_TYPE = 1
D3D12_DESCRIPTOR_HEAP_TYPE_RTV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_HEAP_TYPE = 2
D3D12_DESCRIPTOR_HEAP_TYPE_DSV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_HEAP_TYPE = 3
D3D12_DESCRIPTOR_HEAP_TYPE_NUM_TYPES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_HEAP_TYPE = 4
class D3D12_DESCRIPTOR_RANGE(Structure):
    RangeType: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_RANGE_TYPE
    NumDescriptors: UInt32
    BaseShaderRegister: UInt32
    RegisterSpace: UInt32
    OffsetInDescriptorsFromTableStart: UInt32
class D3D12_DESCRIPTOR_RANGE1(Structure):
    RangeType: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_RANGE_TYPE
    NumDescriptors: UInt32
    BaseShaderRegister: UInt32
    RegisterSpace: UInt32
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_RANGE_FLAGS
    OffsetInDescriptorsFromTableStart: UInt32
D3D12_DESCRIPTOR_RANGE_FLAGS = Int32
D3D12_DESCRIPTOR_RANGE_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_RANGE_FLAGS = 0
D3D12_DESCRIPTOR_RANGE_FLAG_DESCRIPTORS_VOLATILE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_RANGE_FLAGS = 1
D3D12_DESCRIPTOR_RANGE_FLAG_DATA_VOLATILE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_RANGE_FLAGS = 2
D3D12_DESCRIPTOR_RANGE_FLAG_DATA_STATIC_WHILE_SET_AT_EXECUTE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_RANGE_FLAGS = 4
D3D12_DESCRIPTOR_RANGE_FLAG_DATA_STATIC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_RANGE_FLAGS = 8
D3D12_DESCRIPTOR_RANGE_FLAG_DESCRIPTORS_STATIC_KEEPING_BUFFER_BOUNDS_CHECKS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_RANGE_FLAGS = 65536
D3D12_DESCRIPTOR_RANGE_TYPE = Int32
D3D12_DESCRIPTOR_RANGE_TYPE_SRV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_RANGE_TYPE = 0
D3D12_DESCRIPTOR_RANGE_TYPE_UAV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_RANGE_TYPE = 1
D3D12_DESCRIPTOR_RANGE_TYPE_CBV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_RANGE_TYPE = 2
D3D12_DESCRIPTOR_RANGE_TYPE_SAMPLER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_RANGE_TYPE = 3
class D3D12_DEVICE_CONFIGURATION_DESC(Structure):
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FLAGS
    GpuBasedValidationFlags: UInt32
    SDKVersion: UInt32
    NumEnabledExperimentalFeatures: UInt32
D3D12_DEVICE_FACTORY_FLAGS = Int32
D3D12_DEVICE_FACTORY_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FACTORY_FLAGS = 0
D3D12_DEVICE_FACTORY_FLAG_ALLOW_RETURNING_EXISTING_DEVICE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FACTORY_FLAGS = 1
D3D12_DEVICE_FACTORY_FLAG_ALLOW_RETURNING_INCOMPATIBLE_EXISTING_DEVICE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FACTORY_FLAGS = 2
D3D12_DEVICE_FACTORY_FLAG_DISALLOW_STORING_NEW_DEVICE_AS_SINGLETON: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FACTORY_FLAGS = 4
D3D12_DEVICE_FLAGS = Int32
D3D12_DEVICE_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FLAGS = 0
D3D12_DEVICE_FLAG_DEBUG_LAYER_ENABLED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FLAGS = 1
D3D12_DEVICE_FLAG_GPU_BASED_VALIDATION_ENABLED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FLAGS = 2
D3D12_DEVICE_FLAG_SYNCHRONIZED_COMMAND_QUEUE_VALIDATION_DISABLED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FLAGS = 4
D3D12_DEVICE_FLAG_DRED_AUTO_BREADCRUMBS_ENABLED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FLAGS = 8
D3D12_DEVICE_FLAG_DRED_PAGE_FAULT_REPORTING_ENABLED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FLAGS = 16
D3D12_DEVICE_FLAG_DRED_WATSON_REPORTING_ENABLED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FLAGS = 32
D3D12_DEVICE_FLAG_DRED_BREADCRUMB_CONTEXT_ENABLED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FLAGS = 64
D3D12_DEVICE_FLAG_DRED_USE_MARKERS_ONLY_BREADCRUMBS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FLAGS = 128
D3D12_DEVICE_FLAG_SHADER_INSTRUMENTATION_ENABLED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FLAGS = 256
D3D12_DEVICE_FLAG_AUTO_DEBUG_NAME_ENABLED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FLAGS = 512
D3D12_DEVICE_FLAG_FORCE_LEGACY_STATE_VALIDATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FLAGS = 1024
class D3D12_DEVICE_REMOVED_EXTENDED_DATA(Structure):
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_FLAGS
    pHeadAutoBreadcrumbNode: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_NODE)
class D3D12_DEVICE_REMOVED_EXTENDED_DATA1(Structure):
    DeviceRemovedReason: win32more.Windows.Win32.Foundation.HRESULT
    AutoBreadcrumbsOutput: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_AUTO_BREADCRUMBS_OUTPUT
    PageFaultOutput: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_PAGE_FAULT_OUTPUT
class D3D12_DEVICE_REMOVED_EXTENDED_DATA2(Structure):
    DeviceRemovedReason: win32more.Windows.Win32.Foundation.HRESULT
    AutoBreadcrumbsOutput: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_AUTO_BREADCRUMBS_OUTPUT1
    PageFaultOutput: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_PAGE_FAULT_OUTPUT1
class D3D12_DEVICE_REMOVED_EXTENDED_DATA3(Structure):
    DeviceRemovedReason: win32more.Windows.Win32.Foundation.HRESULT
    AutoBreadcrumbsOutput: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_AUTO_BREADCRUMBS_OUTPUT1
    PageFaultOutput: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_PAGE_FAULT_OUTPUT2
    DeviceState: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_DEVICE_STATE
class D3D12_DISCARD_REGION(Structure):
    NumRects: UInt32
    pRects: POINTER(win32more.Windows.Win32.Foundation.RECT)
    FirstSubresource: UInt32
    NumSubresources: UInt32
class D3D12_DISPATCH_ARGUMENTS(Structure):
    ThreadGroupCountX: UInt32
    ThreadGroupCountY: UInt32
    ThreadGroupCountZ: UInt32
class D3D12_DISPATCH_GRAPH_DESC(Structure):
    Mode: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DISPATCH_MODE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        NodeCPUInput: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_CPU_INPUT
        NodeGPUInput: UInt64
        MultiNodeCPUInput: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MULTI_NODE_CPU_INPUT
        MultiNodeGPUInput: UInt64
class D3D12_DISPATCH_MESH_ARGUMENTS(Structure):
    ThreadGroupCountX: UInt32
    ThreadGroupCountY: UInt32
    ThreadGroupCountZ: UInt32
D3D12_DISPATCH_MODE = Int32
D3D12_DISPATCH_MODE_NODE_CPU_INPUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DISPATCH_MODE = 0
D3D12_DISPATCH_MODE_NODE_GPU_INPUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DISPATCH_MODE = 1
D3D12_DISPATCH_MODE_MULTI_NODE_CPU_INPUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DISPATCH_MODE = 2
D3D12_DISPATCH_MODE_MULTI_NODE_GPU_INPUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DISPATCH_MODE = 3
class D3D12_DISPATCH_RAYS_DESC(Structure):
    RayGenerationShaderRecord: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_VIRTUAL_ADDRESS_RANGE
    MissShaderTable: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_VIRTUAL_ADDRESS_RANGE_AND_STRIDE
    HitGroupTable: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_VIRTUAL_ADDRESS_RANGE_AND_STRIDE
    CallableShaderTable: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_VIRTUAL_ADDRESS_RANGE_AND_STRIDE
    Width: UInt32
    Height: UInt32
    Depth: UInt32
class D3D12_DRAW_ARGUMENTS(Structure):
    VertexCountPerInstance: UInt32
    InstanceCount: UInt32
    StartVertexLocation: UInt32
    StartInstanceLocation: UInt32
class D3D12_DRAW_INDEXED_ARGUMENTS(Structure):
    IndexCountPerInstance: UInt32
    InstanceCount: UInt32
    StartIndexLocation: UInt32
    BaseVertexLocation: Int32
    StartInstanceLocation: UInt32
class D3D12_DRED_ALLOCATION_NODE(Structure):
    ObjectNameA: POINTER(Byte)
    ObjectNameW: win32more.Windows.Win32.Foundation.PWSTR
    AllocationType: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE
    pNext: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_NODE)
class D3D12_DRED_ALLOCATION_NODE1(Structure):
    ObjectNameA: POINTER(Byte)
    ObjectNameW: win32more.Windows.Win32.Foundation.PWSTR
    AllocationType: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE
    pNext: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_NODE1)
    pObject: win32more.Windows.Win32.System.Com.IUnknown
D3D12_DRED_ALLOCATION_TYPE = Int32
D3D12_DRED_ALLOCATION_TYPE_COMMAND_QUEUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 19
D3D12_DRED_ALLOCATION_TYPE_COMMAND_ALLOCATOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 20
D3D12_DRED_ALLOCATION_TYPE_PIPELINE_STATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 21
D3D12_DRED_ALLOCATION_TYPE_COMMAND_LIST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 22
D3D12_DRED_ALLOCATION_TYPE_FENCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 23
D3D12_DRED_ALLOCATION_TYPE_DESCRIPTOR_HEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 24
D3D12_DRED_ALLOCATION_TYPE_HEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 25
D3D12_DRED_ALLOCATION_TYPE_QUERY_HEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 27
D3D12_DRED_ALLOCATION_TYPE_COMMAND_SIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 28
D3D12_DRED_ALLOCATION_TYPE_PIPELINE_LIBRARY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 29
D3D12_DRED_ALLOCATION_TYPE_VIDEO_DECODER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 30
D3D12_DRED_ALLOCATION_TYPE_VIDEO_PROCESSOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 32
D3D12_DRED_ALLOCATION_TYPE_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 34
D3D12_DRED_ALLOCATION_TYPE_PASS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 35
D3D12_DRED_ALLOCATION_TYPE_CRYPTOSESSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 36
D3D12_DRED_ALLOCATION_TYPE_CRYPTOSESSIONPOLICY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 37
D3D12_DRED_ALLOCATION_TYPE_PROTECTEDRESOURCESESSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 38
D3D12_DRED_ALLOCATION_TYPE_VIDEO_DECODER_HEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 39
D3D12_DRED_ALLOCATION_TYPE_COMMAND_POOL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 40
D3D12_DRED_ALLOCATION_TYPE_COMMAND_RECORDER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 41
D3D12_DRED_ALLOCATION_TYPE_STATE_OBJECT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 42
D3D12_DRED_ALLOCATION_TYPE_METACOMMAND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 43
D3D12_DRED_ALLOCATION_TYPE_SCHEDULINGGROUP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 44
D3D12_DRED_ALLOCATION_TYPE_VIDEO_MOTION_ESTIMATOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 45
D3D12_DRED_ALLOCATION_TYPE_VIDEO_MOTION_VECTOR_HEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 46
D3D12_DRED_ALLOCATION_TYPE_VIDEO_EXTENSION_COMMAND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 47
D3D12_DRED_ALLOCATION_TYPE_VIDEO_ENCODER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 48
D3D12_DRED_ALLOCATION_TYPE_VIDEO_ENCODER_HEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = 49
D3D12_DRED_ALLOCATION_TYPE_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_TYPE = -1
class D3D12_DRED_AUTO_BREADCRUMBS_OUTPUT(Structure):
    pHeadAutoBreadcrumbNode: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_NODE)
class D3D12_DRED_AUTO_BREADCRUMBS_OUTPUT1(Structure):
    pHeadAutoBreadcrumbNode: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_AUTO_BREADCRUMB_NODE1)
class D3D12_DRED_BREADCRUMB_CONTEXT(Structure):
    BreadcrumbIndex: UInt32
    pContextString: win32more.Windows.Win32.Foundation.PWSTR
D3D12_DRED_DEVICE_STATE = Int32
D3D12_DRED_DEVICE_STATE_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_DEVICE_STATE = 0
D3D12_DRED_DEVICE_STATE_HUNG: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_DEVICE_STATE = 3
D3D12_DRED_DEVICE_STATE_FAULT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_DEVICE_STATE = 6
D3D12_DRED_DEVICE_STATE_PAGEFAULT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_DEVICE_STATE = 7
D3D12_DRED_ENABLEMENT = Int32
D3D12_DRED_ENABLEMENT_SYSTEM_CONTROLLED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ENABLEMENT = 0
D3D12_DRED_ENABLEMENT_FORCED_OFF: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ENABLEMENT = 1
D3D12_DRED_ENABLEMENT_FORCED_ON: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ENABLEMENT = 2
D3D12_DRED_FLAGS = Int32
D3D12_DRED_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_FLAGS = 0
D3D12_DRED_FLAG_FORCE_ENABLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_FLAGS = 1
D3D12_DRED_FLAG_DISABLE_AUTOBREADCRUMBS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_FLAGS = 2
D3D12_DRED_PAGE_FAULT_FLAGS = Int32
D3D12_DRED_PAGE_FAULT_FLAGS_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_PAGE_FAULT_FLAGS = 0
class D3D12_DRED_PAGE_FAULT_OUTPUT(Structure):
    PageFaultVA: UInt64
    pHeadExistingAllocationNode: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_NODE)
    pHeadRecentFreedAllocationNode: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_NODE)
class D3D12_DRED_PAGE_FAULT_OUTPUT1(Structure):
    PageFaultVA: UInt64
    pHeadExistingAllocationNode: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_NODE1)
    pHeadRecentFreedAllocationNode: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_NODE1)
class D3D12_DRED_PAGE_FAULT_OUTPUT2(Structure):
    PageFaultVA: UInt64
    pHeadExistingAllocationNode: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_NODE1)
    pHeadRecentFreedAllocationNode: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ALLOCATION_NODE1)
    PageFaultFlags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_PAGE_FAULT_FLAGS
D3D12_DRED_VERSION = Int32
D3D12_DRED_VERSION_1_0: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_VERSION = 1
D3D12_DRED_VERSION_1_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_VERSION = 2
D3D12_DRED_VERSION_1_2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_VERSION = 3
D3D12_DRED_VERSION_1_3: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_VERSION = 4
D3D12_DRIVER_MATCHING_IDENTIFIER_STATUS = Int32
D3D12_DRIVER_MATCHING_IDENTIFIER_COMPATIBLE_WITH_DEVICE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRIVER_MATCHING_IDENTIFIER_STATUS = 0
D3D12_DRIVER_MATCHING_IDENTIFIER_UNSUPPORTED_TYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRIVER_MATCHING_IDENTIFIER_STATUS = 1
D3D12_DRIVER_MATCHING_IDENTIFIER_UNRECOGNIZED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRIVER_MATCHING_IDENTIFIER_STATUS = 2
D3D12_DRIVER_MATCHING_IDENTIFIER_INCOMPATIBLE_VERSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRIVER_MATCHING_IDENTIFIER_STATUS = 3
D3D12_DRIVER_MATCHING_IDENTIFIER_INCOMPATIBLE_TYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRIVER_MATCHING_IDENTIFIER_STATUS = 4
D3D12_DSV_DIMENSION = Int32
D3D12_DSV_DIMENSION_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DSV_DIMENSION = 0
D3D12_DSV_DIMENSION_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DSV_DIMENSION = 1
D3D12_DSV_DIMENSION_TEXTURE1DARRAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DSV_DIMENSION = 2
D3D12_DSV_DIMENSION_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DSV_DIMENSION = 3
D3D12_DSV_DIMENSION_TEXTURE2DARRAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DSV_DIMENSION = 4
D3D12_DSV_DIMENSION_TEXTURE2DMS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DSV_DIMENSION = 5
D3D12_DSV_DIMENSION_TEXTURE2DMSARRAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DSV_DIMENSION = 6
D3D12_DSV_FLAGS = Int32
D3D12_DSV_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DSV_FLAGS = 0
D3D12_DSV_FLAG_READ_ONLY_DEPTH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DSV_FLAGS = 1
D3D12_DSV_FLAG_READ_ONLY_STENCIL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DSV_FLAGS = 2
class D3D12_DXIL_LIBRARY_DESC(Structure):
    DXILLibrary: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_BYTECODE
    NumExports: UInt32
    pExports: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_EXPORT_DESC)
class D3D12_DXIL_SUBOBJECT_TO_EXPORTS_ASSOCIATION(Structure):
    SubobjectToAssociate: win32more.Windows.Win32.Foundation.PWSTR
    NumExports: UInt32
    pExports: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
D3D12_ELEMENTS_LAYOUT = Int32
D3D12_ELEMENTS_LAYOUT_ARRAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ELEMENTS_LAYOUT = 0
D3D12_ELEMENTS_LAYOUT_ARRAY_OF_POINTERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ELEMENTS_LAYOUT = 1
D3D12_EXECUTE_INDIRECT_TIER = Int32
D3D12_EXECUTE_INDIRECT_TIER_1_0: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_EXECUTE_INDIRECT_TIER = 10
D3D12_EXECUTE_INDIRECT_TIER_1_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_EXECUTE_INDIRECT_TIER = 11
class D3D12_EXISTING_COLLECTION_DESC(Structure):
    pExistingCollection: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12StateObject
    NumExports: UInt32
    pExports: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_EXPORT_DESC)
class D3D12_EXPORT_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PWSTR
    ExportToRename: win32more.Windows.Win32.Foundation.PWSTR
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_EXPORT_FLAGS
D3D12_EXPORT_FLAGS = Int32
D3D12_EXPORT_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_EXPORT_FLAGS = 0
D3D12_FEATURE = Int32
D3D12_FEATURE_D3D12_OPTIONS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 0
D3D12_FEATURE_ARCHITECTURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 1
D3D12_FEATURE_FEATURE_LEVELS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 2
D3D12_FEATURE_FORMAT_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 3
D3D12_FEATURE_MULTISAMPLE_QUALITY_LEVELS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 4
D3D12_FEATURE_FORMAT_INFO: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 5
D3D12_FEATURE_GPU_VIRTUAL_ADDRESS_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 6
D3D12_FEATURE_SHADER_MODEL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 7
D3D12_FEATURE_D3D12_OPTIONS1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 8
D3D12_FEATURE_PROTECTED_RESOURCE_SESSION_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 10
D3D12_FEATURE_ROOT_SIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 12
D3D12_FEATURE_ARCHITECTURE1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 16
D3D12_FEATURE_D3D12_OPTIONS2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 18
D3D12_FEATURE_SHADER_CACHE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 19
D3D12_FEATURE_COMMAND_QUEUE_PRIORITY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 20
D3D12_FEATURE_D3D12_OPTIONS3: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 21
D3D12_FEATURE_EXISTING_HEAPS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 22
D3D12_FEATURE_D3D12_OPTIONS4: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 23
D3D12_FEATURE_SERIALIZATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 24
D3D12_FEATURE_CROSS_NODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 25
D3D12_FEATURE_D3D12_OPTIONS5: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 27
D3D12_FEATURE_DISPLAYABLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 28
D3D12_FEATURE_D3D12_OPTIONS6: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 30
D3D12_FEATURE_QUERY_META_COMMAND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 31
D3D12_FEATURE_D3D12_OPTIONS7: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 32
D3D12_FEATURE_PROTECTED_RESOURCE_SESSION_TYPE_COUNT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 33
D3D12_FEATURE_PROTECTED_RESOURCE_SESSION_TYPES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 34
D3D12_FEATURE_D3D12_OPTIONS8: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 36
D3D12_FEATURE_D3D12_OPTIONS9: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 37
D3D12_FEATURE_D3D12_OPTIONS10: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 39
D3D12_FEATURE_D3D12_OPTIONS11: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 40
D3D12_FEATURE_D3D12_OPTIONS12: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 41
D3D12_FEATURE_D3D12_OPTIONS13: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 42
D3D12_FEATURE_D3D12_OPTIONS14: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 43
D3D12_FEATURE_D3D12_OPTIONS15: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 44
D3D12_FEATURE_D3D12_OPTIONS16: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 45
D3D12_FEATURE_D3D12_OPTIONS17: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 46
D3D12_FEATURE_D3D12_OPTIONS18: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 47
D3D12_FEATURE_D3D12_OPTIONS19: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 48
D3D12_FEATURE_D3D12_OPTIONS20: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 49
D3D12_FEATURE_PREDICATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 50
D3D12_FEATURE_PLACED_RESOURCE_SUPPORT_INFO: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 51
D3D12_FEATURE_HARDWARE_COPY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 52
D3D12_FEATURE_D3D12_OPTIONS21: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE = 53
class D3D12_FEATURE_DATA_ARCHITECTURE(Structure):
    NodeIndex: UInt32
    TileBasedRenderer: win32more.Windows.Win32.Foundation.BOOL
    UMA: win32more.Windows.Win32.Foundation.BOOL
    CacheCoherentUMA: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_ARCHITECTURE1(Structure):
    NodeIndex: UInt32
    TileBasedRenderer: win32more.Windows.Win32.Foundation.BOOL
    UMA: win32more.Windows.Win32.Foundation.BOOL
    CacheCoherentUMA: win32more.Windows.Win32.Foundation.BOOL
    IsolatedMMU: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_COMMAND_QUEUE_PRIORITY(Structure):
    CommandListType: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_TYPE
    Priority: UInt32
    PriorityForTypeIsSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_CROSS_NODE(Structure):
    SharingTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CROSS_NODE_SHARING_TIER
    AtomicShaderInstructions: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_D3D12_OPTIONS(Structure):
    DoublePrecisionFloatShaderOps: win32more.Windows.Win32.Foundation.BOOL
    OutputMergerLogicOp: win32more.Windows.Win32.Foundation.BOOL
    MinPrecisionSupport: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_MIN_PRECISION_SUPPORT
    TiledResourcesTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILED_RESOURCES_TIER
    ResourceBindingTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_BINDING_TIER
    PSSpecifiedStencilRefSupported: win32more.Windows.Win32.Foundation.BOOL
    TypedUAVLoadAdditionalFormats: win32more.Windows.Win32.Foundation.BOOL
    ROVsSupported: win32more.Windows.Win32.Foundation.BOOL
    ConservativeRasterizationTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CONSERVATIVE_RASTERIZATION_TIER
    MaxGPUVirtualAddressBitsPerResource: UInt32
    StandardSwizzle64KBSupported: win32more.Windows.Win32.Foundation.BOOL
    CrossNodeSharingTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CROSS_NODE_SHARING_TIER
    CrossAdapterRowMajorTextureSupported: win32more.Windows.Win32.Foundation.BOOL
    VPAndRTArrayIndexFromAnyShaderFeedingRasterizerSupportedWithoutGSEmulation: win32more.Windows.Win32.Foundation.BOOL
    ResourceHeapTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_HEAP_TIER
class D3D12_FEATURE_DATA_D3D12_OPTIONS1(Structure):
    WaveOps: win32more.Windows.Win32.Foundation.BOOL
    WaveLaneCountMin: UInt32
    WaveLaneCountMax: UInt32
    TotalLaneCount: UInt32
    ExpandedComputeResourceStates: win32more.Windows.Win32.Foundation.BOOL
    Int64ShaderOps: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_D3D12_OPTIONS10(Structure):
    VariableRateShadingSumCombinerSupported: win32more.Windows.Win32.Foundation.BOOL
    MeshShaderPerPrimitiveShadingRateSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_D3D12_OPTIONS11(Structure):
    AtomicInt64OnDescriptorHeapResourceSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_D3D12_OPTIONS12(Structure):
    MSPrimitivesPipelineStatisticIncludesCulledPrimitives: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TRI_STATE
    EnhancedBarriersSupported: win32more.Windows.Win32.Foundation.BOOL
    RelaxedFormatCastingSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_D3D12_OPTIONS13(Structure):
    UnrestrictedBufferTextureCopyPitchSupported: win32more.Windows.Win32.Foundation.BOOL
    UnrestrictedVertexElementAlignmentSupported: win32more.Windows.Win32.Foundation.BOOL
    InvertedViewportHeightFlipsYSupported: win32more.Windows.Win32.Foundation.BOOL
    InvertedViewportDepthFlipsZSupported: win32more.Windows.Win32.Foundation.BOOL
    TextureCopyBetweenDimensionsSupported: win32more.Windows.Win32.Foundation.BOOL
    AlphaBlendFactorSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_D3D12_OPTIONS14(Structure):
    AdvancedTextureOpsSupported: win32more.Windows.Win32.Foundation.BOOL
    WriteableMSAATexturesSupported: win32more.Windows.Win32.Foundation.BOOL
    IndependentFrontAndBackStencilRefMaskSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_D3D12_OPTIONS15(Structure):
    TriangleFanSupported: win32more.Windows.Win32.Foundation.BOOL
    DynamicIndexBufferStripCutSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_D3D12_OPTIONS16(Structure):
    DynamicDepthBiasSupported: win32more.Windows.Win32.Foundation.BOOL
    GPUUploadHeapSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_D3D12_OPTIONS17(Structure):
    NonNormalizedCoordinateSamplersSupported: win32more.Windows.Win32.Foundation.BOOL
    ManualWriteTrackingResourceSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_D3D12_OPTIONS18(Structure):
    RenderPassesValid: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_D3D12_OPTIONS19(Structure):
    MismatchingOutputDimensionsSupported: win32more.Windows.Win32.Foundation.BOOL
    SupportedSampleCountsWithNoOutputs: UInt32
    PointSamplingAddressesNeverRoundUp: win32more.Windows.Win32.Foundation.BOOL
    RasterizerDesc2Supported: win32more.Windows.Win32.Foundation.BOOL
    NarrowQuadrilateralLinesSupported: win32more.Windows.Win32.Foundation.BOOL
    AnisoFilterWithPointMipSupported: win32more.Windows.Win32.Foundation.BOOL
    MaxSamplerDescriptorHeapSize: UInt32
    MaxSamplerDescriptorHeapSizeWithStaticSamplers: UInt32
    MaxViewDescriptorHeapSize: UInt32
    ComputeOnlyCustomHeapSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_D3D12_OPTIONS2(Structure):
    DepthBoundsTestSupported: win32more.Windows.Win32.Foundation.BOOL
    ProgrammableSamplePositionsTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROGRAMMABLE_SAMPLE_POSITIONS_TIER
class D3D12_FEATURE_DATA_D3D12_OPTIONS20(Structure):
    ComputeOnlyWriteWatchSupported: win32more.Windows.Win32.Foundation.BOOL
    RecreateAtTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RECREATE_AT_TIER
class D3D12_FEATURE_DATA_D3D12_OPTIONS21(Structure):
    WorkGraphsTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_WORK_GRAPHS_TIER
    ExecuteIndirectTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_EXECUTE_INDIRECT_TIER
    SampleCmpGradientAndBiasSupported: win32more.Windows.Win32.Foundation.BOOL
    ExtendedCommandInfoSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_D3D12_OPTIONS3(Structure):
    CopyQueueTimestampQueriesSupported: win32more.Windows.Win32.Foundation.BOOL
    CastingFullyTypedFormatSupported: win32more.Windows.Win32.Foundation.BOOL
    WriteBufferImmediateSupportFlags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_SUPPORT_FLAGS
    ViewInstancingTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VIEW_INSTANCING_TIER
    BarycentricsSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_D3D12_OPTIONS4(Structure):
    MSAA64KBAlignedTextureSupported: win32more.Windows.Win32.Foundation.BOOL
    SharedResourceCompatibilityTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHARED_RESOURCE_COMPATIBILITY_TIER
    Native16BitShaderOpsSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_D3D12_OPTIONS5(Structure):
    SRVOnlyTiledResourceTier3: win32more.Windows.Win32.Foundation.BOOL
    RenderPassesTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_TIER
    RaytracingTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_TIER
class D3D12_FEATURE_DATA_D3D12_OPTIONS6(Structure):
    AdditionalShadingRatesSupported: win32more.Windows.Win32.Foundation.BOOL
    PerPrimitiveShadingRateSupportedWithViewportIndexing: win32more.Windows.Win32.Foundation.BOOL
    VariableShadingRateTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VARIABLE_SHADING_RATE_TIER
    ShadingRateImageTileSize: UInt32
    BackgroundProcessingSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_D3D12_OPTIONS7(Structure):
    MeshShaderTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESH_SHADER_TIER
    SamplerFeedbackTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SAMPLER_FEEDBACK_TIER
class D3D12_FEATURE_DATA_D3D12_OPTIONS8(Structure):
    UnalignedBlockTexturesSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_D3D12_OPTIONS9(Structure):
    MeshShaderPipelineStatsSupported: win32more.Windows.Win32.Foundation.BOOL
    MeshShaderSupportsFullRangeRenderTargetArrayIndex: win32more.Windows.Win32.Foundation.BOOL
    AtomicInt64OnTypedResourceSupported: win32more.Windows.Win32.Foundation.BOOL
    AtomicInt64OnGroupSharedSupported: win32more.Windows.Win32.Foundation.BOOL
    DerivativesInMeshAndAmplificationShadersSupported: win32more.Windows.Win32.Foundation.BOOL
    WaveMMATier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_WAVE_MMA_TIER
class D3D12_FEATURE_DATA_DISPLAYABLE(Structure):
    DisplayableTexture: win32more.Windows.Win32.Foundation.BOOL
    SharedResourceCompatibilityTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHARED_RESOURCE_COMPATIBILITY_TIER
class D3D12_FEATURE_DATA_EXISTING_HEAPS(Structure):
    Supported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_FEATURE_LEVELS(Structure):
    NumFeatureLevels: UInt32
    pFeatureLevelsRequested: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL)
    MaxSupportedFeatureLevel: win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL
class D3D12_FEATURE_DATA_FORMAT_INFO(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    PlaneCount: Byte
class D3D12_FEATURE_DATA_FORMAT_SUPPORT(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    Support1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1
    Support2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT2
class D3D12_FEATURE_DATA_GPU_VIRTUAL_ADDRESS_SUPPORT(Structure):
    MaxGPUVirtualAddressBitsPerResource: UInt32
    MaxGPUVirtualAddressBitsPerProcess: UInt32
class D3D12_FEATURE_DATA_HARDWARE_COPY(Structure):
    Supported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_MULTISAMPLE_QUALITY_LEVELS(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    SampleCount: UInt32
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MULTISAMPLE_QUALITY_LEVEL_FLAGS
    NumQualityLevels: UInt32
class D3D12_FEATURE_DATA_PLACED_RESOURCE_SUPPORT_INFO(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    Dimension: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DIMENSION
    DestHeapProperties: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_PROPERTIES
    Supported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_PREDICATION(Structure):
    Supported: win32more.Windows.Win32.Foundation.BOOL
class D3D12_FEATURE_DATA_PROTECTED_RESOURCE_SESSION_SUPPORT(Structure):
    NodeIndex: UInt32
    Support: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROTECTED_RESOURCE_SESSION_SUPPORT_FLAGS
class D3D12_FEATURE_DATA_PROTECTED_RESOURCE_SESSION_TYPES(Structure):
    NodeIndex: UInt32
    Count: UInt32
    pTypes: POINTER(Guid)
class D3D12_FEATURE_DATA_PROTECTED_RESOURCE_SESSION_TYPE_COUNT(Structure):
    NodeIndex: UInt32
    Count: UInt32
class D3D12_FEATURE_DATA_QUERY_META_COMMAND(Structure):
    CommandId: Guid
    NodeMask: UInt32
    pQueryInputData: VoidPtr
    QueryInputDataSizeInBytes: UIntPtr
    pQueryOutputData: VoidPtr
    QueryOutputDataSizeInBytes: UIntPtr
class D3D12_FEATURE_DATA_ROOT_SIGNATURE(Structure):
    HighestVersion: win32more.Windows.Win32.Graphics.Direct3D12.D3D_ROOT_SIGNATURE_VERSION
class D3D12_FEATURE_DATA_SERIALIZATION(Structure):
    NodeIndex: UInt32
    HeapSerializationTier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_SERIALIZATION_TIER
class D3D12_FEATURE_DATA_SHADER_CACHE(Structure):
    SupportFlags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_SUPPORT_FLAGS
class D3D12_FEATURE_DATA_SHADER_MODEL(Structure):
    HighestShaderModel: win32more.Windows.Win32.Graphics.Direct3D12.D3D_SHADER_MODEL
D3D12_FENCE_FLAGS = Int32
D3D12_FENCE_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FENCE_FLAGS = 0
D3D12_FENCE_FLAG_SHARED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FENCE_FLAGS = 1
D3D12_FENCE_FLAG_SHARED_CROSS_ADAPTER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FENCE_FLAGS = 2
D3D12_FENCE_FLAG_NON_MONITORED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FENCE_FLAGS = 4
D3D12_FILL_MODE = Int32
D3D12_FILL_MODE_WIREFRAME: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILL_MODE = 2
D3D12_FILL_MODE_SOLID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILL_MODE = 3
D3D12_FILTER = Int32
D3D12_FILTER_MIN_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 0
D3D12_FILTER_MIN_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 1
D3D12_FILTER_MIN_POINT_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 4
D3D12_FILTER_MIN_POINT_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 5
D3D12_FILTER_MIN_LINEAR_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 16
D3D12_FILTER_MIN_LINEAR_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 17
D3D12_FILTER_MIN_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 20
D3D12_FILTER_MIN_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 21
D3D12_FILTER_MIN_MAG_ANISOTROPIC_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 84
D3D12_FILTER_ANISOTROPIC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 85
D3D12_FILTER_COMPARISON_MIN_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 128
D3D12_FILTER_COMPARISON_MIN_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 129
D3D12_FILTER_COMPARISON_MIN_POINT_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 132
D3D12_FILTER_COMPARISON_MIN_POINT_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 133
D3D12_FILTER_COMPARISON_MIN_LINEAR_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 144
D3D12_FILTER_COMPARISON_MIN_LINEAR_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 145
D3D12_FILTER_COMPARISON_MIN_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 148
D3D12_FILTER_COMPARISON_MIN_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 149
D3D12_FILTER_COMPARISON_MIN_MAG_ANISOTROPIC_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 212
D3D12_FILTER_COMPARISON_ANISOTROPIC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 213
D3D12_FILTER_MINIMUM_MIN_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 256
D3D12_FILTER_MINIMUM_MIN_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 257
D3D12_FILTER_MINIMUM_MIN_POINT_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 260
D3D12_FILTER_MINIMUM_MIN_POINT_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 261
D3D12_FILTER_MINIMUM_MIN_LINEAR_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 272
D3D12_FILTER_MINIMUM_MIN_LINEAR_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 273
D3D12_FILTER_MINIMUM_MIN_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 276
D3D12_FILTER_MINIMUM_MIN_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 277
D3D12_FILTER_MINIMUM_MIN_MAG_ANISOTROPIC_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 340
D3D12_FILTER_MINIMUM_ANISOTROPIC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 341
D3D12_FILTER_MAXIMUM_MIN_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 384
D3D12_FILTER_MAXIMUM_MIN_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 385
D3D12_FILTER_MAXIMUM_MIN_POINT_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 388
D3D12_FILTER_MAXIMUM_MIN_POINT_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 389
D3D12_FILTER_MAXIMUM_MIN_LINEAR_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 400
D3D12_FILTER_MAXIMUM_MIN_LINEAR_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 401
D3D12_FILTER_MAXIMUM_MIN_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 404
D3D12_FILTER_MAXIMUM_MIN_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 405
D3D12_FILTER_MAXIMUM_MIN_MAG_ANISOTROPIC_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 468
D3D12_FILTER_MAXIMUM_ANISOTROPIC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER = 469
D3D12_FILTER_REDUCTION_TYPE = Int32
D3D12_FILTER_REDUCTION_TYPE_STANDARD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER_REDUCTION_TYPE = 0
D3D12_FILTER_REDUCTION_TYPE_COMPARISON: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER_REDUCTION_TYPE = 1
D3D12_FILTER_REDUCTION_TYPE_MINIMUM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER_REDUCTION_TYPE = 2
D3D12_FILTER_REDUCTION_TYPE_MAXIMUM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER_REDUCTION_TYPE = 3
D3D12_FILTER_TYPE = Int32
D3D12_FILTER_TYPE_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER_TYPE = 0
D3D12_FILTER_TYPE_LINEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER_TYPE = 1
D3D12_FORMAT_SUPPORT1 = Int32
D3D12_FORMAT_SUPPORT1_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 0
D3D12_FORMAT_SUPPORT1_BUFFER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 1
D3D12_FORMAT_SUPPORT1_IA_VERTEX_BUFFER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 2
D3D12_FORMAT_SUPPORT1_IA_INDEX_BUFFER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 4
D3D12_FORMAT_SUPPORT1_SO_BUFFER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 8
D3D12_FORMAT_SUPPORT1_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 16
D3D12_FORMAT_SUPPORT1_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 32
D3D12_FORMAT_SUPPORT1_TEXTURE3D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 64
D3D12_FORMAT_SUPPORT1_TEXTURECUBE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 128
D3D12_FORMAT_SUPPORT1_SHADER_LOAD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 256
D3D12_FORMAT_SUPPORT1_SHADER_SAMPLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 512
D3D12_FORMAT_SUPPORT1_SHADER_SAMPLE_COMPARISON: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 1024
D3D12_FORMAT_SUPPORT1_SHADER_SAMPLE_MONO_TEXT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 2048
D3D12_FORMAT_SUPPORT1_MIP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 4096
D3D12_FORMAT_SUPPORT1_RENDER_TARGET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 16384
D3D12_FORMAT_SUPPORT1_BLENDABLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 32768
D3D12_FORMAT_SUPPORT1_DEPTH_STENCIL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 65536
D3D12_FORMAT_SUPPORT1_MULTISAMPLE_RESOLVE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 262144
D3D12_FORMAT_SUPPORT1_DISPLAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 524288
D3D12_FORMAT_SUPPORT1_CAST_WITHIN_BIT_LAYOUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 1048576
D3D12_FORMAT_SUPPORT1_MULTISAMPLE_RENDERTARGET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 2097152
D3D12_FORMAT_SUPPORT1_MULTISAMPLE_LOAD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 4194304
D3D12_FORMAT_SUPPORT1_SHADER_GATHER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 8388608
D3D12_FORMAT_SUPPORT1_BACK_BUFFER_CAST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 16777216
D3D12_FORMAT_SUPPORT1_TYPED_UNORDERED_ACCESS_VIEW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 33554432
D3D12_FORMAT_SUPPORT1_SHADER_GATHER_COMPARISON: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 67108864
D3D12_FORMAT_SUPPORT1_DECODER_OUTPUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 134217728
D3D12_FORMAT_SUPPORT1_VIDEO_PROCESSOR_OUTPUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 268435456
D3D12_FORMAT_SUPPORT1_VIDEO_PROCESSOR_INPUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 536870912
D3D12_FORMAT_SUPPORT1_VIDEO_ENCODER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT1 = 1073741824
D3D12_FORMAT_SUPPORT2 = Int32
D3D12_FORMAT_SUPPORT2_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT2 = 0
D3D12_FORMAT_SUPPORT2_UAV_ATOMIC_ADD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT2 = 1
D3D12_FORMAT_SUPPORT2_UAV_ATOMIC_BITWISE_OPS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT2 = 2
D3D12_FORMAT_SUPPORT2_UAV_ATOMIC_COMPARE_STORE_OR_COMPARE_EXCHANGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT2 = 4
D3D12_FORMAT_SUPPORT2_UAV_ATOMIC_EXCHANGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT2 = 8
D3D12_FORMAT_SUPPORT2_UAV_ATOMIC_SIGNED_MIN_OR_MAX: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT2 = 16
D3D12_FORMAT_SUPPORT2_UAV_ATOMIC_UNSIGNED_MIN_OR_MAX: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT2 = 32
D3D12_FORMAT_SUPPORT2_UAV_TYPED_LOAD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT2 = 64
D3D12_FORMAT_SUPPORT2_UAV_TYPED_STORE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT2 = 128
D3D12_FORMAT_SUPPORT2_OUTPUT_MERGER_LOGIC_OP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT2 = 256
D3D12_FORMAT_SUPPORT2_TILED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT2 = 512
D3D12_FORMAT_SUPPORT2_MULTIPLANE_OVERLAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT2 = 16384
D3D12_FORMAT_SUPPORT2_SAMPLER_FEEDBACK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FORMAT_SUPPORT2 = 32768
class D3D12_FUNCTION_DESC(Structure):
    Version: UInt32
    Creator: win32more.Windows.Win32.Foundation.PSTR
    Flags: UInt32
    ConstantBuffers: UInt32
    BoundResources: UInt32
    InstructionCount: UInt32
    TempRegisterCount: UInt32
    TempArrayCount: UInt32
    DefCount: UInt32
    DclCount: UInt32
    TextureNormalInstructions: UInt32
    TextureLoadInstructions: UInt32
    TextureCompInstructions: UInt32
    TextureBiasInstructions: UInt32
    TextureGradientInstructions: UInt32
    FloatInstructionCount: UInt32
    IntInstructionCount: UInt32
    UintInstructionCount: UInt32
    StaticFlowControlCount: UInt32
    DynamicFlowControlCount: UInt32
    MacroInstructionCount: UInt32
    ArrayInstructionCount: UInt32
    MovInstructionCount: UInt32
    MovcInstructionCount: UInt32
    ConversionInstructionCount: UInt32
    BitwiseInstructionCount: UInt32
    MinFeatureLevel: win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL
    RequiredFeatureFlags: UInt64
    Name: win32more.Windows.Win32.Foundation.PSTR
    FunctionParameterCount: Int32
    HasReturn: win32more.Windows.Win32.Foundation.BOOL
    Has10Level9VertexShader: win32more.Windows.Win32.Foundation.BOOL
    Has10Level9PixelShader: win32more.Windows.Win32.Foundation.BOOL
class D3D12_GENERIC_PROGRAM_DESC(Structure):
    ProgramName: win32more.Windows.Win32.Foundation.PWSTR
    NumExports: UInt32
    pExports: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
    NumSubobjects: UInt32
    ppSubobjects: POINTER(POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT))
class D3D12_GLOBAL_BARRIER(Structure):
    SyncBefore: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC
    SyncAfter: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC
    AccessBefore: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS
    AccessAfter: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS
class D3D12_GLOBAL_ROOT_SIGNATURE(Structure):
    pGlobalRootSignature: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12RootSignature
D3D12_GPU_BASED_VALIDATION_FLAGS = Int32
D3D12_GPU_BASED_VALIDATION_FLAGS_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_BASED_VALIDATION_FLAGS = 0
D3D12_GPU_BASED_VALIDATION_FLAGS_DISABLE_STATE_TRACKING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_BASED_VALIDATION_FLAGS = 1
D3D12_GPU_BASED_VALIDATION_PIPELINE_STATE_CREATE_FLAGS = Int32
D3D12_GPU_BASED_VALIDATION_PIPELINE_STATE_CREATE_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_BASED_VALIDATION_PIPELINE_STATE_CREATE_FLAGS = 0
D3D12_GPU_BASED_VALIDATION_PIPELINE_STATE_CREATE_FLAG_FRONT_LOAD_CREATE_TRACKING_ONLY_SHADERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_BASED_VALIDATION_PIPELINE_STATE_CREATE_FLAGS = 1
D3D12_GPU_BASED_VALIDATION_PIPELINE_STATE_CREATE_FLAG_FRONT_LOAD_CREATE_UNGUARDED_VALIDATION_SHADERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_BASED_VALIDATION_PIPELINE_STATE_CREATE_FLAGS = 2
D3D12_GPU_BASED_VALIDATION_PIPELINE_STATE_CREATE_FLAG_FRONT_LOAD_CREATE_GUARDED_VALIDATION_SHADERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_BASED_VALIDATION_PIPELINE_STATE_CREATE_FLAGS = 4
D3D12_GPU_BASED_VALIDATION_PIPELINE_STATE_CREATE_FLAGS_VALID_MASK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_BASED_VALIDATION_PIPELINE_STATE_CREATE_FLAGS = 7
D3D12_GPU_BASED_VALIDATION_SHADER_PATCH_MODE = Int32
D3D12_GPU_BASED_VALIDATION_SHADER_PATCH_MODE_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_BASED_VALIDATION_SHADER_PATCH_MODE = 0
D3D12_GPU_BASED_VALIDATION_SHADER_PATCH_MODE_STATE_TRACKING_ONLY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_BASED_VALIDATION_SHADER_PATCH_MODE = 1
D3D12_GPU_BASED_VALIDATION_SHADER_PATCH_MODE_UNGUARDED_VALIDATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_BASED_VALIDATION_SHADER_PATCH_MODE = 2
D3D12_GPU_BASED_VALIDATION_SHADER_PATCH_MODE_GUARDED_VALIDATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_BASED_VALIDATION_SHADER_PATCH_MODE = 3
NUM_D3D12_GPU_BASED_VALIDATION_SHADER_PATCH_MODES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_BASED_VALIDATION_SHADER_PATCH_MODE = 4
class D3D12_GPU_DESCRIPTOR_HANDLE(Structure):
    ptr: UInt64
class D3D12_GPU_VIRTUAL_ADDRESS_AND_STRIDE(Structure):
    StartAddress: UInt64
    StrideInBytes: UInt64
class D3D12_GPU_VIRTUAL_ADDRESS_RANGE(Structure):
    StartAddress: UInt64
    SizeInBytes: UInt64
class D3D12_GPU_VIRTUAL_ADDRESS_RANGE_AND_STRIDE(Structure):
    StartAddress: UInt64
    SizeInBytes: UInt64
    StrideInBytes: UInt64
class D3D12_GRAPHICS_PIPELINE_STATE_DESC(Structure):
    pRootSignature: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12RootSignature
    VS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_BYTECODE
    PS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_BYTECODE
    DS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_BYTECODE
    HS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_BYTECODE
    GS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_BYTECODE
    StreamOutput: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STREAM_OUTPUT_DESC
    BlendState: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND_DESC
    SampleMask: UInt32
    RasterizerState: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RASTERIZER_DESC
    DepthStencilState: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEPTH_STENCIL_DESC
    InputLayout: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INPUT_LAYOUT_DESC
    IBStripCutValue: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDEX_BUFFER_STRIP_CUT_VALUE
    PrimitiveTopologyType: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PRIMITIVE_TOPOLOGY_TYPE
    NumRenderTargets: UInt32
    RTVFormats: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT * 8
    DSVFormat: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    SampleDesc: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_SAMPLE_DESC
    NodeMask: UInt32
    CachedPSO: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CACHED_PIPELINE_STATE
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_FLAGS
D3D12_GRAPHICS_STATES = Int32
D3D12_GRAPHICS_STATE_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 0
D3D12_GRAPHICS_STATE_IA_VERTEX_BUFFERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 1
D3D12_GRAPHICS_STATE_IA_INDEX_BUFFER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 2
D3D12_GRAPHICS_STATE_IA_PRIMITIVE_TOPOLOGY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 4
D3D12_GRAPHICS_STATE_DESCRIPTOR_HEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 8
D3D12_GRAPHICS_STATE_GRAPHICS_ROOT_SIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 16
D3D12_GRAPHICS_STATE_COMPUTE_ROOT_SIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 32
D3D12_GRAPHICS_STATE_RS_VIEWPORTS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 64
D3D12_GRAPHICS_STATE_RS_SCISSOR_RECTS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 128
D3D12_GRAPHICS_STATE_PREDICATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 256
D3D12_GRAPHICS_STATE_OM_RENDER_TARGETS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 512
D3D12_GRAPHICS_STATE_OM_STENCIL_REF: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 1024
D3D12_GRAPHICS_STATE_OM_BLEND_FACTOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 2048
D3D12_GRAPHICS_STATE_PIPELINE_STATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 4096
D3D12_GRAPHICS_STATE_SO_TARGETS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 8192
D3D12_GRAPHICS_STATE_OM_DEPTH_BOUNDS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 16384
D3D12_GRAPHICS_STATE_SAMPLE_POSITIONS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 32768
D3D12_GRAPHICS_STATE_VIEW_INSTANCE_MASK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES = 65536
class D3D12_HEAP_DESC(Structure):
    SizeInBytes: UInt64
    Properties: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_PROPERTIES
    Alignment: UInt64
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS
D3D12_HEAP_FLAGS = Int32
D3D12_HEAP_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS = 0
D3D12_HEAP_FLAG_SHARED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS = 1
D3D12_HEAP_FLAG_DENY_BUFFERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS = 4
D3D12_HEAP_FLAG_ALLOW_DISPLAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS = 8
D3D12_HEAP_FLAG_SHARED_CROSS_ADAPTER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS = 32
D3D12_HEAP_FLAG_DENY_RT_DS_TEXTURES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS = 64
D3D12_HEAP_FLAG_DENY_NON_RT_DS_TEXTURES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS = 128
D3D12_HEAP_FLAG_HARDWARE_PROTECTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS = 256
D3D12_HEAP_FLAG_ALLOW_WRITE_WATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS = 512
D3D12_HEAP_FLAG_ALLOW_SHADER_ATOMICS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS = 1024
D3D12_HEAP_FLAG_CREATE_NOT_RESIDENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS = 2048
D3D12_HEAP_FLAG_CREATE_NOT_ZEROED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS = 4096
D3D12_HEAP_FLAG_TOOLS_USE_MANUAL_WRITE_TRACKING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS = 8192
D3D12_HEAP_FLAG_ALLOW_ALL_BUFFERS_AND_TEXTURES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS = 0
D3D12_HEAP_FLAG_ALLOW_ONLY_BUFFERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS = 192
D3D12_HEAP_FLAG_ALLOW_ONLY_NON_RT_DS_TEXTURES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS = 68
D3D12_HEAP_FLAG_ALLOW_ONLY_RT_DS_TEXTURES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS = 132
class D3D12_HEAP_PROPERTIES(Structure):
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_TYPE
    CPUPageProperty: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_PAGE_PROPERTY
    MemoryPoolPreference: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MEMORY_POOL
    CreationNodeMask: UInt32
    VisibleNodeMask: UInt32
D3D12_HEAP_SERIALIZATION_TIER = Int32
D3D12_HEAP_SERIALIZATION_TIER_0: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_SERIALIZATION_TIER = 0
D3D12_HEAP_SERIALIZATION_TIER_10: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_SERIALIZATION_TIER = 10
D3D12_HEAP_TYPE = Int32
D3D12_HEAP_TYPE_DEFAULT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_TYPE = 1
D3D12_HEAP_TYPE_UPLOAD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_TYPE = 2
D3D12_HEAP_TYPE_READBACK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_TYPE = 3
D3D12_HEAP_TYPE_CUSTOM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_TYPE = 4
D3D12_HEAP_TYPE_GPU_UPLOAD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_TYPE = 5
class D3D12_HIT_GROUP_DESC(Structure):
    HitGroupExport: win32more.Windows.Win32.Foundation.PWSTR
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HIT_GROUP_TYPE
    AnyHitShaderImport: win32more.Windows.Win32.Foundation.PWSTR
    ClosestHitShaderImport: win32more.Windows.Win32.Foundation.PWSTR
    IntersectionShaderImport: win32more.Windows.Win32.Foundation.PWSTR
D3D12_HIT_GROUP_TYPE = Int32
D3D12_HIT_GROUP_TYPE_TRIANGLES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HIT_GROUP_TYPE = 0
D3D12_HIT_GROUP_TYPE_PROCEDURAL_PRIMITIVE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HIT_GROUP_TYPE = 1
D3D12_HIT_KIND = Int32
D3D12_HIT_KIND_TRIANGLE_FRONT_FACE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HIT_KIND = 254
D3D12_HIT_KIND_TRIANGLE_BACK_FACE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HIT_KIND = 255
class D3D12_IB_STRIP_CUT_VALUE(Structure):
    IndexBufferStripCutValue: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDEX_BUFFER_STRIP_CUT_VALUE
D3D12_INDEX_BUFFER_STRIP_CUT_VALUE = Int32
D3D12_INDEX_BUFFER_STRIP_CUT_VALUE_DISABLED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDEX_BUFFER_STRIP_CUT_VALUE = 0
D3D12_INDEX_BUFFER_STRIP_CUT_VALUE_0xFFFF: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDEX_BUFFER_STRIP_CUT_VALUE = 1
D3D12_INDEX_BUFFER_STRIP_CUT_VALUE_0xFFFFFFFF: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDEX_BUFFER_STRIP_CUT_VALUE = 2
class D3D12_INDEX_BUFFER_VIEW(Structure):
    BufferLocation: UInt64
    SizeInBytes: UInt32
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
class D3D12_INDIRECT_ARGUMENT_DESC(Structure):
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDIRECT_ARGUMENT_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        VertexBuffer: _VertexBuffer_e__Struct
        Constant: _Constant_e__Struct
        ConstantBufferView: _ConstantBufferView_e__Struct
        ShaderResourceView: _ShaderResourceView_e__Struct
        UnorderedAccessView: _UnorderedAccessView_e__Struct
        IncrementingConstant: _IncrementingConstant_e__Struct
        class _VertexBuffer_e__Struct(Structure):
            Slot: UInt32
        class _Constant_e__Struct(Structure):
            RootParameterIndex: UInt32
            DestOffsetIn32BitValues: UInt32
            Num32BitValuesToSet: UInt32
        class _ConstantBufferView_e__Struct(Structure):
            RootParameterIndex: UInt32
        class _ShaderResourceView_e__Struct(Structure):
            RootParameterIndex: UInt32
        class _UnorderedAccessView_e__Struct(Structure):
            RootParameterIndex: UInt32
        class _IncrementingConstant_e__Struct(Structure):
            RootParameterIndex: UInt32
            DestOffsetIn32BitValues: UInt32
D3D12_INDIRECT_ARGUMENT_TYPE = Int32
D3D12_INDIRECT_ARGUMENT_TYPE_DRAW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDIRECT_ARGUMENT_TYPE = 0
D3D12_INDIRECT_ARGUMENT_TYPE_DRAW_INDEXED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDIRECT_ARGUMENT_TYPE = 1
D3D12_INDIRECT_ARGUMENT_TYPE_DISPATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDIRECT_ARGUMENT_TYPE = 2
D3D12_INDIRECT_ARGUMENT_TYPE_VERTEX_BUFFER_VIEW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDIRECT_ARGUMENT_TYPE = 3
D3D12_INDIRECT_ARGUMENT_TYPE_INDEX_BUFFER_VIEW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDIRECT_ARGUMENT_TYPE = 4
D3D12_INDIRECT_ARGUMENT_TYPE_CONSTANT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDIRECT_ARGUMENT_TYPE = 5
D3D12_INDIRECT_ARGUMENT_TYPE_CONSTANT_BUFFER_VIEW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDIRECT_ARGUMENT_TYPE = 6
D3D12_INDIRECT_ARGUMENT_TYPE_SHADER_RESOURCE_VIEW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDIRECT_ARGUMENT_TYPE = 7
D3D12_INDIRECT_ARGUMENT_TYPE_UNORDERED_ACCESS_VIEW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDIRECT_ARGUMENT_TYPE = 8
D3D12_INDIRECT_ARGUMENT_TYPE_DISPATCH_RAYS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDIRECT_ARGUMENT_TYPE = 9
D3D12_INDIRECT_ARGUMENT_TYPE_DISPATCH_MESH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDIRECT_ARGUMENT_TYPE = 10
D3D12_INDIRECT_ARGUMENT_TYPE_INCREMENTING_CONSTANT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDIRECT_ARGUMENT_TYPE = 11
class D3D12_INFO_QUEUE_FILTER(Structure):
    AllowList: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INFO_QUEUE_FILTER_DESC
    DenyList: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INFO_QUEUE_FILTER_DESC
class D3D12_INFO_QUEUE_FILTER_DESC(Structure):
    NumCategories: UInt32
    pCategoryList: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CATEGORY)
    NumSeverities: UInt32
    pSeverityList: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_SEVERITY)
    NumIDs: UInt32
    pIDList: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID)
D3D12_INPUT_CLASSIFICATION = Int32
D3D12_INPUT_CLASSIFICATION_PER_VERTEX_DATA: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INPUT_CLASSIFICATION = 0
D3D12_INPUT_CLASSIFICATION_PER_INSTANCE_DATA: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INPUT_CLASSIFICATION = 1
class D3D12_INPUT_ELEMENT_DESC(Structure):
    SemanticName: win32more.Windows.Win32.Foundation.PSTR
    SemanticIndex: UInt32
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    InputSlot: UInt32
    AlignedByteOffset: UInt32
    InputSlotClass: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INPUT_CLASSIFICATION
    InstanceDataStepRate: UInt32
class D3D12_INPUT_LAYOUT_DESC(Structure):
    pInputElementDescs: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INPUT_ELEMENT_DESC)
    NumElements: UInt32
class D3D12_LIBRARY_DESC(Structure):
    Creator: win32more.Windows.Win32.Foundation.PSTR
    Flags: UInt32
    FunctionCount: UInt32
D3D12_LIFETIME_STATE = Int32
D3D12_LIFETIME_STATE_IN_USE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LIFETIME_STATE = 0
D3D12_LIFETIME_STATE_NOT_IN_USE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LIFETIME_STATE = 1
D3D12_LINE_RASTERIZATION_MODE = Int32
D3D12_LINE_RASTERIZATION_MODE_ALIASED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LINE_RASTERIZATION_MODE = 0
D3D12_LINE_RASTERIZATION_MODE_ALPHA_ANTIALIASED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LINE_RASTERIZATION_MODE = 1
D3D12_LINE_RASTERIZATION_MODE_QUADRILATERAL_WIDE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LINE_RASTERIZATION_MODE = 2
D3D12_LINE_RASTERIZATION_MODE_QUADRILATERAL_NARROW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LINE_RASTERIZATION_MODE = 3
class D3D12_LOCAL_ROOT_SIGNATURE(Structure):
    pLocalRootSignature: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12RootSignature
D3D12_LOGIC_OP = Int32
D3D12_LOGIC_OP_CLEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LOGIC_OP = 0
D3D12_LOGIC_OP_SET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LOGIC_OP = 1
D3D12_LOGIC_OP_COPY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LOGIC_OP = 2
D3D12_LOGIC_OP_COPY_INVERTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LOGIC_OP = 3
D3D12_LOGIC_OP_NOOP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LOGIC_OP = 4
D3D12_LOGIC_OP_INVERT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LOGIC_OP = 5
D3D12_LOGIC_OP_AND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LOGIC_OP = 6
D3D12_LOGIC_OP_NAND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LOGIC_OP = 7
D3D12_LOGIC_OP_OR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LOGIC_OP = 8
D3D12_LOGIC_OP_NOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LOGIC_OP = 9
D3D12_LOGIC_OP_XOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LOGIC_OP = 10
D3D12_LOGIC_OP_EQUIV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LOGIC_OP = 11
D3D12_LOGIC_OP_AND_REVERSE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LOGIC_OP = 12
D3D12_LOGIC_OP_AND_INVERTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LOGIC_OP = 13
D3D12_LOGIC_OP_OR_REVERSE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LOGIC_OP = 14
D3D12_LOGIC_OP_OR_INVERTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LOGIC_OP = 15
D3D12_MEASUREMENTS_ACTION = Int32
D3D12_MEASUREMENTS_ACTION_KEEP_ALL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MEASUREMENTS_ACTION = 0
D3D12_MEASUREMENTS_ACTION_COMMIT_RESULTS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MEASUREMENTS_ACTION = 1
D3D12_MEASUREMENTS_ACTION_COMMIT_RESULTS_HIGH_PRIORITY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MEASUREMENTS_ACTION = 2
D3D12_MEASUREMENTS_ACTION_DISCARD_PREVIOUS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MEASUREMENTS_ACTION = 3
class D3D12_MEMCPY_DEST(Structure):
    pData: VoidPtr
    RowPitch: UIntPtr
    SlicePitch: UIntPtr
D3D12_MEMORY_POOL = Int32
D3D12_MEMORY_POOL_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MEMORY_POOL = 0
D3D12_MEMORY_POOL_L0: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MEMORY_POOL = 1
D3D12_MEMORY_POOL_L1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MEMORY_POOL = 2
D3D12_MESH_SHADER_TIER = Int32
D3D12_MESH_SHADER_TIER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESH_SHADER_TIER = 0
D3D12_MESH_SHADER_TIER_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESH_SHADER_TIER = 10
class D3D12_MESSAGE(Structure):
    Category: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CATEGORY
    Severity: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_SEVERITY
    ID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID
    pDescription: POINTER(Byte)
    DescriptionByteLength: UIntPtr
D3D12_MESSAGE_CALLBACK_FLAGS = Int32
D3D12_MESSAGE_CALLBACK_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CALLBACK_FLAGS = 0
D3D12_MESSAGE_CALLBACK_IGNORE_FILTERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CALLBACK_FLAGS = 1
D3D12_MESSAGE_CATEGORY = Int32
D3D12_MESSAGE_CATEGORY_APPLICATION_DEFINED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CATEGORY = 0
D3D12_MESSAGE_CATEGORY_MISCELLANEOUS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CATEGORY = 1
D3D12_MESSAGE_CATEGORY_INITIALIZATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CATEGORY = 2
D3D12_MESSAGE_CATEGORY_CLEANUP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CATEGORY = 3
D3D12_MESSAGE_CATEGORY_COMPILATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CATEGORY = 4
D3D12_MESSAGE_CATEGORY_STATE_CREATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CATEGORY = 5
D3D12_MESSAGE_CATEGORY_STATE_SETTING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CATEGORY = 6
D3D12_MESSAGE_CATEGORY_STATE_GETTING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CATEGORY = 7
D3D12_MESSAGE_CATEGORY_RESOURCE_MANIPULATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CATEGORY = 8
D3D12_MESSAGE_CATEGORY_EXECUTION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CATEGORY = 9
D3D12_MESSAGE_CATEGORY_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CATEGORY = 10
D3D12_MESSAGE_ID = Int32
D3D12_MESSAGE_ID_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 0
D3D12_MESSAGE_ID_STRING_FROM_APPLICATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1
D3D12_MESSAGE_ID_CORRUPTED_THIS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 2
D3D12_MESSAGE_ID_CORRUPTED_PARAMETER1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 3
D3D12_MESSAGE_ID_CORRUPTED_PARAMETER2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 4
D3D12_MESSAGE_ID_CORRUPTED_PARAMETER3: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 5
D3D12_MESSAGE_ID_CORRUPTED_PARAMETER4: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 6
D3D12_MESSAGE_ID_CORRUPTED_PARAMETER5: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 7
D3D12_MESSAGE_ID_CORRUPTED_PARAMETER6: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 8
D3D12_MESSAGE_ID_CORRUPTED_PARAMETER7: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 9
D3D12_MESSAGE_ID_CORRUPTED_PARAMETER8: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 10
D3D12_MESSAGE_ID_CORRUPTED_PARAMETER9: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 11
D3D12_MESSAGE_ID_CORRUPTED_PARAMETER10: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 12
D3D12_MESSAGE_ID_CORRUPTED_PARAMETER11: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 13
D3D12_MESSAGE_ID_CORRUPTED_PARAMETER12: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 14
D3D12_MESSAGE_ID_CORRUPTED_PARAMETER13: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 15
D3D12_MESSAGE_ID_CORRUPTED_PARAMETER14: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 16
D3D12_MESSAGE_ID_CORRUPTED_PARAMETER15: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 17
D3D12_MESSAGE_ID_CORRUPTED_MULTITHREADING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 18
D3D12_MESSAGE_ID_MESSAGE_REPORTING_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 19
D3D12_MESSAGE_ID_GETPRIVATEDATA_MOREDATA: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 20
D3D12_MESSAGE_ID_SETPRIVATEDATA_INVALIDFREEDATA: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 21
D3D12_MESSAGE_ID_SETPRIVATEDATA_CHANGINGPARAMS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 24
D3D12_MESSAGE_ID_SETPRIVATEDATA_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 25
D3D12_MESSAGE_ID_CREATESHADERRESOURCEVIEW_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 26
D3D12_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDDESC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 27
D3D12_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 28
D3D12_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDVIDEOPLANESLICE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 29
D3D12_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDPLANESLICE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 30
D3D12_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 31
D3D12_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 32
D3D12_MESSAGE_ID_CREATERENDERTARGETVIEW_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 35
D3D12_MESSAGE_ID_CREATERENDERTARGETVIEW_UNSUPPORTEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 36
D3D12_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDDESC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 37
D3D12_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 38
D3D12_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDVIDEOPLANESLICE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 39
D3D12_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDPLANESLICE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 40
D3D12_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 41
D3D12_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 42
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 45
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_INVALIDDESC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 46
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 47
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 48
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 49
D3D12_MESSAGE_ID_CREATEINPUTLAYOUT_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 52
D3D12_MESSAGE_ID_CREATEINPUTLAYOUT_TOOMANYELEMENTS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 53
D3D12_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 54
D3D12_MESSAGE_ID_CREATEINPUTLAYOUT_INCOMPATIBLEFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 55
D3D12_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDSLOT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 56
D3D12_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDINPUTSLOTCLASS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 57
D3D12_MESSAGE_ID_CREATEINPUTLAYOUT_STEPRATESLOTCLASSMISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 58
D3D12_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDSLOTCLASSCHANGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 59
D3D12_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDSTEPRATECHANGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 60
D3D12_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDALIGNMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 61
D3D12_MESSAGE_ID_CREATEINPUTLAYOUT_DUPLICATESEMANTIC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 62
D3D12_MESSAGE_ID_CREATEINPUTLAYOUT_UNPARSEABLEINPUTSIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 63
D3D12_MESSAGE_ID_CREATEINPUTLAYOUT_NULLSEMANTIC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 64
D3D12_MESSAGE_ID_CREATEINPUTLAYOUT_MISSINGELEMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 65
D3D12_MESSAGE_ID_CREATEVERTEXSHADER_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 66
D3D12_MESSAGE_ID_CREATEVERTEXSHADER_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 67
D3D12_MESSAGE_ID_CREATEVERTEXSHADER_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 68
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADER_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 69
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADER_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 70
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADER_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 71
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 72
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 73
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 74
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDNUMENTRIES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 75
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_OUTPUTSTREAMSTRIDEUNUSED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 76
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_OUTPUTSLOT0EXPECTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 79
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDOUTPUTSLOT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 80
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_ONLYONEELEMENTPERSLOT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 81
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDCOMPONENTCOUNT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 82
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDSTARTCOMPONENTANDCOMPONENTCOUNT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 83
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDGAPDEFINITION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 84
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_REPEATEDOUTPUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 85
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDOUTPUTSTREAMSTRIDE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 86
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_MISSINGSEMANTIC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 87
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_MASKMISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 88
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_CANTHAVEONLYGAPS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 89
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_DECLTOOCOMPLEX: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 90
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_MISSINGOUTPUTSIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 91
D3D12_MESSAGE_ID_CREATEPIXELSHADER_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 92
D3D12_MESSAGE_ID_CREATEPIXELSHADER_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 93
D3D12_MESSAGE_ID_CREATEPIXELSHADER_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 94
D3D12_MESSAGE_ID_CREATERASTERIZERSTATE_INVALIDFILLMODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 95
D3D12_MESSAGE_ID_CREATERASTERIZERSTATE_INVALIDCULLMODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 96
D3D12_MESSAGE_ID_CREATERASTERIZERSTATE_INVALIDDEPTHBIASCLAMP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 97
D3D12_MESSAGE_ID_CREATERASTERIZERSTATE_INVALIDSLOPESCALEDDEPTHBIAS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 98
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDDEPTHWRITEMASK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 100
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDDEPTHFUNC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 101
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDFRONTFACESTENCILFAILOP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 102
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDFRONTFACESTENCILZFAILOP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 103
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDFRONTFACESTENCILPASSOP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 104
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDFRONTFACESTENCILFUNC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 105
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDBACKFACESTENCILFAILOP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 106
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDBACKFACESTENCILZFAILOP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 107
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDBACKFACESTENCILPASSOP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 108
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDBACKFACESTENCILFUNC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 109
D3D12_MESSAGE_ID_CREATEBLENDSTATE_INVALIDSRCBLEND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 111
D3D12_MESSAGE_ID_CREATEBLENDSTATE_INVALIDDESTBLEND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 112
D3D12_MESSAGE_ID_CREATEBLENDSTATE_INVALIDBLENDOP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 113
D3D12_MESSAGE_ID_CREATEBLENDSTATE_INVALIDSRCBLENDALPHA: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 114
D3D12_MESSAGE_ID_CREATEBLENDSTATE_INVALIDDESTBLENDALPHA: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 115
D3D12_MESSAGE_ID_CREATEBLENDSTATE_INVALIDBLENDOPALPHA: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 116
D3D12_MESSAGE_ID_CREATEBLENDSTATE_INVALIDRENDERTARGETWRITEMASK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 117
D3D12_MESSAGE_ID_GET_PROGRAM_IDENTIFIER_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 118
D3D12_MESSAGE_ID_GET_WORK_GRAPH_PROPERTIES_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 119
D3D12_MESSAGE_ID_SET_PROGRAM_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 120
D3D12_MESSAGE_ID_CLEARDEPTHSTENCILVIEW_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 135
D3D12_MESSAGE_ID_COMMAND_LIST_DRAW_ROOT_SIGNATURE_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 200
D3D12_MESSAGE_ID_COMMAND_LIST_DRAW_ROOT_SIGNATURE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 201
D3D12_MESSAGE_ID_COMMAND_LIST_DRAW_VERTEX_BUFFER_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 202
D3D12_MESSAGE_ID_COMMAND_LIST_DRAW_VERTEX_BUFFER_STRIDE_TOO_SMALL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 209
D3D12_MESSAGE_ID_COMMAND_LIST_DRAW_VERTEX_BUFFER_TOO_SMALL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 210
D3D12_MESSAGE_ID_COMMAND_LIST_DRAW_INDEX_BUFFER_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 211
D3D12_MESSAGE_ID_COMMAND_LIST_DRAW_INDEX_BUFFER_FORMAT_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 212
D3D12_MESSAGE_ID_COMMAND_LIST_DRAW_INDEX_BUFFER_TOO_SMALL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 213
D3D12_MESSAGE_ID_COMMAND_LIST_DRAW_INVALID_PRIMITIVETOPOLOGY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 219
D3D12_MESSAGE_ID_COMMAND_LIST_DRAW_VERTEX_STRIDE_UNALIGNED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 221
D3D12_MESSAGE_ID_COMMAND_LIST_DRAW_INDEX_OFFSET_UNALIGNED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 222
D3D12_MESSAGE_ID_DEVICE_REMOVAL_PROCESS_AT_FAULT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 232
D3D12_MESSAGE_ID_DEVICE_REMOVAL_PROCESS_POSSIBLY_AT_FAULT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 233
D3D12_MESSAGE_ID_DEVICE_REMOVAL_PROCESS_NOT_AT_FAULT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 234
D3D12_MESSAGE_ID_CREATEINPUTLAYOUT_TRAILING_DIGIT_IN_SEMANTIC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 239
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_TRAILING_DIGIT_IN_SEMANTIC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 240
D3D12_MESSAGE_ID_CREATEINPUTLAYOUT_TYPE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 245
D3D12_MESSAGE_ID_CREATEINPUTLAYOUT_EMPTY_LAYOUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 253
D3D12_MESSAGE_ID_LIVE_OBJECT_SUMMARY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 255
D3D12_MESSAGE_ID_LIVE_DEVICE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 274
D3D12_MESSAGE_ID_LIVE_SWAPCHAIN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 275
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 276
D3D12_MESSAGE_ID_CREATEVERTEXSHADER_INVALIDCLASSLINKAGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 277
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADER_INVALIDCLASSLINKAGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 278
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDSTREAMTORASTERIZER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 280
D3D12_MESSAGE_ID_CREATEPIXELSHADER_INVALIDCLASSLINKAGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 283
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 284
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_UNEXPECTEDENTRIES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 285
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_UNEXPECTEDSTRIDES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 286
D3D12_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDNUMSTRIDES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 287
D3D12_MESSAGE_ID_CREATEHULLSHADER_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 289
D3D12_MESSAGE_ID_CREATEHULLSHADER_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 290
D3D12_MESSAGE_ID_CREATEHULLSHADER_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 291
D3D12_MESSAGE_ID_CREATEHULLSHADER_INVALIDCLASSLINKAGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 292
D3D12_MESSAGE_ID_CREATEDOMAINSHADER_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 294
D3D12_MESSAGE_ID_CREATEDOMAINSHADER_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 295
D3D12_MESSAGE_ID_CREATEDOMAINSHADER_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 296
D3D12_MESSAGE_ID_CREATEDOMAINSHADER_INVALIDCLASSLINKAGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 297
D3D12_MESSAGE_ID_RESOURCE_UNMAP_NOTMAPPED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 310
D3D12_MESSAGE_ID_DEVICE_CHECKFEATURESUPPORT_MISMATCHED_DATA_SIZE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 318
D3D12_MESSAGE_ID_CREATECOMPUTESHADER_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 321
D3D12_MESSAGE_ID_CREATECOMPUTESHADER_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 322
D3D12_MESSAGE_ID_CREATECOMPUTESHADER_INVALIDCLASSLINKAGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 323
D3D12_MESSAGE_ID_DEVICE_CREATEVERTEXSHADER_DOUBLEFLOATOPSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 331
D3D12_MESSAGE_ID_DEVICE_CREATEHULLSHADER_DOUBLEFLOATOPSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 332
D3D12_MESSAGE_ID_DEVICE_CREATEDOMAINSHADER_DOUBLEFLOATOPSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 333
D3D12_MESSAGE_ID_DEVICE_CREATEGEOMETRYSHADER_DOUBLEFLOATOPSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 334
D3D12_MESSAGE_ID_DEVICE_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_DOUBLEFLOATOPSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 335
D3D12_MESSAGE_ID_DEVICE_CREATEPIXELSHADER_DOUBLEFLOATOPSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 336
D3D12_MESSAGE_ID_DEVICE_CREATECOMPUTESHADER_DOUBLEFLOATOPSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 337
D3D12_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 340
D3D12_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_INVALIDDESC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 341
D3D12_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 342
D3D12_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_INVALIDVIDEOPLANESLICE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 343
D3D12_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_INVALIDPLANESLICE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 344
D3D12_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 345
D3D12_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 346
D3D12_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 354
D3D12_MESSAGE_ID_CREATERASTERIZERSTATE_INVALIDFORCEDSAMPLECOUNT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 401
D3D12_MESSAGE_ID_CREATEBLENDSTATE_INVALIDLOGICOPS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 403
D3D12_MESSAGE_ID_DEVICE_CREATEVERTEXSHADER_DOUBLEEXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 410
D3D12_MESSAGE_ID_DEVICE_CREATEHULLSHADER_DOUBLEEXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 412
D3D12_MESSAGE_ID_DEVICE_CREATEDOMAINSHADER_DOUBLEEXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 414
D3D12_MESSAGE_ID_DEVICE_CREATEGEOMETRYSHADER_DOUBLEEXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 416
D3D12_MESSAGE_ID_DEVICE_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_DOUBLEEXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 418
D3D12_MESSAGE_ID_DEVICE_CREATEPIXELSHADER_DOUBLEEXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 420
D3D12_MESSAGE_ID_DEVICE_CREATECOMPUTESHADER_DOUBLEEXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 422
D3D12_MESSAGE_ID_DEVICE_CREATEVERTEXSHADER_UAVSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 425
D3D12_MESSAGE_ID_DEVICE_CREATEHULLSHADER_UAVSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 426
D3D12_MESSAGE_ID_DEVICE_CREATEDOMAINSHADER_UAVSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 427
D3D12_MESSAGE_ID_DEVICE_CREATEGEOMETRYSHADER_UAVSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 428
D3D12_MESSAGE_ID_DEVICE_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_UAVSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 429
D3D12_MESSAGE_ID_DEVICE_CREATEPIXELSHADER_UAVSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 430
D3D12_MESSAGE_ID_DEVICE_CREATECOMPUTESHADER_UAVSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 431
D3D12_MESSAGE_ID_DEVICE_CLEARVIEW_INVALIDSOURCERECT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 447
D3D12_MESSAGE_ID_DEVICE_CLEARVIEW_EMPTYRECT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 448
D3D12_MESSAGE_ID_UPDATETILEMAPPINGS_INVALID_PARAMETER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 493
D3D12_MESSAGE_ID_COPYTILEMAPPINGS_INVALID_PARAMETER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 494
D3D12_MESSAGE_ID_CREATEDEVICE_INVALIDARGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 506
D3D12_MESSAGE_ID_CREATEDEVICE_WARNING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 507
D3D12_MESSAGE_ID_RESOURCE_BARRIER_INVALID_TYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 519
D3D12_MESSAGE_ID_RESOURCE_BARRIER_NULL_POINTER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 520
D3D12_MESSAGE_ID_RESOURCE_BARRIER_INVALID_SUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 521
D3D12_MESSAGE_ID_RESOURCE_BARRIER_RESERVED_BITS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 522
D3D12_MESSAGE_ID_RESOURCE_BARRIER_MISSING_BIND_FLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 523
D3D12_MESSAGE_ID_RESOURCE_BARRIER_MISMATCHING_MISC_FLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 524
D3D12_MESSAGE_ID_RESOURCE_BARRIER_MATCHING_STATES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 525
D3D12_MESSAGE_ID_RESOURCE_BARRIER_INVALID_COMBINATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 526
D3D12_MESSAGE_ID_RESOURCE_BARRIER_BEFORE_AFTER_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 527
D3D12_MESSAGE_ID_RESOURCE_BARRIER_INVALID_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 528
D3D12_MESSAGE_ID_RESOURCE_BARRIER_SAMPLE_COUNT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 529
D3D12_MESSAGE_ID_RESOURCE_BARRIER_INVALID_FLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 530
D3D12_MESSAGE_ID_RESOURCE_BARRIER_INVALID_COMBINED_FLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 531
D3D12_MESSAGE_ID_RESOURCE_BARRIER_INVALID_FLAGS_FOR_FORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 532
D3D12_MESSAGE_ID_RESOURCE_BARRIER_INVALID_SPLIT_BARRIER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 533
D3D12_MESSAGE_ID_RESOURCE_BARRIER_UNMATCHED_END: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 534
D3D12_MESSAGE_ID_RESOURCE_BARRIER_UNMATCHED_BEGIN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 535
D3D12_MESSAGE_ID_RESOURCE_BARRIER_INVALID_FLAG: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 536
D3D12_MESSAGE_ID_RESOURCE_BARRIER_INVALID_COMMAND_LIST_TYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 537
D3D12_MESSAGE_ID_INVALID_SUBRESOURCE_STATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 538
D3D12_MESSAGE_ID_COMMAND_ALLOCATOR_CONTENTION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 540
D3D12_MESSAGE_ID_COMMAND_ALLOCATOR_RESET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 541
D3D12_MESSAGE_ID_COMMAND_ALLOCATOR_RESET_BUNDLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 542
D3D12_MESSAGE_ID_COMMAND_ALLOCATOR_CANNOT_RESET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 543
D3D12_MESSAGE_ID_COMMAND_LIST_OPEN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 544
D3D12_MESSAGE_ID_INVALID_BUNDLE_API: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 546
D3D12_MESSAGE_ID_COMMAND_LIST_CLOSED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 547
D3D12_MESSAGE_ID_WRONG_COMMAND_ALLOCATOR_TYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 549
D3D12_MESSAGE_ID_COMMAND_ALLOCATOR_SYNC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 552
D3D12_MESSAGE_ID_COMMAND_LIST_SYNC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 553
D3D12_MESSAGE_ID_SET_DESCRIPTOR_HEAP_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 554
D3D12_MESSAGE_ID_CREATE_COMMANDQUEUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 557
D3D12_MESSAGE_ID_CREATE_COMMANDALLOCATOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 558
D3D12_MESSAGE_ID_CREATE_PIPELINESTATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 559
D3D12_MESSAGE_ID_CREATE_COMMANDLIST12: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 560
D3D12_MESSAGE_ID_CREATE_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 562
D3D12_MESSAGE_ID_CREATE_DESCRIPTORHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 563
D3D12_MESSAGE_ID_CREATE_ROOTSIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 564
D3D12_MESSAGE_ID_CREATE_LIBRARY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 565
D3D12_MESSAGE_ID_CREATE_HEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 566
D3D12_MESSAGE_ID_CREATE_MONITOREDFENCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 567
D3D12_MESSAGE_ID_CREATE_QUERYHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 568
D3D12_MESSAGE_ID_CREATE_COMMANDSIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 569
D3D12_MESSAGE_ID_LIVE_COMMANDQUEUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 570
D3D12_MESSAGE_ID_LIVE_COMMANDALLOCATOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 571
D3D12_MESSAGE_ID_LIVE_PIPELINESTATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 572
D3D12_MESSAGE_ID_LIVE_COMMANDLIST12: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 573
D3D12_MESSAGE_ID_LIVE_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 575
D3D12_MESSAGE_ID_LIVE_DESCRIPTORHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 576
D3D12_MESSAGE_ID_LIVE_ROOTSIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 577
D3D12_MESSAGE_ID_LIVE_LIBRARY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 578
D3D12_MESSAGE_ID_LIVE_HEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 579
D3D12_MESSAGE_ID_LIVE_MONITOREDFENCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 580
D3D12_MESSAGE_ID_LIVE_QUERYHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 581
D3D12_MESSAGE_ID_LIVE_COMMANDSIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 582
D3D12_MESSAGE_ID_DESTROY_COMMANDQUEUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 583
D3D12_MESSAGE_ID_DESTROY_COMMANDALLOCATOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 584
D3D12_MESSAGE_ID_DESTROY_PIPELINESTATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 585
D3D12_MESSAGE_ID_DESTROY_COMMANDLIST12: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 586
D3D12_MESSAGE_ID_DESTROY_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 588
D3D12_MESSAGE_ID_DESTROY_DESCRIPTORHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 589
D3D12_MESSAGE_ID_DESTROY_ROOTSIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 590
D3D12_MESSAGE_ID_DESTROY_LIBRARY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 591
D3D12_MESSAGE_ID_DESTROY_HEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 592
D3D12_MESSAGE_ID_DESTROY_MONITOREDFENCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 593
D3D12_MESSAGE_ID_DESTROY_QUERYHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 594
D3D12_MESSAGE_ID_DESTROY_COMMANDSIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 595
D3D12_MESSAGE_ID_CREATERESOURCE_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 597
D3D12_MESSAGE_ID_CREATERESOURCE_INVALIDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 599
D3D12_MESSAGE_ID_CREATERESOURCE_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 602
D3D12_MESSAGE_ID_CREATERESOURCE_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 603
D3D12_MESSAGE_ID_CREATERESOURCE_INVALIDDESC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 604
D3D12_MESSAGE_ID_POSSIBLY_INVALID_SUBRESOURCE_STATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 607
D3D12_MESSAGE_ID_INVALID_USE_OF_NON_RESIDENT_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 608
D3D12_MESSAGE_ID_POSSIBLE_INVALID_USE_OF_NON_RESIDENT_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 609
D3D12_MESSAGE_ID_BUNDLE_PIPELINE_STATE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 610
D3D12_MESSAGE_ID_PRIMITIVE_TOPOLOGY_MISMATCH_PIPELINE_STATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 611
D3D12_MESSAGE_ID_RENDER_TARGET_FORMAT_MISMATCH_PIPELINE_STATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 613
D3D12_MESSAGE_ID_RENDER_TARGET_SAMPLE_DESC_MISMATCH_PIPELINE_STATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 614
D3D12_MESSAGE_ID_DEPTH_STENCIL_FORMAT_MISMATCH_PIPELINE_STATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 615
D3D12_MESSAGE_ID_DEPTH_STENCIL_SAMPLE_DESC_MISMATCH_PIPELINE_STATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 616
D3D12_MESSAGE_ID_CREATESHADER_INVALIDBYTECODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 622
D3D12_MESSAGE_ID_CREATEHEAP_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 623
D3D12_MESSAGE_ID_CREATEHEAP_INVALIDSIZE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 624
D3D12_MESSAGE_ID_CREATEHEAP_UNRECOGNIZEDHEAPTYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 625
D3D12_MESSAGE_ID_CREATEHEAP_UNRECOGNIZEDCPUPAGEPROPERTIES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 626
D3D12_MESSAGE_ID_CREATEHEAP_UNRECOGNIZEDMEMORYPOOL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 627
D3D12_MESSAGE_ID_CREATEHEAP_INVALIDPROPERTIES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 628
D3D12_MESSAGE_ID_CREATEHEAP_INVALIDALIGNMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 629
D3D12_MESSAGE_ID_CREATEHEAP_UNRECOGNIZEDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 630
D3D12_MESSAGE_ID_CREATEHEAP_INVALIDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 631
D3D12_MESSAGE_ID_CREATEHEAP_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 632
D3D12_MESSAGE_ID_CREATEHEAP_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 633
D3D12_MESSAGE_ID_CREATERESOURCEANDHEAP_NULLHEAPPROPERTIES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 634
D3D12_MESSAGE_ID_CREATERESOURCEANDHEAP_UNRECOGNIZEDHEAPTYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 635
D3D12_MESSAGE_ID_CREATERESOURCEANDHEAP_UNRECOGNIZEDCPUPAGEPROPERTIES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 636
D3D12_MESSAGE_ID_CREATERESOURCEANDHEAP_UNRECOGNIZEDMEMORYPOOL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 637
D3D12_MESSAGE_ID_CREATERESOURCEANDHEAP_INVALIDHEAPPROPERTIES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 638
D3D12_MESSAGE_ID_CREATERESOURCEANDHEAP_UNRECOGNIZEDHEAPMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 639
D3D12_MESSAGE_ID_CREATERESOURCEANDHEAP_INVALIDHEAPMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 640
D3D12_MESSAGE_ID_CREATERESOURCEANDHEAP_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 641
D3D12_MESSAGE_ID_CREATERESOURCEANDHEAP_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 642
D3D12_MESSAGE_ID_GETCUSTOMHEAPPROPERTIES_UNRECOGNIZEDHEAPTYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 643
D3D12_MESSAGE_ID_GETCUSTOMHEAPPROPERTIES_INVALIDHEAPTYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 644
D3D12_MESSAGE_ID_CREATE_DESCRIPTOR_HEAP_INVALID_DESC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 645
D3D12_MESSAGE_ID_INVALID_DESCRIPTOR_HANDLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 646
D3D12_MESSAGE_ID_CREATERASTERIZERSTATE_INVALID_CONSERVATIVERASTERMODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 647
D3D12_MESSAGE_ID_CREATE_CONSTANT_BUFFER_VIEW_INVALID_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 649
D3D12_MESSAGE_ID_CREATE_CONSTANT_BUFFER_VIEW_INVALID_DESC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 650
D3D12_MESSAGE_ID_CREATE_UNORDEREDACCESS_VIEW_INVALID_COUNTER_USAGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 652
D3D12_MESSAGE_ID_COPY_DESCRIPTORS_INVALID_RANGES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 653
D3D12_MESSAGE_ID_COPY_DESCRIPTORS_WRITE_ONLY_DESCRIPTOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 654
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_RTV_FORMAT_NOT_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 655
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_INVALID_RENDER_TARGET_COUNT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 656
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_VERTEX_SHADER_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 657
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_INPUTLAYOUT_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 658
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_SHADER_LINKAGE_HS_DS_SIGNATURE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 659
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_SHADER_LINKAGE_REGISTERINDEX: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 660
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_SHADER_LINKAGE_COMPONENTTYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 661
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_SHADER_LINKAGE_REGISTERMASK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 662
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_SHADER_LINKAGE_SYSTEMVALUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 663
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_SHADER_LINKAGE_NEVERWRITTEN_ALWAYSREADS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 664
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_SHADER_LINKAGE_MINPRECISION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 665
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_SHADER_LINKAGE_SEMANTICNAME_NOT_FOUND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 666
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_HS_XOR_DS_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 667
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_HULL_SHADER_INPUT_TOPOLOGY_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 668
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_HS_DS_CONTROL_POINT_COUNT_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 669
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_HS_DS_TESSELLATOR_DOMAIN_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 670
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_INVALID_USE_OF_CENTER_MULTISAMPLE_PATTERN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 671
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_INVALID_USE_OF_FORCED_SAMPLE_COUNT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 672
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_INVALID_PRIMITIVETOPOLOGY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 673
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_INVALID_SYSTEMVALUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 674
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_OM_DUAL_SOURCE_BLENDING_CAN_ONLY_HAVE_RENDER_TARGET_0: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 675
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_OM_RENDER_TARGET_DOES_NOT_SUPPORT_BLENDING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 676
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_PS_OUTPUT_TYPE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 677
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_OM_RENDER_TARGET_DOES_NOT_SUPPORT_LOGIC_OPS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 678
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_RENDERTARGETVIEW_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 679
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_DEPTHSTENCILVIEW_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 680
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_GS_INPUT_PRIMITIVE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 681
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_POSITION_NOT_PRESENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 682
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_MISSING_ROOT_SIGNATURE_FLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 683
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_INVALID_INDEX_BUFFER_PROPERTIES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 684
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_INVALID_SAMPLE_DESC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 685
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_HS_ROOT_SIGNATURE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 686
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_DS_ROOT_SIGNATURE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 687
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_VS_ROOT_SIGNATURE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 688
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_GS_ROOT_SIGNATURE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 689
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_PS_ROOT_SIGNATURE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 690
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_MISSING_ROOT_SIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 691
D3D12_MESSAGE_ID_EXECUTE_BUNDLE_OPEN_BUNDLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 692
D3D12_MESSAGE_ID_EXECUTE_BUNDLE_DESCRIPTOR_HEAP_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 693
D3D12_MESSAGE_ID_EXECUTE_BUNDLE_TYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 694
D3D12_MESSAGE_ID_DRAW_EMPTY_SCISSOR_RECTANGLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 695
D3D12_MESSAGE_ID_CREATE_ROOT_SIGNATURE_BLOB_NOT_FOUND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 696
D3D12_MESSAGE_ID_CREATE_ROOT_SIGNATURE_DESERIALIZE_FAILED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 697
D3D12_MESSAGE_ID_CREATE_ROOT_SIGNATURE_INVALID_CONFIGURATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 698
D3D12_MESSAGE_ID_CREATE_ROOT_SIGNATURE_NOT_SUPPORTED_ON_DEVICE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 699
D3D12_MESSAGE_ID_CREATERESOURCEANDHEAP_NULLRESOURCEPROPERTIES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 700
D3D12_MESSAGE_ID_CREATERESOURCEANDHEAP_NULLHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 701
D3D12_MESSAGE_ID_GETRESOURCEALLOCATIONINFO_INVALIDRDESCS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 702
D3D12_MESSAGE_ID_MAKERESIDENT_NULLOBJECTARRAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 703
D3D12_MESSAGE_ID_EVICT_NULLOBJECTARRAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 705
D3D12_MESSAGE_ID_SET_DESCRIPTOR_TABLE_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 708
D3D12_MESSAGE_ID_SET_ROOT_CONSTANT_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 709
D3D12_MESSAGE_ID_SET_ROOT_CONSTANT_BUFFER_VIEW_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 710
D3D12_MESSAGE_ID_SET_ROOT_SHADER_RESOURCE_VIEW_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 711
D3D12_MESSAGE_ID_SET_ROOT_UNORDERED_ACCESS_VIEW_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 712
D3D12_MESSAGE_ID_SET_VERTEX_BUFFERS_INVALID_DESC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 713
D3D12_MESSAGE_ID_SET_INDEX_BUFFER_INVALID_DESC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 715
D3D12_MESSAGE_ID_SET_STREAM_OUTPUT_BUFFERS_INVALID_DESC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 717
D3D12_MESSAGE_ID_CREATERESOURCE_UNRECOGNIZEDDIMENSIONALITY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 718
D3D12_MESSAGE_ID_CREATERESOURCE_UNRECOGNIZEDLAYOUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 719
D3D12_MESSAGE_ID_CREATERESOURCE_INVALIDDIMENSIONALITY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 720
D3D12_MESSAGE_ID_CREATERESOURCE_INVALIDALIGNMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 721
D3D12_MESSAGE_ID_CREATERESOURCE_INVALIDMIPLEVELS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 722
D3D12_MESSAGE_ID_CREATERESOURCE_INVALIDSAMPLEDESC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 723
D3D12_MESSAGE_ID_CREATERESOURCE_INVALIDLAYOUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 724
D3D12_MESSAGE_ID_SET_INDEX_BUFFER_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 725
D3D12_MESSAGE_ID_SET_VERTEX_BUFFERS_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 726
D3D12_MESSAGE_ID_SET_STREAM_OUTPUT_BUFFERS_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 727
D3D12_MESSAGE_ID_SET_RENDER_TARGETS_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 728
D3D12_MESSAGE_ID_CREATEQUERY_HEAP_INVALID_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 729
D3D12_MESSAGE_ID_BEGIN_END_QUERY_INVALID_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 731
D3D12_MESSAGE_ID_CLOSE_COMMAND_LIST_OPEN_QUERY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 732
D3D12_MESSAGE_ID_RESOLVE_QUERY_DATA_INVALID_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 733
D3D12_MESSAGE_ID_SET_PREDICATION_INVALID_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 734
D3D12_MESSAGE_ID_TIMESTAMPS_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 735
D3D12_MESSAGE_ID_CREATERESOURCE_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 737
D3D12_MESSAGE_ID_CREATERESOURCE_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 738
D3D12_MESSAGE_ID_GETCOPYABLEFOOTPRINTS_INVALIDSUBRESOURCERANGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 739
D3D12_MESSAGE_ID_GETCOPYABLEFOOTPRINTS_INVALIDBASEOFFSET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 740
D3D12_MESSAGE_ID_GETCOPYABLELAYOUT_INVALIDSUBRESOURCERANGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 739
D3D12_MESSAGE_ID_GETCOPYABLELAYOUT_INVALIDBASEOFFSET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 740
D3D12_MESSAGE_ID_RESOURCE_BARRIER_INVALID_HEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 741
D3D12_MESSAGE_ID_CREATE_SAMPLER_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 742
D3D12_MESSAGE_ID_CREATECOMMANDSIGNATURE_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 743
D3D12_MESSAGE_ID_EXECUTE_INDIRECT_INVALID_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 744
D3D12_MESSAGE_ID_GETGPUVIRTUALADDRESS_INVALID_RESOURCE_DIMENSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 745
D3D12_MESSAGE_ID_CREATERESOURCE_INVALIDCLEARVALUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 815
D3D12_MESSAGE_ID_CREATERESOURCE_UNRECOGNIZEDCLEARVALUEFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 816
D3D12_MESSAGE_ID_CREATERESOURCE_INVALIDCLEARVALUEFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 817
D3D12_MESSAGE_ID_CREATERESOURCE_CLEARVALUEDENORMFLUSH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 818
D3D12_MESSAGE_ID_CLEARRENDERTARGETVIEW_MISMATCHINGCLEARVALUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 820
D3D12_MESSAGE_ID_CLEARDEPTHSTENCILVIEW_MISMATCHINGCLEARVALUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 821
D3D12_MESSAGE_ID_MAP_INVALIDHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 822
D3D12_MESSAGE_ID_UNMAP_INVALIDHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 823
D3D12_MESSAGE_ID_MAP_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 824
D3D12_MESSAGE_ID_UNMAP_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 825
D3D12_MESSAGE_ID_MAP_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 826
D3D12_MESSAGE_ID_UNMAP_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 827
D3D12_MESSAGE_ID_MAP_INVALIDRANGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 828
D3D12_MESSAGE_ID_UNMAP_INVALIDRANGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 829
D3D12_MESSAGE_ID_MAP_INVALIDDATAPOINTER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 832
D3D12_MESSAGE_ID_MAP_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 833
D3D12_MESSAGE_ID_MAP_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 834
D3D12_MESSAGE_ID_EXECUTECOMMANDLISTS_BUNDLENOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 835
D3D12_MESSAGE_ID_EXECUTECOMMANDLISTS_COMMANDLISTMISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 836
D3D12_MESSAGE_ID_EXECUTECOMMANDLISTS_OPENCOMMANDLIST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 837
D3D12_MESSAGE_ID_EXECUTECOMMANDLISTS_FAILEDCOMMANDLIST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 838
D3D12_MESSAGE_ID_COPYBUFFERREGION_NULLDST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 839
D3D12_MESSAGE_ID_COPYBUFFERREGION_INVALIDDSTRESOURCEDIMENSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 840
D3D12_MESSAGE_ID_COPYBUFFERREGION_DSTRANGEOUTOFBOUNDS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 841
D3D12_MESSAGE_ID_COPYBUFFERREGION_NULLSRC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 842
D3D12_MESSAGE_ID_COPYBUFFERREGION_INVALIDSRCRESOURCEDIMENSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 843
D3D12_MESSAGE_ID_COPYBUFFERREGION_SRCRANGEOUTOFBOUNDS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 844
D3D12_MESSAGE_ID_COPYBUFFERREGION_INVALIDCOPYFLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 845
D3D12_MESSAGE_ID_COPYTEXTUREREGION_NULLDST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 846
D3D12_MESSAGE_ID_COPYTEXTUREREGION_UNRECOGNIZEDDSTTYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 847
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDDSTRESOURCEDIMENSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 848
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDDSTRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 849
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDDSTSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 850
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDDSTOFFSET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 851
D3D12_MESSAGE_ID_COPYTEXTUREREGION_UNRECOGNIZEDDSTFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 852
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDDSTFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 853
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDDSTDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 854
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDDSTROWPITCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 855
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDDSTPLACEMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 856
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDDSTDSPLACEDFOOTPRINTFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 857
D3D12_MESSAGE_ID_COPYTEXTUREREGION_DSTREGIONOUTOFBOUNDS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 858
D3D12_MESSAGE_ID_COPYTEXTUREREGION_NULLSRC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 859
D3D12_MESSAGE_ID_COPYTEXTUREREGION_UNRECOGNIZEDSRCTYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 860
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDSRCRESOURCEDIMENSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 861
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDSRCRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 862
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDSRCSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 863
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDSRCOFFSET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 864
D3D12_MESSAGE_ID_COPYTEXTUREREGION_UNRECOGNIZEDSRCFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 865
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDSRCFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 866
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDSRCDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 867
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDSRCROWPITCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 868
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDSRCPLACEMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 869
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDSRCDSPLACEDFOOTPRINTFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 870
D3D12_MESSAGE_ID_COPYTEXTUREREGION_SRCREGIONOUTOFBOUNDS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 871
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDDSTCOORDINATES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 872
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDSRCBOX: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 873
D3D12_MESSAGE_ID_COPYTEXTUREREGION_FORMATMISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 874
D3D12_MESSAGE_ID_COPYTEXTUREREGION_EMPTYBOX: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 875
D3D12_MESSAGE_ID_COPYTEXTUREREGION_INVALIDCOPYFLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 876
D3D12_MESSAGE_ID_RESOLVESUBRESOURCE_INVALID_SUBRESOURCE_INDEX: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 877
D3D12_MESSAGE_ID_RESOLVESUBRESOURCE_INVALID_FORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 878
D3D12_MESSAGE_ID_RESOLVESUBRESOURCE_RESOURCE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 879
D3D12_MESSAGE_ID_RESOLVESUBRESOURCE_INVALID_SAMPLE_COUNT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 880
D3D12_MESSAGE_ID_CREATECOMPUTEPIPELINESTATE_INVALID_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 881
D3D12_MESSAGE_ID_CREATECOMPUTEPIPELINESTATE_CS_ROOT_SIGNATURE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 882
D3D12_MESSAGE_ID_CREATECOMPUTEPIPELINESTATE_MISSING_ROOT_SIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 883
D3D12_MESSAGE_ID_CREATEPIPELINESTATE_INVALIDCACHEDBLOB: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 884
D3D12_MESSAGE_ID_CREATEPIPELINESTATE_CACHEDBLOBADAPTERMISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 885
D3D12_MESSAGE_ID_CREATEPIPELINESTATE_CACHEDBLOBDRIVERVERSIONMISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 886
D3D12_MESSAGE_ID_CREATEPIPELINESTATE_CACHEDBLOBDESCMISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 887
D3D12_MESSAGE_ID_CREATEPIPELINESTATE_CACHEDBLOBIGNORED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 888
D3D12_MESSAGE_ID_WRITETOSUBRESOURCE_INVALIDHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 889
D3D12_MESSAGE_ID_WRITETOSUBRESOURCE_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 890
D3D12_MESSAGE_ID_WRITETOSUBRESOURCE_INVALIDBOX: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 891
D3D12_MESSAGE_ID_WRITETOSUBRESOURCE_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 892
D3D12_MESSAGE_ID_WRITETOSUBRESOURCE_EMPTYBOX: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 893
D3D12_MESSAGE_ID_READFROMSUBRESOURCE_INVALIDHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 894
D3D12_MESSAGE_ID_READFROMSUBRESOURCE_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 895
D3D12_MESSAGE_ID_READFROMSUBRESOURCE_INVALIDBOX: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 896
D3D12_MESSAGE_ID_READFROMSUBRESOURCE_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 897
D3D12_MESSAGE_ID_READFROMSUBRESOURCE_EMPTYBOX: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 898
D3D12_MESSAGE_ID_TOO_MANY_NODES_SPECIFIED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 899
D3D12_MESSAGE_ID_INVALID_NODE_INDEX: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 900
D3D12_MESSAGE_ID_GETHEAPPROPERTIES_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 901
D3D12_MESSAGE_ID_NODE_MASK_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 902
D3D12_MESSAGE_ID_COMMAND_LIST_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 903
D3D12_MESSAGE_ID_COMMAND_LIST_MULTIPLE_SWAPCHAIN_BUFFER_REFERENCES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 904
D3D12_MESSAGE_ID_COMMAND_LIST_TOO_MANY_SWAPCHAIN_REFERENCES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 905
D3D12_MESSAGE_ID_COMMAND_QUEUE_TOO_MANY_SWAPCHAIN_REFERENCES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 906
D3D12_MESSAGE_ID_EXECUTECOMMANDLISTS_WRONGSWAPCHAINBUFFERREFERENCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 907
D3D12_MESSAGE_ID_COMMAND_LIST_SETRENDERTARGETS_INVALIDNUMRENDERTARGETS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 908
D3D12_MESSAGE_ID_CREATE_QUEUE_INVALID_TYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 909
D3D12_MESSAGE_ID_CREATE_QUEUE_INVALID_FLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 910
D3D12_MESSAGE_ID_CREATESHAREDRESOURCE_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 911
D3D12_MESSAGE_ID_CREATESHAREDRESOURCE_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 912
D3D12_MESSAGE_ID_CREATESHAREDHEAP_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 913
D3D12_MESSAGE_ID_REFLECTSHAREDPROPERTIES_UNRECOGNIZEDPROPERTIES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 914
D3D12_MESSAGE_ID_REFLECTSHAREDPROPERTIES_INVALIDSIZE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 915
D3D12_MESSAGE_ID_REFLECTSHAREDPROPERTIES_INVALIDOBJECT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 916
D3D12_MESSAGE_ID_KEYEDMUTEX_INVALIDOBJECT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 917
D3D12_MESSAGE_ID_KEYEDMUTEX_INVALIDKEY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 918
D3D12_MESSAGE_ID_KEYEDMUTEX_WRONGSTATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 919
D3D12_MESSAGE_ID_CREATE_QUEUE_INVALID_PRIORITY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 920
D3D12_MESSAGE_ID_OBJECT_DELETED_WHILE_STILL_IN_USE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 921
D3D12_MESSAGE_ID_CREATEPIPELINESTATE_INVALID_FLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 922
D3D12_MESSAGE_ID_HEAP_ADDRESS_RANGE_HAS_NO_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 923
D3D12_MESSAGE_ID_COMMAND_LIST_DRAW_RENDER_TARGET_DELETED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 924
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_ALL_RENDER_TARGETS_HAVE_UNKNOWN_FORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 925
D3D12_MESSAGE_ID_HEAP_ADDRESS_RANGE_INTERSECTS_MULTIPLE_BUFFERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 926
D3D12_MESSAGE_ID_EXECUTECOMMANDLISTS_GPU_WRITTEN_READBACK_RESOURCE_MAPPED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 927
D3D12_MESSAGE_ID_UNMAP_RANGE_NOT_EMPTY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 929
D3D12_MESSAGE_ID_MAP_INVALID_NULLRANGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 930
D3D12_MESSAGE_ID_UNMAP_INVALID_NULLRANGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 931
D3D12_MESSAGE_ID_NO_GRAPHICS_API_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 932
D3D12_MESSAGE_ID_NO_COMPUTE_API_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 933
D3D12_MESSAGE_ID_RESOLVESUBRESOURCE_RESOURCE_FLAGS_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 934
D3D12_MESSAGE_ID_GPU_BASED_VALIDATION_ROOT_ARGUMENT_UNINITIALIZED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 935
D3D12_MESSAGE_ID_GPU_BASED_VALIDATION_DESCRIPTOR_HEAP_INDEX_OUT_OF_BOUNDS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 936
D3D12_MESSAGE_ID_GPU_BASED_VALIDATION_DESCRIPTOR_TABLE_REGISTER_INDEX_OUT_OF_BOUNDS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 937
D3D12_MESSAGE_ID_GPU_BASED_VALIDATION_DESCRIPTOR_UNINITIALIZED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 938
D3D12_MESSAGE_ID_GPU_BASED_VALIDATION_DESCRIPTOR_TYPE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 939
D3D12_MESSAGE_ID_GPU_BASED_VALIDATION_SRV_RESOURCE_DIMENSION_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 940
D3D12_MESSAGE_ID_GPU_BASED_VALIDATION_UAV_RESOURCE_DIMENSION_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 941
D3D12_MESSAGE_ID_GPU_BASED_VALIDATION_INCOMPATIBLE_RESOURCE_STATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 942
D3D12_MESSAGE_ID_COPYRESOURCE_NULLDST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 943
D3D12_MESSAGE_ID_COPYRESOURCE_INVALIDDSTRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 944
D3D12_MESSAGE_ID_COPYRESOURCE_NULLSRC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 945
D3D12_MESSAGE_ID_COPYRESOURCE_INVALIDSRCRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 946
D3D12_MESSAGE_ID_RESOLVESUBRESOURCE_NULLDST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 947
D3D12_MESSAGE_ID_RESOLVESUBRESOURCE_INVALIDDSTRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 948
D3D12_MESSAGE_ID_RESOLVESUBRESOURCE_NULLSRC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 949
D3D12_MESSAGE_ID_RESOLVESUBRESOURCE_INVALIDSRCRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 950
D3D12_MESSAGE_ID_PIPELINE_STATE_TYPE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 951
D3D12_MESSAGE_ID_COMMAND_LIST_DISPATCH_ROOT_SIGNATURE_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 952
D3D12_MESSAGE_ID_COMMAND_LIST_DISPATCH_ROOT_SIGNATURE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 953
D3D12_MESSAGE_ID_RESOURCE_BARRIER_ZERO_BARRIERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 954
D3D12_MESSAGE_ID_BEGIN_END_EVENT_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 955
D3D12_MESSAGE_ID_RESOURCE_BARRIER_POSSIBLE_BEFORE_AFTER_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 956
D3D12_MESSAGE_ID_RESOURCE_BARRIER_MISMATCHING_BEGIN_END: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 957
D3D12_MESSAGE_ID_GPU_BASED_VALIDATION_INVALID_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 958
D3D12_MESSAGE_ID_USE_OF_ZERO_REFCOUNT_OBJECT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 959
D3D12_MESSAGE_ID_OBJECT_EVICTED_WHILE_STILL_IN_USE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 960
D3D12_MESSAGE_ID_GPU_BASED_VALIDATION_ROOT_DESCRIPTOR_ACCESS_OUT_OF_BOUNDS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 961
D3D12_MESSAGE_ID_CREATEPIPELINELIBRARY_INVALIDLIBRARYBLOB: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 962
D3D12_MESSAGE_ID_CREATEPIPELINELIBRARY_DRIVERVERSIONMISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 963
D3D12_MESSAGE_ID_CREATEPIPELINELIBRARY_ADAPTERVERSIONMISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 964
D3D12_MESSAGE_ID_CREATEPIPELINELIBRARY_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 965
D3D12_MESSAGE_ID_CREATE_PIPELINELIBRARY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 966
D3D12_MESSAGE_ID_LIVE_PIPELINELIBRARY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 967
D3D12_MESSAGE_ID_DESTROY_PIPELINELIBRARY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 968
D3D12_MESSAGE_ID_STOREPIPELINE_NONAME: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 969
D3D12_MESSAGE_ID_STOREPIPELINE_DUPLICATENAME: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 970
D3D12_MESSAGE_ID_LOADPIPELINE_NAMENOTFOUND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 971
D3D12_MESSAGE_ID_LOADPIPELINE_INVALIDDESC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 972
D3D12_MESSAGE_ID_PIPELINELIBRARY_SERIALIZE_NOTENOUGHMEMORY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 973
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_PS_OUTPUT_RT_OUTPUT_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 974
D3D12_MESSAGE_ID_SETEVENTONMULTIPLEFENCECOMPLETION_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 975
D3D12_MESSAGE_ID_CREATE_QUEUE_VIDEO_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 976
D3D12_MESSAGE_ID_CREATE_COMMAND_ALLOCATOR_VIDEO_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 977
D3D12_MESSAGE_ID_CREATEQUERY_HEAP_VIDEO_DECODE_STATISTICS_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 978
D3D12_MESSAGE_ID_CREATE_VIDEODECODECOMMANDLIST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 979
D3D12_MESSAGE_ID_CREATE_VIDEODECODER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 980
D3D12_MESSAGE_ID_CREATE_VIDEODECODESTREAM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 981
D3D12_MESSAGE_ID_LIVE_VIDEODECODECOMMANDLIST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 982
D3D12_MESSAGE_ID_LIVE_VIDEODECODER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 983
D3D12_MESSAGE_ID_LIVE_VIDEODECODESTREAM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 984
D3D12_MESSAGE_ID_DESTROY_VIDEODECODECOMMANDLIST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 985
D3D12_MESSAGE_ID_DESTROY_VIDEODECODER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 986
D3D12_MESSAGE_ID_DESTROY_VIDEODECODESTREAM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 987
D3D12_MESSAGE_ID_DECODE_FRAME_INVALID_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 988
D3D12_MESSAGE_ID_DEPRECATED_API: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 989
D3D12_MESSAGE_ID_RESOURCE_BARRIER_MISMATCHING_COMMAND_LIST_TYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 990
D3D12_MESSAGE_ID_COMMAND_LIST_DESCRIPTOR_TABLE_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 991
D3D12_MESSAGE_ID_COMMAND_LIST_ROOT_CONSTANT_BUFFER_VIEW_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 992
D3D12_MESSAGE_ID_COMMAND_LIST_ROOT_SHADER_RESOURCE_VIEW_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 993
D3D12_MESSAGE_ID_COMMAND_LIST_ROOT_UNORDERED_ACCESS_VIEW_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 994
D3D12_MESSAGE_ID_DISCARD_INVALID_SUBRESOURCE_RANGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 995
D3D12_MESSAGE_ID_DISCARD_ONE_SUBRESOURCE_FOR_MIPS_WITH_RECTS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 996
D3D12_MESSAGE_ID_DISCARD_NO_RECTS_FOR_NON_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 997
D3D12_MESSAGE_ID_COPY_ON_SAME_SUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 998
D3D12_MESSAGE_ID_SETRESIDENCYPRIORITY_INVALID_PAGEABLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 999
D3D12_MESSAGE_ID_GPU_BASED_VALIDATION_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1000
D3D12_MESSAGE_ID_STATIC_DESCRIPTOR_INVALID_DESCRIPTOR_CHANGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1001
D3D12_MESSAGE_ID_DATA_STATIC_DESCRIPTOR_INVALID_DATA_CHANGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1002
D3D12_MESSAGE_ID_DATA_STATIC_WHILE_SET_AT_EXECUTE_DESCRIPTOR_INVALID_DATA_CHANGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1003
D3D12_MESSAGE_ID_EXECUTE_BUNDLE_STATIC_DESCRIPTOR_DATA_STATIC_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1004
D3D12_MESSAGE_ID_GPU_BASED_VALIDATION_RESOURCE_ACCESS_OUT_OF_BOUNDS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1005
D3D12_MESSAGE_ID_GPU_BASED_VALIDATION_SAMPLER_MODE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1006
D3D12_MESSAGE_ID_CREATE_FENCE_INVALID_FLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1007
D3D12_MESSAGE_ID_RESOURCE_BARRIER_DUPLICATE_SUBRESOURCE_TRANSITIONS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1008
D3D12_MESSAGE_ID_SETRESIDENCYPRIORITY_INVALID_PRIORITY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1009
D3D12_MESSAGE_ID_CREATE_DESCRIPTOR_HEAP_LARGE_NUM_DESCRIPTORS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1013
D3D12_MESSAGE_ID_BEGIN_EVENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1014
D3D12_MESSAGE_ID_END_EVENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1015
D3D12_MESSAGE_ID_CREATEDEVICE_DEBUG_LAYER_STARTUP_OPTIONS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1016
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_DEPTHBOUNDSTEST_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1017
D3D12_MESSAGE_ID_CREATEPIPELINESTATE_DUPLICATE_SUBOBJECT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1018
D3D12_MESSAGE_ID_CREATEPIPELINESTATE_UNKNOWN_SUBOBJECT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1019
D3D12_MESSAGE_ID_CREATEPIPELINESTATE_ZERO_SIZE_STREAM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1020
D3D12_MESSAGE_ID_CREATEPIPELINESTATE_INVALID_STREAM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1021
D3D12_MESSAGE_ID_CREATEPIPELINESTATE_CANNOT_DEDUCE_TYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1022
D3D12_MESSAGE_ID_COMMAND_LIST_STATIC_DESCRIPTOR_RESOURCE_DIMENSION_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1023
D3D12_MESSAGE_ID_CREATE_COMMAND_QUEUE_INSUFFICIENT_PRIVILEGE_FOR_GLOBAL_REALTIME: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1024
D3D12_MESSAGE_ID_CREATE_COMMAND_QUEUE_INSUFFICIENT_HARDWARE_SUPPORT_FOR_GLOBAL_REALTIME: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1025
D3D12_MESSAGE_ID_ATOMICCOPYBUFFER_INVALID_ARCHITECTURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1026
D3D12_MESSAGE_ID_ATOMICCOPYBUFFER_NULL_DST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1027
D3D12_MESSAGE_ID_ATOMICCOPYBUFFER_INVALID_DST_RESOURCE_DIMENSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1028
D3D12_MESSAGE_ID_ATOMICCOPYBUFFER_DST_RANGE_OUT_OF_BOUNDS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1029
D3D12_MESSAGE_ID_ATOMICCOPYBUFFER_NULL_SRC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1030
D3D12_MESSAGE_ID_ATOMICCOPYBUFFER_INVALID_SRC_RESOURCE_DIMENSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1031
D3D12_MESSAGE_ID_ATOMICCOPYBUFFER_SRC_RANGE_OUT_OF_BOUNDS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1032
D3D12_MESSAGE_ID_ATOMICCOPYBUFFER_INVALID_OFFSET_ALIGNMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1033
D3D12_MESSAGE_ID_ATOMICCOPYBUFFER_NULL_DEPENDENT_RESOURCES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1034
D3D12_MESSAGE_ID_ATOMICCOPYBUFFER_NULL_DEPENDENT_SUBRESOURCE_RANGES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1035
D3D12_MESSAGE_ID_ATOMICCOPYBUFFER_INVALID_DEPENDENT_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1036
D3D12_MESSAGE_ID_ATOMICCOPYBUFFER_INVALID_DEPENDENT_SUBRESOURCE_RANGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1037
D3D12_MESSAGE_ID_ATOMICCOPYBUFFER_DEPENDENT_SUBRESOURCE_OUT_OF_BOUNDS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1038
D3D12_MESSAGE_ID_ATOMICCOPYBUFFER_DEPENDENT_RANGE_OUT_OF_BOUNDS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1039
D3D12_MESSAGE_ID_ATOMICCOPYBUFFER_ZERO_DEPENDENCIES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1040
D3D12_MESSAGE_ID_DEVICE_CREATE_SHARED_HANDLE_INVALIDARG: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1041
D3D12_MESSAGE_ID_DESCRIPTOR_HANDLE_WITH_INVALID_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1042
D3D12_MESSAGE_ID_SETDEPTHBOUNDS_INVALIDARGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1043
D3D12_MESSAGE_ID_GPU_BASED_VALIDATION_RESOURCE_STATE_IMPRECISE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1044
D3D12_MESSAGE_ID_COMMAND_LIST_PIPELINE_STATE_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1045
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_SHADER_MODEL_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1046
D3D12_MESSAGE_ID_OBJECT_ACCESSED_WHILE_STILL_IN_USE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1047
D3D12_MESSAGE_ID_PROGRAMMABLE_MSAA_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1048
D3D12_MESSAGE_ID_SETSAMPLEPOSITIONS_INVALIDARGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1049
D3D12_MESSAGE_ID_RESOLVESUBRESOURCEREGION_INVALID_RECT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1050
D3D12_MESSAGE_ID_CREATE_VIDEODECODECOMMANDQUEUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1051
D3D12_MESSAGE_ID_CREATE_VIDEOPROCESSCOMMANDLIST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1052
D3D12_MESSAGE_ID_CREATE_VIDEOPROCESSCOMMANDQUEUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1053
D3D12_MESSAGE_ID_LIVE_VIDEODECODECOMMANDQUEUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1054
D3D12_MESSAGE_ID_LIVE_VIDEOPROCESSCOMMANDLIST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1055
D3D12_MESSAGE_ID_LIVE_VIDEOPROCESSCOMMANDQUEUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1056
D3D12_MESSAGE_ID_DESTROY_VIDEODECODECOMMANDQUEUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1057
D3D12_MESSAGE_ID_DESTROY_VIDEOPROCESSCOMMANDLIST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1058
D3D12_MESSAGE_ID_DESTROY_VIDEOPROCESSCOMMANDQUEUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1059
D3D12_MESSAGE_ID_CREATE_VIDEOPROCESSOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1060
D3D12_MESSAGE_ID_CREATE_VIDEOPROCESSSTREAM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1061
D3D12_MESSAGE_ID_LIVE_VIDEOPROCESSOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1062
D3D12_MESSAGE_ID_LIVE_VIDEOPROCESSSTREAM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1063
D3D12_MESSAGE_ID_DESTROY_VIDEOPROCESSOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1064
D3D12_MESSAGE_ID_DESTROY_VIDEOPROCESSSTREAM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1065
D3D12_MESSAGE_ID_PROCESS_FRAME_INVALID_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1066
D3D12_MESSAGE_ID_COPY_INVALIDLAYOUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1067
D3D12_MESSAGE_ID_CREATE_CRYPTO_SESSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1068
D3D12_MESSAGE_ID_CREATE_CRYPTO_SESSION_POLICY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1069
D3D12_MESSAGE_ID_CREATE_PROTECTED_RESOURCE_SESSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1070
D3D12_MESSAGE_ID_LIVE_CRYPTO_SESSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1071
D3D12_MESSAGE_ID_LIVE_CRYPTO_SESSION_POLICY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1072
D3D12_MESSAGE_ID_LIVE_PROTECTED_RESOURCE_SESSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1073
D3D12_MESSAGE_ID_DESTROY_CRYPTO_SESSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1074
D3D12_MESSAGE_ID_DESTROY_CRYPTO_SESSION_POLICY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1075
D3D12_MESSAGE_ID_DESTROY_PROTECTED_RESOURCE_SESSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1076
D3D12_MESSAGE_ID_PROTECTED_RESOURCE_SESSION_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1077
D3D12_MESSAGE_ID_FENCE_INVALIDOPERATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1078
D3D12_MESSAGE_ID_CREATEQUERY_HEAP_COPY_QUEUE_TIMESTAMPS_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1079
D3D12_MESSAGE_ID_SAMPLEPOSITIONS_MISMATCH_DEFERRED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1080
D3D12_MESSAGE_ID_SAMPLEPOSITIONS_MISMATCH_RECORDTIME_ASSUMEDFROMFIRSTUSE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1081
D3D12_MESSAGE_ID_SAMPLEPOSITIONS_MISMATCH_RECORDTIME_ASSUMEDFROMCLEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1082
D3D12_MESSAGE_ID_CREATE_VIDEODECODERHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1083
D3D12_MESSAGE_ID_LIVE_VIDEODECODERHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1084
D3D12_MESSAGE_ID_DESTROY_VIDEODECODERHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1085
D3D12_MESSAGE_ID_OPENEXISTINGHEAP_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1086
D3D12_MESSAGE_ID_OPENEXISTINGHEAP_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1087
D3D12_MESSAGE_ID_OPENEXISTINGHEAP_INVALIDADDRESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1088
D3D12_MESSAGE_ID_OPENEXISTINGHEAP_INVALIDHANDLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1089
D3D12_MESSAGE_ID_WRITEBUFFERIMMEDIATE_INVALID_DEST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1090
D3D12_MESSAGE_ID_WRITEBUFFERIMMEDIATE_INVALID_MODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1091
D3D12_MESSAGE_ID_WRITEBUFFERIMMEDIATE_INVALID_ALIGNMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1092
D3D12_MESSAGE_ID_WRITEBUFFERIMMEDIATE_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1093
D3D12_MESSAGE_ID_SETVIEWINSTANCEMASK_INVALIDARGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1094
D3D12_MESSAGE_ID_VIEW_INSTANCING_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1095
D3D12_MESSAGE_ID_VIEW_INSTANCING_INVALIDARGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1096
D3D12_MESSAGE_ID_COPYTEXTUREREGION_MISMATCH_DECODE_REFERENCE_ONLY_FLAG: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1097
D3D12_MESSAGE_ID_COPYRESOURCE_MISMATCH_DECODE_REFERENCE_ONLY_FLAG: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1098
D3D12_MESSAGE_ID_CREATE_VIDEO_DECODE_HEAP_CAPS_FAILURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1099
D3D12_MESSAGE_ID_CREATE_VIDEO_DECODE_HEAP_CAPS_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1100
D3D12_MESSAGE_ID_VIDEO_DECODE_SUPPORT_INVALID_INPUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1101
D3D12_MESSAGE_ID_CREATE_VIDEO_DECODER_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1102
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_METADATA_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1103
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_VIEW_INSTANCING_VERTEX_SIZE_EXCEEDED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1104
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_RUNTIME_INTERNAL_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1105
D3D12_MESSAGE_ID_NO_VIDEO_API_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1106
D3D12_MESSAGE_ID_VIDEO_PROCESS_SUPPORT_INVALID_INPUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1107
D3D12_MESSAGE_ID_CREATE_VIDEO_PROCESSOR_CAPS_FAILURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1108
D3D12_MESSAGE_ID_VIDEO_PROCESS_SUPPORT_UNSUPPORTED_FORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1109
D3D12_MESSAGE_ID_VIDEO_DECODE_FRAME_INVALID_ARGUMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1110
D3D12_MESSAGE_ID_ENQUEUE_MAKE_RESIDENT_INVALID_FLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1111
D3D12_MESSAGE_ID_OPENEXISTINGHEAP_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1112
D3D12_MESSAGE_ID_VIDEO_PROCESS_FRAMES_INVALID_ARGUMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1113
D3D12_MESSAGE_ID_VIDEO_DECODE_SUPPORT_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1114
D3D12_MESSAGE_ID_CREATE_COMMANDRECORDER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1115
D3D12_MESSAGE_ID_LIVE_COMMANDRECORDER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1116
D3D12_MESSAGE_ID_DESTROY_COMMANDRECORDER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1117
D3D12_MESSAGE_ID_CREATE_COMMAND_RECORDER_VIDEO_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1118
D3D12_MESSAGE_ID_CREATE_COMMAND_RECORDER_INVALID_SUPPORT_FLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1119
D3D12_MESSAGE_ID_CREATE_COMMAND_RECORDER_INVALID_FLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1120
D3D12_MESSAGE_ID_CREATE_COMMAND_RECORDER_MORE_RECORDERS_THAN_LOGICAL_PROCESSORS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1121
D3D12_MESSAGE_ID_CREATE_COMMANDPOOL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1122
D3D12_MESSAGE_ID_LIVE_COMMANDPOOL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1123
D3D12_MESSAGE_ID_DESTROY_COMMANDPOOL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1124
D3D12_MESSAGE_ID_CREATE_COMMAND_POOL_INVALID_FLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1125
D3D12_MESSAGE_ID_CREATE_COMMAND_LIST_VIDEO_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1126
D3D12_MESSAGE_ID_COMMAND_RECORDER_SUPPORT_FLAGS_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1127
D3D12_MESSAGE_ID_COMMAND_RECORDER_CONTENTION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1128
D3D12_MESSAGE_ID_COMMAND_RECORDER_USAGE_WITH_CREATECOMMANDLIST_COMMAND_LIST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1129
D3D12_MESSAGE_ID_COMMAND_ALLOCATOR_USAGE_WITH_CREATECOMMANDLIST1_COMMAND_LIST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1130
D3D12_MESSAGE_ID_CANNOT_EXECUTE_EMPTY_COMMAND_LIST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1131
D3D12_MESSAGE_ID_CANNOT_RESET_COMMAND_POOL_WITH_OPEN_COMMAND_LISTS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1132
D3D12_MESSAGE_ID_CANNOT_USE_COMMAND_RECORDER_WITHOUT_CURRENT_TARGET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1133
D3D12_MESSAGE_ID_CANNOT_CHANGE_COMMAND_RECORDER_TARGET_WHILE_RECORDING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1134
D3D12_MESSAGE_ID_COMMAND_POOL_SYNC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1135
D3D12_MESSAGE_ID_EVICT_UNDERFLOW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1136
D3D12_MESSAGE_ID_CREATE_META_COMMAND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1137
D3D12_MESSAGE_ID_LIVE_META_COMMAND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1138
D3D12_MESSAGE_ID_DESTROY_META_COMMAND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1139
D3D12_MESSAGE_ID_COPYBUFFERREGION_INVALID_DST_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1140
D3D12_MESSAGE_ID_COPYBUFFERREGION_INVALID_SRC_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1141
D3D12_MESSAGE_ID_ATOMICCOPYBUFFER_INVALID_DST_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1142
D3D12_MESSAGE_ID_ATOMICCOPYBUFFER_INVALID_SRC_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1143
D3D12_MESSAGE_ID_CREATEPLACEDRESOURCEONBUFFER_NULL_BUFFER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1144
D3D12_MESSAGE_ID_CREATEPLACEDRESOURCEONBUFFER_NULL_RESOURCE_DESC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1145
D3D12_MESSAGE_ID_CREATEPLACEDRESOURCEONBUFFER_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1146
D3D12_MESSAGE_ID_CREATEPLACEDRESOURCEONBUFFER_INVALID_BUFFER_DIMENSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1147
D3D12_MESSAGE_ID_CREATEPLACEDRESOURCEONBUFFER_INVALID_BUFFER_FLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1148
D3D12_MESSAGE_ID_CREATEPLACEDRESOURCEONBUFFER_INVALID_BUFFER_OFFSET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1149
D3D12_MESSAGE_ID_CREATEPLACEDRESOURCEONBUFFER_INVALID_RESOURCE_DIMENSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1150
D3D12_MESSAGE_ID_CREATEPLACEDRESOURCEONBUFFER_INVALID_RESOURCE_FLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1151
D3D12_MESSAGE_ID_CREATEPLACEDRESOURCEONBUFFER_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1152
D3D12_MESSAGE_ID_CANNOT_CREATE_GRAPHICS_AND_VIDEO_COMMAND_RECORDER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1153
D3D12_MESSAGE_ID_UPDATETILEMAPPINGS_POSSIBLY_MISMATCHING_PROPERTIES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1154
D3D12_MESSAGE_ID_CREATE_COMMAND_LIST_INVALID_COMMAND_LIST_TYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1155
D3D12_MESSAGE_ID_CLEARUNORDEREDACCESSVIEW_INCOMPATIBLE_WITH_STRUCTURED_BUFFERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1156
D3D12_MESSAGE_ID_COMPUTE_ONLY_DEVICE_OPERATION_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1157
D3D12_MESSAGE_ID_BUILD_RAYTRACING_ACCELERATION_STRUCTURE_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1158
D3D12_MESSAGE_ID_EMIT_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1159
D3D12_MESSAGE_ID_COPY_RAYTRACING_ACCELERATION_STRUCTURE_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1160
D3D12_MESSAGE_ID_DISPATCH_RAYS_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1161
D3D12_MESSAGE_ID_GET_RAYTRACING_ACCELERATION_STRUCTURE_PREBUILD_INFO_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1162
D3D12_MESSAGE_ID_CREATE_LIFETIMETRACKER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1163
D3D12_MESSAGE_ID_LIVE_LIFETIMETRACKER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1164
D3D12_MESSAGE_ID_DESTROY_LIFETIMETRACKER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1165
D3D12_MESSAGE_ID_DESTROYOWNEDOBJECT_OBJECTNOTOWNED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1166
D3D12_MESSAGE_ID_CREATE_TRACKEDWORKLOAD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1167
D3D12_MESSAGE_ID_LIVE_TRACKEDWORKLOAD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1168
D3D12_MESSAGE_ID_DESTROY_TRACKEDWORKLOAD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1169
D3D12_MESSAGE_ID_RENDER_PASS_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1170
D3D12_MESSAGE_ID_META_COMMAND_ID_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1171
D3D12_MESSAGE_ID_META_COMMAND_UNSUPPORTED_PARAMS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1172
D3D12_MESSAGE_ID_META_COMMAND_FAILED_ENUMERATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1173
D3D12_MESSAGE_ID_META_COMMAND_PARAMETER_SIZE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1174
D3D12_MESSAGE_ID_UNINITIALIZED_META_COMMAND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1175
D3D12_MESSAGE_ID_META_COMMAND_INVALID_GPU_VIRTUAL_ADDRESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1176
D3D12_MESSAGE_ID_CREATE_VIDEOENCODECOMMANDLIST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1177
D3D12_MESSAGE_ID_LIVE_VIDEOENCODECOMMANDLIST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1178
D3D12_MESSAGE_ID_DESTROY_VIDEOENCODECOMMANDLIST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1179
D3D12_MESSAGE_ID_CREATE_VIDEOENCODECOMMANDQUEUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1180
D3D12_MESSAGE_ID_LIVE_VIDEOENCODECOMMANDQUEUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1181
D3D12_MESSAGE_ID_DESTROY_VIDEOENCODECOMMANDQUEUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1182
D3D12_MESSAGE_ID_CREATE_VIDEOMOTIONESTIMATOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1183
D3D12_MESSAGE_ID_LIVE_VIDEOMOTIONESTIMATOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1184
D3D12_MESSAGE_ID_DESTROY_VIDEOMOTIONESTIMATOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1185
D3D12_MESSAGE_ID_CREATE_VIDEOMOTIONVECTORHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1186
D3D12_MESSAGE_ID_LIVE_VIDEOMOTIONVECTORHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1187
D3D12_MESSAGE_ID_DESTROY_VIDEOMOTIONVECTORHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1188
D3D12_MESSAGE_ID_MULTIPLE_TRACKED_WORKLOADS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1189
D3D12_MESSAGE_ID_MULTIPLE_TRACKED_WORKLOAD_PAIRS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1190
D3D12_MESSAGE_ID_OUT_OF_ORDER_TRACKED_WORKLOAD_PAIR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1191
D3D12_MESSAGE_ID_CANNOT_ADD_TRACKED_WORKLOAD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1192
D3D12_MESSAGE_ID_INCOMPLETE_TRACKED_WORKLOAD_PAIR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1193
D3D12_MESSAGE_ID_CREATE_STATE_OBJECT_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1194
D3D12_MESSAGE_ID_GET_SHADER_IDENTIFIER_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1195
D3D12_MESSAGE_ID_GET_SHADER_STACK_SIZE_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1196
D3D12_MESSAGE_ID_GET_PIPELINE_STACK_SIZE_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1197
D3D12_MESSAGE_ID_SET_PIPELINE_STACK_SIZE_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1198
D3D12_MESSAGE_ID_GET_SHADER_IDENTIFIER_SIZE_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1199
D3D12_MESSAGE_ID_CHECK_DRIVER_MATCHING_IDENTIFIER_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1200
D3D12_MESSAGE_ID_CHECK_DRIVER_MATCHING_IDENTIFIER_DRIVER_REPORTED_ISSUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1201
D3D12_MESSAGE_ID_RENDER_PASS_INVALID_RESOURCE_BARRIER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1202
D3D12_MESSAGE_ID_RENDER_PASS_DISALLOWED_API_CALLED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1203
D3D12_MESSAGE_ID_RENDER_PASS_CANNOT_NEST_RENDER_PASSES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1204
D3D12_MESSAGE_ID_RENDER_PASS_CANNOT_END_WITHOUT_BEGIN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1205
D3D12_MESSAGE_ID_RENDER_PASS_CANNOT_CLOSE_COMMAND_LIST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1206
D3D12_MESSAGE_ID_RENDER_PASS_GPU_WORK_WHILE_SUSPENDED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1207
D3D12_MESSAGE_ID_RENDER_PASS_MISMATCHING_SUSPEND_RESUME: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1208
D3D12_MESSAGE_ID_RENDER_PASS_NO_PRIOR_SUSPEND_WITHIN_EXECUTECOMMANDLISTS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1209
D3D12_MESSAGE_ID_RENDER_PASS_NO_SUBSEQUENT_RESUME_WITHIN_EXECUTECOMMANDLISTS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1210
D3D12_MESSAGE_ID_TRACKED_WORKLOAD_COMMAND_QUEUE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1211
D3D12_MESSAGE_ID_TRACKED_WORKLOAD_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1212
D3D12_MESSAGE_ID_RENDER_PASS_MISMATCHING_NO_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1213
D3D12_MESSAGE_ID_RENDER_PASS_UNSUPPORTED_RESOLVE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1214
D3D12_MESSAGE_ID_CLEARUNORDEREDACCESSVIEW_INVALID_RESOURCE_PTR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1215
D3D12_MESSAGE_ID_WINDOWS7_FENCE_OUTOFORDER_SIGNAL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1216
D3D12_MESSAGE_ID_WINDOWS7_FENCE_OUTOFORDER_WAIT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1217
D3D12_MESSAGE_ID_VIDEO_CREATE_MOTION_ESTIMATOR_INVALID_ARGUMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1218
D3D12_MESSAGE_ID_VIDEO_CREATE_MOTION_VECTOR_HEAP_INVALID_ARGUMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1219
D3D12_MESSAGE_ID_ESTIMATE_MOTION_INVALID_ARGUMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1220
D3D12_MESSAGE_ID_RESOLVE_MOTION_VECTOR_HEAP_INVALID_ARGUMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1221
D3D12_MESSAGE_ID_GETGPUVIRTUALADDRESS_INVALID_HEAP_TYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1222
D3D12_MESSAGE_ID_SET_BACKGROUND_PROCESSING_MODE_INVALID_ARGUMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1223
D3D12_MESSAGE_ID_CREATE_COMMAND_LIST_INVALID_COMMAND_LIST_TYPE_FOR_FEATURE_LEVEL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1224
D3D12_MESSAGE_ID_CREATE_VIDEOEXTENSIONCOMMAND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1225
D3D12_MESSAGE_ID_LIVE_VIDEOEXTENSIONCOMMAND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1226
D3D12_MESSAGE_ID_DESTROY_VIDEOEXTENSIONCOMMAND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1227
D3D12_MESSAGE_ID_INVALID_VIDEO_EXTENSION_COMMAND_ID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1228
D3D12_MESSAGE_ID_VIDEO_EXTENSION_COMMAND_INVALID_ARGUMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1229
D3D12_MESSAGE_ID_CREATE_ROOT_SIGNATURE_NOT_UNIQUE_IN_DXIL_LIBRARY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1230
D3D12_MESSAGE_ID_VARIABLE_SHADING_RATE_NOT_ALLOWED_WITH_TIR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1231
D3D12_MESSAGE_ID_GEOMETRY_SHADER_OUTPUTTING_BOTH_VIEWPORT_ARRAY_INDEX_AND_SHADING_RATE_NOT_SUPPORTED_ON_DEVICE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1232
D3D12_MESSAGE_ID_RSSETSHADING_RATE_INVALID_SHADING_RATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1233
D3D12_MESSAGE_ID_RSSETSHADING_RATE_SHADING_RATE_NOT_PERMITTED_BY_CAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1234
D3D12_MESSAGE_ID_RSSETSHADING_RATE_INVALID_COMBINER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1235
D3D12_MESSAGE_ID_RSSETSHADINGRATEIMAGE_REQUIRES_TIER_2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1236
D3D12_MESSAGE_ID_RSSETSHADINGRATE_REQUIRES_TIER_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1237
D3D12_MESSAGE_ID_SHADING_RATE_IMAGE_INCORRECT_FORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1238
D3D12_MESSAGE_ID_SHADING_RATE_IMAGE_INCORRECT_ARRAY_SIZE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1239
D3D12_MESSAGE_ID_SHADING_RATE_IMAGE_INCORRECT_MIP_LEVEL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1240
D3D12_MESSAGE_ID_SHADING_RATE_IMAGE_INCORRECT_SAMPLE_COUNT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1241
D3D12_MESSAGE_ID_SHADING_RATE_IMAGE_INCORRECT_SAMPLE_QUALITY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1242
D3D12_MESSAGE_ID_NON_RETAIL_SHADER_MODEL_WONT_VALIDATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1243
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_AS_ROOT_SIGNATURE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1244
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_MS_ROOT_SIGNATURE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1245
D3D12_MESSAGE_ID_ADD_TO_STATE_OBJECT_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1246
D3D12_MESSAGE_ID_CREATE_PROTECTED_RESOURCE_SESSION_INVALID_ARGUMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1247
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_MS_PSO_DESC_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1248
D3D12_MESSAGE_ID_CREATEPIPELINESTATE_MS_INCOMPLETE_TYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1249
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_AS_NOT_MS_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1250
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_MS_NOT_PS_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1251
D3D12_MESSAGE_ID_NONZERO_SAMPLER_FEEDBACK_MIP_REGION_WITH_INCOMPATIBLE_FORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1252
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_INPUTLAYOUT_SHADER_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1253
D3D12_MESSAGE_ID_EMPTY_DISPATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1254
D3D12_MESSAGE_ID_RESOURCE_FORMAT_REQUIRES_SAMPLER_FEEDBACK_CAPABILITY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1255
D3D12_MESSAGE_ID_SAMPLER_FEEDBACK_MAP_INVALID_MIP_REGION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1256
D3D12_MESSAGE_ID_SAMPLER_FEEDBACK_MAP_INVALID_DIMENSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1257
D3D12_MESSAGE_ID_SAMPLER_FEEDBACK_MAP_INVALID_SAMPLE_COUNT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1258
D3D12_MESSAGE_ID_SAMPLER_FEEDBACK_MAP_INVALID_SAMPLE_QUALITY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1259
D3D12_MESSAGE_ID_SAMPLER_FEEDBACK_MAP_INVALID_LAYOUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1260
D3D12_MESSAGE_ID_SAMPLER_FEEDBACK_MAP_REQUIRES_UNORDERED_ACCESS_FLAG: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1261
D3D12_MESSAGE_ID_SAMPLER_FEEDBACK_CREATE_UAV_NULL_ARGUMENTS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1262
D3D12_MESSAGE_ID_SAMPLER_FEEDBACK_UAV_REQUIRES_SAMPLER_FEEDBACK_CAPABILITY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1263
D3D12_MESSAGE_ID_SAMPLER_FEEDBACK_CREATE_UAV_REQUIRES_FEEDBACK_MAP_FORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1264
D3D12_MESSAGE_ID_CREATEMESHSHADER_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1265
D3D12_MESSAGE_ID_CREATEMESHSHADER_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1266
D3D12_MESSAGE_ID_CREATEMESHSHADERWITHSTREAMOUTPUT_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1267
D3D12_MESSAGE_ID_RESOLVESUBRESOURCE_SAMPLER_FEEDBACK_TRANSCODE_INVALID_FORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1268
D3D12_MESSAGE_ID_RESOLVESUBRESOURCE_SAMPLER_FEEDBACK_INVALID_MIP_LEVEL_COUNT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1269
D3D12_MESSAGE_ID_RESOLVESUBRESOURCE_SAMPLER_FEEDBACK_TRANSCODE_ARRAY_SIZE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1270
D3D12_MESSAGE_ID_SAMPLER_FEEDBACK_CREATE_UAV_MISMATCHING_TARGETED_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1271
D3D12_MESSAGE_ID_CREATEMESHSHADER_OUTPUTEXCEEDSMAXSIZE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1272
D3D12_MESSAGE_ID_CREATEMESHSHADER_GROUPSHAREDEXCEEDSMAXSIZE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1273
D3D12_MESSAGE_ID_VERTEX_SHADER_OUTPUTTING_BOTH_VIEWPORT_ARRAY_INDEX_AND_SHADING_RATE_NOT_SUPPORTED_ON_DEVICE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1274
D3D12_MESSAGE_ID_MESH_SHADER_OUTPUTTING_BOTH_VIEWPORT_ARRAY_INDEX_AND_SHADING_RATE_NOT_SUPPORTED_ON_DEVICE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1275
D3D12_MESSAGE_ID_CREATEMESHSHADER_MISMATCHEDASMSPAYLOADSIZE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1276
D3D12_MESSAGE_ID_CREATE_ROOT_SIGNATURE_UNBOUNDED_STATIC_DESCRIPTORS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1277
D3D12_MESSAGE_ID_CREATEAMPLIFICATIONSHADER_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1278
D3D12_MESSAGE_ID_CREATEAMPLIFICATIONSHADER_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1279
D3D12_MESSAGE_ID_CREATE_SHADERCACHESESSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1280
D3D12_MESSAGE_ID_LIVE_SHADERCACHESESSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1281
D3D12_MESSAGE_ID_DESTROY_SHADERCACHESESSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1282
D3D12_MESSAGE_ID_CREATESHADERCACHESESSION_INVALIDARGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1283
D3D12_MESSAGE_ID_CREATESHADERCACHESESSION_DISABLED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1284
D3D12_MESSAGE_ID_CREATESHADERCACHESESSION_ALREADYOPEN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1285
D3D12_MESSAGE_ID_SHADERCACHECONTROL_DEVELOPERMODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1286
D3D12_MESSAGE_ID_SHADERCACHECONTROL_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1287
D3D12_MESSAGE_ID_SHADERCACHECONTROL_STATEALREADYSET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1288
D3D12_MESSAGE_ID_SHADERCACHECONTROL_IGNOREDFLAG: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1289
D3D12_MESSAGE_ID_SHADERCACHESESSION_STOREVALUE_ALREADYPRESENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1290
D3D12_MESSAGE_ID_SHADERCACHESESSION_STOREVALUE_HASHCOLLISION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1291
D3D12_MESSAGE_ID_SHADERCACHESESSION_STOREVALUE_CACHEFULL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1292
D3D12_MESSAGE_ID_SHADERCACHESESSION_FINDVALUE_NOTFOUND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1293
D3D12_MESSAGE_ID_SHADERCACHESESSION_CORRUPT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1294
D3D12_MESSAGE_ID_SHADERCACHESESSION_DISABLED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1295
D3D12_MESSAGE_ID_OVERSIZED_DISPATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1296
D3D12_MESSAGE_ID_CREATE_VIDEOENCODER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1297
D3D12_MESSAGE_ID_LIVE_VIDEOENCODER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1298
D3D12_MESSAGE_ID_DESTROY_VIDEOENCODER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1299
D3D12_MESSAGE_ID_CREATE_VIDEOENCODERHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1300
D3D12_MESSAGE_ID_LIVE_VIDEOENCODERHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1301
D3D12_MESSAGE_ID_DESTROY_VIDEOENCODERHEAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1302
D3D12_MESSAGE_ID_COPYTEXTUREREGION_MISMATCH_ENCODE_REFERENCE_ONLY_FLAG: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1303
D3D12_MESSAGE_ID_COPYRESOURCE_MISMATCH_ENCODE_REFERENCE_ONLY_FLAG: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1304
D3D12_MESSAGE_ID_ENCODE_FRAME_INVALID_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1305
D3D12_MESSAGE_ID_ENCODE_FRAME_UNSUPPORTED_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1306
D3D12_MESSAGE_ID_RESOLVE_ENCODER_OUTPUT_METADATA_INVALID_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1307
D3D12_MESSAGE_ID_RESOLVE_ENCODER_OUTPUT_METADATA_UNSUPPORTED_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1308
D3D12_MESSAGE_ID_CREATE_VIDEO_ENCODER_INVALID_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1309
D3D12_MESSAGE_ID_CREATE_VIDEO_ENCODER_UNSUPPORTED_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1310
D3D12_MESSAGE_ID_CREATE_VIDEO_ENCODER_HEAP_INVALID_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1311
D3D12_MESSAGE_ID_CREATE_VIDEO_ENCODER_HEAP_UNSUPPORTED_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1312
D3D12_MESSAGE_ID_CREATECOMMANDLIST_NULL_COMMANDALLOCATOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1313
D3D12_MESSAGE_ID_CLEAR_UNORDERED_ACCESS_VIEW_INVALID_DESCRIPTOR_HANDLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1314
D3D12_MESSAGE_ID_DESCRIPTOR_HEAP_NOT_SHADER_VISIBLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1315
D3D12_MESSAGE_ID_CREATEBLENDSTATE_BLENDOP_WARNING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1316
D3D12_MESSAGE_ID_CREATEBLENDSTATE_BLENDOPALPHA_WARNING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1317
D3D12_MESSAGE_ID_WRITE_COMBINE_PERFORMANCE_WARNING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1318
D3D12_MESSAGE_ID_RESOLVE_QUERY_INVALID_QUERY_STATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1319
D3D12_MESSAGE_ID_SETPRIVATEDATA_NO_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1320
D3D12_MESSAGE_ID_COMMAND_LIST_STATIC_DESCRIPTOR_SAMPLER_MODE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1321
D3D12_MESSAGE_ID_GETCOPYABLEFOOTPRINTS_UNSUPPORTED_BUFFER_WIDTH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1322
D3D12_MESSAGE_ID_CREATEMESHSHADER_TOPOLOGY_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1323
D3D12_MESSAGE_ID_VRS_SUM_COMBINER_REQUIRES_CAPABILITY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1324
D3D12_MESSAGE_ID_SETTING_SHADING_RATE_FROM_MS_REQUIRES_CAPABILITY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1325
D3D12_MESSAGE_ID_SHADERCACHESESSION_SHADERCACHEDELETE_NOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1326
D3D12_MESSAGE_ID_SHADERCACHECONTROL_SHADERCACHECLEAR_NOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1327
D3D12_MESSAGE_ID_CREATERESOURCE_STATE_IGNORED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1328
D3D12_MESSAGE_ID_UNUSED_CROSS_EXECUTE_SPLIT_BARRIER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1329
D3D12_MESSAGE_ID_DEVICE_OPEN_SHARED_HANDLE_ACCESS_DENIED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1330
D3D12_MESSAGE_ID_INCOMPATIBLE_BARRIER_VALUES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1331
D3D12_MESSAGE_ID_INCOMPATIBLE_BARRIER_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1332
D3D12_MESSAGE_ID_INCOMPATIBLE_BARRIER_SYNC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1333
D3D12_MESSAGE_ID_INCOMPATIBLE_BARRIER_LAYOUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1334
D3D12_MESSAGE_ID_INCOMPATIBLE_BARRIER_TYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1335
D3D12_MESSAGE_ID_OUT_OF_BOUNDS_BARRIER_SUBRESOURCE_RANGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1336
D3D12_MESSAGE_ID_INCOMPATIBLE_BARRIER_RESOURCE_DIMENSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1337
D3D12_MESSAGE_ID_SET_SCISSOR_RECTS_INVALID_RECT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1338
D3D12_MESSAGE_ID_SHADING_RATE_SOURCE_REQUIRES_DIMENSION_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1339
D3D12_MESSAGE_ID_BUFFER_BARRIER_SUBREGION_OUT_OF_BOUNDS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1340
D3D12_MESSAGE_ID_UNSUPPORTED_BARRIER_LAYOUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1341
D3D12_MESSAGE_ID_CREATERESOURCEANDHEAP_INVALID_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1342
D3D12_MESSAGE_ID_ENHANCED_BARRIERS_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1343
D3D12_MESSAGE_ID_LEGACY_BARRIER_VALIDATION_FORCED_ON: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1346
D3D12_MESSAGE_ID_EMPTY_ROOT_DESCRIPTOR_TABLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1347
D3D12_MESSAGE_ID_COMMAND_LIST_DRAW_ELEMENT_OFFSET_UNALIGNED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1348
D3D12_MESSAGE_ID_ALPHA_BLEND_FACTOR_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1349
D3D12_MESSAGE_ID_BARRIER_INTEROP_INVALID_LAYOUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1350
D3D12_MESSAGE_ID_BARRIER_INTEROP_INVALID_STATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1351
D3D12_MESSAGE_ID_GRAPHICS_PIPELINE_STATE_DESC_ZERO_SAMPLE_MASK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1352
D3D12_MESSAGE_ID_INDEPENDENT_STENCIL_REF_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1353
D3D12_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INDEPENDENT_MASKS_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1354
D3D12_MESSAGE_ID_TEXTURE_BARRIER_SUBRESOURCES_OUT_OF_BOUNDS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1355
D3D12_MESSAGE_ID_NON_OPTIMAL_BARRIER_ONLY_EXECUTE_COMMAND_LISTS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1356
D3D12_MESSAGE_ID_EXECUTE_INDIRECT_ZERO_COMMAND_COUNT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1357
D3D12_MESSAGE_ID_GPU_BASED_VALIDATION_INCOMPATIBLE_TEXTURE_LAYOUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1358
D3D12_MESSAGE_ID_DYNAMIC_INDEX_BUFFER_STRIP_CUT_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1359
D3D12_MESSAGE_ID_PRIMITIVE_TOPOLOGY_TRIANGLE_FANS_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1360
D3D12_MESSAGE_ID_CREATE_SAMPLER_COMPARISON_FUNC_IGNORED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1361
D3D12_MESSAGE_ID_CREATEHEAP_INVALIDHEAPTYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1362
D3D12_MESSAGE_ID_CREATERESOURCEANDHEAP_INVALIDHEAPTYPE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1363
D3D12_MESSAGE_ID_DYNAMIC_DEPTH_BIAS_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1364
D3D12_MESSAGE_ID_CREATERASTERIZERSTATE_NON_WHOLE_DYNAMIC_DEPTH_BIAS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1365
D3D12_MESSAGE_ID_DYNAMIC_DEPTH_BIAS_FLAG_MISSING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1366
D3D12_MESSAGE_ID_DYNAMIC_DEPTH_BIAS_NO_PIPELINE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1367
D3D12_MESSAGE_ID_DYNAMIC_INDEX_BUFFER_STRIP_CUT_FLAG_MISSING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1368
D3D12_MESSAGE_ID_DYNAMIC_INDEX_BUFFER_STRIP_CUT_NO_PIPELINE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1369
D3D12_MESSAGE_ID_NONNORMALIZED_COORDINATE_SAMPLING_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1370
D3D12_MESSAGE_ID_INVALID_CAST_TARGET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1371
D3D12_MESSAGE_ID_RENDER_PASS_COMMANDLIST_INVALID_END_STATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1372
D3D12_MESSAGE_ID_RENDER_PASS_COMMANDLIST_INVALID_START_STATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1373
D3D12_MESSAGE_ID_RENDER_PASS_MISMATCHING_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1374
D3D12_MESSAGE_ID_RENDER_PASS_MISMATCHING_LOCAL_PRESERVE_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1375
D3D12_MESSAGE_ID_RENDER_PASS_LOCAL_PRESERVE_RENDER_PARAMETERS_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1376
D3D12_MESSAGE_ID_RENDER_PASS_LOCAL_DEPTH_STENCIL_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1377
D3D12_MESSAGE_ID_DRAW_POTENTIALLY_OUTSIDE_OF_VALID_RENDER_AREA: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1378
D3D12_MESSAGE_ID_CREATERASTERIZERSTATE_INVALID_LINERASTERIZATIONMODE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1379
D3D12_MESSAGE_ID_CREATERESOURCE_INVALIDALIGNMENT_SMALLRESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1380
D3D12_MESSAGE_ID_GENERIC_DEVICE_OPERATION_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1381
D3D12_MESSAGE_ID_CREATEGRAPHICSPIPELINESTATE_RENDER_TARGET_WRONG_WRITE_MASK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1382
D3D12_MESSAGE_ID_PROBABLE_PIX_EVENT_LEAK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1383
D3D12_MESSAGE_ID_PIX_EVENT_UNDERFLOW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1384
D3D12_MESSAGE_ID_RECREATEAT_INVALID_TARGET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1385
D3D12_MESSAGE_ID_RECREATEAT_INSUFFICIENT_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1386
D3D12_MESSAGE_ID_GPU_BASED_VALIDATION_STRUCTURED_BUFFER_STRIDE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1387
D3D12_MESSAGE_ID_DISPATCH_GRAPH_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1388
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_TARGET_FORMAT_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1389
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_TARGET_DIMENSION_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1390
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_SOURCE_COLOR_FORMAT_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1391
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_SOURCE_DEPTH_FORMAT_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1392
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_EXPOSURE_SCALE_FORMAT_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1393
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_ENGINE_CREATE_FLAGS_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1394
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_EXTENSION_INTERNAL_LOAD_FAILURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1395
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_EXTENSION_INTERNAL_ENGINE_CREATION_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1396
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_EXTENSION_INTERNAL_UPSCALER_CREATION_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1397
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_EXTENSION_INTERNAL_UPSCALER_EXECUTION_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1398
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_UPSCALER_EXECUTE_REGION_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1399
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_UPSCALER_EXECUTE_TIME_DELTA_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1400
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_UPSCALER_EXECUTE_REQUIRED_TEXTURE_IS_NULL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1401
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_UPSCALER_EXECUTE_MOTION_VECTORS_FORMAT_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1402
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_UPSCALER_EXECUTE_FLAGS_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1403
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_UPSCALER_EXECUTE_FORMAT_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1404
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_UPSCALER_EXECUTE_EXPOSURE_SCALE_TEXTURE_SIZE_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1405
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_VARIANT_INDEX_OUT_OF_BOUNDS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1406
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_VARIANT_ID_NOT_FOUND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1407
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_DUPLICATE_VARIANT_ID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1408
D3D12_MESSAGE_ID_DIRECTSR_OUT_OF_MEMORY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1409
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_UPSCALER_EXECUTE_UNEXPECTED_TEXTURE_IS_IGNORED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1410
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_UPSCALER_EVICT_UNDERFLOW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1411
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_UPSCALER_EXECUTE_OPTIONAL_TEXTURE_IS_NULL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1412
D3D12_MESSAGE_ID_DIRECTSR_SUPERRES_UPSCALER_EXECUTE_INVALID_CAMERA_JITTER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1413
D3D12_MESSAGE_ID_CREATE_STATE_OBJECT_WARNING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1414
D3D12_MESSAGE_ID_GUID_TEXTURE_LAYOUT_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1415
D3D12_MESSAGE_ID_RESOLVE_ENCODER_INPUT_PARAM_LAYOUT_INVALID_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1416
D3D12_MESSAGE_ID_INVALID_BARRIER_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1417
D3D12_MESSAGE_ID_COMMAND_LIST_DRAW_INSTANCE_COUNT_ZERO: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1418
D3D12_MESSAGE_ID_DESCRIPTOR_HEAP_NOT_SET_BEFORE_ROOT_SIGNATURE_WITH_DIRECTLY_INDEXED_FLAG: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1419
D3D12_MESSAGE_ID_DIFFERENT_DESCRIPTOR_HEAP_SET_AFTER_ROOT_SIGNATURE_WITH_DIRECTLY_INDEXED_FLAG: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1420
D3D12_MESSAGE_ID_D3D12_MESSAGES_END: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID = 1421
D3D12_MESSAGE_SEVERITY = Int32
D3D12_MESSAGE_SEVERITY_CORRUPTION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_SEVERITY = 0
D3D12_MESSAGE_SEVERITY_ERROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_SEVERITY = 1
D3D12_MESSAGE_SEVERITY_WARNING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_SEVERITY = 2
D3D12_MESSAGE_SEVERITY_INFO: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_SEVERITY = 3
D3D12_MESSAGE_SEVERITY_MESSAGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_SEVERITY = 4
class D3D12_META_COMMAND_DESC(Structure):
    Id: Guid
    Name: win32more.Windows.Win32.Foundation.PWSTR
    InitializationDirtyState: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES
    ExecutionDirtyState: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_STATES
class D3D12_META_COMMAND_PARAMETER_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PWSTR
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_META_COMMAND_PARAMETER_TYPE
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_META_COMMAND_PARAMETER_FLAGS
    RequiredResourceState: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES
    StructureOffset: UInt32
D3D12_META_COMMAND_PARAMETER_FLAGS = Int32
D3D12_META_COMMAND_PARAMETER_FLAG_INPUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_META_COMMAND_PARAMETER_FLAGS = 1
D3D12_META_COMMAND_PARAMETER_FLAG_OUTPUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_META_COMMAND_PARAMETER_FLAGS = 2
D3D12_META_COMMAND_PARAMETER_STAGE = Int32
D3D12_META_COMMAND_PARAMETER_STAGE_CREATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_META_COMMAND_PARAMETER_STAGE = 0
D3D12_META_COMMAND_PARAMETER_STAGE_INITIALIZATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_META_COMMAND_PARAMETER_STAGE = 1
D3D12_META_COMMAND_PARAMETER_STAGE_EXECUTION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_META_COMMAND_PARAMETER_STAGE = 2
D3D12_META_COMMAND_PARAMETER_TYPE = Int32
D3D12_META_COMMAND_PARAMETER_TYPE_FLOAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_META_COMMAND_PARAMETER_TYPE = 0
D3D12_META_COMMAND_PARAMETER_TYPE_UINT64: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_META_COMMAND_PARAMETER_TYPE = 1
D3D12_META_COMMAND_PARAMETER_TYPE_GPU_VIRTUAL_ADDRESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_META_COMMAND_PARAMETER_TYPE = 2
D3D12_META_COMMAND_PARAMETER_TYPE_CPU_DESCRIPTOR_HANDLE_HEAP_TYPE_CBV_SRV_UAV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_META_COMMAND_PARAMETER_TYPE = 3
D3D12_META_COMMAND_PARAMETER_TYPE_GPU_DESCRIPTOR_HANDLE_HEAP_TYPE_CBV_SRV_UAV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_META_COMMAND_PARAMETER_TYPE = 4
class D3D12_MIP_REGION(Structure):
    Width: UInt32
    Height: UInt32
    Depth: UInt32
D3D12_MULTIPLE_FENCE_WAIT_FLAGS = Int32
D3D12_MULTIPLE_FENCE_WAIT_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MULTIPLE_FENCE_WAIT_FLAGS = 0
D3D12_MULTIPLE_FENCE_WAIT_FLAG_ANY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MULTIPLE_FENCE_WAIT_FLAGS = 1
D3D12_MULTIPLE_FENCE_WAIT_FLAG_ALL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MULTIPLE_FENCE_WAIT_FLAGS = 0
D3D12_MULTISAMPLE_QUALITY_LEVEL_FLAGS = Int32
D3D12_MULTISAMPLE_QUALITY_LEVELS_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MULTISAMPLE_QUALITY_LEVEL_FLAGS = 0
D3D12_MULTISAMPLE_QUALITY_LEVELS_FLAG_TILED_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MULTISAMPLE_QUALITY_LEVEL_FLAGS = 1
class D3D12_MULTI_NODE_CPU_INPUT(Structure):
    NumNodeInputs: UInt32
    pNodeInputs: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_CPU_INPUT)
    NodeInputStrideInBytes: UInt64
class D3D12_MULTI_NODE_GPU_INPUT(Structure):
    NumNodeInputs: UInt32
    NodeInputs: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_VIRTUAL_ADDRESS_AND_STRIDE
class D3D12_NODE(Structure):
    NodeType: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Shader: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_NODE
class D3D12_NODE_CPU_INPUT(Structure):
    EntrypointIndex: UInt32
    NumRecords: UInt32
    pRecords: VoidPtr
    RecordStrideInBytes: UInt64
class D3D12_NODE_GPU_INPUT(Structure):
    EntrypointIndex: UInt32
    NumRecords: UInt32
    Records: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_VIRTUAL_ADDRESS_AND_STRIDE
class D3D12_NODE_ID(Structure):
    Name: win32more.Windows.Win32.Foundation.PWSTR
    ArrayIndex: UInt32
class D3D12_NODE_MASK(Structure):
    NodeMask: UInt32
class D3D12_NODE_OUTPUT_OVERRIDES(Structure):
    OutputIndex: UInt32
    pNewName: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_ID)
    pAllowSparseNodes: POINTER(win32more.Windows.Win32.Foundation.BOOL)
    pMaxRecords: POINTER(UInt32)
    pMaxRecordsSharedWithOutputIndex: POINTER(UInt32)
D3D12_NODE_OVERRIDES_TYPE = Int32
D3D12_NODE_OVERRIDES_TYPE_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_OVERRIDES_TYPE = 0
D3D12_NODE_OVERRIDES_TYPE_BROADCASTING_LAUNCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_OVERRIDES_TYPE = 1
D3D12_NODE_OVERRIDES_TYPE_COALESCING_LAUNCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_OVERRIDES_TYPE = 2
D3D12_NODE_OVERRIDES_TYPE_THREAD_LAUNCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_OVERRIDES_TYPE = 3
D3D12_NODE_OVERRIDES_TYPE_COMMON_COMPUTE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_OVERRIDES_TYPE = 4
D3D12_NODE_TYPE = Int32
D3D12_NODE_TYPE_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_TYPE = 0
class D3D12_PACKED_MIP_INFO(Structure):
    NumStandardMips: Byte
    NumPackedMips: Byte
    NumTilesForPackedMips: UInt32
    StartTileIndexInOverallResource: UInt32
class D3D12_PARAMETER_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PSTR
    SemanticName: win32more.Windows.Win32.Foundation.PSTR
    Type: win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_VARIABLE_TYPE
    Class: win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_VARIABLE_CLASS
    Rows: UInt32
    Columns: UInt32
    InterpolationMode: win32more.Windows.Win32.Graphics.Direct3D.D3D_INTERPOLATION_MODE
    Flags: win32more.Windows.Win32.Graphics.Direct3D.D3D_PARAMETER_FLAGS
    FirstInRegister: UInt32
    FirstInComponent: UInt32
    FirstOutRegister: UInt32
    FirstOutComponent: UInt32
D3D12_PIPELINE_STATE_FLAGS = Int32
D3D12_PIPELINE_STATE_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_FLAGS = 0
D3D12_PIPELINE_STATE_FLAG_TOOL_DEBUG: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_FLAGS = 1
D3D12_PIPELINE_STATE_FLAG_DYNAMIC_DEPTH_BIAS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_FLAGS = 4
D3D12_PIPELINE_STATE_FLAG_DYNAMIC_INDEX_BUFFER_STRIP_CUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_FLAGS = 8
class D3D12_PIPELINE_STATE_STREAM_DESC(Structure):
    SizeInBytes: UIntPtr
    pPipelineStateSubobjectStream: VoidPtr
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = Int32
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_ROOT_SIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 0
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_VS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 1
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_PS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 2
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_DS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 3
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_HS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 4
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_GS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 5
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_CS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 6
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_STREAM_OUTPUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 7
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_BLEND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 8
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_SAMPLE_MASK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 9
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_RASTERIZER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 10
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_DEPTH_STENCIL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 11
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_INPUT_LAYOUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 12
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_IB_STRIP_CUT_VALUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 13
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_PRIMITIVE_TOPOLOGY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 14
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_RENDER_TARGET_FORMATS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 15
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_DEPTH_STENCIL_FORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 16
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_SAMPLE_DESC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 17
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_NODE_MASK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 18
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_CACHED_PSO: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 19
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_FLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 20
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_DEPTH_STENCIL1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 21
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_VIEW_INSTANCING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 22
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_AS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 24
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_MS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 25
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_DEPTH_STENCIL2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 26
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_RASTERIZER1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 27
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_RASTERIZER2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 28
D3D12_PIPELINE_STATE_SUBOBJECT_TYPE_MAX_VALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_SUBOBJECT_TYPE = 29
class D3D12_PLACED_SUBRESOURCE_FOOTPRINT(Structure):
    Offset: UInt64
    Footprint: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SUBRESOURCE_FOOTPRINT
D3D12_PREDICATION_OP = Int32
D3D12_PREDICATION_OP_EQUAL_ZERO: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PREDICATION_OP = 0
D3D12_PREDICATION_OP_NOT_EQUAL_ZERO: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PREDICATION_OP = 1
class D3D12_PRIMITIVE_TOPOLOGY_DESC(Structure):
    PrimitiveTopology: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PRIMITIVE_TOPOLOGY_TYPE
D3D12_PRIMITIVE_TOPOLOGY_TYPE = Int32
D3D12_PRIMITIVE_TOPOLOGY_TYPE_UNDEFINED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PRIMITIVE_TOPOLOGY_TYPE = 0
D3D12_PRIMITIVE_TOPOLOGY_TYPE_POINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PRIMITIVE_TOPOLOGY_TYPE = 1
D3D12_PRIMITIVE_TOPOLOGY_TYPE_LINE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PRIMITIVE_TOPOLOGY_TYPE = 2
D3D12_PRIMITIVE_TOPOLOGY_TYPE_TRIANGLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PRIMITIVE_TOPOLOGY_TYPE = 3
D3D12_PRIMITIVE_TOPOLOGY_TYPE_PATCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PRIMITIVE_TOPOLOGY_TYPE = 4
D3D12_PROGRAMMABLE_SAMPLE_POSITIONS_TIER = Int32
D3D12_PROGRAMMABLE_SAMPLE_POSITIONS_TIER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROGRAMMABLE_SAMPLE_POSITIONS_TIER = 0
D3D12_PROGRAMMABLE_SAMPLE_POSITIONS_TIER_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROGRAMMABLE_SAMPLE_POSITIONS_TIER = 1
D3D12_PROGRAMMABLE_SAMPLE_POSITIONS_TIER_2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROGRAMMABLE_SAMPLE_POSITIONS_TIER = 2
class D3D12_PROGRAM_IDENTIFIER(Structure):
    OpaqueData: UInt64 * 4
D3D12_PROGRAM_TYPE = Int32
D3D12_PROGRAM_TYPE_GENERIC_PIPELINE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROGRAM_TYPE = 1
D3D12_PROGRAM_TYPE_RAYTRACING_PIPELINE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROGRAM_TYPE = 4
D3D12_PROGRAM_TYPE_WORK_GRAPH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROGRAM_TYPE = 5
class D3D12_PROTECTED_RESOURCE_SESSION_DESC(Structure):
    NodeMask: UInt32
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROTECTED_RESOURCE_SESSION_FLAGS
class D3D12_PROTECTED_RESOURCE_SESSION_DESC1(Structure):
    NodeMask: UInt32
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROTECTED_RESOURCE_SESSION_FLAGS
    ProtectionType: Guid
D3D12_PROTECTED_RESOURCE_SESSION_FLAGS = Int32
D3D12_PROTECTED_RESOURCE_SESSION_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROTECTED_RESOURCE_SESSION_FLAGS = 0
D3D12_PROTECTED_RESOURCE_SESSION_SUPPORT_FLAGS = Int32
D3D12_PROTECTED_RESOURCE_SESSION_SUPPORT_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROTECTED_RESOURCE_SESSION_SUPPORT_FLAGS = 0
D3D12_PROTECTED_RESOURCE_SESSION_SUPPORT_FLAG_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROTECTED_RESOURCE_SESSION_SUPPORT_FLAGS = 1
D3D12_PROTECTED_SESSION_STATUS = Int32
D3D12_PROTECTED_SESSION_STATUS_OK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROTECTED_SESSION_STATUS = 0
D3D12_PROTECTED_SESSION_STATUS_INVALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROTECTED_SESSION_STATUS = 1
class D3D12_QUERY_DATA_PIPELINE_STATISTICS(Structure):
    IAVertices: UInt64
    IAPrimitives: UInt64
    VSInvocations: UInt64
    GSInvocations: UInt64
    GSPrimitives: UInt64
    CInvocations: UInt64
    CPrimitives: UInt64
    PSInvocations: UInt64
    HSInvocations: UInt64
    DSInvocations: UInt64
    CSInvocations: UInt64
class D3D12_QUERY_DATA_PIPELINE_STATISTICS1(Structure):
    IAVertices: UInt64
    IAPrimitives: UInt64
    VSInvocations: UInt64
    GSInvocations: UInt64
    GSPrimitives: UInt64
    CInvocations: UInt64
    CPrimitives: UInt64
    PSInvocations: UInt64
    HSInvocations: UInt64
    DSInvocations: UInt64
    CSInvocations: UInt64
    ASInvocations: UInt64
    MSInvocations: UInt64
    MSPrimitives: UInt64
class D3D12_QUERY_DATA_SO_STATISTICS(Structure):
    NumPrimitivesWritten: UInt64
    PrimitivesStorageNeeded: UInt64
class D3D12_QUERY_HEAP_DESC(Structure):
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_HEAP_TYPE
    Count: UInt32
    NodeMask: UInt32
D3D12_QUERY_HEAP_TYPE = Int32
D3D12_QUERY_HEAP_TYPE_OCCLUSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_HEAP_TYPE = 0
D3D12_QUERY_HEAP_TYPE_TIMESTAMP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_HEAP_TYPE = 1
D3D12_QUERY_HEAP_TYPE_PIPELINE_STATISTICS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_HEAP_TYPE = 2
D3D12_QUERY_HEAP_TYPE_SO_STATISTICS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_HEAP_TYPE = 3
D3D12_QUERY_HEAP_TYPE_VIDEO_DECODE_STATISTICS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_HEAP_TYPE = 4
D3D12_QUERY_HEAP_TYPE_COPY_QUEUE_TIMESTAMP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_HEAP_TYPE = 5
D3D12_QUERY_HEAP_TYPE_PIPELINE_STATISTICS1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_HEAP_TYPE = 7
D3D12_QUERY_TYPE = Int32
D3D12_QUERY_TYPE_OCCLUSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_TYPE = 0
D3D12_QUERY_TYPE_BINARY_OCCLUSION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_TYPE = 1
D3D12_QUERY_TYPE_TIMESTAMP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_TYPE = 2
D3D12_QUERY_TYPE_PIPELINE_STATISTICS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_TYPE = 3
D3D12_QUERY_TYPE_SO_STATISTICS_STREAM0: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_TYPE = 4
D3D12_QUERY_TYPE_SO_STATISTICS_STREAM1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_TYPE = 5
D3D12_QUERY_TYPE_SO_STATISTICS_STREAM2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_TYPE = 6
D3D12_QUERY_TYPE_SO_STATISTICS_STREAM3: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_TYPE = 7
D3D12_QUERY_TYPE_VIDEO_DECODE_STATISTICS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_TYPE = 8
D3D12_QUERY_TYPE_PIPELINE_STATISTICS1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_TYPE = 10
class D3D12_RANGE(Structure):
    Begin: UIntPtr
    End: UIntPtr
class D3D12_RANGE_UINT64(Structure):
    Begin: UInt64
    End: UInt64
class D3D12_RASTERIZER_DESC(Structure):
    FillMode: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILL_MODE
    CullMode: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CULL_MODE
    FrontCounterClockwise: win32more.Windows.Win32.Foundation.BOOL
    DepthBias: Int32
    DepthBiasClamp: Single
    SlopeScaledDepthBias: Single
    DepthClipEnable: win32more.Windows.Win32.Foundation.BOOL
    MultisampleEnable: win32more.Windows.Win32.Foundation.BOOL
    AntialiasedLineEnable: win32more.Windows.Win32.Foundation.BOOL
    ForcedSampleCount: UInt32
    ConservativeRaster: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CONSERVATIVE_RASTERIZATION_MODE
class D3D12_RASTERIZER_DESC1(Structure):
    FillMode: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILL_MODE
    CullMode: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CULL_MODE
    FrontCounterClockwise: win32more.Windows.Win32.Foundation.BOOL
    DepthBias: Single
    DepthBiasClamp: Single
    SlopeScaledDepthBias: Single
    DepthClipEnable: win32more.Windows.Win32.Foundation.BOOL
    MultisampleEnable: win32more.Windows.Win32.Foundation.BOOL
    AntialiasedLineEnable: win32more.Windows.Win32.Foundation.BOOL
    ForcedSampleCount: UInt32
    ConservativeRaster: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CONSERVATIVE_RASTERIZATION_MODE
class D3D12_RASTERIZER_DESC2(Structure):
    FillMode: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILL_MODE
    CullMode: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CULL_MODE
    FrontCounterClockwise: win32more.Windows.Win32.Foundation.BOOL
    DepthBias: Single
    DepthBiasClamp: Single
    SlopeScaledDepthBias: Single
    DepthClipEnable: win32more.Windows.Win32.Foundation.BOOL
    LineRasterizationMode: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LINE_RASTERIZATION_MODE
    ForcedSampleCount: UInt32
    ConservativeRaster: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CONSERVATIVE_RASTERIZATION_MODE
class D3D12_RAYTRACING_AABB(Structure):
    MinX: Single
    MinY: Single
    MinZ: Single
    MaxX: Single
    MaxY: Single
    MaxZ: Single
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAGS = Int32
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAGS = 0
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_ALLOW_UPDATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAGS = 1
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_ALLOW_COMPACTION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAGS = 2
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_PREFER_FAST_TRACE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAGS = 4
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_PREFER_FAST_BUILD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAGS = 8
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_MINIMIZE_MEMORY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAGS = 16
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_PERFORM_UPDATE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAGS = 32
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE = Int32
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_CLONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE = 0
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_COMPACT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE = 1
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_VISUALIZATION_DECODE_FOR_TOOLS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE = 2
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_SERIALIZE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE = 3
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_DESERIALIZE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE = 4
class D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_COMPACTED_SIZE_DESC(Structure):
    CompactedSizeInBytes: UInt64
class D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_CURRENT_SIZE_DESC(Structure):
    CurrentSizeInBytes: UInt64
class D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_DESC(Structure):
    DestBuffer: UInt64
    InfoType: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_TYPE
class D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_SERIALIZATION_DESC(Structure):
    SerializedSizeInBytes: UInt64
    NumBottomLevelAccelerationStructurePointers: UInt64
class D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_TOOLS_VISUALIZATION_DESC(Structure):
    DecodedSizeInBytes: UInt64
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_TYPE = Int32
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_COMPACTED_SIZE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_TYPE = 0
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_TOOLS_VISUALIZATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_TYPE = 1
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_SERIALIZATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_TYPE = 2
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_CURRENT_SIZE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_TYPE = 3
class D3D12_RAYTRACING_ACCELERATION_STRUCTURE_PREBUILD_INFO(Structure):
    ResultDataMaxSizeInBytes: UInt64
    ScratchDataSizeInBytes: UInt64
    UpdateScratchDataSizeInBytes: UInt64
class D3D12_RAYTRACING_ACCELERATION_STRUCTURE_SRV(Structure):
    Location: UInt64
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_TYPE = Int32
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_TYPE_TOP_LEVEL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_TYPE = 0
D3D12_RAYTRACING_ACCELERATION_STRUCTURE_TYPE_BOTTOM_LEVEL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_TYPE = 1
class D3D12_RAYTRACING_GEOMETRY_AABBS_DESC(Structure):
    AABBCount: UInt64
    AABBs: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_VIRTUAL_ADDRESS_AND_STRIDE
class D3D12_RAYTRACING_GEOMETRY_DESC(Structure):
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_GEOMETRY_TYPE
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_GEOMETRY_FLAGS
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Triangles: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_GEOMETRY_TRIANGLES_DESC
        AABBs: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_GEOMETRY_AABBS_DESC
D3D12_RAYTRACING_GEOMETRY_FLAGS = Int32
D3D12_RAYTRACING_GEOMETRY_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_GEOMETRY_FLAGS = 0
D3D12_RAYTRACING_GEOMETRY_FLAG_OPAQUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_GEOMETRY_FLAGS = 1
D3D12_RAYTRACING_GEOMETRY_FLAG_NO_DUPLICATE_ANYHIT_INVOCATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_GEOMETRY_FLAGS = 2
class D3D12_RAYTRACING_GEOMETRY_TRIANGLES_DESC(Structure):
    Transform3x4: UInt64
    IndexFormat: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    VertexFormat: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    IndexCount: UInt32
    VertexCount: UInt32
    IndexBuffer: UInt64
    VertexBuffer: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_VIRTUAL_ADDRESS_AND_STRIDE
D3D12_RAYTRACING_GEOMETRY_TYPE = Int32
D3D12_RAYTRACING_GEOMETRY_TYPE_TRIANGLES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_GEOMETRY_TYPE = 0
D3D12_RAYTRACING_GEOMETRY_TYPE_PROCEDURAL_PRIMITIVE_AABBS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_GEOMETRY_TYPE = 1
class D3D12_RAYTRACING_INSTANCE_DESC(Structure):
    Transform: Single * 12
    InstanceID: Annotated[UInt32, 24]
    InstanceMask: Annotated[UInt32, 8]
    InstanceContributionToHitGroupIndex: Annotated[UInt32, 24]
    Flags: Annotated[UInt32, 8]
    AccelerationStructure: UInt64
D3D12_RAYTRACING_INSTANCE_FLAGS = Int32
D3D12_RAYTRACING_INSTANCE_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_INSTANCE_FLAGS = 0
D3D12_RAYTRACING_INSTANCE_FLAG_TRIANGLE_CULL_DISABLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_INSTANCE_FLAGS = 1
D3D12_RAYTRACING_INSTANCE_FLAG_TRIANGLE_FRONT_COUNTERCLOCKWISE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_INSTANCE_FLAGS = 2
D3D12_RAYTRACING_INSTANCE_FLAG_FORCE_OPAQUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_INSTANCE_FLAGS = 4
D3D12_RAYTRACING_INSTANCE_FLAG_FORCE_NON_OPAQUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_INSTANCE_FLAGS = 8
class D3D12_RAYTRACING_PIPELINE_CONFIG(Structure):
    MaxTraceRecursionDepth: UInt32
class D3D12_RAYTRACING_PIPELINE_CONFIG1(Structure):
    MaxTraceRecursionDepth: UInt32
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_PIPELINE_FLAGS
D3D12_RAYTRACING_PIPELINE_FLAGS = Int32
D3D12_RAYTRACING_PIPELINE_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_PIPELINE_FLAGS = 0
D3D12_RAYTRACING_PIPELINE_FLAG_SKIP_TRIANGLES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_PIPELINE_FLAGS = 256
D3D12_RAYTRACING_PIPELINE_FLAG_SKIP_PROCEDURAL_PRIMITIVES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_PIPELINE_FLAGS = 512
class D3D12_RAYTRACING_SHADER_CONFIG(Structure):
    MaxPayloadSizeInBytes: UInt32
    MaxAttributeSizeInBytes: UInt32
D3D12_RAYTRACING_TIER = Int32
D3D12_RAYTRACING_TIER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_TIER = 0
D3D12_RAYTRACING_TIER_1_0: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_TIER = 10
D3D12_RAYTRACING_TIER_1_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_TIER = 11
D3D12_RAY_FLAGS = Int32
D3D12_RAY_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAY_FLAGS = 0
D3D12_RAY_FLAG_FORCE_OPAQUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAY_FLAGS = 1
D3D12_RAY_FLAG_FORCE_NON_OPAQUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAY_FLAGS = 2
D3D12_RAY_FLAG_ACCEPT_FIRST_HIT_AND_END_SEARCH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAY_FLAGS = 4
D3D12_RAY_FLAG_SKIP_CLOSEST_HIT_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAY_FLAGS = 8
D3D12_RAY_FLAG_CULL_BACK_FACING_TRIANGLES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAY_FLAGS = 16
D3D12_RAY_FLAG_CULL_FRONT_FACING_TRIANGLES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAY_FLAGS = 32
D3D12_RAY_FLAG_CULL_OPAQUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAY_FLAGS = 64
D3D12_RAY_FLAG_CULL_NON_OPAQUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAY_FLAGS = 128
D3D12_RAY_FLAG_SKIP_TRIANGLES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAY_FLAGS = 256
D3D12_RAY_FLAG_SKIP_PROCEDURAL_PRIMITIVES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAY_FLAGS = 512
D3D12_RECREATE_AT_TIER = Int32
D3D12_RECREATE_AT_TIER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RECREATE_AT_TIER = 0
D3D12_RECREATE_AT_TIER_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RECREATE_AT_TIER = 1
class D3D12_RENDER_PASS_BEGINNING_ACCESS(Structure):
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Clear: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_BEGINNING_ACCESS_CLEAR_PARAMETERS
        PreserveLocal: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_BEGINNING_ACCESS_PRESERVE_LOCAL_PARAMETERS
class D3D12_RENDER_PASS_BEGINNING_ACCESS_CLEAR_PARAMETERS(Structure):
    ClearValue: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CLEAR_VALUE
class D3D12_RENDER_PASS_BEGINNING_ACCESS_PRESERVE_LOCAL_PARAMETERS(Structure):
    AdditionalWidth: UInt32
    AdditionalHeight: UInt32
D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE = Int32
D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_DISCARD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE = 0
D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_PRESERVE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE = 1
D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_CLEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE = 2
D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_NO_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE = 3
D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_PRESERVE_LOCAL_RENDER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE = 4
D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_PRESERVE_LOCAL_SRV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE = 5
D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_PRESERVE_LOCAL_UAV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE = 6
class D3D12_RENDER_PASS_DEPTH_STENCIL_DESC(Structure):
    cpuDescriptor: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE
    DepthBeginningAccess: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_BEGINNING_ACCESS
    StencilBeginningAccess: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_BEGINNING_ACCESS
    DepthEndingAccess: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_ENDING_ACCESS
    StencilEndingAccess: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_ENDING_ACCESS
class D3D12_RENDER_PASS_ENDING_ACCESS(Structure):
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_ENDING_ACCESS_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Resolve: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_ENDING_ACCESS_RESOLVE_PARAMETERS
        PreserveLocal: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_ENDING_ACCESS_PRESERVE_LOCAL_PARAMETERS
class D3D12_RENDER_PASS_ENDING_ACCESS_PRESERVE_LOCAL_PARAMETERS(Structure):
    AdditionalWidth: UInt32
    AdditionalHeight: UInt32
class D3D12_RENDER_PASS_ENDING_ACCESS_RESOLVE_PARAMETERS(Structure):
    pSrcResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource
    pDstResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource
    SubresourceCount: UInt32
    pSubresourceParameters: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_ENDING_ACCESS_RESOLVE_SUBRESOURCE_PARAMETERS)
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    ResolveMode: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOLVE_MODE
    PreserveResolveSource: win32more.Windows.Win32.Foundation.BOOL
class D3D12_RENDER_PASS_ENDING_ACCESS_RESOLVE_SUBRESOURCE_PARAMETERS(Structure):
    SrcSubresource: UInt32
    DstSubresource: UInt32
    DstX: UInt32
    DstY: UInt32
    SrcRect: win32more.Windows.Win32.Foundation.RECT
D3D12_RENDER_PASS_ENDING_ACCESS_TYPE = Int32
D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_DISCARD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_ENDING_ACCESS_TYPE = 0
D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_PRESERVE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_ENDING_ACCESS_TYPE = 1
D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_RESOLVE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_ENDING_ACCESS_TYPE = 2
D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_NO_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_ENDING_ACCESS_TYPE = 3
D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_PRESERVE_LOCAL_RENDER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_ENDING_ACCESS_TYPE = 4
D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_PRESERVE_LOCAL_SRV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_ENDING_ACCESS_TYPE = 5
D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_PRESERVE_LOCAL_UAV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_ENDING_ACCESS_TYPE = 6
D3D12_RENDER_PASS_FLAGS = Int32
D3D12_RENDER_PASS_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_FLAGS = 0
D3D12_RENDER_PASS_FLAG_ALLOW_UAV_WRITES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_FLAGS = 1
D3D12_RENDER_PASS_FLAG_SUSPENDING_PASS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_FLAGS = 2
D3D12_RENDER_PASS_FLAG_RESUMING_PASS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_FLAGS = 4
D3D12_RENDER_PASS_FLAG_BIND_READ_ONLY_DEPTH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_FLAGS = 8
D3D12_RENDER_PASS_FLAG_BIND_READ_ONLY_STENCIL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_FLAGS = 16
class D3D12_RENDER_PASS_RENDER_TARGET_DESC(Structure):
    cpuDescriptor: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE
    BeginningAccess: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_BEGINNING_ACCESS
    EndingAccess: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_ENDING_ACCESS
D3D12_RENDER_PASS_TIER = Int32
D3D12_RENDER_PASS_TIER_0: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_TIER = 0
D3D12_RENDER_PASS_TIER_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_TIER = 1
D3D12_RENDER_PASS_TIER_2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_TIER = 2
class D3D12_RENDER_TARGET_BLEND_DESC(Structure):
    BlendEnable: win32more.Windows.Win32.Foundation.BOOL
    LogicOpEnable: win32more.Windows.Win32.Foundation.BOOL
    SrcBlend: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND
    DestBlend: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND
    BlendOp: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND_OP
    SrcBlendAlpha: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND
    DestBlendAlpha: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND
    BlendOpAlpha: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BLEND_OP
    LogicOp: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LOGIC_OP
    RenderTargetWriteMask: Byte
class D3D12_RENDER_TARGET_VIEW_DESC(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RTV_DIMENSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Buffer: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BUFFER_RTV
        Texture1D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX1D_RTV
        Texture1DArray: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX1D_ARRAY_RTV
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX2D_RTV
        Texture2DArray: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX2D_ARRAY_RTV
        Texture2DMS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX2DMS_RTV
        Texture2DMSArray: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX2DMS_ARRAY_RTV
        Texture3D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX3D_RTV
D3D12_RESIDENCY_FLAGS = Int32
D3D12_RESIDENCY_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESIDENCY_FLAGS = 0
D3D12_RESIDENCY_FLAG_DENY_OVERBUDGET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESIDENCY_FLAGS = 1
D3D12_RESIDENCY_PRIORITY = Int32
D3D12_RESIDENCY_PRIORITY_MINIMUM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESIDENCY_PRIORITY = 671088640
D3D12_RESIDENCY_PRIORITY_LOW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESIDENCY_PRIORITY = 1342177280
D3D12_RESIDENCY_PRIORITY_NORMAL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESIDENCY_PRIORITY = 2013265920
D3D12_RESIDENCY_PRIORITY_HIGH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESIDENCY_PRIORITY = -1610547200
D3D12_RESIDENCY_PRIORITY_MAXIMUM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESIDENCY_PRIORITY = -939524096
D3D12_RESOLVE_MODE = Int32
D3D12_RESOLVE_MODE_DECOMPRESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOLVE_MODE = 0
D3D12_RESOLVE_MODE_MIN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOLVE_MODE = 1
D3D12_RESOLVE_MODE_MAX: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOLVE_MODE = 2
D3D12_RESOLVE_MODE_AVERAGE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOLVE_MODE = 3
D3D12_RESOLVE_MODE_ENCODE_SAMPLER_FEEDBACK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOLVE_MODE = 4
D3D12_RESOLVE_MODE_DECODE_SAMPLER_FEEDBACK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOLVE_MODE = 5
class D3D12_RESOURCE_ALIASING_BARRIER(Structure):
    pResourceBefore: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource
    pResourceAfter: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource
class D3D12_RESOURCE_ALLOCATION_INFO(Structure):
    SizeInBytes: UInt64
    Alignment: UInt64
class D3D12_RESOURCE_ALLOCATION_INFO1(Structure):
    Offset: UInt64
    Alignment: UInt64
    SizeInBytes: UInt64
class D3D12_RESOURCE_BARRIER(Structure):
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_BARRIER_TYPE
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_BARRIER_FLAGS
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Transition: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_TRANSITION_BARRIER
        Aliasing: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_ALIASING_BARRIER
        UAV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_UAV_BARRIER
D3D12_RESOURCE_BARRIER_FLAGS = Int32
D3D12_RESOURCE_BARRIER_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_BARRIER_FLAGS = 0
D3D12_RESOURCE_BARRIER_FLAG_BEGIN_ONLY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_BARRIER_FLAGS = 1
D3D12_RESOURCE_BARRIER_FLAG_END_ONLY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_BARRIER_FLAGS = 2
D3D12_RESOURCE_BARRIER_TYPE = Int32
D3D12_RESOURCE_BARRIER_TYPE_TRANSITION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_BARRIER_TYPE = 0
D3D12_RESOURCE_BARRIER_TYPE_ALIASING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_BARRIER_TYPE = 1
D3D12_RESOURCE_BARRIER_TYPE_UAV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_BARRIER_TYPE = 2
D3D12_RESOURCE_BINDING_TIER = Int32
D3D12_RESOURCE_BINDING_TIER_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_BINDING_TIER = 1
D3D12_RESOURCE_BINDING_TIER_2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_BINDING_TIER = 2
D3D12_RESOURCE_BINDING_TIER_3: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_BINDING_TIER = 3
class D3D12_RESOURCE_DESC(Structure):
    Dimension: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DIMENSION
    Alignment: UInt64
    Width: UInt64
    Height: UInt32
    DepthOrArraySize: UInt16
    MipLevels: UInt16
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    SampleDesc: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_SAMPLE_DESC
    Layout: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_LAYOUT
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_FLAGS
class D3D12_RESOURCE_DESC1(Structure):
    Dimension: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DIMENSION
    Alignment: UInt64
    Width: UInt64
    Height: UInt32
    DepthOrArraySize: UInt16
    MipLevels: UInt16
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    SampleDesc: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_SAMPLE_DESC
    Layout: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_LAYOUT
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_FLAGS
    SamplerFeedbackMipRegion: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MIP_REGION
D3D12_RESOURCE_DIMENSION = Int32
D3D12_RESOURCE_DIMENSION_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DIMENSION = 0
D3D12_RESOURCE_DIMENSION_BUFFER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DIMENSION = 1
D3D12_RESOURCE_DIMENSION_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DIMENSION = 2
D3D12_RESOURCE_DIMENSION_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DIMENSION = 3
D3D12_RESOURCE_DIMENSION_TEXTURE3D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DIMENSION = 4
D3D12_RESOURCE_FLAGS = Int32
D3D12_RESOURCE_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_FLAGS = 0
D3D12_RESOURCE_FLAG_ALLOW_RENDER_TARGET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_FLAGS = 1
D3D12_RESOURCE_FLAG_ALLOW_DEPTH_STENCIL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_FLAGS = 2
D3D12_RESOURCE_FLAG_ALLOW_UNORDERED_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_FLAGS = 4
D3D12_RESOURCE_FLAG_DENY_SHADER_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_FLAGS = 8
D3D12_RESOURCE_FLAG_ALLOW_CROSS_ADAPTER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_FLAGS = 16
D3D12_RESOURCE_FLAG_ALLOW_SIMULTANEOUS_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_FLAGS = 32
D3D12_RESOURCE_FLAG_VIDEO_DECODE_REFERENCE_ONLY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_FLAGS = 64
D3D12_RESOURCE_FLAG_VIDEO_ENCODE_REFERENCE_ONLY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_FLAGS = 128
D3D12_RESOURCE_FLAG_RAYTRACING_ACCELERATION_STRUCTURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_FLAGS = 256
D3D12_RESOURCE_HEAP_TIER = Int32
D3D12_RESOURCE_HEAP_TIER_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_HEAP_TIER = 1
D3D12_RESOURCE_HEAP_TIER_2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_HEAP_TIER = 2
D3D12_RESOURCE_STATES = Int32
D3D12_RESOURCE_STATE_COMMON: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 0
D3D12_RESOURCE_STATE_VERTEX_AND_CONSTANT_BUFFER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 1
D3D12_RESOURCE_STATE_INDEX_BUFFER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 2
D3D12_RESOURCE_STATE_RENDER_TARGET: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 4
D3D12_RESOURCE_STATE_UNORDERED_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 8
D3D12_RESOURCE_STATE_DEPTH_WRITE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 16
D3D12_RESOURCE_STATE_DEPTH_READ: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 32
D3D12_RESOURCE_STATE_NON_PIXEL_SHADER_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 64
D3D12_RESOURCE_STATE_PIXEL_SHADER_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 128
D3D12_RESOURCE_STATE_STREAM_OUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 256
D3D12_RESOURCE_STATE_INDIRECT_ARGUMENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 512
D3D12_RESOURCE_STATE_COPY_DEST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 1024
D3D12_RESOURCE_STATE_COPY_SOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 2048
D3D12_RESOURCE_STATE_RESOLVE_DEST: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 4096
D3D12_RESOURCE_STATE_RESOLVE_SOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 8192
D3D12_RESOURCE_STATE_RAYTRACING_ACCELERATION_STRUCTURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 4194304
D3D12_RESOURCE_STATE_SHADING_RATE_SOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 16777216
D3D12_RESOURCE_STATE_RESERVED_INTERNAL_8000: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 32768
D3D12_RESOURCE_STATE_RESERVED_INTERNAL_4000: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 16384
D3D12_RESOURCE_STATE_RESERVED_INTERNAL_100000: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 1048576
D3D12_RESOURCE_STATE_RESERVED_INTERNAL_40000000: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 1073741824
D3D12_RESOURCE_STATE_RESERVED_INTERNAL_80000000: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = -2147483648
D3D12_RESOURCE_STATE_GENERIC_READ: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 2755
D3D12_RESOURCE_STATE_ALL_SHADER_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 192
D3D12_RESOURCE_STATE_PRESENT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 0
D3D12_RESOURCE_STATE_PREDICATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 512
D3D12_RESOURCE_STATE_VIDEO_DECODE_READ: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 65536
D3D12_RESOURCE_STATE_VIDEO_DECODE_WRITE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 131072
D3D12_RESOURCE_STATE_VIDEO_PROCESS_READ: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 262144
D3D12_RESOURCE_STATE_VIDEO_PROCESS_WRITE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 524288
D3D12_RESOURCE_STATE_VIDEO_ENCODE_READ: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 2097152
D3D12_RESOURCE_STATE_VIDEO_ENCODE_WRITE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES = 8388608
class D3D12_RESOURCE_TRANSITION_BARRIER(Structure):
    pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource
    Subresource: UInt32
    StateBefore: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES
    StateAfter: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES
class D3D12_RESOURCE_UAV_BARRIER(Structure):
    pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource
D3D12_RLDO_FLAGS = Int32
D3D12_RLDO_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RLDO_FLAGS = 0
D3D12_RLDO_SUMMARY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RLDO_FLAGS = 1
D3D12_RLDO_DETAIL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RLDO_FLAGS = 2
D3D12_RLDO_IGNORE_INTERNAL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RLDO_FLAGS = 4
class D3D12_ROOT_CONSTANTS(Structure):
    ShaderRegister: UInt32
    RegisterSpace: UInt32
    Num32BitValues: UInt32
class D3D12_ROOT_DESCRIPTOR(Structure):
    ShaderRegister: UInt32
    RegisterSpace: UInt32
class D3D12_ROOT_DESCRIPTOR1(Structure):
    ShaderRegister: UInt32
    RegisterSpace: UInt32
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_DESCRIPTOR_FLAGS
D3D12_ROOT_DESCRIPTOR_FLAGS = Int32
D3D12_ROOT_DESCRIPTOR_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_DESCRIPTOR_FLAGS = 0
D3D12_ROOT_DESCRIPTOR_FLAG_DATA_VOLATILE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_DESCRIPTOR_FLAGS = 2
D3D12_ROOT_DESCRIPTOR_FLAG_DATA_STATIC_WHILE_SET_AT_EXECUTE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_DESCRIPTOR_FLAGS = 4
D3D12_ROOT_DESCRIPTOR_FLAG_DATA_STATIC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_DESCRIPTOR_FLAGS = 8
class D3D12_ROOT_DESCRIPTOR_TABLE(Structure):
    NumDescriptorRanges: UInt32
    pDescriptorRanges: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_RANGE)
class D3D12_ROOT_DESCRIPTOR_TABLE1(Structure):
    NumDescriptorRanges: UInt32
    pDescriptorRanges: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_RANGE1)
class D3D12_ROOT_PARAMETER(Structure):
    ParameterType: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_PARAMETER_TYPE
    Anonymous: _Anonymous_e__Union
    ShaderVisibility: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VISIBILITY
    class _Anonymous_e__Union(Union):
        DescriptorTable: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_DESCRIPTOR_TABLE
        Constants: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_CONSTANTS
        Descriptor: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_DESCRIPTOR
class D3D12_ROOT_PARAMETER1(Structure):
    ParameterType: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_PARAMETER_TYPE
    Anonymous: _Anonymous_e__Union
    ShaderVisibility: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VISIBILITY
    class _Anonymous_e__Union(Union):
        DescriptorTable: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_DESCRIPTOR_TABLE1
        Constants: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_CONSTANTS
        Descriptor: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_DESCRIPTOR1
D3D12_ROOT_PARAMETER_TYPE = Int32
D3D12_ROOT_PARAMETER_TYPE_DESCRIPTOR_TABLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_PARAMETER_TYPE = 0
D3D12_ROOT_PARAMETER_TYPE_32BIT_CONSTANTS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_PARAMETER_TYPE = 1
D3D12_ROOT_PARAMETER_TYPE_CBV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_PARAMETER_TYPE = 2
D3D12_ROOT_PARAMETER_TYPE_SRV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_PARAMETER_TYPE = 3
D3D12_ROOT_PARAMETER_TYPE_UAV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_PARAMETER_TYPE = 4
class D3D12_ROOT_SIGNATURE_DESC(Structure):
    NumParameters: UInt32
    pParameters: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_PARAMETER)
    NumStaticSamplers: UInt32
    pStaticSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATIC_SAMPLER_DESC)
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_FLAGS
class D3D12_ROOT_SIGNATURE_DESC1(Structure):
    NumParameters: UInt32
    pParameters: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_PARAMETER1)
    NumStaticSamplers: UInt32
    pStaticSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATIC_SAMPLER_DESC)
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_FLAGS
class D3D12_ROOT_SIGNATURE_DESC2(Structure):
    NumParameters: UInt32
    pParameters: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_PARAMETER1)
    NumStaticSamplers: UInt32
    pStaticSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATIC_SAMPLER_DESC1)
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_FLAGS
D3D12_ROOT_SIGNATURE_FLAGS = Int32
D3D12_ROOT_SIGNATURE_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_FLAGS = 0
D3D12_ROOT_SIGNATURE_FLAG_ALLOW_INPUT_ASSEMBLER_INPUT_LAYOUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_FLAGS = 1
D3D12_ROOT_SIGNATURE_FLAG_DENY_VERTEX_SHADER_ROOT_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_FLAGS = 2
D3D12_ROOT_SIGNATURE_FLAG_DENY_HULL_SHADER_ROOT_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_FLAGS = 4
D3D12_ROOT_SIGNATURE_FLAG_DENY_DOMAIN_SHADER_ROOT_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_FLAGS = 8
D3D12_ROOT_SIGNATURE_FLAG_DENY_GEOMETRY_SHADER_ROOT_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_FLAGS = 16
D3D12_ROOT_SIGNATURE_FLAG_DENY_PIXEL_SHADER_ROOT_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_FLAGS = 32
D3D12_ROOT_SIGNATURE_FLAG_ALLOW_STREAM_OUTPUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_FLAGS = 64
D3D12_ROOT_SIGNATURE_FLAG_LOCAL_ROOT_SIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_FLAGS = 128
D3D12_ROOT_SIGNATURE_FLAG_DENY_AMPLIFICATION_SHADER_ROOT_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_FLAGS = 256
D3D12_ROOT_SIGNATURE_FLAG_DENY_MESH_SHADER_ROOT_ACCESS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_FLAGS = 512
D3D12_ROOT_SIGNATURE_FLAG_CBV_SRV_UAV_HEAP_DIRECTLY_INDEXED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_FLAGS = 1024
D3D12_ROOT_SIGNATURE_FLAG_SAMPLER_HEAP_DIRECTLY_INDEXED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_FLAGS = 2048
D3D12_RTV_DIMENSION = Int32
D3D12_RTV_DIMENSION_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RTV_DIMENSION = 0
D3D12_RTV_DIMENSION_BUFFER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RTV_DIMENSION = 1
D3D12_RTV_DIMENSION_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RTV_DIMENSION = 2
D3D12_RTV_DIMENSION_TEXTURE1DARRAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RTV_DIMENSION = 3
D3D12_RTV_DIMENSION_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RTV_DIMENSION = 4
D3D12_RTV_DIMENSION_TEXTURE2DARRAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RTV_DIMENSION = 5
D3D12_RTV_DIMENSION_TEXTURE2DMS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RTV_DIMENSION = 6
D3D12_RTV_DIMENSION_TEXTURE2DMSARRAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RTV_DIMENSION = 7
D3D12_RTV_DIMENSION_TEXTURE3D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RTV_DIMENSION = 8
class D3D12_RT_FORMAT_ARRAY(Structure):
    RTFormats: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT * 8
    NumRenderTargets: UInt32
class D3D12_SAMPLER_DESC(Structure):
    Filter: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER
    AddressU: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_ADDRESS_MODE
    AddressV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_ADDRESS_MODE
    AddressW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_ADDRESS_MODE
    MipLODBias: Single
    MaxAnisotropy: UInt32
    ComparisonFunc: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC
    BorderColor: Single * 4
    MinLOD: Single
    MaxLOD: Single
class D3D12_SAMPLER_DESC2(Structure):
    Filter: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER
    AddressU: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_ADDRESS_MODE
    AddressV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_ADDRESS_MODE
    AddressW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_ADDRESS_MODE
    MipLODBias: Single
    MaxAnisotropy: UInt32
    ComparisonFunc: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC
    Anonymous: _Anonymous_e__Union
    MinLOD: Single
    MaxLOD: Single
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SAMPLER_FLAGS
    class _Anonymous_e__Union(Union):
        FloatBorderColor: Single * 4
        UintBorderColor: UInt32 * 4
D3D12_SAMPLER_FEEDBACK_TIER = Int32
D3D12_SAMPLER_FEEDBACK_TIER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SAMPLER_FEEDBACK_TIER = 0
D3D12_SAMPLER_FEEDBACK_TIER_0_9: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SAMPLER_FEEDBACK_TIER = 90
D3D12_SAMPLER_FEEDBACK_TIER_1_0: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SAMPLER_FEEDBACK_TIER = 100
D3D12_SAMPLER_FLAGS = Int32
D3D12_SAMPLER_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SAMPLER_FLAGS = 0
D3D12_SAMPLER_FLAG_UINT_BORDER_COLOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SAMPLER_FLAGS = 1
D3D12_SAMPLER_FLAG_NON_NORMALIZED_COORDINATES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SAMPLER_FLAGS = 2
class D3D12_SAMPLE_MASK(Structure):
    SampleMask: UInt32
class D3D12_SAMPLE_POSITION(Structure):
    X: SByte
    Y: SByte
class D3D12_SERIALIZED_DATA_DRIVER_MATCHING_IDENTIFIER(Structure):
    DriverOpaqueGUID: Guid
    DriverOpaqueVersioningData: Byte * 16
D3D12_SERIALIZED_DATA_TYPE = Int32
D3D12_SERIALIZED_DATA_RAYTRACING_ACCELERATION_STRUCTURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SERIALIZED_DATA_TYPE = 0
class D3D12_SERIALIZED_RAYTRACING_ACCELERATION_STRUCTURE_HEADER(Structure):
    DriverMatchingIdentifier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SERIALIZED_DATA_DRIVER_MATCHING_IDENTIFIER
    SerializedSizeInBytesIncludingHeader: UInt64
    DeserializedSizeInBytes: UInt64
    NumBottomLevelAccelerationStructurePointersAfterHeader: UInt64
class D3D12_SET_GENERIC_PIPELINE_DESC(Structure):
    ProgramIdentifier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROGRAM_IDENTIFIER
class D3D12_SET_PROGRAM_DESC(Structure):
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROGRAM_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        GenericPipeline: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SET_GENERIC_PIPELINE_DESC
        RaytracingPipeline: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SET_RAYTRACING_PIPELINE_DESC
        WorkGraph: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SET_WORK_GRAPH_DESC
class D3D12_SET_RAYTRACING_PIPELINE_DESC(Structure):
    ProgramIdentifier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROGRAM_IDENTIFIER
class D3D12_SET_WORK_GRAPH_DESC(Structure):
    ProgramIdentifier: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROGRAM_IDENTIFIER
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SET_WORK_GRAPH_FLAGS
    BackingMemory: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_VIRTUAL_ADDRESS_RANGE
    NodeLocalRootArgumentsTable: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_VIRTUAL_ADDRESS_RANGE_AND_STRIDE
D3D12_SET_WORK_GRAPH_FLAGS = Int32
D3D12_SET_WORK_GRAPH_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SET_WORK_GRAPH_FLAGS = 0
D3D12_SET_WORK_GRAPH_FLAG_INITIALIZE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SET_WORK_GRAPH_FLAGS = 1
class D3D12_SHADER_BUFFER_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PSTR
    Type: win32more.Windows.Win32.Graphics.Direct3D.D3D_CBUFFER_TYPE
    Variables: UInt32
    Size: UInt32
    uFlags: UInt32
class D3D12_SHADER_BYTECODE(Structure):
    pShaderBytecode: VoidPtr
    BytecodeLength: UIntPtr
D3D12_SHADER_CACHE_CONTROL_FLAGS = Int32
D3D12_SHADER_CACHE_CONTROL_FLAG_DISABLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_CONTROL_FLAGS = 1
D3D12_SHADER_CACHE_CONTROL_FLAG_ENABLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_CONTROL_FLAGS = 2
D3D12_SHADER_CACHE_CONTROL_FLAG_CLEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_CONTROL_FLAGS = 4
D3D12_SHADER_CACHE_FLAGS = Int32
D3D12_SHADER_CACHE_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_FLAGS = 0
D3D12_SHADER_CACHE_FLAG_DRIVER_VERSIONED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_FLAGS = 1
D3D12_SHADER_CACHE_FLAG_USE_WORKING_DIR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_FLAGS = 2
D3D12_SHADER_CACHE_KIND_FLAGS = Int32
D3D12_SHADER_CACHE_KIND_FLAG_IMPLICIT_D3D_CACHE_FOR_DRIVER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_KIND_FLAGS = 1
D3D12_SHADER_CACHE_KIND_FLAG_IMPLICIT_D3D_CONVERSIONS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_KIND_FLAGS = 2
D3D12_SHADER_CACHE_KIND_FLAG_IMPLICIT_DRIVER_MANAGED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_KIND_FLAGS = 4
D3D12_SHADER_CACHE_KIND_FLAG_APPLICATION_MANAGED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_KIND_FLAGS = 8
D3D12_SHADER_CACHE_MODE = Int32
D3D12_SHADER_CACHE_MODE_MEMORY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_MODE = 0
D3D12_SHADER_CACHE_MODE_DISK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_MODE = 1
class D3D12_SHADER_CACHE_SESSION_DESC(Structure):
    Identifier: Guid
    Mode: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_MODE
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_FLAGS
    MaximumInMemoryCacheSizeBytes: UInt32
    MaximumInMemoryCacheEntries: UInt32
    MaximumValueFileSizeBytes: UInt32
    Version: UInt64
D3D12_SHADER_CACHE_SUPPORT_FLAGS = Int32
D3D12_SHADER_CACHE_SUPPORT_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_SUPPORT_FLAGS = 0
D3D12_SHADER_CACHE_SUPPORT_SINGLE_PSO: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_SUPPORT_FLAGS = 1
D3D12_SHADER_CACHE_SUPPORT_LIBRARY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_SUPPORT_FLAGS = 2
D3D12_SHADER_CACHE_SUPPORT_AUTOMATIC_INPROC_CACHE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_SUPPORT_FLAGS = 4
D3D12_SHADER_CACHE_SUPPORT_AUTOMATIC_DISK_CACHE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_SUPPORT_FLAGS = 8
D3D12_SHADER_CACHE_SUPPORT_DRIVER_MANAGED_CACHE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_SUPPORT_FLAGS = 16
D3D12_SHADER_CACHE_SUPPORT_SHADER_CONTROL_CLEAR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_SUPPORT_FLAGS = 32
D3D12_SHADER_CACHE_SUPPORT_SHADER_SESSION_DELETE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_SUPPORT_FLAGS = 64
D3D12_SHADER_COMPONENT_MAPPING = Int32
D3D12_SHADER_COMPONENT_MAPPING_FROM_MEMORY_COMPONENT_0: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_COMPONENT_MAPPING = 0
D3D12_SHADER_COMPONENT_MAPPING_FROM_MEMORY_COMPONENT_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_COMPONENT_MAPPING = 1
D3D12_SHADER_COMPONENT_MAPPING_FROM_MEMORY_COMPONENT_2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_COMPONENT_MAPPING = 2
D3D12_SHADER_COMPONENT_MAPPING_FROM_MEMORY_COMPONENT_3: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_COMPONENT_MAPPING = 3
D3D12_SHADER_COMPONENT_MAPPING_FORCE_VALUE_0: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_COMPONENT_MAPPING = 4
D3D12_SHADER_COMPONENT_MAPPING_FORCE_VALUE_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_COMPONENT_MAPPING = 5
class D3D12_SHADER_DESC(Structure):
    Version: UInt32
    Creator: win32more.Windows.Win32.Foundation.PSTR
    Flags: UInt32
    ConstantBuffers: UInt32
    BoundResources: UInt32
    InputParameters: UInt32
    OutputParameters: UInt32
    InstructionCount: UInt32
    TempRegisterCount: UInt32
    TempArrayCount: UInt32
    DefCount: UInt32
    DclCount: UInt32
    TextureNormalInstructions: UInt32
    TextureLoadInstructions: UInt32
    TextureCompInstructions: UInt32
    TextureBiasInstructions: UInt32
    TextureGradientInstructions: UInt32
    FloatInstructionCount: UInt32
    IntInstructionCount: UInt32
    UintInstructionCount: UInt32
    StaticFlowControlCount: UInt32
    DynamicFlowControlCount: UInt32
    MacroInstructionCount: UInt32
    ArrayInstructionCount: UInt32
    CutInstructionCount: UInt32
    EmitInstructionCount: UInt32
    GSOutputTopology: win32more.Windows.Win32.Graphics.Direct3D.D3D_PRIMITIVE_TOPOLOGY
    GSMaxOutputVertexCount: UInt32
    InputPrimitive: win32more.Windows.Win32.Graphics.Direct3D.D3D_PRIMITIVE
    PatchConstantParameters: UInt32
    cGSInstanceCount: UInt32
    cControlPoints: UInt32
    HSOutputPrimitive: win32more.Windows.Win32.Graphics.Direct3D.D3D_TESSELLATOR_OUTPUT_PRIMITIVE
    HSPartitioning: win32more.Windows.Win32.Graphics.Direct3D.D3D_TESSELLATOR_PARTITIONING
    TessellatorDomain: win32more.Windows.Win32.Graphics.Direct3D.D3D_TESSELLATOR_DOMAIN
    cBarrierInstructions: UInt32
    cInterlockedInstructions: UInt32
    cTextureStoreInstructions: UInt32
class D3D12_SHADER_INPUT_BIND_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PSTR
    Type: win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_INPUT_TYPE
    BindPoint: UInt32
    BindCount: UInt32
    uFlags: UInt32
    ReturnType: win32more.Windows.Win32.Graphics.Direct3D.D3D_RESOURCE_RETURN_TYPE
    Dimension: win32more.Windows.Win32.Graphics.Direct3D.D3D_SRV_DIMENSION
    NumSamples: UInt32
    Space: UInt32
    uID: UInt32
D3D12_SHADER_MIN_PRECISION_SUPPORT = Int32
D3D12_SHADER_MIN_PRECISION_SUPPORT_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_MIN_PRECISION_SUPPORT = 0
D3D12_SHADER_MIN_PRECISION_SUPPORT_10_BIT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_MIN_PRECISION_SUPPORT = 1
D3D12_SHADER_MIN_PRECISION_SUPPORT_16_BIT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_MIN_PRECISION_SUPPORT = 2
class D3D12_SHADER_NODE(Structure):
    Shader: win32more.Windows.Win32.Foundation.PWSTR
    OverridesType: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_OVERRIDES_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        pBroadcastingLaunchOverrides: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BROADCASTING_LAUNCH_OVERRIDES)
        pCoalescingLaunchOverrides: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COALESCING_LAUNCH_OVERRIDES)
        pThreadLaunchOverrides: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_THREAD_LAUNCH_OVERRIDES)
        pCommonComputeNodeOverrides: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMON_COMPUTE_NODE_OVERRIDES)
class D3D12_SHADER_RESOURCE_VIEW_DESC(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SRV_DIMENSION
    Shader4ComponentMapping: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Buffer: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BUFFER_SRV
        Texture1D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX1D_SRV
        Texture1DArray: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX1D_ARRAY_SRV
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX2D_SRV
        Texture2DArray: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX2D_ARRAY_SRV
        Texture2DMS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX2DMS_SRV
        Texture2DMSArray: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX2DMS_ARRAY_SRV
        Texture3D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX3D_SRV
        TextureCube: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXCUBE_SRV
        TextureCubeArray: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXCUBE_ARRAY_SRV
        RaytracingAccelerationStructure: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_SRV
class D3D12_SHADER_TYPE_DESC(Structure):
    Class: win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_VARIABLE_CLASS
    Type: win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_VARIABLE_TYPE
    Rows: UInt32
    Columns: UInt32
    Elements: UInt32
    Members: UInt32
    Offset: UInt32
    Name: win32more.Windows.Win32.Foundation.PSTR
class D3D12_SHADER_VARIABLE_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PSTR
    StartOffset: UInt32
    Size: UInt32
    uFlags: UInt32
    DefaultValue: VoidPtr
    StartTexture: UInt32
    TextureSize: UInt32
    StartSampler: UInt32
    SamplerSize: UInt32
D3D12_SHADER_VERSION_TYPE = Int32
D3D12_SHVER_PIXEL_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VERSION_TYPE = 0
D3D12_SHVER_VERTEX_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VERSION_TYPE = 1
D3D12_SHVER_GEOMETRY_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VERSION_TYPE = 2
D3D12_SHVER_HULL_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VERSION_TYPE = 3
D3D12_SHVER_DOMAIN_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VERSION_TYPE = 4
D3D12_SHVER_COMPUTE_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VERSION_TYPE = 5
D3D12_SHVER_LIBRARY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VERSION_TYPE = 6
D3D12_SHVER_RAY_GENERATION_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VERSION_TYPE = 7
D3D12_SHVER_INTERSECTION_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VERSION_TYPE = 8
D3D12_SHVER_ANY_HIT_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VERSION_TYPE = 9
D3D12_SHVER_CLOSEST_HIT_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VERSION_TYPE = 10
D3D12_SHVER_MISS_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VERSION_TYPE = 11
D3D12_SHVER_CALLABLE_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VERSION_TYPE = 12
D3D12_SHVER_MESH_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VERSION_TYPE = 13
D3D12_SHVER_AMPLIFICATION_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VERSION_TYPE = 14
D3D12_SHVER_NODE_SHADER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VERSION_TYPE = 15
D3D12_SHVER_RESERVED0: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VERSION_TYPE = 65520
D3D12_SHADER_VISIBILITY = Int32
D3D12_SHADER_VISIBILITY_ALL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VISIBILITY = 0
D3D12_SHADER_VISIBILITY_VERTEX: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VISIBILITY = 1
D3D12_SHADER_VISIBILITY_HULL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VISIBILITY = 2
D3D12_SHADER_VISIBILITY_DOMAIN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VISIBILITY = 3
D3D12_SHADER_VISIBILITY_GEOMETRY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VISIBILITY = 4
D3D12_SHADER_VISIBILITY_PIXEL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VISIBILITY = 5
D3D12_SHADER_VISIBILITY_AMPLIFICATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VISIBILITY = 6
D3D12_SHADER_VISIBILITY_MESH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VISIBILITY = 7
D3D12_SHADING_RATE = Int32
D3D12_SHADING_RATE_1X1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADING_RATE = 0
D3D12_SHADING_RATE_1X2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADING_RATE = 1
D3D12_SHADING_RATE_2X1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADING_RATE = 4
D3D12_SHADING_RATE_2X2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADING_RATE = 5
D3D12_SHADING_RATE_2X4: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADING_RATE = 6
D3D12_SHADING_RATE_4X2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADING_RATE = 9
D3D12_SHADING_RATE_4X4: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADING_RATE = 10
D3D12_SHADING_RATE_COMBINER = Int32
D3D12_SHADING_RATE_COMBINER_PASSTHROUGH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADING_RATE_COMBINER = 0
D3D12_SHADING_RATE_COMBINER_OVERRIDE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADING_RATE_COMBINER = 1
D3D12_SHADING_RATE_COMBINER_MIN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADING_RATE_COMBINER = 2
D3D12_SHADING_RATE_COMBINER_MAX: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADING_RATE_COMBINER = 3
D3D12_SHADING_RATE_COMBINER_SUM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADING_RATE_COMBINER = 4
D3D12_SHARED_RESOURCE_COMPATIBILITY_TIER = Int32
D3D12_SHARED_RESOURCE_COMPATIBILITY_TIER_0: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHARED_RESOURCE_COMPATIBILITY_TIER = 0
D3D12_SHARED_RESOURCE_COMPATIBILITY_TIER_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHARED_RESOURCE_COMPATIBILITY_TIER = 1
D3D12_SHARED_RESOURCE_COMPATIBILITY_TIER_2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHARED_RESOURCE_COMPATIBILITY_TIER = 2
class D3D12_SIGNATURE_PARAMETER_DESC(Structure):
    SemanticName: win32more.Windows.Win32.Foundation.PSTR
    SemanticIndex: UInt32
    Register: UInt32
    SystemValueType: win32more.Windows.Win32.Graphics.Direct3D.D3D_NAME
    ComponentType: win32more.Windows.Win32.Graphics.Direct3D.D3D_REGISTER_COMPONENT_TYPE
    Mask: Byte
    ReadWriteMask: Byte
    Stream: UInt32
    MinPrecision: win32more.Windows.Win32.Graphics.Direct3D.D3D_MIN_PRECISION
class D3D12_SO_DECLARATION_ENTRY(Structure):
    Stream: UInt32
    SemanticName: win32more.Windows.Win32.Foundation.PSTR
    SemanticIndex: UInt32
    StartComponent: Byte
    ComponentCount: Byte
    OutputSlot: Byte
D3D12_SRV_DIMENSION = Int32
D3D12_SRV_DIMENSION_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SRV_DIMENSION = 0
D3D12_SRV_DIMENSION_BUFFER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SRV_DIMENSION = 1
D3D12_SRV_DIMENSION_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SRV_DIMENSION = 2
D3D12_SRV_DIMENSION_TEXTURE1DARRAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SRV_DIMENSION = 3
D3D12_SRV_DIMENSION_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SRV_DIMENSION = 4
D3D12_SRV_DIMENSION_TEXTURE2DARRAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SRV_DIMENSION = 5
D3D12_SRV_DIMENSION_TEXTURE2DMS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SRV_DIMENSION = 6
D3D12_SRV_DIMENSION_TEXTURE2DMSARRAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SRV_DIMENSION = 7
D3D12_SRV_DIMENSION_TEXTURE3D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SRV_DIMENSION = 8
D3D12_SRV_DIMENSION_TEXTURECUBE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SRV_DIMENSION = 9
D3D12_SRV_DIMENSION_TEXTURECUBEARRAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SRV_DIMENSION = 10
D3D12_SRV_DIMENSION_RAYTRACING_ACCELERATION_STRUCTURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SRV_DIMENSION = 11
D3D12_STANDARD_MULTISAMPLE_QUALITY_LEVELS = Int32
D3D12_STANDARD_MULTISAMPLE_PATTERN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STANDARD_MULTISAMPLE_QUALITY_LEVELS = -1
D3D12_CENTER_MULTISAMPLE_PATTERN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STANDARD_MULTISAMPLE_QUALITY_LEVELS = -2
class D3D12_STATE_OBJECT_CONFIG(Structure):
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_OBJECT_FLAGS
class D3D12_STATE_OBJECT_DESC(Structure):
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_OBJECT_TYPE
    NumSubobjects: UInt32
    pSubobjects: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT)
D3D12_STATE_OBJECT_FLAGS = Int32
D3D12_STATE_OBJECT_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_OBJECT_FLAGS = 0
D3D12_STATE_OBJECT_FLAG_ALLOW_LOCAL_DEPENDENCIES_ON_EXTERNAL_DEFINITIONS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_OBJECT_FLAGS = 1
D3D12_STATE_OBJECT_FLAG_ALLOW_EXTERNAL_DEPENDENCIES_ON_LOCAL_DEFINITIONS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_OBJECT_FLAGS = 2
D3D12_STATE_OBJECT_FLAG_ALLOW_STATE_OBJECT_ADDITIONS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_OBJECT_FLAGS = 4
D3D12_STATE_OBJECT_TYPE = Int32
D3D12_STATE_OBJECT_TYPE_COLLECTION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_OBJECT_TYPE = 0
D3D12_STATE_OBJECT_TYPE_RAYTRACING_PIPELINE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_OBJECT_TYPE = 3
D3D12_STATE_OBJECT_TYPE_EXECUTABLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_OBJECT_TYPE = 4
class D3D12_STATE_SUBOBJECT(Structure):
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE
    pDesc: VoidPtr
D3D12_STATE_SUBOBJECT_TYPE = Int32
D3D12_STATE_SUBOBJECT_TYPE_STATE_OBJECT_CONFIG: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 0
D3D12_STATE_SUBOBJECT_TYPE_GLOBAL_ROOT_SIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 1
D3D12_STATE_SUBOBJECT_TYPE_LOCAL_ROOT_SIGNATURE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 2
D3D12_STATE_SUBOBJECT_TYPE_NODE_MASK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 3
D3D12_STATE_SUBOBJECT_TYPE_DXIL_LIBRARY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 5
D3D12_STATE_SUBOBJECT_TYPE_EXISTING_COLLECTION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 6
D3D12_STATE_SUBOBJECT_TYPE_SUBOBJECT_TO_EXPORTS_ASSOCIATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 7
D3D12_STATE_SUBOBJECT_TYPE_DXIL_SUBOBJECT_TO_EXPORTS_ASSOCIATION: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 8
D3D12_STATE_SUBOBJECT_TYPE_RAYTRACING_SHADER_CONFIG: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 9
D3D12_STATE_SUBOBJECT_TYPE_RAYTRACING_PIPELINE_CONFIG: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 10
D3D12_STATE_SUBOBJECT_TYPE_HIT_GROUP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 11
D3D12_STATE_SUBOBJECT_TYPE_RAYTRACING_PIPELINE_CONFIG1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 12
D3D12_STATE_SUBOBJECT_TYPE_WORK_GRAPH: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 13
D3D12_STATE_SUBOBJECT_TYPE_STREAM_OUTPUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 14
D3D12_STATE_SUBOBJECT_TYPE_BLEND: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 15
D3D12_STATE_SUBOBJECT_TYPE_SAMPLE_MASK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 16
D3D12_STATE_SUBOBJECT_TYPE_RASTERIZER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 17
D3D12_STATE_SUBOBJECT_TYPE_DEPTH_STENCIL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 18
D3D12_STATE_SUBOBJECT_TYPE_INPUT_LAYOUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 19
D3D12_STATE_SUBOBJECT_TYPE_IB_STRIP_CUT_VALUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 20
D3D12_STATE_SUBOBJECT_TYPE_PRIMITIVE_TOPOLOGY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 21
D3D12_STATE_SUBOBJECT_TYPE_RENDER_TARGET_FORMATS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 22
D3D12_STATE_SUBOBJECT_TYPE_DEPTH_STENCIL_FORMAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 23
D3D12_STATE_SUBOBJECT_TYPE_SAMPLE_DESC: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 24
D3D12_STATE_SUBOBJECT_TYPE_FLAGS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 26
D3D12_STATE_SUBOBJECT_TYPE_DEPTH_STENCIL1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 27
D3D12_STATE_SUBOBJECT_TYPE_VIEW_INSTANCING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 28
D3D12_STATE_SUBOBJECT_TYPE_GENERIC_PROGRAM: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 29
D3D12_STATE_SUBOBJECT_TYPE_DEPTH_STENCIL2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 30
D3D12_STATE_SUBOBJECT_TYPE_MAX_VALID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT_TYPE = 31
D3D12_STATIC_BORDER_COLOR = Int32
D3D12_STATIC_BORDER_COLOR_TRANSPARENT_BLACK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATIC_BORDER_COLOR = 0
D3D12_STATIC_BORDER_COLOR_OPAQUE_BLACK: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATIC_BORDER_COLOR = 1
D3D12_STATIC_BORDER_COLOR_OPAQUE_WHITE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATIC_BORDER_COLOR = 2
D3D12_STATIC_BORDER_COLOR_OPAQUE_BLACK_UINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATIC_BORDER_COLOR = 3
D3D12_STATIC_BORDER_COLOR_OPAQUE_WHITE_UINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATIC_BORDER_COLOR = 4
class D3D12_STATIC_SAMPLER_DESC(Structure):
    Filter: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER
    AddressU: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_ADDRESS_MODE
    AddressV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_ADDRESS_MODE
    AddressW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_ADDRESS_MODE
    MipLODBias: Single
    MaxAnisotropy: UInt32
    ComparisonFunc: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC
    BorderColor: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATIC_BORDER_COLOR
    MinLOD: Single
    MaxLOD: Single
    ShaderRegister: UInt32
    RegisterSpace: UInt32
    ShaderVisibility: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VISIBILITY
class D3D12_STATIC_SAMPLER_DESC1(Structure):
    Filter: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FILTER
    AddressU: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_ADDRESS_MODE
    AddressV: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_ADDRESS_MODE
    AddressW: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_ADDRESS_MODE
    MipLODBias: Single
    MaxAnisotropy: UInt32
    ComparisonFunc: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPARISON_FUNC
    BorderColor: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATIC_BORDER_COLOR
    MinLOD: Single
    MaxLOD: Single
    ShaderRegister: UInt32
    RegisterSpace: UInt32
    ShaderVisibility: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VISIBILITY
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SAMPLER_FLAGS
D3D12_STENCIL_OP = Int32
D3D12_STENCIL_OP_KEEP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STENCIL_OP = 1
D3D12_STENCIL_OP_ZERO: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STENCIL_OP = 2
D3D12_STENCIL_OP_REPLACE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STENCIL_OP = 3
D3D12_STENCIL_OP_INCR_SAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STENCIL_OP = 4
D3D12_STENCIL_OP_DECR_SAT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STENCIL_OP = 5
D3D12_STENCIL_OP_INVERT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STENCIL_OP = 6
D3D12_STENCIL_OP_INCR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STENCIL_OP = 7
D3D12_STENCIL_OP_DECR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STENCIL_OP = 8
class D3D12_STREAM_OUTPUT_BUFFER_VIEW(Structure):
    BufferLocation: UInt64
    SizeInBytes: UInt64
    BufferFilledSizeLocation: UInt64
class D3D12_STREAM_OUTPUT_DESC(Structure):
    pSODeclaration: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SO_DECLARATION_ENTRY)
    NumEntries: UInt32
    pBufferStrides: POINTER(UInt32)
    NumStrides: UInt32
    RasterizedStream: UInt32
class D3D12_SUBOBJECT_TO_EXPORTS_ASSOCIATION(Structure):
    pSubobjectToAssociate: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_SUBOBJECT)
    NumExports: UInt32
    pExports: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
class D3D12_SUBRESOURCE_DATA(Structure):
    pData: VoidPtr
    RowPitch: IntPtr
    SlicePitch: IntPtr
class D3D12_SUBRESOURCE_FOOTPRINT(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    Width: UInt32
    Height: UInt32
    Depth: UInt32
    RowPitch: UInt32
class D3D12_SUBRESOURCE_INFO(Structure):
    Offset: UInt64
    RowPitch: UInt32
    DepthPitch: UInt32
class D3D12_SUBRESOURCE_RANGE_UINT64(Structure):
    Subresource: UInt32
    Range: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RANGE_UINT64
class D3D12_SUBRESOURCE_TILING(Structure):
    WidthInTiles: UInt32
    HeightInTiles: UInt16
    DepthInTiles: UInt16
    StartTileIndexInOverallResource: UInt32
class D3D12_TEX1D_ARRAY_DSV(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D12_TEX1D_ARRAY_RTV(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D12_TEX1D_ARRAY_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
    ResourceMinLODClamp: Single
class D3D12_TEX1D_ARRAY_UAV(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D12_TEX1D_DSV(Structure):
    MipSlice: UInt32
class D3D12_TEX1D_RTV(Structure):
    MipSlice: UInt32
class D3D12_TEX1D_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
    ResourceMinLODClamp: Single
class D3D12_TEX1D_UAV(Structure):
    MipSlice: UInt32
class D3D12_TEX2DMS_ARRAY_DSV(Structure):
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D12_TEX2DMS_ARRAY_RTV(Structure):
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D12_TEX2DMS_ARRAY_SRV(Structure):
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D12_TEX2DMS_ARRAY_UAV(Structure):
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D12_TEX2DMS_DSV(Structure):
    UnusedField_NothingToDefine: UInt32
class D3D12_TEX2DMS_RTV(Structure):
    UnusedField_NothingToDefine: UInt32
class D3D12_TEX2DMS_SRV(Structure):
    UnusedField_NothingToDefine: UInt32
class D3D12_TEX2DMS_UAV(Structure):
    UnusedField_NothingToDefine: UInt32
class D3D12_TEX2D_ARRAY_DSV(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D12_TEX2D_ARRAY_RTV(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
    PlaneSlice: UInt32
class D3D12_TEX2D_ARRAY_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
    PlaneSlice: UInt32
    ResourceMinLODClamp: Single
class D3D12_TEX2D_ARRAY_UAV(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
    PlaneSlice: UInt32
class D3D12_TEX2D_DSV(Structure):
    MipSlice: UInt32
class D3D12_TEX2D_RTV(Structure):
    MipSlice: UInt32
    PlaneSlice: UInt32
class D3D12_TEX2D_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
    PlaneSlice: UInt32
    ResourceMinLODClamp: Single
class D3D12_TEX2D_UAV(Structure):
    MipSlice: UInt32
    PlaneSlice: UInt32
class D3D12_TEX3D_RTV(Structure):
    MipSlice: UInt32
    FirstWSlice: UInt32
    WSize: UInt32
class D3D12_TEX3D_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
    ResourceMinLODClamp: Single
class D3D12_TEX3D_UAV(Structure):
    MipSlice: UInt32
    FirstWSlice: UInt32
    WSize: UInt32
class D3D12_TEXCUBE_ARRAY_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
    First2DArrayFace: UInt32
    NumCubes: UInt32
    ResourceMinLODClamp: Single
class D3D12_TEXCUBE_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
    ResourceMinLODClamp: Single
D3D12_TEXTURE_ADDRESS_MODE = Int32
D3D12_TEXTURE_ADDRESS_MODE_WRAP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_ADDRESS_MODE = 1
D3D12_TEXTURE_ADDRESS_MODE_MIRROR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_ADDRESS_MODE = 2
D3D12_TEXTURE_ADDRESS_MODE_CLAMP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_ADDRESS_MODE = 3
D3D12_TEXTURE_ADDRESS_MODE_BORDER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_ADDRESS_MODE = 4
D3D12_TEXTURE_ADDRESS_MODE_MIRROR_ONCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_ADDRESS_MODE = 5
class D3D12_TEXTURE_BARRIER(Structure):
    SyncBefore: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC
    SyncAfter: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SYNC
    AccessBefore: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS
    AccessAfter: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS
    LayoutBefore: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT
    LayoutAfter: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT
    pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource
    Subresources: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_SUBRESOURCE_RANGE
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_BARRIER_FLAGS
D3D12_TEXTURE_BARRIER_FLAGS = Int32
D3D12_TEXTURE_BARRIER_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_BARRIER_FLAGS = 0
D3D12_TEXTURE_BARRIER_FLAG_DISCARD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_BARRIER_FLAGS = 1
class D3D12_TEXTURE_COPY_LOCATION(Structure):
    pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource
    Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_COPY_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        PlacedFootprint: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PLACED_SUBRESOURCE_FOOTPRINT
        SubresourceIndex: UInt32
D3D12_TEXTURE_COPY_TYPE = Int32
D3D12_TEXTURE_COPY_TYPE_SUBRESOURCE_INDEX: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_COPY_TYPE = 0
D3D12_TEXTURE_COPY_TYPE_PLACED_FOOTPRINT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_COPY_TYPE = 1
D3D12_TEXTURE_LAYOUT = Int32
D3D12_TEXTURE_LAYOUT_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_LAYOUT = 0
D3D12_TEXTURE_LAYOUT_ROW_MAJOR: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_LAYOUT = 1
D3D12_TEXTURE_LAYOUT_64KB_UNDEFINED_SWIZZLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_LAYOUT = 2
D3D12_TEXTURE_LAYOUT_64KB_STANDARD_SWIZZLE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_LAYOUT = 3
class D3D12_THREAD_LAUNCH_OVERRIDES(Structure):
    pLocalRootArgumentsTableIndex: POINTER(UInt32)
    pProgramEntry: POINTER(win32more.Windows.Win32.Foundation.BOOL)
    pNewName: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_ID)
    pShareInputOf: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_ID)
    NumOutputOverrides: UInt32
    pOutputOverrides: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_OUTPUT_OVERRIDES)
D3D12_TILED_RESOURCES_TIER = Int32
D3D12_TILED_RESOURCES_TIER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILED_RESOURCES_TIER = 0
D3D12_TILED_RESOURCES_TIER_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILED_RESOURCES_TIER = 1
D3D12_TILED_RESOURCES_TIER_2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILED_RESOURCES_TIER = 2
D3D12_TILED_RESOURCES_TIER_3: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILED_RESOURCES_TIER = 3
D3D12_TILED_RESOURCES_TIER_4: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILED_RESOURCES_TIER = 4
class D3D12_TILED_RESOURCE_COORDINATE(Structure):
    X: UInt32
    Y: UInt32
    Z: UInt32
    Subresource: UInt32
D3D12_TILE_COPY_FLAGS = Int32
D3D12_TILE_COPY_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_COPY_FLAGS = 0
D3D12_TILE_COPY_FLAG_NO_HAZARD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_COPY_FLAGS = 1
D3D12_TILE_COPY_FLAG_LINEAR_BUFFER_TO_SWIZZLED_TILED_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_COPY_FLAGS = 2
D3D12_TILE_COPY_FLAG_SWIZZLED_TILED_RESOURCE_TO_LINEAR_BUFFER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_COPY_FLAGS = 4
D3D12_TILE_MAPPING_FLAGS = Int32
D3D12_TILE_MAPPING_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_MAPPING_FLAGS = 0
D3D12_TILE_MAPPING_FLAG_NO_HAZARD: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_MAPPING_FLAGS = 1
D3D12_TILE_RANGE_FLAGS = Int32
D3D12_TILE_RANGE_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_RANGE_FLAGS = 0
D3D12_TILE_RANGE_FLAG_NULL: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_RANGE_FLAGS = 1
D3D12_TILE_RANGE_FLAG_SKIP: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_RANGE_FLAGS = 2
D3D12_TILE_RANGE_FLAG_REUSE_SINGLE_TILE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_RANGE_FLAGS = 4
class D3D12_TILE_REGION_SIZE(Structure):
    NumTiles: UInt32
    UseBox: win32more.Windows.Win32.Foundation.BOOL
    Width: UInt32
    Height: UInt16
    Depth: UInt16
class D3D12_TILE_SHAPE(Structure):
    WidthInTexels: UInt32
    HeightInTexels: UInt32
    DepthInTexels: UInt32
D3D12_TRI_STATE = Int32
D3D12_TRI_STATE_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TRI_STATE = -1
D3D12_TRI_STATE_FALSE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TRI_STATE = 0
D3D12_TRI_STATE_TRUE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TRI_STATE = 1
D3D12_UAV_DIMENSION = Int32
D3D12_UAV_DIMENSION_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_UAV_DIMENSION = 0
D3D12_UAV_DIMENSION_BUFFER: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_UAV_DIMENSION = 1
D3D12_UAV_DIMENSION_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_UAV_DIMENSION = 2
D3D12_UAV_DIMENSION_TEXTURE1DARRAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_UAV_DIMENSION = 3
D3D12_UAV_DIMENSION_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_UAV_DIMENSION = 4
D3D12_UAV_DIMENSION_TEXTURE2DARRAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_UAV_DIMENSION = 5
D3D12_UAV_DIMENSION_TEXTURE2DMS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_UAV_DIMENSION = 6
D3D12_UAV_DIMENSION_TEXTURE2DMSARRAY: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_UAV_DIMENSION = 7
D3D12_UAV_DIMENSION_TEXTURE3D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_UAV_DIMENSION = 8
class D3D12_UNORDERED_ACCESS_VIEW_DESC(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_UAV_DIMENSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Buffer: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BUFFER_UAV
        Texture1D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX1D_UAV
        Texture1DArray: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX1D_ARRAY_UAV
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX2D_UAV
        Texture2DArray: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX2D_ARRAY_UAV
        Texture2DMS: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX2DMS_UAV
        Texture2DMSArray: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX2DMS_ARRAY_UAV
        Texture3D: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEX3D_UAV
D3D12_VARIABLE_SHADING_RATE_TIER = Int32
D3D12_VARIABLE_SHADING_RATE_TIER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VARIABLE_SHADING_RATE_TIER = 0
D3D12_VARIABLE_SHADING_RATE_TIER_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VARIABLE_SHADING_RATE_TIER = 1
D3D12_VARIABLE_SHADING_RATE_TIER_2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VARIABLE_SHADING_RATE_TIER = 2
class D3D12_VERSIONED_DEVICE_REMOVED_EXTENDED_DATA(Structure):
    Version: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_VERSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Dred_1_0: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_REMOVED_EXTENDED_DATA
        Dred_1_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_REMOVED_EXTENDED_DATA1
        Dred_1_2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_REMOVED_EXTENDED_DATA2
        Dred_1_3: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_REMOVED_EXTENDED_DATA3
class D3D12_VERSIONED_ROOT_SIGNATURE_DESC(Structure):
    Version: win32more.Windows.Win32.Graphics.Direct3D12.D3D_ROOT_SIGNATURE_VERSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Desc_1_0: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_DESC
        Desc_1_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_DESC1
        Desc_1_2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_DESC2
class D3D12_VERTEX_BUFFER_VIEW(Structure):
    BufferLocation: UInt64
    SizeInBytes: UInt32
    StrideInBytes: UInt32
class D3D12_VIEWPORT(Structure):
    TopLeftX: Single
    TopLeftY: Single
    Width: Single
    Height: Single
    MinDepth: Single
    MaxDepth: Single
class D3D12_VIEW_INSTANCE_LOCATION(Structure):
    ViewportArrayIndex: UInt32
    RenderTargetArrayIndex: UInt32
class D3D12_VIEW_INSTANCING_DESC(Structure):
    ViewInstanceCount: UInt32
    pViewInstanceLocations: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VIEW_INSTANCE_LOCATION)
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VIEW_INSTANCING_FLAGS
D3D12_VIEW_INSTANCING_FLAGS = Int32
D3D12_VIEW_INSTANCING_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VIEW_INSTANCING_FLAGS = 0
D3D12_VIEW_INSTANCING_FLAG_ENABLE_VIEW_INSTANCE_MASKING: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VIEW_INSTANCING_FLAGS = 1
D3D12_VIEW_INSTANCING_TIER = Int32
D3D12_VIEW_INSTANCING_TIER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VIEW_INSTANCING_TIER = 0
D3D12_VIEW_INSTANCING_TIER_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VIEW_INSTANCING_TIER = 1
D3D12_VIEW_INSTANCING_TIER_2: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VIEW_INSTANCING_TIER = 2
D3D12_VIEW_INSTANCING_TIER_3: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VIEW_INSTANCING_TIER = 3
D3D12_WAVE_MMA_TIER = Int32
D3D12_WAVE_MMA_TIER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_WAVE_MMA_TIER = 0
D3D12_WAVE_MMA_TIER_1_0: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_WAVE_MMA_TIER = 10
D3D12_WORK_GRAPHS_TIER = Int32
D3D12_WORK_GRAPHS_TIER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_WORK_GRAPHS_TIER = 0
D3D12_WORK_GRAPHS_TIER_1_0: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_WORK_GRAPHS_TIER = 10
class D3D12_WORK_GRAPH_DESC(Structure):
    ProgramName: win32more.Windows.Win32.Foundation.PWSTR
    Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_WORK_GRAPH_FLAGS
    NumEntrypoints: UInt32
    pEntrypoints: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_ID)
    NumExplicitlyDefinedNodes: UInt32
    pExplicitlyDefinedNodes: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE)
D3D12_WORK_GRAPH_FLAGS = Int32
D3D12_WORK_GRAPH_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_WORK_GRAPH_FLAGS = 0
D3D12_WORK_GRAPH_FLAG_INCLUDE_ALL_AVAILABLE_NODES: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_WORK_GRAPH_FLAGS = 1
class D3D12_WORK_GRAPH_MEMORY_REQUIREMENTS(Structure):
    MinSizeInBytes: UInt64
    MaxSizeInBytes: UInt64
    SizeGranularityInBytes: UInt32
D3D12_WRITEBUFFERIMMEDIATE_MODE = Int32
D3D12_WRITEBUFFERIMMEDIATE_MODE_DEFAULT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_WRITEBUFFERIMMEDIATE_MODE = 0
D3D12_WRITEBUFFERIMMEDIATE_MODE_MARKER_IN: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_WRITEBUFFERIMMEDIATE_MODE = 1
D3D12_WRITEBUFFERIMMEDIATE_MODE_MARKER_OUT: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_WRITEBUFFERIMMEDIATE_MODE = 2
class D3D12_WRITEBUFFERIMMEDIATE_PARAMETER(Structure):
    Dest: UInt64
    Value: UInt32
D3D_ROOT_SIGNATURE_VERSION = Int32
D3D_ROOT_SIGNATURE_VERSION_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D_ROOT_SIGNATURE_VERSION = 1
D3D_ROOT_SIGNATURE_VERSION_1_0: win32more.Windows.Win32.Graphics.Direct3D12.D3D_ROOT_SIGNATURE_VERSION = 1
D3D_ROOT_SIGNATURE_VERSION_1_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D_ROOT_SIGNATURE_VERSION = 2
D3D_ROOT_SIGNATURE_VERSION_1_2: win32more.Windows.Win32.Graphics.Direct3D12.D3D_ROOT_SIGNATURE_VERSION = 3
D3D_SHADER_MODEL = Int32
D3D_SHADER_MODEL_NONE: win32more.Windows.Win32.Graphics.Direct3D12.D3D_SHADER_MODEL = 0
D3D_SHADER_MODEL_5_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D_SHADER_MODEL = 81
D3D_SHADER_MODEL_6_0: win32more.Windows.Win32.Graphics.Direct3D12.D3D_SHADER_MODEL = 96
D3D_SHADER_MODEL_6_1: win32more.Windows.Win32.Graphics.Direct3D12.D3D_SHADER_MODEL = 97
D3D_SHADER_MODEL_6_2: win32more.Windows.Win32.Graphics.Direct3D12.D3D_SHADER_MODEL = 98
D3D_SHADER_MODEL_6_3: win32more.Windows.Win32.Graphics.Direct3D12.D3D_SHADER_MODEL = 99
D3D_SHADER_MODEL_6_4: win32more.Windows.Win32.Graphics.Direct3D12.D3D_SHADER_MODEL = 100
D3D_SHADER_MODEL_6_5: win32more.Windows.Win32.Graphics.Direct3D12.D3D_SHADER_MODEL = 101
D3D_SHADER_MODEL_6_6: win32more.Windows.Win32.Graphics.Direct3D12.D3D_SHADER_MODEL = 102
D3D_SHADER_MODEL_6_7: win32more.Windows.Win32.Graphics.Direct3D12.D3D_SHADER_MODEL = 103
D3D_SHADER_MODEL_6_8: win32more.Windows.Win32.Graphics.Direct3D12.D3D_SHADER_MODEL = 104
D3D_SHADER_MODEL_6_9: win32more.Windows.Win32.Graphics.Direct3D12.D3D_SHADER_MODEL = 105
D3D_HIGHEST_SHADER_MODEL: win32more.Windows.Win32.Graphics.Direct3D12.D3D_SHADER_MODEL = 105
class ID3D12CommandAllocator(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Pageable
    _iid_ = Guid('{6102dee4-af59-4b09-b999-b44d73f09b24}')
    @commethod(8)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12CommandList(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DeviceChild
    _iid_ = Guid('{7116d91c-e7e4-47ce-b8c6-ec8168f437e5}')
    @commethod(8)
    def GetType(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_TYPE: ...
class ID3D12CommandQueue(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Pageable
    _iid_ = Guid('{0ec870a6-5d7e-4c22-8cfc-5baae07616ed}')
    @commethod(8)
    def UpdateTileMappings(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, NumResourceRegions: UInt32, pResourceRegionStartCoordinates: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILED_RESOURCE_COORDINATE), pResourceRegionSizes: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_REGION_SIZE), pHeap: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Heap, NumRanges: UInt32, pRangeFlags: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_RANGE_FLAGS), pHeapRangeStartOffsets: POINTER(UInt32), pRangeTileCounts: POINTER(UInt32), Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_MAPPING_FLAGS) -> Void: ...
    @commethod(9)
    def CopyTileMappings(self, pDstResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, pDstRegionStartCoordinate: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILED_RESOURCE_COORDINATE), pSrcResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, pSrcRegionStartCoordinate: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILED_RESOURCE_COORDINATE), pRegionSize: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_REGION_SIZE), Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_MAPPING_FLAGS) -> Void: ...
    @commethod(10)
    def ExecuteCommandLists(self, NumCommandLists: UInt32, ppCommandLists: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.ID3D12CommandList)) -> Void: ...
    @commethod(11)
    def SetMarker(self, Metadata: UInt32, pData: VoidPtr, Size: UInt32) -> Void: ...
    @commethod(12)
    def BeginEvent(self, Metadata: UInt32, pData: VoidPtr, Size: UInt32) -> Void: ...
    @commethod(13)
    def EndEvent(self) -> Void: ...
    @commethod(14)
    def Signal(self, pFence: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Fence, Value: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def Wait(self, pFence: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Fence, Value: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetTimestampFrequency(self, pFrequency: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetClockCalibration(self, pGpuTimestamp: POINTER(UInt64), pCpuTimestamp: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetDesc(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_QUEUE_DESC: ...
class ID3D12CommandSignature(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Pageable
    _iid_ = Guid('{c36a797c-ec80-4f0a-8985-a7b2475082d1}')
class ID3D12Debug(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{344488b7-6846-474b-b989-f027448245e0}')
    @commethod(3)
    def EnableDebugLayer(self) -> Void: ...
class ID3D12Debug1(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{affaa4ca-63fe-4d8e-b8ad-159000af4304}')
    @commethod(3)
    def EnableDebugLayer(self) -> Void: ...
    @commethod(4)
    def SetEnableGPUBasedValidation(self, Enable: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
    @commethod(5)
    def SetEnableSynchronizedCommandQueueValidation(self, Enable: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
class ID3D12Debug2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{93a665c4-a3b2-4e5d-b692-a26ae14e3374}')
    @commethod(3)
    def SetGPUBasedValidationFlags(self, Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_BASED_VALIDATION_FLAGS) -> Void: ...
class ID3D12Debug3(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Debug
    _iid_ = Guid('{5cf4e58f-f671-4ff1-a542-3686e3d153d1}')
    @commethod(4)
    def SetEnableGPUBasedValidation(self, Enable: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
    @commethod(5)
    def SetEnableSynchronizedCommandQueueValidation(self, Enable: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
    @commethod(6)
    def SetGPUBasedValidationFlags(self, Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_BASED_VALIDATION_FLAGS) -> Void: ...
class ID3D12Debug4(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Debug3
    _iid_ = Guid('{014b816e-9ec5-4a2f-a845-ffbe441ce13a}')
    @commethod(7)
    def DisableDebugLayer(self) -> Void: ...
class ID3D12Debug5(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Debug4
    _iid_ = Guid('{548d6b12-09fa-40e0-9069-5dcd589a52c9}')
    @commethod(8)
    def SetEnableAutoName(self, Enable: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
class ID3D12Debug6(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Debug5
    _iid_ = Guid('{82a816d6-5d01-4157-97d0-4975463fd1ed}')
    @commethod(9)
    def SetForceLegacyBarrierValidation(self, Enable: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
class ID3D12DebugCommandList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{09e0bf36-54ac-484f-8847-4baeeab6053f}')
    @commethod(3)
    def AssertResourceState(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, Subresource: UInt32, State: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(4)
    def SetFeatureMask(self, Mask: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_FEATURE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetFeatureMask(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_FEATURE: ...
class ID3D12DebugCommandList1(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{102ca951-311b-4b01-b11f-ecb83e061b37}')
    @commethod(3)
    def AssertResourceState(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, Subresource: UInt32, State: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(4)
    def SetDebugParameter(self, Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_COMMAND_LIST_PARAMETER_TYPE, pData: VoidPtr, DataSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetDebugParameter(self, Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_COMMAND_LIST_PARAMETER_TYPE, pData: VoidPtr, DataSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12DebugCommandList2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DebugCommandList
    _iid_ = Guid('{aeb575cf-4e06-48be-ba3b-c450fc96652e}')
    @commethod(6)
    def SetDebugParameter(self, Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_COMMAND_LIST_PARAMETER_TYPE, pData: VoidPtr, DataSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetDebugParameter(self, Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_COMMAND_LIST_PARAMETER_TYPE, pData: VoidPtr, DataSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12DebugCommandList3(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DebugCommandList2
    _iid_ = Guid('{197d5e15-4d37-4d34-af78-724cd70fdb1f}')
    @commethod(8)
    def AssertResourceAccess(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, Subresource: UInt32, Access: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS) -> Void: ...
    @commethod(9)
    def AssertTextureLayout(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, Subresource: UInt32, Layout: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT) -> Void: ...
class ID3D12DebugCommandQueue(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{09e0bf36-54ac-484f-8847-4baeeab6053a}')
    @commethod(3)
    def AssertResourceState(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, Subresource: UInt32, State: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
class ID3D12DebugCommandQueue1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DebugCommandQueue
    _iid_ = Guid('{16be35a2-bfd6-49f2-bcae-eaae4aff862d}')
    @commethod(4)
    def AssertResourceAccess(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, Subresource: UInt32, Access: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_ACCESS) -> Void: ...
    @commethod(5)
    def AssertTextureLayout(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, Subresource: UInt32, Layout: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT) -> Void: ...
class ID3D12DebugDevice(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3febd6dd-4973-4787-8194-e45f9e28923e}')
    @commethod(3)
    def SetFeatureMask(self, Mask: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_FEATURE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetFeatureMask(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_FEATURE: ...
    @commethod(5)
    def ReportLiveDeviceObjects(self, Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RLDO_FLAGS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12DebugDevice1(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a9b71770-d099-4a65-a698-3dee10020f88}')
    @commethod(3)
    def SetDebugParameter(self, Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_DEVICE_PARAMETER_TYPE, pData: VoidPtr, DataSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDebugParameter(self, Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_DEVICE_PARAMETER_TYPE, pData: VoidPtr, DataSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def ReportLiveDeviceObjects(self, Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RLDO_FLAGS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12DebugDevice2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DebugDevice
    _iid_ = Guid('{60eccbc1-378d-4df1-894c-f8ac5ce4d7dd}')
    @commethod(6)
    def SetDebugParameter(self, Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_DEVICE_PARAMETER_TYPE, pData: VoidPtr, DataSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetDebugParameter(self, Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEBUG_DEVICE_PARAMETER_TYPE, pData: VoidPtr, DataSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12DescriptorHeap(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Pageable
    _iid_ = Guid('{8efb471d-616c-4f49-90f7-127bb763fa51}')
    @commethod(8)
    def GetDesc(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_HEAP_DESC: ...
    @commethod(9)
    def GetCPUDescriptorHandleForHeapStart(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE: ...
    @commethod(10)
    def GetGPUDescriptorHandleForHeapStart(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_DESCRIPTOR_HANDLE: ...
class ID3D12Device(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Object
    _iid_ = Guid('{189819f1-1db6-4b57-be54-1821339b85f7}')
    @commethod(7)
    def GetNodeCount(self) -> UInt32: ...
    @commethod(8)
    def CreateCommandQueue(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_QUEUE_DESC), riid: POINTER(Guid), ppCommandQueue: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CreateCommandAllocator(self, type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_TYPE, riid: POINTER(Guid), ppCommandAllocator: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CreateGraphicsPipelineState(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_PIPELINE_STATE_DESC), riid: POINTER(Guid), ppPipelineState: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateComputePipelineState(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPUTE_PIPELINE_STATE_DESC), riid: POINTER(Guid), ppPipelineState: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def CreateCommandList(self, nodeMask: UInt32, type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_TYPE, pCommandAllocator: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12CommandAllocator, pInitialState: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12PipelineState, riid: POINTER(Guid), ppCommandList: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CheckFeatureSupport(self, Feature: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FEATURE, pFeatureSupportData: VoidPtr, FeatureSupportDataSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateDescriptorHeap(self, pDescriptorHeapDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_HEAP_DESC), riid: POINTER(Guid), ppvHeap: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetDescriptorHandleIncrementSize(self, DescriptorHeapType: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_HEAP_TYPE) -> UInt32: ...
    @commethod(16)
    def CreateRootSignature(self, nodeMask: UInt32, pBlobWithRootSignature: VoidPtr, blobLengthInBytes: UIntPtr, riid: POINTER(Guid), ppvRootSignature: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def CreateConstantBufferView(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CONSTANT_BUFFER_VIEW_DESC), DestDescriptor: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE) -> Void: ...
    @commethod(18)
    def CreateShaderResourceView(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_RESOURCE_VIEW_DESC), DestDescriptor: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE) -> Void: ...
    @commethod(19)
    def CreateUnorderedAccessView(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, pCounterResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_UNORDERED_ACCESS_VIEW_DESC), DestDescriptor: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE) -> Void: ...
    @commethod(20)
    def CreateRenderTargetView(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_TARGET_VIEW_DESC), DestDescriptor: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE) -> Void: ...
    @commethod(21)
    def CreateDepthStencilView(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEPTH_STENCIL_VIEW_DESC), DestDescriptor: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE) -> Void: ...
    @commethod(22)
    def CreateSampler(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SAMPLER_DESC), DestDescriptor: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE) -> Void: ...
    @commethod(23)
    def CopyDescriptors(self, NumDestDescriptorRanges: UInt32, pDestDescriptorRangeStarts: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE), pDestDescriptorRangeSizes: POINTER(UInt32), NumSrcDescriptorRanges: UInt32, pSrcDescriptorRangeStarts: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE), pSrcDescriptorRangeSizes: POINTER(UInt32), DescriptorHeapsType: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_HEAP_TYPE) -> Void: ...
    @commethod(24)
    def CopyDescriptorsSimple(self, NumDescriptors: UInt32, DestDescriptorRangeStart: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE, SrcDescriptorRangeStart: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE, DescriptorHeapsType: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DESCRIPTOR_HEAP_TYPE) -> Void: ...
    @commethod(25)
    def GetResourceAllocationInfo(self, visibleMask: UInt32, numResourceDescs: UInt32, pResourceDescs: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC)) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_ALLOCATION_INFO: ...
    @commethod(26)
    def GetCustomHeapProperties(self, nodeMask: UInt32, heapType: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_TYPE) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_PROPERTIES: ...
    @commethod(27)
    def CreateCommittedResource(self, pHeapProperties: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_PROPERTIES), HeapFlags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC), InitialResourceState: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES, pOptimizedClearValue: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CLEAR_VALUE), riidResource: POINTER(Guid), ppvResource: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def CreateHeap(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_DESC), riid: POINTER(Guid), ppvHeap: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def CreatePlacedResource(self, pHeap: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Heap, HeapOffset: UInt64, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC), InitialState: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES, pOptimizedClearValue: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CLEAR_VALUE), riid: POINTER(Guid), ppvResource: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def CreateReservedResource(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC), InitialState: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES, pOptimizedClearValue: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CLEAR_VALUE), riid: POINTER(Guid), ppvResource: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def CreateSharedHandle(self, pObject: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DeviceChild, pAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES), Access: UInt32, Name: win32more.Windows.Win32.Foundation.PWSTR, pHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def OpenSharedHandle(self, NTHandle: win32more.Windows.Win32.Foundation.HANDLE, riid: POINTER(Guid), ppvObj: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def OpenSharedHandleByName(self, Name: win32more.Windows.Win32.Foundation.PWSTR, Access: UInt32, pNTHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def MakeResident(self, NumObjects: UInt32, ppObjects: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Pageable)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def Evict(self, NumObjects: UInt32, ppObjects: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Pageable)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def CreateFence(self, InitialValue: UInt64, Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FENCE_FLAGS, riid: POINTER(Guid), ppFence: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetDeviceRemovedReason(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def GetCopyableFootprints(self, pResourceDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC), FirstSubresource: UInt32, NumSubresources: UInt32, BaseOffset: UInt64, pLayouts: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PLACED_SUBRESOURCE_FOOTPRINT), pNumRows: POINTER(UInt32), pRowSizeInBytes: POINTER(UInt64), pTotalBytes: POINTER(UInt64)) -> Void: ...
    @commethod(39)
    def CreateQueryHeap(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_HEAP_DESC), riid: POINTER(Guid), ppvHeap: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def SetStablePowerState(self, Enable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def CreateCommandSignature(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_SIGNATURE_DESC), pRootSignature: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12RootSignature, riid: POINTER(Guid), ppvCommandSignature: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def GetResourceTiling(self, pTiledResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, pNumTilesForEntireResource: POINTER(UInt32), pPackedMipDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PACKED_MIP_INFO), pStandardTileShapeForNonPackedMips: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_SHAPE), pNumSubresourceTilings: POINTER(UInt32), FirstSubresourceTilingToGet: UInt32, pSubresourceTilingsForNonPackedMips: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SUBRESOURCE_TILING)) -> Void: ...
    @commethod(43)
    def GetAdapterLuid(self) -> win32more.Windows.Win32.Foundation.LUID: ...
class ID3D12Device1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Device
    _iid_ = Guid('{77acce80-638e-4e65-8895-c1f23386863e}')
    @commethod(44)
    def CreatePipelineLibrary(self, pLibraryBlob: VoidPtr, BlobLength: UIntPtr, riid: POINTER(Guid), ppPipelineLibrary: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def SetEventOnMultipleFenceCompletion(self, ppFences: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Fence), pFenceValues: POINTER(UInt64), NumFences: UInt32, Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MULTIPLE_FENCE_WAIT_FLAGS, hEvent: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def SetResidencyPriority(self, NumObjects: UInt32, ppObjects: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Pageable), pPriorities: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESIDENCY_PRIORITY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12Device10(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Device9
    _iid_ = Guid('{517f8718-aa66-49f9-b02b-a7ab89c06031}')
    @commethod(76)
    def CreateCommittedResource3(self, pHeapProperties: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_PROPERTIES), HeapFlags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC1), InitialLayout: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT, pOptimizedClearValue: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CLEAR_VALUE), pProtectedSession: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ProtectedResourceSession, NumCastableFormats: UInt32, pCastableFormats: POINTER(win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT), riidResource: POINTER(Guid), ppvResource: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def CreatePlacedResource2(self, pHeap: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Heap, HeapOffset: UInt64, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC1), InitialLayout: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT, pOptimizedClearValue: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CLEAR_VALUE), NumCastableFormats: UInt32, pCastableFormats: POINTER(win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT), riid: POINTER(Guid), ppvResource: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def CreateReservedResource2(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC), InitialLayout: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_LAYOUT, pOptimizedClearValue: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CLEAR_VALUE), pProtectedSession: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ProtectedResourceSession, NumCastableFormats: UInt32, pCastableFormats: POINTER(win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT), riid: POINTER(Guid), ppvResource: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12Device11(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Device10
    _iid_ = Guid('{5405c344-d457-444e-b4dd-2366e45aee39}')
    @commethod(79)
    def CreateSampler2(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SAMPLER_DESC2), DestDescriptor: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE) -> Void: ...
class ID3D12Device12(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Device11
    _iid_ = Guid('{5af5c532-4c91-4cd0-b541-15a405395fc5}')
    @commethod(80)
    def GetResourceAllocationInfo3(self, visibleMask: UInt32, numResourceDescs: UInt32, pResourceDescs: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC1), pNumCastableFormats: POINTER(UInt32), ppCastableFormats: POINTER(POINTER(win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT)), pResourceAllocationInfo1: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_ALLOCATION_INFO1)) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_ALLOCATION_INFO: ...
class ID3D12Device13(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Device12
    _iid_ = Guid('{14eecffc-4df8-40f7-a118-5c816f45695e}')
    @commethod(81)
    def OpenExistingHeapFromAddress1(self, pAddress: VoidPtr, size: UIntPtr, riid: POINTER(Guid), ppvHeap: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12Device14(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Device13
    _iid_ = Guid('{5f6e592d-d895-44c2-8e4a-88ad4926d323}')
    @commethod(82)
    def CreateRootSignatureFromSubobjectInLibrary(self, nodeMask: UInt32, pLibraryBlob: VoidPtr, blobLengthInBytes: UIntPtr, subobjectName: win32more.Windows.Win32.Foundation.PWSTR, riid: POINTER(Guid), ppvRootSignature: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12Device2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Device1
    _iid_ = Guid('{30baa41e-b15b-475c-a0bb-1af5c5b64328}')
    @commethod(47)
    def CreatePipelineState(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_STREAM_DESC), riid: POINTER(Guid), ppPipelineState: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12Device3(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Device2
    _iid_ = Guid('{81dadc15-2bad-4392-93c5-101345c4aa98}')
    @commethod(48)
    def OpenExistingHeapFromAddress(self, pAddress: VoidPtr, riid: POINTER(Guid), ppvHeap: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def OpenExistingHeapFromFileMapping(self, hFileMapping: win32more.Windows.Win32.Foundation.HANDLE, riid: POINTER(Guid), ppvHeap: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def EnqueueMakeResident(self, Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESIDENCY_FLAGS, NumObjects: UInt32, ppObjects: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Pageable), pFenceToSignal: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Fence, FenceValueToSignal: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12Device4(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Device3
    _iid_ = Guid('{e865df17-a9ee-46f9-a463-3098315aa2e5}')
    @commethod(51)
    def CreateCommandList1(self, nodeMask: UInt32, type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_TYPE, flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_LIST_FLAGS, riid: POINTER(Guid), ppCommandList: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def CreateProtectedResourceSession(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROTECTED_RESOURCE_SESSION_DESC), riid: POINTER(Guid), ppSession: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def CreateCommittedResource1(self, pHeapProperties: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_PROPERTIES), HeapFlags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC), InitialResourceState: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES, pOptimizedClearValue: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CLEAR_VALUE), pProtectedSession: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ProtectedResourceSession, riidResource: POINTER(Guid), ppvResource: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def CreateHeap1(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_DESC), pProtectedSession: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ProtectedResourceSession, riid: POINTER(Guid), ppvHeap: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def CreateReservedResource1(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC), InitialState: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES, pOptimizedClearValue: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CLEAR_VALUE), pProtectedSession: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ProtectedResourceSession, riid: POINTER(Guid), ppvResource: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def GetResourceAllocationInfo1(self, visibleMask: UInt32, numResourceDescs: UInt32, pResourceDescs: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC), pResourceAllocationInfo1: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_ALLOCATION_INFO1)) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_ALLOCATION_INFO: ...
class ID3D12Device5(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Device4
    _iid_ = Guid('{8b4f173b-2fea-4b80-8f58-4307191ab95d}')
    @commethod(57)
    def CreateLifetimeTracker(self, pOwner: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12LifetimeOwner, riid: POINTER(Guid), ppvTracker: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def RemoveDevice(self) -> Void: ...
    @commethod(59)
    def EnumerateMetaCommands(self, pNumMetaCommands: POINTER(UInt32), pDescs: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_META_COMMAND_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def EnumerateMetaCommandParameters(self, CommandId: POINTER(Guid), Stage: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_META_COMMAND_PARAMETER_STAGE, pTotalStructureSizeInBytes: POINTER(UInt32), pParameterCount: POINTER(UInt32), pParameterDescs: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_META_COMMAND_PARAMETER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def CreateMetaCommand(self, CommandId: POINTER(Guid), NodeMask: UInt32, pCreationParametersData: VoidPtr, CreationParametersDataSizeInBytes: UIntPtr, riid: POINTER(Guid), ppMetaCommand: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def CreateStateObject(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_OBJECT_DESC), riid: POINTER(Guid), ppStateObject: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def GetRaytracingAccelerationStructurePrebuildInfo(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BUILD_RAYTRACING_ACCELERATION_STRUCTURE_INPUTS), pInfo: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_PREBUILD_INFO)) -> Void: ...
    @commethod(64)
    def CheckDriverMatchingIdentifier(self, SerializedDataType: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SERIALIZED_DATA_TYPE, pIdentifierToCheck: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SERIALIZED_DATA_DRIVER_MATCHING_IDENTIFIER)) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRIVER_MATCHING_IDENTIFIER_STATUS: ...
class ID3D12Device6(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Device5
    _iid_ = Guid('{c70b221b-40e4-4a17-89af-025a0727a6dc}')
    @commethod(65)
    def SetBackgroundProcessingMode(self, Mode: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BACKGROUND_PROCESSING_MODE, MeasurementsAction: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MEASUREMENTS_ACTION, hEventToSignalUponCompletion: win32more.Windows.Win32.Foundation.HANDLE, pbFurtherMeasurementsDesired: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12Device7(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Device6
    _iid_ = Guid('{5c014b53-68a1-4b9b-8bd1-dd6046b9358b}')
    @commethod(66)
    def AddToStateObject(self, pAddition: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STATE_OBJECT_DESC), pStateObjectToGrowFrom: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12StateObject, riid: POINTER(Guid), ppNewStateObject: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def CreateProtectedResourceSession1(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROTECTED_RESOURCE_SESSION_DESC1), riid: POINTER(Guid), ppSession: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12Device8(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Device7
    _iid_ = Guid('{9218e6bb-f944-4f7e-a75c-b1b2c7b701f3}')
    @commethod(68)
    def GetResourceAllocationInfo2(self, visibleMask: UInt32, numResourceDescs: UInt32, pResourceDescs: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC1), pResourceAllocationInfo1: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_ALLOCATION_INFO1)) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_ALLOCATION_INFO: ...
    @commethod(69)
    def CreateCommittedResource2(self, pHeapProperties: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_PROPERTIES), HeapFlags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC1), InitialResourceState: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES, pOptimizedClearValue: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CLEAR_VALUE), pProtectedSession: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ProtectedResourceSession, riidResource: POINTER(Guid), ppvResource: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def CreatePlacedResource1(self, pHeap: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Heap, HeapOffset: UInt64, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC1), InitialState: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES, pOptimizedClearValue: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CLEAR_VALUE), riid: POINTER(Guid), ppvResource: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def CreateSamplerFeedbackUnorderedAccessView(self, pTargetedResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, pFeedbackResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, DestDescriptor: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE) -> Void: ...
    @commethod(72)
    def GetCopyableFootprints1(self, pResourceDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC1), FirstSubresource: UInt32, NumSubresources: UInt32, BaseOffset: UInt64, pLayouts: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PLACED_SUBRESOURCE_FOOTPRINT), pNumRows: POINTER(UInt32), pRowSizeInBytes: POINTER(UInt64), pTotalBytes: POINTER(UInt64)) -> Void: ...
class ID3D12Device9(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Device8
    _iid_ = Guid('{4c80e962-f032-4f60-bc9e-ebc2cfa1d83c}')
    @commethod(73)
    def CreateShaderCacheSession(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_SESSION_DESC), riid: POINTER(Guid), ppvSession: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def ShaderCacheControl(self, Kinds: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_KIND_FLAGS, Control: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_CONTROL_FLAGS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def CreateCommandQueue1(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMMAND_QUEUE_DESC), CreatorID: POINTER(Guid), riid: POINTER(Guid), ppCommandQueue: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12DeviceChild(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Object
    _iid_ = Guid('{905db94b-a00c-4140-9df5-2b64ca9ea357}')
    @commethod(7)
    def GetDevice(self, riid: POINTER(Guid), ppvDevice: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12DeviceConfiguration(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{78dbf87b-f766-422b-a61c-c8c446bdb9ad}')
    @commethod(3)
    def GetDesc(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_CONFIGURATION_DESC: ...
    @commethod(4)
    def GetEnabledExperimentalFeatures(self, pGuids: POINTER(Guid), NumGuids: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SerializeVersionedRootSignature(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VERSIONED_ROOT_SIGNATURE_DESC), ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob), ppError: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateVersionedRootSignatureDeserializer(self, pBlob: VoidPtr, Size: UIntPtr, riid: POINTER(Guid), ppvDeserializer: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12DeviceConfiguration1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DeviceConfiguration
    _iid_ = Guid('{ed342442-6343-4e16-bb82-a3a577874e56}')
    @commethod(7)
    def CreateVersionedRootSignatureDeserializerFromSubobjectInLibrary(self, pLibraryBlob: VoidPtr, Size: UIntPtr, RootSignatureSubobjectName: win32more.Windows.Win32.Foundation.PWSTR, riid: POINTER(Guid), ppvDeserializer: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12DeviceFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{61f307d3-d34e-4e7c-8374-3ba4de23cccb}')
    @commethod(3)
    def InitializeFromGlobalState(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ApplyToGlobalState(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetFlags(self, flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FACTORY_FLAGS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetFlags(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DEVICE_FACTORY_FLAGS: ...
    @commethod(7)
    def GetConfigurationInterface(self, clsid: POINTER(Guid), iid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def EnableExperimentalFeatures(self, NumFeatures: UInt32, pIIDs: POINTER(Guid), pConfigurationStructs: VoidPtr, pConfigurationStructSizes: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CreateDevice(self, adapter: win32more.Windows.Win32.System.Com.IUnknown, FeatureLevel: win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL, riid: POINTER(Guid), ppvDevice: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12DeviceRemovedExtendedData(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{98931d33-5ae8-4791-aa3c-1a73a2934e71}')
    @commethod(3)
    def GetAutoBreadcrumbsOutput(self, pOutput: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_AUTO_BREADCRUMBS_OUTPUT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetPageFaultAllocationOutput(self, pOutput: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_PAGE_FAULT_OUTPUT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12DeviceRemovedExtendedData1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DeviceRemovedExtendedData
    _iid_ = Guid('{9727a022-cf1d-4dda-9eba-effa653fc506}')
    @commethod(5)
    def GetAutoBreadcrumbsOutput1(self, pOutput: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_AUTO_BREADCRUMBS_OUTPUT1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetPageFaultAllocationOutput1(self, pOutput: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_PAGE_FAULT_OUTPUT1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12DeviceRemovedExtendedData2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DeviceRemovedExtendedData1
    _iid_ = Guid('{67fc5816-e4ca-4915-bf18-42541272da54}')
    @commethod(7)
    def GetPageFaultAllocationOutput2(self, pOutput: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_PAGE_FAULT_OUTPUT2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetDeviceState(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_DEVICE_STATE: ...
class ID3D12DeviceRemovedExtendedDataSettings(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{82bc481c-6b9b-4030-aedb-7ee3d1df1e63}')
    @commethod(3)
    def SetAutoBreadcrumbsEnablement(self, Enablement: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ENABLEMENT) -> Void: ...
    @commethod(4)
    def SetPageFaultEnablement(self, Enablement: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ENABLEMENT) -> Void: ...
    @commethod(5)
    def SetWatsonDumpEnablement(self, Enablement: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ENABLEMENT) -> Void: ...
class ID3D12DeviceRemovedExtendedDataSettings1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DeviceRemovedExtendedDataSettings
    _iid_ = Guid('{dbd5ae51-3317-4f0a-adf9-1d7cedcaae0b}')
    @commethod(6)
    def SetBreadcrumbContextEnablement(self, Enablement: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DRED_ENABLEMENT) -> Void: ...
class ID3D12DeviceRemovedExtendedDataSettings2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DeviceRemovedExtendedDataSettings1
    _iid_ = Guid('{61552388-01ab-4008-a436-83db189566ea}')
    @commethod(7)
    def UseMarkersOnlyAutoBreadcrumbs(self, MarkersOnly: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
class ID3D12Fence(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Pageable
    _iid_ = Guid('{0a753dcf-c4d8-4b91-adf6-be5a60d95a76}')
    @commethod(8)
    def GetCompletedValue(self) -> UInt64: ...
    @commethod(9)
    def SetEventOnCompletion(self, Value: UInt64, hEvent: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def Signal(self, Value: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12Fence1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Fence
    _iid_ = Guid('{433685fe-e22b-4ca0-a8db-b5b4f4dd0e4a}')
    @commethod(11)
    def GetCreationFlags(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FENCE_FLAGS: ...
class ID3D12FunctionParameterReflection(ComPtr):
    extends: None
    _iid_ = Guid('{ec25f42d-7006-4f2b-b33e-02cc3375733f}')
    @commethod(0)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PARAMETER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12FunctionReflection(ComPtr):
    extends: None
    _iid_ = Guid('{1108795c-2772-4ba9-b2a8-d464dc7e2799}')
    @commethod(0)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_FUNCTION_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(1)
    def GetConstantBufferByIndex(self, BufferIndex: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionConstantBuffer: ...
    @commethod(2)
    def GetConstantBufferByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionConstantBuffer: ...
    @commethod(3)
    def GetResourceBindingDesc(self, ResourceIndex: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_INPUT_BIND_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetVariableByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionVariable: ...
    @commethod(5)
    def GetResourceBindingDescByName(self, Name: win32more.Windows.Win32.Foundation.PSTR, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_INPUT_BIND_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetFunctionParameter(self, ParameterIndex: Int32) -> win32more.Windows.Win32.Graphics.Direct3D12.ID3D12FunctionParameterReflection: ...
class ID3D12GBVDiagnostics(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{597985ab-9b75-4dbb-be23-0761195bebee}')
    @commethod(3)
    def GetGBVEntireSubresourceStatesData(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, pData: POINTER(Int32), DataSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetGBVSubresourceState(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, Subresource: UInt32, pData: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetGBVResourceUniformState(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, pData: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetGBVResourceInfo(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, pResourceDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC), pResourceHash: POINTER(UInt32), pSubresourceStatesByteOffset: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GBVReserved0(self) -> Void: ...
    @commethod(8)
    def GBVReserved1(self) -> Void: ...
class ID3D12GraphicsCommandList(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12CommandList
    _iid_ = Guid('{5b160d0f-ac1b-4185-8ba8-b3ae42a5a455}')
    @commethod(9)
    def Close(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def Reset(self, pAllocator: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12CommandAllocator, pInitialState: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12PipelineState) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def ClearState(self, pPipelineState: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12PipelineState) -> Void: ...
    @commethod(12)
    def DrawInstanced(self, VertexCountPerInstance: UInt32, InstanceCount: UInt32, StartVertexLocation: UInt32, StartInstanceLocation: UInt32) -> Void: ...
    @commethod(13)
    def DrawIndexedInstanced(self, IndexCountPerInstance: UInt32, InstanceCount: UInt32, StartIndexLocation: UInt32, BaseVertexLocation: Int32, StartInstanceLocation: UInt32) -> Void: ...
    @commethod(14)
    def Dispatch(self, ThreadGroupCountX: UInt32, ThreadGroupCountY: UInt32, ThreadGroupCountZ: UInt32) -> Void: ...
    @commethod(15)
    def CopyBufferRegion(self, pDstBuffer: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, DstOffset: UInt64, pSrcBuffer: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, SrcOffset: UInt64, NumBytes: UInt64) -> Void: ...
    @commethod(16)
    def CopyTextureRegion(self, pDst: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_COPY_LOCATION), DstX: UInt32, DstY: UInt32, DstZ: UInt32, pSrc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TEXTURE_COPY_LOCATION), pSrcBox: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BOX)) -> Void: ...
    @commethod(17)
    def CopyResource(self, pDstResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, pSrcResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource) -> Void: ...
    @commethod(18)
    def CopyTiles(self, pTiledResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, pTileRegionStartCoordinate: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILED_RESOURCE_COORDINATE), pTileRegionSize: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_REGION_SIZE), pBuffer: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, BufferStartOffsetInBytes: UInt64, Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_TILE_COPY_FLAGS) -> Void: ...
    @commethod(19)
    def ResolveSubresource(self, pDstResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, DstSubresource: UInt32, pSrcResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, SrcSubresource: UInt32, Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT) -> Void: ...
    @commethod(20)
    def IASetPrimitiveTopology(self, PrimitiveTopology: win32more.Windows.Win32.Graphics.Direct3D.D3D_PRIMITIVE_TOPOLOGY) -> Void: ...
    @commethod(21)
    def RSSetViewports(self, NumViewports: UInt32, pViewports: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VIEWPORT)) -> Void: ...
    @commethod(22)
    def RSSetScissorRects(self, NumRects: UInt32, pRects: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> Void: ...
    @commethod(23)
    def OMSetBlendFactor(self, BlendFactor: POINTER(Single)) -> Void: ...
    @commethod(24)
    def OMSetStencilRef(self, StencilRef: UInt32) -> Void: ...
    @commethod(25)
    def SetPipelineState(self, pPipelineState: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12PipelineState) -> Void: ...
    @commethod(26)
    def ResourceBarrier(self, NumBarriers: UInt32, pBarriers: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_BARRIER)) -> Void: ...
    @commethod(27)
    def ExecuteBundle(self, pCommandList: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12GraphicsCommandList) -> Void: ...
    @commethod(28)
    def SetDescriptorHeaps(self, NumDescriptorHeaps: UInt32, ppDescriptorHeaps: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DescriptorHeap)) -> Void: ...
    @commethod(29)
    def SetComputeRootSignature(self, pRootSignature: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12RootSignature) -> Void: ...
    @commethod(30)
    def SetGraphicsRootSignature(self, pRootSignature: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12RootSignature) -> Void: ...
    @commethod(31)
    def SetComputeRootDescriptorTable(self, RootParameterIndex: UInt32, BaseDescriptor: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_DESCRIPTOR_HANDLE) -> Void: ...
    @commethod(32)
    def SetGraphicsRootDescriptorTable(self, RootParameterIndex: UInt32, BaseDescriptor: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_DESCRIPTOR_HANDLE) -> Void: ...
    @commethod(33)
    def SetComputeRoot32BitConstant(self, RootParameterIndex: UInt32, SrcData: UInt32, DestOffsetIn32BitValues: UInt32) -> Void: ...
    @commethod(34)
    def SetGraphicsRoot32BitConstant(self, RootParameterIndex: UInt32, SrcData: UInt32, DestOffsetIn32BitValues: UInt32) -> Void: ...
    @commethod(35)
    def SetComputeRoot32BitConstants(self, RootParameterIndex: UInt32, Num32BitValuesToSet: UInt32, pSrcData: VoidPtr, DestOffsetIn32BitValues: UInt32) -> Void: ...
    @commethod(36)
    def SetGraphicsRoot32BitConstants(self, RootParameterIndex: UInt32, Num32BitValuesToSet: UInt32, pSrcData: VoidPtr, DestOffsetIn32BitValues: UInt32) -> Void: ...
    @commethod(37)
    def SetComputeRootConstantBufferView(self, RootParameterIndex: UInt32, BufferLocation: UInt64) -> Void: ...
    @commethod(38)
    def SetGraphicsRootConstantBufferView(self, RootParameterIndex: UInt32, BufferLocation: UInt64) -> Void: ...
    @commethod(39)
    def SetComputeRootShaderResourceView(self, RootParameterIndex: UInt32, BufferLocation: UInt64) -> Void: ...
    @commethod(40)
    def SetGraphicsRootShaderResourceView(self, RootParameterIndex: UInt32, BufferLocation: UInt64) -> Void: ...
    @commethod(41)
    def SetComputeRootUnorderedAccessView(self, RootParameterIndex: UInt32, BufferLocation: UInt64) -> Void: ...
    @commethod(42)
    def SetGraphicsRootUnorderedAccessView(self, RootParameterIndex: UInt32, BufferLocation: UInt64) -> Void: ...
    @commethod(43)
    def IASetIndexBuffer(self, pView: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDEX_BUFFER_VIEW)) -> Void: ...
    @commethod(44)
    def IASetVertexBuffers(self, StartSlot: UInt32, NumViews: UInt32, pViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VERTEX_BUFFER_VIEW)) -> Void: ...
    @commethod(45)
    def SOSetTargets(self, StartSlot: UInt32, NumViews: UInt32, pViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_STREAM_OUTPUT_BUFFER_VIEW)) -> Void: ...
    @commethod(46)
    def OMSetRenderTargets(self, NumRenderTargetDescriptors: UInt32, pRenderTargetDescriptors: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE), RTsSingleHandleToDescriptorRange: win32more.Windows.Win32.Foundation.BOOL, pDepthStencilDescriptor: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE)) -> Void: ...
    @commethod(47)
    def ClearDepthStencilView(self, DepthStencilView: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE, ClearFlags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CLEAR_FLAGS, Depth: Single, Stencil: Byte, NumRects: UInt32, pRects: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> Void: ...
    @commethod(48)
    def ClearRenderTargetView(self, RenderTargetView: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE, ColorRGBA: POINTER(Single), NumRects: UInt32, pRects: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> Void: ...
    @commethod(49)
    def ClearUnorderedAccessViewUint(self, ViewGPUHandleInCurrentHeap: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_DESCRIPTOR_HANDLE, ViewCPUHandle: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, Values: POINTER(UInt32), NumRects: UInt32, pRects: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> Void: ...
    @commethod(50)
    def ClearUnorderedAccessViewFloat(self, ViewGPUHandleInCurrentHeap: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GPU_DESCRIPTOR_HANDLE, ViewCPUHandle: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_CPU_DESCRIPTOR_HANDLE, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, Values: POINTER(Single), NumRects: UInt32, pRects: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> Void: ...
    @commethod(51)
    def DiscardResource(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, pRegion: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DISCARD_REGION)) -> Void: ...
    @commethod(52)
    def BeginQuery(self, pQueryHeap: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12QueryHeap, Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_TYPE, Index: UInt32) -> Void: ...
    @commethod(53)
    def EndQuery(self, pQueryHeap: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12QueryHeap, Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_TYPE, Index: UInt32) -> Void: ...
    @commethod(54)
    def ResolveQueryData(self, pQueryHeap: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12QueryHeap, Type: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_QUERY_TYPE, StartIndex: UInt32, NumQueries: UInt32, pDestinationBuffer: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, AlignedDestinationBufferOffset: UInt64) -> Void: ...
    @commethod(55)
    def SetPredication(self, pBuffer: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, AlignedBufferOffset: UInt64, Operation: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PREDICATION_OP) -> Void: ...
    @commethod(56)
    def SetMarker(self, Metadata: UInt32, pData: VoidPtr, Size: UInt32) -> Void: ...
    @commethod(57)
    def BeginEvent(self, Metadata: UInt32, pData: VoidPtr, Size: UInt32) -> Void: ...
    @commethod(58)
    def EndEvent(self) -> Void: ...
    @commethod(59)
    def ExecuteIndirect(self, pCommandSignature: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12CommandSignature, MaxCommandCount: UInt32, pArgumentBuffer: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, ArgumentBufferOffset: UInt64, pCountBuffer: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, CountBufferOffset: UInt64) -> Void: ...
class ID3D12GraphicsCommandList1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12GraphicsCommandList
    _iid_ = Guid('{553103fb-1fe7-4557-bb38-946d7d0e7ca7}')
    @commethod(60)
    def AtomicCopyBufferUINT(self, pDstBuffer: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, DstOffset: UInt64, pSrcBuffer: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, SrcOffset: UInt64, Dependencies: UInt32, ppDependentResources: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource), pDependentSubresourceRanges: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SUBRESOURCE_RANGE_UINT64)) -> Void: ...
    @commethod(61)
    def AtomicCopyBufferUINT64(self, pDstBuffer: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, DstOffset: UInt64, pSrcBuffer: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, SrcOffset: UInt64, Dependencies: UInt32, ppDependentResources: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource), pDependentSubresourceRanges: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SUBRESOURCE_RANGE_UINT64)) -> Void: ...
    @commethod(62)
    def OMSetDepthBounds(self, Min: Single, Max: Single) -> Void: ...
    @commethod(63)
    def SetSamplePositions(self, NumSamplesPerPixel: UInt32, NumPixels: UInt32, pSamplePositions: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SAMPLE_POSITION)) -> Void: ...
    @commethod(64)
    def ResolveSubresourceRegion(self, pDstResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, DstSubresource: UInt32, DstX: UInt32, DstY: UInt32, pSrcResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, SrcSubresource: UInt32, pSrcRect: POINTER(win32more.Windows.Win32.Foundation.RECT), Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, ResolveMode: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOLVE_MODE) -> Void: ...
    @commethod(65)
    def SetViewInstanceMask(self, Mask: UInt32) -> Void: ...
class ID3D12GraphicsCommandList10(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12GraphicsCommandList9
    _iid_ = Guid('{7013c015-d161-4b63-a08c-238552dd8acc}')
    @commethod(84)
    def SetProgram(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SET_PROGRAM_DESC)) -> Void: ...
    @commethod(85)
    def DispatchGraph(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DISPATCH_GRAPH_DESC)) -> Void: ...
class ID3D12GraphicsCommandList2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12GraphicsCommandList1
    _iid_ = Guid('{38c3e585-ff17-412c-9150-4fc6f9d72a28}')
    @commethod(66)
    def WriteBufferImmediate(self, Count: UInt32, pParams: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_WRITEBUFFERIMMEDIATE_PARAMETER), pModes: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_WRITEBUFFERIMMEDIATE_MODE)) -> Void: ...
class ID3D12GraphicsCommandList3(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12GraphicsCommandList2
    _iid_ = Guid('{6fda83a7-b84c-4e38-9ac8-c7bd22016b3d}')
    @commethod(67)
    def SetProtectedResourceSession(self, pProtectedResourceSession: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ProtectedResourceSession) -> Void: ...
class ID3D12GraphicsCommandList4(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12GraphicsCommandList3
    _iid_ = Guid('{8754318e-d3a9-4541-98cf-645b50dc4874}')
    @commethod(68)
    def BeginRenderPass(self, NumRenderTargets: UInt32, pRenderTargets: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_RENDER_TARGET_DESC), pDepthStencil: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_DEPTH_STENCIL_DESC), Flags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RENDER_PASS_FLAGS) -> Void: ...
    @commethod(69)
    def EndRenderPass(self) -> Void: ...
    @commethod(70)
    def InitializeMetaCommand(self, pMetaCommand: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12MetaCommand, pInitializationParametersData: VoidPtr, InitializationParametersDataSizeInBytes: UIntPtr) -> Void: ...
    @commethod(71)
    def ExecuteMetaCommand(self, pMetaCommand: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12MetaCommand, pExecutionParametersData: VoidPtr, ExecutionParametersDataSizeInBytes: UIntPtr) -> Void: ...
    @commethod(72)
    def BuildRaytracingAccelerationStructure(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BUILD_RAYTRACING_ACCELERATION_STRUCTURE_DESC), NumPostbuildInfoDescs: UInt32, pPostbuildInfoDescs: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_DESC)) -> Void: ...
    @commethod(73)
    def EmitRaytracingAccelerationStructurePostbuildInfo(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_DESC), NumSourceAccelerationStructures: UInt32, pSourceAccelerationStructureData: POINTER(UInt64)) -> Void: ...
    @commethod(74)
    def CopyRaytracingAccelerationStructure(self, DestAccelerationStructureData: UInt64, SourceAccelerationStructureData: UInt64, Mode: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE) -> Void: ...
    @commethod(75)
    def SetPipelineState1(self, pStateObject: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12StateObject) -> Void: ...
    @commethod(76)
    def DispatchRays(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_DISPATCH_RAYS_DESC)) -> Void: ...
class ID3D12GraphicsCommandList5(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12GraphicsCommandList4
    _iid_ = Guid('{55050859-4024-474c-87f5-6472eaee44ea}')
    @commethod(77)
    def RSSetShadingRate(self, baseShadingRate: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADING_RATE, combiners: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADING_RATE_COMBINER)) -> Void: ...
    @commethod(78)
    def RSSetShadingRateImage(self, shadingRateImage: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource) -> Void: ...
class ID3D12GraphicsCommandList6(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12GraphicsCommandList5
    _iid_ = Guid('{c3827890-e548-4cfa-96cf-5689a9370f80}')
    @commethod(79)
    def DispatchMesh(self, ThreadGroupCountX: UInt32, ThreadGroupCountY: UInt32, ThreadGroupCountZ: UInt32) -> Void: ...
class ID3D12GraphicsCommandList7(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12GraphicsCommandList6
    _iid_ = Guid('{dd171223-8b61-4769-90e3-160ccde4e2c1}')
    @commethod(80)
    def Barrier(self, NumBarrierGroups: UInt32, pBarrierGroups: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BARRIER_GROUP)) -> Void: ...
class ID3D12GraphicsCommandList8(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12GraphicsCommandList7
    _iid_ = Guid('{ee936ef9-599d-4d28-938e-23c4ad05ce51}')
    @commethod(81)
    def OMSetFrontAndBackStencilRef(self, FrontStencilRef: UInt32, BackStencilRef: UInt32) -> Void: ...
class ID3D12GraphicsCommandList9(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12GraphicsCommandList8
    _iid_ = Guid('{34ed2808-ffe6-4c2b-b11a-cabd2b0c59e1}')
    @commethod(82)
    def RSSetDepthBias(self, DepthBias: Single, DepthBiasClamp: Single, SlopeScaledDepthBias: Single) -> Void: ...
    @commethod(83)
    def IASetIndexBufferStripCutValue(self, IBStripCutValue: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INDEX_BUFFER_STRIP_CUT_VALUE) -> Void: ...
class ID3D12Heap(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Pageable
    _iid_ = Guid('{6b3b2502-6e51-45b3-90ee-9884265e8df3}')
    @commethod(8)
    def GetDesc(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_DESC: ...
class ID3D12Heap1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Heap
    _iid_ = Guid('{572f7389-2168-49e3-9693-d6df5871bf6d}')
    @commethod(9)
    def GetProtectedResourceSession(self, riid: POINTER(Guid), ppProtectedSession: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12InfoQueue(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0742a90b-c387-483f-b946-30a7e4e61458}')
    @commethod(3)
    def SetMessageCountLimit(self, MessageCountLimit: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ClearStoredMessages(self) -> Void: ...
    @commethod(5)
    def GetMessage(self, MessageIndex: UInt64, pMessage: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE), pMessageByteLength: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetNumMessagesAllowedByStorageFilter(self) -> UInt64: ...
    @commethod(7)
    def GetNumMessagesDeniedByStorageFilter(self) -> UInt64: ...
    @commethod(8)
    def GetNumStoredMessages(self) -> UInt64: ...
    @commethod(9)
    def GetNumStoredMessagesAllowedByRetrievalFilter(self) -> UInt64: ...
    @commethod(10)
    def GetNumMessagesDiscardedByMessageCountLimit(self) -> UInt64: ...
    @commethod(11)
    def GetMessageCountLimit(self) -> UInt64: ...
    @commethod(12)
    def AddStorageFilterEntries(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INFO_QUEUE_FILTER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetStorageFilter(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INFO_QUEUE_FILTER), pFilterByteLength: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def ClearStorageFilter(self) -> Void: ...
    @commethod(15)
    def PushEmptyStorageFilter(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def PushCopyOfStorageFilter(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def PushStorageFilter(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INFO_QUEUE_FILTER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def PopStorageFilter(self) -> Void: ...
    @commethod(19)
    def GetStorageFilterStackSize(self) -> UInt32: ...
    @commethod(20)
    def AddRetrievalFilterEntries(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INFO_QUEUE_FILTER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetRetrievalFilter(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INFO_QUEUE_FILTER), pFilterByteLength: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def ClearRetrievalFilter(self) -> Void: ...
    @commethod(23)
    def PushEmptyRetrievalFilter(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def PushCopyOfRetrievalFilter(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def PushRetrievalFilter(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_INFO_QUEUE_FILTER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def PopRetrievalFilter(self) -> Void: ...
    @commethod(27)
    def GetRetrievalFilterStackSize(self) -> UInt32: ...
    @commethod(28)
    def AddMessage(self, Category: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CATEGORY, Severity: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_SEVERITY, ID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID, pDescription: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def AddApplicationMessage(self, Severity: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_SEVERITY, pDescription: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def SetBreakOnCategory(self, Category: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CATEGORY, bEnable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def SetBreakOnSeverity(self, Severity: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_SEVERITY, bEnable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetBreakOnID(self, ID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID, bEnable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetBreakOnCategory(self, Category: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CATEGORY) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(34)
    def GetBreakOnSeverity(self, Severity: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_SEVERITY) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(35)
    def GetBreakOnID(self, ID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_ID) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(36)
    def SetMuteDebugOutput(self, bMute: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
    @commethod(37)
    def GetMuteDebugOutput(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
class ID3D12InfoQueue1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12InfoQueue
    _iid_ = Guid('{2852dd88-b484-4c0c-b6b1-67168500e600}')
    @commethod(38)
    def RegisterMessageCallback(self, CallbackFunc: win32more.Windows.Win32.Graphics.Direct3D12.D3D12MessageFunc, CallbackFilterFlags: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_MESSAGE_CALLBACK_FLAGS, pContext: VoidPtr, pCallbackCookie: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def UnregisterMessageCallback(self, CallbackCookie: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12LibraryReflection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8e349d19-54db-4a56-9dc9-119d87bdb804}')
    @commethod(3)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LIBRARY_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetFunctionByIndex(self, FunctionIndex: Int32) -> win32more.Windows.Win32.Graphics.Direct3D12.ID3D12FunctionReflection: ...
class ID3D12LifetimeOwner(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e667af9f-cd56-4f46-83ce-032e595d70a8}')
    @commethod(3)
    def LifetimeStateUpdated(self, NewState: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_LIFETIME_STATE) -> Void: ...
class ID3D12LifetimeTracker(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DeviceChild
    _iid_ = Guid('{3fd03d36-4eb1-424a-a582-494ecb8ba813}')
    @commethod(8)
    def DestroyOwnedObject(self, pObject: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DeviceChild) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12ManualWriteTrackingResource(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{86ca3b85-49ad-4b6e-aed5-eddb18540f41}')
    @commethod(3)
    def TrackWrite(self, Subresource: UInt32, pWrittenRange: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RANGE)) -> Void: ...
class ID3D12MetaCommand(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Pageable
    _iid_ = Guid('{dbb84c27-36ce-4fc9-b801-f048c46ac570}')
    @commethod(8)
    def GetRequiredParameterResourceSize(self, Stage: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_META_COMMAND_PARAMETER_STAGE, ParameterIndex: UInt32) -> UInt64: ...
class ID3D12Object(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c4fec28f-7966-4e95-9f94-f431cb56c3b8}')
    @commethod(3)
    def GetPrivateData(self, guid: POINTER(Guid), pDataSize: POINTER(UInt32), pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetPrivateData(self, guid: POINTER(Guid), DataSize: UInt32, pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetPrivateDataInterface(self, guid: POINTER(Guid), pData: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetName(self, Name: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12Pageable(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DeviceChild
    _iid_ = Guid('{63ee58fb-1268-4835-86da-f008ce62f0d6}')
class ID3D12PipelineLibrary(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DeviceChild
    _iid_ = Guid('{c64226a8-9201-46af-b4cc-53fb9ff7414f}')
    @commethod(8)
    def StorePipeline(self, pName: win32more.Windows.Win32.Foundation.PWSTR, pPipeline: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12PipelineState) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def LoadGraphicsPipeline(self, pName: win32more.Windows.Win32.Foundation.PWSTR, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_GRAPHICS_PIPELINE_STATE_DESC), riid: POINTER(Guid), ppPipelineState: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def LoadComputePipeline(self, pName: win32more.Windows.Win32.Foundation.PWSTR, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_COMPUTE_PIPELINE_STATE_DESC), riid: POINTER(Guid), ppPipelineState: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetSerializedSize(self) -> UIntPtr: ...
    @commethod(12)
    def Serialize(self, pData: VoidPtr, DataSizeInBytes: UIntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12PipelineLibrary1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12PipelineLibrary
    _iid_ = Guid('{80eabf42-2568-4e5e-bd82-c37f86961dc3}')
    @commethod(13)
    def LoadPipeline(self, pName: win32more.Windows.Win32.Foundation.PWSTR, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PIPELINE_STATE_STREAM_DESC), riid: POINTER(Guid), ppPipelineState: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12PipelineState(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Pageable
    _iid_ = Guid('{765a30f3-f624-4c6f-a828-ace948622445}')
    @commethod(8)
    def GetCachedBlob(self, ppBlob: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12ProtectedResourceSession(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ProtectedSession
    _iid_ = Guid('{6cd696f4-f289-40cc-8091-5a6c0a099c3d}')
    @commethod(10)
    def GetDesc(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROTECTED_RESOURCE_SESSION_DESC: ...
class ID3D12ProtectedResourceSession1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ProtectedResourceSession
    _iid_ = Guid('{d6f12dd6-76fb-406e-8961-4296eefc0409}')
    @commethod(11)
    def GetDesc1(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROTECTED_RESOURCE_SESSION_DESC1: ...
class ID3D12ProtectedSession(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DeviceChild
    _iid_ = Guid('{a1533d18-0ac1-4084-85b9-89a96116806b}')
    @commethod(8)
    def GetStatusFence(self, riid: POINTER(Guid), ppFence: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetSessionStatus(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROTECTED_SESSION_STATUS: ...
class ID3D12QueryHeap(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Pageable
    _iid_ = Guid('{0d9658ae-ed45-469e-a61d-970ec583cab4}')
class ID3D12Resource(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Pageable
    _iid_ = Guid('{696442be-a72e-4059-bc79-5b5c98040fad}')
    @commethod(8)
    def Map(self, Subresource: UInt32, pReadRange: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RANGE), ppData: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Unmap(self, Subresource: UInt32, pWrittenRange: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RANGE)) -> Void: ...
    @commethod(10)
    def GetDesc(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC: ...
    @commethod(11)
    def GetGPUVirtualAddress(self) -> UInt64: ...
    @commethod(12)
    def WriteToSubresource(self, DstSubresource: UInt32, pDstBox: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BOX), pSrcData: VoidPtr, SrcRowPitch: UInt32, SrcDepthPitch: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def ReadFromSubresource(self, pDstData: VoidPtr, DstRowPitch: UInt32, DstDepthPitch: UInt32, SrcSubresource: UInt32, pSrcBox: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_BOX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetHeapProperties(self, pHeapProperties: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_PROPERTIES), pHeapFlags: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_HEAP_FLAGS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12Resource1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource
    _iid_ = Guid('{9d5e227a-4430-4161-88b3-3eca6bb16e19}')
    @commethod(15)
    def GetProtectedResourceSession(self, riid: POINTER(Guid), ppProtectedSession: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12Resource2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource1
    _iid_ = Guid('{be36ec3b-ea85-4aeb-a45a-e9d76404a495}')
    @commethod(16)
    def GetDesc1(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_DESC1: ...
class ID3D12RootSignature(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DeviceChild
    _iid_ = Guid('{c54a6b66-72df-4ee8-8be5-a946a1429214}')
class ID3D12RootSignatureDeserializer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{34ab647b-3cc8-46ac-841b-c0965645c046}')
    @commethod(3)
    def GetRootSignatureDesc(self) -> POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_DESC): ...
class ID3D12SDKConfiguration(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e9eb5314-33aa-42b2-a718-d77f58b1f1c7}')
    @commethod(3)
    def SetSDKVersion(self, SDKVersion: UInt32, SDKPath: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12SDKConfiguration1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12SDKConfiguration
    _iid_ = Guid('{8aaf9303-ad25-48b9-9a57-d9c37e009d9f}')
    @commethod(4)
    def CreateDeviceFactory(self, SDKVersion: UInt32, SDKPath: win32more.Windows.Win32.Foundation.PSTR, riid: POINTER(Guid), ppvFactory: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def FreeUnusedSDKs(self) -> Void: ...
class ID3D12ShaderCacheSession(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DeviceChild
    _iid_ = Guid('{28e2495d-0f64-4ae4-a6ec-129255dc49a8}')
    @commethod(8)
    def FindValue(self, pKey: VoidPtr, KeySize: UInt32, pValue: VoidPtr, pValueSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def StoreValue(self, pKey: VoidPtr, KeySize: UInt32, pValue: VoidPtr, ValueSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetDeleteOnDestroy(self) -> Void: ...
    @commethod(11)
    def GetDesc(self) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_CACHE_SESSION_DESC: ...
class ID3D12ShaderReflection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5a58797d-a72c-478d-8ba2-efc6b0efe88e}')
    @commethod(3)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetConstantBufferByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionConstantBuffer: ...
    @commethod(5)
    def GetConstantBufferByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionConstantBuffer: ...
    @commethod(6)
    def GetResourceBindingDesc(self, ResourceIndex: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_INPUT_BIND_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetInputParameterDesc(self, ParameterIndex: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SIGNATURE_PARAMETER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetOutputParameterDesc(self, ParameterIndex: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SIGNATURE_PARAMETER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetPatchConstantParameterDesc(self, ParameterIndex: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SIGNATURE_PARAMETER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetVariableByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionVariable: ...
    @commethod(11)
    def GetResourceBindingDescByName(self, Name: win32more.Windows.Win32.Foundation.PSTR, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_INPUT_BIND_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetMovInstructionCount(self) -> UInt32: ...
    @commethod(13)
    def GetMovcInstructionCount(self) -> UInt32: ...
    @commethod(14)
    def GetConversionInstructionCount(self) -> UInt32: ...
    @commethod(15)
    def GetBitwiseInstructionCount(self) -> UInt32: ...
    @commethod(16)
    def GetGSInputPrimitive(self) -> win32more.Windows.Win32.Graphics.Direct3D.D3D_PRIMITIVE: ...
    @commethod(17)
    def IsSampleFrequencyShader(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(18)
    def GetNumInterfaceSlots(self) -> UInt32: ...
    @commethod(19)
    def GetMinFeatureLevel(self, pLevel: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetThreadGroupSize(self, pSizeX: POINTER(UInt32), pSizeY: POINTER(UInt32), pSizeZ: POINTER(UInt32)) -> UInt32: ...
    @commethod(21)
    def GetRequiresFlags(self) -> UInt64: ...
class ID3D12ShaderReflectionConstantBuffer(ComPtr):
    extends: None
    _iid_ = Guid('{c59598b4-48b3-4869-b9b1-b1618b14a8b7}')
    @commethod(0)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_BUFFER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(1)
    def GetVariableByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionVariable: ...
    @commethod(2)
    def GetVariableByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionVariable: ...
class ID3D12ShaderReflectionType(ComPtr):
    extends: None
    _iid_ = Guid('{e913c351-783d-48ca-a1d1-4f306284ad56}')
    @commethod(0)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_TYPE_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(1)
    def GetMemberTypeByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionType: ...
    @commethod(2)
    def GetMemberTypeByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionType: ...
    @commethod(3)
    def GetMemberTypeName(self, Index: UInt32) -> win32more.Windows.Win32.Foundation.PSTR: ...
    @commethod(4)
    def IsEqual(self, pType: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionType) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetSubType(self) -> win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionType: ...
    @commethod(6)
    def GetBaseClass(self) -> win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionType: ...
    @commethod(7)
    def GetNumInterfaces(self) -> UInt32: ...
    @commethod(8)
    def GetInterfaceByIndex(self, uIndex: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionType: ...
    @commethod(9)
    def IsOfType(self, pType: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionType) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def ImplementsInterface(self, pBase: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionType) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12ShaderReflectionVariable(ComPtr):
    extends: None
    _iid_ = Guid('{8337a8a6-a216-444a-b2f4-314733a73aea}')
    @commethod(0)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_SHADER_VARIABLE_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(1)
    def GetType(self) -> win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionType: ...
    @commethod(2)
    def GetBuffer(self) -> win32more.Windows.Win32.Graphics.Direct3D12.ID3D12ShaderReflectionConstantBuffer: ...
    @commethod(3)
    def GetInterfaceSlot(self, uArrayIndex: UInt32) -> UInt32: ...
class ID3D12SharingContract(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0adf7d52-929c-4e61-addb-ffed30de66ef}')
    @commethod(3)
    def Present(self, pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, Subresource: UInt32, window: win32more.Windows.Win32.Foundation.HWND) -> Void: ...
    @commethod(4)
    def SharedFenceSignal(self, pFence: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Fence, FenceValue: UInt64) -> Void: ...
    @commethod(5)
    def BeginCapturableWork(self, guid: POINTER(Guid)) -> Void: ...
    @commethod(6)
    def EndCapturableWork(self, guid: POINTER(Guid)) -> Void: ...
class ID3D12StateObject(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Pageable
    _iid_ = Guid('{47016943-fca8-4594-93ea-af258b55346d}')
class ID3D12StateObjectProperties(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{de5fa827-9bf9-4f26-89ff-d7f56fde3860}')
    @commethod(3)
    def GetShaderIdentifier(self, pExportName: win32more.Windows.Win32.Foundation.PWSTR) -> VoidPtr: ...
    @commethod(4)
    def GetShaderStackSize(self, pExportName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt64: ...
    @commethod(5)
    def GetPipelineStackSize(self) -> UInt64: ...
    @commethod(6)
    def SetPipelineStackSize(self, PipelineStackSizeInBytes: UInt64) -> Void: ...
class ID3D12StateObjectProperties1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12StateObjectProperties
    _iid_ = Guid('{460caac7-1d24-446a-a184-ca67db494138}')
    @commethod(7)
    def GetProgramIdentifier(self, pProgramName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_PROGRAM_IDENTIFIER: ...
class ID3D12SwapChainAssistant(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f1df64b6-57fd-49cd-8807-c0eb88b45c8f}')
    @commethod(3)
    def GetLUID(self) -> win32more.Windows.Win32.Foundation.LUID: ...
    @commethod(4)
    def GetSwapChainObject(self, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCurrentResourceAndCommandQueue(self, riidResource: POINTER(Guid), ppvResource: POINTER(VoidPtr), riidQueue: POINTER(Guid), ppvQueue: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def InsertImplicitSync(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12Tools(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7071e1f0-e84b-4b33-974f-12fa49de65c5}')
    @commethod(3)
    def EnableShaderInstrumentation(self, bEnable: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
    @commethod(4)
    def ShaderInstrumentationEnabled(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
class ID3D12VersionedRootSignatureDeserializer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7f91ce67-090c-4bb7-b78e-ed8ff2e31da0}')
    @commethod(3)
    def GetRootSignatureDescAtVersion(self, convertToVersion: win32more.Windows.Win32.Graphics.Direct3D12.D3D_ROOT_SIGNATURE_VERSION, ppDesc: POINTER(POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VERSIONED_ROOT_SIGNATURE_DESC))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetUnconvertedRootSignatureDesc(self) -> POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VERSIONED_ROOT_SIGNATURE_DESC): ...
class ID3D12VirtualizationGuestDevice(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bc66d368-7373-4943-8757-fc87dc79e476}')
    @commethod(3)
    def ShareWithHost(self, pObject: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12DeviceChild, pHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateFenceFd(self, pFence: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Fence, FenceValue: UInt64, pFenceFd: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D12WorkGraphProperties(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{065acf71-f863-4b89-82f4-02e4d5886757}')
    @commethod(3)
    def GetNumWorkGraphs(self) -> UInt32: ...
    @commethod(4)
    def GetProgramName(self, WorkGraphIndex: UInt32) -> win32more.Windows.Win32.Foundation.PWSTR: ...
    @commethod(5)
    def GetWorkGraphIndex(self, pProgramName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
    @commethod(6)
    def GetNumNodes(self, WorkGraphIndex: UInt32) -> UInt32: ...
    @commethod(7)
    def GetNodeID(self, WorkGraphIndex: UInt32, NodeIndex: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_ID: ...
    @commethod(8)
    def GetNodeIndex(self, WorkGraphIndex: UInt32, NodeID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_ID) -> UInt32: ...
    @commethod(9)
    def GetNodeLocalRootArgumentsTableIndex(self, WorkGraphIndex: UInt32, NodeIndex: UInt32) -> UInt32: ...
    @commethod(10)
    def GetNumEntrypoints(self, WorkGraphIndex: UInt32) -> UInt32: ...
    @commethod(11)
    def GetEntrypointID(self, WorkGraphIndex: UInt32, EntrypointIndex: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_ID: ...
    @commethod(12)
    def GetEntrypointIndex(self, WorkGraphIndex: UInt32, NodeID: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_NODE_ID) -> UInt32: ...
    @commethod(13)
    def GetEntrypointRecordSizeInBytes(self, WorkGraphIndex: UInt32, EntrypointIndex: UInt32) -> UInt32: ...
    @commethod(14)
    def GetWorkGraphMemoryRequirements(self, WorkGraphIndex: UInt32, pWorkGraphMemoryRequirements: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_WORK_GRAPH_MEMORY_REQUIREMENTS)) -> Void: ...
    @commethod(15)
    def GetEntrypointRecordAlignmentInBytes(self, WorkGraphIndex: UInt32, EntrypointIndex: UInt32) -> UInt32: ...
@winfunctype_pointer
def PFN_D3D12_CREATE_DEVICE(param0: win32more.Windows.Win32.System.Com.IUnknown, param1: win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL, param2: POINTER(Guid), param3: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFN_D3D12_CREATE_ROOT_SIGNATURE_DESERIALIZER(pSrcData: VoidPtr, SrcDataSizeInBytes: UIntPtr, pRootSignatureDeserializerInterface: POINTER(Guid), ppRootSignatureDeserializer: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFN_D3D12_CREATE_VERSIONED_ROOT_SIGNATURE_DESERIALIZER(pSrcData: VoidPtr, SrcDataSizeInBytes: UIntPtr, pRootSignatureDeserializerInterface: POINTER(Guid), ppRootSignatureDeserializer: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFN_D3D12_GET_DEBUG_INTERFACE(param0: POINTER(Guid), param1: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFN_D3D12_GET_INTERFACE(param0: POINTER(Guid), param1: POINTER(Guid), param2: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFN_D3D12_SERIALIZE_ROOT_SIGNATURE(pRootSignature: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_ROOT_SIGNATURE_DESC), Version: win32more.Windows.Win32.Graphics.Direct3D12.D3D_ROOT_SIGNATURE_VERSION, ppBlob: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob), ppErrorBlob: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFN_D3D12_SERIALIZE_VERSIONED_ROOT_SIGNATURE(pRootSignature: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.D3D12_VERSIONED_ROOT_SIGNATURE_DESC), ppBlob: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob), ppErrorBlob: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)
