from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.UI.Shell
import win32more.Windows.Win32.UI.WindowsAndMessaging
class ACCEL(Structure):
    fVirt: win32more.Windows.Win32.UI.WindowsAndMessaging.ACCEL_VIRT_FLAGS
    key: UInt16
    cmd: UInt16
ACCEL_VIRT_FLAGS = Byte
FVIRTKEY: win32more.Windows.Win32.UI.WindowsAndMessaging.ACCEL_VIRT_FLAGS = 1
FNOINVERT: win32more.Windows.Win32.UI.WindowsAndMessaging.ACCEL_VIRT_FLAGS = 2
FSHIFT: win32more.Windows.Win32.UI.WindowsAndMessaging.ACCEL_VIRT_FLAGS = 4
FCONTROL: win32more.Windows.Win32.UI.WindowsAndMessaging.ACCEL_VIRT_FLAGS = 8
FALT: win32more.Windows.Win32.UI.WindowsAndMessaging.ACCEL_VIRT_FLAGS = 16
class ALTTABINFO(Structure):
    cbSize: UInt32
    cItems: Int32
    cColumns: Int32
    cRows: Int32
    iColFocus: Int32
    iRowFocus: Int32
    cxItem: Int32
    cyItem: Int32
    ptStart: win32more.Windows.Win32.Foundation.POINT
ANIMATE_WINDOW_FLAGS = UInt32
AW_ACTIVATE: win32more.Windows.Win32.UI.WindowsAndMessaging.ANIMATE_WINDOW_FLAGS = 131072
AW_BLEND: win32more.Windows.Win32.UI.WindowsAndMessaging.ANIMATE_WINDOW_FLAGS = 524288
AW_CENTER: win32more.Windows.Win32.UI.WindowsAndMessaging.ANIMATE_WINDOW_FLAGS = 16
AW_HIDE: win32more.Windows.Win32.UI.WindowsAndMessaging.ANIMATE_WINDOW_FLAGS = 65536
AW_HOR_POSITIVE: win32more.Windows.Win32.UI.WindowsAndMessaging.ANIMATE_WINDOW_FLAGS = 1
AW_HOR_NEGATIVE: win32more.Windows.Win32.UI.WindowsAndMessaging.ANIMATE_WINDOW_FLAGS = 2
AW_SLIDE: win32more.Windows.Win32.UI.WindowsAndMessaging.ANIMATE_WINDOW_FLAGS = 262144
AW_VER_POSITIVE: win32more.Windows.Win32.UI.WindowsAndMessaging.ANIMATE_WINDOW_FLAGS = 4
AW_VER_NEGATIVE: win32more.Windows.Win32.UI.WindowsAndMessaging.ANIMATE_WINDOW_FLAGS = 8
class ANIMATIONINFO(Structure):
    cbSize: UInt32
    iMinAnimate: Int32
class AUDIODESCRIPTION(Structure):
    cbSize: UInt32
    Enabled: win32more.Windows.Win32.Foundation.BOOL
    Locale: UInt32
WM_CONTEXTMENU: UInt32 = 123
WM_UNICHAR: UInt32 = 265
WM_PRINTCLIENT: UInt32 = 792
WM_NOTIFY: UInt32 = 78
GUID_IO_VOLUME_CHANGE: Guid = Guid('{7373654a-812a-11d0-bec7-08002be2092f}')
GUID_IO_VOLUME_DISMOUNT: Guid = Guid('{d16a55e8-1059-11d2-8ffd-00a0c9a06d32}')
GUID_IO_VOLUME_DISMOUNT_FAILED: Guid = Guid('{e3c5b178-105d-11d2-8ffd-00a0c9a06d32}')
GUID_IO_VOLUME_MOUNT: Guid = Guid('{b5804878-1a96-11d2-8ffd-00a0c9a06d32}')
GUID_IO_VOLUME_LOCK: Guid = Guid('{50708874-c9af-11d1-8fef-00a0c9a06d32}')
GUID_IO_VOLUME_LOCK_FAILED: Guid = Guid('{ae2eed10-0ba8-11d2-8ffb-00a0c9a06d32}')
GUID_IO_VOLUME_UNLOCK: Guid = Guid('{9a8c3d68-d0cb-11d1-8fef-00a0c9a06d32}')
GUID_IO_VOLUME_NAME_CHANGE: Guid = Guid('{2de97f83-4c06-11d2-a532-00609713055a}')
GUID_IO_VOLUME_NEED_CHKDSK: Guid = Guid('{799a0960-0a0b-4e03-ad88-2fa7c6ce748a}')
GUID_IO_VOLUME_WORM_NEAR_FULL: Guid = Guid('{f3bfff82-f3de-48d2-af95-457f80b763f2}')
GUID_IO_VOLUME_WEARING_OUT: Guid = Guid('{873113ca-1486-4508-82ac-c3b2e5297aaa}')
GUID_IO_VOLUME_FORCE_CLOSED: Guid = Guid('{411ad84f-433e-4dc2-a5ae-4a2d1a2de654}')
GUID_IO_VOLUME_INFO_MAKE_COMPAT: Guid = Guid('{3ab9a0d2-ef80-45cf-8cdc-cbe02a212906}')
GUID_IO_VOLUME_PREPARING_EJECT: Guid = Guid('{c79eb16e-0dac-4e7a-a86c-b25ceeaa88f6}')
GUID_IO_VOLUME_BACKGROUND_FORMAT: Guid = Guid('{a2e5fc86-d5cd-4038-b2e3-4445065c2377}')
GUID_IO_VOLUME_PHYSICAL_CONFIGURATION_CHANGE: Guid = Guid('{2de97f84-4c06-11d2-a532-00609713055a}')
GUID_IO_VOLUME_UNIQUE_ID_CHANGE: Guid = Guid('{af39da42-6622-41f5-970b-139d092fa3d9}')
GUID_IO_VOLUME_FVE_STATUS_CHANGE: Guid = Guid('{062998b2-ee1f-4b6a-b857-e76cbbe9a6da}')
GUID_IO_VOLUME_DEVICE_INTERFACE: Guid = Guid('{53f5630d-b6bf-11d0-94f2-00a0c91efb8b}')
GUID_IO_VOLUME_CHANGE_SIZE: Guid = Guid('{3a1625be-ad03-49f1-8ef8-6bbac182d1fd}')
GUID_IO_MEDIA_ARRIVAL: Guid = Guid('{d07433c0-a98e-11d2-917a-00a0c9068ff3}')
GUID_IO_MEDIA_REMOVAL: Guid = Guid('{d07433c1-a98e-11d2-917a-00a0c9068ff3}')
GUID_IO_CDROM_EXCLUSIVE_LOCK: Guid = Guid('{bc56c139-7a10-47ee-a294-4c6a38f0149a}')
GUID_IO_CDROM_EXCLUSIVE_UNLOCK: Guid = Guid('{a3b6d27d-5e35-4885-81e5-ee18c00ed779}')
GUID_IO_DEVICE_BECOMING_READY: Guid = Guid('{d07433f0-a98e-11d2-917a-00a0c9068ff3}')
GUID_IO_DEVICE_EXTERNAL_REQUEST: Guid = Guid('{d07433d0-a98e-11d2-917a-00a0c9068ff3}')
GUID_IO_MEDIA_EJECT_REQUEST: Guid = Guid('{d07433d1-a98e-11d2-917a-00a0c9068ff3}')
GUID_IO_DRIVE_REQUIRES_CLEANING: Guid = Guid('{7207877c-90ed-44e5-a000-81428d4c79bb}')
GUID_IO_TAPE_ERASE: Guid = Guid('{852d11eb-4bb8-4507-9d9b-417cc2b1b438}')
GUID_DEVICE_EVENT_RBC: Guid = Guid('{d0744792-a98e-11d2-917a-00a0c9068ff3}')
GUID_IO_DISK_CLONE_ARRIVAL: Guid = Guid('{6a61885b-7c39-43dd-9b56-b8ac22a549aa}')
GUID_IO_DISK_LAYOUT_CHANGE: Guid = Guid('{11dff54c-8469-41f9-b3de-ef836487c54a}')
GUID_IO_DISK_HEALTH_NOTIFICATION: Guid = Guid('{0f1bd644-3916-49c5-b063-991940118fb2}')
STRSAFE_USE_SECURE_CRT: UInt32 = 0
STRSAFE_MAX_CCH: UInt32 = 2147483647
STRSAFE_MAX_LENGTH: UInt32 = 2147483646
STRSAFE_IGNORE_NULLS: UInt32 = 256
STRSAFE_FILL_BEHIND_NULL: UInt32 = 512
STRSAFE_FILL_ON_FAILURE: UInt32 = 1024
STRSAFE_NULL_ON_FAILURE: UInt32 = 2048
STRSAFE_NO_TRUNCATION: UInt32 = 4096
STRSAFE_E_INSUFFICIENT_BUFFER: win32more.Windows.Win32.Foundation.HRESULT = -2147024774
STRSAFE_E_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.HRESULT = -2147024809
STRSAFE_E_END_OF_FILE: win32more.Windows.Win32.Foundation.HRESULT = -2147024858
__WARNING_CYCLOMATIC_COMPLEXITY: UInt32 = 28734
__WARNING_USING_UNINIT_VAR: UInt32 = 6001
__WARNING_RETURN_UNINIT_VAR: UInt32 = 6101
__WARNING_DEREF_NULL_PTR: UInt32 = 6011
__WARNING_MISSING_ZERO_TERMINATION2: UInt32 = 6054
__WARNING_INVALID_PARAM_VALUE_1: UInt32 = 6387
__WARNING_INCORRECT_ANNOTATION: UInt32 = 26007
__WARNING_POTENTIAL_BUFFER_OVERFLOW_HIGH_PRIORITY: UInt32 = 26015
__WARNING_PRECONDITION_NULLTERMINATION_VIOLATION: UInt32 = 26035
__WARNING_POSTCONDITION_NULLTERMINATION_VIOLATION: UInt32 = 26036
__WARNING_HIGH_PRIORITY_OVERFLOW_POSTCONDITION: UInt32 = 26045
__WARNING_RANGE_POSTCONDITION_VIOLATION: UInt32 = 26061
__WARNING_POTENTIAL_RANGE_POSTCONDITION_VIOLATION: UInt32 = 26071
__WARNING_INVALID_PARAM_VALUE_3: UInt32 = 28183
__WARNING_RETURNING_BAD_RESULT: UInt32 = 28196
__WARNING_BANNED_API_USAGE: UInt32 = 28719
__WARNING_POST_EXPECTED: UInt32 = 28210
WM_DEVICECHANGE: UInt32 = 537
BSF_MSGSRV32ISOK: UInt32 = 2147483648
BSF_MSGSRV32ISOK_BIT: UInt32 = 31
BSM_VXDS: UInt32 = 1
BSM_NETDRIVER: UInt32 = 2
BSM_INSTALLABLEDRIVERS: UInt32 = 4
DBT_APPYBEGIN: UInt32 = 0
DBT_APPYEND: UInt32 = 1
DBT_DEVNODES_CHANGED: UInt32 = 7
DBT_QUERYCHANGECONFIG: UInt32 = 23
DBT_CONFIGCHANGED: UInt32 = 24
DBT_CONFIGCHANGECANCELED: UInt32 = 25
DBT_MONITORCHANGE: UInt32 = 27
DBT_SHELLLOGGEDON: UInt32 = 32
DBT_CONFIGMGAPI32: UInt32 = 34
DBT_VXDINITCOMPLETE: UInt32 = 35
DBT_VOLLOCKQUERYLOCK: UInt32 = 32833
DBT_VOLLOCKLOCKTAKEN: UInt32 = 32834
DBT_VOLLOCKLOCKFAILED: UInt32 = 32835
DBT_VOLLOCKQUERYUNLOCK: UInt32 = 32836
DBT_VOLLOCKLOCKRELEASED: UInt32 = 32837
DBT_VOLLOCKUNLOCKFAILED: UInt32 = 32838
LOCKP_ALLOW_WRITES: UInt32 = 1
LOCKP_FAIL_WRITES: UInt32 = 0
LOCKP_FAIL_MEM_MAPPING: UInt32 = 2
LOCKP_ALLOW_MEM_MAPPING: UInt32 = 0
LOCKP_USER_MASK: UInt32 = 3
LOCKP_LOCK_FOR_FORMAT: UInt32 = 4
LOCKF_LOGICAL_LOCK: UInt32 = 0
LOCKF_PHYSICAL_LOCK: UInt32 = 1
DBT_NO_DISK_SPACE: UInt32 = 71
DBT_LOW_DISK_SPACE: UInt32 = 72
DBT_CONFIGMGPRIVATE: UInt32 = 32767
DBT_DEVICEARRIVAL: UInt32 = 32768
DBT_DEVICEQUERYREMOVE: UInt32 = 32769
DBT_DEVICEQUERYREMOVEFAILED: UInt32 = 32770
DBT_DEVICEREMOVEPENDING: UInt32 = 32771
DBT_DEVICEREMOVECOMPLETE: UInt32 = 32772
DBT_DEVICETYPESPECIFIC: UInt32 = 32773
DBT_CUSTOMEVENT: UInt32 = 32774
DBT_DEVTYP_DEVNODE: UInt32 = 1
DBT_DEVTYP_NET: UInt32 = 4
DBTF_RESOURCE: UInt32 = 1
DBTF_XPORT: UInt32 = 2
DBTF_SLOWNET: UInt32 = 4
DBT_VPOWERDAPI: UInt32 = 33024
DBT_USERDEFINED: UInt32 = 65535
RT_CURSOR: win32more.Windows.Win32.Foundation.PWSTR = 1
RT_BITMAP: win32more.Windows.Win32.Foundation.PWSTR = 2
RT_ICON: win32more.Windows.Win32.Foundation.PWSTR = 3
RT_MENU: win32more.Windows.Win32.Foundation.PWSTR = 4
RT_DIALOG: win32more.Windows.Win32.Foundation.PWSTR = 5
RT_FONTDIR: win32more.Windows.Win32.Foundation.PWSTR = 7
RT_FONT: win32more.Windows.Win32.Foundation.PWSTR = 8
RT_ACCELERATOR: win32more.Windows.Win32.Foundation.PWSTR = 9
RT_MESSAGETABLE: win32more.Windows.Win32.Foundation.PWSTR = 11
DIFFERENCE: UInt32 = 11
RT_VERSION: win32more.Windows.Win32.Foundation.PWSTR = 16
RT_DLGINCLUDE: win32more.Windows.Win32.Foundation.PWSTR = 17
RT_PLUGPLAY: win32more.Windows.Win32.Foundation.PWSTR = 19
RT_VXD: win32more.Windows.Win32.Foundation.PWSTR = 20
RT_ANICURSOR: win32more.Windows.Win32.Foundation.PWSTR = 21
RT_ANIICON: win32more.Windows.Win32.Foundation.PWSTR = 22
RT_HTML: win32more.Windows.Win32.Foundation.PWSTR = 23
CREATEPROCESS_MANIFEST_RESOURCE_ID: UInt32 = 1
ISOLATIONAWARE_MANIFEST_RESOURCE_ID: UInt32 = 2
ISOLATIONAWARE_NOSTATICIMPORT_MANIFEST_RESOURCE_ID: UInt32 = 3
ISOLATIONPOLICY_MANIFEST_RESOURCE_ID: UInt32 = 4
ISOLATIONPOLICY_BROWSER_MANIFEST_RESOURCE_ID: UInt32 = 5
MINIMUM_RESERVED_MANIFEST_RESOURCE_ID: UInt32 = 1
MAXIMUM_RESERVED_MANIFEST_RESOURCE_ID: UInt32 = 16
HIDE_WINDOW: UInt32 = 0
SHOW_OPENWINDOW: UInt32 = 1
SHOW_ICONWINDOW: UInt32 = 2
SHOW_FULLSCREEN: UInt32 = 3
SHOW_OPENNOACTIVATE: UInt32 = 4
KF_EXTENDED: UInt32 = 256
KF_DLGMODE: UInt32 = 2048
KF_MENUMODE: UInt32 = 4096
KF_ALTDOWN: UInt32 = 8192
KF_REPEAT: UInt32 = 16384
KF_UP: UInt32 = 32768
WH_MIN: Int32 = -1
WH_HARDWARE: UInt32 = 8
WH_MAX: UInt32 = 14
WH_MINHOOK: Int32 = -1
WH_MAXHOOK: UInt32 = 14
HC_ACTION: UInt32 = 0
HC_GETNEXT: UInt32 = 1
HC_SKIP: UInt32 = 2
HC_NOREMOVE: UInt32 = 3
HC_NOREM: UInt32 = 3
HC_SYSMODALON: UInt32 = 4
HC_SYSMODALOFF: UInt32 = 5
HCBT_MOVESIZE: UInt32 = 0
HCBT_MINMAX: UInt32 = 1
HCBT_QS: UInt32 = 2
HCBT_CREATEWND: UInt32 = 3
HCBT_DESTROYWND: UInt32 = 4
HCBT_ACTIVATE: UInt32 = 5
HCBT_CLICKSKIPPED: UInt32 = 6
HCBT_KEYSKIPPED: UInt32 = 7
HCBT_SYSCOMMAND: UInt32 = 8
HCBT_SETFOCUS: UInt32 = 9
WTS_CONSOLE_CONNECT: UInt32 = 1
WTS_CONSOLE_DISCONNECT: UInt32 = 2
WTS_REMOTE_CONNECT: UInt32 = 3
WTS_REMOTE_DISCONNECT: UInt32 = 4
WTS_SESSION_LOGON: UInt32 = 5
WTS_SESSION_LOGOFF: UInt32 = 6
WTS_SESSION_LOCK: UInt32 = 7
WTS_SESSION_UNLOCK: UInt32 = 8
WTS_SESSION_REMOTE_CONTROL: UInt32 = 9
WTS_SESSION_CREATE: UInt32 = 10
WTS_SESSION_TERMINATE: UInt32 = 11
MSGF_DIALOGBOX: UInt32 = 0
MSGF_MESSAGEBOX: UInt32 = 1
MSGF_MENU: UInt32 = 2
MSGF_SCROLLBAR: UInt32 = 5
MSGF_NEXTWINDOW: UInt32 = 6
MSGF_MAX: UInt32 = 8
MSGF_USER: UInt32 = 4096
HSHELL_WINDOWCREATED: UInt32 = 1
HSHELL_WINDOWDESTROYED: UInt32 = 2
HSHELL_ACTIVATESHELLWINDOW: UInt32 = 3
HSHELL_WINDOWACTIVATED: UInt32 = 4
HSHELL_GETMINRECT: UInt32 = 5
HSHELL_REDRAW: UInt32 = 6
HSHELL_TASKMAN: UInt32 = 7
HSHELL_LANGUAGE: UInt32 = 8
HSHELL_SYSMENU: UInt32 = 9
HSHELL_ENDTASK: UInt32 = 10
HSHELL_ACCESSIBILITYSTATE: UInt32 = 11
HSHELL_APPCOMMAND: UInt32 = 12
HSHELL_WINDOWREPLACED: UInt32 = 13
HSHELL_WINDOWREPLACING: UInt32 = 14
HSHELL_MONITORCHANGED: UInt32 = 16
HSHELL_HIGHBIT: UInt32 = 32768
FAPPCOMMAND_MOUSE: UInt32 = 32768
FAPPCOMMAND_KEY: UInt32 = 0
FAPPCOMMAND_OEM: UInt32 = 4096
FAPPCOMMAND_MASK: UInt32 = 61440
LLMHF_INJECTED: UInt32 = 1
LLMHF_LOWER_IL_INJECTED: UInt32 = 2
HKL_PREV: UInt32 = 0
HKL_NEXT: UInt32 = 1
INPUTLANGCHANGE_SYSCHARSET: UInt32 = 1
INPUTLANGCHANGE_FORWARD: UInt32 = 2
INPUTLANGCHANGE_BACKWARD: UInt32 = 4
KL_NAMELENGTH: UInt32 = 9
WINSTA_ENUMDESKTOPS: Int32 = 1
WINSTA_READATTRIBUTES: Int32 = 2
WINSTA_ACCESSCLIPBOARD: Int32 = 4
WINSTA_CREATEDESKTOP: Int32 = 8
WINSTA_WRITEATTRIBUTES: Int32 = 16
WINSTA_ACCESSGLOBALATOMS: Int32 = 32
WINSTA_EXITWINDOWS: Int32 = 64
WINSTA_ENUMERATE: Int32 = 256
WINSTA_READSCREEN: Int32 = 512
CWF_CREATE_ONLY: UInt32 = 1
WSF_VISIBLE: Int32 = 1
UOI_TIMERPROC_EXCEPTION_SUPPRESSION: UInt32 = 7
WM_NULL: UInt32 = 0
WM_CREATE: UInt32 = 1
WM_DESTROY: UInt32 = 2
WM_MOVE: UInt32 = 3
WM_SIZE: UInt32 = 5
WM_ACTIVATE: UInt32 = 6
WA_INACTIVE: UInt32 = 0
WA_ACTIVE: UInt32 = 1
WA_CLICKACTIVE: UInt32 = 2
WM_SETFOCUS: UInt32 = 7
WM_KILLFOCUS: UInt32 = 8
WM_ENABLE: UInt32 = 10
WM_SETREDRAW: UInt32 = 11
WM_SETTEXT: UInt32 = 12
WM_GETTEXT: UInt32 = 13
WM_GETTEXTLENGTH: UInt32 = 14
WM_PAINT: UInt32 = 15
WM_CLOSE: UInt32 = 16
WM_QUERYENDSESSION: UInt32 = 17
WM_QUERYOPEN: UInt32 = 19
WM_ENDSESSION: UInt32 = 22
WM_QUIT: UInt32 = 18
WM_ERASEBKGND: UInt32 = 20
WM_SYSCOLORCHANGE: UInt32 = 21
WM_SHOWWINDOW: UInt32 = 24
WM_WININICHANGE: UInt32 = 26
WM_SETTINGCHANGE: UInt32 = 26
WM_DEVMODECHANGE: UInt32 = 27
WM_ACTIVATEAPP: UInt32 = 28
WM_FONTCHANGE: UInt32 = 29
WM_TIMECHANGE: UInt32 = 30
WM_CANCELMODE: UInt32 = 31
WM_SETCURSOR: UInt32 = 32
WM_MOUSEACTIVATE: UInt32 = 33
WM_CHILDACTIVATE: UInt32 = 34
WM_QUEUESYNC: UInt32 = 35
WM_GETMINMAXINFO: UInt32 = 36
WM_PAINTICON: UInt32 = 38
WM_ICONERASEBKGND: UInt32 = 39
WM_NEXTDLGCTL: UInt32 = 40
WM_SPOOLERSTATUS: UInt32 = 42
WM_DRAWITEM: UInt32 = 43
WM_MEASUREITEM: UInt32 = 44
WM_DELETEITEM: UInt32 = 45
WM_VKEYTOITEM: UInt32 = 46
WM_CHARTOITEM: UInt32 = 47
WM_SETFONT: UInt32 = 48
WM_GETFONT: UInt32 = 49
WM_SETHOTKEY: UInt32 = 50
WM_GETHOTKEY: UInt32 = 51
WM_QUERYDRAGICON: UInt32 = 55
WM_COMPAREITEM: UInt32 = 57
WM_GETOBJECT: UInt32 = 61
WM_COMPACTING: UInt32 = 65
WM_COMMNOTIFY: UInt32 = 68
WM_WINDOWPOSCHANGING: UInt32 = 70
WM_WINDOWPOSCHANGED: UInt32 = 71
WM_POWER: UInt32 = 72
PWR_OK: UInt32 = 1
PWR_FAIL: Int32 = -1
PWR_SUSPENDREQUEST: UInt32 = 1
PWR_SUSPENDRESUME: UInt32 = 2
PWR_CRITICALRESUME: UInt32 = 3
WM_COPYDATA: UInt32 = 74
WM_CANCELJOURNAL: UInt32 = 75
WM_INPUTLANGCHANGEREQUEST: UInt32 = 80
WM_INPUTLANGCHANGE: UInt32 = 81
WM_TCARD: UInt32 = 82
WM_HELP: UInt32 = 83
WM_USERCHANGED: UInt32 = 84
WM_NOTIFYFORMAT: UInt32 = 85
NFR_ANSI: UInt32 = 1
NFR_UNICODE: UInt32 = 2
NF_QUERY: UInt32 = 3
NF_REQUERY: UInt32 = 4
WM_STYLECHANGING: UInt32 = 124
WM_STYLECHANGED: UInt32 = 125
WM_DISPLAYCHANGE: UInt32 = 126
WM_GETICON: UInt32 = 127
WM_SETICON: UInt32 = 128
WM_NCCREATE: UInt32 = 129
WM_NCDESTROY: UInt32 = 130
WM_NCCALCSIZE: UInt32 = 131
WM_NCHITTEST: UInt32 = 132
WM_NCPAINT: UInt32 = 133
WM_NCACTIVATE: UInt32 = 134
WM_GETDLGCODE: UInt32 = 135
WM_SYNCPAINT: UInt32 = 136
WM_NCMOUSEMOVE: UInt32 = 160
WM_NCLBUTTONDOWN: UInt32 = 161
WM_NCLBUTTONUP: UInt32 = 162
WM_NCLBUTTONDBLCLK: UInt32 = 163
WM_NCRBUTTONDOWN: UInt32 = 164
WM_NCRBUTTONUP: UInt32 = 165
WM_NCRBUTTONDBLCLK: UInt32 = 166
WM_NCMBUTTONDOWN: UInt32 = 167
WM_NCMBUTTONUP: UInt32 = 168
WM_NCMBUTTONDBLCLK: UInt32 = 169
WM_NCXBUTTONDOWN: UInt32 = 171
WM_NCXBUTTONUP: UInt32 = 172
WM_NCXBUTTONDBLCLK: UInt32 = 173
WM_INPUT_DEVICE_CHANGE: UInt32 = 254
WM_INPUT: UInt32 = 255
WM_KEYFIRST: UInt32 = 256
WM_KEYDOWN: UInt32 = 256
WM_KEYUP: UInt32 = 257
WM_CHAR: UInt32 = 258
WM_DEADCHAR: UInt32 = 259
WM_SYSKEYDOWN: UInt32 = 260
WM_SYSKEYUP: UInt32 = 261
WM_SYSCHAR: UInt32 = 262
WM_SYSDEADCHAR: UInt32 = 263
WM_KEYLAST: UInt32 = 265
UNICODE_NOCHAR: UInt32 = 65535
WM_IME_STARTCOMPOSITION: UInt32 = 269
WM_IME_ENDCOMPOSITION: UInt32 = 270
WM_IME_COMPOSITION: UInt32 = 271
WM_IME_KEYLAST: UInt32 = 271
WM_INITDIALOG: UInt32 = 272
WM_COMMAND: UInt32 = 273
WM_SYSCOMMAND: UInt32 = 274
WM_TIMER: UInt32 = 275
WM_HSCROLL: UInt32 = 276
WM_VSCROLL: UInt32 = 277
WM_INITMENU: UInt32 = 278
WM_INITMENUPOPUP: UInt32 = 279
WM_GESTURE: UInt32 = 281
WM_GESTURENOTIFY: UInt32 = 282
WM_MENUSELECT: UInt32 = 287
WM_MENUCHAR: UInt32 = 288
WM_ENTERIDLE: UInt32 = 289
WM_MENURBUTTONUP: UInt32 = 290
WM_MENUDRAG: UInt32 = 291
WM_MENUGETOBJECT: UInt32 = 292
WM_UNINITMENUPOPUP: UInt32 = 293
WM_MENUCOMMAND: UInt32 = 294
WM_CHANGEUISTATE: UInt32 = 295
WM_UPDATEUISTATE: UInt32 = 296
WM_QUERYUISTATE: UInt32 = 297
UIS_SET: UInt32 = 1
UIS_CLEAR: UInt32 = 2
UIS_INITIALIZE: UInt32 = 3
UISF_HIDEFOCUS: UInt32 = 1
UISF_HIDEACCEL: UInt32 = 2
UISF_ACTIVE: UInt32 = 4
WM_CTLCOLORMSGBOX: UInt32 = 306
WM_CTLCOLOREDIT: UInt32 = 307
WM_CTLCOLORLISTBOX: UInt32 = 308
WM_CTLCOLORBTN: UInt32 = 309
WM_CTLCOLORDLG: UInt32 = 310
WM_CTLCOLORSCROLLBAR: UInt32 = 311
WM_CTLCOLORSTATIC: UInt32 = 312
MN_GETHMENU: UInt32 = 481
WM_MOUSEFIRST: UInt32 = 512
WM_MOUSEMOVE: UInt32 = 512
WM_LBUTTONDOWN: UInt32 = 513
WM_LBUTTONUP: UInt32 = 514
WM_LBUTTONDBLCLK: UInt32 = 515
WM_RBUTTONDOWN: UInt32 = 516
WM_RBUTTONUP: UInt32 = 517
WM_RBUTTONDBLCLK: UInt32 = 518
WM_MBUTTONDOWN: UInt32 = 519
WM_MBUTTONUP: UInt32 = 520
WM_MBUTTONDBLCLK: UInt32 = 521
WM_MOUSEWHEEL: UInt32 = 522
WM_XBUTTONDOWN: UInt32 = 523
WM_XBUTTONUP: UInt32 = 524
WM_XBUTTONDBLCLK: UInt32 = 525
WM_MOUSEHWHEEL: UInt32 = 526
WM_MOUSELAST: UInt32 = 526
WHEEL_DELTA: UInt32 = 120
XBUTTON1: UInt16 = 1
XBUTTON2: UInt16 = 2
WM_PARENTNOTIFY: UInt32 = 528
WM_ENTERMENULOOP: UInt32 = 529
WM_EXITMENULOOP: UInt32 = 530
WM_NEXTMENU: UInt32 = 531
WM_SIZING: UInt32 = 532
WM_CAPTURECHANGED: UInt32 = 533
WM_MOVING: UInt32 = 534
WM_POWERBROADCAST: UInt32 = 536
PBT_APMQUERYSUSPEND: UInt32 = 0
PBT_APMQUERYSTANDBY: UInt32 = 1
PBT_APMQUERYSUSPENDFAILED: UInt32 = 2
PBT_APMQUERYSTANDBYFAILED: UInt32 = 3
PBT_APMSUSPEND: UInt32 = 4
PBT_APMSTANDBY: UInt32 = 5
PBT_APMRESUMECRITICAL: UInt32 = 6
PBT_APMRESUMESUSPEND: UInt32 = 7
PBT_APMRESUMESTANDBY: UInt32 = 8
PBTF_APMRESUMEFROMFAILURE: UInt32 = 1
PBT_APMBATTERYLOW: UInt32 = 9
PBT_APMPOWERSTATUSCHANGE: UInt32 = 10
PBT_APMOEMEVENT: UInt32 = 11
PBT_APMRESUMEAUTOMATIC: UInt32 = 18
PBT_POWERSETTINGCHANGE: UInt32 = 32787
WM_MDICREATE: UInt32 = 544
WM_MDIDESTROY: UInt32 = 545
WM_MDIACTIVATE: UInt32 = 546
WM_MDIRESTORE: UInt32 = 547
WM_MDINEXT: UInt32 = 548
WM_MDIMAXIMIZE: UInt32 = 549
WM_MDITILE: UInt32 = 550
WM_MDICASCADE: UInt32 = 551
WM_MDIICONARRANGE: UInt32 = 552
WM_MDIGETACTIVE: UInt32 = 553
WM_MDISETMENU: UInt32 = 560
WM_ENTERSIZEMOVE: UInt32 = 561
WM_EXITSIZEMOVE: UInt32 = 562
WM_DROPFILES: UInt32 = 563
WM_MDIREFRESHMENU: UInt32 = 564
WM_POINTERDEVICECHANGE: UInt32 = 568
WM_POINTERDEVICEINRANGE: UInt32 = 569
WM_POINTERDEVICEOUTOFRANGE: UInt32 = 570
WM_TOUCH: UInt32 = 576
WM_NCPOINTERUPDATE: UInt32 = 577
WM_NCPOINTERDOWN: UInt32 = 578
WM_NCPOINTERUP: UInt32 = 579
WM_POINTERUPDATE: UInt32 = 581
WM_POINTERDOWN: UInt32 = 582
WM_POINTERUP: UInt32 = 583
WM_POINTERENTER: UInt32 = 585
WM_POINTERLEAVE: UInt32 = 586
WM_POINTERACTIVATE: UInt32 = 587
WM_POINTERCAPTURECHANGED: UInt32 = 588
WM_TOUCHHITTESTING: UInt32 = 589
WM_POINTERWHEEL: UInt32 = 590
WM_POINTERHWHEEL: UInt32 = 591
DM_POINTERHITTEST: UInt32 = 592
WM_POINTERROUTEDTO: UInt32 = 593
WM_POINTERROUTEDAWAY: UInt32 = 594
WM_POINTERROUTEDRELEASED: UInt32 = 595
WM_IME_SETCONTEXT: UInt32 = 641
WM_IME_NOTIFY: UInt32 = 642
WM_IME_CONTROL: UInt32 = 643
WM_IME_COMPOSITIONFULL: UInt32 = 644
WM_IME_SELECT: UInt32 = 645
WM_IME_CHAR: UInt32 = 646
WM_IME_REQUEST: UInt32 = 648
WM_IME_KEYDOWN: UInt32 = 656
WM_IME_KEYUP: UInt32 = 657
WM_NCMOUSEHOVER: UInt32 = 672
WM_NCMOUSELEAVE: UInt32 = 674
WM_WTSSESSION_CHANGE: UInt32 = 689
WM_TABLET_FIRST: UInt32 = 704
WM_TABLET_LAST: UInt32 = 735
WM_DPICHANGED: UInt32 = 736
WM_DPICHANGED_BEFOREPARENT: UInt32 = 738
WM_DPICHANGED_AFTERPARENT: UInt32 = 739
WM_GETDPISCALEDSIZE: UInt32 = 740
WM_CUT: UInt32 = 768
WM_COPY: UInt32 = 769
WM_PASTE: UInt32 = 770
WM_CLEAR: UInt32 = 771
WM_UNDO: UInt32 = 772
WM_RENDERFORMAT: UInt32 = 773
WM_RENDERALLFORMATS: UInt32 = 774
WM_DESTROYCLIPBOARD: UInt32 = 775
WM_DRAWCLIPBOARD: UInt32 = 776
WM_PAINTCLIPBOARD: UInt32 = 777
WM_VSCROLLCLIPBOARD: UInt32 = 778
WM_SIZECLIPBOARD: UInt32 = 779
WM_ASKCBFORMATNAME: UInt32 = 780
WM_CHANGECBCHAIN: UInt32 = 781
WM_HSCROLLCLIPBOARD: UInt32 = 782
WM_QUERYNEWPALETTE: UInt32 = 783
WM_PALETTEISCHANGING: UInt32 = 784
WM_PALETTECHANGED: UInt32 = 785
WM_HOTKEY: UInt32 = 786
WM_PRINT: UInt32 = 791
WM_APPCOMMAND: UInt32 = 793
WM_THEMECHANGED: UInt32 = 794
WM_CLIPBOARDUPDATE: UInt32 = 797
WM_DWMCOMPOSITIONCHANGED: UInt32 = 798
WM_DWMNCRENDERINGCHANGED: UInt32 = 799
WM_DWMCOLORIZATIONCOLORCHANGED: UInt32 = 800
WM_DWMWINDOWMAXIMIZEDCHANGE: UInt32 = 801
WM_DWMSENDICONICTHUMBNAIL: UInt32 = 803
WM_DWMSENDICONICLIVEPREVIEWBITMAP: UInt32 = 806
WM_GETTITLEBARINFOEX: UInt32 = 831
WM_HANDHELDFIRST: UInt32 = 856
WM_HANDHELDLAST: UInt32 = 863
WM_AFXFIRST: UInt32 = 864
WM_AFXLAST: UInt32 = 895
WM_PENWINFIRST: UInt32 = 896
WM_PENWINLAST: UInt32 = 911
WM_APP: UInt32 = 32768
WM_USER: UInt32 = 1024
WMSZ_LEFT: UInt32 = 1
WMSZ_RIGHT: UInt32 = 2
WMSZ_TOP: UInt32 = 3
WMSZ_TOPLEFT: UInt32 = 4
WMSZ_TOPRIGHT: UInt32 = 5
WMSZ_BOTTOM: UInt32 = 6
WMSZ_BOTTOMLEFT: UInt32 = 7
WMSZ_BOTTOMRIGHT: UInt32 = 8
HTERROR: Int32 = -2
HTTRANSPARENT: Int32 = -1
HTNOWHERE: UInt32 = 0
HTCLIENT: UInt32 = 1
HTCAPTION: UInt32 = 2
HTSYSMENU: UInt32 = 3
HTGROWBOX: UInt32 = 4
HTSIZE: UInt32 = 4
HTMENU: UInt32 = 5
HTHSCROLL: UInt32 = 6
HTVSCROLL: UInt32 = 7
HTMINBUTTON: UInt32 = 8
HTMAXBUTTON: UInt32 = 9
HTLEFT: UInt32 = 10
HTRIGHT: UInt32 = 11
HTTOP: UInt32 = 12
HTTOPLEFT: UInt32 = 13
HTTOPRIGHT: UInt32 = 14
HTBOTTOM: UInt32 = 15
HTBOTTOMLEFT: UInt32 = 16
HTBOTTOMRIGHT: UInt32 = 17
HTBORDER: UInt32 = 18
HTREDUCE: UInt32 = 8
HTZOOM: UInt32 = 9
HTSIZEFIRST: UInt32 = 10
HTSIZELAST: UInt32 = 17
HTOBJECT: UInt32 = 19
HTCLOSE: UInt32 = 20
HTHELP: UInt32 = 21
MA_ACTIVATE: UInt32 = 1
MA_ACTIVATEANDEAT: UInt32 = 2
MA_NOACTIVATE: UInt32 = 3
MA_NOACTIVATEANDEAT: UInt32 = 4
ICON_SMALL: UInt32 = 0
ICON_BIG: UInt32 = 1
ICON_SMALL2: UInt32 = 2
SIZE_RESTORED: UInt32 = 0
SIZE_MINIMIZED: UInt32 = 1
SIZE_MAXIMIZED: UInt32 = 2
SIZE_MAXSHOW: UInt32 = 3
SIZE_MAXHIDE: UInt32 = 4
SIZENORMAL: UInt32 = 0
SIZEICONIC: UInt32 = 1
SIZEFULLSCREEN: UInt32 = 2
SIZEZOOMSHOW: UInt32 = 3
SIZEZOOMHIDE: UInt32 = 4
WVR_ALIGNTOP: UInt32 = 16
WVR_ALIGNLEFT: UInt32 = 32
WVR_ALIGNBOTTOM: UInt32 = 64
WVR_ALIGNRIGHT: UInt32 = 128
WVR_HREDRAW: UInt32 = 256
WVR_VREDRAW: UInt32 = 512
WVR_VALIDRECTS: UInt32 = 1024
PRF_CHECKVISIBLE: Int32 = 1
PRF_NONCLIENT: Int32 = 2
PRF_CLIENT: Int32 = 4
PRF_ERASEBKGND: Int32 = 8
PRF_CHILDREN: Int32 = 16
PRF_OWNED: Int32 = 32
IDANI_OPEN: UInt32 = 1
IDANI_CAPTION: UInt32 = 3
IDHOT_SNAPWINDOW: Int32 = -1
IDHOT_SNAPDESKTOP: Int32 = -2
ENDSESSION_CLOSEAPP: UInt32 = 1
ENDSESSION_CRITICAL: UInt32 = 1073741824
ENDSESSION_LOGOFF: UInt32 = 2147483648
BROADCAST_QUERY_DENY: UInt32 = 1112363332
HWND_BROADCAST: win32more.Windows.Win32.Foundation.HWND = 65535
HWND_MESSAGE: win32more.Windows.Win32.Foundation.HWND = -3
ISMEX_NOSEND: UInt32 = 0
ISMEX_SEND: UInt32 = 1
ISMEX_NOTIFY: UInt32 = 2
ISMEX_CALLBACK: UInt32 = 4
ISMEX_REPLIED: UInt32 = 8
HWND_DESKTOP: win32more.Windows.Win32.Foundation.HWND = 0
PW_RENDERFULLCONTENT: UInt32 = 2
HWND_TOP: win32more.Windows.Win32.Foundation.HWND = 0
HWND_BOTTOM: win32more.Windows.Win32.Foundation.HWND = 1
HWND_TOPMOST: win32more.Windows.Win32.Foundation.HWND = -1
HWND_NOTOPMOST: win32more.Windows.Win32.Foundation.HWND = -2
DLGWINDOWEXTRA: UInt32 = 30
POINTER_MOD_SHIFT: UInt32 = 4
POINTER_MOD_CTRL: UInt32 = 8
TOUCH_FLAG_NONE: UInt32 = 0
TOUCH_MASK_NONE: UInt32 = 0
TOUCH_MASK_CONTACTAREA: UInt32 = 1
TOUCH_MASK_ORIENTATION: UInt32 = 2
TOUCH_MASK_PRESSURE: UInt32 = 4
PEN_FLAG_NONE: UInt32 = 0
PEN_FLAG_BARREL: UInt32 = 1
PEN_FLAG_INVERTED: UInt32 = 2
PEN_FLAG_ERASER: UInt32 = 4
PEN_MASK_NONE: UInt32 = 0
PEN_MASK_PRESSURE: UInt32 = 1
PEN_MASK_ROTATION: UInt32 = 2
PEN_MASK_TILT_X: UInt32 = 4
PEN_MASK_TILT_Y: UInt32 = 8
POINTER_MESSAGE_FLAG_NEW: UInt32 = 1
POINTER_MESSAGE_FLAG_INRANGE: UInt32 = 2
POINTER_MESSAGE_FLAG_INCONTACT: UInt32 = 4
POINTER_MESSAGE_FLAG_FIRSTBUTTON: UInt32 = 16
POINTER_MESSAGE_FLAG_SECONDBUTTON: UInt32 = 32
POINTER_MESSAGE_FLAG_THIRDBUTTON: UInt32 = 64
POINTER_MESSAGE_FLAG_FOURTHBUTTON: UInt32 = 128
POINTER_MESSAGE_FLAG_FIFTHBUTTON: UInt32 = 256
POINTER_MESSAGE_FLAG_PRIMARY: UInt32 = 8192
POINTER_MESSAGE_FLAG_CONFIDENCE: UInt32 = 16384
POINTER_MESSAGE_FLAG_CANCELED: UInt32 = 32768
PA_ACTIVATE: UInt32 = 1
PA_NOACTIVATE: UInt32 = 3
MAX_TOUCH_COUNT: UInt32 = 256
TOUCH_HIT_TESTING_DEFAULT: UInt32 = 0
TOUCH_HIT_TESTING_CLIENT: UInt32 = 1
TOUCH_HIT_TESTING_NONE: UInt32 = 2
TOUCH_HIT_TESTING_PROXIMITY_CLOSEST: UInt32 = 0
TOUCH_HIT_TESTING_PROXIMITY_FARTHEST: UInt32 = 4095
GWFS_INCLUDE_ANCESTORS: UInt32 = 1
QS_TOUCH: UInt32 = 2048
QS_POINTER: UInt32 = 4096
USER_TIMER_MAXIMUM: UInt32 = 2147483647
USER_TIMER_MINIMUM: UInt32 = 10
TIMERV_DEFAULT_COALESCING: UInt32 = 0
TIMERV_NO_COALESCING: UInt32 = 4294967295
TIMERV_COALESCING_MIN: UInt32 = 1
TIMERV_COALESCING_MAX: UInt32 = 2147483637
SM_RESERVED1: UInt32 = 24
SM_RESERVED2: UInt32 = 25
SM_RESERVED3: UInt32 = 26
SM_RESERVED4: UInt32 = 27
SM_CMETRICS: UInt32 = 76
SM_CARETBLINKINGENABLED: UInt32 = 8194
PMB_ACTIVE: UInt32 = 1
MNC_IGNORE: UInt32 = 0
MNC_CLOSE: UInt32 = 1
MNC_EXECUTE: UInt32 = 2
MNC_SELECT: UInt32 = 3
MND_CONTINUE: UInt32 = 0
MND_ENDMENU: UInt32 = 1
MNGO_NOINTERFACE: UInt32 = 0
MNGO_NOERROR: UInt32 = 1
DOF_EXECUTABLE: UInt32 = 32769
DOF_DOCUMENT: UInt32 = 32770
DOF_DIRECTORY: UInt32 = 32771
DOF_MULTIPLE: UInt32 = 32772
DOF_PROGMAN: UInt32 = 1
DOF_SHELLDATA: UInt32 = 2
DO_DROPFILE: Int32 = 1162627398
DO_PRINTFILE: Int32 = 1414419024
ASFW_ANY: UInt32 = 4294967295
DCX_EXCLUDEUPDATE: Int32 = 256
CTLCOLOR_MSGBOX: UInt32 = 0
CTLCOLOR_EDIT: UInt32 = 1
CTLCOLOR_LISTBOX: UInt32 = 2
CTLCOLOR_BTN: UInt32 = 3
CTLCOLOR_DLG: UInt32 = 4
CTLCOLOR_SCROLLBAR: UInt32 = 5
CTLCOLOR_STATIC: UInt32 = 6
CTLCOLOR_MAX: UInt32 = 7
GW_MAX: UInt32 = 5
SC_SIZE: UInt32 = 61440
SC_MOVE: UInt32 = 61456
SC_MINIMIZE: UInt32 = 61472
SC_MAXIMIZE: UInt32 = 61488
SC_NEXTWINDOW: UInt32 = 61504
SC_PREVWINDOW: UInt32 = 61520
SC_CLOSE: UInt32 = 61536
SC_VSCROLL: UInt32 = 61552
SC_HSCROLL: UInt32 = 61568
SC_MOUSEMENU: UInt32 = 61584
SC_KEYMENU: UInt32 = 61696
SC_ARRANGE: UInt32 = 61712
SC_RESTORE: UInt32 = 61728
SC_TASKLIST: UInt32 = 61744
SC_HOTKEY: UInt32 = 61776
SC_DEFAULT: UInt32 = 61792
SC_MONITORPOWER: UInt32 = 61808
SC_CONTEXTHELP: UInt32 = 61824
SC_SEPARATOR: UInt32 = 61455
SCF_ISSECURE: UInt32 = 1
SC_ICON: UInt32 = 61472
SC_ZOOM: UInt32 = 61488
IDC_ARROW: win32more.Windows.Win32.Foundation.PWSTR = 32512
IDC_IBEAM: win32more.Windows.Win32.Foundation.PWSTR = 32513
IDC_WAIT: win32more.Windows.Win32.Foundation.PWSTR = 32514
IDC_CROSS: win32more.Windows.Win32.Foundation.PWSTR = 32515
IDC_UPARROW: win32more.Windows.Win32.Foundation.PWSTR = 32516
IDC_SIZE: win32more.Windows.Win32.Foundation.PWSTR = 32640
IDC_ICON: win32more.Windows.Win32.Foundation.PWSTR = 32641
IDC_SIZENWSE: win32more.Windows.Win32.Foundation.PWSTR = 32642
IDC_SIZENESW: win32more.Windows.Win32.Foundation.PWSTR = 32643
IDC_SIZEWE: win32more.Windows.Win32.Foundation.PWSTR = 32644
IDC_SIZENS: win32more.Windows.Win32.Foundation.PWSTR = 32645
IDC_SIZEALL: win32more.Windows.Win32.Foundation.PWSTR = 32646
IDC_NO: win32more.Windows.Win32.Foundation.PWSTR = 32648
IDC_HAND: win32more.Windows.Win32.Foundation.PWSTR = 32649
IDC_APPSTARTING: win32more.Windows.Win32.Foundation.PWSTR = 32650
IDC_HELP: win32more.Windows.Win32.Foundation.PWSTR = 32651
IDC_PIN: win32more.Windows.Win32.Foundation.PWSTR = 32671
IDC_PERSON: win32more.Windows.Win32.Foundation.PWSTR = 32672
CURSOR_CREATION_SCALING_NONE: UInt32 = 1
CURSOR_CREATION_SCALING_DEFAULT: UInt32 = 2
IMAGE_ENHMETAFILE: UInt32 = 3
LR_COLOR: UInt32 = 2
RES_ICON: UInt32 = 1
RES_CURSOR: UInt32 = 2
OBM_CLOSE: UInt32 = 32754
OBM_UPARROW: UInt32 = 32753
OBM_DNARROW: UInt32 = 32752
OBM_RGARROW: UInt32 = 32751
OBM_LFARROW: UInt32 = 32750
OBM_REDUCE: UInt32 = 32749
OBM_ZOOM: UInt32 = 32748
OBM_RESTORE: UInt32 = 32747
OBM_REDUCED: UInt32 = 32746
OBM_ZOOMD: UInt32 = 32745
OBM_RESTORED: UInt32 = 32744
OBM_UPARROWD: UInt32 = 32743
OBM_DNARROWD: UInt32 = 32742
OBM_RGARROWD: UInt32 = 32741
OBM_LFARROWD: UInt32 = 32740
OBM_MNARROW: UInt32 = 32739
OBM_COMBO: UInt32 = 32738
OBM_UPARROWI: UInt32 = 32737
OBM_DNARROWI: UInt32 = 32736
OBM_RGARROWI: UInt32 = 32735
OBM_LFARROWI: UInt32 = 32734
OBM_OLD_CLOSE: UInt32 = 32767
OBM_SIZE: UInt32 = 32766
OBM_OLD_UPARROW: UInt32 = 32765
OBM_OLD_DNARROW: UInt32 = 32764
OBM_OLD_RGARROW: UInt32 = 32763
OBM_OLD_LFARROW: UInt32 = 32762
OBM_BTSIZE: UInt32 = 32761
OBM_CHECK: UInt32 = 32760
OBM_CHECKBOXES: UInt32 = 32759
OBM_BTNCORNERS: UInt32 = 32758
OBM_OLD_REDUCE: UInt32 = 32757
OBM_OLD_ZOOM: UInt32 = 32756
OBM_OLD_RESTORE: UInt32 = 32755
OCR_SIZE: UInt32 = 32640
OCR_ICON: UInt32 = 32641
OCR_ICOCUR: UInt32 = 32647
OIC_SAMPLE: UInt32 = 32512
OIC_HAND: UInt32 = 32513
OIC_QUES: UInt32 = 32514
OIC_BANG: UInt32 = 32515
OIC_NOTE: UInt32 = 32516
OIC_WINLOGO: UInt32 = 32517
OIC_WARNING: UInt32 = 32515
OIC_ERROR: UInt32 = 32513
OIC_INFORMATION: UInt32 = 32516
OIC_SHIELD: UInt32 = 32518
ORD_LANGDRIVER: UInt32 = 1
IDI_APPLICATION: win32more.Windows.Win32.Foundation.PWSTR = 32512
IDI_HAND: win32more.Windows.Win32.Foundation.PWSTR = 32513
IDI_QUESTION: win32more.Windows.Win32.Foundation.PWSTR = 32514
IDI_EXCLAMATION: win32more.Windows.Win32.Foundation.PWSTR = 32515
IDI_ASTERISK: win32more.Windows.Win32.Foundation.PWSTR = 32516
IDI_WINLOGO: win32more.Windows.Win32.Foundation.PWSTR = 32517
IDI_SHIELD: win32more.Windows.Win32.Foundation.PWSTR = 32518
IDI_WARNING: win32more.Windows.Win32.Foundation.PWSTR = 32515
IDI_ERROR: win32more.Windows.Win32.Foundation.PWSTR = 32513
IDI_INFORMATION: win32more.Windows.Win32.Foundation.PWSTR = 32516
ES_LEFT: Int32 = 0
ES_CENTER: Int32 = 1
ES_RIGHT: Int32 = 2
ES_MULTILINE: Int32 = 4
ES_UPPERCASE: Int32 = 8
ES_LOWERCASE: Int32 = 16
ES_PASSWORD: Int32 = 32
ES_AUTOVSCROLL: Int32 = 64
ES_AUTOHSCROLL: Int32 = 128
ES_NOHIDESEL: Int32 = 256
ES_OEMCONVERT: Int32 = 1024
ES_READONLY: Int32 = 2048
ES_WANTRETURN: Int32 = 4096
ES_NUMBER: Int32 = 8192
EN_SETFOCUS: UInt32 = 256
EN_KILLFOCUS: UInt32 = 512
EN_CHANGE: UInt32 = 768
EN_UPDATE: UInt32 = 1024
EN_ERRSPACE: UInt32 = 1280
EN_MAXTEXT: UInt32 = 1281
EN_HSCROLL: UInt32 = 1537
EN_VSCROLL: UInt32 = 1538
EN_ALIGN_LTR_EC: UInt32 = 1792
EN_ALIGN_RTL_EC: UInt32 = 1793
EN_BEFORE_PASTE: UInt32 = 2048
EN_AFTER_PASTE: UInt32 = 2049
EC_LEFTMARGIN: UInt32 = 1
EC_RIGHTMARGIN: UInt32 = 2
EC_USEFONTINFO: UInt32 = 65535
EMSIS_COMPOSITIONSTRING: UInt32 = 1
EIMES_GETCOMPSTRATONCE: UInt32 = 1
EIMES_CANCELCOMPSTRINFOCUS: UInt32 = 2
EIMES_COMPLETECOMPSTRKILLFOCUS: UInt32 = 4
BS_PUSHBUTTON: Int32 = 0
BS_DEFPUSHBUTTON: Int32 = 1
BS_CHECKBOX: Int32 = 2
BS_AUTOCHECKBOX: Int32 = 3
BS_RADIOBUTTON: Int32 = 4
BS_3STATE: Int32 = 5
BS_AUTO3STATE: Int32 = 6
BS_GROUPBOX: Int32 = 7
BS_USERBUTTON: Int32 = 8
BS_AUTORADIOBUTTON: Int32 = 9
BS_PUSHBOX: Int32 = 10
BS_OWNERDRAW: Int32 = 11
BS_TYPEMASK: Int32 = 15
BS_LEFTTEXT: Int32 = 32
BS_TEXT: Int32 = 0
BS_ICON: Int32 = 64
BS_BITMAP: Int32 = 128
BS_LEFT: Int32 = 256
BS_RIGHT: Int32 = 512
BS_CENTER: Int32 = 768
BS_TOP: Int32 = 1024
BS_BOTTOM: Int32 = 2048
BS_VCENTER: Int32 = 3072
BS_PUSHLIKE: Int32 = 4096
BS_MULTILINE: Int32 = 8192
BS_NOTIFY: Int32 = 16384
BS_FLAT: Int32 = 32768
BS_RIGHTBUTTON: Int32 = 32
BN_CLICKED: UInt32 = 0
BN_PAINT: UInt32 = 1
BN_HILITE: UInt32 = 2
BN_UNHILITE: UInt32 = 3
BN_DISABLE: UInt32 = 4
BN_DOUBLECLICKED: UInt32 = 5
BN_PUSHED: UInt32 = 2
BN_UNPUSHED: UInt32 = 3
BN_DBLCLK: UInt32 = 5
BN_SETFOCUS: UInt32 = 6
BN_KILLFOCUS: UInt32 = 7
BM_GETCHECK: UInt32 = 240
BM_SETCHECK: UInt32 = 241
BM_GETSTATE: UInt32 = 242
BM_SETSTATE: UInt32 = 243
BM_SETSTYLE: UInt32 = 244
BM_CLICK: UInt32 = 245
BM_GETIMAGE: UInt32 = 246
BM_SETIMAGE: UInt32 = 247
BM_SETDONTCLICK: UInt32 = 248
BST_PUSHED: UInt32 = 4
BST_FOCUS: UInt32 = 8
STM_SETICON: UInt32 = 368
STM_GETICON: UInt32 = 369
STM_SETIMAGE: UInt32 = 370
STM_GETIMAGE: UInt32 = 371
STN_CLICKED: UInt32 = 0
STN_DBLCLK: UInt32 = 1
STN_ENABLE: UInt32 = 2
STN_DISABLE: UInt32 = 3
STM_MSGMAX: UInt32 = 372
DWL_MSGRESULT: UInt32 = 0
DWL_DLGPROC: UInt32 = 4
DWL_USER: UInt32 = 8
DWLP_MSGRESULT: UInt32 = 0
DS_ABSALIGN: Int32 = 1
DS_SYSMODAL: Int32 = 2
DS_LOCALEDIT: Int32 = 32
DS_SETFONT: Int32 = 64
DS_MODALFRAME: Int32 = 128
DS_NOIDLEMSG: Int32 = 256
DS_SETFOREGROUND: Int32 = 512
DS_3DLOOK: Int32 = 4
DS_FIXEDSYS: Int32 = 8
DS_NOFAILCREATE: Int32 = 16
DS_CONTROL: Int32 = 1024
DS_CENTER: Int32 = 2048
DS_CENTERMOUSE: Int32 = 4096
DS_CONTEXTHELP: Int32 = 8192
DS_USEPIXELS: Int32 = 32768
DM_GETDEFID: UInt32 = 1024
DM_SETDEFID: UInt32 = 1025
DM_REPOSITION: UInt32 = 1026
DC_HASDEFID: UInt32 = 21323
DLGC_WANTARROWS: UInt32 = 1
DLGC_WANTTAB: UInt32 = 2
DLGC_WANTALLKEYS: UInt32 = 4
DLGC_WANTMESSAGE: UInt32 = 4
DLGC_HASSETSEL: UInt32 = 8
DLGC_DEFPUSHBUTTON: UInt32 = 16
DLGC_UNDEFPUSHBUTTON: UInt32 = 32
DLGC_RADIOBUTTON: UInt32 = 64
DLGC_WANTCHARS: UInt32 = 128
DLGC_STATIC: UInt32 = 256
DLGC_BUTTON: UInt32 = 8192
LB_CTLCODE: Int32 = 0
LB_OKAY: UInt32 = 0
LB_ERR: Int32 = -1
LB_ERRSPACE: Int32 = -2
LBN_ERRSPACE: Int32 = -2
LBN_SELCHANGE: UInt32 = 1
LBN_DBLCLK: UInt32 = 2
LBN_SELCANCEL: UInt32 = 3
LBN_SETFOCUS: UInt32 = 4
LBN_KILLFOCUS: UInt32 = 5
LB_ADDSTRING: UInt32 = 384
LB_INSERTSTRING: UInt32 = 385
LB_DELETESTRING: UInt32 = 386
LB_SELITEMRANGEEX: UInt32 = 387
LB_RESETCONTENT: UInt32 = 388
LB_SETSEL: UInt32 = 389
LB_SETCURSEL: UInt32 = 390
LB_GETSEL: UInt32 = 391
LB_GETCURSEL: UInt32 = 392
LB_GETTEXT: UInt32 = 393
LB_GETTEXTLEN: UInt32 = 394
LB_GETCOUNT: UInt32 = 395
LB_SELECTSTRING: UInt32 = 396
LB_DIR: UInt32 = 397
LB_GETTOPINDEX: UInt32 = 398
LB_FINDSTRING: UInt32 = 399
LB_GETSELCOUNT: UInt32 = 400
LB_GETSELITEMS: UInt32 = 401
LB_SETTABSTOPS: UInt32 = 402
LB_GETHORIZONTALEXTENT: UInt32 = 403
LB_SETHORIZONTALEXTENT: UInt32 = 404
LB_SETCOLUMNWIDTH: UInt32 = 405
LB_ADDFILE: UInt32 = 406
LB_SETTOPINDEX: UInt32 = 407
LB_GETITEMRECT: UInt32 = 408
LB_GETITEMDATA: UInt32 = 409
LB_SETITEMDATA: UInt32 = 410
LB_SELITEMRANGE: UInt32 = 411
LB_SETANCHORINDEX: UInt32 = 412
LB_GETANCHORINDEX: UInt32 = 413
LB_SETCARETINDEX: UInt32 = 414
LB_GETCARETINDEX: UInt32 = 415
LB_SETITEMHEIGHT: UInt32 = 416
LB_GETITEMHEIGHT: UInt32 = 417
LB_FINDSTRINGEXACT: UInt32 = 418
LB_SETLOCALE: UInt32 = 421
LB_GETLOCALE: UInt32 = 422
LB_SETCOUNT: UInt32 = 423
LB_INITSTORAGE: UInt32 = 424
LB_ITEMFROMPOINT: UInt32 = 425
LB_MULTIPLEADDSTRING: UInt32 = 433
LB_GETLISTBOXINFO: UInt32 = 434
LB_MSGMAX: UInt32 = 435
LBS_NOTIFY: Int32 = 1
LBS_SORT: Int32 = 2
LBS_NOREDRAW: Int32 = 4
LBS_MULTIPLESEL: Int32 = 8
LBS_OWNERDRAWFIXED: Int32 = 16
LBS_OWNERDRAWVARIABLE: Int32 = 32
LBS_HASSTRINGS: Int32 = 64
LBS_USETABSTOPS: Int32 = 128
LBS_NOINTEGRALHEIGHT: Int32 = 256
LBS_MULTICOLUMN: Int32 = 512
LBS_WANTKEYBOARDINPUT: Int32 = 1024
LBS_EXTENDEDSEL: Int32 = 2048
LBS_DISABLENOSCROLL: Int32 = 4096
LBS_NODATA: Int32 = 8192
LBS_NOSEL: Int32 = 16384
LBS_COMBOBOX: Int32 = 32768
CB_OKAY: UInt32 = 0
CB_ERR: Int32 = -1
CB_ERRSPACE: Int32 = -2
CBN_ERRSPACE: Int32 = -1
CBN_SELCHANGE: UInt32 = 1
CBN_DBLCLK: UInt32 = 2
CBN_SETFOCUS: UInt32 = 3
CBN_KILLFOCUS: UInt32 = 4
CBN_EDITCHANGE: UInt32 = 5
CBN_EDITUPDATE: UInt32 = 6
CBN_DROPDOWN: UInt32 = 7
CBN_CLOSEUP: UInt32 = 8
CBN_SELENDOK: UInt32 = 9
CBN_SELENDCANCEL: UInt32 = 10
CBS_SIMPLE: Int32 = 1
CBS_DROPDOWN: Int32 = 2
CBS_DROPDOWNLIST: Int32 = 3
CBS_OWNERDRAWFIXED: Int32 = 16
CBS_OWNERDRAWVARIABLE: Int32 = 32
CBS_AUTOHSCROLL: Int32 = 64
CBS_OEMCONVERT: Int32 = 128
CBS_SORT: Int32 = 256
CBS_HASSTRINGS: Int32 = 512
CBS_NOINTEGRALHEIGHT: Int32 = 1024
CBS_DISABLENOSCROLL: Int32 = 2048
CBS_UPPERCASE: Int32 = 8192
CBS_LOWERCASE: Int32 = 16384
CB_GETEDITSEL: UInt32 = 320
CB_LIMITTEXT: UInt32 = 321
CB_SETEDITSEL: UInt32 = 322
CB_ADDSTRING: UInt32 = 323
CB_DELETESTRING: UInt32 = 324
CB_DIR: UInt32 = 325
CB_GETCOUNT: UInt32 = 326
CB_GETCURSEL: UInt32 = 327
CB_GETLBTEXT: UInt32 = 328
CB_GETLBTEXTLEN: UInt32 = 329
CB_INSERTSTRING: UInt32 = 330
CB_RESETCONTENT: UInt32 = 331
CB_FINDSTRING: UInt32 = 332
CB_SELECTSTRING: UInt32 = 333
CB_SETCURSEL: UInt32 = 334
CB_SHOWDROPDOWN: UInt32 = 335
CB_GETITEMDATA: UInt32 = 336
CB_SETITEMDATA: UInt32 = 337
CB_GETDROPPEDCONTROLRECT: UInt32 = 338
CB_SETITEMHEIGHT: UInt32 = 339
CB_GETITEMHEIGHT: UInt32 = 340
CB_SETEXTENDEDUI: UInt32 = 341
CB_GETEXTENDEDUI: UInt32 = 342
CB_GETDROPPEDSTATE: UInt32 = 343
CB_FINDSTRINGEXACT: UInt32 = 344
CB_SETLOCALE: UInt32 = 345
CB_GETLOCALE: UInt32 = 346
CB_GETTOPINDEX: UInt32 = 347
CB_SETTOPINDEX: UInt32 = 348
CB_GETHORIZONTALEXTENT: UInt32 = 349
CB_SETHORIZONTALEXTENT: UInt32 = 350
CB_GETDROPPEDWIDTH: UInt32 = 351
CB_SETDROPPEDWIDTH: UInt32 = 352
CB_INITSTORAGE: UInt32 = 353
CB_MULTIPLEADDSTRING: UInt32 = 355
CB_GETCOMBOBOXINFO: UInt32 = 356
CB_MSGMAX: UInt32 = 357
SBS_HORZ: Int32 = 0
SBS_VERT: Int32 = 1
SBS_TOPALIGN: Int32 = 2
SBS_LEFTALIGN: Int32 = 2
SBS_BOTTOMALIGN: Int32 = 4
SBS_RIGHTALIGN: Int32 = 4
SBS_SIZEBOXTOPLEFTALIGN: Int32 = 2
SBS_SIZEBOXBOTTOMRIGHTALIGN: Int32 = 4
SBS_SIZEBOX: Int32 = 8
SBS_SIZEGRIP: Int32 = 16
SBM_SETPOS: UInt32 = 224
SBM_GETPOS: UInt32 = 225
SBM_SETRANGE: UInt32 = 226
SBM_SETRANGEREDRAW: UInt32 = 230
SBM_GETRANGE: UInt32 = 227
SBM_ENABLE_ARROWS: UInt32 = 228
SBM_SETSCROLLINFO: UInt32 = 233
SBM_GETSCROLLINFO: UInt32 = 234
SBM_GETSCROLLBARINFO: UInt32 = 235
MDIS_ALLCHILDSTYLES: UInt32 = 1
HELP_CONTEXT: Int32 = 1
HELP_QUIT: Int32 = 2
HELP_INDEX: Int32 = 3
HELP_CONTENTS: Int32 = 3
HELP_HELPONHELP: Int32 = 4
HELP_SETINDEX: Int32 = 5
HELP_SETCONTENTS: Int32 = 5
HELP_CONTEXTPOPUP: Int32 = 8
HELP_FORCEFILE: Int32 = 9
HELP_KEY: Int32 = 257
HELP_COMMAND: Int32 = 258
HELP_PARTIALKEY: Int32 = 261
HELP_MULTIKEY: Int32 = 513
HELP_SETWINPOS: Int32 = 515
HELP_CONTEXTMENU: UInt32 = 10
HELP_FINDER: UInt32 = 11
HELP_WM_HELP: UInt32 = 12
HELP_SETPOPUP_POS: UInt32 = 13
HELP_TCARD: UInt32 = 32768
HELP_TCARD_DATA: UInt32 = 16
HELP_TCARD_OTHER_CALLER: UInt32 = 17
IDH_NO_HELP: UInt32 = 28440
IDH_MISSING_CONTEXT: UInt32 = 28441
IDH_GENERIC_HELP_BUTTON: UInt32 = 28442
IDH_OK: UInt32 = 28443
IDH_CANCEL: UInt32 = 28444
IDH_HELP: UInt32 = 28445
MAX_TOUCH_PREDICTION_FILTER_TAPS: UInt32 = 3
TOUCHPREDICTIONPARAMETERS_DEFAULT_LATENCY: UInt32 = 8
TOUCHPREDICTIONPARAMETERS_DEFAULT_SAMPLETIME: UInt32 = 8
TOUCHPREDICTIONPARAMETERS_DEFAULT_USE_HW_TIMESTAMP: UInt32 = 1
TOUCHPREDICTIONPARAMETERS_DEFAULT_RLS_DELTA: Single = 0.001
TOUCHPREDICTIONPARAMETERS_DEFAULT_RLS_LAMBDA_MIN: Single = 0.9
TOUCHPREDICTIONPARAMETERS_DEFAULT_RLS_LAMBDA_MAX: Single = 0.999
TOUCHPREDICTIONPARAMETERS_DEFAULT_RLS_LAMBDA_LEARNING_RATE: Single = 0.001
TOUCHPREDICTIONPARAMETERS_DEFAULT_RLS_EXPO_SMOOTH_ALPHA: Single = 0.99
MAX_LOGICALDPIOVERRIDE: UInt32 = 2
MIN_LOGICALDPIOVERRIDE: Int32 = -2
FE_FONTSMOOTHINGSTANDARD: UInt32 = 1
FE_FONTSMOOTHINGCLEARTYPE: UInt32 = 2
FE_FONTSMOOTHINGORIENTATIONBGR: UInt32 = 0
FE_FONTSMOOTHINGORIENTATIONRGB: UInt32 = 1
CONTACTVISUALIZATION_OFF: UInt32 = 0
CONTACTVISUALIZATION_ON: UInt32 = 1
CONTACTVISUALIZATION_PRESENTATIONMODE: UInt32 = 2
GESTUREVISUALIZATION_OFF: UInt32 = 0
GESTUREVISUALIZATION_ON: UInt32 = 31
GESTUREVISUALIZATION_TAP: UInt32 = 1
GESTUREVISUALIZATION_DOUBLETAP: UInt32 = 2
GESTUREVISUALIZATION_PRESSANDTAP: UInt32 = 4
GESTUREVISUALIZATION_PRESSANDHOLD: UInt32 = 8
GESTUREVISUALIZATION_RIGHTTAP: UInt32 = 16
MOUSEWHEEL_ROUTING_FOCUS: UInt32 = 0
MOUSEWHEEL_ROUTING_HYBRID: UInt32 = 1
MOUSEWHEEL_ROUTING_MOUSE_POS: UInt32 = 2
PENVISUALIZATION_ON: UInt32 = 35
PENVISUALIZATION_OFF: UInt32 = 0
PENVISUALIZATION_TAP: UInt32 = 1
PENVISUALIZATION_DOUBLETAP: UInt32 = 2
PENVISUALIZATION_CURSOR: UInt32 = 32
PENARBITRATIONTYPE_NONE: UInt32 = 0
PENARBITRATIONTYPE_WIN8: UInt32 = 1
PENARBITRATIONTYPE_FIS: UInt32 = 2
PENARBITRATIONTYPE_SPT: UInt32 = 3
PENARBITRATIONTYPE_MAX: UInt32 = 4
METRICS_USEDEFAULT: Int32 = -1
ARW_STARTMASK: Int32 = 3
ARW_STARTRIGHT: Int32 = 1
ARW_STARTTOP: Int32 = 2
ARW_LEFT: Int32 = 0
ARW_RIGHT: Int32 = 0
ARW_UP: Int32 = 4
ARW_DOWN: Int32 = 4
ARW_HIDE: Int32 = 8
HCF_LOGONDESKTOP: UInt32 = 256
HCF_DEFAULTDESKTOP: UInt32 = 512
EDD_GET_DEVICE_INTERFACE_NAME: UInt32 = 1
FKF_FILTERKEYSON: UInt32 = 1
FKF_AVAILABLE: UInt32 = 2
FKF_HOTKEYACTIVE: UInt32 = 4
FKF_CONFIRMHOTKEY: UInt32 = 8
FKF_HOTKEYSOUND: UInt32 = 16
FKF_INDICATOR: UInt32 = 32
FKF_CLICKON: UInt32 = 64
MKF_MOUSEKEYSON: UInt32 = 1
MKF_AVAILABLE: UInt32 = 2
MKF_HOTKEYACTIVE: UInt32 = 4
MKF_CONFIRMHOTKEY: UInt32 = 8
MKF_HOTKEYSOUND: UInt32 = 16
MKF_INDICATOR: UInt32 = 32
MKF_MODIFIERS: UInt32 = 64
MKF_REPLACENUMBERS: UInt32 = 128
MKF_LEFTBUTTONSEL: UInt32 = 268435456
MKF_RIGHTBUTTONSEL: UInt32 = 536870912
MKF_LEFTBUTTONDOWN: UInt32 = 16777216
MKF_RIGHTBUTTONDOWN: UInt32 = 33554432
MKF_MOUSEMODE: UInt32 = 2147483648
TKF_TOGGLEKEYSON: UInt32 = 1
TKF_AVAILABLE: UInt32 = 2
TKF_HOTKEYACTIVE: UInt32 = 4
TKF_CONFIRMHOTKEY: UInt32 = 8
TKF_HOTKEYSOUND: UInt32 = 16
TKF_INDICATOR: UInt32 = 32
MONITORINFOF_PRIMARY: UInt32 = 1
WINEVENT_OUTOFCONTEXT: UInt32 = 0
WINEVENT_SKIPOWNTHREAD: UInt32 = 1
WINEVENT_SKIPOWNPROCESS: UInt32 = 2
WINEVENT_INCONTEXT: UInt32 = 4
CHILDID_SELF: UInt32 = 0
INDEXID_OBJECT: UInt32 = 0
INDEXID_CONTAINER: UInt32 = 0
EVENT_MIN: UInt32 = 1
EVENT_MAX: UInt32 = 2147483647
EVENT_SYSTEM_SOUND: UInt32 = 1
EVENT_SYSTEM_ALERT: UInt32 = 2
EVENT_SYSTEM_FOREGROUND: UInt32 = 3
EVENT_SYSTEM_MENUSTART: UInt32 = 4
EVENT_SYSTEM_MENUEND: UInt32 = 5
EVENT_SYSTEM_MENUPOPUPSTART: UInt32 = 6
EVENT_SYSTEM_MENUPOPUPEND: UInt32 = 7
EVENT_SYSTEM_CAPTURESTART: UInt32 = 8
EVENT_SYSTEM_CAPTUREEND: UInt32 = 9
EVENT_SYSTEM_MOVESIZESTART: UInt32 = 10
EVENT_SYSTEM_MOVESIZEEND: UInt32 = 11
EVENT_SYSTEM_CONTEXTHELPSTART: UInt32 = 12
EVENT_SYSTEM_CONTEXTHELPEND: UInt32 = 13
EVENT_SYSTEM_DRAGDROPSTART: UInt32 = 14
EVENT_SYSTEM_DRAGDROPEND: UInt32 = 15
EVENT_SYSTEM_DIALOGSTART: UInt32 = 16
EVENT_SYSTEM_DIALOGEND: UInt32 = 17
EVENT_SYSTEM_SCROLLINGSTART: UInt32 = 18
EVENT_SYSTEM_SCROLLINGEND: UInt32 = 19
EVENT_SYSTEM_SWITCHSTART: UInt32 = 20
EVENT_SYSTEM_SWITCHEND: UInt32 = 21
EVENT_SYSTEM_MINIMIZESTART: UInt32 = 22
EVENT_SYSTEM_MINIMIZEEND: UInt32 = 23
EVENT_SYSTEM_DESKTOPSWITCH: UInt32 = 32
EVENT_SYSTEM_SWITCHER_APPGRABBED: UInt32 = 36
EVENT_SYSTEM_SWITCHER_APPOVERTARGET: UInt32 = 37
EVENT_SYSTEM_SWITCHER_APPDROPPED: UInt32 = 38
EVENT_SYSTEM_SWITCHER_CANCELLED: UInt32 = 39
EVENT_SYSTEM_IME_KEY_NOTIFICATION: UInt32 = 41
EVENT_SYSTEM_END: UInt32 = 255
EVENT_OEM_DEFINED_START: UInt32 = 257
EVENT_OEM_DEFINED_END: UInt32 = 511
EVENT_UIA_EVENTID_START: UInt32 = 19968
EVENT_UIA_EVENTID_END: UInt32 = 20223
EVENT_UIA_PROPID_START: UInt32 = 29952
EVENT_UIA_PROPID_END: UInt32 = 30207
EVENT_CONSOLE_CARET: UInt32 = 16385
EVENT_CONSOLE_UPDATE_REGION: UInt32 = 16386
EVENT_CONSOLE_UPDATE_SIMPLE: UInt32 = 16387
EVENT_CONSOLE_UPDATE_SCROLL: UInt32 = 16388
EVENT_CONSOLE_LAYOUT: UInt32 = 16389
EVENT_CONSOLE_START_APPLICATION: UInt32 = 16390
EVENT_CONSOLE_END_APPLICATION: UInt32 = 16391
CONSOLE_APPLICATION_16BIT: UInt32 = 0
CONSOLE_CARET_SELECTION: UInt32 = 1
CONSOLE_CARET_VISIBLE: UInt32 = 2
EVENT_CONSOLE_END: UInt32 = 16639
EVENT_OBJECT_CREATE: UInt32 = 32768
EVENT_OBJECT_DESTROY: UInt32 = 32769
EVENT_OBJECT_SHOW: UInt32 = 32770
EVENT_OBJECT_HIDE: UInt32 = 32771
EVENT_OBJECT_REORDER: UInt32 = 32772
EVENT_OBJECT_FOCUS: UInt32 = 32773
EVENT_OBJECT_SELECTION: UInt32 = 32774
EVENT_OBJECT_SELECTIONADD: UInt32 = 32775
EVENT_OBJECT_SELECTIONREMOVE: UInt32 = 32776
EVENT_OBJECT_SELECTIONWITHIN: UInt32 = 32777
EVENT_OBJECT_STATECHANGE: UInt32 = 32778
EVENT_OBJECT_LOCATIONCHANGE: UInt32 = 32779
EVENT_OBJECT_NAMECHANGE: UInt32 = 32780
EVENT_OBJECT_DESCRIPTIONCHANGE: UInt32 = 32781
EVENT_OBJECT_VALUECHANGE: UInt32 = 32782
EVENT_OBJECT_PARENTCHANGE: UInt32 = 32783
EVENT_OBJECT_HELPCHANGE: UInt32 = 32784
EVENT_OBJECT_DEFACTIONCHANGE: UInt32 = 32785
EVENT_OBJECT_ACCELERATORCHANGE: UInt32 = 32786
EVENT_OBJECT_INVOKED: UInt32 = 32787
EVENT_OBJECT_TEXTSELECTIONCHANGED: UInt32 = 32788
EVENT_OBJECT_CONTENTSCROLLED: UInt32 = 32789
EVENT_SYSTEM_ARRANGMENTPREVIEW: UInt32 = 32790
EVENT_OBJECT_CLOAKED: UInt32 = 32791
EVENT_OBJECT_UNCLOAKED: UInt32 = 32792
EVENT_OBJECT_LIVEREGIONCHANGED: UInt32 = 32793
EVENT_OBJECT_HOSTEDOBJECTSINVALIDATED: UInt32 = 32800
EVENT_OBJECT_DRAGSTART: UInt32 = 32801
EVENT_OBJECT_DRAGCANCEL: UInt32 = 32802
EVENT_OBJECT_DRAGCOMPLETE: UInt32 = 32803
EVENT_OBJECT_DRAGENTER: UInt32 = 32804
EVENT_OBJECT_DRAGLEAVE: UInt32 = 32805
EVENT_OBJECT_DRAGDROPPED: UInt32 = 32806
EVENT_OBJECT_IME_SHOW: UInt32 = 32807
EVENT_OBJECT_IME_HIDE: UInt32 = 32808
EVENT_OBJECT_IME_CHANGE: UInt32 = 32809
EVENT_OBJECT_TEXTEDIT_CONVERSIONTARGETCHANGED: UInt32 = 32816
EVENT_OBJECT_END: UInt32 = 33023
EVENT_AIA_START: UInt32 = 40960
EVENT_AIA_END: UInt32 = 45055
SOUND_SYSTEM_STARTUP: UInt32 = 1
SOUND_SYSTEM_SHUTDOWN: UInt32 = 2
SOUND_SYSTEM_BEEP: UInt32 = 3
SOUND_SYSTEM_ERROR: UInt32 = 4
SOUND_SYSTEM_QUESTION: UInt32 = 5
SOUND_SYSTEM_WARNING: UInt32 = 6
SOUND_SYSTEM_INFORMATION: UInt32 = 7
SOUND_SYSTEM_MAXIMIZE: UInt32 = 8
SOUND_SYSTEM_MINIMIZE: UInt32 = 9
SOUND_SYSTEM_RESTOREUP: UInt32 = 10
SOUND_SYSTEM_RESTOREDOWN: UInt32 = 11
SOUND_SYSTEM_APPSTART: UInt32 = 12
SOUND_SYSTEM_FAULT: UInt32 = 13
SOUND_SYSTEM_APPEND: UInt32 = 14
SOUND_SYSTEM_MENUCOMMAND: UInt32 = 15
SOUND_SYSTEM_MENUPOPUP: UInt32 = 16
CSOUND_SYSTEM: UInt32 = 16
CALERT_SYSTEM: UInt32 = 6
GUI_16BITTASK: UInt32 = 0
USER_DEFAULT_SCREEN_DPI: UInt32 = 96
STATE_SYSTEM_SELECTED: UInt32 = 2
STATE_SYSTEM_FOCUSED: UInt32 = 4
STATE_SYSTEM_CHECKED: UInt32 = 16
STATE_SYSTEM_MIXED: UInt32 = 32
STATE_SYSTEM_INDETERMINATE: UInt32 = 32
STATE_SYSTEM_READONLY: UInt32 = 64
STATE_SYSTEM_HOTTRACKED: UInt32 = 128
STATE_SYSTEM_DEFAULT: UInt32 = 256
STATE_SYSTEM_EXPANDED: UInt32 = 512
STATE_SYSTEM_COLLAPSED: UInt32 = 1024
STATE_SYSTEM_BUSY: UInt32 = 2048
STATE_SYSTEM_FLOATING: UInt32 = 4096
STATE_SYSTEM_MARQUEED: UInt32 = 8192
STATE_SYSTEM_ANIMATED: UInt32 = 16384
STATE_SYSTEM_SIZEABLE: UInt32 = 131072
STATE_SYSTEM_MOVEABLE: UInt32 = 262144
STATE_SYSTEM_SELFVOICING: UInt32 = 524288
STATE_SYSTEM_SELECTABLE: UInt32 = 2097152
STATE_SYSTEM_LINKED: UInt32 = 4194304
STATE_SYSTEM_TRAVERSED: UInt32 = 8388608
STATE_SYSTEM_MULTISELECTABLE: UInt32 = 16777216
STATE_SYSTEM_EXTSELECTABLE: UInt32 = 33554432
STATE_SYSTEM_ALERT_LOW: UInt32 = 67108864
STATE_SYSTEM_ALERT_MEDIUM: UInt32 = 134217728
STATE_SYSTEM_ALERT_HIGH: UInt32 = 268435456
STATE_SYSTEM_PROTECTED: UInt32 = 536870912
STATE_SYSTEM_VALID: UInt32 = 1073741823
CCHILDREN_TITLEBAR: UInt32 = 5
CCHILDREN_SCROLLBAR: UInt32 = 5
RIM_INPUT: UInt32 = 0
RIM_INPUTSINK: UInt32 = 1
RIM_TYPEMAX: UInt32 = 2
RI_MOUSE_LEFT_BUTTON_DOWN: UInt32 = 1
RI_MOUSE_LEFT_BUTTON_UP: UInt32 = 2
RI_MOUSE_RIGHT_BUTTON_DOWN: UInt32 = 4
RI_MOUSE_RIGHT_BUTTON_UP: UInt32 = 8
RI_MOUSE_MIDDLE_BUTTON_DOWN: UInt32 = 16
RI_MOUSE_MIDDLE_BUTTON_UP: UInt32 = 32
RI_MOUSE_BUTTON_1_DOWN: UInt32 = 1
RI_MOUSE_BUTTON_1_UP: UInt32 = 2
RI_MOUSE_BUTTON_2_DOWN: UInt32 = 4
RI_MOUSE_BUTTON_2_UP: UInt32 = 8
RI_MOUSE_BUTTON_3_DOWN: UInt32 = 16
RI_MOUSE_BUTTON_3_UP: UInt32 = 32
RI_MOUSE_BUTTON_4_DOWN: UInt32 = 64
RI_MOUSE_BUTTON_4_UP: UInt32 = 128
RI_MOUSE_BUTTON_5_DOWN: UInt32 = 256
RI_MOUSE_BUTTON_5_UP: UInt32 = 512
RI_MOUSE_WHEEL: UInt32 = 1024
RI_MOUSE_HWHEEL: UInt32 = 2048
RI_KEY_MAKE: UInt32 = 0
RI_KEY_BREAK: UInt32 = 1
RI_KEY_E0: UInt32 = 2
RI_KEY_E1: UInt32 = 4
RI_KEY_TERMSRV_SET_LED: UInt32 = 8
RI_KEY_TERMSRV_SHADOW: UInt32 = 16
RIDEV_EXMODEMASK: UInt32 = 240
GIDC_ARRIVAL: UInt32 = 1
GIDC_REMOVAL: UInt32 = 2
POINTER_DEVICE_PRODUCT_STRING_MAX: UInt32 = 520
PDC_ARRIVAL: UInt32 = 1
PDC_REMOVAL: UInt32 = 2
PDC_ORIENTATION_0: UInt32 = 4
PDC_ORIENTATION_90: UInt32 = 8
PDC_ORIENTATION_180: UInt32 = 16
PDC_ORIENTATION_270: UInt32 = 32
PDC_MODE_DEFAULT: UInt32 = 64
PDC_MODE_CENTERED: UInt32 = 128
PDC_MAPPING_CHANGE: UInt32 = 256
PDC_RESOLUTION: UInt32 = 512
PDC_ORIGIN: UInt32 = 1024
PDC_MODE_ASPECTRATIOPRESERVED: UInt32 = 2048
GF_BEGIN: UInt32 = 1
GF_INERTIA: UInt32 = 2
GF_END: UInt32 = 4
GESTURECONFIGMAXCOUNT: UInt32 = 256
GCF_INCLUDE_ANCESTORS: UInt32 = 1
NID_INTEGRATED_TOUCH: UInt32 = 1
NID_EXTERNAL_TOUCH: UInt32 = 2
NID_INTEGRATED_PEN: UInt32 = 4
NID_EXTERNAL_PEN: UInt32 = 8
NID_MULTI_INPUT: UInt32 = 64
NID_READY: UInt32 = 128
MAX_STR_BLOCKREASON: UInt32 = 256
WM_TOOLTIPDISMISS: UInt32 = 837
HBMMENU_CALLBACK: win32more.Windows.Win32.Graphics.Gdi.HBITMAP = -1
HBMMENU_SYSTEM: win32more.Windows.Win32.Graphics.Gdi.HBITMAP = 1
HBMMENU_MBAR_RESTORE: win32more.Windows.Win32.Graphics.Gdi.HBITMAP = 2
HBMMENU_MBAR_MINIMIZE: win32more.Windows.Win32.Graphics.Gdi.HBITMAP = 3
HBMMENU_MBAR_CLOSE: win32more.Windows.Win32.Graphics.Gdi.HBITMAP = 5
HBMMENU_MBAR_CLOSE_D: win32more.Windows.Win32.Graphics.Gdi.HBITMAP = 6
HBMMENU_MBAR_MINIMIZE_D: win32more.Windows.Win32.Graphics.Gdi.HBITMAP = 7
HBMMENU_POPUP_CLOSE: win32more.Windows.Win32.Graphics.Gdi.HBITMAP = 8
HBMMENU_POPUP_RESTORE: win32more.Windows.Win32.Graphics.Gdi.HBITMAP = 9
HBMMENU_POPUP_MAXIMIZE: win32more.Windows.Win32.Graphics.Gdi.HBITMAP = 10
HBMMENU_POPUP_MINIMIZE: win32more.Windows.Win32.Graphics.Gdi.HBITMAP = 11
CW_USEDEFAULT: Int32 = -2147483648
LBS_STANDARD: Int32 = 10485763
WINSTA_ALL_ACCESS: Int32 = 895
WVR_REDRAW: UInt32 = 768
RT_GROUP_CURSOR: win32more.Windows.Win32.Foundation.PWSTR = 12
RT_GROUP_ICON: win32more.Windows.Win32.Foundation.PWSTR = 14
RT_MANIFEST: win32more.Windows.Win32.Foundation.PWSTR = 24
IDC_STATIC: Int32 = -1
@winfunctype('USER32.dll')
def LoadStringA(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, uID: UInt32, lpBuffer: win32more.Windows.Win32.Foundation.PSTR, cchBufferMax: Int32) -> Int32: ...
@winfunctype('USER32.dll')
def LoadStringW(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, uID: UInt32, lpBuffer: win32more.Windows.Win32.Foundation.PWSTR, cchBufferMax: Int32) -> Int32: ...
LoadString = UnicodeAlias('LoadStringW')
if ARCH in 'X64,ARM64':
    @winfunctype('USER32.dll')
    def GetWindowLongPtrA(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX) -> IntPtr: ...
if ARCH in 'X64,ARM64':
    @winfunctype('USER32.dll')
    def GetWindowLongPtrW(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX) -> IntPtr: ...
if ARCH in 'X64,ARM64':
    GetWindowLongPtr = UnicodeAlias('GetWindowLongPtrW')
if ARCH in 'X64,ARM64':
    @winfunctype('USER32.dll')
    def SetWindowLongPtrA(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX, dwNewLong: IntPtr) -> IntPtr: ...
if ARCH in 'X64,ARM64':
    @winfunctype('USER32.dll')
    def SetWindowLongPtrW(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX, dwNewLong: IntPtr) -> IntPtr: ...
if ARCH in 'X64,ARM64':
    SetWindowLongPtr = UnicodeAlias('SetWindowLongPtrW')
if ARCH in 'X64,ARM64':
    @winfunctype('USER32.dll')
    def GetClassLongPtrA(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX) -> UIntPtr: ...
if ARCH in 'X64,ARM64':
    @winfunctype('USER32.dll')
    def GetClassLongPtrW(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX) -> UIntPtr: ...
if ARCH in 'X64,ARM64':
    GetClassLongPtr = UnicodeAlias('GetClassLongPtrW')
if ARCH in 'X64,ARM64':
    @winfunctype('USER32.dll')
    def SetClassLongPtrA(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX, dwNewLong: IntPtr) -> UIntPtr: ...
if ARCH in 'X64,ARM64':
    @winfunctype('USER32.dll')
    def SetClassLongPtrW(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX, dwNewLong: IntPtr) -> UIntPtr: ...
if ARCH in 'X64,ARM64':
    SetClassLongPtr = UnicodeAlias('SetClassLongPtrW')
@winfunctype('USER32.dll')
def wvsprintfA(param0: win32more.Windows.Win32.Foundation.PSTR, param1: win32more.Windows.Win32.Foundation.PSTR, arglist: POINTER(SByte)) -> Int32: ...
@winfunctype('USER32.dll')
def wvsprintfW(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: win32more.Windows.Win32.Foundation.PWSTR, arglist: POINTER(SByte)) -> Int32: ...
wvsprintf = UnicodeAlias('wvsprintfW')
@cfunctype('USER32.dll', variadic=True)
def wsprintfA(param0: win32more.Windows.Win32.Foundation.PSTR, param1: win32more.Windows.Win32.Foundation.PSTR, *__arglist) -> Int32: ...
@cfunctype('USER32.dll', variadic=True)
def wsprintfW(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: win32more.Windows.Win32.Foundation.PWSTR, *__arglist) -> Int32: ...
wsprintf = UnicodeAlias('wsprintfW')
@winfunctype('USER32.dll')
def IsHungAppWindow(hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DisableProcessWindowsGhosting() -> Void: ...
@winfunctype('USER32.dll')
def RegisterWindowMessageA(lpString: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('USER32.dll')
def RegisterWindowMessageW(lpString: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
RegisterWindowMessage = UnicodeAlias('RegisterWindowMessageW')
@winfunctype('USER32.dll')
def GetMessageA(lpMsg: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MSG), hWnd: win32more.Windows.Win32.Foundation.HWND, wMsgFilterMin: UInt32, wMsgFilterMax: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetMessageW(lpMsg: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MSG), hWnd: win32more.Windows.Win32.Foundation.HWND, wMsgFilterMin: UInt32, wMsgFilterMax: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetMessage = UnicodeAlias('GetMessageW')
@winfunctype('USER32.dll')
def TranslateMessage(lpMsg: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MSG)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DispatchMessageA(lpMsg: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MSG)) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('USER32.dll')
def DispatchMessageW(lpMsg: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MSG)) -> win32more.Windows.Win32.Foundation.LRESULT: ...
DispatchMessage = UnicodeAlias('DispatchMessageW')
@winfunctype('USER32.dll')
def SetMessageQueue(cMessagesMax: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def PeekMessageA(lpMsg: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MSG), hWnd: win32more.Windows.Win32.Foundation.HWND, wMsgFilterMin: UInt32, wMsgFilterMax: UInt32, wRemoveMsg: win32more.Windows.Win32.UI.WindowsAndMessaging.PEEK_MESSAGE_REMOVE_TYPE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def PeekMessageW(lpMsg: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MSG), hWnd: win32more.Windows.Win32.Foundation.HWND, wMsgFilterMin: UInt32, wMsgFilterMax: UInt32, wRemoveMsg: win32more.Windows.Win32.UI.WindowsAndMessaging.PEEK_MESSAGE_REMOVE_TYPE) -> win32more.Windows.Win32.Foundation.BOOL: ...
PeekMessage = UnicodeAlias('PeekMessageW')
@winfunctype('USER32.dll')
def GetMessagePos() -> UInt32: ...
@winfunctype('USER32.dll')
def GetMessageTime() -> Int32: ...
@winfunctype('USER32.dll')
def GetMessageExtraInfo() -> win32more.Windows.Win32.Foundation.LPARAM: ...
@winfunctype('USER32.dll')
def IsWow64Message() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetMessageExtraInfo(lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LPARAM: ...
@winfunctype('USER32.dll')
def SendMessageA(hWnd: win32more.Windows.Win32.Foundation.HWND, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('USER32.dll')
def SendMessageW(hWnd: win32more.Windows.Win32.Foundation.HWND, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
SendMessage = UnicodeAlias('SendMessageW')
@winfunctype('USER32.dll')
def SendMessageTimeoutA(hWnd: win32more.Windows.Win32.Foundation.HWND, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM, fuFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.SEND_MESSAGE_TIMEOUT_FLAGS, uTimeout: UInt32, lpdwResult: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('USER32.dll')
def SendMessageTimeoutW(hWnd: win32more.Windows.Win32.Foundation.HWND, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM, fuFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.SEND_MESSAGE_TIMEOUT_FLAGS, uTimeout: UInt32, lpdwResult: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.LRESULT: ...
SendMessageTimeout = UnicodeAlias('SendMessageTimeoutW')
@winfunctype('USER32.dll')
def SendNotifyMessageA(hWnd: win32more.Windows.Win32.Foundation.HWND, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SendNotifyMessageW(hWnd: win32more.Windows.Win32.Foundation.HWND, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
SendNotifyMessage = UnicodeAlias('SendNotifyMessageW')
@winfunctype('USER32.dll')
def SendMessageCallbackA(hWnd: win32more.Windows.Win32.Foundation.HWND, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM, lpResultCallBack: win32more.Windows.Win32.UI.WindowsAndMessaging.SENDASYNCPROC, dwData: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SendMessageCallbackW(hWnd: win32more.Windows.Win32.Foundation.HWND, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM, lpResultCallBack: win32more.Windows.Win32.UI.WindowsAndMessaging.SENDASYNCPROC, dwData: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
SendMessageCallback = UnicodeAlias('SendMessageCallbackW')
@winfunctype('USER32.dll')
def RegisterDeviceNotificationA(hRecipient: win32more.Windows.Win32.Foundation.HANDLE, NotificationFilter: VoidPtr, Flags: win32more.Windows.Win32.UI.WindowsAndMessaging.REGISTER_NOTIFICATION_FLAGS) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HDEVNOTIFY: ...
@winfunctype('USER32.dll')
def RegisterDeviceNotificationW(hRecipient: win32more.Windows.Win32.Foundation.HANDLE, NotificationFilter: VoidPtr, Flags: win32more.Windows.Win32.UI.WindowsAndMessaging.REGISTER_NOTIFICATION_FLAGS) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HDEVNOTIFY: ...
RegisterDeviceNotification = UnicodeAlias('RegisterDeviceNotificationW')
@winfunctype('USER32.dll')
def UnregisterDeviceNotification(Handle: win32more.Windows.Win32.UI.WindowsAndMessaging.HDEVNOTIFY) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def PostMessageA(hWnd: win32more.Windows.Win32.Foundation.HWND, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def PostMessageW(hWnd: win32more.Windows.Win32.Foundation.HWND, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
PostMessage = UnicodeAlias('PostMessageW')
@winfunctype('USER32.dll')
def PostThreadMessageA(idThread: UInt32, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def PostThreadMessageW(idThread: UInt32, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
PostThreadMessage = UnicodeAlias('PostThreadMessageW')
@winfunctype('USER32.dll')
def ReplyMessage(lResult: win32more.Windows.Win32.Foundation.LRESULT) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def WaitMessage() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DefWindowProcA(hWnd: win32more.Windows.Win32.Foundation.HWND, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('USER32.dll')
def DefWindowProcW(hWnd: win32more.Windows.Win32.Foundation.HWND, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
DefWindowProc = UnicodeAlias('DefWindowProcW')
@winfunctype('USER32.dll')
def PostQuitMessage(nExitCode: Int32) -> Void: ...
@winfunctype('USER32.dll')
def CallWindowProcA(lpPrevWndFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDPROC, hWnd: win32more.Windows.Win32.Foundation.HWND, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('USER32.dll')
def CallWindowProcW(lpPrevWndFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDPROC, hWnd: win32more.Windows.Win32.Foundation.HWND, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
CallWindowProc = UnicodeAlias('CallWindowProcW')
@winfunctype('USER32.dll')
def InSendMessage() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def InSendMessageEx(lpReserved: VoidPtr) -> UInt32: ...
@winfunctype('USER32.dll')
def RegisterClassA(lpWndClass: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASSA)) -> UInt16: ...
@winfunctype('USER32.dll')
def RegisterClassW(lpWndClass: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASSW)) -> UInt16: ...
RegisterClass = UnicodeAlias('RegisterClassW')
@winfunctype('USER32.dll')
def UnregisterClassA(lpClassName: win32more.Windows.Win32.Foundation.PSTR, hInstance: win32more.Windows.Win32.Foundation.HINSTANCE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def UnregisterClassW(lpClassName: win32more.Windows.Win32.Foundation.PWSTR, hInstance: win32more.Windows.Win32.Foundation.HINSTANCE) -> win32more.Windows.Win32.Foundation.BOOL: ...
UnregisterClass = UnicodeAlias('UnregisterClassW')
@winfunctype('USER32.dll')
def GetClassInfoA(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpClassName: win32more.Windows.Win32.Foundation.PSTR, lpWndClass: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASSA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetClassInfoW(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpClassName: win32more.Windows.Win32.Foundation.PWSTR, lpWndClass: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASSW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetClassInfo = UnicodeAlias('GetClassInfoW')
@winfunctype('USER32.dll')
def RegisterClassExA(param0: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASSEXA)) -> UInt16: ...
@winfunctype('USER32.dll')
def RegisterClassExW(param0: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASSEXW)) -> UInt16: ...
RegisterClassEx = UnicodeAlias('RegisterClassExW')
@winfunctype('USER32.dll')
def GetClassInfoExA(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpszClass: win32more.Windows.Win32.Foundation.PSTR, lpwcx: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASSEXA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetClassInfoExW(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpszClass: win32more.Windows.Win32.Foundation.PWSTR, lpwcx: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASSEXW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetClassInfoEx = UnicodeAlias('GetClassInfoExW')
@winfunctype('USER32.dll')
def CreateWindowExA(dwExStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE, lpClassName: win32more.Windows.Win32.Foundation.PSTR, lpWindowName: win32more.Windows.Win32.Foundation.PSTR, dwStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE, X: Int32, Y: Int32, nWidth: Int32, nHeight: Int32, hWndParent: win32more.Windows.Win32.Foundation.HWND, hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpParam: VoidPtr) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def CreateWindowExW(dwExStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE, lpClassName: win32more.Windows.Win32.Foundation.PWSTR, lpWindowName: win32more.Windows.Win32.Foundation.PWSTR, dwStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE, X: Int32, Y: Int32, nWidth: Int32, nHeight: Int32, hWndParent: win32more.Windows.Win32.Foundation.HWND, hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpParam: VoidPtr) -> win32more.Windows.Win32.Foundation.HWND: ...
CreateWindowEx = UnicodeAlias('CreateWindowExW')
@winfunctype('USER32.dll')
def IsWindow(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def IsMenu(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def IsChild(hWndParent: win32more.Windows.Win32.Foundation.HWND, hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DestroyWindow(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ShowWindow(hWnd: win32more.Windows.Win32.Foundation.HWND, nCmdShow: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_CMD) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def AnimateWindow(hWnd: win32more.Windows.Win32.Foundation.HWND, dwTime: UInt32, dwFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.ANIMATE_WINDOW_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def UpdateLayeredWindow(hWnd: win32more.Windows.Win32.Foundation.HWND, hdcDst: win32more.Windows.Win32.Graphics.Gdi.HDC, pptDst: POINTER(win32more.Windows.Win32.Foundation.POINT), psize: POINTER(win32more.Windows.Win32.Foundation.SIZE), hdcSrc: win32more.Windows.Win32.Graphics.Gdi.HDC, pptSrc: POINTER(win32more.Windows.Win32.Foundation.POINT), crKey: win32more.Windows.Win32.Foundation.COLORREF, pblend: POINTER(win32more.Windows.Win32.Graphics.Gdi.BLENDFUNCTION), dwFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.UPDATE_LAYERED_WINDOW_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def UpdateLayeredWindowIndirect(hWnd: win32more.Windows.Win32.Foundation.HWND, pULWInfo: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.UPDATELAYEREDWINDOWINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetLayeredWindowAttributes(hwnd: win32more.Windows.Win32.Foundation.HWND, pcrKey: POINTER(win32more.Windows.Win32.Foundation.COLORREF), pbAlpha: POINTER(Byte), pdwFlags: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.LAYERED_WINDOW_ATTRIBUTES_FLAGS)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetLayeredWindowAttributes(hwnd: win32more.Windows.Win32.Foundation.HWND, crKey: win32more.Windows.Win32.Foundation.COLORREF, bAlpha: Byte, dwFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.LAYERED_WINDOW_ATTRIBUTES_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ShowWindowAsync(hWnd: win32more.Windows.Win32.Foundation.HWND, nCmdShow: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_CMD) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def FlashWindow(hWnd: win32more.Windows.Win32.Foundation.HWND, bInvert: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def FlashWindowEx(pfwi: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.FLASHWINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ShowOwnedPopups(hWnd: win32more.Windows.Win32.Foundation.HWND, fShow: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def OpenIcon(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def CloseWindow(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def MoveWindow(hWnd: win32more.Windows.Win32.Foundation.HWND, X: Int32, Y: Int32, nWidth: Int32, nHeight: Int32, bRepaint: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetWindowPos(hWnd: win32more.Windows.Win32.Foundation.HWND, hWndInsertAfter: win32more.Windows.Win32.Foundation.HWND, X: Int32, Y: Int32, cx: Int32, cy: Int32, uFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetWindowPlacement(hWnd: win32more.Windows.Win32.Foundation.HWND, lpwndpl: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWPLACEMENT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetWindowPlacement(hWnd: win32more.Windows.Win32.Foundation.HWND, lpwndpl: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWPLACEMENT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetWindowDisplayAffinity(hWnd: win32more.Windows.Win32.Foundation.HWND, pdwAffinity: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetWindowDisplayAffinity(hWnd: win32more.Windows.Win32.Foundation.HWND, dwAffinity: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_DISPLAY_AFFINITY) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def BeginDeferWindowPos(nNumWindows: Int32) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HDWP: ...
@winfunctype('USER32.dll')
def DeferWindowPos(hWinPosInfo: win32more.Windows.Win32.UI.WindowsAndMessaging.HDWP, hWnd: win32more.Windows.Win32.Foundation.HWND, hWndInsertAfter: win32more.Windows.Win32.Foundation.HWND, x: Int32, y: Int32, cx: Int32, cy: Int32, uFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HDWP: ...
@winfunctype('USER32.dll')
def EndDeferWindowPos(hWinPosInfo: win32more.Windows.Win32.UI.WindowsAndMessaging.HDWP) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def IsWindowVisible(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def IsIconic(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def AnyPopup() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def BringWindowToTop(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def IsZoomed(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def CreateDialogParamA(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpTemplateName: win32more.Windows.Win32.Foundation.PSTR, hWndParent: win32more.Windows.Win32.Foundation.HWND, lpDialogFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC, dwInitParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def CreateDialogParamW(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpTemplateName: win32more.Windows.Win32.Foundation.PWSTR, hWndParent: win32more.Windows.Win32.Foundation.HWND, lpDialogFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC, dwInitParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HWND: ...
CreateDialogParam = UnicodeAlias('CreateDialogParamW')
@winfunctype('USER32.dll')
def CreateDialogIndirectParamA(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpTemplate: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.DLGTEMPLATE), hWndParent: win32more.Windows.Win32.Foundation.HWND, lpDialogFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC, dwInitParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def CreateDialogIndirectParamW(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpTemplate: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.DLGTEMPLATE), hWndParent: win32more.Windows.Win32.Foundation.HWND, lpDialogFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC, dwInitParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HWND: ...
CreateDialogIndirectParam = UnicodeAlias('CreateDialogIndirectParamW')
@winfunctype('USER32.dll')
def DialogBoxParamA(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpTemplateName: win32more.Windows.Win32.Foundation.PSTR, hWndParent: win32more.Windows.Win32.Foundation.HWND, lpDialogFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC, dwInitParam: win32more.Windows.Win32.Foundation.LPARAM) -> IntPtr: ...
@winfunctype('USER32.dll')
def DialogBoxParamW(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpTemplateName: win32more.Windows.Win32.Foundation.PWSTR, hWndParent: win32more.Windows.Win32.Foundation.HWND, lpDialogFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC, dwInitParam: win32more.Windows.Win32.Foundation.LPARAM) -> IntPtr: ...
DialogBoxParam = UnicodeAlias('DialogBoxParamW')
@winfunctype('USER32.dll')
def DialogBoxIndirectParamA(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, hDialogTemplate: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.DLGTEMPLATE), hWndParent: win32more.Windows.Win32.Foundation.HWND, lpDialogFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC, dwInitParam: win32more.Windows.Win32.Foundation.LPARAM) -> IntPtr: ...
@winfunctype('USER32.dll')
def DialogBoxIndirectParamW(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, hDialogTemplate: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.DLGTEMPLATE), hWndParent: win32more.Windows.Win32.Foundation.HWND, lpDialogFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC, dwInitParam: win32more.Windows.Win32.Foundation.LPARAM) -> IntPtr: ...
DialogBoxIndirectParam = UnicodeAlias('DialogBoxIndirectParamW')
@winfunctype('USER32.dll')
def EndDialog(hDlg: win32more.Windows.Win32.Foundation.HWND, nResult: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetDlgItem(hDlg: win32more.Windows.Win32.Foundation.HWND, nIDDlgItem: Int32) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def SetDlgItemInt(hDlg: win32more.Windows.Win32.Foundation.HWND, nIDDlgItem: Int32, uValue: UInt32, bSigned: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetDlgItemInt(hDlg: win32more.Windows.Win32.Foundation.HWND, nIDDlgItem: Int32, lpTranslated: POINTER(win32more.Windows.Win32.Foundation.BOOL), bSigned: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype('USER32.dll')
def SetDlgItemTextA(hDlg: win32more.Windows.Win32.Foundation.HWND, nIDDlgItem: Int32, lpString: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetDlgItemTextW(hDlg: win32more.Windows.Win32.Foundation.HWND, nIDDlgItem: Int32, lpString: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetDlgItemText = UnicodeAlias('SetDlgItemTextW')
@winfunctype('USER32.dll')
def GetDlgItemTextA(hDlg: win32more.Windows.Win32.Foundation.HWND, nIDDlgItem: Int32, lpString: win32more.Windows.Win32.Foundation.PSTR, cchMax: Int32) -> UInt32: ...
@winfunctype('USER32.dll')
def GetDlgItemTextW(hDlg: win32more.Windows.Win32.Foundation.HWND, nIDDlgItem: Int32, lpString: win32more.Windows.Win32.Foundation.PWSTR, cchMax: Int32) -> UInt32: ...
GetDlgItemText = UnicodeAlias('GetDlgItemTextW')
@winfunctype('USER32.dll')
def SendDlgItemMessageA(hDlg: win32more.Windows.Win32.Foundation.HWND, nIDDlgItem: Int32, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('USER32.dll')
def SendDlgItemMessageW(hDlg: win32more.Windows.Win32.Foundation.HWND, nIDDlgItem: Int32, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
SendDlgItemMessage = UnicodeAlias('SendDlgItemMessageW')
@winfunctype('USER32.dll')
def GetNextDlgGroupItem(hDlg: win32more.Windows.Win32.Foundation.HWND, hCtl: win32more.Windows.Win32.Foundation.HWND, bPrevious: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def GetNextDlgTabItem(hDlg: win32more.Windows.Win32.Foundation.HWND, hCtl: win32more.Windows.Win32.Foundation.HWND, bPrevious: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def GetDlgCtrlID(hWnd: win32more.Windows.Win32.Foundation.HWND) -> Int32: ...
@winfunctype('USER32.dll')
def GetDialogBaseUnits() -> Int32: ...
@winfunctype('USER32.dll')
def DefDlgProcA(hDlg: win32more.Windows.Win32.Foundation.HWND, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('USER32.dll')
def DefDlgProcW(hDlg: win32more.Windows.Win32.Foundation.HWND, Msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
DefDlgProc = UnicodeAlias('DefDlgProcW')
@winfunctype('USER32.dll')
def CallMsgFilterA(lpMsg: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MSG), nCode: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def CallMsgFilterW(lpMsg: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MSG), nCode: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
CallMsgFilter = UnicodeAlias('CallMsgFilterW')
@winfunctype('USER32.dll')
def CharToOemA(pSrc: win32more.Windows.Win32.Foundation.PSTR, pDst: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def CharToOemW(pSrc: win32more.Windows.Win32.Foundation.PWSTR, pDst: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
CharToOem = UnicodeAlias('CharToOemW')
@winfunctype('USER32.dll')
def OemToCharA(pSrc: win32more.Windows.Win32.Foundation.PSTR, pDst: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def OemToCharW(pSrc: win32more.Windows.Win32.Foundation.PSTR, pDst: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
OemToChar = UnicodeAlias('OemToCharW')
@winfunctype('USER32.dll')
def CharToOemBuffA(lpszSrc: win32more.Windows.Win32.Foundation.PSTR, lpszDst: win32more.Windows.Win32.Foundation.PSTR, cchDstLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def CharToOemBuffW(lpszSrc: win32more.Windows.Win32.Foundation.PWSTR, lpszDst: win32more.Windows.Win32.Foundation.PSTR, cchDstLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
CharToOemBuff = UnicodeAlias('CharToOemBuffW')
@winfunctype('USER32.dll')
def OemToCharBuffA(lpszSrc: win32more.Windows.Win32.Foundation.PSTR, lpszDst: win32more.Windows.Win32.Foundation.PSTR, cchDstLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def OemToCharBuffW(lpszSrc: win32more.Windows.Win32.Foundation.PSTR, lpszDst: win32more.Windows.Win32.Foundation.PWSTR, cchDstLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
OemToCharBuff = UnicodeAlias('OemToCharBuffW')
@winfunctype('USER32.dll')
def CharUpperA(lpsz: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('USER32.dll')
def CharUpperW(lpsz: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.PWSTR: ...
CharUpper = UnicodeAlias('CharUpperW')
@winfunctype('USER32.dll')
def CharUpperBuffA(lpsz: win32more.Windows.Win32.Foundation.PSTR, cchLength: UInt32) -> UInt32: ...
@winfunctype('USER32.dll')
def CharUpperBuffW(lpsz: win32more.Windows.Win32.Foundation.PWSTR, cchLength: UInt32) -> UInt32: ...
CharUpperBuff = UnicodeAlias('CharUpperBuffW')
@winfunctype('USER32.dll')
def CharLowerA(lpsz: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('USER32.dll')
def CharLowerW(lpsz: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.PWSTR: ...
CharLower = UnicodeAlias('CharLowerW')
@winfunctype('USER32.dll')
def CharLowerBuffA(lpsz: win32more.Windows.Win32.Foundation.PSTR, cchLength: UInt32) -> UInt32: ...
@winfunctype('USER32.dll')
def CharLowerBuffW(lpsz: win32more.Windows.Win32.Foundation.PWSTR, cchLength: UInt32) -> UInt32: ...
CharLowerBuff = UnicodeAlias('CharLowerBuffW')
@winfunctype('USER32.dll')
def CharNextA(lpsz: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('USER32.dll')
def CharNextW(lpsz: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.PWSTR: ...
CharNext = UnicodeAlias('CharNextW')
@winfunctype('USER32.dll')
def CharPrevA(lpszStart: win32more.Windows.Win32.Foundation.PSTR, lpszCurrent: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('USER32.dll')
def CharPrevW(lpszStart: win32more.Windows.Win32.Foundation.PWSTR, lpszCurrent: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.PWSTR: ...
CharPrev = UnicodeAlias('CharPrevW')
@winfunctype('USER32.dll')
def CharNextExA(CodePage: UInt16, lpCurrentChar: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('USER32.dll')
def CharPrevExA(CodePage: UInt16, lpStart: win32more.Windows.Win32.Foundation.PSTR, lpCurrentChar: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('USER32.dll')
def IsCharAlphaA(ch: win32more.Windows.Win32.Foundation.CHAR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def IsCharAlphaW(ch: Char) -> win32more.Windows.Win32.Foundation.BOOL: ...
IsCharAlpha = UnicodeAlias('IsCharAlphaW')
@winfunctype('USER32.dll')
def IsCharAlphaNumericA(ch: win32more.Windows.Win32.Foundation.CHAR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def IsCharAlphaNumericW(ch: Char) -> win32more.Windows.Win32.Foundation.BOOL: ...
IsCharAlphaNumeric = UnicodeAlias('IsCharAlphaNumericW')
@winfunctype('USER32.dll')
def IsCharUpperA(ch: win32more.Windows.Win32.Foundation.CHAR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def IsCharUpperW(ch: Char) -> win32more.Windows.Win32.Foundation.BOOL: ...
IsCharUpper = UnicodeAlias('IsCharUpperW')
@winfunctype('USER32.dll')
def IsCharLowerA(ch: win32more.Windows.Win32.Foundation.CHAR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetInputState() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetQueueStatus(flags: win32more.Windows.Win32.UI.WindowsAndMessaging.QUEUE_STATUS_FLAGS) -> UInt32: ...
@winfunctype('USER32.dll')
def MsgWaitForMultipleObjects(nCount: UInt32, pHandles: POINTER(win32more.Windows.Win32.Foundation.HANDLE), fWaitAll: win32more.Windows.Win32.Foundation.BOOL, dwMilliseconds: UInt32, dwWakeMask: win32more.Windows.Win32.UI.WindowsAndMessaging.QUEUE_STATUS_FLAGS) -> win32more.Windows.Win32.Foundation.WAIT_EVENT: ...
@winfunctype('USER32.dll')
def MsgWaitForMultipleObjectsEx(nCount: UInt32, pHandles: POINTER(win32more.Windows.Win32.Foundation.HANDLE), dwMilliseconds: UInt32, dwWakeMask: win32more.Windows.Win32.UI.WindowsAndMessaging.QUEUE_STATUS_FLAGS, dwFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.MSG_WAIT_FOR_MULTIPLE_OBJECTS_EX_FLAGS) -> win32more.Windows.Win32.Foundation.WAIT_EVENT: ...
@winfunctype('USER32.dll')
def SetTimer(hWnd: win32more.Windows.Win32.Foundation.HWND, nIDEvent: UIntPtr, uElapse: UInt32, lpTimerFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.TIMERPROC) -> UIntPtr: ...
@winfunctype('USER32.dll')
def SetCoalescableTimer(hWnd: win32more.Windows.Win32.Foundation.HWND, nIDEvent: UIntPtr, uElapse: UInt32, lpTimerFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.TIMERPROC, uToleranceDelay: UInt32) -> UIntPtr: ...
@winfunctype('USER32.dll')
def KillTimer(hWnd: win32more.Windows.Win32.Foundation.HWND, uIDEvent: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def IsWindowUnicode(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def LoadAcceleratorsA(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpTableName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HACCEL: ...
@winfunctype('USER32.dll')
def LoadAcceleratorsW(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpTableName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HACCEL: ...
LoadAccelerators = UnicodeAlias('LoadAcceleratorsW')
@winfunctype('USER32.dll')
def CreateAcceleratorTableA(paccel: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.ACCEL), cAccel: Int32) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HACCEL: ...
@winfunctype('USER32.dll')
def CreateAcceleratorTableW(paccel: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.ACCEL), cAccel: Int32) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HACCEL: ...
CreateAcceleratorTable = UnicodeAlias('CreateAcceleratorTableW')
@winfunctype('USER32.dll')
def DestroyAcceleratorTable(hAccel: win32more.Windows.Win32.UI.WindowsAndMessaging.HACCEL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def CopyAcceleratorTableA(hAccelSrc: win32more.Windows.Win32.UI.WindowsAndMessaging.HACCEL, lpAccelDst: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.ACCEL), cAccelEntries: Int32) -> Int32: ...
@winfunctype('USER32.dll')
def CopyAcceleratorTableW(hAccelSrc: win32more.Windows.Win32.UI.WindowsAndMessaging.HACCEL, lpAccelDst: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.ACCEL), cAccelEntries: Int32) -> Int32: ...
CopyAcceleratorTable = UnicodeAlias('CopyAcceleratorTableW')
@winfunctype('USER32.dll')
def TranslateAcceleratorA(hWnd: win32more.Windows.Win32.Foundation.HWND, hAccTable: win32more.Windows.Win32.UI.WindowsAndMessaging.HACCEL, lpMsg: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MSG)) -> Int32: ...
@winfunctype('USER32.dll')
def TranslateAcceleratorW(hWnd: win32more.Windows.Win32.Foundation.HWND, hAccTable: win32more.Windows.Win32.UI.WindowsAndMessaging.HACCEL, lpMsg: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MSG)) -> Int32: ...
TranslateAccelerator = UnicodeAlias('TranslateAcceleratorW')
@winfunctype('USER32.dll')
def GetSystemMetrics(nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX) -> Int32: ...
@winfunctype('USER32.dll')
def LoadMenuA(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpMenuName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU: ...
@winfunctype('USER32.dll')
def LoadMenuW(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpMenuName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU: ...
LoadMenu = UnicodeAlias('LoadMenuW')
@winfunctype('USER32.dll')
def LoadMenuIndirectA(lpMenuTemplate: VoidPtr) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU: ...
@winfunctype('USER32.dll')
def LoadMenuIndirectW(lpMenuTemplate: VoidPtr) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU: ...
LoadMenuIndirect = UnicodeAlias('LoadMenuIndirectW')
@winfunctype('USER32.dll')
def GetMenu(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU: ...
@winfunctype('USER32.dll')
def SetMenu(hWnd: win32more.Windows.Win32.Foundation.HWND, hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ChangeMenuA(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, cmd: UInt32, lpszNewItem: win32more.Windows.Win32.Foundation.PSTR, cmdInsert: UInt32, flags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ChangeMenuW(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, cmd: UInt32, lpszNewItem: win32more.Windows.Win32.Foundation.PWSTR, cmdInsert: UInt32, flags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
ChangeMenu = UnicodeAlias('ChangeMenuW')
@winfunctype('USER32.dll')
def HiliteMenuItem(hWnd: win32more.Windows.Win32.Foundation.HWND, hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uIDHiliteItem: UInt32, uHilite: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetMenuStringA(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uIDItem: UInt32, lpString: win32more.Windows.Win32.Foundation.PSTR, cchMax: Int32, flags: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS) -> Int32: ...
@winfunctype('USER32.dll')
def GetMenuStringW(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uIDItem: UInt32, lpString: win32more.Windows.Win32.Foundation.PWSTR, cchMax: Int32, flags: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS) -> Int32: ...
GetMenuString = UnicodeAlias('GetMenuStringW')
@winfunctype('USER32.dll')
def GetMenuState(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uId: UInt32, uFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS) -> UInt32: ...
@winfunctype('USER32.dll')
def DrawMenuBar(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetSystemMenu(hWnd: win32more.Windows.Win32.Foundation.HWND, bRevert: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU: ...
@winfunctype('USER32.dll')
def CreateMenu() -> win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU: ...
@winfunctype('USER32.dll')
def CreatePopupMenu() -> win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU: ...
@winfunctype('USER32.dll')
def DestroyMenu(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def CheckMenuItem(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uIDCheckItem: UInt32, uCheck: UInt32) -> UInt32: ...
@winfunctype('USER32.dll')
def EnableMenuItem(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uIDEnableItem: UInt32, uEnable: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetSubMenu(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, nPos: Int32) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU: ...
@winfunctype('USER32.dll')
def GetMenuItemID(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, nPos: Int32) -> UInt32: ...
@winfunctype('USER32.dll')
def GetMenuItemCount(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU) -> Int32: ...
@winfunctype('USER32.dll')
def InsertMenuA(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uPosition: UInt32, uFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS, uIDNewItem: UIntPtr, lpNewItem: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def InsertMenuW(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uPosition: UInt32, uFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS, uIDNewItem: UIntPtr, lpNewItem: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
InsertMenu = UnicodeAlias('InsertMenuW')
@winfunctype('USER32.dll')
def AppendMenuA(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS, uIDNewItem: UIntPtr, lpNewItem: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def AppendMenuW(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS, uIDNewItem: UIntPtr, lpNewItem: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
AppendMenu = UnicodeAlias('AppendMenuW')
@winfunctype('USER32.dll')
def ModifyMenuA(hMnu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uPosition: UInt32, uFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS, uIDNewItem: UIntPtr, lpNewItem: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ModifyMenuW(hMnu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uPosition: UInt32, uFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS, uIDNewItem: UIntPtr, lpNewItem: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
ModifyMenu = UnicodeAlias('ModifyMenuW')
@winfunctype('USER32.dll')
def RemoveMenu(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uPosition: UInt32, uFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DeleteMenu(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uPosition: UInt32, uFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetMenuItemBitmaps(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uPosition: UInt32, uFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS, hBitmapUnchecked: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, hBitmapChecked: win32more.Windows.Win32.Graphics.Gdi.HBITMAP) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetMenuCheckMarkDimensions() -> Int32: ...
@winfunctype('USER32.dll')
def TrackPopupMenu(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS, x: Int32, y: Int32, nReserved: Int32, hWnd: win32more.Windows.Win32.Foundation.HWND, prcRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def TrackPopupMenuEx(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uFlags: UInt32, x: Int32, y: Int32, hwnd: win32more.Windows.Win32.Foundation.HWND, lptpm: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.TPMPARAMS)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def CalculatePopupWindowPosition(anchorPoint: POINTER(win32more.Windows.Win32.Foundation.POINT), windowSize: POINTER(win32more.Windows.Win32.Foundation.SIZE), flags: UInt32, excludeRect: POINTER(win32more.Windows.Win32.Foundation.RECT), popupWindowPosition: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetMenuInfo(param0: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, param1: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MENUINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetMenuInfo(param0: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, param1: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MENUINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def EndMenu() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def InsertMenuItemA(hmenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, item: UInt32, fByPosition: win32more.Windows.Win32.Foundation.BOOL, lpmi: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MENUITEMINFOA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def InsertMenuItemW(hmenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, item: UInt32, fByPosition: win32more.Windows.Win32.Foundation.BOOL, lpmi: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MENUITEMINFOW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
InsertMenuItem = UnicodeAlias('InsertMenuItemW')
@winfunctype('USER32.dll')
def GetMenuItemInfoA(hmenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, item: UInt32, fByPosition: win32more.Windows.Win32.Foundation.BOOL, lpmii: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MENUITEMINFOA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetMenuItemInfoW(hmenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, item: UInt32, fByPosition: win32more.Windows.Win32.Foundation.BOOL, lpmii: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MENUITEMINFOW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetMenuItemInfo = UnicodeAlias('GetMenuItemInfoW')
@winfunctype('USER32.dll')
def SetMenuItemInfoA(hmenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, item: UInt32, fByPositon: win32more.Windows.Win32.Foundation.BOOL, lpmii: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MENUITEMINFOA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetMenuItemInfoW(hmenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, item: UInt32, fByPositon: win32more.Windows.Win32.Foundation.BOOL, lpmii: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MENUITEMINFOW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetMenuItemInfo = UnicodeAlias('SetMenuItemInfoW')
@winfunctype('USER32.dll')
def GetMenuDefaultItem(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, fByPos: UInt32, gmdiFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_MENU_DEFAULT_ITEM_FLAGS) -> UInt32: ...
@winfunctype('USER32.dll')
def SetMenuDefaultItem(hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uItem: UInt32, fByPos: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetMenuItemRect(hWnd: win32more.Windows.Win32.Foundation.HWND, hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, uItem: UInt32, lprcItem: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def MenuItemFromPoint(hWnd: win32more.Windows.Win32.Foundation.HWND, hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, ptScreen: win32more.Windows.Win32.Foundation.POINT) -> Int32: ...
@winfunctype('USER32.dll')
def DragObject(hwndParent: win32more.Windows.Win32.Foundation.HWND, hwndFrom: win32more.Windows.Win32.Foundation.HWND, fmt: UInt32, data: UIntPtr, hcur: win32more.Windows.Win32.UI.WindowsAndMessaging.HCURSOR) -> UInt32: ...
@winfunctype('USER32.dll')
def DrawIcon(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, X: Int32, Y: Int32, hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetForegroundWindow() -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def SwitchToThisWindow(hwnd: win32more.Windows.Win32.Foundation.HWND, fUnknown: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
@winfunctype('USER32.dll')
def SetForegroundWindow(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def AllowSetForegroundWindow(dwProcessId: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def LockSetForegroundWindow(uLockCode: win32more.Windows.Win32.UI.WindowsAndMessaging.FOREGROUND_WINDOW_LOCK_CODE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ScrollWindow(hWnd: win32more.Windows.Win32.Foundation.HWND, XAmount: Int32, YAmount: Int32, lpRect: POINTER(win32more.Windows.Win32.Foundation.RECT), lpClipRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ScrollDC(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, dx: Int32, dy: Int32, lprcScroll: POINTER(win32more.Windows.Win32.Foundation.RECT), lprcClip: POINTER(win32more.Windows.Win32.Foundation.RECT), hrgnUpdate: win32more.Windows.Win32.Graphics.Gdi.HRGN, lprcUpdate: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ScrollWindowEx(hWnd: win32more.Windows.Win32.Foundation.HWND, dx: Int32, dy: Int32, prcScroll: POINTER(win32more.Windows.Win32.Foundation.RECT), prcClip: POINTER(win32more.Windows.Win32.Foundation.RECT), hrgnUpdate: win32more.Windows.Win32.Graphics.Gdi.HRGN, prcUpdate: POINTER(win32more.Windows.Win32.Foundation.RECT), flags: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLL_WINDOW_FLAGS) -> Int32: ...
@winfunctype('USER32.dll')
def GetScrollPos(hWnd: win32more.Windows.Win32.Foundation.HWND, nBar: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS) -> Int32: ...
@winfunctype('USER32.dll')
def GetScrollRange(hWnd: win32more.Windows.Win32.Foundation.HWND, nBar: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS, lpMinPos: POINTER(Int32), lpMaxPos: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetPropA(hWnd: win32more.Windows.Win32.Foundation.HWND, lpString: win32more.Windows.Win32.Foundation.PSTR, hData: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetPropW(hWnd: win32more.Windows.Win32.Foundation.HWND, lpString: win32more.Windows.Win32.Foundation.PWSTR, hData: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetProp = UnicodeAlias('SetPropW')
@winfunctype('USER32.dll')
def GetPropA(hWnd: win32more.Windows.Win32.Foundation.HWND, lpString: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('USER32.dll')
def GetPropW(hWnd: win32more.Windows.Win32.Foundation.HWND, lpString: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
GetProp = UnicodeAlias('GetPropW')
@winfunctype('USER32.dll')
def RemovePropA(hWnd: win32more.Windows.Win32.Foundation.HWND, lpString: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('USER32.dll')
def RemovePropW(hWnd: win32more.Windows.Win32.Foundation.HWND, lpString: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
RemoveProp = UnicodeAlias('RemovePropW')
@winfunctype('USER32.dll')
def EnumPropsExA(hWnd: win32more.Windows.Win32.Foundation.HWND, lpEnumFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.PROPENUMPROCEXA, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype('USER32.dll')
def EnumPropsExW(hWnd: win32more.Windows.Win32.Foundation.HWND, lpEnumFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.PROPENUMPROCEXW, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
EnumPropsEx = UnicodeAlias('EnumPropsExW')
@winfunctype('USER32.dll')
def EnumPropsA(hWnd: win32more.Windows.Win32.Foundation.HWND, lpEnumFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.PROPENUMPROCA) -> Int32: ...
@winfunctype('USER32.dll')
def EnumPropsW(hWnd: win32more.Windows.Win32.Foundation.HWND, lpEnumFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.PROPENUMPROCW) -> Int32: ...
EnumProps = UnicodeAlias('EnumPropsW')
@winfunctype('USER32.dll')
def SetWindowTextA(hWnd: win32more.Windows.Win32.Foundation.HWND, lpString: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetWindowTextW(hWnd: win32more.Windows.Win32.Foundation.HWND, lpString: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetWindowText = UnicodeAlias('SetWindowTextW')
@winfunctype('USER32.dll')
def GetWindowTextA(hWnd: win32more.Windows.Win32.Foundation.HWND, lpString: win32more.Windows.Win32.Foundation.PSTR, nMaxCount: Int32) -> Int32: ...
@winfunctype('USER32.dll')
def GetWindowTextW(hWnd: win32more.Windows.Win32.Foundation.HWND, lpString: win32more.Windows.Win32.Foundation.PWSTR, nMaxCount: Int32) -> Int32: ...
GetWindowText = UnicodeAlias('GetWindowTextW')
@winfunctype('USER32.dll')
def GetWindowTextLengthA(hWnd: win32more.Windows.Win32.Foundation.HWND) -> Int32: ...
@winfunctype('USER32.dll')
def GetWindowTextLengthW(hWnd: win32more.Windows.Win32.Foundation.HWND) -> Int32: ...
GetWindowTextLength = UnicodeAlias('GetWindowTextLengthW')
@winfunctype('USER32.dll')
def GetClientRect(hWnd: win32more.Windows.Win32.Foundation.HWND, lpRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetWindowRect(hWnd: win32more.Windows.Win32.Foundation.HWND, lpRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def AdjustWindowRect(lpRect: POINTER(win32more.Windows.Win32.Foundation.RECT), dwStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE, bMenu: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def AdjustWindowRectEx(lpRect: POINTER(win32more.Windows.Win32.Foundation.RECT), dwStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE, bMenu: win32more.Windows.Win32.Foundation.BOOL, dwExStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def MessageBoxA(hWnd: win32more.Windows.Win32.Foundation.HWND, lpText: win32more.Windows.Win32.Foundation.PSTR, lpCaption: win32more.Windows.Win32.Foundation.PSTR, uType: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE) -> win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT: ...
@winfunctype('USER32.dll')
def MessageBoxW(hWnd: win32more.Windows.Win32.Foundation.HWND, lpText: win32more.Windows.Win32.Foundation.PWSTR, lpCaption: win32more.Windows.Win32.Foundation.PWSTR, uType: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE) -> win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT: ...
MessageBox = UnicodeAlias('MessageBoxW')
@winfunctype('USER32.dll')
def MessageBoxExA(hWnd: win32more.Windows.Win32.Foundation.HWND, lpText: win32more.Windows.Win32.Foundation.PSTR, lpCaption: win32more.Windows.Win32.Foundation.PSTR, uType: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE, wLanguageId: UInt16) -> win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT: ...
@winfunctype('USER32.dll')
def MessageBoxExW(hWnd: win32more.Windows.Win32.Foundation.HWND, lpText: win32more.Windows.Win32.Foundation.PWSTR, lpCaption: win32more.Windows.Win32.Foundation.PWSTR, uType: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE, wLanguageId: UInt16) -> win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT: ...
MessageBoxEx = UnicodeAlias('MessageBoxExW')
@winfunctype('USER32.dll')
def MessageBoxIndirectA(lpmbp: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MSGBOXPARAMSA)) -> win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT: ...
@winfunctype('USER32.dll')
def MessageBoxIndirectW(lpmbp: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MSGBOXPARAMSW)) -> win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT: ...
MessageBoxIndirect = UnicodeAlias('MessageBoxIndirectW')
@winfunctype('USER32.dll')
def ShowCursor(bShow: win32more.Windows.Win32.Foundation.BOOL) -> Int32: ...
@winfunctype('USER32.dll')
def SetCursorPos(X: Int32, Y: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetPhysicalCursorPos(X: Int32, Y: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetCursor(hCursor: win32more.Windows.Win32.UI.WindowsAndMessaging.HCURSOR) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HCURSOR: ...
@winfunctype('USER32.dll')
def GetCursorPos(lpPoint: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetPhysicalCursorPos(lpPoint: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetClipCursor(lpRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetCursor() -> win32more.Windows.Win32.UI.WindowsAndMessaging.HCURSOR: ...
@winfunctype('USER32.dll')
def CreateCaret(hWnd: win32more.Windows.Win32.Foundation.HWND, hBitmap: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, nWidth: Int32, nHeight: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetCaretBlinkTime() -> UInt32: ...
@winfunctype('USER32.dll')
def SetCaretBlinkTime(uMSeconds: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DestroyCaret() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def HideCaret(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ShowCaret(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetCaretPos(X: Int32, Y: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetCaretPos(lpPoint: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def LogicalToPhysicalPoint(hWnd: win32more.Windows.Win32.Foundation.HWND, lpPoint: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def PhysicalToLogicalPoint(hWnd: win32more.Windows.Win32.Foundation.HWND, lpPoint: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def WindowFromPoint(Point: win32more.Windows.Win32.Foundation.POINT) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def WindowFromPhysicalPoint(Point: win32more.Windows.Win32.Foundation.POINT) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def ChildWindowFromPoint(hWndParent: win32more.Windows.Win32.Foundation.HWND, Point: win32more.Windows.Win32.Foundation.POINT) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def ClipCursor(lpRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ChildWindowFromPointEx(hwnd: win32more.Windows.Win32.Foundation.HWND, pt: win32more.Windows.Win32.Foundation.POINT, flags: win32more.Windows.Win32.UI.WindowsAndMessaging.CWP_FLAGS) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def GetWindowWord(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: Int32) -> UInt16: ...
@winfunctype('USER32.dll')
def SetWindowWord(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: Int32, wNewWord: UInt16) -> UInt16: ...
@winfunctype('USER32.dll')
def GetWindowLongA(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX) -> Int32: ...
@winfunctype('USER32.dll')
def GetWindowLongW(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX) -> Int32: ...
GetWindowLong = UnicodeAlias('GetWindowLongW')
@winfunctype('USER32.dll')
def SetWindowLongA(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX, dwNewLong: Int32) -> Int32: ...
@winfunctype('USER32.dll')
def SetWindowLongW(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX, dwNewLong: Int32) -> Int32: ...
SetWindowLong = UnicodeAlias('SetWindowLongW')
@winfunctype('USER32.dll')
def GetClassWord(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: Int32) -> UInt16: ...
@winfunctype('USER32.dll')
def SetClassWord(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: Int32, wNewWord: UInt16) -> UInt16: ...
@winfunctype('USER32.dll')
def GetClassLongA(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX) -> UInt32: ...
@winfunctype('USER32.dll')
def GetClassLongW(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX) -> UInt32: ...
GetClassLong = UnicodeAlias('GetClassLongW')
@winfunctype('USER32.dll')
def SetClassLongA(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX, dwNewLong: Int32) -> UInt32: ...
@winfunctype('USER32.dll')
def SetClassLongW(hWnd: win32more.Windows.Win32.Foundation.HWND, nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX, dwNewLong: Int32) -> UInt32: ...
SetClassLong = UnicodeAlias('SetClassLongW')
@winfunctype('USER32.dll')
def GetProcessDefaultLayout(pdwDefaultLayout: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetProcessDefaultLayout(dwDefaultLayout: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetDesktopWindow() -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def GetParent(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def SetParent(hWndChild: win32more.Windows.Win32.Foundation.HWND, hWndNewParent: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def EnumChildWindows(hWndParent: win32more.Windows.Win32.Foundation.HWND, lpEnumFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDENUMPROC, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def FindWindowA(lpClassName: win32more.Windows.Win32.Foundation.PSTR, lpWindowName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def FindWindowW(lpClassName: win32more.Windows.Win32.Foundation.PWSTR, lpWindowName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HWND: ...
FindWindow = UnicodeAlias('FindWindowW')
@winfunctype('USER32.dll')
def FindWindowExA(hWndParent: win32more.Windows.Win32.Foundation.HWND, hWndChildAfter: win32more.Windows.Win32.Foundation.HWND, lpszClass: win32more.Windows.Win32.Foundation.PSTR, lpszWindow: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def FindWindowExW(hWndParent: win32more.Windows.Win32.Foundation.HWND, hWndChildAfter: win32more.Windows.Win32.Foundation.HWND, lpszClass: win32more.Windows.Win32.Foundation.PWSTR, lpszWindow: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HWND: ...
FindWindowEx = UnicodeAlias('FindWindowExW')
@winfunctype('USER32.dll')
def GetShellWindow() -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def RegisterShellHookWindow(hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DeregisterShellHookWindow(hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def EnumWindows(lpEnumFunc: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDENUMPROC, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def EnumThreadWindows(dwThreadId: UInt32, lpfn: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDENUMPROC, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetClassNameA(hWnd: win32more.Windows.Win32.Foundation.HWND, lpClassName: win32more.Windows.Win32.Foundation.PSTR, nMaxCount: Int32) -> Int32: ...
@winfunctype('USER32.dll')
def GetClassNameW(hWnd: win32more.Windows.Win32.Foundation.HWND, lpClassName: win32more.Windows.Win32.Foundation.PWSTR, nMaxCount: Int32) -> Int32: ...
GetClassName = UnicodeAlias('GetClassNameW')
@winfunctype('USER32.dll')
def GetTopWindow(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def GetWindowThreadProcessId(hWnd: win32more.Windows.Win32.Foundation.HWND, lpdwProcessId: POINTER(UInt32)) -> UInt32: ...
@winfunctype('USER32.dll')
def IsGUIThread(bConvert: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetLastActivePopup(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def GetWindow(hWnd: win32more.Windows.Win32.Foundation.HWND, uCmd: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_WINDOW_CMD) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def SetWindowsHookA(nFilterType: Int32, pfnFilterProc: win32more.Windows.Win32.UI.WindowsAndMessaging.HOOKPROC) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HHOOK: ...
@winfunctype('USER32.dll')
def SetWindowsHookW(nFilterType: Int32, pfnFilterProc: win32more.Windows.Win32.UI.WindowsAndMessaging.HOOKPROC) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HHOOK: ...
SetWindowsHook = UnicodeAlias('SetWindowsHookW')
@winfunctype('USER32.dll')
def UnhookWindowsHook(nCode: Int32, pfnFilterProc: win32more.Windows.Win32.UI.WindowsAndMessaging.HOOKPROC) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetWindowsHookExA(idHook: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWS_HOOK_ID, lpfn: win32more.Windows.Win32.UI.WindowsAndMessaging.HOOKPROC, hmod: win32more.Windows.Win32.Foundation.HINSTANCE, dwThreadId: UInt32) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HHOOK: ...
@winfunctype('USER32.dll')
def SetWindowsHookExW(idHook: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWS_HOOK_ID, lpfn: win32more.Windows.Win32.UI.WindowsAndMessaging.HOOKPROC, hmod: win32more.Windows.Win32.Foundation.HINSTANCE, dwThreadId: UInt32) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HHOOK: ...
SetWindowsHookEx = UnicodeAlias('SetWindowsHookExW')
@winfunctype('USER32.dll')
def UnhookWindowsHookEx(hhk: win32more.Windows.Win32.UI.WindowsAndMessaging.HHOOK) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def CallNextHookEx(hhk: win32more.Windows.Win32.UI.WindowsAndMessaging.HHOOK, nCode: Int32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('USER32.dll')
def CheckMenuRadioItem(hmenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, first: UInt32, last: UInt32, check: UInt32, flags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def LoadCursorA(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpCursorName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HCURSOR: ...
@winfunctype('USER32.dll')
def LoadCursorW(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpCursorName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HCURSOR: ...
LoadCursor = UnicodeAlias('LoadCursorW')
@winfunctype('USER32.dll')
def LoadCursorFromFileA(lpFileName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HCURSOR: ...
@winfunctype('USER32.dll')
def LoadCursorFromFileW(lpFileName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HCURSOR: ...
LoadCursorFromFile = UnicodeAlias('LoadCursorFromFileW')
@winfunctype('USER32.dll')
def CreateCursor(hInst: win32more.Windows.Win32.Foundation.HINSTANCE, xHotSpot: Int32, yHotSpot: Int32, nWidth: Int32, nHeight: Int32, pvANDPlane: VoidPtr, pvXORPlane: VoidPtr) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HCURSOR: ...
@winfunctype('USER32.dll')
def DestroyCursor(hCursor: win32more.Windows.Win32.UI.WindowsAndMessaging.HCURSOR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetSystemCursor(hcur: win32more.Windows.Win32.UI.WindowsAndMessaging.HCURSOR, id: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_CURSOR_ID) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def LoadIconA(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpIconName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HICON: ...
@winfunctype('USER32.dll')
def LoadIconW(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpIconName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HICON: ...
LoadIcon = UnicodeAlias('LoadIconW')
@winfunctype('USER32.dll')
def PrivateExtractIconsA(szFileName: win32more.Windows.Win32.Foundation.PSTR, nIconIndex: Int32, cxIcon: Int32, cyIcon: Int32, phicon: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON), piconid: POINTER(UInt32), nIcons: UInt32, flags: UInt32) -> UInt32: ...
@winfunctype('USER32.dll')
def PrivateExtractIconsW(szFileName: win32more.Windows.Win32.Foundation.PWSTR, nIconIndex: Int32, cxIcon: Int32, cyIcon: Int32, phicon: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON), piconid: POINTER(UInt32), nIcons: UInt32, flags: UInt32) -> UInt32: ...
PrivateExtractIcons = UnicodeAlias('PrivateExtractIconsW')
@winfunctype('USER32.dll')
def CreateIcon(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, nWidth: Int32, nHeight: Int32, cPlanes: Byte, cBitsPixel: Byte, lpbANDbits: POINTER(Byte), lpbXORbits: POINTER(Byte)) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HICON: ...
@winfunctype('USER32.dll')
def DestroyIcon(hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def LookupIconIdFromDirectory(presbits: POINTER(Byte), fIcon: win32more.Windows.Win32.Foundation.BOOL) -> Int32: ...
@winfunctype('USER32.dll')
def LookupIconIdFromDirectoryEx(presbits: POINTER(Byte), fIcon: win32more.Windows.Win32.Foundation.BOOL, cxDesired: Int32, cyDesired: Int32, Flags: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS) -> Int32: ...
@winfunctype('USER32.dll')
def CreateIconFromResource(presbits: POINTER(Byte), dwResSize: UInt32, fIcon: win32more.Windows.Win32.Foundation.BOOL, dwVer: UInt32) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HICON: ...
@winfunctype('USER32.dll')
def CreateIconFromResourceEx(presbits: POINTER(Byte), dwResSize: UInt32, fIcon: win32more.Windows.Win32.Foundation.BOOL, dwVer: UInt32, cxDesired: Int32, cyDesired: Int32, Flags: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HICON: ...
@winfunctype('USER32.dll')
def LoadImageA(hInst: win32more.Windows.Win32.Foundation.HINSTANCE, name: win32more.Windows.Win32.Foundation.PSTR, type: win32more.Windows.Win32.UI.WindowsAndMessaging.GDI_IMAGE_TYPE, cx: Int32, cy: Int32, fuLoad: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('USER32.dll')
def LoadImageW(hInst: win32more.Windows.Win32.Foundation.HINSTANCE, name: win32more.Windows.Win32.Foundation.PWSTR, type: win32more.Windows.Win32.UI.WindowsAndMessaging.GDI_IMAGE_TYPE, cx: Int32, cy: Int32, fuLoad: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS) -> win32more.Windows.Win32.Foundation.HANDLE: ...
LoadImage = UnicodeAlias('LoadImageW')
@winfunctype('USER32.dll')
def CopyImage(h: win32more.Windows.Win32.Foundation.HANDLE, type: win32more.Windows.Win32.UI.WindowsAndMessaging.GDI_IMAGE_TYPE, cx: Int32, cy: Int32, flags: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('USER32.dll')
def DrawIconEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, xLeft: Int32, yTop: Int32, hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON, cxWidth: Int32, cyWidth: Int32, istepIfAniCur: UInt32, hbrFlickerFreeDraw: win32more.Windows.Win32.Graphics.Gdi.HBRUSH, diFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.DI_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def CreateIconIndirect(piconinfo: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.ICONINFO)) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HICON: ...
@winfunctype('USER32.dll')
def CopyIcon(hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HICON: ...
@winfunctype('USER32.dll')
def GetIconInfo(hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON, piconinfo: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.ICONINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetIconInfoExA(hicon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON, piconinfo: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.ICONINFOEXA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetIconInfoExW(hicon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON, piconinfo: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.ICONINFOEXW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetIconInfoEx = UnicodeAlias('GetIconInfoExW')
@winfunctype('USER32.dll')
def IsDialogMessageA(hDlg: win32more.Windows.Win32.Foundation.HWND, lpMsg: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MSG)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def IsDialogMessageW(hDlg: win32more.Windows.Win32.Foundation.HWND, lpMsg: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MSG)) -> win32more.Windows.Win32.Foundation.BOOL: ...
IsDialogMessage = UnicodeAlias('IsDialogMessageW')
@winfunctype('USER32.dll')
def MapDialogRect(hDlg: win32more.Windows.Win32.Foundation.HWND, lpRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetScrollInfo(hwnd: win32more.Windows.Win32.Foundation.HWND, nBar: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS, lpsi: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DefFrameProcA(hWnd: win32more.Windows.Win32.Foundation.HWND, hWndMDIClient: win32more.Windows.Win32.Foundation.HWND, uMsg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('USER32.dll')
def DefFrameProcW(hWnd: win32more.Windows.Win32.Foundation.HWND, hWndMDIClient: win32more.Windows.Win32.Foundation.HWND, uMsg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
DefFrameProc = UnicodeAlias('DefFrameProcW')
@winfunctype('USER32.dll')
def DefMDIChildProcA(hWnd: win32more.Windows.Win32.Foundation.HWND, uMsg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('USER32.dll')
def DefMDIChildProcW(hWnd: win32more.Windows.Win32.Foundation.HWND, uMsg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
DefMDIChildProc = UnicodeAlias('DefMDIChildProcW')
@winfunctype('USER32.dll')
def TranslateMDISysAccel(hWndClient: win32more.Windows.Win32.Foundation.HWND, lpMsg: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MSG)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ArrangeIconicWindows(hWnd: win32more.Windows.Win32.Foundation.HWND) -> UInt32: ...
@winfunctype('USER32.dll')
def CreateMDIWindowA(lpClassName: win32more.Windows.Win32.Foundation.PSTR, lpWindowName: win32more.Windows.Win32.Foundation.PSTR, dwStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE, X: Int32, Y: Int32, nWidth: Int32, nHeight: Int32, hWndParent: win32more.Windows.Win32.Foundation.HWND, hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def CreateMDIWindowW(lpClassName: win32more.Windows.Win32.Foundation.PWSTR, lpWindowName: win32more.Windows.Win32.Foundation.PWSTR, dwStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE, X: Int32, Y: Int32, nWidth: Int32, nHeight: Int32, hWndParent: win32more.Windows.Win32.Foundation.HWND, hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HWND: ...
CreateMDIWindow = UnicodeAlias('CreateMDIWindowW')
@winfunctype('USER32.dll')
def TileWindows(hwndParent: win32more.Windows.Win32.Foundation.HWND, wHow: win32more.Windows.Win32.UI.WindowsAndMessaging.TILE_WINDOWS_HOW, lpRect: POINTER(win32more.Windows.Win32.Foundation.RECT), cKids: UInt32, lpKids: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> UInt16: ...
@winfunctype('USER32.dll')
def CascadeWindows(hwndParent: win32more.Windows.Win32.Foundation.HWND, wHow: win32more.Windows.Win32.UI.WindowsAndMessaging.CASCADE_WINDOWS_HOW, lpRect: POINTER(win32more.Windows.Win32.Foundation.RECT), cKids: UInt32, lpKids: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> UInt16: ...
@winfunctype('USER32.dll')
def SystemParametersInfoA(uiAction: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION, uiParam: UInt32, pvParam: VoidPtr, fWinIni: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_UPDATE_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SystemParametersInfoW(uiAction: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION, uiParam: UInt32, pvParam: VoidPtr, fWinIni: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_UPDATE_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
SystemParametersInfo = UnicodeAlias('SystemParametersInfoW')
@winfunctype('USER32.dll')
def SoundSentry() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetDebugErrorLevel(dwLevel: UInt32) -> Void: ...
@winfunctype('USER32.dll')
def InternalGetWindowText(hWnd: win32more.Windows.Win32.Foundation.HWND, pString: win32more.Windows.Win32.Foundation.PWSTR, cchMaxCount: Int32) -> Int32: ...
@winfunctype('USER32.dll')
def CancelShutdown() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetGUIThreadInfo(idThread: UInt32, pgui: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.GUITHREADINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetProcessDPIAware() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def IsProcessDPIAware() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def InheritWindowMonitor(hwnd: win32more.Windows.Win32.Foundation.HWND, hwndInherit: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetWindowModuleFileNameA(hwnd: win32more.Windows.Win32.Foundation.HWND, pszFileName: win32more.Windows.Win32.Foundation.PSTR, cchFileNameMax: UInt32) -> UInt32: ...
@winfunctype('USER32.dll')
def GetWindowModuleFileNameW(hwnd: win32more.Windows.Win32.Foundation.HWND, pszFileName: win32more.Windows.Win32.Foundation.PWSTR, cchFileNameMax: UInt32) -> UInt32: ...
GetWindowModuleFileName = UnicodeAlias('GetWindowModuleFileNameW')
@winfunctype('USER32.dll')
def GetCursorInfo(pci: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.CURSORINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetWindowInfo(hwnd: win32more.Windows.Win32.Foundation.HWND, pwi: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetTitleBarInfo(hwnd: win32more.Windows.Win32.Foundation.HWND, pti: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.TITLEBARINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetMenuBarInfo(hwnd: win32more.Windows.Win32.Foundation.HWND, idObject: win32more.Windows.Win32.UI.WindowsAndMessaging.OBJECT_IDENTIFIER, idItem: Int32, pmbi: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MENUBARINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetScrollBarInfo(hwnd: win32more.Windows.Win32.Foundation.HWND, idObject: win32more.Windows.Win32.UI.WindowsAndMessaging.OBJECT_IDENTIFIER, psbi: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBARINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetAncestor(hwnd: win32more.Windows.Win32.Foundation.HWND, gaFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_ANCESTOR_FLAGS) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def RealChildWindowFromPoint(hwndParent: win32more.Windows.Win32.Foundation.HWND, ptParentClientCoords: win32more.Windows.Win32.Foundation.POINT) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def RealGetWindowClassA(hwnd: win32more.Windows.Win32.Foundation.HWND, ptszClassName: win32more.Windows.Win32.Foundation.PSTR, cchClassNameMax: UInt32) -> UInt32: ...
@winfunctype('USER32.dll')
def RealGetWindowClassW(hwnd: win32more.Windows.Win32.Foundation.HWND, ptszClassName: win32more.Windows.Win32.Foundation.PWSTR, cchClassNameMax: UInt32) -> UInt32: ...
RealGetWindowClass = UnicodeAlias('RealGetWindowClassW')
@winfunctype('USER32.dll')
def GetAltTabInfoA(hwnd: win32more.Windows.Win32.Foundation.HWND, iItem: Int32, pati: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.ALTTABINFO), pszItemText: win32more.Windows.Win32.Foundation.PSTR, cchItemText: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetAltTabInfoW(hwnd: win32more.Windows.Win32.Foundation.HWND, iItem: Int32, pati: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.ALTTABINFO), pszItemText: win32more.Windows.Win32.Foundation.PWSTR, cchItemText: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetAltTabInfo = UnicodeAlias('GetAltTabInfoW')
@winfunctype('USER32.dll')
def ChangeWindowMessageFilter(message: UInt32, dwFlag: win32more.Windows.Win32.UI.WindowsAndMessaging.CHANGE_WINDOW_MESSAGE_FILTER_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ChangeWindowMessageFilterEx(hwnd: win32more.Windows.Win32.Foundation.HWND, message: UInt32, action: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_MESSAGE_FILTER_ACTION, pChangeFilterStruct: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.CHANGEFILTERSTRUCT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetAdditionalForegroundBoostProcesses(topLevelWindow: win32more.Windows.Win32.Foundation.HWND, processHandleCount: UInt32, processHandleArray: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def RegisterForTooltipDismissNotification(hWnd: win32more.Windows.Win32.Foundation.HWND, tdFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.TOOLTIP_DISMISS_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MrmSupport.dll')
def CreateResourceIndexer(projectRoot: win32more.Windows.Win32.Foundation.PWSTR, extensionDllPath: win32more.Windows.Win32.Foundation.PWSTR, ppResourceIndexer: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def DestroyResourceIndexer(resourceIndexer: VoidPtr) -> Void: ...
@winfunctype('MrmSupport.dll')
def IndexFilePath(resourceIndexer: VoidPtr, filePath: win32more.Windows.Win32.Foundation.PWSTR, ppResourceUri: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pQualifierCount: POINTER(UInt32), ppQualifiers: POINTER(POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.IndexedResourceQualifier))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def DestroyIndexedResults(resourceUri: win32more.Windows.Win32.Foundation.PWSTR, qualifierCount: UInt32, qualifiers: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.IndexedResourceQualifier)) -> Void: ...
@winfunctype('MrmSupport.dll')
def MrmCreateResourceIndexer(packageFamilyName: win32more.Windows.Win32.Foundation.PWSTR, projectRoot: win32more.Windows.Win32.Foundation.PWSTR, platformVersion: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPlatformVersion, defaultQualifiers: win32more.Windows.Win32.Foundation.PWSTR, indexer: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmCreateResourceIndexerFromPreviousSchemaFile(projectRoot: win32more.Windows.Win32.Foundation.PWSTR, platformVersion: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPlatformVersion, defaultQualifiers: win32more.Windows.Win32.Foundation.PWSTR, schemaFile: win32more.Windows.Win32.Foundation.PWSTR, indexer: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmCreateResourceIndexerFromPreviousPriFile(projectRoot: win32more.Windows.Win32.Foundation.PWSTR, platformVersion: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPlatformVersion, defaultQualifiers: win32more.Windows.Win32.Foundation.PWSTR, priFile: win32more.Windows.Win32.Foundation.PWSTR, indexer: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmCreateResourceIndexerFromPreviousSchemaData(projectRoot: win32more.Windows.Win32.Foundation.PWSTR, platformVersion: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPlatformVersion, defaultQualifiers: win32more.Windows.Win32.Foundation.PWSTR, schemaXmlData: POINTER(Byte), schemaXmlSize: UInt32, indexer: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmCreateResourceIndexerFromPreviousPriData(projectRoot: win32more.Windows.Win32.Foundation.PWSTR, platformVersion: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPlatformVersion, defaultQualifiers: win32more.Windows.Win32.Foundation.PWSTR, priData: POINTER(Byte), priSize: UInt32, indexer: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmCreateResourceIndexerWithFlags(packageFamilyName: win32more.Windows.Win32.Foundation.PWSTR, projectRoot: win32more.Windows.Win32.Foundation.PWSTR, platformVersion: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPlatformVersion, defaultQualifiers: win32more.Windows.Win32.Foundation.PWSTR, flags: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmIndexerFlags, indexer: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmIndexString(indexer: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerHandle, resourceUri: win32more.Windows.Win32.Foundation.PWSTR, resourceString: win32more.Windows.Win32.Foundation.PWSTR, qualifiers: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmIndexEmbeddedData(indexer: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerHandle, resourceUri: win32more.Windows.Win32.Foundation.PWSTR, embeddedData: POINTER(Byte), embeddedDataSize: UInt32, qualifiers: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmIndexFile(indexer: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerHandle, resourceUri: win32more.Windows.Win32.Foundation.PWSTR, filePath: win32more.Windows.Win32.Foundation.PWSTR, qualifiers: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmIndexFileAutoQualifiers(indexer: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerHandle, filePath: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmIndexResourceContainerAutoQualifiers(indexer: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerHandle, containerPath: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmCreateResourceFile(indexer: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerHandle, packagingMode: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPackagingMode, packagingOptions: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPackagingOptions, outputDirectory: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmCreateResourceFileWithChecksum(indexer: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerHandle, packagingMode: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPackagingMode, packagingOptions: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPackagingOptions, checksum: UInt32, outputDirectory: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmCreateResourceFileInMemory(indexer: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerHandle, packagingMode: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPackagingMode, packagingOptions: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPackagingOptions, outputPriData: POINTER(POINTER(Byte)), outputPriSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmPeekResourceIndexerMessages(handle: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerHandle, messages: POINTER(POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerMessage)), numMsgs: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmDestroyIndexerAndMessages(indexer: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerHandle) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmFreeMemory(data: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmDumpPriFile(indexFileName: win32more.Windows.Win32.Foundation.PWSTR, schemaPriFile: win32more.Windows.Win32.Foundation.PWSTR, dumpType: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmDumpType, outputXmlFile: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmDumpPriFileInMemory(indexFileName: win32more.Windows.Win32.Foundation.PWSTR, schemaPriFile: win32more.Windows.Win32.Foundation.PWSTR, dumpType: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmDumpType, outputXmlData: POINTER(POINTER(Byte)), outputXmlSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmDumpPriDataInMemory(inputPriData: POINTER(Byte), inputPriSize: UInt32, schemaPriData: POINTER(Byte), schemaPriSize: UInt32, dumpType: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmDumpType, outputXmlData: POINTER(POINTER(Byte)), outputXmlSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmCreateConfig(platformVersion: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPlatformVersion, defaultQualifiers: win32more.Windows.Win32.Foundation.PWSTR, outputXmlFile: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmCreateConfigInMemory(platformVersion: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPlatformVersion, defaultQualifiers: win32more.Windows.Win32.Foundation.PWSTR, outputXmlData: POINTER(POINTER(Byte)), outputXmlSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MrmSupport.dll')
def MrmGetPriFileContentChecksum(priFile: win32more.Windows.Win32.Foundation.PWSTR, checksum: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USER32.dll')
def IsWindowArranged(hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
CASCADE_WINDOWS_HOW = UInt32
MDITILE_SKIPDISABLED: win32more.Windows.Win32.UI.WindowsAndMessaging.CASCADE_WINDOWS_HOW = 2
MDITILE_ZORDER: win32more.Windows.Win32.UI.WindowsAndMessaging.CASCADE_WINDOWS_HOW = 4
class CBTACTIVATESTRUCT(Structure):
    fMouse: win32more.Windows.Win32.Foundation.BOOL
    hWndActive: win32more.Windows.Win32.Foundation.HWND
class CBT_CREATEWNDA(Structure):
    lpcs: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.CREATESTRUCTA)
    hwndInsertAfter: win32more.Windows.Win32.Foundation.HWND
class CBT_CREATEWNDW(Structure):
    lpcs: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.CREATESTRUCTW)
    hwndInsertAfter: win32more.Windows.Win32.Foundation.HWND
CBT_CREATEWND = UnicodeAlias('CBT_CREATEWNDW')
class CHANGEFILTERSTRUCT(Structure):
    cbSize: UInt32
    ExtStatus: win32more.Windows.Win32.UI.WindowsAndMessaging.MSGFLTINFO_STATUS
CHANGE_WINDOW_MESSAGE_FILTER_FLAGS = UInt32
MSGFLT_ADD: win32more.Windows.Win32.UI.WindowsAndMessaging.CHANGE_WINDOW_MESSAGE_FILTER_FLAGS = 1
MSGFLT_REMOVE: win32more.Windows.Win32.UI.WindowsAndMessaging.CHANGE_WINDOW_MESSAGE_FILTER_FLAGS = 2
class CLIENTCREATESTRUCT(Structure):
    hWindowMenu: win32more.Windows.Win32.Foundation.HANDLE
    idFirstChild: UInt32
class CREATESTRUCTA(Structure):
    lpCreateParams: VoidPtr
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU
    hwndParent: win32more.Windows.Win32.Foundation.HWND
    cy: Int32
    cx: Int32
    y: Int32
    x: Int32
    style: Int32
    lpszName: win32more.Windows.Win32.Foundation.PSTR
    lpszClass: win32more.Windows.Win32.Foundation.PSTR
    dwExStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE
class CREATESTRUCTW(Structure):
    lpCreateParams: VoidPtr
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU
    hwndParent: win32more.Windows.Win32.Foundation.HWND
    cy: Int32
    cx: Int32
    y: Int32
    x: Int32
    style: Int32
    lpszName: win32more.Windows.Win32.Foundation.PWSTR
    lpszClass: win32more.Windows.Win32.Foundation.PWSTR
    dwExStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE
CREATESTRUCT = UnicodeAlias('CREATESTRUCTW')
class CURSORINFO(Structure):
    cbSize: UInt32
    flags: win32more.Windows.Win32.UI.WindowsAndMessaging.CURSORINFO_FLAGS
    hCursor: win32more.Windows.Win32.UI.WindowsAndMessaging.HCURSOR
    ptScreenPos: win32more.Windows.Win32.Foundation.POINT
CURSORINFO_FLAGS = UInt32
CURSOR_SHOWING: win32more.Windows.Win32.UI.WindowsAndMessaging.CURSORINFO_FLAGS = 1
CURSOR_SUPPRESSED: win32more.Windows.Win32.UI.WindowsAndMessaging.CURSORINFO_FLAGS = 2
class CURSORSHAPE(Structure):
    xHotSpot: Int32
    yHotSpot: Int32
    cx: Int32
    cy: Int32
    cbWidth: Int32
    Planes: Byte
    BitsPixel: Byte
class CWPRETSTRUCT(Structure):
    lResult: win32more.Windows.Win32.Foundation.LRESULT
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    wParam: win32more.Windows.Win32.Foundation.WPARAM
    message: UInt32
    hwnd: win32more.Windows.Win32.Foundation.HWND
class CWPSTRUCT(Structure):
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    wParam: win32more.Windows.Win32.Foundation.WPARAM
    message: UInt32
    hwnd: win32more.Windows.Win32.Foundation.HWND
CWP_FLAGS = UInt32
CWP_ALL: win32more.Windows.Win32.UI.WindowsAndMessaging.CWP_FLAGS = 0
CWP_SKIPINVISIBLE: win32more.Windows.Win32.UI.WindowsAndMessaging.CWP_FLAGS = 1
CWP_SKIPDISABLED: win32more.Windows.Win32.UI.WindowsAndMessaging.CWP_FLAGS = 2
CWP_SKIPTRANSPARENT: win32more.Windows.Win32.UI.WindowsAndMessaging.CWP_FLAGS = 4
class DEBUGHOOKINFO(Structure):
    idThread: UInt32
    idThreadInstaller: UInt32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    wParam: win32more.Windows.Win32.Foundation.WPARAM
    code: Int32
class DEVICE_EVENT_BECOMING_READY(Structure):
    Version: UInt32
    Reason: UInt32
    Estimated100msToReady: UInt32
class DEVICE_EVENT_EXTERNAL_REQUEST(Structure):
    Version: UInt32
    DeviceClass: UInt32
    ButtonStatus: UInt16
    Request: UInt16
    SystemTime: Int64
class DEVICE_EVENT_GENERIC_DATA(Structure):
    EventNumber: UInt32
class DEVICE_EVENT_MOUNT(Structure):
    Version: UInt32
    Flags: UInt32
    FileSystemNameLength: UInt32
    FileSystemNameOffset: UInt32
class DEVICE_EVENT_RBC_DATA(Structure):
    EventNumber: UInt32
    SenseQualifier: Byte
    SenseCode: Byte
    SenseKey: Byte
    Reserved: Byte
    Information: UInt32
class DEV_BROADCAST_DEVICEINTERFACE_A(Structure):
    dbcc_size: UInt32
    dbcc_devicetype: UInt32
    dbcc_reserved: UInt32
    dbcc_classguid: Guid
    dbcc_name: win32more.Windows.Win32.Foundation.CHAR * 1
class DEV_BROADCAST_DEVICEINTERFACE_W(Structure):
    dbcc_size: UInt32
    dbcc_devicetype: UInt32
    dbcc_reserved: UInt32
    dbcc_classguid: Guid
    dbcc_name: Char * 1
DEV_BROADCAST_DEVICEINTERFACE = UnicodeAlias('DEV_BROADCAST_DEVICEINTERFACE_W')
class DEV_BROADCAST_DEVNODE(Structure):
    dbcd_size: UInt32
    dbcd_devicetype: UInt32
    dbcd_reserved: UInt32
    dbcd_devnode: UInt32
class DEV_BROADCAST_HANDLE(Structure):
    dbch_size: UInt32
    dbch_devicetype: UInt32
    dbch_reserved: UInt32
    dbch_handle: win32more.Windows.Win32.Foundation.HANDLE
    dbch_hdevnotify: win32more.Windows.Win32.UI.WindowsAndMessaging.HDEVNOTIFY
    dbch_eventguid: Guid
    dbch_nameoffset: Int32
    dbch_data: Byte * 1
class DEV_BROADCAST_HANDLE32(Structure):
    dbch_size: UInt32
    dbch_devicetype: UInt32
    dbch_reserved: UInt32
    dbch_handle: UInt32
    dbch_hdevnotify: UInt32
    dbch_eventguid: Guid
    dbch_nameoffset: Int32
    dbch_data: Byte * 1
class DEV_BROADCAST_HANDLE64(Structure):
    dbch_size: UInt32
    dbch_devicetype: UInt32
    dbch_reserved: UInt32
    dbch_handle: UInt64
    dbch_hdevnotify: UInt64
    dbch_eventguid: Guid
    dbch_nameoffset: Int32
    dbch_data: Byte * 1
class DEV_BROADCAST_HDR(Structure):
    dbch_size: UInt32
    dbch_devicetype: win32more.Windows.Win32.UI.WindowsAndMessaging.DEV_BROADCAST_HDR_DEVICE_TYPE
    dbch_reserved: UInt32
DEV_BROADCAST_HDR_DEVICE_TYPE = UInt32
DBT_DEVTYP_DEVICEINTERFACE: win32more.Windows.Win32.UI.WindowsAndMessaging.DEV_BROADCAST_HDR_DEVICE_TYPE = 5
DBT_DEVTYP_HANDLE: win32more.Windows.Win32.UI.WindowsAndMessaging.DEV_BROADCAST_HDR_DEVICE_TYPE = 6
DBT_DEVTYP_OEM: win32more.Windows.Win32.UI.WindowsAndMessaging.DEV_BROADCAST_HDR_DEVICE_TYPE = 0
DBT_DEVTYP_PORT: win32more.Windows.Win32.UI.WindowsAndMessaging.DEV_BROADCAST_HDR_DEVICE_TYPE = 3
DBT_DEVTYP_VOLUME: win32more.Windows.Win32.UI.WindowsAndMessaging.DEV_BROADCAST_HDR_DEVICE_TYPE = 2
class DEV_BROADCAST_NET(Structure):
    dbcn_size: UInt32
    dbcn_devicetype: UInt32
    dbcn_reserved: UInt32
    dbcn_resource: UInt32
    dbcn_flags: UInt32
class DEV_BROADCAST_OEM(Structure):
    dbco_size: UInt32
    dbco_devicetype: UInt32
    dbco_reserved: UInt32
    dbco_identifier: UInt32
    dbco_suppfunc: UInt32
class DEV_BROADCAST_PORT_A(Structure):
    dbcp_size: UInt32
    dbcp_devicetype: UInt32
    dbcp_reserved: UInt32
    dbcp_name: win32more.Windows.Win32.Foundation.CHAR * 1
class DEV_BROADCAST_PORT_W(Structure):
    dbcp_size: UInt32
    dbcp_devicetype: UInt32
    dbcp_reserved: UInt32
    dbcp_name: Char * 1
DEV_BROADCAST_PORT = UnicodeAlias('DEV_BROADCAST_PORT_W')
class DEV_BROADCAST_VOLUME(Structure):
    dbcv_size: UInt32
    dbcv_devicetype: UInt32
    dbcv_reserved: UInt32
    dbcv_unitmask: UInt32
    dbcv_flags: win32more.Windows.Win32.UI.WindowsAndMessaging.DEV_BROADCAST_VOLUME_FLAGS
DEV_BROADCAST_VOLUME_FLAGS = UInt16
DBTF_MEDIA: win32more.Windows.Win32.UI.WindowsAndMessaging.DEV_BROADCAST_VOLUME_FLAGS = 1
DBTF_NET: win32more.Windows.Win32.UI.WindowsAndMessaging.DEV_BROADCAST_VOLUME_FLAGS = 2
class DISK_HEALTH_NOTIFICATION_DATA(Structure):
    DeviceGuid: Guid
DI_FLAGS = UInt32
DI_MASK: win32more.Windows.Win32.UI.WindowsAndMessaging.DI_FLAGS = 1
DI_IMAGE: win32more.Windows.Win32.UI.WindowsAndMessaging.DI_FLAGS = 2
DI_NORMAL: win32more.Windows.Win32.UI.WindowsAndMessaging.DI_FLAGS = 3
DI_COMPAT: win32more.Windows.Win32.UI.WindowsAndMessaging.DI_FLAGS = 4
DI_DEFAULTSIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.DI_FLAGS = 8
DI_NOMIRROR: win32more.Windows.Win32.UI.WindowsAndMessaging.DI_FLAGS = 16
class DLGITEMTEMPLATE(Structure):
    style: UInt32
    dwExtendedStyle: UInt32
    x: Int16
    y: Int16
    cx: Int16
    cy: Int16
    id: UInt16
    _pack_ = 2
@winfunctype_pointer
def DLGPROC(param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32, param2: win32more.Windows.Win32.Foundation.WPARAM, param3: win32more.Windows.Win32.Foundation.LPARAM) -> IntPtr: ...
class DLGTEMPLATE(Structure):
    style: UInt32
    dwExtendedStyle: UInt32
    cdit: UInt16
    x: Int16
    y: Int16
    cx: Int16
    cy: Int16
    _pack_ = 2
class DROPSTRUCT(Structure):
    hwndSource: win32more.Windows.Win32.Foundation.HWND
    hwndSink: win32more.Windows.Win32.Foundation.HWND
    wFmt: UInt32
    dwData: UIntPtr
    ptDrop: win32more.Windows.Win32.Foundation.POINT
    dwControlData: UInt32
EDIT_CONTROL_FEATURE = Int32
EDIT_CONTROL_FEATURE_ENTERPRISE_DATA_PROTECTION_PASTE_SUPPORT: win32more.Windows.Win32.UI.WindowsAndMessaging.EDIT_CONTROL_FEATURE = 0
EDIT_CONTROL_FEATURE_PASTE_NOTIFICATIONS: win32more.Windows.Win32.UI.WindowsAndMessaging.EDIT_CONTROL_FEATURE = 1
class EVENTMSG(Structure):
    message: UInt32
    paramL: UInt32
    paramH: UInt32
    time: UInt32
    hwnd: win32more.Windows.Win32.Foundation.HWND
class FLASHWINFO(Structure):
    cbSize: UInt32
    hwnd: win32more.Windows.Win32.Foundation.HWND
    dwFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.FLASHWINFO_FLAGS
    uCount: UInt32
    dwTimeout: UInt32
FLASHWINFO_FLAGS = UInt32
FLASHW_ALL: win32more.Windows.Win32.UI.WindowsAndMessaging.FLASHWINFO_FLAGS = 3
FLASHW_CAPTION: win32more.Windows.Win32.UI.WindowsAndMessaging.FLASHWINFO_FLAGS = 1
FLASHW_STOP: win32more.Windows.Win32.UI.WindowsAndMessaging.FLASHWINFO_FLAGS = 0
FLASHW_TIMER: win32more.Windows.Win32.UI.WindowsAndMessaging.FLASHWINFO_FLAGS = 4
FLASHW_TIMERNOFG: win32more.Windows.Win32.UI.WindowsAndMessaging.FLASHWINFO_FLAGS = 12
FLASHW_TRAY: win32more.Windows.Win32.UI.WindowsAndMessaging.FLASHWINFO_FLAGS = 2
FOREGROUND_WINDOW_LOCK_CODE = UInt32
LSFW_LOCK: win32more.Windows.Win32.UI.WindowsAndMessaging.FOREGROUND_WINDOW_LOCK_CODE = 1
LSFW_UNLOCK: win32more.Windows.Win32.UI.WindowsAndMessaging.FOREGROUND_WINDOW_LOCK_CODE = 2
GDI_IMAGE_TYPE = UInt32
IMAGE_BITMAP: win32more.Windows.Win32.UI.WindowsAndMessaging.GDI_IMAGE_TYPE = 0
IMAGE_CURSOR: win32more.Windows.Win32.UI.WindowsAndMessaging.GDI_IMAGE_TYPE = 2
IMAGE_ICON: win32more.Windows.Win32.UI.WindowsAndMessaging.GDI_IMAGE_TYPE = 1
class GETCLIPBMETADATA(Structure):
    Version: UInt32
    IsDelayRendered: win32more.Windows.Win32.Foundation.BOOL
    IsSynthetic: win32more.Windows.Win32.Foundation.BOOL
GET_ANCESTOR_FLAGS = UInt32
GA_PARENT: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_ANCESTOR_FLAGS = 1
GA_ROOT: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_ANCESTOR_FLAGS = 2
GA_ROOTOWNER: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_ANCESTOR_FLAGS = 3
GET_CLASS_LONG_INDEX = Int32
GCW_ATOM: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -32
GCL_CBCLSEXTRA: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -20
GCL_CBWNDEXTRA: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -18
GCL_HBRBACKGROUND: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -10
GCL_HCURSOR: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -12
GCL_HICON: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -14
GCL_HICONSM: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -34
GCL_HMODULE: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -16
GCL_MENUNAME: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -8
GCL_STYLE: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -26
GCL_WNDPROC: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -24
GCLP_HBRBACKGROUND: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -10
GCLP_HCURSOR: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -12
GCLP_HICON: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -14
GCLP_HICONSM: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -34
GCLP_HMODULE: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -16
GCLP_MENUNAME: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -8
GCLP_WNDPROC: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_CLASS_LONG_INDEX = -24
GET_MENU_DEFAULT_ITEM_FLAGS = UInt32
GMDI_GOINTOPOPUPS: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_MENU_DEFAULT_ITEM_FLAGS = 2
GMDI_USEDISABLED: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_MENU_DEFAULT_ITEM_FLAGS = 1
GET_WINDOW_CMD = UInt32
GW_CHILD: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_WINDOW_CMD = 5
GW_ENABLEDPOPUP: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_WINDOW_CMD = 6
GW_HWNDFIRST: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_WINDOW_CMD = 0
GW_HWNDLAST: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_WINDOW_CMD = 1
GW_HWNDNEXT: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_WINDOW_CMD = 2
GW_HWNDPREV: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_WINDOW_CMD = 3
GW_OWNER: win32more.Windows.Win32.UI.WindowsAndMessaging.GET_WINDOW_CMD = 4
class GUID_IO_DISK_CLONE_ARRIVAL_INFORMATION(Structure):
    DiskNumber: UInt32
class GUITHREADINFO(Structure):
    cbSize: UInt32
    flags: win32more.Windows.Win32.UI.WindowsAndMessaging.GUITHREADINFO_FLAGS
    hwndActive: win32more.Windows.Win32.Foundation.HWND
    hwndFocus: win32more.Windows.Win32.Foundation.HWND
    hwndCapture: win32more.Windows.Win32.Foundation.HWND
    hwndMenuOwner: win32more.Windows.Win32.Foundation.HWND
    hwndMoveSize: win32more.Windows.Win32.Foundation.HWND
    hwndCaret: win32more.Windows.Win32.Foundation.HWND
    rcCaret: win32more.Windows.Win32.Foundation.RECT
GUITHREADINFO_FLAGS = UInt32
GUI_CARETBLINKING: win32more.Windows.Win32.UI.WindowsAndMessaging.GUITHREADINFO_FLAGS = 1
GUI_INMENUMODE: win32more.Windows.Win32.UI.WindowsAndMessaging.GUITHREADINFO_FLAGS = 4
GUI_INMOVESIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.GUITHREADINFO_FLAGS = 2
GUI_POPUPMENUMODE: win32more.Windows.Win32.UI.WindowsAndMessaging.GUITHREADINFO_FLAGS = 16
GUI_SYSTEMMENUMODE: win32more.Windows.Win32.UI.WindowsAndMessaging.GUITHREADINFO_FLAGS = 8
HACCEL = VoidPtr
HANDEDNESS = Int32
HANDEDNESS_LEFT: win32more.Windows.Win32.UI.WindowsAndMessaging.HANDEDNESS = 0
HANDEDNESS_RIGHT: win32more.Windows.Win32.UI.WindowsAndMessaging.HANDEDNESS = 1
class HARDWAREHOOKSTRUCT(Structure):
    hwnd: win32more.Windows.Win32.Foundation.HWND
    message: UInt32
    wParam: win32more.Windows.Win32.Foundation.WPARAM
    lParam: win32more.Windows.Win32.Foundation.LPARAM
HCURSOR = VoidPtr
HDEVNOTIFY = VoidPtr
HDWP = VoidPtr
HHOOK = VoidPtr
HICON = VoidPtr
HMENU = VoidPtr
@winfunctype_pointer
def HOOKPROC(code: Int32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
class ICONINFO(Structure):
    fIcon: win32more.Windows.Win32.Foundation.BOOL
    xHotspot: UInt32
    yHotspot: UInt32
    hbmMask: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
    hbmColor: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
class ICONINFOEXA(Structure):
    cbSize: UInt32
    fIcon: win32more.Windows.Win32.Foundation.BOOL
    xHotspot: UInt32
    yHotspot: UInt32
    hbmMask: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
    hbmColor: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
    wResID: UInt16
    szModName: win32more.Windows.Win32.Foundation.CHAR * 260
    szResName: win32more.Windows.Win32.Foundation.CHAR * 260
class ICONINFOEXW(Structure):
    cbSize: UInt32
    fIcon: win32more.Windows.Win32.Foundation.BOOL
    xHotspot: UInt32
    yHotspot: UInt32
    hbmMask: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
    hbmColor: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
    wResID: UInt16
    szModName: Char * 260
    szResName: Char * 260
ICONINFOEX = UnicodeAlias('ICONINFOEXW')
class ICONMETRICSA(Structure):
    cbSize: UInt32
    iHorzSpacing: Int32
    iVertSpacing: Int32
    iTitleWrap: Int32
    lfFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTA
class ICONMETRICSW(Structure):
    cbSize: UInt32
    iHorzSpacing: Int32
    iVertSpacing: Int32
    iTitleWrap: Int32
    lfFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTW
ICONMETRICS = UnicodeAlias('ICONMETRICSW')
IMAGE_FLAGS = UInt32
LR_CREATEDIBSECTION: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS = 8192
LR_DEFAULTCOLOR: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS = 0
LR_DEFAULTSIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS = 64
LR_LOADFROMFILE: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS = 16
LR_LOADMAP3DCOLORS: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS = 4096
LR_LOADTRANSPARENT: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS = 32
LR_MONOCHROME: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS = 1
LR_SHARED: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS = 32768
LR_VGACOLOR: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS = 128
LR_COPYDELETEORG: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS = 8
LR_COPYFROMRESOURCE: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS = 16384
LR_COPYRETURNORG: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS = 4
class IndexedResourceQualifier(Structure):
    name: win32more.Windows.Win32.Foundation.PWSTR
    value: win32more.Windows.Win32.Foundation.PWSTR
class KBDLLHOOKSTRUCT(Structure):
    vkCode: UInt32
    scanCode: UInt32
    flags: win32more.Windows.Win32.UI.WindowsAndMessaging.KBDLLHOOKSTRUCT_FLAGS
    time: UInt32
    dwExtraInfo: UIntPtr
KBDLLHOOKSTRUCT_FLAGS = UInt32
LLKHF_EXTENDED: win32more.Windows.Win32.UI.WindowsAndMessaging.KBDLLHOOKSTRUCT_FLAGS = 1
LLKHF_ALTDOWN: win32more.Windows.Win32.UI.WindowsAndMessaging.KBDLLHOOKSTRUCT_FLAGS = 32
LLKHF_UP: win32more.Windows.Win32.UI.WindowsAndMessaging.KBDLLHOOKSTRUCT_FLAGS = 128
LLKHF_INJECTED: win32more.Windows.Win32.UI.WindowsAndMessaging.KBDLLHOOKSTRUCT_FLAGS = 16
LLKHF_LOWER_IL_INJECTED: win32more.Windows.Win32.UI.WindowsAndMessaging.KBDLLHOOKSTRUCT_FLAGS = 2
LAYERED_WINDOW_ATTRIBUTES_FLAGS = UInt32
LWA_ALPHA: win32more.Windows.Win32.UI.WindowsAndMessaging.LAYERED_WINDOW_ATTRIBUTES_FLAGS = 2
LWA_COLORKEY: win32more.Windows.Win32.UI.WindowsAndMessaging.LAYERED_WINDOW_ATTRIBUTES_FLAGS = 1
class MDICREATESTRUCTA(Structure):
    szClass: win32more.Windows.Win32.Foundation.PSTR
    szTitle: win32more.Windows.Win32.Foundation.PSTR
    hOwner: win32more.Windows.Win32.Foundation.HANDLE
    x: Int32
    y: Int32
    cx: Int32
    cy: Int32
    style: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE
    lParam: win32more.Windows.Win32.Foundation.LPARAM
class MDICREATESTRUCTW(Structure):
    szClass: win32more.Windows.Win32.Foundation.PWSTR
    szTitle: win32more.Windows.Win32.Foundation.PWSTR
    hOwner: win32more.Windows.Win32.Foundation.HANDLE
    x: Int32
    y: Int32
    cx: Int32
    cy: Int32
    style: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE
    lParam: win32more.Windows.Win32.Foundation.LPARAM
MDICREATESTRUCT = UnicodeAlias('MDICREATESTRUCTW')
class MDINEXTMENU(Structure):
    hmenuIn: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU
    hmenuNext: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU
    hwndNext: win32more.Windows.Win32.Foundation.HWND
class MENUBARINFO(Structure):
    cbSize: UInt32
    rcBar: win32more.Windows.Win32.Foundation.RECT
    hMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU
    hwndMenu: win32more.Windows.Win32.Foundation.HWND
    fBarFocused: Annotated[Int32, 1]
    fFocused: Annotated[Int32, 1]
    fUnused: Annotated[Int32, 30]
class MENUEX_TEMPLATE_HEADER(Structure):
    wVersion: UInt16
    wOffset: UInt16
    dwHelpId: UInt32
class MENUEX_TEMPLATE_ITEM(Structure):
    dwType: UInt32
    dwState: UInt32
    uId: UInt32
    wFlags: UInt16
    szText: Char * 1
class MENUGETOBJECTINFO(Structure):
    dwFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUGETOBJECTINFO_FLAGS
    uPos: UInt32
    hmenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU
    riid: VoidPtr
    pvObj: VoidPtr
MENUGETOBJECTINFO_FLAGS = UInt32
MNGOF_BOTTOMGAP: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUGETOBJECTINFO_FLAGS = 2
MNGOF_TOPGAP: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUGETOBJECTINFO_FLAGS = 1
class MENUINFO(Structure):
    cbSize: UInt32
    fMask: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUINFO_MASK
    dwStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUINFO_STYLE
    cyMax: UInt32
    hbrBack: win32more.Windows.Win32.Graphics.Gdi.HBRUSH
    dwContextHelpID: UInt32
    dwMenuData: UIntPtr
MENUINFO_MASK = UInt32
MIM_APPLYTOSUBMENUS: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUINFO_MASK = 2147483648
MIM_BACKGROUND: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUINFO_MASK = 2
MIM_HELPID: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUINFO_MASK = 4
MIM_MAXHEIGHT: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUINFO_MASK = 1
MIM_MENUDATA: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUINFO_MASK = 8
MIM_STYLE: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUINFO_MASK = 16
MENUINFO_STYLE = UInt32
MNS_AUTODISMISS: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUINFO_STYLE = 268435456
MNS_CHECKORBMP: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUINFO_STYLE = 67108864
MNS_DRAGDROP: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUINFO_STYLE = 536870912
MNS_MODELESS: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUINFO_STYLE = 1073741824
MNS_NOCHECK: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUINFO_STYLE = 2147483648
MNS_NOTIFYBYPOS: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUINFO_STYLE = 134217728
class MENUITEMINFOA(Structure):
    cbSize: UInt32
    fMask: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_MASK
    fType: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_TYPE
    fState: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_STATE
    wID: UInt32
    hSubMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU
    hbmpChecked: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
    hbmpUnchecked: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
    dwItemData: UIntPtr
    dwTypeData: win32more.Windows.Win32.Foundation.PSTR
    cch: UInt32
    hbmpItem: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
class MENUITEMINFOW(Structure):
    cbSize: UInt32
    fMask: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_MASK
    fType: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_TYPE
    fState: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_STATE
    wID: UInt32
    hSubMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU
    hbmpChecked: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
    hbmpUnchecked: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
    dwItemData: UIntPtr
    dwTypeData: win32more.Windows.Win32.Foundation.PWSTR
    cch: UInt32
    hbmpItem: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
MENUITEMINFO = UnicodeAlias('MENUITEMINFOW')
class MENUITEMTEMPLATE(Structure):
    mtOption: UInt16
    mtID: UInt16
    mtString: Char * 1
class MENUITEMTEMPLATEHEADER(Structure):
    versionNumber: UInt16
    offset: UInt16
class MENUTEMPLATEEX(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Menu: _Menu_e__Struct
        MenuEx: _MenuEx_e__Struct
        class _Menu_e__Struct(Structure):
            mitHeader: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUITEMTEMPLATEHEADER
            miTemplate: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUITEMTEMPLATE * 1
        class _MenuEx_e__Struct(Structure):
            mexHeader: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUEX_TEMPLATE_HEADER
            mexItem: win32more.Windows.Win32.UI.WindowsAndMessaging.MENUEX_TEMPLATE_ITEM * 1
MENU_ITEM_FLAGS = UInt32
MF_BYCOMMAND: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 0
MF_BYPOSITION: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 1024
MF_BITMAP: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 4
MF_CHECKED: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 8
MF_DISABLED: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 2
MF_ENABLED: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 0
MF_GRAYED: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 1
MF_MENUBARBREAK: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 32
MF_MENUBREAK: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 64
MF_OWNERDRAW: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 256
MF_POPUP: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 16
MF_SEPARATOR: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 2048
MF_STRING: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 0
MF_UNCHECKED: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 0
MF_INSERT: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 0
MF_CHANGE: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 128
MF_APPEND: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 256
MF_DELETE: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 512
MF_REMOVE: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 4096
MF_USECHECKBITMAPS: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 512
MF_UNHILITE: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 0
MF_HILITE: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 128
MF_DEFAULT: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 4096
MF_SYSMENU: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 8192
MF_HELP: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 16384
MF_RIGHTJUSTIFY: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 16384
MF_MOUSESELECT: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 32768
MF_END: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_FLAGS = 128
MENU_ITEM_MASK = UInt32
MIIM_BITMAP: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_MASK = 128
MIIM_CHECKMARKS: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_MASK = 8
MIIM_DATA: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_MASK = 32
MIIM_FTYPE: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_MASK = 256
MIIM_ID: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_MASK = 2
MIIM_STATE: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_MASK = 1
MIIM_STRING: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_MASK = 64
MIIM_SUBMENU: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_MASK = 4
MIIM_TYPE: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_MASK = 16
MENU_ITEM_STATE = UInt32
MFS_GRAYED: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_STATE = 3
MFS_DISABLED: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_STATE = 3
MFS_CHECKED: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_STATE = 8
MFS_HILITE: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_STATE = 128
MFS_ENABLED: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_STATE = 0
MFS_UNCHECKED: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_STATE = 0
MFS_UNHILITE: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_STATE = 0
MFS_DEFAULT: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_STATE = 4096
MENU_ITEM_TYPE = UInt32
MFT_BITMAP: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_TYPE = 4
MFT_MENUBARBREAK: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_TYPE = 32
MFT_MENUBREAK: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_TYPE = 64
MFT_OWNERDRAW: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_TYPE = 256
MFT_RADIOCHECK: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_TYPE = 512
MFT_RIGHTJUSTIFY: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_TYPE = 16384
MFT_RIGHTORDER: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_TYPE = 8192
MFT_SEPARATOR: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_TYPE = 2048
MFT_STRING: win32more.Windows.Win32.UI.WindowsAndMessaging.MENU_ITEM_TYPE = 0
MESSAGEBOX_RESULT = Int32
IDOK: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT = 1
IDCANCEL: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT = 2
IDABORT: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT = 3
IDRETRY: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT = 4
IDIGNORE: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT = 5
IDYES: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT = 6
IDNO: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT = 7
IDCLOSE: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT = 8
IDHELP: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT = 9
IDTRYAGAIN: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT = 10
IDCONTINUE: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT = 11
IDASYNC: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT = 32001
IDTIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_RESULT = 32000
MESSAGEBOX_STYLE = UInt32
MB_ABORTRETRYIGNORE: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 2
MB_CANCELTRYCONTINUE: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 6
MB_HELP: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 16384
MB_OK: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 0
MB_OKCANCEL: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 1
MB_RETRYCANCEL: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 5
MB_YESNO: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 4
MB_YESNOCANCEL: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 3
MB_ICONHAND: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 16
MB_ICONQUESTION: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 32
MB_ICONEXCLAMATION: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 48
MB_ICONASTERISK: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 64
MB_USERICON: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 128
MB_ICONWARNING: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 48
MB_ICONERROR: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 16
MB_ICONINFORMATION: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 64
MB_ICONSTOP: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 16
MB_DEFBUTTON1: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 0
MB_DEFBUTTON2: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 256
MB_DEFBUTTON3: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 512
MB_DEFBUTTON4: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 768
MB_APPLMODAL: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 0
MB_SYSTEMMODAL: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 4096
MB_TASKMODAL: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 8192
MB_NOFOCUS: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 32768
MB_SETFOREGROUND: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 65536
MB_DEFAULT_DESKTOP_ONLY: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 131072
MB_TOPMOST: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 262144
MB_RIGHT: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 524288
MB_RTLREADING: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 1048576
MB_SERVICE_NOTIFICATION: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 2097152
MB_SERVICE_NOTIFICATION_NT3X: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 262144
MB_TYPEMASK: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 15
MB_ICONMASK: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 240
MB_DEFMASK: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 3840
MB_MODEMASK: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 12288
MB_MISCMASK: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE = 49152
class MESSAGE_RESOURCE_BLOCK(Structure):
    LowId: UInt32
    HighId: UInt32
    OffsetToEntries: UInt32
class MESSAGE_RESOURCE_DATA(Structure):
    NumberOfBlocks: UInt32
    Blocks: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGE_RESOURCE_BLOCK * 1
class MESSAGE_RESOURCE_ENTRY(Structure):
    Length: UInt16
    Flags: UInt16
    Text: Byte * 1
class MINIMIZEDMETRICS(Structure):
    cbSize: UInt32
    iWidth: Int32
    iHorzGap: Int32
    iVertGap: Int32
    iArrange: win32more.Windows.Win32.UI.WindowsAndMessaging.MINIMIZEDMETRICS_ARRANGE
MINIMIZEDMETRICS_ARRANGE = Int32
ARW_BOTTOMLEFT: win32more.Windows.Win32.UI.WindowsAndMessaging.MINIMIZEDMETRICS_ARRANGE = 0
ARW_BOTTOMRIGHT: win32more.Windows.Win32.UI.WindowsAndMessaging.MINIMIZEDMETRICS_ARRANGE = 1
ARW_TOPLEFT: win32more.Windows.Win32.UI.WindowsAndMessaging.MINIMIZEDMETRICS_ARRANGE = 2
ARW_TOPRIGHT: win32more.Windows.Win32.UI.WindowsAndMessaging.MINIMIZEDMETRICS_ARRANGE = 3
class MINMAXINFO(Structure):
    ptReserved: win32more.Windows.Win32.Foundation.POINT
    ptMaxSize: win32more.Windows.Win32.Foundation.POINT
    ptMaxPosition: win32more.Windows.Win32.Foundation.POINT
    ptMinTrackSize: win32more.Windows.Win32.Foundation.POINT
    ptMaxTrackSize: win32more.Windows.Win32.Foundation.POINT
class MOUSEHOOKSTRUCT(Structure):
    pt: win32more.Windows.Win32.Foundation.POINT
    hwnd: win32more.Windows.Win32.Foundation.HWND
    wHitTestCode: UInt32
    dwExtraInfo: UIntPtr
class MOUSEHOOKSTRUCTEX(Structure):
    Base: win32more.Windows.Win32.UI.WindowsAndMessaging.MOUSEHOOKSTRUCT
    mouseData: UInt32
class MSG(Structure):
    hwnd: win32more.Windows.Win32.Foundation.HWND
    message: UInt32
    wParam: win32more.Windows.Win32.Foundation.WPARAM
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    time: UInt32
    pt: win32more.Windows.Win32.Foundation.POINT
@winfunctype_pointer
def MSGBOXCALLBACK(lpHelpInfo: POINTER(win32more.Windows.Win32.UI.Shell.HELPINFO)) -> Void: ...
class MSGBOXPARAMSA(Structure):
    cbSize: UInt32
    hwndOwner: win32more.Windows.Win32.Foundation.HWND
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    lpszText: win32more.Windows.Win32.Foundation.PSTR
    lpszCaption: win32more.Windows.Win32.Foundation.PSTR
    dwStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE
    lpszIcon: win32more.Windows.Win32.Foundation.PSTR
    dwContextHelpId: UIntPtr
    lpfnMsgBoxCallback: win32more.Windows.Win32.UI.WindowsAndMessaging.MSGBOXCALLBACK
    dwLanguageId: UInt32
class MSGBOXPARAMSW(Structure):
    cbSize: UInt32
    hwndOwner: win32more.Windows.Win32.Foundation.HWND
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    lpszText: win32more.Windows.Win32.Foundation.PWSTR
    lpszCaption: win32more.Windows.Win32.Foundation.PWSTR
    dwStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.MESSAGEBOX_STYLE
    lpszIcon: win32more.Windows.Win32.Foundation.PWSTR
    dwContextHelpId: UIntPtr
    lpfnMsgBoxCallback: win32more.Windows.Win32.UI.WindowsAndMessaging.MSGBOXCALLBACK
    dwLanguageId: UInt32
MSGBOXPARAMS = UnicodeAlias('MSGBOXPARAMSW')
MSGFLTINFO_STATUS = UInt32
MSGFLTINFO_NONE: win32more.Windows.Win32.UI.WindowsAndMessaging.MSGFLTINFO_STATUS = 0
MSGFLTINFO_ALLOWED_HIGHER: win32more.Windows.Win32.UI.WindowsAndMessaging.MSGFLTINFO_STATUS = 3
MSGFLTINFO_ALREADYALLOWED_FORWND: win32more.Windows.Win32.UI.WindowsAndMessaging.MSGFLTINFO_STATUS = 1
MSGFLTINFO_ALREADYDISALLOWED_FORWND: win32more.Windows.Win32.UI.WindowsAndMessaging.MSGFLTINFO_STATUS = 2
MSG_WAIT_FOR_MULTIPLE_OBJECTS_EX_FLAGS = UInt32
MWMO_NONE: win32more.Windows.Win32.UI.WindowsAndMessaging.MSG_WAIT_FOR_MULTIPLE_OBJECTS_EX_FLAGS = 0
MWMO_ALERTABLE: win32more.Windows.Win32.UI.WindowsAndMessaging.MSG_WAIT_FOR_MULTIPLE_OBJECTS_EX_FLAGS = 2
MWMO_INPUTAVAILABLE: win32more.Windows.Win32.UI.WindowsAndMessaging.MSG_WAIT_FOR_MULTIPLE_OBJECTS_EX_FLAGS = 4
MWMO_WAITALL: win32more.Windows.Win32.UI.WindowsAndMessaging.MSG_WAIT_FOR_MULTIPLE_OBJECTS_EX_FLAGS = 1
class MSLLHOOKSTRUCT(Structure):
    pt: win32more.Windows.Win32.Foundation.POINT
    mouseData: UInt32
    flags: UInt32
    time: UInt32
    dwExtraInfo: UIntPtr
MrmDumpType = Int32
MrmDumpType_Basic: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmDumpType = 0
MrmDumpType_Detailed: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmDumpType = 1
MrmDumpType_Schema: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmDumpType = 2
MrmIndexerFlags = Int32
MrmIndexerFlagsNone: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmIndexerFlags = 0
MrmIndexerFlagsAutoMerge: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmIndexerFlags = 1
MrmIndexerFlagsCreateContentChecksum: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmIndexerFlags = 2
MrmPackagingMode = Int32
MrmPackagingModeStandaloneFile: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPackagingMode = 0
MrmPackagingModeAutoSplit: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPackagingMode = 1
MrmPackagingModeResourcePack: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPackagingMode = 2
MrmPackagingOptions = Int32
MrmPackagingOptionsNone: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPackagingOptions = 0
MrmPackagingOptionsOmitSchemaFromResourcePacks: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPackagingOptions = 1
MrmPackagingOptionsSplitLanguageVariants: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPackagingOptions = 2
MrmPlatformVersion = Int32
MrmPlatformVersion_Default: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPlatformVersion = 0
MrmPlatformVersion_Windows10_0_0_0: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPlatformVersion = 17432576
MrmPlatformVersion_Windows10_0_0_5: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmPlatformVersion = 17432581
class MrmResourceIndexerHandle(Structure):
    handle: VoidPtr
class MrmResourceIndexerMessage(Structure):
    severity: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerMessageSeverity
    id: UInt32
    text: win32more.Windows.Win32.Foundation.PWSTR
MrmResourceIndexerMessageSeverity = Int32
MrmResourceIndexerMessageSeverityVerbose: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerMessageSeverity = 0
MrmResourceIndexerMessageSeverityInfo: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerMessageSeverity = 1
MrmResourceIndexerMessageSeverityWarning: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerMessageSeverity = 2
MrmResourceIndexerMessageSeverityError: win32more.Windows.Win32.UI.WindowsAndMessaging.MrmResourceIndexerMessageSeverity = 3
@winfunctype_pointer
def NAMEENUMPROCA(param0: win32more.Windows.Win32.Foundation.PSTR, param1: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def NAMEENUMPROCW(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
NAMEENUMPROC = UnicodeAlias('NAMEENUMPROCW')
class NCCALCSIZE_PARAMS(Structure):
    rgrc: win32more.Windows.Win32.Foundation.RECT * 3
    lppos: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWPOS)
class NONCLIENTMETRICSA(Structure):
    cbSize: UInt32
    iBorderWidth: Int32
    iScrollWidth: Int32
    iScrollHeight: Int32
    iCaptionWidth: Int32
    iCaptionHeight: Int32
    lfCaptionFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTA
    iSmCaptionWidth: Int32
    iSmCaptionHeight: Int32
    lfSmCaptionFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTA
    iMenuWidth: Int32
    iMenuHeight: Int32
    lfMenuFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTA
    lfStatusFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTA
    lfMessageFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTA
    iPaddedBorderWidth: Int32
class NONCLIENTMETRICSW(Structure):
    cbSize: UInt32
    iBorderWidth: Int32
    iScrollWidth: Int32
    iScrollHeight: Int32
    iCaptionWidth: Int32
    iCaptionHeight: Int32
    lfCaptionFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTW
    iSmCaptionWidth: Int32
    iSmCaptionHeight: Int32
    lfSmCaptionFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTW
    iMenuWidth: Int32
    iMenuHeight: Int32
    lfMenuFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTW
    lfStatusFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTW
    lfMessageFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTW
    iPaddedBorderWidth: Int32
NONCLIENTMETRICS = UnicodeAlias('NONCLIENTMETRICSW')
OBJECT_IDENTIFIER = Int32
OBJID_WINDOW: win32more.Windows.Win32.UI.WindowsAndMessaging.OBJECT_IDENTIFIER = 0
OBJID_SYSMENU: win32more.Windows.Win32.UI.WindowsAndMessaging.OBJECT_IDENTIFIER = -1
OBJID_TITLEBAR: win32more.Windows.Win32.UI.WindowsAndMessaging.OBJECT_IDENTIFIER = -2
OBJID_MENU: win32more.Windows.Win32.UI.WindowsAndMessaging.OBJECT_IDENTIFIER = -3
OBJID_CLIENT: win32more.Windows.Win32.UI.WindowsAndMessaging.OBJECT_IDENTIFIER = -4
OBJID_VSCROLL: win32more.Windows.Win32.UI.WindowsAndMessaging.OBJECT_IDENTIFIER = -5
OBJID_HSCROLL: win32more.Windows.Win32.UI.WindowsAndMessaging.OBJECT_IDENTIFIER = -6
OBJID_SIZEGRIP: win32more.Windows.Win32.UI.WindowsAndMessaging.OBJECT_IDENTIFIER = -7
OBJID_CARET: win32more.Windows.Win32.UI.WindowsAndMessaging.OBJECT_IDENTIFIER = -8
OBJID_CURSOR: win32more.Windows.Win32.UI.WindowsAndMessaging.OBJECT_IDENTIFIER = -9
OBJID_ALERT: win32more.Windows.Win32.UI.WindowsAndMessaging.OBJECT_IDENTIFIER = -10
OBJID_SOUND: win32more.Windows.Win32.UI.WindowsAndMessaging.OBJECT_IDENTIFIER = -11
OBJID_QUERYCLASSNAMEIDX: win32more.Windows.Win32.UI.WindowsAndMessaging.OBJECT_IDENTIFIER = -12
OBJID_NATIVEOM: win32more.Windows.Win32.UI.WindowsAndMessaging.OBJECT_IDENTIFIER = -16
PEEK_MESSAGE_REMOVE_TYPE = UInt32
PM_NOREMOVE: win32more.Windows.Win32.UI.WindowsAndMessaging.PEEK_MESSAGE_REMOVE_TYPE = 0
PM_REMOVE: win32more.Windows.Win32.UI.WindowsAndMessaging.PEEK_MESSAGE_REMOVE_TYPE = 1
PM_NOYIELD: win32more.Windows.Win32.UI.WindowsAndMessaging.PEEK_MESSAGE_REMOVE_TYPE = 2
PM_QS_INPUT: win32more.Windows.Win32.UI.WindowsAndMessaging.PEEK_MESSAGE_REMOVE_TYPE = 67567616
PM_QS_POSTMESSAGE: win32more.Windows.Win32.UI.WindowsAndMessaging.PEEK_MESSAGE_REMOVE_TYPE = 9961472
PM_QS_PAINT: win32more.Windows.Win32.UI.WindowsAndMessaging.PEEK_MESSAGE_REMOVE_TYPE = 2097152
PM_QS_SENDMESSAGE: win32more.Windows.Win32.UI.WindowsAndMessaging.PEEK_MESSAGE_REMOVE_TYPE = 4194304
POINTER_INPUT_TYPE = Int32
PT_POINTER: win32more.Windows.Win32.UI.WindowsAndMessaging.POINTER_INPUT_TYPE = 1
PT_TOUCH: win32more.Windows.Win32.UI.WindowsAndMessaging.POINTER_INPUT_TYPE = 2
PT_PEN: win32more.Windows.Win32.UI.WindowsAndMessaging.POINTER_INPUT_TYPE = 3
PT_MOUSE: win32more.Windows.Win32.UI.WindowsAndMessaging.POINTER_INPUT_TYPE = 4
PT_TOUCHPAD: win32more.Windows.Win32.UI.WindowsAndMessaging.POINTER_INPUT_TYPE = 5
@winfunctype_pointer
def PREGISTERCLASSNAMEW(param0: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype_pointer
def PROPENUMPROCA(param0: win32more.Windows.Win32.Foundation.HWND, param1: win32more.Windows.Win32.Foundation.PSTR, param2: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PROPENUMPROCEXA(param0: win32more.Windows.Win32.Foundation.HWND, param1: win32more.Windows.Win32.Foundation.PSTR, param2: win32more.Windows.Win32.Foundation.HANDLE, param3: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PROPENUMPROCEXW(param0: win32more.Windows.Win32.Foundation.HWND, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: win32more.Windows.Win32.Foundation.HANDLE, param3: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
PROPENUMPROCEX = UnicodeAlias('PROPENUMPROCEXW')
@winfunctype_pointer
def PROPENUMPROCW(param0: win32more.Windows.Win32.Foundation.HWND, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
PROPENUMPROC = UnicodeAlias('PROPENUMPROCW')
QUEUE_STATUS_FLAGS = UInt32
QS_ALLEVENTS: win32more.Windows.Win32.UI.WindowsAndMessaging.QUEUE_STATUS_FLAGS = 1215
QS_ALLINPUT: win32more.Windows.Win32.UI.WindowsAndMessaging.QUEUE_STATUS_FLAGS = 1279
QS_ALLPOSTMESSAGE: win32more.Windows.Win32.UI.WindowsAndMessaging.QUEUE_STATUS_FLAGS = 256
QS_HOTKEY: win32more.Windows.Win32.UI.WindowsAndMessaging.QUEUE_STATUS_FLAGS = 128
QS_INPUT: win32more.Windows.Win32.UI.WindowsAndMessaging.QUEUE_STATUS_FLAGS = 1031
QS_KEY: win32more.Windows.Win32.UI.WindowsAndMessaging.QUEUE_STATUS_FLAGS = 1
QS_MOUSE: win32more.Windows.Win32.UI.WindowsAndMessaging.QUEUE_STATUS_FLAGS = 6
QS_MOUSEBUTTON: win32more.Windows.Win32.UI.WindowsAndMessaging.QUEUE_STATUS_FLAGS = 4
QS_MOUSEMOVE: win32more.Windows.Win32.UI.WindowsAndMessaging.QUEUE_STATUS_FLAGS = 2
QS_PAINT: win32more.Windows.Win32.UI.WindowsAndMessaging.QUEUE_STATUS_FLAGS = 32
QS_POSTMESSAGE: win32more.Windows.Win32.UI.WindowsAndMessaging.QUEUE_STATUS_FLAGS = 8
QS_RAWINPUT: win32more.Windows.Win32.UI.WindowsAndMessaging.QUEUE_STATUS_FLAGS = 1024
QS_SENDMESSAGE: win32more.Windows.Win32.UI.WindowsAndMessaging.QUEUE_STATUS_FLAGS = 64
QS_TIMER: win32more.Windows.Win32.UI.WindowsAndMessaging.QUEUE_STATUS_FLAGS = 16
REGISTER_NOTIFICATION_FLAGS = UInt32
DEVICE_NOTIFY_SERVICE_HANDLE: win32more.Windows.Win32.UI.WindowsAndMessaging.REGISTER_NOTIFICATION_FLAGS = 1
DEVICE_NOTIFY_CALLBACK: win32more.Windows.Win32.UI.WindowsAndMessaging.REGISTER_NOTIFICATION_FLAGS = 2
DEVICE_NOTIFY_WINDOW_HANDLE: win32more.Windows.Win32.UI.WindowsAndMessaging.REGISTER_NOTIFICATION_FLAGS = 0
DEVICE_NOTIFY_ALL_INTERFACE_CLASSES: win32more.Windows.Win32.UI.WindowsAndMessaging.REGISTER_NOTIFICATION_FLAGS = 4
class SCROLLBARINFO(Structure):
    cbSize: UInt32
    rcScrollBar: win32more.Windows.Win32.Foundation.RECT
    dxyLineButton: Int32
    xyThumbTop: Int32
    xyThumbBottom: Int32
    reserved: Int32
    rgstate: UInt32 * 6
SCROLLBAR_COMMAND = Int32
SB_LINEUP: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_COMMAND = 0
SB_LINELEFT: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_COMMAND = 0
SB_LINEDOWN: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_COMMAND = 1
SB_LINERIGHT: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_COMMAND = 1
SB_PAGEUP: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_COMMAND = 2
SB_PAGELEFT: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_COMMAND = 2
SB_PAGEDOWN: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_COMMAND = 3
SB_PAGERIGHT: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_COMMAND = 3
SB_THUMBPOSITION: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_COMMAND = 4
SB_THUMBTRACK: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_COMMAND = 5
SB_TOP: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_COMMAND = 6
SB_LEFT: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_COMMAND = 6
SB_RIGHT: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_COMMAND = 7
SB_BOTTOM: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_COMMAND = 7
SB_ENDSCROLL: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_COMMAND = 8
SCROLLBAR_CONSTANTS = Int32
SB_CTL: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS = 2
SB_HORZ: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS = 0
SB_VERT: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS = 1
SB_BOTH: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS = 3
class SCROLLINFO(Structure):
    cbSize: UInt32
    fMask: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLINFO_MASK
    nMin: Int32
    nMax: Int32
    nPage: UInt32
    nPos: Int32
    nTrackPos: Int32
SCROLLINFO_MASK = UInt32
SIF_ALL: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLINFO_MASK = 23
SIF_DISABLENOSCROLL: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLINFO_MASK = 8
SIF_PAGE: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLINFO_MASK = 2
SIF_POS: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLINFO_MASK = 4
SIF_RANGE: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLINFO_MASK = 1
SIF_TRACKPOS: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLINFO_MASK = 16
SCROLL_WINDOW_FLAGS = UInt32
SW_SCROLLCHILDREN: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLL_WINDOW_FLAGS = 1
SW_INVALIDATE: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLL_WINDOW_FLAGS = 2
SW_ERASE: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLL_WINDOW_FLAGS = 4
SW_SMOOTHSCROLL: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLL_WINDOW_FLAGS = 16
@winfunctype_pointer
def SENDASYNCPROC(param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32, param2: UIntPtr, param3: win32more.Windows.Win32.Foundation.LRESULT) -> Void: ...
SEND_MESSAGE_TIMEOUT_FLAGS = UInt32
SMTO_ABORTIFHUNG: win32more.Windows.Win32.UI.WindowsAndMessaging.SEND_MESSAGE_TIMEOUT_FLAGS = 2
SMTO_BLOCK: win32more.Windows.Win32.UI.WindowsAndMessaging.SEND_MESSAGE_TIMEOUT_FLAGS = 1
SMTO_NORMAL: win32more.Windows.Win32.UI.WindowsAndMessaging.SEND_MESSAGE_TIMEOUT_FLAGS = 0
SMTO_NOTIMEOUTIFNOTHUNG: win32more.Windows.Win32.UI.WindowsAndMessaging.SEND_MESSAGE_TIMEOUT_FLAGS = 8
SMTO_ERRORONEXIT: win32more.Windows.Win32.UI.WindowsAndMessaging.SEND_MESSAGE_TIMEOUT_FLAGS = 32
SET_WINDOW_POS_FLAGS = UInt32
SWP_ASYNCWINDOWPOS: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS = 16384
SWP_DEFERERASE: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS = 8192
SWP_DRAWFRAME: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS = 32
SWP_FRAMECHANGED: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS = 32
SWP_HIDEWINDOW: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS = 128
SWP_NOACTIVATE: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS = 16
SWP_NOCOPYBITS: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS = 256
SWP_NOMOVE: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS = 2
SWP_NOOWNERZORDER: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS = 512
SWP_NOREDRAW: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS = 8
SWP_NOREPOSITION: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS = 512
SWP_NOSENDCHANGING: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS = 1024
SWP_NOSIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS = 1
SWP_NOZORDER: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS = 4
SWP_SHOWWINDOW: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS = 64
class SHELLHOOKINFO(Structure):
    hwnd: win32more.Windows.Win32.Foundation.HWND
    rc: win32more.Windows.Win32.Foundation.RECT
SHOW_WINDOW_CMD = Int32
SW_HIDE: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_CMD = 0
SW_SHOWNORMAL: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_CMD = 1
SW_NORMAL: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_CMD = 1
SW_SHOWMINIMIZED: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_CMD = 2
SW_SHOWMAXIMIZED: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_CMD = 3
SW_MAXIMIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_CMD = 3
SW_SHOWNOACTIVATE: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_CMD = 4
SW_SHOW: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_CMD = 5
SW_MINIMIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_CMD = 6
SW_SHOWMINNOACTIVE: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_CMD = 7
SW_SHOWNA: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_CMD = 8
SW_RESTORE: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_CMD = 9
SW_SHOWDEFAULT: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_CMD = 10
SW_FORCEMINIMIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_CMD = 11
SW_MAX: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_CMD = 11
SHOW_WINDOW_STATUS = UInt32
SW_PARENTCLOSING: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_STATUS = 1
SW_OTHERZOOM: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_STATUS = 2
SW_PARENTOPENING: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_STATUS = 3
SW_OTHERUNZOOM: win32more.Windows.Win32.UI.WindowsAndMessaging.SHOW_WINDOW_STATUS = 4
class STYLESTRUCT(Structure):
    styleOld: UInt32
    styleNew: UInt32
SYSTEM_CURSOR_ID = UInt32
OCR_APPSTARTING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_CURSOR_ID = 32650
OCR_NORMAL: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_CURSOR_ID = 32512
OCR_CROSS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_CURSOR_ID = 32515
OCR_HAND: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_CURSOR_ID = 32649
OCR_HELP: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_CURSOR_ID = 32651
OCR_IBEAM: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_CURSOR_ID = 32513
OCR_NO: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_CURSOR_ID = 32648
OCR_SIZEALL: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_CURSOR_ID = 32646
OCR_SIZENESW: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_CURSOR_ID = 32643
OCR_SIZENS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_CURSOR_ID = 32645
OCR_SIZENWSE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_CURSOR_ID = 32642
OCR_SIZEWE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_CURSOR_ID = 32644
OCR_UP: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_CURSOR_ID = 32516
OCR_WAIT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_CURSOR_ID = 32514
SYSTEM_METRICS_INDEX = Int32
SM_ARRANGE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 56
SM_CLEANBOOT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 67
SM_CMONITORS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 80
SM_CMOUSEBUTTONS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 43
SM_CONVERTIBLESLATEMODE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 8195
SM_CXBORDER: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 5
SM_CXCURSOR: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 13
SM_CXDLGFRAME: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 7
SM_CXDOUBLECLK: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 36
SM_CXDRAG: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 68
SM_CXEDGE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 45
SM_CXFIXEDFRAME: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 7
SM_CXFOCUSBORDER: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 83
SM_CXFRAME: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 32
SM_CXFULLSCREEN: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 16
SM_CXHSCROLL: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 21
SM_CXHTHUMB: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 10
SM_CXICON: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 11
SM_CXICONSPACING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 38
SM_CXMAXIMIZED: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 61
SM_CXMAXTRACK: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 59
SM_CXMENUCHECK: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 71
SM_CXMENUSIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 54
SM_CXMIN: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 28
SM_CXMINIMIZED: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 57
SM_CXMINSPACING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 47
SM_CXMINTRACK: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 34
SM_CXPADDEDBORDER: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 92
SM_CXSCREEN: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 0
SM_CXSIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 30
SM_CXSIZEFRAME: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 32
SM_CXSMICON: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 49
SM_CXSMSIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 52
SM_CXVIRTUALSCREEN: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 78
SM_CXVSCROLL: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 2
SM_CYBORDER: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 6
SM_CYCAPTION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 4
SM_CYCURSOR: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 14
SM_CYDLGFRAME: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 8
SM_CYDOUBLECLK: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 37
SM_CYDRAG: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 69
SM_CYEDGE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 46
SM_CYFIXEDFRAME: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 8
SM_CYFOCUSBORDER: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 84
SM_CYFRAME: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 33
SM_CYFULLSCREEN: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 17
SM_CYHSCROLL: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 3
SM_CYICON: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 12
SM_CYICONSPACING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 39
SM_CYKANJIWINDOW: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 18
SM_CYMAXIMIZED: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 62
SM_CYMAXTRACK: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 60
SM_CYMENU: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 15
SM_CYMENUCHECK: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 72
SM_CYMENUSIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 55
SM_CYMIN: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 29
SM_CYMINIMIZED: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 58
SM_CYMINSPACING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 48
SM_CYMINTRACK: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 35
SM_CYSCREEN: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 1
SM_CYSIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 31
SM_CYSIZEFRAME: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 33
SM_CYSMCAPTION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 51
SM_CYSMICON: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 50
SM_CYSMSIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 53
SM_CYVIRTUALSCREEN: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 79
SM_CYVSCROLL: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 20
SM_CYVTHUMB: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 9
SM_DBCSENABLED: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 42
SM_DEBUG: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 22
SM_DIGITIZER: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 94
SM_IMMENABLED: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 82
SM_MAXIMUMTOUCHES: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 95
SM_MEDIACENTER: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 87
SM_MENUDROPALIGNMENT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 40
SM_MIDEASTENABLED: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 74
SM_MOUSEPRESENT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 19
SM_MOUSEHORIZONTALWHEELPRESENT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 91
SM_MOUSEWHEELPRESENT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 75
SM_NETWORK: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 63
SM_PENWINDOWS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 41
SM_REMOTECONTROL: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 8193
SM_REMOTESESSION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 4096
SM_SAMEDISPLAYFORMAT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 81
SM_SECURE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 44
SM_SERVERR2: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 89
SM_SHOWSOUNDS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 70
SM_SHUTTINGDOWN: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 8192
SM_SLOWMACHINE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 73
SM_STARTER: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 88
SM_SWAPBUTTON: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 23
SM_SYSTEMDOCKED: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 8196
SM_TABLETPC: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 86
SM_XVIRTUALSCREEN: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 76
SM_YVIRTUALSCREEN: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX = 77
SYSTEM_PARAMETERS_INFO_ACTION = UInt32
SPI_GETBEEP: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 1
SPI_SETBEEP: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 2
SPI_GETMOUSE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 3
SPI_SETMOUSE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4
SPI_GETBORDER: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 5
SPI_SETBORDER: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 6
SPI_GETKEYBOARDSPEED: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 10
SPI_SETKEYBOARDSPEED: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 11
SPI_LANGDRIVER: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 12
SPI_ICONHORIZONTALSPACING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 13
SPI_GETSCREENSAVETIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 14
SPI_SETSCREENSAVETIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 15
SPI_GETSCREENSAVEACTIVE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 16
SPI_SETSCREENSAVEACTIVE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 17
SPI_GETGRIDGRANULARITY: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 18
SPI_SETGRIDGRANULARITY: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 19
SPI_SETDESKWALLPAPER: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 20
SPI_SETDESKPATTERN: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 21
SPI_GETKEYBOARDDELAY: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 22
SPI_SETKEYBOARDDELAY: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 23
SPI_ICONVERTICALSPACING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 24
SPI_GETICONTITLEWRAP: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 25
SPI_SETICONTITLEWRAP: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 26
SPI_GETMENUDROPALIGNMENT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 27
SPI_SETMENUDROPALIGNMENT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 28
SPI_SETDOUBLECLKWIDTH: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 29
SPI_SETDOUBLECLKHEIGHT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 30
SPI_GETICONTITLELOGFONT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 31
SPI_SETDOUBLECLICKTIME: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 32
SPI_SETMOUSEBUTTONSWAP: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 33
SPI_SETICONTITLELOGFONT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 34
SPI_GETFASTTASKSWITCH: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 35
SPI_SETFASTTASKSWITCH: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 36
SPI_SETDRAGFULLWINDOWS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 37
SPI_GETDRAGFULLWINDOWS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 38
SPI_GETNONCLIENTMETRICS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 41
SPI_SETNONCLIENTMETRICS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 42
SPI_GETMINIMIZEDMETRICS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 43
SPI_SETMINIMIZEDMETRICS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 44
SPI_GETICONMETRICS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 45
SPI_SETICONMETRICS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 46
SPI_SETWORKAREA: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 47
SPI_GETWORKAREA: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 48
SPI_SETPENWINDOWS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 49
SPI_GETHIGHCONTRAST: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 66
SPI_SETHIGHCONTRAST: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 67
SPI_GETKEYBOARDPREF: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 68
SPI_SETKEYBOARDPREF: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 69
SPI_GETSCREENREADER: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 70
SPI_SETSCREENREADER: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 71
SPI_GETANIMATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 72
SPI_SETANIMATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 73
SPI_GETFONTSMOOTHING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 74
SPI_SETFONTSMOOTHING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 75
SPI_SETDRAGWIDTH: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 76
SPI_SETDRAGHEIGHT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 77
SPI_SETHANDHELD: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 78
SPI_GETLOWPOWERTIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 79
SPI_GETPOWEROFFTIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 80
SPI_SETLOWPOWERTIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 81
SPI_SETPOWEROFFTIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 82
SPI_GETLOWPOWERACTIVE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 83
SPI_GETPOWEROFFACTIVE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 84
SPI_SETLOWPOWERACTIVE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 85
SPI_SETPOWEROFFACTIVE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 86
SPI_SETCURSORS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 87
SPI_SETICONS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 88
SPI_GETDEFAULTINPUTLANG: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 89
SPI_SETDEFAULTINPUTLANG: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 90
SPI_SETLANGTOGGLE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 91
SPI_GETWINDOWSEXTENSION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 92
SPI_SETMOUSETRAILS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 93
SPI_GETMOUSETRAILS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 94
SPI_SETSCREENSAVERRUNNING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 97
SPI_SCREENSAVERRUNNING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 97
SPI_GETFILTERKEYS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 50
SPI_SETFILTERKEYS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 51
SPI_GETTOGGLEKEYS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 52
SPI_SETTOGGLEKEYS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 53
SPI_GETMOUSEKEYS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 54
SPI_SETMOUSEKEYS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 55
SPI_GETSHOWSOUNDS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 56
SPI_SETSHOWSOUNDS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 57
SPI_GETSTICKYKEYS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 58
SPI_SETSTICKYKEYS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 59
SPI_GETACCESSTIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 60
SPI_SETACCESSTIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 61
SPI_GETSERIALKEYS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 62
SPI_SETSERIALKEYS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 63
SPI_GETSOUNDSENTRY: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 64
SPI_SETSOUNDSENTRY: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 65
SPI_GETSNAPTODEFBUTTON: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 95
SPI_SETSNAPTODEFBUTTON: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 96
SPI_GETMOUSEHOVERWIDTH: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 98
SPI_SETMOUSEHOVERWIDTH: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 99
SPI_GETMOUSEHOVERHEIGHT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 100
SPI_SETMOUSEHOVERHEIGHT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 101
SPI_GETMOUSEHOVERTIME: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 102
SPI_SETMOUSEHOVERTIME: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 103
SPI_GETWHEELSCROLLLINES: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 104
SPI_SETWHEELSCROLLLINES: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 105
SPI_GETMENUSHOWDELAY: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 106
SPI_SETMENUSHOWDELAY: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 107
SPI_GETWHEELSCROLLCHARS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 108
SPI_SETWHEELSCROLLCHARS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 109
SPI_GETSHOWIMEUI: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 110
SPI_SETSHOWIMEUI: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 111
SPI_GETMOUSESPEED: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 112
SPI_SETMOUSESPEED: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 113
SPI_GETSCREENSAVERRUNNING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 114
SPI_GETDESKWALLPAPER: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 115
SPI_GETAUDIODESCRIPTION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 116
SPI_SETAUDIODESCRIPTION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 117
SPI_GETSCREENSAVESECURE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 118
SPI_SETSCREENSAVESECURE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 119
SPI_GETHUNGAPPTIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 120
SPI_SETHUNGAPPTIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 121
SPI_GETWAITTOKILLTIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 122
SPI_SETWAITTOKILLTIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 123
SPI_GETWAITTOKILLSERVICETIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 124
SPI_SETWAITTOKILLSERVICETIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 125
SPI_GETMOUSEDOCKTHRESHOLD: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 126
SPI_SETMOUSEDOCKTHRESHOLD: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 127
SPI_GETPENDOCKTHRESHOLD: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 128
SPI_SETPENDOCKTHRESHOLD: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 129
SPI_GETWINARRANGING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 130
SPI_SETWINARRANGING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 131
SPI_GETMOUSEDRAGOUTTHRESHOLD: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 132
SPI_SETMOUSEDRAGOUTTHRESHOLD: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 133
SPI_GETPENDRAGOUTTHRESHOLD: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 134
SPI_SETPENDRAGOUTTHRESHOLD: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 135
SPI_GETMOUSESIDEMOVETHRESHOLD: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 136
SPI_SETMOUSESIDEMOVETHRESHOLD: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 137
SPI_GETPENSIDEMOVETHRESHOLD: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 138
SPI_SETPENSIDEMOVETHRESHOLD: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 139
SPI_GETDRAGFROMMAXIMIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 140
SPI_SETDRAGFROMMAXIMIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 141
SPI_GETSNAPSIZING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 142
SPI_SETSNAPSIZING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 143
SPI_GETDOCKMOVING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 144
SPI_SETDOCKMOVING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 145
SPI_GETTOUCHPREDICTIONPARAMETERS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 156
SPI_SETTOUCHPREDICTIONPARAMETERS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 157
SPI_GETLOGICALDPIOVERRIDE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 158
SPI_SETLOGICALDPIOVERRIDE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 159
SPI_GETMENURECT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 162
SPI_SETMENURECT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 163
SPI_GETACTIVEWINDOWTRACKING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4096
SPI_SETACTIVEWINDOWTRACKING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4097
SPI_GETMENUANIMATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4098
SPI_SETMENUANIMATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4099
SPI_GETCOMBOBOXANIMATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4100
SPI_SETCOMBOBOXANIMATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4101
SPI_GETLISTBOXSMOOTHSCROLLING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4102
SPI_SETLISTBOXSMOOTHSCROLLING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4103
SPI_GETGRADIENTCAPTIONS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4104
SPI_SETGRADIENTCAPTIONS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4105
SPI_GETKEYBOARDCUES: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4106
SPI_SETKEYBOARDCUES: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4107
SPI_GETMENUUNDERLINES: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4106
SPI_SETMENUUNDERLINES: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4107
SPI_GETACTIVEWNDTRKZORDER: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4108
SPI_SETACTIVEWNDTRKZORDER: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4109
SPI_GETHOTTRACKING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4110
SPI_SETHOTTRACKING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4111
SPI_GETMENUFADE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4114
SPI_SETMENUFADE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4115
SPI_GETSELECTIONFADE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4116
SPI_SETSELECTIONFADE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4117
SPI_GETTOOLTIPANIMATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4118
SPI_SETTOOLTIPANIMATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4119
SPI_GETTOOLTIPFADE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4120
SPI_SETTOOLTIPFADE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4121
SPI_GETCURSORSHADOW: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4122
SPI_SETCURSORSHADOW: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4123
SPI_GETMOUSESONAR: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4124
SPI_SETMOUSESONAR: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4125
SPI_GETMOUSECLICKLOCK: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4126
SPI_SETMOUSECLICKLOCK: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4127
SPI_GETMOUSEVANISH: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4128
SPI_SETMOUSEVANISH: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4129
SPI_GETFLATMENU: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4130
SPI_SETFLATMENU: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4131
SPI_GETDROPSHADOW: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4132
SPI_SETDROPSHADOW: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4133
SPI_GETBLOCKSENDINPUTRESETS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4134
SPI_SETBLOCKSENDINPUTRESETS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4135
SPI_GETUIEFFECTS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4158
SPI_SETUIEFFECTS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4159
SPI_GETDISABLEOVERLAPPEDCONTENT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4160
SPI_SETDISABLEOVERLAPPEDCONTENT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4161
SPI_GETCLIENTAREAANIMATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4162
SPI_SETCLIENTAREAANIMATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4163
SPI_GETCLEARTYPE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4168
SPI_SETCLEARTYPE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4169
SPI_GETSPEECHRECOGNITION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4170
SPI_SETSPEECHRECOGNITION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4171
SPI_GETCARETBROWSING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4172
SPI_SETCARETBROWSING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4173
SPI_GETTHREADLOCALINPUTSETTINGS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4174
SPI_SETTHREADLOCALINPUTSETTINGS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4175
SPI_GETSYSTEMLANGUAGEBAR: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4176
SPI_SETSYSTEMLANGUAGEBAR: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 4177
SPI_GETFOREGROUNDLOCKTIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8192
SPI_SETFOREGROUNDLOCKTIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8193
SPI_GETACTIVEWNDTRKTIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8194
SPI_SETACTIVEWNDTRKTIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8195
SPI_GETFOREGROUNDFLASHCOUNT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8196
SPI_SETFOREGROUNDFLASHCOUNT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8197
SPI_GETCARETWIDTH: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8198
SPI_SETCARETWIDTH: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8199
SPI_GETMOUSECLICKLOCKTIME: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8200
SPI_SETMOUSECLICKLOCKTIME: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8201
SPI_GETFONTSMOOTHINGTYPE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8202
SPI_SETFONTSMOOTHINGTYPE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8203
SPI_GETFONTSMOOTHINGCONTRAST: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8204
SPI_SETFONTSMOOTHINGCONTRAST: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8205
SPI_GETFOCUSBORDERWIDTH: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8206
SPI_SETFOCUSBORDERWIDTH: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8207
SPI_GETFOCUSBORDERHEIGHT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8208
SPI_SETFOCUSBORDERHEIGHT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8209
SPI_GETFONTSMOOTHINGORIENTATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8210
SPI_SETFONTSMOOTHINGORIENTATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8211
SPI_GETMINIMUMHITRADIUS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8212
SPI_SETMINIMUMHITRADIUS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8213
SPI_GETMESSAGEDURATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8214
SPI_SETMESSAGEDURATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8215
SPI_GETCONTACTVISUALIZATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8216
SPI_SETCONTACTVISUALIZATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8217
SPI_GETGESTUREVISUALIZATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8218
SPI_SETGESTUREVISUALIZATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8219
SPI_GETMOUSEWHEELROUTING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8220
SPI_SETMOUSEWHEELROUTING: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8221
SPI_GETPENVISUALIZATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8222
SPI_SETPENVISUALIZATION: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8223
SPI_GETPENARBITRATIONTYPE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8224
SPI_SETPENARBITRATIONTYPE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8225
SPI_GETCARETTIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8226
SPI_SETCARETTIMEOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8227
SPI_GETHANDEDNESS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8228
SPI_SETHANDEDNESS: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_ACTION = 8229
SYSTEM_PARAMETERS_INFO_UPDATE_FLAGS = UInt32
SPIF_UPDATEINIFILE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_UPDATE_FLAGS = 1
SPIF_SENDCHANGE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_UPDATE_FLAGS = 2
SPIF_SENDWININICHANGE: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_PARAMETERS_INFO_UPDATE_FLAGS = 2
TILE_WINDOWS_HOW = UInt32
MDITILE_HORIZONTAL: win32more.Windows.Win32.UI.WindowsAndMessaging.TILE_WINDOWS_HOW = 1
MDITILE_VERTICAL: win32more.Windows.Win32.UI.WindowsAndMessaging.TILE_WINDOWS_HOW = 0
@winfunctype_pointer
def TIMERPROC(param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32, param2: UIntPtr, param3: UInt32) -> Void: ...
class TITLEBARINFO(Structure):
    cbSize: UInt32
    rcTitleBar: win32more.Windows.Win32.Foundation.RECT
    rgstate: UInt32 * 6
class TITLEBARINFOEX(Structure):
    cbSize: UInt32
    rcTitleBar: win32more.Windows.Win32.Foundation.RECT
    rgstate: UInt32 * 6
    rgrect: win32more.Windows.Win32.Foundation.RECT * 6
TOOLTIP_DISMISS_FLAGS = Int32
TDF_REGISTER: win32more.Windows.Win32.UI.WindowsAndMessaging.TOOLTIP_DISMISS_FLAGS = 1
TDF_UNREGISTER: win32more.Windows.Win32.UI.WindowsAndMessaging.TOOLTIP_DISMISS_FLAGS = 2
class TOUCHPREDICTIONPARAMETERS(Structure):
    cbSize: UInt32
    dwLatency: UInt32
    dwSampleTime: UInt32
    bUseHWTimeStamp: UInt32
class TPMPARAMS(Structure):
    cbSize: UInt32
    rcExclude: win32more.Windows.Win32.Foundation.RECT
TRACK_POPUP_MENU_FLAGS = UInt32
TPM_LEFTBUTTON: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 0
TPM_RIGHTBUTTON: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 2
TPM_LEFTALIGN: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 0
TPM_CENTERALIGN: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 4
TPM_RIGHTALIGN: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 8
TPM_TOPALIGN: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 0
TPM_VCENTERALIGN: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 16
TPM_BOTTOMALIGN: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 32
TPM_HORIZONTAL: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 0
TPM_VERTICAL: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 64
TPM_NONOTIFY: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 128
TPM_RETURNCMD: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 256
TPM_RECURSE: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 1
TPM_HORPOSANIMATION: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 1024
TPM_HORNEGANIMATION: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 2048
TPM_VERPOSANIMATION: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 4096
TPM_VERNEGANIMATION: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 8192
TPM_NOANIMATION: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 16384
TPM_LAYOUTRTL: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 32768
TPM_WORKAREA: win32more.Windows.Win32.UI.WindowsAndMessaging.TRACK_POPUP_MENU_FLAGS = 65536
class UPDATELAYEREDWINDOWINFO(Structure):
    cbSize: UInt32
    hdcDst: win32more.Windows.Win32.Graphics.Gdi.HDC
    pptDst: POINTER(win32more.Windows.Win32.Foundation.POINT)
    psize: POINTER(win32more.Windows.Win32.Foundation.SIZE)
    hdcSrc: win32more.Windows.Win32.Graphics.Gdi.HDC
    pptSrc: POINTER(win32more.Windows.Win32.Foundation.POINT)
    crKey: win32more.Windows.Win32.Foundation.COLORREF
    pblend: POINTER(win32more.Windows.Win32.Graphics.Gdi.BLENDFUNCTION)
    dwFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.UPDATE_LAYERED_WINDOW_FLAGS
    prcDirty: POINTER(win32more.Windows.Win32.Foundation.RECT)
UPDATE_LAYERED_WINDOW_FLAGS = UInt32
ULW_ALPHA: win32more.Windows.Win32.UI.WindowsAndMessaging.UPDATE_LAYERED_WINDOW_FLAGS = 2
ULW_COLORKEY: win32more.Windows.Win32.UI.WindowsAndMessaging.UPDATE_LAYERED_WINDOW_FLAGS = 1
ULW_OPAQUE: win32more.Windows.Win32.UI.WindowsAndMessaging.UPDATE_LAYERED_WINDOW_FLAGS = 4
ULW_EX_NORESIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.UPDATE_LAYERED_WINDOW_FLAGS = 8
class VolLockBroadcast(Structure):
    vlb_dbh: win32more.Windows.Win32.UI.WindowsAndMessaging.DEV_BROADCAST_HDR
    vlb_owner: UInt32
    vlb_perms: Byte
    vlb_lockType: Byte
    vlb_drive: Byte
    vlb_flags: Byte
class WINDOWINFO(Structure):
    cbSize: UInt32
    rcWindow: win32more.Windows.Win32.Foundation.RECT
    rcClient: win32more.Windows.Win32.Foundation.RECT
    dwStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE
    dwExStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE
    dwWindowStatus: UInt32
    cxWindowBorders: UInt32
    cyWindowBorders: UInt32
    atomWindowType: UInt16
    wCreatorVersion: UInt16
class WINDOWPLACEMENT(Structure):
    length: UInt32
    flags: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWPLACEMENT_FLAGS
    showCmd: UInt32
    ptMinPosition: win32more.Windows.Win32.Foundation.POINT
    ptMaxPosition: win32more.Windows.Win32.Foundation.POINT
    rcNormalPosition: win32more.Windows.Win32.Foundation.RECT
WINDOWPLACEMENT_FLAGS = UInt32
WPF_ASYNCWINDOWPLACEMENT: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWPLACEMENT_FLAGS = 4
WPF_RESTORETOMAXIMIZED: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWPLACEMENT_FLAGS = 2
WPF_SETMINPOSITION: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWPLACEMENT_FLAGS = 1
class WINDOWPOS(Structure):
    hwnd: win32more.Windows.Win32.Foundation.HWND
    hwndInsertAfter: win32more.Windows.Win32.Foundation.HWND
    x: Int32
    y: Int32
    cx: Int32
    cy: Int32
    flags: win32more.Windows.Win32.UI.WindowsAndMessaging.SET_WINDOW_POS_FLAGS
WINDOWS_HOOK_ID = Int32
WH_CALLWNDPROC: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWS_HOOK_ID = 4
WH_CALLWNDPROCRET: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWS_HOOK_ID = 12
WH_CBT: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWS_HOOK_ID = 5
WH_DEBUG: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWS_HOOK_ID = 9
WH_FOREGROUNDIDLE: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWS_HOOK_ID = 11
WH_GETMESSAGE: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWS_HOOK_ID = 3
WH_JOURNALPLAYBACK: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWS_HOOK_ID = 1
WH_JOURNALRECORD: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWS_HOOK_ID = 0
WH_KEYBOARD: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWS_HOOK_ID = 2
WH_KEYBOARD_LL: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWS_HOOK_ID = 13
WH_MOUSE: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWS_HOOK_ID = 7
WH_MOUSE_LL: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWS_HOOK_ID = 14
WH_MSGFILTER: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWS_HOOK_ID = -1
WH_SHELL: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWS_HOOK_ID = 10
WH_SYSMSGFILTER: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWS_HOOK_ID = 6
WINDOW_DISPLAY_AFFINITY = UInt32
WDA_NONE: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_DISPLAY_AFFINITY = 0
WDA_MONITOR: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_DISPLAY_AFFINITY = 1
WDA_EXCLUDEFROMCAPTURE: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_DISPLAY_AFFINITY = 17
WINDOW_EX_STYLE = UInt32
WS_EX_DLGMODALFRAME: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 1
WS_EX_NOPARENTNOTIFY: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 4
WS_EX_TOPMOST: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 8
WS_EX_ACCEPTFILES: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 16
WS_EX_TRANSPARENT: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 32
WS_EX_MDICHILD: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 64
WS_EX_TOOLWINDOW: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 128
WS_EX_WINDOWEDGE: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 256
WS_EX_CLIENTEDGE: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 512
WS_EX_CONTEXTHELP: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 1024
WS_EX_RIGHT: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 4096
WS_EX_LEFT: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 0
WS_EX_RTLREADING: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 8192
WS_EX_LTRREADING: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 0
WS_EX_LEFTSCROLLBAR: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 16384
WS_EX_RIGHTSCROLLBAR: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 0
WS_EX_CONTROLPARENT: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 65536
WS_EX_STATICEDGE: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 131072
WS_EX_APPWINDOW: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 262144
WS_EX_OVERLAPPEDWINDOW: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 768
WS_EX_PALETTEWINDOW: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 392
WS_EX_LAYERED: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 524288
WS_EX_NOINHERITLAYOUT: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 1048576
WS_EX_NOREDIRECTIONBITMAP: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 2097152
WS_EX_LAYOUTRTL: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 4194304
WS_EX_COMPOSITED: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 33554432
WS_EX_NOACTIVATE: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE = 134217728
WINDOW_LONG_PTR_INDEX = Int32
GWL_EXSTYLE: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX = -20
GWLP_HINSTANCE: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX = -6
GWLP_HWNDPARENT: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX = -8
GWLP_ID: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX = -12
GWL_STYLE: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX = -16
GWLP_USERDATA: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX = -21
GWLP_WNDPROC: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX = -4
GWL_HINSTANCE: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX = -6
GWL_ID: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX = -12
GWL_USERDATA: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX = -21
GWL_WNDPROC: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX = -4
GWL_HWNDPARENT: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_LONG_PTR_INDEX = -8
WINDOW_MESSAGE_FILTER_ACTION = UInt32
MSGFLT_ALLOW: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_MESSAGE_FILTER_ACTION = 1
MSGFLT_DISALLOW: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_MESSAGE_FILTER_ACTION = 2
MSGFLT_RESET: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_MESSAGE_FILTER_ACTION = 0
WINDOW_STYLE = UInt32
WS_OVERLAPPED: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 0
WS_POPUP: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 2147483648
WS_CHILD: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 1073741824
WS_MINIMIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 536870912
WS_VISIBLE: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 268435456
WS_DISABLED: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 134217728
WS_CLIPSIBLINGS: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 67108864
WS_CLIPCHILDREN: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 33554432
WS_MAXIMIZE: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 16777216
WS_CAPTION: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 12582912
WS_BORDER: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 8388608
WS_DLGFRAME: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 4194304
WS_VSCROLL: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 2097152
WS_HSCROLL: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 1048576
WS_SYSMENU: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 524288
WS_THICKFRAME: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 262144
WS_GROUP: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 131072
WS_TABSTOP: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 65536
WS_MINIMIZEBOX: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 131072
WS_MAXIMIZEBOX: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 65536
WS_TILED: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 0
WS_ICONIC: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 536870912
WS_SIZEBOX: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 262144
WS_TILEDWINDOW: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 13565952
WS_OVERLAPPEDWINDOW: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 13565952
WS_POPUPWINDOW: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 2156396544
WS_CHILDWINDOW: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 1073741824
WS_ACTIVECAPTION: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE = 1
class WNDCLASSA(Structure):
    style: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASS_STYLES
    lpfnWndProc: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDPROC
    cbClsExtra: Int32
    cbWndExtra: Int32
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
    hCursor: win32more.Windows.Win32.UI.WindowsAndMessaging.HCURSOR
    hbrBackground: win32more.Windows.Win32.Graphics.Gdi.HBRUSH
    lpszMenuName: win32more.Windows.Win32.Foundation.PSTR
    lpszClassName: win32more.Windows.Win32.Foundation.PSTR
class WNDCLASSEXA(Structure):
    cbSize: UInt32
    style: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASS_STYLES
    lpfnWndProc: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDPROC
    cbClsExtra: Int32
    cbWndExtra: Int32
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
    hCursor: win32more.Windows.Win32.UI.WindowsAndMessaging.HCURSOR
    hbrBackground: win32more.Windows.Win32.Graphics.Gdi.HBRUSH
    lpszMenuName: win32more.Windows.Win32.Foundation.PSTR
    lpszClassName: win32more.Windows.Win32.Foundation.PSTR
    hIconSm: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
class WNDCLASSEXW(Structure):
    cbSize: UInt32
    style: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASS_STYLES
    lpfnWndProc: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDPROC
    cbClsExtra: Int32
    cbWndExtra: Int32
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
    hCursor: win32more.Windows.Win32.UI.WindowsAndMessaging.HCURSOR
    hbrBackground: win32more.Windows.Win32.Graphics.Gdi.HBRUSH
    lpszMenuName: win32more.Windows.Win32.Foundation.PWSTR
    lpszClassName: win32more.Windows.Win32.Foundation.PWSTR
    hIconSm: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
WNDCLASSEX = UnicodeAlias('WNDCLASSEXW')
class WNDCLASSW(Structure):
    style: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASS_STYLES
    lpfnWndProc: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDPROC
    cbClsExtra: Int32
    cbWndExtra: Int32
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
    hCursor: win32more.Windows.Win32.UI.WindowsAndMessaging.HCURSOR
    hbrBackground: win32more.Windows.Win32.Graphics.Gdi.HBRUSH
    lpszMenuName: win32more.Windows.Win32.Foundation.PWSTR
    lpszClassName: win32more.Windows.Win32.Foundation.PWSTR
WNDCLASS = UnicodeAlias('WNDCLASSW')
WNDCLASS_STYLES = UInt32
CS_VREDRAW: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASS_STYLES = 1
CS_HREDRAW: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASS_STYLES = 2
CS_DBLCLKS: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASS_STYLES = 8
CS_OWNDC: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASS_STYLES = 32
CS_CLASSDC: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASS_STYLES = 64
CS_PARENTDC: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASS_STYLES = 128
CS_NOCLOSE: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASS_STYLES = 512
CS_SAVEBITS: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASS_STYLES = 2048
CS_BYTEALIGNCLIENT: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASS_STYLES = 4096
CS_BYTEALIGNWINDOW: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASS_STYLES = 8192
CS_GLOBALCLASS: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASS_STYLES = 16384
CS_IME: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASS_STYLES = 65536
CS_DROPSHADOW: win32more.Windows.Win32.UI.WindowsAndMessaging.WNDCLASS_STYLES = 131072
@winfunctype_pointer
def WNDENUMPROC(param0: win32more.Windows.Win32.Foundation.HWND, param1: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def WNDPROC(param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32, param2: win32more.Windows.Win32.Foundation.WPARAM, param3: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.LRESULT: ...
class _DEV_BROADCAST_HEADER(Structure):
    dbcd_size: UInt32
    dbcd_devicetype: UInt32
    dbcd_reserved: UInt32
class _DEV_BROADCAST_USERDEFINED(Structure):
    dbud_dbh: win32more.Windows.Win32.UI.WindowsAndMessaging.DEV_BROADCAST_HDR
    dbud_szName: win32more.Windows.Win32.Foundation.CHAR * 1


make_ready(__name__)
