from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Data.Xml.MsXml
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Diagnostics.Debug
import win32more.Windows.Win32.System.Diagnostics.Debug.Extensions
import win32more.Windows.Win32.System.Kernel
import win32more.Windows.Win32.System.Memory
import win32more.Windows.Win32.System.Variant
ERROR_DBG_CANCELLED: UInt32 = 3221226695
ERROR_DBG_TIMEOUT: UInt32 = 3221226932
DEBUG_GET_TEXT_COMPLETIONS_NO_DOT_COMMANDS: UInt32 = 1
DEBUG_GET_TEXT_COMPLETIONS_NO_EXTENSION_COMMANDS: UInt32 = 2
DEBUG_GET_TEXT_COMPLETIONS_NO_SYMBOLS: UInt32 = 4
DEBUG_GET_TEXT_COMPLETIONS_IS_DOT_COMMAND: UInt32 = 1
DEBUG_GET_TEXT_COMPLETIONS_IS_EXTENSION_COMMAND: UInt32 = 2
DEBUG_GET_TEXT_COMPLETIONS_IS_SYMBOL: UInt32 = 4
DEBUG_REQUEST_SOURCE_PATH_HAS_SOURCE_SERVER: UInt32 = 0
DEBUG_REQUEST_TARGET_EXCEPTION_CONTEXT: UInt32 = 1
DEBUG_REQUEST_TARGET_EXCEPTION_THREAD: UInt32 = 2
DEBUG_REQUEST_TARGET_EXCEPTION_RECORD: UInt32 = 3
DEBUG_REQUEST_GET_ADDITIONAL_CREATE_OPTIONS: UInt32 = 4
DEBUG_REQUEST_SET_ADDITIONAL_CREATE_OPTIONS: UInt32 = 5
DEBUG_REQUEST_GET_WIN32_MAJOR_MINOR_VERSIONS: UInt32 = 6
DEBUG_REQUEST_READ_USER_MINIDUMP_STREAM: UInt32 = 7
DEBUG_REQUEST_TARGET_CAN_DETACH: UInt32 = 8
DEBUG_REQUEST_SET_LOCAL_IMPLICIT_COMMAND_LINE: UInt32 = 9
DEBUG_REQUEST_GET_CAPTURED_EVENT_CODE_OFFSET: UInt32 = 10
DEBUG_REQUEST_READ_CAPTURED_EVENT_CODE_STREAM: UInt32 = 11
DEBUG_REQUEST_EXT_TYPED_DATA_ANSI: UInt32 = 12
DEBUG_REQUEST_GET_EXTENSION_SEARCH_PATH_WIDE: UInt32 = 13
DEBUG_REQUEST_GET_TEXT_COMPLETIONS_WIDE: UInt32 = 14
DEBUG_REQUEST_GET_CACHED_SYMBOL_INFO: UInt32 = 15
DEBUG_REQUEST_ADD_CACHED_SYMBOL_INFO: UInt32 = 16
DEBUG_REQUEST_REMOVE_CACHED_SYMBOL_INFO: UInt32 = 17
DEBUG_REQUEST_GET_TEXT_COMPLETIONS_ANSI: UInt32 = 18
DEBUG_REQUEST_CURRENT_OUTPUT_CALLBACKS_ARE_DML_AWARE: UInt32 = 19
DEBUG_REQUEST_GET_OFFSET_UNWIND_INFORMATION: UInt32 = 20
DEBUG_REQUEST_GET_DUMP_HEADER: UInt32 = 21
DEBUG_REQUEST_SET_DUMP_HEADER: UInt32 = 22
DEBUG_REQUEST_MIDORI: UInt32 = 23
DEBUG_REQUEST_PROCESS_DESCRIPTORS: UInt32 = 24
DEBUG_REQUEST_MISC_INFORMATION: UInt32 = 25
DEBUG_REQUEST_OPEN_PROCESS_TOKEN: UInt32 = 26
DEBUG_REQUEST_OPEN_THREAD_TOKEN: UInt32 = 27
DEBUG_REQUEST_DUPLICATE_TOKEN: UInt32 = 28
DEBUG_REQUEST_QUERY_INFO_TOKEN: UInt32 = 29
DEBUG_REQUEST_CLOSE_TOKEN: UInt32 = 30
DEBUG_REQUEST_WOW_PROCESS: UInt32 = 31
DEBUG_REQUEST_WOW_MODULE: UInt32 = 32
DEBUG_LIVE_USER_NON_INVASIVE: UInt32 = 33
DEBUG_REQUEST_RESUME_THREAD: UInt32 = 34
DEBUG_REQUEST_INLINE_QUERY: UInt32 = 35
DEBUG_REQUEST_TL_INSTRUMENTATION_AWARE: UInt32 = 36
DEBUG_REQUEST_GET_INSTRUMENTATION_VERSION: UInt32 = 37
DEBUG_REQUEST_GET_MODULE_ARCHITECTURE: UInt32 = 38
DEBUG_REQUEST_GET_IMAGE_ARCHITECTURE: UInt32 = 39
DEBUG_SRCFILE_SYMBOL_TOKEN: UInt32 = 0
DEBUG_SRCFILE_SYMBOL_TOKEN_SOURCE_COMMAND_WIDE: UInt32 = 1
DEBUG_SRCFILE_SYMBOL_CHECKSUMINFO: UInt32 = 2
DEBUG_SYMINFO_BREAKPOINT_SOURCE_LINE: UInt32 = 0
DEBUG_SYMINFO_IMAGEHLP_MODULEW64: UInt32 = 1
DEBUG_SYMINFO_GET_SYMBOL_NAME_BY_OFFSET_AND_TAG_WIDE: UInt32 = 2
DEBUG_SYMINFO_GET_MODULE_SYMBOL_NAMES_AND_OFFSETS: UInt32 = 3
DEBUG_SYSOBJINFO_THREAD_BASIC_INFORMATION: UInt32 = 0
DEBUG_SYSOBJINFO_THREAD_NAME_WIDE: UInt32 = 1
DEBUG_SYSOBJINFO_CURRENT_PROCESS_COOKIE: UInt32 = 2
DEBUG_TBINFO_EXIT_STATUS: UInt32 = 1
DEBUG_TBINFO_PRIORITY_CLASS: UInt32 = 2
DEBUG_TBINFO_PRIORITY: UInt32 = 4
DEBUG_TBINFO_TIMES: UInt32 = 8
DEBUG_TBINFO_START_OFFSET: UInt32 = 16
DEBUG_TBINFO_AFFINITY: UInt32 = 32
DEBUG_TBINFO_ALL: UInt32 = 63
DEBUG_BREAKPOINT_CODE: UInt32 = 0
DEBUG_BREAKPOINT_DATA: UInt32 = 1
DEBUG_BREAKPOINT_TIME: UInt32 = 2
DEBUG_BREAKPOINT_INLINE: UInt32 = 3
DEBUG_BREAKPOINT_GO_ONLY: UInt32 = 1
DEBUG_BREAKPOINT_DEFERRED: UInt32 = 2
DEBUG_BREAKPOINT_ENABLED: UInt32 = 4
DEBUG_BREAKPOINT_ADDER_ONLY: UInt32 = 8
DEBUG_BREAKPOINT_ONE_SHOT: UInt32 = 16
DEBUG_BREAK_READ: UInt32 = 1
DEBUG_BREAK_WRITE: UInt32 = 2
DEBUG_BREAK_EXECUTE: UInt32 = 4
DEBUG_BREAK_IO: UInt32 = 8
DEBUG_ATTACH_KERNEL_CONNECTION: UInt32 = 0
DEBUG_ATTACH_LOCAL_KERNEL: UInt32 = 1
DEBUG_ATTACH_EXDI_DRIVER: UInt32 = 2
DEBUG_ATTACH_INSTALL_DRIVER: UInt32 = 4
DEBUG_GET_PROC_DEFAULT: UInt32 = 0
DEBUG_GET_PROC_FULL_MATCH: UInt32 = 1
DEBUG_GET_PROC_ONLY_MATCH: UInt32 = 2
DEBUG_GET_PROC_SERVICE_NAME: UInt32 = 4
DEBUG_PROC_DESC_DEFAULT: UInt32 = 0
DEBUG_PROC_DESC_NO_PATHS: UInt32 = 1
DEBUG_PROC_DESC_NO_SERVICES: UInt32 = 2
DEBUG_PROC_DESC_NO_MTS_PACKAGES: UInt32 = 4
DEBUG_PROC_DESC_NO_COMMAND_LINE: UInt32 = 8
DEBUG_PROC_DESC_NO_SESSION_ID: UInt32 = 16
DEBUG_PROC_DESC_NO_USER_NAME: UInt32 = 32
DEBUG_PROC_DESC_WITH_PACKAGEFAMILY: UInt32 = 64
DEBUG_PROC_DESC_WITH_ARCHITECTURE: UInt32 = 128
DEBUG_ATTACH_DEFAULT: UInt32 = 0
DEBUG_ATTACH_NONINVASIVE: UInt32 = 1
DEBUG_ATTACH_EXISTING: UInt32 = 2
DEBUG_ATTACH_NONINVASIVE_NO_SUSPEND: UInt32 = 4
DEBUG_ATTACH_INVASIVE_NO_INITIAL_BREAK: UInt32 = 8
DEBUG_ATTACH_INVASIVE_RESUME_PROCESS: UInt32 = 16
DEBUG_ATTACH_NONINVASIVE_ALLOW_PARTIAL: UInt32 = 32
DEBUG_ECREATE_PROCESS_DEFAULT: UInt32 = 0
DEBUG_ECREATE_PROCESS_INHERIT_HANDLES: UInt32 = 1
DEBUG_ECREATE_PROCESS_USE_VERIFIER_FLAGS: UInt32 = 2
DEBUG_ECREATE_PROCESS_USE_IMPLICIT_COMMAND_LINE: UInt32 = 4
DEBUG_PROCESS_DETACH_ON_EXIT: UInt32 = 1
DEBUG_PROCESS_ONLY_THIS_PROCESS: UInt32 = 2
DEBUG_CONNECT_SESSION_DEFAULT: UInt32 = 0
DEBUG_CONNECT_SESSION_NO_VERSION: UInt32 = 1
DEBUG_CONNECT_SESSION_NO_ANNOUNCE: UInt32 = 2
DEBUG_SERVERS_DEBUGGER: UInt32 = 1
DEBUG_SERVERS_PROCESS: UInt32 = 2
DEBUG_SERVERS_ALL: UInt32 = 3
DEBUG_END_PASSIVE: UInt32 = 0
DEBUG_END_ACTIVE_TERMINATE: UInt32 = 1
DEBUG_END_ACTIVE_DETACH: UInt32 = 2
DEBUG_END_REENTRANT: UInt32 = 3
DEBUG_END_DISCONNECT: UInt32 = 4
DEBUG_OUTPUT_NORMAL: UInt32 = 1
DEBUG_OUTPUT_ERROR: UInt32 = 2
DEBUG_OUTPUT_WARNING: UInt32 = 4
DEBUG_OUTPUT_VERBOSE: UInt32 = 8
DEBUG_OUTPUT_PROMPT: UInt32 = 16
DEBUG_OUTPUT_PROMPT_REGISTERS: UInt32 = 32
DEBUG_OUTPUT_EXTENSION_WARNING: UInt32 = 64
DEBUG_OUTPUT_DEBUGGEE: UInt32 = 128
DEBUG_OUTPUT_DEBUGGEE_PROMPT: UInt32 = 256
DEBUG_OUTPUT_SYMBOLS: UInt32 = 512
DEBUG_OUTPUT_STATUS: UInt32 = 1024
DEBUG_OUTPUT_XML: UInt32 = 2048
DEBUG_IOUTPUT_KD_PROTOCOL: UInt32 = 2147483648
DEBUG_IOUTPUT_REMOTING: UInt32 = 1073741824
DEBUG_IOUTPUT_BREAKPOINT: UInt32 = 536870912
DEBUG_IOUTPUT_EVENT: UInt32 = 268435456
DEBUG_IOUTPUT_ADDR_TRANSLATE: UInt32 = 134217728
DEBUG_OUTPUT_IDENTITY_DEFAULT: UInt32 = 0
DEBUG_CLIENT_UNKNOWN: UInt32 = 0
DEBUG_CLIENT_VSINT: UInt32 = 1
DEBUG_CLIENT_NTSD: UInt32 = 2
DEBUG_CLIENT_NTKD: UInt32 = 3
DEBUG_CLIENT_CDB: UInt32 = 4
DEBUG_CLIENT_KD: UInt32 = 5
DEBUG_CLIENT_WINDBG: UInt32 = 6
DEBUG_CLIENT_WINIDE: UInt32 = 7
DEBUG_FORMAT_DEFAULT: UInt32 = 0
DEBUG_FORMAT_CAB_SECONDARY_ALL_IMAGES: UInt32 = 268435456
DEBUG_FORMAT_WRITE_CAB: UInt32 = 536870912
DEBUG_FORMAT_CAB_SECONDARY_FILES: UInt32 = 1073741824
DEBUG_FORMAT_NO_OVERWRITE: UInt32 = 2147483648
DEBUG_FORMAT_USER_SMALL_FULL_MEMORY: UInt32 = 1
DEBUG_FORMAT_USER_SMALL_HANDLE_DATA: UInt32 = 2
DEBUG_FORMAT_USER_SMALL_UNLOADED_MODULES: UInt32 = 4
DEBUG_FORMAT_USER_SMALL_INDIRECT_MEMORY: UInt32 = 8
DEBUG_FORMAT_USER_SMALL_DATA_SEGMENTS: UInt32 = 16
DEBUG_FORMAT_USER_SMALL_FILTER_MEMORY: UInt32 = 32
DEBUG_FORMAT_USER_SMALL_FILTER_PATHS: UInt32 = 64
DEBUG_FORMAT_USER_SMALL_PROCESS_THREAD_DATA: UInt32 = 128
DEBUG_FORMAT_USER_SMALL_PRIVATE_READ_WRITE_MEMORY: UInt32 = 256
DEBUG_FORMAT_USER_SMALL_NO_OPTIONAL_DATA: UInt32 = 512
DEBUG_FORMAT_USER_SMALL_FULL_MEMORY_INFO: UInt32 = 1024
DEBUG_FORMAT_USER_SMALL_THREAD_INFO: UInt32 = 2048
DEBUG_FORMAT_USER_SMALL_CODE_SEGMENTS: UInt32 = 4096
DEBUG_FORMAT_USER_SMALL_NO_AUXILIARY_STATE: UInt32 = 8192
DEBUG_FORMAT_USER_SMALL_FULL_AUXILIARY_STATE: UInt32 = 16384
DEBUG_FORMAT_USER_SMALL_MODULE_HEADERS: UInt32 = 32768
DEBUG_FORMAT_USER_SMALL_FILTER_TRIAGE: UInt32 = 65536
DEBUG_FORMAT_USER_SMALL_ADD_AVX_XSTATE_CONTEXT: UInt32 = 131072
DEBUG_FORMAT_USER_SMALL_IPT_TRACE: UInt32 = 262144
DEBUG_FORMAT_USER_SMALL_IGNORE_INACCESSIBLE_MEM: UInt32 = 134217728
DEBUG_FORMAT_USER_SMALL_SCAN_PARTIAL_PAGES: UInt32 = 268435456
DEBUG_DUMP_FILE_BASE: UInt32 = 4294967295
DEBUG_DUMP_FILE_PAGE_FILE_DUMP: UInt32 = 0
DEBUG_DUMP_FILE_LOAD_FAILED_INDEX: UInt32 = 4294967295
DEBUG_DUMP_FILE_ORIGINAL_CAB_INDEX: UInt32 = 4294967294
DEBUG_STATUS_NO_CHANGE: UInt32 = 0
DEBUG_STATUS_GO: UInt32 = 1
DEBUG_STATUS_GO_HANDLED: UInt32 = 2
DEBUG_STATUS_GO_NOT_HANDLED: UInt32 = 3
DEBUG_STATUS_STEP_OVER: UInt32 = 4
DEBUG_STATUS_STEP_INTO: UInt32 = 5
DEBUG_STATUS_BREAK: UInt32 = 6
DEBUG_STATUS_NO_DEBUGGEE: UInt32 = 7
DEBUG_STATUS_STEP_BRANCH: UInt32 = 8
DEBUG_STATUS_IGNORE_EVENT: UInt32 = 9
DEBUG_STATUS_RESTART_REQUESTED: UInt32 = 10
DEBUG_STATUS_REVERSE_GO: UInt32 = 11
DEBUG_STATUS_REVERSE_STEP_BRANCH: UInt32 = 12
DEBUG_STATUS_REVERSE_STEP_OVER: UInt32 = 13
DEBUG_STATUS_REVERSE_STEP_INTO: UInt32 = 14
DEBUG_STATUS_OUT_OF_SYNC: UInt32 = 15
DEBUG_STATUS_WAIT_INPUT: UInt32 = 16
DEBUG_STATUS_TIMEOUT: UInt32 = 17
DEBUG_STATUS_MASK: UInt32 = 31
DEBUG_STATUS_INSIDE_WAIT: UInt64 = 4294967296
DEBUG_STATUS_WAIT_TIMEOUT: UInt64 = 8589934592
DEBUG_OUTCTL_THIS_CLIENT: UInt32 = 0
DEBUG_OUTCTL_ALL_CLIENTS: UInt32 = 1
DEBUG_OUTCTL_ALL_OTHER_CLIENTS: UInt32 = 2
DEBUG_OUTCTL_IGNORE: UInt32 = 3
DEBUG_OUTCTL_LOG_ONLY: UInt32 = 4
DEBUG_OUTCTL_SEND_MASK: UInt32 = 7
DEBUG_OUTCTL_NOT_LOGGED: UInt32 = 8
DEBUG_OUTCTL_OVERRIDE_MASK: UInt32 = 16
DEBUG_OUTCTL_DML: UInt32 = 32
DEBUG_OUTCTL_AMBIENT_DML: UInt32 = 4294967294
DEBUG_OUTCTL_AMBIENT_TEXT: UInt32 = 4294967295
DEBUG_OUTCTL_AMBIENT: UInt32 = 4294967295
DEBUG_INTERRUPT_ACTIVE: UInt32 = 0
DEBUG_INTERRUPT_PASSIVE: UInt32 = 1
DEBUG_INTERRUPT_EXIT: UInt32 = 2
DEBUG_CURRENT_DEFAULT: UInt32 = 15
DEBUG_CURRENT_SYMBOL: UInt32 = 1
DEBUG_CURRENT_DISASM: UInt32 = 2
DEBUG_CURRENT_REGISTERS: UInt32 = 4
DEBUG_CURRENT_SOURCE_LINE: UInt32 = 8
DEBUG_DISASM_EFFECTIVE_ADDRESS: UInt32 = 1
DEBUG_DISASM_MATCHING_SYMBOLS: UInt32 = 2
DEBUG_DISASM_SOURCE_LINE_NUMBER: UInt32 = 4
DEBUG_DISASM_SOURCE_FILE_NAME: UInt32 = 8
DEBUG_LEVEL_SOURCE: UInt32 = 0
DEBUG_LEVEL_ASSEMBLY: UInt32 = 1
DEBUG_ENGOPT_IGNORE_DBGHELP_VERSION: UInt32 = 1
DEBUG_ENGOPT_IGNORE_EXTENSION_VERSIONS: UInt32 = 2
DEBUG_ENGOPT_ALLOW_NETWORK_PATHS: UInt32 = 4
DEBUG_ENGOPT_DISALLOW_NETWORK_PATHS: UInt32 = 8
DEBUG_ENGOPT_IGNORE_LOADER_EXCEPTIONS: UInt32 = 16
DEBUG_ENGOPT_INITIAL_BREAK: UInt32 = 32
DEBUG_ENGOPT_INITIAL_MODULE_BREAK: UInt32 = 64
DEBUG_ENGOPT_FINAL_BREAK: UInt32 = 128
DEBUG_ENGOPT_NO_EXECUTE_REPEAT: UInt32 = 256
DEBUG_ENGOPT_FAIL_INCOMPLETE_INFORMATION: UInt32 = 512
DEBUG_ENGOPT_ALLOW_READ_ONLY_BREAKPOINTS: UInt32 = 1024
DEBUG_ENGOPT_SYNCHRONIZE_BREAKPOINTS: UInt32 = 2048
DEBUG_ENGOPT_DISALLOW_SHELL_COMMANDS: UInt32 = 4096
DEBUG_ENGOPT_KD_QUIET_MODE: UInt32 = 8192
DEBUG_ENGOPT_DISABLE_MANAGED_SUPPORT: UInt32 = 16384
DEBUG_ENGOPT_DISABLE_MODULE_SYMBOL_LOAD: UInt32 = 32768
DEBUG_ENGOPT_DISABLE_EXECUTION_COMMANDS: UInt32 = 65536
DEBUG_ENGOPT_DISALLOW_IMAGE_FILE_MAPPING: UInt32 = 131072
DEBUG_ENGOPT_PREFER_DML: UInt32 = 262144
DEBUG_ENGOPT_DISABLESQM: UInt32 = 524288
DEBUG_ENGOPT_DISABLE_STEPLINES_OPTIONS: UInt32 = 2097152
DEBUG_ENGOPT_DEBUGGING_SENSITIVE_DATA: UInt32 = 4194304
DEBUG_ENGOPT_PREFER_TRACE_FILES: UInt32 = 8388608
DEBUG_ENGOPT_RESOLVE_SHADOWED_VARIABLES: UInt32 = 16777216
DEBUG_ENGOPT_ALL: UInt32 = 32505855
DEBUG_ANY_ID: UInt32 = 4294967295
DBG_FRAME_DEFAULT: UInt32 = 0
DBG_FRAME_IGNORE_INLINE: UInt32 = 4294967295
STACK_FRAME_TYPE_INIT: UInt32 = 0
STACK_FRAME_TYPE_STACK: UInt32 = 1
STACK_FRAME_TYPE_INLINE: UInt32 = 2
STACK_FRAME_TYPE_RA: UInt32 = 128
STACK_FRAME_TYPE_IGNORE: UInt32 = 255
DEBUG_STACK_ARGUMENTS: UInt32 = 1
DEBUG_STACK_FUNCTION_INFO: UInt32 = 2
DEBUG_STACK_SOURCE_LINE: UInt32 = 4
DEBUG_STACK_FRAME_ADDRESSES: UInt32 = 8
DEBUG_STACK_COLUMN_NAMES: UInt32 = 16
DEBUG_STACK_NONVOLATILE_REGISTERS: UInt32 = 32
DEBUG_STACK_FRAME_NUMBERS: UInt32 = 64
DEBUG_STACK_PARAMETERS: UInt32 = 128
DEBUG_STACK_FRAME_ADDRESSES_RA_ONLY: UInt32 = 256
DEBUG_STACK_FRAME_MEMORY_USAGE: UInt32 = 512
DEBUG_STACK_PARAMETERS_NEWLINE: UInt32 = 1024
DEBUG_STACK_DML: UInt32 = 2048
DEBUG_STACK_FRAME_OFFSETS: UInt32 = 4096
DEBUG_STACK_PROVIDER: UInt32 = 8192
DEBUG_STACK_FRAME_ARCH: UInt32 = 16384
DEBUG_CLASS_UNINITIALIZED: UInt32 = 0
DEBUG_CLASS_KERNEL: UInt32 = 1
DEBUG_CLASS_USER_WINDOWS: UInt32 = 2
DEBUG_CLASS_IMAGE_FILE: UInt32 = 3
DEBUG_DUMP_SMALL: UInt32 = 1024
DEBUG_DUMP_DEFAULT: UInt32 = 1025
DEBUG_DUMP_FULL: UInt32 = 1026
DEBUG_DUMP_IMAGE_FILE: UInt32 = 1027
DEBUG_DUMP_TRACE_LOG: UInt32 = 1028
DEBUG_DUMP_WINDOWS_CE: UInt32 = 1029
DEBUG_DUMP_ACTIVE: UInt32 = 1030
DEBUG_KERNEL_CONNECTION: UInt32 = 0
DEBUG_KERNEL_LOCAL: UInt32 = 1
DEBUG_KERNEL_EXDI_DRIVER: UInt32 = 2
DEBUG_KERNEL_IDNA: UInt32 = 3
DEBUG_KERNEL_INSTALL_DRIVER: UInt32 = 4
DEBUG_KERNEL_REPT: UInt32 = 5
DEBUG_KERNEL_SMALL_DUMP: UInt32 = 1024
DEBUG_KERNEL_DUMP: UInt32 = 1025
DEBUG_KERNEL_ACTIVE_DUMP: UInt32 = 1030
DEBUG_KERNEL_FULL_DUMP: UInt32 = 1026
DEBUG_KERNEL_TRACE_LOG: UInt32 = 1028
DEBUG_USER_WINDOWS_PROCESS: UInt32 = 0
DEBUG_USER_WINDOWS_PROCESS_SERVER: UInt32 = 1
DEBUG_USER_WINDOWS_IDNA: UInt32 = 2
DEBUG_USER_WINDOWS_REPT: UInt32 = 3
DEBUG_USER_WINDOWS_SMALL_DUMP: UInt32 = 1024
DEBUG_USER_WINDOWS_DUMP: UInt32 = 1025
DEBUG_USER_WINDOWS_DUMP_WINDOWS_CE: UInt32 = 1029
DEBUG_EXTENSION_AT_ENGINE: UInt32 = 0
DEBUG_EXECUTE_DEFAULT: UInt32 = 0
DEBUG_EXECUTE_ECHO: UInt32 = 1
DEBUG_EXECUTE_NOT_LOGGED: UInt32 = 2
DEBUG_EXECUTE_NO_REPEAT: UInt32 = 4
DEBUG_EXECUTE_USER_TYPED: UInt32 = 8
DEBUG_EXECUTE_USER_CLICKED: UInt32 = 16
DEBUG_EXECUTE_EXTENSION: UInt32 = 32
DEBUG_EXECUTE_INTERNAL: UInt32 = 64
DEBUG_EXECUTE_SCRIPT: UInt32 = 128
DEBUG_EXECUTE_TOOLBAR: UInt32 = 256
DEBUG_EXECUTE_MENU: UInt32 = 512
DEBUG_EXECUTE_HOTKEY: UInt32 = 1024
DEBUG_EXECUTE_EVENT: UInt32 = 2048
DEBUG_FILTER_CREATE_THREAD: UInt32 = 0
DEBUG_FILTER_EXIT_THREAD: UInt32 = 1
DEBUG_FILTER_CREATE_PROCESS: UInt32 = 2
DEBUG_FILTER_EXIT_PROCESS: UInt32 = 3
DEBUG_FILTER_LOAD_MODULE: UInt32 = 4
DEBUG_FILTER_UNLOAD_MODULE: UInt32 = 5
DEBUG_FILTER_SYSTEM_ERROR: UInt32 = 6
DEBUG_FILTER_INITIAL_BREAKPOINT: UInt32 = 7
DEBUG_FILTER_INITIAL_MODULE_LOAD: UInt32 = 8
DEBUG_FILTER_DEBUGGEE_OUTPUT: UInt32 = 9
DEBUG_FILTER_BREAK: UInt32 = 0
DEBUG_FILTER_SECOND_CHANCE_BREAK: UInt32 = 1
DEBUG_FILTER_OUTPUT: UInt32 = 2
DEBUG_FILTER_IGNORE: UInt32 = 3
DEBUG_FILTER_REMOVE: UInt32 = 4
DEBUG_FILTER_GO_HANDLED: UInt32 = 0
DEBUG_FILTER_GO_NOT_HANDLED: UInt32 = 1
DEBUG_WAIT_DEFAULT: UInt32 = 0
DEBUG_VALUE_INVALID: UInt32 = 0
DEBUG_VALUE_INT8: UInt32 = 1
DEBUG_VALUE_INT16: UInt32 = 2
DEBUG_VALUE_INT32: UInt32 = 3
DEBUG_VALUE_INT64: UInt32 = 4
DEBUG_VALUE_FLOAT32: UInt32 = 5
DEBUG_VALUE_FLOAT64: UInt32 = 6
DEBUG_VALUE_FLOAT80: UInt32 = 7
DEBUG_VALUE_FLOAT82: UInt32 = 8
DEBUG_VALUE_FLOAT128: UInt32 = 9
DEBUG_VALUE_VECTOR64: UInt32 = 10
DEBUG_VALUE_VECTOR128: UInt32 = 11
DEBUG_VALUE_TYPES: UInt32 = 12
DEBUG_OUT_TEXT_REPL_DEFAULT: UInt32 = 0
DEBUG_ASMOPT_DEFAULT: UInt32 = 0
DEBUG_ASMOPT_VERBOSE: UInt32 = 1
DEBUG_ASMOPT_NO_CODE_BYTES: UInt32 = 2
DEBUG_ASMOPT_IGNORE_OUTPUT_WIDTH: UInt32 = 4
DEBUG_ASMOPT_SOURCE_LINE_NUMBER: UInt32 = 8
DEBUG_EXPR_MASM: UInt32 = 0
DEBUG_EXPR_CPLUSPLUS: UInt32 = 1
DEBUG_EINDEX_NAME: UInt32 = 0
DEBUG_EINDEX_FROM_START: UInt32 = 0
DEBUG_EINDEX_FROM_END: UInt32 = 1
DEBUG_EINDEX_FROM_CURRENT: UInt32 = 2
DEBUG_LOG_DEFAULT: UInt32 = 0
DEBUG_LOG_APPEND: UInt32 = 1
DEBUG_LOG_UNICODE: UInt32 = 2
DEBUG_LOG_DML: UInt32 = 4
DEBUG_SYSVERSTR_SERVICE_PACK: UInt32 = 0
DEBUG_SYSVERSTR_BUILD: UInt32 = 1
DEBUG_MANAGED_DISABLED: UInt32 = 0
DEBUG_MANAGED_ALLOWED: UInt32 = 1
DEBUG_MANAGED_DLL_LOADED: UInt32 = 2
DEBUG_MANSTR_NONE: UInt32 = 0
DEBUG_MANSTR_LOADED_SUPPORT_DLL: UInt32 = 1
DEBUG_MANSTR_LOAD_STATUS: UInt32 = 2
DEBUG_MANRESET_DEFAULT: UInt32 = 0
DEBUG_MANRESET_LOAD_DLL: UInt32 = 1
DEBUG_EXEC_FLAGS_NONBLOCK: UInt32 = 1
DEBUG_DATA_SPACE_VIRTUAL: UInt32 = 0
DEBUG_DATA_SPACE_PHYSICAL: UInt32 = 1
DEBUG_DATA_SPACE_CONTROL: UInt32 = 2
DEBUG_DATA_SPACE_IO: UInt32 = 3
DEBUG_DATA_SPACE_MSR: UInt32 = 4
DEBUG_DATA_SPACE_BUS_DATA: UInt32 = 5
DEBUG_DATA_SPACE_DEBUGGER_DATA: UInt32 = 6
DEBUG_DATA_SPACE_COUNT: UInt32 = 7
DEBUG_DATA_KernBase: UInt32 = 24
DEBUG_DATA_BreakpointWithStatusAddr: UInt32 = 32
DEBUG_DATA_SavedContextAddr: UInt32 = 40
DEBUG_DATA_KiCallUserModeAddr: UInt32 = 56
DEBUG_DATA_KeUserCallbackDispatcherAddr: UInt32 = 64
DEBUG_DATA_PsLoadedModuleListAddr: UInt32 = 72
DEBUG_DATA_PsActiveProcessHeadAddr: UInt32 = 80
DEBUG_DATA_PspCidTableAddr: UInt32 = 88
DEBUG_DATA_ExpSystemResourcesListAddr: UInt32 = 96
DEBUG_DATA_ExpPagedPoolDescriptorAddr: UInt32 = 104
DEBUG_DATA_ExpNumberOfPagedPoolsAddr: UInt32 = 112
DEBUG_DATA_KeTimeIncrementAddr: UInt32 = 120
DEBUG_DATA_KeBugCheckCallbackListHeadAddr: UInt32 = 128
DEBUG_DATA_KiBugcheckDataAddr: UInt32 = 136
DEBUG_DATA_IopErrorLogListHeadAddr: UInt32 = 144
DEBUG_DATA_ObpRootDirectoryObjectAddr: UInt32 = 152
DEBUG_DATA_ObpTypeObjectTypeAddr: UInt32 = 160
DEBUG_DATA_MmSystemCacheStartAddr: UInt32 = 168
DEBUG_DATA_MmSystemCacheEndAddr: UInt32 = 176
DEBUG_DATA_MmSystemCacheWsAddr: UInt32 = 184
DEBUG_DATA_MmPfnDatabaseAddr: UInt32 = 192
DEBUG_DATA_MmSystemPtesStartAddr: UInt32 = 200
DEBUG_DATA_MmSystemPtesEndAddr: UInt32 = 208
DEBUG_DATA_MmSubsectionBaseAddr: UInt32 = 216
DEBUG_DATA_MmNumberOfPagingFilesAddr: UInt32 = 224
DEBUG_DATA_MmLowestPhysicalPageAddr: UInt32 = 232
DEBUG_DATA_MmHighestPhysicalPageAddr: UInt32 = 240
DEBUG_DATA_MmNumberOfPhysicalPagesAddr: UInt32 = 248
DEBUG_DATA_MmMaximumNonPagedPoolInBytesAddr: UInt32 = 256
DEBUG_DATA_MmNonPagedSystemStartAddr: UInt32 = 264
DEBUG_DATA_MmNonPagedPoolStartAddr: UInt32 = 272
DEBUG_DATA_MmNonPagedPoolEndAddr: UInt32 = 280
DEBUG_DATA_MmPagedPoolStartAddr: UInt32 = 288
DEBUG_DATA_MmPagedPoolEndAddr: UInt32 = 296
DEBUG_DATA_MmPagedPoolInformationAddr: UInt32 = 304
DEBUG_DATA_MmPageSize: UInt32 = 312
DEBUG_DATA_MmSizeOfPagedPoolInBytesAddr: UInt32 = 320
DEBUG_DATA_MmTotalCommitLimitAddr: UInt32 = 328
DEBUG_DATA_MmTotalCommittedPagesAddr: UInt32 = 336
DEBUG_DATA_MmSharedCommitAddr: UInt32 = 344
DEBUG_DATA_MmDriverCommitAddr: UInt32 = 352
DEBUG_DATA_MmProcessCommitAddr: UInt32 = 360
DEBUG_DATA_MmPagedPoolCommitAddr: UInt32 = 368
DEBUG_DATA_MmExtendedCommitAddr: UInt32 = 376
DEBUG_DATA_MmZeroedPageListHeadAddr: UInt32 = 384
DEBUG_DATA_MmFreePageListHeadAddr: UInt32 = 392
DEBUG_DATA_MmStandbyPageListHeadAddr: UInt32 = 400
DEBUG_DATA_MmModifiedPageListHeadAddr: UInt32 = 408
DEBUG_DATA_MmModifiedNoWritePageListHeadAddr: UInt32 = 416
DEBUG_DATA_MmAvailablePagesAddr: UInt32 = 424
DEBUG_DATA_MmResidentAvailablePagesAddr: UInt32 = 432
DEBUG_DATA_PoolTrackTableAddr: UInt32 = 440
DEBUG_DATA_NonPagedPoolDescriptorAddr: UInt32 = 448
DEBUG_DATA_MmHighestUserAddressAddr: UInt32 = 456
DEBUG_DATA_MmSystemRangeStartAddr: UInt32 = 464
DEBUG_DATA_MmUserProbeAddressAddr: UInt32 = 472
DEBUG_DATA_KdPrintCircularBufferAddr: UInt32 = 480
DEBUG_DATA_KdPrintCircularBufferEndAddr: UInt32 = 488
DEBUG_DATA_KdPrintWritePointerAddr: UInt32 = 496
DEBUG_DATA_KdPrintRolloverCountAddr: UInt32 = 504
DEBUG_DATA_MmLoadedUserImageListAddr: UInt32 = 512
DEBUG_DATA_NtBuildLabAddr: UInt32 = 520
DEBUG_DATA_KiNormalSystemCall: UInt32 = 528
DEBUG_DATA_KiProcessorBlockAddr: UInt32 = 536
DEBUG_DATA_MmUnloadedDriversAddr: UInt32 = 544
DEBUG_DATA_MmLastUnloadedDriverAddr: UInt32 = 552
DEBUG_DATA_MmTriageActionTakenAddr: UInt32 = 560
DEBUG_DATA_MmSpecialPoolTagAddr: UInt32 = 568
DEBUG_DATA_KernelVerifierAddr: UInt32 = 576
DEBUG_DATA_MmVerifierDataAddr: UInt32 = 584
DEBUG_DATA_MmAllocatedNonPagedPoolAddr: UInt32 = 592
DEBUG_DATA_MmPeakCommitmentAddr: UInt32 = 600
DEBUG_DATA_MmTotalCommitLimitMaximumAddr: UInt32 = 608
DEBUG_DATA_CmNtCSDVersionAddr: UInt32 = 616
DEBUG_DATA_MmPhysicalMemoryBlockAddr: UInt32 = 624
DEBUG_DATA_MmSessionBase: UInt32 = 632
DEBUG_DATA_MmSessionSize: UInt32 = 640
DEBUG_DATA_MmSystemParentTablePage: UInt32 = 648
DEBUG_DATA_MmVirtualTranslationBase: UInt32 = 656
DEBUG_DATA_OffsetKThreadNextProcessor: UInt32 = 664
DEBUG_DATA_OffsetKThreadTeb: UInt32 = 666
DEBUG_DATA_OffsetKThreadKernelStack: UInt32 = 668
DEBUG_DATA_OffsetKThreadInitialStack: UInt32 = 670
DEBUG_DATA_OffsetKThreadApcProcess: UInt32 = 672
DEBUG_DATA_OffsetKThreadState: UInt32 = 674
DEBUG_DATA_OffsetKThreadBStore: UInt32 = 676
DEBUG_DATA_OffsetKThreadBStoreLimit: UInt32 = 678
DEBUG_DATA_SizeEProcess: UInt32 = 680
DEBUG_DATA_OffsetEprocessPeb: UInt32 = 682
DEBUG_DATA_OffsetEprocessParentCID: UInt32 = 684
DEBUG_DATA_OffsetEprocessDirectoryTableBase: UInt32 = 686
DEBUG_DATA_SizePrcb: UInt32 = 688
DEBUG_DATA_OffsetPrcbDpcRoutine: UInt32 = 690
DEBUG_DATA_OffsetPrcbCurrentThread: UInt32 = 692
DEBUG_DATA_OffsetPrcbMhz: UInt32 = 694
DEBUG_DATA_OffsetPrcbCpuType: UInt32 = 696
DEBUG_DATA_OffsetPrcbVendorString: UInt32 = 698
DEBUG_DATA_OffsetPrcbProcessorState: UInt32 = 700
DEBUG_DATA_OffsetPrcbNumber: UInt32 = 702
DEBUG_DATA_SizeEThread: UInt32 = 704
DEBUG_DATA_KdPrintCircularBufferPtrAddr: UInt32 = 712
DEBUG_DATA_KdPrintBufferSizeAddr: UInt32 = 720
DEBUG_DATA_MmBadPagesDetected: UInt32 = 800
DEBUG_DATA_EtwpDebuggerData: UInt32 = 816
DEBUG_DATA_PteBase: UInt32 = 864
DEBUG_DATA_PaeEnabled: UInt32 = 100000
DEBUG_DATA_SharedUserData: UInt32 = 100008
DEBUG_DATA_ProductType: UInt32 = 100016
DEBUG_DATA_SuiteMask: UInt32 = 100024
DEBUG_DATA_DumpWriterStatus: UInt32 = 100032
DEBUG_DATA_DumpFormatVersion: UInt32 = 100040
DEBUG_DATA_DumpWriterVersion: UInt32 = 100048
DEBUG_DATA_DumpPowerState: UInt32 = 100056
DEBUG_DATA_DumpMmStorage: UInt32 = 100064
DEBUG_DATA_DumpAttributes: UInt32 = 100072
DEBUG_DATA_PagingLevels: UInt32 = 100080
DEBUG_DATA_KPCR_OFFSET: UInt32 = 0
DEBUG_DATA_KPRCB_OFFSET: UInt32 = 1
DEBUG_DATA_KTHREAD_OFFSET: UInt32 = 2
DEBUG_DATA_BASE_TRANSLATION_VIRTUAL_OFFSET: UInt32 = 3
DEBUG_DATA_PROCESSOR_IDENTIFICATION: UInt32 = 4
DEBUG_DATA_PROCESSOR_SPEED: UInt32 = 5
DEBUG_HANDLE_DATA_TYPE_BASIC: UInt32 = 0
DEBUG_HANDLE_DATA_TYPE_TYPE_NAME: UInt32 = 1
DEBUG_HANDLE_DATA_TYPE_OBJECT_NAME: UInt32 = 2
DEBUG_HANDLE_DATA_TYPE_HANDLE_COUNT: UInt32 = 3
DEBUG_HANDLE_DATA_TYPE_TYPE_NAME_WIDE: UInt32 = 4
DEBUG_HANDLE_DATA_TYPE_OBJECT_NAME_WIDE: UInt32 = 5
DEBUG_HANDLE_DATA_TYPE_MINI_THREAD_1: UInt32 = 6
DEBUG_HANDLE_DATA_TYPE_MINI_MUTANT_1: UInt32 = 7
DEBUG_HANDLE_DATA_TYPE_MINI_MUTANT_2: UInt32 = 8
DEBUG_HANDLE_DATA_TYPE_PER_HANDLE_OPERATIONS: UInt32 = 9
DEBUG_HANDLE_DATA_TYPE_ALL_HANDLE_OPERATIONS: UInt32 = 10
DEBUG_HANDLE_DATA_TYPE_MINI_PROCESS_1: UInt32 = 11
DEBUG_HANDLE_DATA_TYPE_MINI_PROCESS_2: UInt32 = 12
DEBUG_HANDLE_DATA_TYPE_MINI_EVENT_1: UInt32 = 13
DEBUG_HANDLE_DATA_TYPE_MINI_SECTION_1: UInt32 = 14
DEBUG_HANDLE_DATA_TYPE_MINI_SEMAPHORE_1: UInt32 = 15
DEBUG_OFFSINFO_VIRTUAL_SOURCE: UInt32 = 1
DEBUG_VSOURCE_INVALID: UInt32 = 0
DEBUG_VSOURCE_DEBUGGEE: UInt32 = 1
DEBUG_VSOURCE_MAPPED_IMAGE: UInt32 = 2
DEBUG_VSOURCE_DUMP_WITHOUT_MEMINFO: UInt32 = 3
DEBUG_VSEARCH_DEFAULT: UInt32 = 0
DEBUG_VSEARCH_WRITABLE_ONLY: UInt32 = 1
DEBUG_PHYSICAL_DEFAULT: UInt32 = 0
DEBUG_PHYSICAL_CACHED: UInt32 = 1
DEBUG_PHYSICAL_UNCACHED: UInt32 = 2
DEBUG_PHYSICAL_WRITE_COMBINED: UInt32 = 3
DEBUG_EVENT_BREAKPOINT: UInt32 = 1
DEBUG_EVENT_EXCEPTION: UInt32 = 2
DEBUG_EVENT_CREATE_THREAD: UInt32 = 4
DEBUG_EVENT_EXIT_THREAD: UInt32 = 8
DEBUG_EVENT_CREATE_PROCESS: UInt32 = 16
DEBUG_EVENT_EXIT_PROCESS: UInt32 = 32
DEBUG_EVENT_LOAD_MODULE: UInt32 = 64
DEBUG_EVENT_UNLOAD_MODULE: UInt32 = 128
DEBUG_EVENT_SYSTEM_ERROR: UInt32 = 256
DEBUG_EVENT_SESSION_STATUS: UInt32 = 512
DEBUG_EVENT_CHANGE_DEBUGGEE_STATE: UInt32 = 1024
DEBUG_EVENT_CHANGE_ENGINE_STATE: UInt32 = 2048
DEBUG_EVENT_CHANGE_SYMBOL_STATE: UInt32 = 4096
DEBUG_EVENT_SERVICE_EXCEPTION: UInt32 = 8192
DEBUG_SESSION_ACTIVE: UInt32 = 0
DEBUG_SESSION_END_SESSION_ACTIVE_TERMINATE: UInt32 = 1
DEBUG_SESSION_END_SESSION_ACTIVE_DETACH: UInt32 = 2
DEBUG_SESSION_END_SESSION_PASSIVE: UInt32 = 3
DEBUG_SESSION_END: UInt32 = 4
DEBUG_SESSION_REBOOT: UInt32 = 5
DEBUG_SESSION_HIBERNATE: UInt32 = 6
DEBUG_SESSION_FAILURE: UInt32 = 7
DEBUG_CDS_ALL: UInt32 = 4294967295
DEBUG_CDS_REGISTERS: UInt32 = 1
DEBUG_CDS_DATA: UInt32 = 2
DEBUG_CDS_REFRESH: UInt32 = 4
DEBUG_CDS_REFRESH_EVALUATE: UInt32 = 1
DEBUG_CDS_REFRESH_EXECUTE: UInt32 = 2
DEBUG_CDS_REFRESH_EXECUTECOMMANDFILE: UInt32 = 3
DEBUG_CDS_REFRESH_ADDBREAKPOINT: UInt32 = 4
DEBUG_CDS_REFRESH_REMOVEBREAKPOINT: UInt32 = 5
DEBUG_CDS_REFRESH_WRITEVIRTUAL: UInt32 = 6
DEBUG_CDS_REFRESH_WRITEVIRTUALUNCACHED: UInt32 = 7
DEBUG_CDS_REFRESH_WRITEPHYSICAL: UInt32 = 8
DEBUG_CDS_REFRESH_WRITEPHYSICAL2: UInt32 = 9
DEBUG_CDS_REFRESH_SETVALUE: UInt32 = 10
DEBUG_CDS_REFRESH_SETVALUE2: UInt32 = 11
DEBUG_CDS_REFRESH_SETSCOPE: UInt32 = 12
DEBUG_CDS_REFRESH_SETSCOPEFRAMEBYINDEX: UInt32 = 13
DEBUG_CDS_REFRESH_SETSCOPEFROMJITDEBUGINFO: UInt32 = 14
DEBUG_CDS_REFRESH_SETSCOPEFROMSTOREDEVENT: UInt32 = 15
DEBUG_CDS_REFRESH_INLINESTEP: UInt32 = 16
DEBUG_CDS_REFRESH_INLINESTEP_PSEUDO: UInt32 = 17
DEBUG_CES_ALL: UInt32 = 4294967295
DEBUG_CES_CURRENT_THREAD: UInt32 = 1
DEBUG_CES_EFFECTIVE_PROCESSOR: UInt32 = 2
DEBUG_CES_BREAKPOINTS: UInt32 = 4
DEBUG_CES_CODE_LEVEL: UInt32 = 8
DEBUG_CES_EXECUTION_STATUS: UInt32 = 16
DEBUG_CES_ENGINE_OPTIONS: UInt32 = 32
DEBUG_CES_LOG_FILE: UInt32 = 64
DEBUG_CES_RADIX: UInt32 = 128
DEBUG_CES_EVENT_FILTERS: UInt32 = 256
DEBUG_CES_PROCESS_OPTIONS: UInt32 = 512
DEBUG_CES_EXTENSIONS: UInt32 = 1024
DEBUG_CES_SYSTEMS: UInt32 = 2048
DEBUG_CES_ASSEMBLY_OPTIONS: UInt32 = 4096
DEBUG_CES_EXPRESSION_SYNTAX: UInt32 = 8192
DEBUG_CES_TEXT_REPLACEMENTS: UInt32 = 16384
DEBUG_CSS_ALL: UInt32 = 4294967295
DEBUG_CSS_LOADS: UInt32 = 1
DEBUG_CSS_UNLOADS: UInt32 = 2
DEBUG_CSS_SCOPE: UInt32 = 4
DEBUG_CSS_PATHS: UInt32 = 8
DEBUG_CSS_SYMBOL_OPTIONS: UInt32 = 16
DEBUG_CSS_TYPE_OPTIONS: UInt32 = 32
DEBUG_CSS_COLLAPSE_CHILDREN: UInt32 = 64
DEBUG_OUTCBI_EXPLICIT_FLUSH: UInt32 = 1
DEBUG_OUTCBI_TEXT: UInt32 = 2
DEBUG_OUTCBI_DML: UInt32 = 4
DEBUG_OUTCBI_ANY_FORMAT: UInt32 = 6
DEBUG_OUTCB_TEXT: UInt32 = 0
DEBUG_OUTCB_DML: UInt32 = 1
DEBUG_OUTCB_EXPLICIT_FLUSH: UInt32 = 2
DEBUG_OUTCBF_COMBINED_EXPLICIT_FLUSH: UInt32 = 1
DEBUG_OUTCBF_DML_HAS_TAGS: UInt32 = 2
DEBUG_OUTCBF_DML_HAS_SPECIAL_CHARACTERS: UInt32 = 4
DEBUG_REGISTERS_DEFAULT: UInt32 = 0
DEBUG_REGISTERS_INT32: UInt32 = 1
DEBUG_REGISTERS_INT64: UInt32 = 2
DEBUG_REGISTERS_FLOAT: UInt32 = 4
DEBUG_REGISTERS_ALL: UInt32 = 7
DEBUG_REGISTER_SUB_REGISTER: UInt32 = 1
DEBUG_REGSRC_DEBUGGEE: UInt32 = 0
DEBUG_REGSRC_EXPLICIT: UInt32 = 1
DEBUG_REGSRC_FRAME: UInt32 = 2
DEBUG_OUTPUT_SYMBOLS_DEFAULT: UInt32 = 0
DEBUG_OUTPUT_SYMBOLS_NO_NAMES: UInt32 = 1
DEBUG_OUTPUT_SYMBOLS_NO_OFFSETS: UInt32 = 2
DEBUG_OUTPUT_SYMBOLS_NO_VALUES: UInt32 = 4
DEBUG_OUTPUT_SYMBOLS_NO_TYPES: UInt32 = 16
DEBUG_OUTPUT_NAME_END: String = '**NAME**'
DEBUG_OUTPUT_OFFSET_END: String = '**OFF**'
DEBUG_OUTPUT_VALUE_END: String = '**VALUE**'
DEBUG_OUTPUT_TYPE_END: String = '**TYPE**'
DEBUG_OUTPUT_NAME_END_WIDE: String = '**NAME**'
DEBUG_OUTPUT_OFFSET_END_WIDE: String = '**OFF**'
DEBUG_OUTPUT_VALUE_END_WIDE: String = '**VALUE**'
DEBUG_OUTPUT_TYPE_END_WIDE: String = '**TYPE**'
DEBUG_OUTPUT_NAME_END_T: String = '**NAME**'
DEBUG_OUTPUT_OFFSET_END_T: String = '**OFF**'
DEBUG_OUTPUT_VALUE_END_T: String = '**VALUE**'
DEBUG_OUTPUT_TYPE_END_T: String = '**TYPE**'
DEBUG_SYMBOL_EXPANSION_LEVEL_MASK: UInt32 = 15
DEBUG_SYMBOL_EXPANDED: UInt32 = 16
DEBUG_SYMBOL_READ_ONLY: UInt32 = 32
DEBUG_SYMBOL_IS_ARRAY: UInt32 = 64
DEBUG_SYMBOL_IS_FLOAT: UInt32 = 128
DEBUG_SYMBOL_IS_ARGUMENT: UInt32 = 256
DEBUG_SYMBOL_IS_LOCAL: UInt32 = 512
DEBUG_SYMENT_IS_CODE: UInt32 = 1
DEBUG_SYMENT_IS_DATA: UInt32 = 2
DEBUG_SYMENT_IS_PARAMETER: UInt32 = 4
DEBUG_SYMENT_IS_LOCAL: UInt32 = 8
DEBUG_SYMENT_IS_MANAGED: UInt32 = 16
DEBUG_SYMENT_IS_SYNTHETIC: UInt32 = 32
DEBUG_MODULE_LOADED: UInt32 = 0
DEBUG_MODULE_UNLOADED: UInt32 = 1
DEBUG_MODULE_USER_MODE: UInt32 = 2
DEBUG_MODULE_EXE_MODULE: UInt32 = 4
DEBUG_MODULE_EXPLICIT: UInt32 = 8
DEBUG_MODULE_SECONDARY: UInt32 = 16
DEBUG_MODULE_SYNTHETIC: UInt32 = 32
DEBUG_MODULE_SYM_BAD_CHECKSUM: UInt32 = 65536
DEBUG_SYMTYPE_NONE: UInt32 = 0
DEBUG_SYMTYPE_COFF: UInt32 = 1
DEBUG_SYMTYPE_CODEVIEW: UInt32 = 2
DEBUG_SYMTYPE_PDB: UInt32 = 3
DEBUG_SYMTYPE_EXPORT: UInt32 = 4
DEBUG_SYMTYPE_DEFERRED: UInt32 = 5
DEBUG_SYMTYPE_SYM: UInt32 = 6
DEBUG_SYMTYPE_DIA: UInt32 = 7
DEBUG_SCOPE_GROUP_ARGUMENTS: UInt32 = 1
DEBUG_SCOPE_GROUP_LOCALS: UInt32 = 2
DEBUG_SCOPE_GROUP_ALL: UInt32 = 3
DEBUG_SCOPE_GROUP_BY_DATAMODEL: UInt32 = 4
DEBUG_OUTTYPE_DEFAULT: UInt32 = 0
DEBUG_OUTTYPE_NO_INDENT: UInt32 = 1
DEBUG_OUTTYPE_NO_OFFSET: UInt32 = 2
DEBUG_OUTTYPE_VERBOSE: UInt32 = 4
DEBUG_OUTTYPE_COMPACT_OUTPUT: UInt32 = 8
DEBUG_OUTTYPE_ADDRESS_OF_FIELD: UInt32 = 65536
DEBUG_OUTTYPE_ADDRESS_AT_END: UInt32 = 131072
DEBUG_OUTTYPE_BLOCK_RECURSE: UInt32 = 2097152
DEBUG_FIND_SOURCE_DEFAULT: UInt32 = 0
DEBUG_FIND_SOURCE_FULL_PATH: UInt32 = 1
DEBUG_FIND_SOURCE_BEST_MATCH: UInt32 = 2
DEBUG_FIND_SOURCE_NO_SRCSRV: UInt32 = 4
DEBUG_FIND_SOURCE_TOKEN_LOOKUP: UInt32 = 8
DEBUG_FIND_SOURCE_WITH_CHECKSUM: UInt32 = 16
DEBUG_FIND_SOURCE_WITH_CHECKSUM_STRICT: UInt32 = 32
MODULE_ORDERS_MASK: UInt32 = 4026531840
MODULE_ORDERS_LOADTIME: UInt32 = 268435456
MODULE_ORDERS_MODULENAME: UInt32 = 536870912
DEBUG_MODNAME_IMAGE: UInt32 = 0
DEBUG_MODNAME_MODULE: UInt32 = 1
DEBUG_MODNAME_LOADED_IMAGE: UInt32 = 2
DEBUG_MODNAME_SYMBOL_FILE: UInt32 = 3
DEBUG_MODNAME_MAPPED_IMAGE: UInt32 = 4
DEBUG_TYPEOPTS_UNICODE_DISPLAY: UInt32 = 1
DEBUG_TYPEOPTS_LONGSTATUS_DISPLAY: UInt32 = 2
DEBUG_TYPEOPTS_FORCERADIX_OUTPUT: UInt32 = 4
DEBUG_TYPEOPTS_MATCH_MAXSIZE: UInt32 = 8
DEBUG_GETMOD_DEFAULT: UInt32 = 0
DEBUG_GETMOD_NO_LOADED_MODULES: UInt32 = 1
DEBUG_GETMOD_NO_UNLOADED_MODULES: UInt32 = 2
DEBUG_ADDSYNTHMOD_DEFAULT: UInt32 = 0
DEBUG_ADDSYNTHMOD_ZEROBASE: UInt32 = 1
DEBUG_ADDSYNTHSYM_DEFAULT: UInt32 = 0
DEBUG_OUTSYM_DEFAULT: UInt32 = 0
DEBUG_OUTSYM_FORCE_OFFSET: UInt32 = 1
DEBUG_OUTSYM_SOURCE_LINE: UInt32 = 2
DEBUG_OUTSYM_ALLOW_DISPLACEMENT: UInt32 = 4
DEBUG_GETFNENT_DEFAULT: UInt32 = 0
DEBUG_GETFNENT_RAW_ENTRY_ONLY: UInt32 = 1
DEBUG_SOURCE_IS_STATEMENT: UInt32 = 1
DEBUG_GSEL_DEFAULT: UInt32 = 0
DEBUG_GSEL_NO_SYMBOL_LOADS: UInt32 = 1
DEBUG_GSEL_ALLOW_LOWER: UInt32 = 2
DEBUG_GSEL_ALLOW_HIGHER: UInt32 = 4
DEBUG_GSEL_NEAREST_ONLY: UInt32 = 8
DEBUG_GSEL_INLINE_CALLSITE: UInt32 = 16
DEBUG_FRAME_DEFAULT: UInt32 = 0
DEBUG_FRAME_IGNORE_INLINE: UInt32 = 1
DEBUG_COMMAND_EXCEPTION_ID: UInt32 = 3688893886
DEBUG_CMDEX_INVALID: UInt32 = 0
DEBUG_CMDEX_ADD_EVENT_STRING: UInt32 = 1
DEBUG_CMDEX_RESET_EVENT_STRINGS: UInt32 = 2
DEBUG_EXTINIT_HAS_COMMAND_HELP: UInt32 = 1
DEBUG_NOTIFY_SESSION_ACTIVE: UInt32 = 0
DEBUG_NOTIFY_SESSION_INACTIVE: UInt32 = 1
DEBUG_NOTIFY_SESSION_ACCESSIBLE: UInt32 = 2
DEBUG_NOTIFY_SESSION_INACCESSIBLE: UInt32 = 3
DEBUG_KNOWN_STRUCT_GET_NAMES: UInt32 = 1
DEBUG_KNOWN_STRUCT_GET_SINGLE_LINE_OUTPUT: UInt32 = 2
DEBUG_KNOWN_STRUCT_SUPPRESS_TYPE_NAME: UInt32 = 3
DEBUG_EXT_QVALUE_DEFAULT: UInt32 = 0
DEBUG_EXT_PVALUE_DEFAULT: UInt32 = 0
DEBUG_EXT_PVTYPE_IS_VALUE: UInt32 = 0
DEBUG_EXT_PVTYPE_IS_POINTER: UInt32 = 1
_EXTSAPI_VER_: UInt32 = 10
DUMP_HANDLE_FLAG_PRINT_OBJECT: UInt32 = 2
DUMP_HANDLE_FLAG_PRINT_FREE_ENTRY: UInt32 = 4
DUMP_HANDLE_FLAG_KERNEL_TABLE: UInt32 = 16
DUMP_HANDLE_FLAG_CID_TABLE: UInt32 = 32
KDEXTS_LOCK_CALLBACKROUTINE_DEFINED: UInt32 = 2
FAILURE_ANALYSIS_NO_DB_LOOKUP: UInt32 = 1
FAILURE_ANALYSIS_VERBOSE: UInt32 = 2
FAILURE_ANALYSIS_ASSUME_HANG: UInt32 = 4
FAILURE_ANALYSIS_IGNORE_BREAKIN: UInt32 = 8
FAILURE_ANALYSIS_SET_FAILURE_CONTEXT: UInt32 = 16
FAILURE_ANALYSIS_EXCEPTION_AS_HANG: UInt32 = 32
FAILURE_ANALYSIS_AUTOBUG_PROCESSING: UInt32 = 64
FAILURE_ANALYSIS_XML_OUTPUT: UInt32 = 128
FAILURE_ANALYSIS_CALLSTACK_XML: UInt32 = 256
FAILURE_ANALYSIS_REGISTRY_DATA: UInt32 = 512
FAILURE_ANALYSIS_WMI_QUERY_DATA: UInt32 = 1024
FAILURE_ANALYSIS_USER_ATTRIBUTES: UInt32 = 2048
FAILURE_ANALYSIS_MODULE_INFO_XML: UInt32 = 4096
FAILURE_ANALYSIS_NO_IMAGE_CORRUPTION: UInt32 = 8192
FAILURE_ANALYSIS_AUTOSET_SYMPATH: UInt32 = 16384
FAILURE_ANALYSIS_USER_ATTRIBUTES_ALL: UInt32 = 32768
FAILURE_ANALYSIS_USER_ATTRIBUTES_FRAMES: UInt32 = 65536
FAILURE_ANALYSIS_MULTI_TARGET: UInt32 = 131072
FAILURE_ANALYSIS_SHOW_SOURCE: UInt32 = 262144
FAILURE_ANALYSIS_SHOW_WCT_STACKS: UInt32 = 524288
FAILURE_ANALYSIS_CREATE_INSTANCE: UInt32 = 1048576
FAILURE_ANALYSIS_LIVE_DEBUG_HOLD_CHECK: UInt32 = 2097152
FAILURE_ANALYSIS_XML_FILE_OUTPUT: UInt32 = 4194304
FAILURE_ANALYSIS_XSD_VERIFY: UInt32 = 8388608
FAILURE_ANALYSIS_CALLSTACK_XML_FULL_SOURCE_INFO: UInt32 = 16777216
FAILURE_ANALYSIS_HEAP_CORRUPTION_BLAME_FUNCTION: UInt32 = 33554432
FAILURE_ANALYSIS_PERMIT_HEAP_ACCESS_VIOLATIONS: UInt32 = 67108864
FAILURE_ANALYSIS_XSLT_FILE_INPUT: UInt32 = 268435456
FAILURE_ANALYSIS_XSLT_FILE_OUTPUT: UInt32 = 536870912
CLSID_DebugFailureAnalysisBasic: Guid = Guid('{b74eed7f-1c7d-4c1b-959f-b96dd9175aa4}')
CLSID_DebugFailureAnalysisTarget: Guid = Guid('{ba9bfb05-ef75-4bbd-a745-a6b5529458b8}')
CLSID_DebugFailureAnalysisUser: Guid = Guid('{e60b0c93-cf49-4a32-8147-0362202dc56b}')
CLSID_DebugFailureAnalysisKernel: Guid = Guid('{ee433078-64af-4c33-ab2f-ecad7f2a002d}')
CLSID_DebugFailureAnalysisWinCE: Guid = Guid('{67d5e86f-f5e2-462a-9233-1bd616fcc7e8}')
CLSID_DebugFailureAnalysisXBox360: Guid = Guid('{901625bb-95f1-4318-ac80-9d733cee8c8b}')
CROSS_PLATFORM_MAXIMUM_PROCESSORS: UInt32 = 2048
MAX_STACK_IN_BYTES: UInt32 = 4096
TRIAGE_FOLLOWUP_FAIL: UInt32 = 0
TRIAGE_FOLLOWUP_IGNORE: UInt32 = 1
TRIAGE_FOLLOWUP_DEFAULT: UInt32 = 2
TRIAGE_FOLLOWUP_SUCCESS: UInt32 = 3
EXT_ANALYZER_FLAG_MOD: UInt32 = 1
EXT_ANALYZER_FLAG_ID: UInt32 = 2
EXTDLL_DATA_QUERY_BUILD_BINDIR: UInt32 = 1
EXTDLL_DATA_QUERY_BUILD_SYMDIR: UInt32 = 2
EXTDLL_DATA_QUERY_BUILD_WOW64SYMDIR: UInt32 = 3
EXTDLL_DATA_QUERY_BUILD_WOW64BINDIR: UInt32 = 4
EXTDLL_DATA_QUERY_BUILD_BINDIR_SYMSRV: UInt32 = 11
EXTDLL_DATA_QUERY_BUILD_SYMDIR_SYMSRV: UInt32 = 12
EXTDLL_DATA_QUERY_BUILD_WOW64SYMDIR_SYMSRV: UInt32 = 13
EXTDLL_DATA_QUERY_BUILD_WOW64BINDIR_SYMSRV: UInt32 = 14
EXT_API_VERSION_NUMBER: UInt32 = 5
EXT_API_VERSION_NUMBER32: UInt32 = 5
EXT_API_VERSION_NUMBER64: UInt32 = 6
IG_KD_CONTEXT: UInt32 = 1
IG_READ_CONTROL_SPACE: UInt32 = 2
IG_WRITE_CONTROL_SPACE: UInt32 = 3
IG_READ_IO_SPACE: UInt32 = 4
IG_WRITE_IO_SPACE: UInt32 = 5
IG_READ_PHYSICAL: UInt32 = 6
IG_WRITE_PHYSICAL: UInt32 = 7
IG_READ_IO_SPACE_EX: UInt32 = 8
IG_WRITE_IO_SPACE_EX: UInt32 = 9
IG_KSTACK_HELP: UInt32 = 10
IG_SET_THREAD: UInt32 = 11
IG_READ_MSR: UInt32 = 12
IG_WRITE_MSR: UInt32 = 13
IG_GET_DEBUGGER_DATA: UInt32 = 14
IG_GET_KERNEL_VERSION: UInt32 = 15
IG_RELOAD_SYMBOLS: UInt32 = 16
IG_GET_SET_SYMPATH: UInt32 = 17
IG_GET_EXCEPTION_RECORD: UInt32 = 18
IG_IS_PTR64: UInt32 = 19
IG_GET_BUS_DATA: UInt32 = 20
IG_SET_BUS_DATA: UInt32 = 21
IG_DUMP_SYMBOL_INFO: UInt32 = 22
IG_LOWMEM_CHECK: UInt32 = 23
IG_SEARCH_MEMORY: UInt32 = 24
IG_GET_CURRENT_THREAD: UInt32 = 25
IG_GET_CURRENT_PROCESS: UInt32 = 26
IG_GET_TYPE_SIZE: UInt32 = 27
IG_GET_CURRENT_PROCESS_HANDLE: UInt32 = 28
IG_GET_INPUT_LINE: UInt32 = 29
IG_GET_EXPRESSION_EX: UInt32 = 30
IG_TRANSLATE_VIRTUAL_TO_PHYSICAL: UInt32 = 31
IG_GET_CACHE_SIZE: UInt32 = 32
IG_READ_PHYSICAL_WITH_FLAGS: UInt32 = 33
IG_WRITE_PHYSICAL_WITH_FLAGS: UInt32 = 34
IG_POINTER_SEARCH_PHYSICAL: UInt32 = 35
IG_OBSOLETE_PLACEHOLDER_36: UInt32 = 36
IG_GET_THREAD_OS_INFO: UInt32 = 37
IG_GET_CLR_DATA_INTERFACE: UInt32 = 38
IG_MATCH_PATTERN_A: UInt32 = 39
IG_FIND_FILE: UInt32 = 40
IG_TYPED_DATA_OBSOLETE: UInt32 = 41
IG_QUERY_TARGET_INTERFACE: UInt32 = 42
IG_TYPED_DATA: UInt32 = 43
IG_DISASSEMBLE_BUFFER: UInt32 = 44
IG_GET_ANY_MODULE_IN_RANGE: UInt32 = 45
IG_VIRTUAL_TO_PHYSICAL: UInt32 = 46
IG_PHYSICAL_TO_VIRTUAL: UInt32 = 47
IG_GET_CONTEXT_EX: UInt32 = 48
IG_GET_TEB_ADDRESS: UInt32 = 128
IG_GET_PEB_ADDRESS: UInt32 = 129
PHYS_FLAG_DEFAULT: UInt32 = 0
PHYS_FLAG_CACHED: UInt32 = 1
PHYS_FLAG_UNCACHED: UInt32 = 2
PHYS_FLAG_WRITE_COMBINED: UInt32 = 3
PTR_SEARCH_PHYS_ALL_HITS: UInt32 = 1
PTR_SEARCH_PHYS_PTE: UInt32 = 2
PTR_SEARCH_PHYS_RANGE_CHECK_ONLY: UInt32 = 4
PTR_SEARCH_PHYS_SIZE_SHIFT: UInt32 = 3
PTR_SEARCH_NO_SYMBOL_CHECK: UInt32 = 2147483648
EXT_FIND_FILE_ALLOW_GIVEN_PATH: UInt32 = 1
DEBUG_TYPED_DATA_IS_IN_MEMORY: UInt32 = 1
DEBUG_TYPED_DATA_PHYSICAL_DEFAULT: UInt32 = 2
DEBUG_TYPED_DATA_PHYSICAL_CACHED: UInt32 = 4
DEBUG_TYPED_DATA_PHYSICAL_UNCACHED: UInt32 = 6
DEBUG_TYPED_DATA_PHYSICAL_WRITE_COMBINED: UInt32 = 8
DEBUG_TYPED_DATA_PHYSICAL_MEMORY: UInt32 = 14
EXT_TDF_PHYSICAL_DEFAULT: UInt32 = 2
EXT_TDF_PHYSICAL_CACHED: UInt32 = 4
EXT_TDF_PHYSICAL_UNCACHED: UInt32 = 6
EXT_TDF_PHYSICAL_WRITE_COMBINED: UInt32 = 8
EXT_TDF_PHYSICAL_MEMORY: UInt32 = 14
WDBGEXTS_ADDRESS_DEFAULT: UInt32 = 0
WDBGEXTS_ADDRESS_SEG16: UInt32 = 1
WDBGEXTS_ADDRESS_SEG32: UInt32 = 2
WDBGEXTS_ADDRESS_RESERVED0: UInt32 = 2147483648
DBGKD_VERS_FLAG_MP: UInt32 = 1
DBGKD_VERS_FLAG_DATA: UInt32 = 2
DBGKD_VERS_FLAG_PTR64: UInt32 = 4
DBGKD_VERS_FLAG_NOMM: UInt32 = 8
DBGKD_VERS_FLAG_HSS: UInt32 = 16
DBGKD_VERS_FLAG_PARTITIONS: UInt32 = 32
DBGKD_VERS_FLAG_HAL_IN_NTOS: UInt32 = 64
KD_SECONDARY_VERSION_DEFAULT: UInt32 = 0
KD_SECONDARY_VERSION_AMD64_OBSOLETE_CONTEXT_1: UInt32 = 0
KD_SECONDARY_VERSION_AMD64_OBSOLETE_CONTEXT_2: UInt32 = 1
KD_SECONDARY_VERSION_AMD64_CONTEXT: UInt32 = 2
CURRENT_KD_SECONDARY_VERSION: UInt32 = 2
DBG_DUMP_NO_INDENT: UInt32 = 1
DBG_DUMP_NO_OFFSET: UInt32 = 2
DBG_DUMP_VERBOSE: UInt32 = 4
DBG_DUMP_CALL_FOR_EACH: UInt32 = 8
DBG_DUMP_LIST: UInt32 = 32
DBG_DUMP_NO_PRINT: UInt32 = 64
DBG_DUMP_GET_SIZE_ONLY: UInt32 = 128
DBG_DUMP_COMPACT_OUT: UInt32 = 8192
DBG_DUMP_ARRAY: UInt32 = 32768
DBG_DUMP_ADDRESS_OF_FIELD: UInt32 = 65536
DBG_DUMP_ADDRESS_AT_END: UInt32 = 131072
DBG_DUMP_COPY_TYPE_DATA: UInt32 = 262144
DBG_DUMP_READ_PHYSICAL: UInt32 = 524288
DBG_DUMP_FUNCTION_FORMAT: UInt32 = 1048576
DBG_DUMP_BLOCK_RECURSE: UInt32 = 2097152
DBG_DUMP_MATCH_SIZE: UInt32 = 4194304
DBG_RETURN_TYPE: UInt32 = 0
DBG_RETURN_SUBTYPES: UInt32 = 0
DBG_RETURN_TYPE_VALUES: UInt32 = 0
DBG_DUMP_FIELD_CALL_BEFORE_PRINT: UInt32 = 1
DBG_DUMP_FIELD_NO_CALLBACK_REQ: UInt32 = 2
DBG_DUMP_FIELD_RECUR_ON_THIS: UInt32 = 4
DBG_DUMP_FIELD_FULL_NAME: UInt32 = 8
DBG_DUMP_FIELD_ARRAY: UInt32 = 16
DBG_DUMP_FIELD_COPY_FIELD_DATA: UInt32 = 32
DBG_DUMP_FIELD_RETURN_ADDRESS: UInt32 = 4096
DBG_DUMP_FIELD_SIZE_IN_BITS: UInt32 = 8192
DBG_DUMP_FIELD_NO_PRINT: UInt32 = 16384
DBG_DUMP_FIELD_DEFAULT_STRING: UInt32 = 65536
DBG_DUMP_FIELD_WCHAR_STRING: UInt32 = 131072
DBG_DUMP_FIELD_MULTI_STRING: UInt32 = 262144
DBG_DUMP_FIELD_GUID_STRING: UInt32 = 524288
DBG_DUMP_FIELD_UTF32_STRING: UInt32 = 1048576
MEMORY_READ_ERROR: UInt32 = 1
SYMBOL_TYPE_INDEX_NOT_FOUND: UInt32 = 2
SYMBOL_TYPE_INFO_NOT_FOUND: UInt32 = 3
FIELDS_DID_NOT_MATCH: UInt32 = 4
NULL_SYM_DUMP_PARAM: UInt32 = 5
NULL_FIELD_NAME: UInt32 = 6
INCORRECT_VERSION_INFO: UInt32 = 7
EXIT_ON_CONTROLC: UInt32 = 8
CANNOT_ALLOCATE_MEMORY: UInt32 = 9
INSUFFICIENT_SPACE_TO_COPY: UInt32 = 10
ADDRESS_TYPE_INDEX_NOT_FOUND: UInt32 = 11
UNAVAILABLE_ERROR: UInt32 = 12
DBGKD_SIMULATION_NONE: Int32 = 0
DBGKD_SIMULATION_EXDI: Int32 = 1
@winfunctype('dbgeng.dll')
def DebugConnect(RemoteOptions: win32more.Windows.Win32.Foundation.PSTR, InterfaceId: POINTER(Guid), Interface: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dbgeng.dll')
def DebugConnectWide(RemoteOptions: win32more.Windows.Win32.Foundation.PWSTR, InterfaceId: POINTER(Guid), Interface: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dbgeng.dll')
def DebugCreate(InterfaceId: POINTER(Guid), Interface: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dbgeng.dll')
def DebugCreateEx(InterfaceId: POINTER(Guid), DbgEngOptions: UInt32, Interface: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dbgmodel.dll')
def CreateDataModelManager(debugHost: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHost, manager: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelManager)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ArrayDimension(Structure):
    LowerBound: Int64
    Length: UInt64
    Stride: UInt64
class BUSDATA(Structure):
    BusDataType: UInt32
    BusNumber: UInt32
    SlotNumber: UInt32
    Buffer: VoidPtr
    Offset: UInt32
    Length: UInt32
class CKCL_DATA(Structure):
    NextLogEvent: VoidPtr
    TAnalyzeString: win32more.Windows.Win32.Foundation.PSTR
    TAnalyzeReturnType: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TANALYZE_RETURN
class CKCL_LISTHEAD(Structure):
    LogEventListHead: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.CKCL_DATA)
    Heap: win32more.Windows.Win32.Foundation.HANDLE
class CPU_INFO(Structure):
    Type: UInt32
    NumCPUs: UInt32
    CurrentProc: UInt32
    ProcInfo: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_PROCESSOR_IDENTIFICATION_ALL * 2048
    Mhz: UInt32
class CPU_INFO_v1(Structure):
    Type: UInt32
    NumCPUs: UInt32
    CurrentProc: UInt32
    ProcInfo: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_PROCESSOR_IDENTIFICATION_ALL * 32
    Mhz: UInt32
class CPU_INFO_v2(Structure):
    Type: UInt32
    NumCPUs: UInt32
    CurrentProc: UInt32
    ProcInfo: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_PROCESSOR_IDENTIFICATION_ALL * 1280
    Mhz: UInt32
CallingConventionKind = Int32
CallingConventionUnknown: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.CallingConventionKind = 0
CallingConventionCDecl: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.CallingConventionKind = 1
CallingConventionFastCall: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.CallingConventionKind = 2
CallingConventionStdCall: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.CallingConventionKind = 3
CallingConventionSysCall: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.CallingConventionKind = 4
CallingConventionThisCall: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.CallingConventionKind = 5
class DBGKD_DEBUG_DATA_HEADER32(Structure):
    List: win32more.Windows.Win32.System.Kernel.LIST_ENTRY32
    OwnerTag: UInt32
    Size: UInt32
class DBGKD_DEBUG_DATA_HEADER64(Structure):
    List: win32more.Windows.Win32.System.Kernel.LIST_ENTRY64
    OwnerTag: UInt32
    Size: UInt32
class DBGKD_GET_VERSION32(Structure):
    MajorVersion: UInt16
    MinorVersion: UInt16
    ProtocolVersion: UInt16
    Flags: UInt16
    KernBase: UInt32
    PsLoadedModuleList: UInt32
    MachineType: UInt16
    ThCallbackStack: UInt16
    NextCallback: UInt16
    FramePointer: UInt16
    KiCallUserMode: UInt32
    KeUserCallbackDispatcher: UInt32
    BreakpointWithStatus: UInt32
    DebuggerDataList: UInt32
class DBGKD_GET_VERSION64(Structure):
    MajorVersion: UInt16
    MinorVersion: UInt16
    ProtocolVersion: Byte
    KdSecondaryVersion: Byte
    Flags: UInt16
    MachineType: UInt16
    MaxPacketType: Byte
    MaxStateChange: Byte
    MaxManipulate: Byte
    Simulation: Byte
    Unused: UInt16 * 1
    KernBase: UInt64
    PsLoadedModuleList: UInt64
    DebuggerDataList: UInt64
DBGKD_MAJOR_TYPES = Int32
DBGKD_MAJOR_NT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DBGKD_MAJOR_TYPES = 0
DBGKD_MAJOR_XBOX: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DBGKD_MAJOR_TYPES = 1
DBGKD_MAJOR_BIG: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DBGKD_MAJOR_TYPES = 2
DBGKD_MAJOR_EXDI: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DBGKD_MAJOR_TYPES = 3
DBGKD_MAJOR_NTBD: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DBGKD_MAJOR_TYPES = 4
DBGKD_MAJOR_EFI: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DBGKD_MAJOR_TYPES = 5
DBGKD_MAJOR_TNT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DBGKD_MAJOR_TYPES = 6
DBGKD_MAJOR_SINGULARITY: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DBGKD_MAJOR_TYPES = 7
DBGKD_MAJOR_HYPERVISOR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DBGKD_MAJOR_TYPES = 8
DBGKD_MAJOR_MIDORI: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DBGKD_MAJOR_TYPES = 9
DBGKD_MAJOR_CE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DBGKD_MAJOR_TYPES = 10
DBGKD_MAJOR_COUNT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DBGKD_MAJOR_TYPES = 11
class DBG_THREAD_ATTRIBUTES(Structure):
    ThreadIndex: UInt32
    ProcessID: UInt64
    ThreadID: UInt64
    AttributeBits: UInt64
    BoolBits: UInt32
    BlockedOnPID: UInt64
    BlockedOnTID: UInt64
    CritSecAddress: UInt64
    Timeout_msec: UInt32
    StringData: win32more.Windows.Win32.Foundation.CHAR * 100
    SymName: win32more.Windows.Win32.Foundation.CHAR * 100
class DEBUG_ANALYSIS_PROCESSOR_INFO(Structure):
    SizeOfStruct: UInt32
    Model: UInt32
    Family: UInt32
    Stepping: UInt32
    Architecture: UInt32
    Revision: UInt32
    CurrentClockSpeed: UInt32
    CurrentVoltage: UInt32
    MaxClockSpeed: UInt32
    ProcessorType: UInt32
    DeviceID: win32more.Windows.Win32.Foundation.CHAR * 32
    Manufacturer: win32more.Windows.Win32.Foundation.CHAR * 64
    Name: win32more.Windows.Win32.Foundation.CHAR * 64
    Version: win32more.Windows.Win32.Foundation.CHAR * 64
    Description: win32more.Windows.Win32.Foundation.CHAR * 64
class DEBUG_BREAKPOINT_PARAMETERS(Structure):
    Offset: UInt64
    Id: UInt32
    BreakType: UInt32
    ProcType: UInt32
    Flags: UInt32
    DataSize: UInt32
    DataAccessType: UInt32
    PassCount: UInt32
    CurrentPassCount: UInt32
    MatchThread: UInt32
    CommandSize: UInt32
    OffsetExpressionSize: UInt32
class DEBUG_CACHED_SYMBOL_INFO(Structure):
    ModBase: UInt64
    Arg1: UInt64
    Arg2: UInt64
    Id: UInt32
    Arg3: UInt32
class DEBUG_CLIENT_CONTEXT(Structure):
    cbSize: UInt32
    eClient: UInt32
class DEBUG_CPU_MICROCODE_VERSION(Structure):
    SizeOfStruct: UInt32
    CachedSignature: Int64
    InitialSignature: Int64
    ProcessorModel: UInt32
    ProcessorFamily: UInt32
    ProcessorStepping: UInt32
    ProcessorArchRev: UInt32
class DEBUG_CPU_SPEED_INFO(Structure):
    SizeOfStruct: UInt32
    CurrentSpeed: UInt32
    RatedSpeed: UInt32
    NameString: Char * 256
class DEBUG_CREATE_PROCESS_OPTIONS(Structure):
    CreateFlags: UInt32
    EngCreateFlags: UInt32
    VerifierFlags: UInt32
    Reserved: UInt32
class DEBUG_DECODE_ERROR(Structure):
    SizeOfStruct: UInt32
    Code: UInt32
    TreatAsStatus: win32more.Windows.Win32.Foundation.BOOL
    Source: win32more.Windows.Win32.Foundation.CHAR * 64
    Message: win32more.Windows.Win32.Foundation.CHAR * 260
class DEBUG_DEVICE_OBJECT_INFO(Structure):
    SizeOfStruct: UInt32
    DevObjAddress: UInt64
    ReferenceCount: UInt32
    QBusy: win32more.Windows.Win32.Foundation.BOOL
    DriverObject: UInt64
    CurrentIrp: UInt64
    DevExtension: UInt64
    DevObjExtension: UInt64
class DEBUG_DRIVER_OBJECT_INFO(Structure):
    SizeOfStruct: UInt32
    DriverSize: UInt32
    DriverObjAddress: UInt64
    DriverStart: UInt64
    DriverExtension: UInt64
    DeviceObject: UInt64
    DriverName: _DriverName_e__Struct
    class _DriverName_e__Struct(Structure):
        Length: UInt16
        MaximumLength: UInt16
        Buffer: UInt64
class DEBUG_EVENT_CONTEXT(Structure):
    Size: UInt32
    ProcessEngineId: UInt32
    ThreadEngineId: UInt32
    FrameEngineId: UInt32
class DEBUG_EXCEPTION_FILTER_PARAMETERS(Structure):
    ExecutionOption: UInt32
    ContinueOption: UInt32
    TextSize: UInt32
    CommandSize: UInt32
    SecondCommandSize: UInt32
    ExceptionCode: UInt32
DEBUG_FAILURE_TYPE = Int32
DEBUG_FLR_UNKNOWN: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FAILURE_TYPE = 0
DEBUG_FLR_KERNEL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FAILURE_TYPE = 1
DEBUG_FLR_USER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FAILURE_TYPE = 2
DEBUG_FLR_PARAM_TYPE = Int32
DEBUG_FLR_INVALID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 0
DEBUG_FLR_RESERVED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1
DEBUG_FLR_DRIVER_OBJECT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2
DEBUG_FLR_DEVICE_OBJECT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 3
DEBUG_FLR_INVALID_PFN: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4
DEBUG_FLR_WORKER_ROUTINE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 5
DEBUG_FLR_WORK_ITEM: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 6
DEBUG_FLR_INVALID_DPC_FOUND: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 7
DEBUG_FLR_PROCESS_OBJECT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8
DEBUG_FLR_FAILED_INSTRUCTION_ADDRESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 9
DEBUG_FLR_LAST_CONTROL_TRANSFER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 10
DEBUG_FLR_ACPI_EXTENSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 11
DEBUG_FLR_ACPI_RESCONFLICT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12
DEBUG_FLR_ACPI_OBJECT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 13
DEBUG_FLR_READ_ADDRESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 14
DEBUG_FLR_WRITE_ADDRESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 15
DEBUG_FLR_CRITICAL_SECTION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16
DEBUG_FLR_BAD_HANDLE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 17
DEBUG_FLR_INVALID_HEAP_ADDRESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 18
DEBUG_FLR_CHKIMG_EXTENSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 19
DEBUG_FLR_USBPORT_OCADATA: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 20
DEBUG_FLR_WORK_QUEUE_ITEM: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 21
DEBUG_FLR_ERESOURCE_ADDRESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 22
DEBUG_FLR_PNP_TRIAGE_DATA_DEPRECATED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 23
DEBUG_FLR_HANDLE_VALUE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 24
DEBUG_FLR_WHEA_ERROR_RECORD: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 25
DEBUG_FLR_VERIFIER_FOUND_DEADLOCK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 26
DEBUG_FLR_PG_MISMATCH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 27
DEBUG_FLR_DEVICE_NODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 28
DEBUG_FLR_POWERREQUEST_ADDRESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 29
DEBUG_FLR_EXECUTE_ADDRESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 30
DEBUG_FLR_IRP_ADDRESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 256
DEBUG_FLR_IRP_MAJOR_FN: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 257
DEBUG_FLR_IRP_MINOR_FN: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 258
DEBUG_FLR_IRP_CANCEL_ROUTINE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 259
DEBUG_FLR_IOSB_ADDRESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 260
DEBUG_FLR_INVALID_USEREVENT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 261
DEBUG_FLR_VIDEO_TDR_CONTEXT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 262
DEBUG_FLR_VERIFIER_DRIVER_ENTRY: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 263
DEBUG_FLR_PNP_IRP_ADDRESS_DEPRECATED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 264
DEBUG_FLR_PREVIOUS_MODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 265
DEBUG_FLR_CURRENT_IRQL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 512
DEBUG_FLR_PREVIOUS_IRQL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 513
DEBUG_FLR_REQUESTED_IRQL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 514
DEBUG_FLR_ASSERT_DATA: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 768
DEBUG_FLR_ASSERT_FILE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 769
DEBUG_FLR_EXCEPTION_PARAMETER1: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 770
DEBUG_FLR_EXCEPTION_PARAMETER2: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 771
DEBUG_FLR_EXCEPTION_PARAMETER3: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 772
DEBUG_FLR_EXCEPTION_PARAMETER4: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 773
DEBUG_FLR_EXCEPTION_RECORD: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 774
DEBUG_FLR_IO_ERROR_CODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 775
DEBUG_FLR_EXCEPTION_STR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 776
DEBUG_FLR_EXCEPTION_DOESNOT_MATCH_CODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 777
DEBUG_FLR_ASSERT_INSTRUCTION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 778
DEBUG_FLR_POOL_ADDRESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1024
DEBUG_FLR_SPECIAL_POOL_CORRUPTION_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1025
DEBUG_FLR_CORRUPTING_POOL_ADDRESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1026
DEBUG_FLR_CORRUPTING_POOL_TAG: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1027
DEBUG_FLR_FREED_POOL_TAG: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1028
DEBUG_FLR_LEAKED_SESSION_POOL_TAG: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1029
DEBUG_FLR_INSTR_SESSION_POOL_TAG: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1030
DEBUG_FLR_CLIENT_DRIVER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1031
DEBUG_FLR_FILE_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1280
DEBUG_FLR_FILE_LINE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1281
DEBUG_FLR_BUGCHECK_STR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1536
DEBUG_FLR_BUGCHECK_SPECIFIER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1537
DEBUG_FLR_BUGCHECK_DESC: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1538
DEBUG_FLR_MANAGED_CODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1792
DEBUG_FLR_MANAGED_OBJECT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1793
DEBUG_FLR_MANAGED_EXCEPTION_OBJECT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1794
DEBUG_FLR_MANAGED_EXCEPTION_MESSAGE_deprecated: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1795
DEBUG_FLR_MANAGED_STACK_STRING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1796
DEBUG_FLR_MANAGED_BITNESS_MISMATCH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1797
DEBUG_FLR_MANAGED_OBJECT_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1798
DEBUG_FLR_MANAGED_EXCEPTION_CONTEXT_MESSAGE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1799
DEBUG_FLR_MANAGED_STACK_COMMAND: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1800
DEBUG_FLR_MANAGED_KERNEL_DEBUGGER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1801
DEBUG_FLR_MANAGED_HRESULT_STRING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1802
DEBUG_FLR_MANAGED_ENGINE_MODULE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1803
DEBUG_FLR_MANAGED_ANALYSIS_PROVIDER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1804
DEBUG_FLR_MANAGED_EXCEPTION_ADDRESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2048
DEBUG_FLR_MANAGED_EXCEPTION_HRESULT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2049
DEBUG_FLR_MANAGED_EXCEPTION_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2050
DEBUG_FLR_MANAGED_EXCEPTION_MESSAGE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2051
DEBUG_FLR_MANAGED_EXCEPTION_CALLSTACK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2052
DEBUG_FLR_MANAGED_EXCEPTION_INNER_ADDRESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2064
DEBUG_FLR_MANAGED_EXCEPTION_INNER_HRESULT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2065
DEBUG_FLR_MANAGED_EXCEPTION_INNER_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2066
DEBUG_FLR_MANAGED_EXCEPTION_INNER_MESSAGE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2067
DEBUG_FLR_MANAGED_EXCEPTION_INNER_CALLSTACK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2068
DEBUG_FLR_MANAGED_EXCEPTION_NESTED_ADDRESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2080
DEBUG_FLR_MANAGED_EXCEPTION_NESTED_HRESULT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2081
DEBUG_FLR_MANAGED_EXCEPTION_NESTED_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2082
DEBUG_FLR_MANAGED_EXCEPTION_NESTED_MESSAGE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2083
DEBUG_FLR_MANAGED_EXCEPTION_NESTED_CALLSTACK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2084
DEBUG_FLR_MANAGED_EXCEPTION_CMD: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2288
DEBUG_FLR_MANAGED_THREAD_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2304
DEBUG_FLR_MANAGED_THREAD_CMD_CALLSTACK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2544
DEBUG_FLR_MANAGED_THREAD_CMD_STACKOBJECTS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2545
DEBUG_FLR_DRIVER_VERIFIER_IO_VIOLATION_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4096
DEBUG_FLR_EXCEPTION_CODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4097
DEBUG_FLR_EXCEPTION_CODE_STR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4098
DEBUG_FLR_IOCONTROL_CODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4099
DEBUG_FLR_MM_INTERNAL_CODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4100
DEBUG_FLR_DRVPOWERSTATE_SUBCODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4101
DEBUG_FLR_STATUS_CODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4102
DEBUG_FLR_SYMBOL_STACK_INDEX: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4103
DEBUG_FLR_SYMBOL_ON_RAW_STACK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4104
DEBUG_FLR_SECURITY_COOKIES: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4105
DEBUG_FLR_THREADPOOL_WAITER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4106
DEBUG_FLR_TARGET_MODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4107
DEBUG_FLR_BUGCHECK_CODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4108
DEBUG_FLR_BADPAGES_DETECTED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4109
DEBUG_FLR_DPC_TIMEOUT_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4110
DEBUG_FLR_DPC_RUNTIME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4111
DEBUG_FLR_DPC_TIMELIMIT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4112
DEBUG_FLR_DUMP_FILE_ATTRIBUTES: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4113
DEBUG_FLR_PAGE_HASH_ERRORS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4114
DEBUG_FLR_BUGCHECK_P1: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4115
DEBUG_FLR_BUGCHECK_P2: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4116
DEBUG_FLR_BUGCHECK_P3: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4117
DEBUG_FLR_BUGCHECK_P4: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4118
DEBUG_FLR_CRITICAL_PROCESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4119
DEBUG_FLR_RESOURCE_CALL_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4352
DEBUG_FLR_RESOURCE_CALL_TYPE_STR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 4353
DEBUG_FLR_CORRUPT_MODULE_LIST: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8192
DEBUG_FLR_BAD_STACK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8193
DEBUG_FLR_ZEROED_STACK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8194
DEBUG_FLR_WRONG_SYMBOLS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8195
DEBUG_FLR_FOLLOWUP_DRIVER_ONLY: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8196
DEBUG_FLR_UNUSED001: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8197
DEBUG_FLR_CPU_OVERCLOCKED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8198
DEBUG_FLR_POSSIBLE_INVALID_CONTROL_TRANSFER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8199
DEBUG_FLR_POISONED_TB: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8200
DEBUG_FLR_UNKNOWN_MODULE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8201
DEBUG_FLR_ANALYZABLE_POOL_CORRUPTION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8202
DEBUG_FLR_SINGLE_BIT_ERROR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8203
DEBUG_FLR_TWO_BIT_ERROR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8204
DEBUG_FLR_INVALID_KERNEL_CONTEXT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8205
DEBUG_FLR_DISK_HARDWARE_ERROR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8206
DEBUG_FLR_SHOW_ERRORLOG: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8207
DEBUG_FLR_MANUAL_BREAKIN: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8208
DEBUG_FLR_HANG: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8209
DEBUG_FLR_BAD_MEMORY_REFERENCE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8210
DEBUG_FLR_BAD_OBJECT_REFERENCE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8211
DEBUG_FLR_APPKILL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8212
DEBUG_FLR_SINGLE_BIT_PFN_PAGE_ERROR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8213
DEBUG_FLR_HARDWARE_ERROR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8214
DEBUG_FLR_NO_IMAGE_IN_BUCKET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8215
DEBUG_FLR_NO_BUGCHECK_IN_BUCKET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8216
DEBUG_FLR_SKIP_STACK_ANALYSIS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8217
DEBUG_FLR_INVALID_OPCODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8218
DEBUG_FLR_ADD_PROCESS_IN_BUCKET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8219
DEBUG_FLR_RAISED_IRQL_USER_FAULT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8220
DEBUG_FLR_USE_DEFAULT_CONTEXT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8221
DEBUG_FLR_BOOST_FOLLOWUP_TO_SPECIFIC: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8222
DEBUG_FLR_SWITCH_PROCESS_CONTEXT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8223
DEBUG_FLR_VERIFIER_STOP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8224
DEBUG_FLR_USERBREAK_PEB_PAGEDOUT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8225
DEBUG_FLR_MOD_SPECIFIC_DATA_ONLY: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8226
DEBUG_FLR_OVERLAPPED_MODULE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8227
DEBUG_FLR_CPU_MICROCODE_ZERO_INTEL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8228
DEBUG_FLR_INTEL_CPU_BIOS_UPGRADE_NEEDED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8229
DEBUG_FLR_OVERLAPPED_UNLOADED_MODULE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8230
DEBUG_FLR_INVALID_USER_CONTEXT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8231
DEBUG_FLR_MILCORE_BREAK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8232
DEBUG_FLR_NO_IMAGE_TIMESTAMP_IN_BUCKET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8233
DEBUG_FLR_KERNEL_VERIFIER_ENABLED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8234
DEBUG_FLR_SKIP_CORRUPT_MODULE_DETECTION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8235
DEBUG_FLR_GSFAILURE_FALSE_POSITIVE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8236
DEBUG_FLR_IGNORE_LARGE_MODULE_CORRUPTION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8237
DEBUG_FLR_IGNORE_BUCKET_ID_OFFSET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8238
DEBUG_FLR_NO_ARCH_IN_BUCKET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8239
DEBUG_FLR_IGNORE_MODULE_HARDWARE_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8240
DEBUG_FLR_ARM_WRITE_AV_CAVEAT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8241
DEBUG_FLR_ON_DPC_STACK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8242
DEBUG_FLR_LIVE_KERNEL_DUMP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8243
DEBUG_FLR_COVERAGE_BUILD: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8244
DEBUG_FLR_POSSIBLE_STACK_OVERFLOW: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8245
DEBUG_FLR_WRONG_SYMBOLS_TIMESTAMP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8246
DEBUG_FLR_WRONG_SYMBOLS_SIZE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8247
DEBUG_FLR_MISSING_IMPORTANT_SYMBOL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8248
DEBUG_FLR_MISSING_CLR_SYMBOL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8249
DEBUG_FLR_TARGET_TIME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8250
DEBUG_FLR_LOW_SYSTEM_COMMIT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8251
DEBUG_FLR_LEGACY_PAGE_TABLE_ACCESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8252
DEBUG_FLR_HIGH_PROCESS_COMMIT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8253
DEBUG_FLR_HIGH_SERVICE_COMMIT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8254
DEBUG_FLR_HIGH_NONPAGED_POOL_USAGE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8255
DEBUG_FLR_HIGH_PAGED_POOL_USAGE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8256
DEBUG_FLR_HIGH_SHARED_COMMIT_USAGE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8257
DEBUG_FLR_APPS_NOT_TERMINATED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 8258
DEBUG_FLR_POOL_CORRUPTOR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12288
DEBUG_FLR_MEMORY_CORRUPTOR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12289
DEBUG_FLR_UNALIGNED_STACK_POINTER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12290
DEBUG_FLR_OS_VERSION_deprecated: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12291
DEBUG_FLR_BUGCHECKING_DRIVER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12292
DEBUG_FLR_SOLUTION_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12293
DEBUG_FLR_DEFAULT_SOLUTION_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12294
DEBUG_FLR_SOLUTION_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12295
DEBUG_FLR_RECURRING_STACK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12296
DEBUG_FLR_FAULTING_INSTR_CODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12297
DEBUG_FLR_SYSTEM_LOCALE_deprecated: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12298
DEBUG_FLR_CUSTOMER_CRASH_COUNT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12299
DEBUG_FLR_TRAP_FRAME_RECURSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12300
DEBUG_FLR_STACK_OVERFLOW: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12301
DEBUG_FLR_STACK_POINTER_ERROR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12302
DEBUG_FLR_STACK_POINTER_ONEBIT_ERROR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12303
DEBUG_FLR_STACK_POINTER_MISALIGNED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12304
DEBUG_FLR_INSTR_POINTER_MISALIGNED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12305
DEBUG_FLR_INSTR_POINTER_CLIFAULT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12306
DEBUG_FLR_REGISTRYTXT_STRESS_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12307
DEBUG_FLR_CORRUPT_SERVICE_TABLE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12308
DEBUG_FLR_LOP_STACKHASH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12309
DEBUG_FLR_GSFAILURE_FUNCTION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12310
DEBUG_FLR_GSFAILURE_MODULE_COOKIE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12311
DEBUG_FLR_GSFAILURE_FRAME_COOKIE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12312
DEBUG_FLR_GSFAILURE_FRAME_COOKIE_COMPLEMENT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12313
DEBUG_FLR_GSFAILURE_CORRUPTED_COOKIE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12314
DEBUG_FLR_GSFAILURE_CORRUPTED_EBP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12315
DEBUG_FLR_GSFAILURE_OVERRUN_LOCAL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12316
DEBUG_FLR_GSFAILURE_OVERRUN_LOCAL_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12317
DEBUG_FLR_GSFAILURE_CORRUPTED_EBPESP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12318
DEBUG_FLR_GSFAILURE_POSITIVELY_CORRUPTED_EBPESP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12319
DEBUG_FLR_GSFAILURE_MEMORY_READ_ERROR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12320
DEBUG_FLR_GSFAILURE_PROBABLY_NOT_USING_GS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12321
DEBUG_FLR_GSFAILURE_POSITIVE_BUFFER_OVERFLOW: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12322
DEBUG_FLR_GSFAILURE_ANALYSIS_TEXT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12323
DEBUG_FLR_GSFAILURE_OFF_BY_ONE_OVERRUN: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12324
DEBUG_FLR_GSFAILURE_RA_SMASHED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12325
DEBUG_FLR_GSFAILURE_NOT_UP2DATE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12326
DEBUG_FLR_GSFAILURE_UP2DATE_UNKNOWN: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12327
DEBUG_FLR_TRIAGER_OS_BUILD_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12328
DEBUG_FLR_CPU_MICROCODE_VERSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12329
DEBUG_FLR_CPU_COUNT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12330
DEBUG_FLR_CPU_SPEED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12331
DEBUG_FLR_CPU_VENDOR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12332
DEBUG_FLR_CPU_FAMILY: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12333
DEBUG_FLR_CPU_MODEL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12334
DEBUG_FLR_CPU_STEPPING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12335
DEBUG_FLR_INSTR_POINTER_ON_STACK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12336
DEBUG_FLR_INSTR_POINTER_ON_HEAP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12337
DEBUG_FLR_EVENT_CODE_DATA_MISMATCH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12338
DEBUG_FLR_PROCESSOR_INFO: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12339
DEBUG_FLR_INSTR_POINTER_IN_UNLOADED_MODULE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12340
DEBUG_FLR_MEMDIAG_LASTRUN_STATUS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12341
DEBUG_FLR_MEMDIAG_LASTRUN_TIME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12342
DEBUG_FLR_INSTR_POINTER_IN_FREE_BLOCK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12343
DEBUG_FLR_INSTR_POINTER_IN_RESERVED_BLOCK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12344
DEBUG_FLR_INSTR_POINTER_IN_VM_MAPPED_MODULE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12345
DEBUG_FLR_INSTR_POINTER_IN_MODULE_NOT_IN_LIST: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12346
DEBUG_FLR_INSTR_POINTER_NOT_IN_STREAM: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12347
DEBUG_FLR_MEMORY_CORRUPTION_SIGNATURE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12348
DEBUG_FLR_BUILDNAME_IN_BUCKET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12349
DEBUG_FLR_CANCELLATION_NOT_SUPPORTED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12350
DEBUG_FLR_DETOURED_IMAGE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12351
DEBUG_FLR_EXCEPTION_CONTEXT_RECURSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12352
DEBUG_FLR_DISKIO_READ_FAILURE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12353
DEBUG_FLR_DISKIO_WRITE_FAILURE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12354
DEBUG_FLR_GSFAILURE_MISSING_ESTABLISHER_FRAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12355
DEBUG_FLR_GSFAILURE_COOKIES_MATCH_EXH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12356
DEBUG_FLR_GSFAILURE_MANAGED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12357
DEBUG_FLR_MANAGED_FRAME_CHAIN_CORRUPTION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12358
DEBUG_FLR_GSFAILURE_MANAGED_THREADID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12359
DEBUG_FLR_GSFAILURE_MANAGED_FRAMEID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12360
DEBUG_FLR_STACKUSAGE_IMAGE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12361
DEBUG_FLR_STACKUSAGE_IMAGE_SIZE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12362
DEBUG_FLR_STACKUSAGE_FUNCTION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12363
DEBUG_FLR_STACKUSAGE_FUNCTION_SIZE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12364
DEBUG_FLR_STACKUSAGE_RECURSION_COUNT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12365
DEBUG_FLR_XBOX_SYSTEM_UPTIME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12366
DEBUG_FLR_XBOX_SYSTEM_CRASHTIME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12367
DEBUG_FLR_XBOX_LIVE_ENVIRONMENT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12368
DEBUG_FLR_LARGE_TICK_INCREMENT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12369
DEBUG_FLR_INSTR_POINTER_IN_PAGED_CODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12370
DEBUG_FLR_SERVICETABLE_MODIFIED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12371
DEBUG_FLR_ALUREON: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 12372
DEBUG_FLR_INTERNAL_RAID_BUG: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16384
DEBUG_FLR_INTERNAL_BUCKET_URL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16385
DEBUG_FLR_INTERNAL_SOLUTION_TEXT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16386
DEBUG_FLR_INTERNAL_BUCKET_HITCOUNT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16387
DEBUG_FLR_INTERNAL_RAID_BUG_DATABASE_STRING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16388
DEBUG_FLR_INTERNAL_BUCKET_CONTINUABLE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16389
DEBUG_FLR_INTERNAL_BUCKET_STATUS_TEXT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16390
DEBUG_FLR_WATSON_MODULE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16640
DEBUG_FLR_WATSON_MODULE_VERSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16641
DEBUG_FLR_WATSON_MODULE_OFFSET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16642
DEBUG_FLR_WATSON_PROCESS_VERSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16643
DEBUG_FLR_WATSON_IBUCKET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16644
DEBUG_FLR_WATSON_MODULE_TIMESTAMP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16645
DEBUG_FLR_WATSON_PROCESS_TIMESTAMP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16646
DEBUG_FLR_WATSON_GENERIC_EVENT_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16647
DEBUG_FLR_WATSON_GENERIC_BUCKETING_00: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16648
DEBUG_FLR_WATSON_GENERIC_BUCKETING_01: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16649
DEBUG_FLR_WATSON_GENERIC_BUCKETING_02: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16650
DEBUG_FLR_WATSON_GENERIC_BUCKETING_03: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16651
DEBUG_FLR_WATSON_GENERIC_BUCKETING_04: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16652
DEBUG_FLR_WATSON_GENERIC_BUCKETING_05: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16653
DEBUG_FLR_WATSON_GENERIC_BUCKETING_06: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16654
DEBUG_FLR_WATSON_GENERIC_BUCKETING_07: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16655
DEBUG_FLR_WATSON_GENERIC_BUCKETING_08: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16656
DEBUG_FLR_WATSON_GENERIC_BUCKETING_09: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16657
DEBUG_FLR_SYSXML_LOCALEID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16896
DEBUG_FLR_SYSXML_CHECKSUM: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16897
DEBUG_FLR_WQL_EVENT_COUNT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16898
DEBUG_FLR_WQL_EVENTLOG_INFO: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 16899
DEBUG_FLR_SYSINFO_SYSTEM_MANUFACTURER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 17152
DEBUG_FLR_SYSINFO_SYSTEM_PRODUCT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 17153
DEBUG_FLR_SYSINFO_SYSTEM_SKU: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 17154
DEBUG_FLR_SYSINFO_SYSTEM_VERSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 17155
DEBUG_FLR_SYSINFO_BASEBOARD_MANUFACTURER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 17156
DEBUG_FLR_SYSINFO_BASEBOARD_PRODUCT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 17157
DEBUG_FLR_SYSINFO_BASEBOARD_VERSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 17158
DEBUG_FLR_SYSINFO_BIOS_VENDOR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 17159
DEBUG_FLR_SYSINFO_BIOS_VERSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 17160
DEBUG_FLR_SYSINFO_BIOS_DATE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 17161
DEBUG_FLR_VIRTUAL_MACHINE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 17162
DEBUG_FLR_SERVICE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 20480
DEBUG_FLR_SERVICE_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 20481
DEBUG_FLR_SERVICE_GROUP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 20482
DEBUG_FLR_SERVICE_DISPLAYNAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 20483
DEBUG_FLR_SERVICE_DESCRIPTION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 20484
DEBUG_FLR_SERVICE_DEPENDONSERVICE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 20485
DEBUG_FLR_SERVICE_DEPENDONGROUP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 20486
DEBUG_FLR_SVCHOST: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 20736
DEBUG_FLR_SVCHOST_GROUP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 20737
DEBUG_FLR_SVCHOST_IMAGEPATH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 20738
DEBUG_FLR_SVCHOST_SERVICEDLL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 20739
DEBUG_FLR_SCM: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 20992
DEBUG_FLR_SCM_BLACKBOX: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 21232
DEBUG_FLR_SCM_BLACKBOX_ENTRY: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 21233
DEBUG_FLR_SCM_BLACKBOX_ENTRY_CONTROLCODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 21234
DEBUG_FLR_SCM_BLACKBOX_ENTRY_STARTTIME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 21235
DEBUG_FLR_SCM_BLACKBOX_ENTRY_SERVICENAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 21236
DEBUG_FLR_ACPI: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 24576
DEBUG_FLR_ACPI_BLACKBOX: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 24832
DEBUG_FLR_PO_BLACKBOX: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 24833
DEBUG_FLR_BOOTSTAT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 28672
DEBUG_FLR_BOOTSTAT_BLACKBOX: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 28928
DEBUG_FLR_STORAGE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 29696
DEBUG_FLR_STORAGE_ORGID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 29697
DEBUG_FLR_STORAGE_MODEL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 29698
DEBUG_FLR_STORAGE_MFGID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 29699
DEBUG_FLR_STORAGE_ISSUEDESCSTRING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 29700
DEBUG_FLR_STORAGE_PUBLIC_TOTSIZE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 29701
DEBUG_FLR_STORAGE_PUBLIC_OFFSET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 29702
DEBUG_FLR_STORAGE_PUBLIC_DATASIZE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 29703
DEBUG_FLR_STORAGE_PRIVATE_TOTSIZE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 29704
DEBUG_FLR_STORAGE_PRIVATE_OFFSET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 29705
DEBUG_FLR_STORAGE_PRIVATE_DATASIZE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 29706
DEBUG_FLR_STORAGE_TOTALSIZE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 29707
DEBUG_FLR_STORAGE_REASON: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 29708
DEBUG_FLR_STORAGE_BLACKBOX: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 29936
DEBUG_FLR_FILESYSTEMS_NTFS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 30208
DEBUG_FLR_FILESYSTEMS_NTFS_BLACKBOX: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 30448
DEBUG_FLR_FILESYSTEMS_REFS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 30720
DEBUG_FLR_FILESYSTEMS_REFS_BLACKBOX: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 30960
DEBUG_FLR_PNP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 32768
DEBUG_FLR_PNP_TRIAGE_DATA: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 32769
DEBUG_FLR_PNP_IRP_ADDRESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 32770
DEBUG_FLR_PNP_BLACKBOX: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 33024
DEBUG_FLR_BUCKET_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65536
DEBUG_FLR_IMAGE_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65537
DEBUG_FLR_SYMBOL_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65538
DEBUG_FLR_FOLLOWUP_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65539
DEBUG_FLR_STACK_COMMAND: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65540
DEBUG_FLR_STACK_TEXT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65541
DEBUG_FLR_MODULE_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65542
DEBUG_FLR_FIXED_IN_OSVERSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65543
DEBUG_FLR_DEFAULT_BUCKET_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65544
DEBUG_FLR_MODULE_BUCKET_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65545
DEBUG_FLR_ADDITIONAL_DEBUGTEXT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65546
DEBUG_FLR_PROCESS_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65547
DEBUG_FLR_USER_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65548
DEBUG_FLR_MARKER_FILE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65549
DEBUG_FLR_INTERNAL_RESPONSE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65550
DEBUG_FLR_CONTEXT_RESTORE_COMMAND: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65551
DEBUG_FLR_DRIVER_HARDWAREID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65552
DEBUG_FLR_DRIVER_HARDWARE_VENDOR_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65553
DEBUG_FLR_DRIVER_HARDWARE_DEVICE_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65554
DEBUG_FLR_DRIVER_HARDWARE_SUBSYS_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65555
DEBUG_FLR_DRIVER_HARDWARE_REV_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65556
DEBUG_FLR_DRIVER_HARDWARE_ID_BUS_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65557
DEBUG_FLR_MARKER_MODULE_FILE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65558
DEBUG_FLR_BUGCHECKING_DRIVER_IDTAG: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65559
DEBUG_FLR_MARKER_BUCKET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65560
DEBUG_FLR_FAILURE_BUCKET_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65561
DEBUG_FLR_DRIVER_XML_DESCRIPTION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65562
DEBUG_FLR_DRIVER_XML_PRODUCTNAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65563
DEBUG_FLR_DRIVER_XML_MANUFACTURER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65564
DEBUG_FLR_DRIVER_XML_VERSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65565
DEBUG_FLR_BUILD_VERSION_STRING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65566
DEBUG_FLR_BUILD_OS_FULL_VERSION_STRING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65567
DEBUG_FLR_ORIGINAL_CAB_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65568
DEBUG_FLR_FAULTING_SOURCE_CODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65569
DEBUG_FLR_FAULTING_SERVICE_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65570
DEBUG_FLR_FILE_IN_CAB: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65571
DEBUG_FLR_UNRESPONSIVE_UI_SYMBOL_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65572
DEBUG_FLR_UNRESPONSIVE_UI_FOLLOWUP_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65573
DEBUG_FLR_UNRESPONSIVE_UI_STACK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65574
DEBUG_FLR_PROCESS_PRODUCTNAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65575
DEBUG_FLR_MODULE_PRODUCTNAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65576
DEBUG_FLR_COLLECT_DATA_FOR_BUCKET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65577
DEBUG_FLR_COMPUTER_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65578
DEBUG_FLR_IMAGE_CLASS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65579
DEBUG_FLR_SYMBOL_ROUTINE_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65580
DEBUG_FLR_HARDWARE_BUCKET_TAG: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65581
DEBUG_FLR_KERNEL_LOG_PROCESS_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65582
DEBUG_FLR_KERNEL_LOG_STATUS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65583
DEBUG_FLR_REGISTRYTXT_SOURCE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65584
DEBUG_FLR_FAULTING_SOURCE_LINE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65585
DEBUG_FLR_FAULTING_SOURCE_FILE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65586
DEBUG_FLR_FAULTING_SOURCE_LINE_NUMBER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65587
DEBUG_FLR_SKIP_MODULE_SPECIFIC_BUCKET_INFO: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65588
DEBUG_FLR_BUCKET_ID_FUNC_OFFSET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65589
DEBUG_FLR_XHCI_FIRMWARE_VERSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65590
DEBUG_FLR_FAILURE_ANALYSIS_SOURCE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65591
DEBUG_FLR_FAILURE_ID_HASH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65592
DEBUG_FLR_FAILURE_ID_HASH_STRING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65593
DEBUG_FLR_FAILURE_ID_REPORT_LINK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65594
DEBUG_FLR_HOLDINFO: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65595
DEBUG_FLR_HOLDINFO_ACTIVE_HOLD_COUNT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65596
DEBUG_FLR_HOLDINFO_TENET_SOCRE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65597
DEBUG_FLR_HOLDINFO_HISTORIC_HOLD_COUNT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65598
DEBUG_FLR_HOLDINFO_ALWAYS_IGNORE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65599
DEBUG_FLR_HOLDINFO_ALWAYS_HOLD: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65600
DEBUG_FLR_HOLDINFO_MAX_HOLD_LIMIT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65601
DEBUG_FLR_HOLDINFO_MANUAL_HOLD: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65602
DEBUG_FLR_HOLDINFO_NOTIFICATION_ALIASES: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65603
DEBUG_FLR_HOLDINFO_LAST_SEEN_HOLD_DATE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65604
DEBUG_FLR_HOLDINFO_RECOMMEND_HOLD: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65605
DEBUG_FLR_FAILURE_PROBLEM_CLASS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65606
DEBUG_FLR_FAILURE_EXCEPTION_CODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65607
DEBUG_FLR_FAILURE_IMAGE_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65608
DEBUG_FLR_FAILURE_FUNCTION_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65609
DEBUG_FLR_FAILURE_SYMBOL_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65610
DEBUG_FLR_FOLLOWUP_BEFORE_RETRACER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65611
DEBUG_FLR_END_MESSAGE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65612
DEBUG_FLR_FEATURE_PATH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65613
DEBUG_FLR_USER_MODE_BUCKET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65614
DEBUG_FLR_USER_MODE_BUCKET_INDEX: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65615
DEBUG_FLR_USER_MODE_BUCKET_EVENTTYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65616
DEBUG_FLR_USER_MODE_BUCKET_REPORTGUID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65617
DEBUG_FLR_USER_MODE_BUCKET_REPORTCREATIONTIME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65618
DEBUG_FLR_USER_MODE_BUCKET_P0: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65619
DEBUG_FLR_USER_MODE_BUCKET_P1: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65620
DEBUG_FLR_USER_MODE_BUCKET_P2: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65621
DEBUG_FLR_USER_MODE_BUCKET_P3: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65622
DEBUG_FLR_USER_MODE_BUCKET_P4: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65623
DEBUG_FLR_USER_MODE_BUCKET_P5: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65624
DEBUG_FLR_USER_MODE_BUCKET_P6: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65625
DEBUG_FLR_USER_MODE_BUCKET_P7: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65626
DEBUG_FLR_USER_MODE_BUCKET_STRING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65627
DEBUG_FLR_CRITICAL_PROCESS_REPORTGUID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65628
DEBUG_FLR_FAILURE_MODULE_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65629
DEBUG_FLR_PLATFORM_BUCKET_STRING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65630
DEBUG_FLR_DRIVER_HARDWARE_VENDOR_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65631
DEBUG_FLR_DRIVER_HARDWARE_SUBVENDOR_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65632
DEBUG_FLR_DRIVER_HARDWARE_DEVICE_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65633
DEBUG_FLR_FAULTING_SOURCE_COMMIT_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65634
DEBUG_FLR_FAULTING_SOURCE_CONTROL_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65635
DEBUG_FLR_FAULTING_SOURCE_PROJECT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65636
DEBUG_FLR_FAULTING_SOURCE_REPO_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65637
DEBUG_FLR_FAULTING_SOURCE_REPO_URL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65638
DEBUG_FLR_FAULTING_SOURCE_SRV_COMMAND: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 65639
DEBUG_FLR_USERMODE_DATA: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048576
DEBUG_FLR_THREAD_ATTRIBUTES: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048577
DEBUG_FLR_PROBLEM_CLASSES: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048578
DEBUG_FLR_PRIMARY_PROBLEM_CLASS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048579
DEBUG_FLR_PRIMARY_PROBLEM_CLASS_DATA: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048580
DEBUG_FLR_UNRESPONSIVE_UI_PROBLEM_CLASS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048581
DEBUG_FLR_UNRESPONSIVE_UI_PROBLEM_CLASS_DATA: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048582
DEBUG_FLR_DERIVED_WAIT_CHAIN: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048583
DEBUG_FLR_HANG_DATA_NEEDED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048584
DEBUG_FLR_PROBLEM_CODE_PATH_HASH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048585
DEBUG_FLR_SUSPECT_CODE_PATH_HASH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048586
DEBUG_FLR_LOADERLOCK_IN_WAIT_CHAIN: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048587
DEBUG_FLR_XPROC_HANG: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048588
DEBUG_FLR_DEADLOCK_INPROC: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048589
DEBUG_FLR_DEADLOCK_XPROC: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048590
DEBUG_FLR_WCT_XML_AVAILABLE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048591
DEBUG_FLR_XPROC_DUMP_AVAILABLE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048592
DEBUG_FLR_DESKTOP_HEAP_MISSING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048593
DEBUG_FLR_HANG_REPORT_THREAD_IS_IDLE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048594
DEBUG_FLR_FAULT_THREAD_SHA1_HASH_MF: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048595
DEBUG_FLR_FAULT_THREAD_SHA1_HASH_MFO: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048596
DEBUG_FLR_FAULT_THREAD_SHA1_HASH_M: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048597
DEBUG_FLR_WAIT_CHAIN_COMMAND: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048598
DEBUG_FLR_NTGLOBALFLAG: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048599
DEBUG_FLR_APPVERIFERFLAGS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048600
DEBUG_FLR_MODLIST_SHA1_HASH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048601
DEBUG_FLR_DUMP_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048602
DEBUG_FLR_XCS_PATH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048603
DEBUG_FLR_LOADERLOCK_OWNER_API: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048604
DEBUG_FLR_LOADERLOCK_BLOCKED_API: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048605
DEBUG_FLR_MODLIST_TSCHKSUM_SHA1_HASH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048606
DEBUG_FLR_MODLIST_UNLOADED_SHA1_HASH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048607
DEBUG_FLR_MACHINE_INFO_SHA1_HASH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048608
DEBUG_FLR_URLS_DISCOVERED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048609
DEBUG_FLR_URLS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048610
DEBUG_FLR_URL_ENTRY: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048611
DEBUG_FLR_WATSON_IBUCKET_S1_RESP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048612
DEBUG_FLR_WATSON_IBUCKETTABLE_S1_RESP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048613
DEBUG_FLR_SEARCH_HANG: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048614
DEBUG_FLR_WER_DATA_COLLECTION_INFO: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048615
DEBUG_FLR_WER_MACHINE_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048616
DEBUG_FLR_ULS_SCRIPT_EXCEPTION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048617
DEBUG_FLR_LCIE_ISO_AVAILABLE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048618
DEBUG_FLR_SHOW_LCIE_ISO_DATA: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048619
DEBUG_FLR_URL_LCIE_ENTRY: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048620
DEBUG_FLR_URL_URLMON_ENTRY: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048621
DEBUG_FLR_URL_XMLHTTPREQ_SYNC_ENTRY: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048622
DEBUG_FLR_FAULTING_LOCAL_VARIABLE_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048623
DEBUG_FLR_MODULE_LIST: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048624
DEBUG_FLR_DUMP_FLAGS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048625
DEBUG_FLR_APPLICATION_VERIFIER_LOADED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048626
DEBUG_FLR_DUMP_CLASS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048627
DEBUG_FLR_DUMP_QUALIFIER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048628
DEBUG_FLR_KM_MODULE_LIST: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1048629
DEBUG_FLR_EXCEPTION_CODE_STR_deprecated: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052672
DEBUG_FLR_BUCKET_ID_PREFIX_STR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052673
DEBUG_FLR_BUCKET_ID_MODULE_STR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052674
DEBUG_FLR_BUCKET_ID_MODVER_STR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052675
DEBUG_FLR_BUCKET_ID_FUNCTION_STR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052676
DEBUG_FLR_BUCKET_ID_OFFSET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052677
DEBUG_FLR_OS_BUILD: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052678
DEBUG_FLR_OS_SERVICEPACK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052679
DEBUG_FLR_OS_BRANCH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052680
DEBUG_FLR_OS_BUILD_TIMESTAMP_LAB: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052681
DEBUG_FLR_OS_VERSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052682
DEBUG_FLR_BUCKET_ID_TIMEDATESTAMP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052683
DEBUG_FLR_BUCKET_ID_CHECKSUM: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052684
DEBUG_FLR_OS_FLAVOR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052685
DEBUG_FLR_BUCKET_ID_FLAVOR_STR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052686
DEBUG_FLR_OS_SKU: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052687
DEBUG_FLR_OS_PRODUCT_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052688
DEBUG_FLR_OS_SUITE_MASK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052689
DEBUG_FLR_USER_LCID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052690
DEBUG_FLR_OS_REVISION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052691
DEBUG_FLR_OS_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052692
DEBUG_FLR_OS_NAME_EDITION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052693
DEBUG_FLR_OS_PLATFORM_ARCH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052694
DEBUG_FLR_OS_SERVICEPACK_deprecated: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052695
DEBUG_FLR_OS_LOCALE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052696
DEBUG_FLR_OS_BUILD_TIMESTAMP_ISO: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052697
DEBUG_FLR_USER_LCID_STR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052698
DEBUG_FLR_ANALYSIS_SESSION_TIME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052699
DEBUG_FLR_ANALYSIS_SESSION_HOST: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052700
DEBUG_FLR_ANALYSIS_SESSION_ELAPSED_TIME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052701
DEBUG_FLR_ANALYSIS_VERSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052702
DEBUG_FLR_BUCKET_ID_IMAGE_STR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052703
DEBUG_FLR_BUCKET_ID_PRIVATE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052704
DEBUG_FLR_ANALYSIS_REPROCESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052705
DEBUG_FLR_OS_MAJOR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052706
DEBUG_FLR_OS_MINOR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052707
DEBUG_FLR_OS_BUILD_STRING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052708
DEBUG_FLR_OS_LOCALE_LCID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052709
DEBUG_FLR_OS_PLATFORM_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052710
DEBUG_FLR_OS_BUILD_LAYERS_XML: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052711
DEBUG_FLR_OSBUILD_deprecated: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052928
DEBUG_FLR_BUILDOSVER_STR_deprecated: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1052929
DEBUG_FLR_DEBUG_ANALYSIS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1118208
DEBUG_FLR_KEYVALUE_ANALYSIS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1122304
DEBUG_FLR_KEY_VALUES_STRING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1122560
DEBUG_FLR_KEY_VALUES_VARIANT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1122816
DEBUG_FLR_TIMELINE_ANALYSIS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1126400
DEBUG_FLR_TIMELINE_TIMES: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1126401
DEBUG_FLR_STREAM_ANALYSIS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1130496
DEBUG_FLR_MEMORY_ANALYSIS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1134592
DEBUG_FLR_STACKHASH_ANALYSIS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1138688
DEBUG_FLR_PROCESSES_ANALYSIS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1142784
DEBUG_FLR_SERVICE_ANALYSIS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1146880
DEBUG_FLR_ADDITIONAL_XML: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1150976
DEBUG_FLR_STACK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097152
DEBUG_FLR_FOLLOWUP_CONTEXT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097153
DEBUG_FLR_XML_MODULE_LIST: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097154
DEBUG_FLR_STACK_FRAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097155
DEBUG_FLR_STACK_FRAME_NUMBER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097156
DEBUG_FLR_STACK_FRAME_INSTRUCTION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097157
DEBUG_FLR_STACK_FRAME_SYMBOL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097158
DEBUG_FLR_STACK_FRAME_SYMBOL_OFFSET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097159
DEBUG_FLR_STACK_FRAME_MODULE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097160
DEBUG_FLR_STACK_FRAME_IMAGE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097161
DEBUG_FLR_STACK_FRAME_FUNCTION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097162
DEBUG_FLR_STACK_FRAME_FLAGS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097163
DEBUG_FLR_CONTEXT_COMMAND: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097164
DEBUG_FLR_CONTEXT_FLAGS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097165
DEBUG_FLR_CONTEXT_ORDER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097166
DEBUG_FLR_CONTEXT_SYSTEM: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097167
DEBUG_FLR_CONTEXT_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097168
DEBUG_FLR_XML_MODULE_INFO: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097169
DEBUG_FLR_XML_MODULE_INFO_INDEX: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097170
DEBUG_FLR_XML_MODULE_INFO_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097171
DEBUG_FLR_XML_MODULE_INFO_IMAGE_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097172
DEBUG_FLR_XML_MODULE_INFO_IMAGE_PATH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097173
DEBUG_FLR_XML_MODULE_INFO_CHECKSUM: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097174
DEBUG_FLR_XML_MODULE_INFO_TIMESTAMP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097175
DEBUG_FLR_XML_MODULE_INFO_UNLOADED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097176
DEBUG_FLR_XML_MODULE_INFO_ON_STACK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097177
DEBUG_FLR_XML_MODULE_INFO_FIXED_FILE_VER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097178
DEBUG_FLR_XML_MODULE_INFO_FIXED_PROD_VER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097179
DEBUG_FLR_XML_MODULE_INFO_STRING_FILE_VER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097180
DEBUG_FLR_XML_MODULE_INFO_STRING_PROD_VER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097181
DEBUG_FLR_XML_MODULE_INFO_COMPANY_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097182
DEBUG_FLR_XML_MODULE_INFO_FILE_DESCRIPTION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097183
DEBUG_FLR_XML_MODULE_INFO_INTERNAL_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097184
DEBUG_FLR_XML_MODULE_INFO_ORIG_FILE_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097185
DEBUG_FLR_XML_MODULE_INFO_BASE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097186
DEBUG_FLR_XML_MODULE_INFO_SIZE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097187
DEBUG_FLR_XML_MODULE_INFO_PRODUCT_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097188
DEBUG_FLR_PROCESS_INFO: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097189
DEBUG_FLR_EXCEPTION_MODULE_INFO: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097190
DEBUG_FLR_CONTEXT_FOLLOWUP_INDEX: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097191
DEBUG_FLR_XML_GLOBALATTRIBUTE_LIST: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097192
DEBUG_FLR_XML_ATTRIBUTE_LIST: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097193
DEBUG_FLR_XML_ATTRIBUTE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097194
DEBUG_FLR_XML_ATTRIBUTE_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097195
DEBUG_FLR_XML_ATTRIBUTE_VALUE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097196
DEBUG_FLR_XML_ATTRIBUTE_D1VALUE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097197
DEBUG_FLR_XML_ATTRIBUTE_D2VALUE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097198
DEBUG_FLR_XML_ATTRIBUTE_DOVALUE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097199
DEBUG_FLR_XML_ATTRIBUTE_VALUE_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097200
DEBUG_FLR_XML_ATTRIBUTE_FRAME_NUMBER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097201
DEBUG_FLR_XML_ATTRIBUTE_THREAD_INDEX: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097202
DEBUG_FLR_XML_PROBLEMCLASS_LIST: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097203
DEBUG_FLR_XML_PROBLEMCLASS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097204
DEBUG_FLR_XML_PROBLEMCLASS_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097205
DEBUG_FLR_XML_PROBLEMCLASS_VALUE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097206
DEBUG_FLR_XML_PROBLEMCLASS_VALUE_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097207
DEBUG_FLR_XML_PROBLEMCLASS_FRAME_NUMBER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097208
DEBUG_FLR_XML_PROBLEMCLASS_THREAD_INDEX: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097209
DEBUG_FLR_XML_STACK_FRAME_TRIAGE_STATUS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097210
DEBUG_FLR_CONTEXT_METADATA: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097211
DEBUG_FLR_STACK_FRAMES: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097212
DEBUG_FLR_XML_ENCODED_OFFSETS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097213
DEBUG_FLR_FA_PERF_DATA: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097214
DEBUG_FLR_FA_PERF_ITEM: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097215
DEBUG_FLR_FA_PERF_ITEM_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097216
DEBUG_FLR_FA_PERF_ITERATIONS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097217
DEBUG_FLR_FA_PERF_ELAPSED_MS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097218
DEBUG_FLR_STACK_SHA1_HASH_MF: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097219
DEBUG_FLR_STACK_SHA1_HASH_MFO: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097220
DEBUG_FLR_STACK_SHA1_HASH_M: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097221
DEBUG_FLR_XML_MODULE_INFO_SYMBOL_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097222
DEBUG_FLR_XML_MODULE_INFO_FILE_FLAGS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097223
DEBUG_FLR_STACK_FRAME_MODULE_BASE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097224
DEBUG_FLR_STACK_FRAME_SRC: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097225
DEBUG_FLR_XML_SYSTEMINFO: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097226
DEBUG_FLR_XML_SYSTEMINFO_SYSTEMMANUFACTURER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097227
DEBUG_FLR_XML_SYSTEMINFO_SYSTEMMODEL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097228
DEBUG_FLR_XML_SYSTEMINFO_SYSTEMMARKER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097229
DEBUG_FLR_FA_ADHOC_ANALYSIS_ITEMS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097230
DEBUG_FLR_XML_APPLICATION_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097231
DEBUG_FLR_XML_PACKAGE_MONIKER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097232
DEBUG_FLR_XML_PACKAGE_RELATIVE_APPLICATION_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097233
DEBUG_FLR_XML_MODERN_ASYNC_REQUEST_OUTSTANDING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097234
DEBUG_FLR_XML_EVENTTYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097235
DEBUG_FLR_XML_PACKAGE_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097236
DEBUG_FLR_XML_PACKAGE_VERSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097237
DEBUG_FLR_FAILURE_LIST: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097238
DEBUG_FLR_FAILURE_DISPLAY_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097239
DEBUG_FLR_FRAME_SOURCE_FILE_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097240
DEBUG_FLR_FRAME_SOURCE_FILE_PATH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097241
DEBUG_FLR_FRAME_SOURCE_LINE_NUMBER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097242
DEBUG_FLR_XML_MODULE_INFO_SYMSRV_IMAGE_STATUS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097243
DEBUG_FLR_XML_MODULE_INFO_SYMSRV_IMAGE_ERROR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097244
DEBUG_FLR_XML_MODULE_INFO_SYMSRV_IMAGE_DETAIL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097245
DEBUG_FLR_XML_MODULE_INFO_SYMSRV_IMAGE_SEC: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097246
DEBUG_FLR_XML_MODULE_INFO_SYMSRV_PDB_STATUS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097247
DEBUG_FLR_XML_MODULE_INFO_SYMSRV_PDB_ERROR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097248
DEBUG_FLR_XML_MODULE_INFO_SYMSRV_PDB_DETAIL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097249
DEBUG_FLR_XML_MODULE_INFO_SYMSRV_PDB_SEC: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097250
DEBUG_FLR_XML_MODULE_INFO_DRIVER_GROUP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 2097251
DEBUG_FLR_REGISTRY_DATA: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 3145728
DEBUG_FLR_WMI_QUERY_DATA: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 3149824
DEBUG_FLR_USER_GLOBAL_ATTRIBUTES: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 3153920
DEBUG_FLR_USER_THREAD_ATTRIBUTES: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 3158016
DEBUG_FLR_USER_PROBLEM_CLASSES: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 3162112
DEBUG_FLR_SM_COMPRESSION_FORMAT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1342177280
DEBUG_FLR_SM_SOURCE_PFN1: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1342177281
DEBUG_FLR_SM_SOURCE_PFN2: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1342177282
DEBUG_FLR_SM_SOURCE_OFFSET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1342177283
DEBUG_FLR_SM_SOURCE_SIZE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1342177284
DEBUG_FLR_SM_TARGET_PFN: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1342177285
DEBUG_FLR_SM_BUFFER_HASH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1342177286
DEBUG_FLR_SM_ONEBIT_SOLUTION_COUNT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1342177287
DEBUG_FLR_STORE_PRODUCT_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612736
DEBUG_FLR_STORE_PRODUCT_DISPLAY_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612737
DEBUG_FLR_STORE_PRODUCT_DESCRIPTION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612738
DEBUG_FLR_STORE_PRODUCT_EXTENDED_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612739
DEBUG_FLR_STORE_PUBLISHER_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612740
DEBUG_FLR_STORE_PUBLISHER_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612741
DEBUG_FLR_STORE_PUBLISHER_CERTIFICATE_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612742
DEBUG_FLR_STORE_DEVELOPER_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612743
DEBUG_FLR_STORE_PACKAGE_FAMILY_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612744
DEBUG_FLR_STORE_PACKAGE_IDENTITY_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612745
DEBUG_FLR_STORE_PRIMARY_PARENT_PRODUCT_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612746
DEBUG_FLR_STORE_LEGACY_PARENT_PRODUCT_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612747
DEBUG_FLR_STORE_LEGACY_WINDOWS_STORE_PRODUCT_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612748
DEBUG_FLR_STORE_LEGACY_WINDOWS_PHONE_PRODUCT_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612749
DEBUG_FLR_STORE_LEGACY_XBOX_ONE_PRODUCT_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612750
DEBUG_FLR_STORE_LEGACY_XBOX_360_PRODUCT_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612751
DEBUG_FLR_STORE_XBOX_TITLE_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612752
DEBUG_FLR_STORE_PREFERRED_SKU_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612753
DEBUG_FLR_STORE_IS_MICROSOFT_PRODUCT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612754
DEBUG_FLR_STORE_URL_APP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612755
DEBUG_FLR_STORE_URL_APPHEALTH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1610612756
DEBUG_FLR_PHONE_VERSIONMAJOR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048192
DEBUG_FLR_PHONE_VERSIONMINOR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048193
DEBUG_FLR_PHONE_BUILDNUMBER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048194
DEBUG_FLR_PHONE_BUILDTIMESTAMP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048195
DEBUG_FLR_PHONE_BUILDBRANCH: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048196
DEBUG_FLR_PHONE_BUILDER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048197
DEBUG_FLR_PHONE_LCID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048198
DEBUG_FLR_PHONE_QFE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048199
DEBUG_FLR_PHONE_OPERATOR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048200
DEBUG_FLR_PHONE_MCCMNC: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048201
DEBUG_FLR_PHONE_FIRMWAREREVISION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048202
DEBUG_FLR_PHONE_RAM: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048203
DEBUG_FLR_PHONE_ROMVERSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048204
DEBUG_FLR_PHONE_SOCVERSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048205
DEBUG_FLR_PHONE_HARDWAREREVISION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048206
DEBUG_FLR_PHONE_RADIOHARDWAREREVISION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048207
DEBUG_FLR_PHONE_RADIOSOFTWAREREVISION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048208
DEBUG_FLR_PHONE_BOOTLOADERVERSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048209
DEBUG_FLR_PHONE_REPORTGUID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048210
DEBUG_FLR_PHONE_SOURCE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048211
DEBUG_FLR_PHONE_SOURCEEXTERNAL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048212
DEBUG_FLR_PHONE_USERALIAS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048213
DEBUG_FLR_PHONE_REPORTTIMESTAMP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048214
DEBUG_FLR_PHONE_APPID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048215
DEBUG_FLR_PHONE_SKUID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048216
DEBUG_FLR_PHONE_APPVERSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048217
DEBUG_FLR_PHONE_UIF_COMMENT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048218
DEBUG_FLR_PHONE_UIF_APPNAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048219
DEBUG_FLR_PHONE_UIF_APPID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048220
DEBUG_FLR_PHONE_UIF_CATEGORY: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048221
DEBUG_FLR_PHONE_UIF_ORIGIN: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048222
DEBUG_FLR_SIMULTANEOUS_TELSVC_INSTANCES: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048223
DEBUG_FLR_SIMULTANEOUS_TELWP_INSTANCES: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048224
DEBUG_FLR_MINUTES_SINCE_LAST_EVENT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048225
DEBUG_FLR_MINUTES_SINCE_LAST_EVENT_OF_THIS_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048226
DEBUG_FLR_REPORT_INFO_GUID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048227
DEBUG_FLR_REPORT_INFO_SOURCE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048228
DEBUG_FLR_REPORT_INFO_CREATION_TIME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = 1879048229
DEBUG_FLR_FAULTING_IP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -2147483648
DEBUG_FLR_FAULTING_MODULE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -2147483647
DEBUG_FLR_IMAGE_TIMESTAMP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -2147483646
DEBUG_FLR_FOLLOWUP_IP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -2147483645
DEBUG_FLR_FRAME_ONE_INVALID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -2147483644
DEBUG_FLR_SYMBOL_FROM_RAW_STACK_ADDRESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -2147483643
DEBUG_FLR_IMAGE_VERSION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -2147483642
DEBUG_FLR_FOLLOWUP_BUCKET_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -2147483641
DEBUG_FLR_CUSTOM_ANALYSIS_TAG_MIN: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1610612736
DEBUG_FLR_CUSTOM_ANALYSIS_TAG_MAX: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1342177280
DEBUG_FLR_FAULTING_THREAD: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1073741824
DEBUG_FLR_CONTEXT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1073741823
DEBUG_FLR_TRAP_FRAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1073741822
DEBUG_FLR_TSS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1073741821
DEBUG_FLR_BLOCKING_THREAD: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1073741820
DEBUG_FLR_UNRESPONSIVE_UI_THREAD: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1073741819
DEBUG_FLR_BLOCKED_THREAD0: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1073741818
DEBUG_FLR_BLOCKED_THREAD1: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1073741817
DEBUG_FLR_BLOCKED_THREAD2: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1073741816
DEBUG_FLR_BLOCKING_PROCESSID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1073741815
DEBUG_FLR_PROCESSOR_ID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1073741814
DEBUG_FLR_XDV_VIOLATED_CONDITION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1073741813
DEBUG_FLR_XDV_STATE_VARIABLE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1073741812
DEBUG_FLR_XDV_HELP_LINK: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1073741811
DEBUG_FLR_XDV_RULE_INFO: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1073741810
DEBUG_FLR_DPC_STACK_BASE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1073741809
DEBUG_FLR_TESTRESULTSERVER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435456
DEBUG_FLR_TESTRESULTGUID: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435455
DEBUG_FLR_CUSTOMREPORTTAG: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435454
DEBUG_FLR_DISKSEC_ORGID_DEPRECATED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435453
DEBUG_FLR_DISKSEC_MODEL_DEPRECATED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435452
DEBUG_FLR_DISKSEC_MFGID_DEPRECATED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435451
DEBUG_FLR_DISKSEC_ISSUEDESCSTRING_DEPRECATED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435450
DEBUG_FLR_DISKSEC_PUBLIC_TOTSIZE_DEPRECATED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435449
DEBUG_FLR_DISKSEC_PUBLIC_OFFSET_DEPRECATED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435448
DEBUG_FLR_DISKSEC_PUBLIC_DATASIZE_DEPRECATED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435447
DEBUG_FLR_DISKSEC_PRIVATE_TOTSIZE_DEPRECATED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435446
DEBUG_FLR_DISKSEC_PRIVATE_OFFSET_DEPRECATED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435445
DEBUG_FLR_DISKSEC_PRIVATE_DATASIZE_DEPRECATED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435444
DEBUG_FLR_DISKSEC_TOTALSIZE_DEPRECATED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435443
DEBUG_FLR_DISKSEC_REASON_DEPRECATED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435442
DEBUG_FLR_WERCOLLECTION_PROCESSTERMINATED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435441
DEBUG_FLR_WERCOLLECTION_PROCESSHEAPDUMP_REQUEST_FAILURE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435440
DEBUG_FLR_WERCOLLECTION_MINIDUMP_WRITE_FAILURE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435439
DEBUG_FLR_WERCOLLECTION_DEFAULTCOLLECTION_FAILURE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435438
DEBUG_FLR_PROCESS_BAM_CURRENT_THROTTLED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435437
DEBUG_FLR_PROCESS_BAM_PREVIOUS_THROTTLED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435436
DEBUG_FLR_DUMPSTREAM_COMMENTA: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435435
DEBUG_FLR_DUMPSTREAM_COMMENTW: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435434
DEBUG_FLR_CHPE_PROCESS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435433
DEBUG_FLR_WINLOGON_BLACKBOX: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435432
DEBUG_FLR_CUSTOM_COMMAND: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435431
DEBUG_FLR_CUSTOM_COMMAND_OUTPUT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -268435430
DEBUG_FLR_MASK_ALL: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE = -1
class DEBUG_GET_TEXT_COMPLETIONS_IN(Structure):
    Flags: UInt32
    MatchCountLimit: UInt32
    Reserved: UInt64 * 3
class DEBUG_GET_TEXT_COMPLETIONS_OUT(Structure):
    Flags: UInt32
    ReplaceIndex: UInt32
    MatchCount: UInt32
    Reserved1: UInt32
    Reserved2: UInt64 * 2
class DEBUG_HANDLE_DATA_BASIC(Structure):
    TypeNameSize: UInt32
    ObjectNameSize: UInt32
    Attributes: UInt32
    GrantedAccess: UInt32
    HandleCount: UInt32
    PointerCount: UInt32
class DEBUG_IRP_INFO(Structure):
    SizeOfStruct: UInt32
    IrpAddress: UInt64
    IoStatus: UInt32
    StackCount: UInt32
    CurrentLocation: UInt32
    MdlAddress: UInt64
    Thread: UInt64
    CancelRoutine: UInt64
    CurrentStack: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_IRP_STACK_INFO
    Stack: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_IRP_STACK_INFO * 10
class DEBUG_IRP_STACK_INFO(Structure):
    Major: Byte
    Minor: Byte
    DeviceObject: UInt64
    FileObject: UInt64
    CompletionRoutine: UInt64
    StackAddress: UInt64
class DEBUG_LAST_EVENT_INFO_BREAKPOINT(Structure):
    Id: UInt32
class DEBUG_LAST_EVENT_INFO_EXCEPTION(Structure):
    ExceptionRecord: win32more.Windows.Win32.System.Diagnostics.Debug.EXCEPTION_RECORD64
    FirstChance: UInt32
class DEBUG_LAST_EVENT_INFO_EXIT_PROCESS(Structure):
    ExitCode: UInt32
class DEBUG_LAST_EVENT_INFO_EXIT_THREAD(Structure):
    ExitCode: UInt32
class DEBUG_LAST_EVENT_INFO_LOAD_MODULE(Structure):
    Base: UInt64
class DEBUG_LAST_EVENT_INFO_SERVICE_EXCEPTION(Structure):
    Kind: UInt32
    DataSize: UInt32
    Address: UInt64
class DEBUG_LAST_EVENT_INFO_SYSTEM_ERROR(Structure):
    Error: UInt32
    Level: UInt32
class DEBUG_LAST_EVENT_INFO_UNLOAD_MODULE(Structure):
    Base: UInt64
class DEBUG_MODULE_AND_ID(Structure):
    ModuleBase: UInt64
    Id: UInt64
class DEBUG_MODULE_PARAMETERS(Structure):
    Base: UInt64
    Size: UInt32
    TimeDateStamp: UInt32
    Checksum: UInt32
    Flags: UInt32
    SymbolType: UInt32
    ImageNameSize: UInt32
    ModuleNameSize: UInt32
    LoadedImageNameSize: UInt32
    SymbolFileNameSize: UInt32
    MappedImageNameSize: UInt32
    Reserved: UInt64 * 2
class DEBUG_OFFSET_REGION(Structure):
    Base: UInt64
    Size: UInt64
class DEBUG_PNP_TRIAGE_INFO(Structure):
    SizeOfStruct: UInt32
    Lock_Address: UInt64
    Lock_ActiveCount: Int32
    Lock_ContentionCount: UInt32
    Lock_NumberOfExclusiveWaiters: UInt32
    Lock_NumberOfSharedWaiters: UInt32
    Lock_Flag: UInt16
    TriagedThread: UInt64
    ThreadCount: Int32
    TriagedThread_WaitTime: UInt64
class DEBUG_POOLTAG_DESCRIPTION(Structure):
    SizeOfStruct: UInt32
    PoolTag: UInt32
    Description: win32more.Windows.Win32.Foundation.CHAR * 260
    Binary: win32more.Windows.Win32.Foundation.CHAR * 32
    Owner: win32more.Windows.Win32.Foundation.CHAR * 32
class DEBUG_POOL_DATA(Structure):
    SizeofStruct: UInt32
    PoolBlock: UInt64
    Pool: UInt64
    PreviousSize: UInt32
    Size: UInt32
    PoolTag: UInt32
    ProcessBilled: UInt64
    Anonymous: _Anonymous_e__Union
    Reserved2: UInt64 * 4
    PoolTagDescription: win32more.Windows.Win32.Foundation.CHAR * 64
    class _Anonymous_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        AsUlong: UInt32
        class _Anonymous_e__Struct(Structure):
            Free: Annotated[UInt32, 1]
            LargePool: Annotated[UInt32, 1]
            SpecialPool: Annotated[UInt32, 1]
            Pageable: Annotated[UInt32, 1]
            Protected: Annotated[UInt32, 1]
            Allocated: Annotated[UInt32, 1]
            Session: Annotated[UInt32, 1]
            Reserved: Annotated[UInt32, 25]
DEBUG_POOL_REGION = Int32
DbgPoolRegionUnknown: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_POOL_REGION = 0
DbgPoolRegionSpecial: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_POOL_REGION = 1
DbgPoolRegionPaged: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_POOL_REGION = 2
DbgPoolRegionNonPaged: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_POOL_REGION = 3
DbgPoolRegionNonPagedExpansion: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_POOL_REGION = 4
DbgPoolRegionSessionPaged: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_POOL_REGION = 5
DbgPoolRegionMax: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_POOL_REGION = 6
class DEBUG_PROCESSOR_IDENTIFICATION_ALL(Union):
    Alpha: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_PROCESSOR_IDENTIFICATION_ALPHA
    Amd64: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_PROCESSOR_IDENTIFICATION_AMD64
    Ia64: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_PROCESSOR_IDENTIFICATION_IA64
    X86: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_PROCESSOR_IDENTIFICATION_X86
    Arm: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_PROCESSOR_IDENTIFICATION_ARM
    Arm64: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_PROCESSOR_IDENTIFICATION_ARM64
class DEBUG_PROCESSOR_IDENTIFICATION_ALPHA(Structure):
    Type: UInt32
    Revision: UInt32
class DEBUG_PROCESSOR_IDENTIFICATION_AMD64(Structure):
    Family: UInt32
    Model: UInt32
    Stepping: UInt32
    VendorString: win32more.Windows.Win32.Foundation.CHAR * 16
class DEBUG_PROCESSOR_IDENTIFICATION_ARM(Structure):
    Model: UInt32
    Revision: UInt32
    VendorString: win32more.Windows.Win32.Foundation.CHAR * 16
class DEBUG_PROCESSOR_IDENTIFICATION_ARM64(Structure):
    Model: UInt32
    Revision: UInt32
    VendorString: win32more.Windows.Win32.Foundation.CHAR * 16
class DEBUG_PROCESSOR_IDENTIFICATION_IA64(Structure):
    Model: UInt32
    Revision: UInt32
    Family: UInt32
    ArchRev: UInt32
    VendorString: win32more.Windows.Win32.Foundation.CHAR * 16
class DEBUG_PROCESSOR_IDENTIFICATION_X86(Structure):
    Family: UInt32
    Model: UInt32
    Stepping: UInt32
    VendorString: win32more.Windows.Win32.Foundation.CHAR * 16
class DEBUG_READ_USER_MINIDUMP_STREAM(Structure):
    StreamType: UInt32
    Flags: UInt32
    Offset: UInt64
    Buffer: VoidPtr
    BufferSize: UInt32
    BufferUsed: UInt32
class DEBUG_REGISTER_DESCRIPTION(Structure):
    Type: UInt32
    Flags: UInt32
    SubregMaster: UInt32
    SubregLength: UInt32
    SubregMask: UInt64
    SubregShift: UInt32
    Reserved0: UInt32
class DEBUG_SMBIOS_INFO(Structure):
    SizeOfStruct: UInt32
    SmbiosMajorVersion: Byte
    SmbiosMinorVersion: Byte
    DMIVersion: Byte
    TableSize: UInt32
    BiosMajorRelease: Byte
    BiosMinorRelease: Byte
    FirmwareMajorRelease: Byte
    FirmwareMinorRelease: Byte
    BaseBoardManufacturer: win32more.Windows.Win32.Foundation.CHAR * 64
    BaseBoardProduct: win32more.Windows.Win32.Foundation.CHAR * 64
    BaseBoardVersion: win32more.Windows.Win32.Foundation.CHAR * 64
    BiosReleaseDate: win32more.Windows.Win32.Foundation.CHAR * 64
    BiosVendor: win32more.Windows.Win32.Foundation.CHAR * 64
    BiosVersion: win32more.Windows.Win32.Foundation.CHAR * 64
    SystemFamily: win32more.Windows.Win32.Foundation.CHAR * 64
    SystemManufacturer: win32more.Windows.Win32.Foundation.CHAR * 64
    SystemProductName: win32more.Windows.Win32.Foundation.CHAR * 64
    SystemSKU: win32more.Windows.Win32.Foundation.CHAR * 64
    SystemVersion: win32more.Windows.Win32.Foundation.CHAR * 64
class DEBUG_SPECIFIC_FILTER_PARAMETERS(Structure):
    ExecutionOption: UInt32
    ContinueOption: UInt32
    TextSize: UInt32
    CommandSize: UInt32
    ArgumentSize: UInt32
class DEBUG_STACK_FRAME(Structure):
    InstructionOffset: UInt64
    ReturnOffset: UInt64
    FrameOffset: UInt64
    StackOffset: UInt64
    FuncTableEntry: UInt64
    Params: UInt64 * 4
    Reserved: UInt64 * 6
    Virtual: win32more.Windows.Win32.Foundation.BOOL
    FrameNumber: UInt32
class DEBUG_STACK_FRAME_EX(Structure):
    InstructionOffset: UInt64
    ReturnOffset: UInt64
    FrameOffset: UInt64
    StackOffset: UInt64
    FuncTableEntry: UInt64
    Params: UInt64 * 4
    Reserved: UInt64 * 6
    Virtual: win32more.Windows.Win32.Foundation.BOOL
    FrameNumber: UInt32
    InlineFrameContext: UInt32
    Reserved1: UInt32
class DEBUG_SYMBOL_ENTRY(Structure):
    ModuleBase: UInt64
    Offset: UInt64
    Id: UInt64
    Arg64: UInt64
    Size: UInt32
    Flags: UInt32
    TypeId: UInt32
    NameSize: UInt32
    Token: UInt32
    Tag: UInt32
    Arg32: UInt32
    Reserved: UInt32
class DEBUG_SYMBOL_PARAMETERS(Structure):
    Module: UInt64
    TypeId: UInt32
    ParentSymbol: UInt32
    SubElements: UInt32
    Flags: UInt32
    Reserved: UInt64
class DEBUG_SYMBOL_SOURCE_ENTRY(Structure):
    ModuleBase: UInt64
    Offset: UInt64
    FileNameId: UInt64
    EngineInternal: UInt64
    Size: UInt32
    Flags: UInt32
    FileNameSize: UInt32
    StartLine: UInt32
    EndLine: UInt32
    StartColumn: UInt32
    EndColumn: UInt32
    Reserved: UInt32
class DEBUG_THREAD_BASIC_INFORMATION(Structure):
    Valid: UInt32
    ExitStatus: UInt32
    PriorityClass: UInt32
    Priority: UInt32
    CreateTime: UInt64
    ExitTime: UInt64
    KernelTime: UInt64
    UserTime: UInt64
    StartOffset: UInt64
    Affinity: UInt64
class DEBUG_TRIAGE_FOLLOWUP_INFO(Structure):
    SizeOfStruct: UInt32
    OwnerNameSize: UInt32
    OwnerName: win32more.Windows.Win32.Foundation.PSTR
class DEBUG_TRIAGE_FOLLOWUP_INFO_2(Structure):
    SizeOfStruct: UInt32
    OwnerNameSize: UInt32
    OwnerName: win32more.Windows.Win32.Foundation.PSTR
    FeaturePathSize: UInt32
    FeaturePath: win32more.Windows.Win32.Foundation.PSTR
class DEBUG_TYPED_DATA(Structure):
    ModBase: UInt64
    Offset: UInt64
    EngineHandle: UInt64
    Data: UInt64
    Size: UInt32
    Flags: UInt32
    TypeId: UInt32
    BaseTypeId: UInt32
    Tag: UInt32
    Register: UInt32
    Internal: UInt64 * 9
class DEBUG_VALUE(Structure):
    Anonymous: _Anonymous_e__Union
    TailOfRawBytes: UInt32
    Type: UInt32
    class _Anonymous_e__Union(Union):
        I8: Byte
        I16: UInt16
        I32: UInt32
        Anonymous: _Anonymous_e__Struct
        F32: Single
        F64: Double
        F80Bytes: Byte * 10
        F82Bytes: Byte * 11
        F128Bytes: Byte * 16
        VI8: Byte * 16
        VI16: UInt16 * 8
        VI32: UInt32 * 4
        VI64: UInt64 * 2
        VF32: Single * 4
        VF64: Double * 2
        I64Parts32: _I64Parts32_e__Struct
        F128Parts64: _F128Parts64_e__Struct
        RawBytes: Byte * 24
        class _Anonymous_e__Struct(Structure):
            I64: UInt64
            Nat: win32more.Windows.Win32.Foundation.BOOL
        class _I64Parts32_e__Struct(Structure):
            LowPart: UInt32
            HighPart: UInt32
        class _F128Parts64_e__Struct(Structure):
            LowPart: UInt64
            HighPart: Int64
class DebugBaseEventCallbacks(ComPtr):
    extends: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacks
class DebugBaseEventCallbacksWide(ComPtr):
    extends: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacksWide
@winfunctype_pointer
def ENTRY_CALLBACK(EntryAddress: UInt64, Context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def EXTDLL_ITERATERTLBALANCEDNODES(RootNode: UInt64, EntryOffset: UInt32, Callback: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ENTRY_CALLBACK, CallbackContext: VoidPtr) -> Void: ...
@winfunctype_pointer
def EXTDLL_QUERYDATABYTAG(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient4, dwDataTag: UInt32, pQueryInfo: VoidPtr, pData: POINTER(Byte), cbData: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def EXTDLL_QUERYDATABYTAGEX(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient4, dwDataTag: UInt32, pQueryInfo: VoidPtr, pData: POINTER(Byte), cbData: UInt32, pDataEx: POINTER(Byte), cbDataEx: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class EXTSTACKTRACE(Structure):
    FramePointer: UInt32
    ProgramCounter: UInt32
    ReturnAddress: UInt32
    Args: UInt32 * 4
class EXTSTACKTRACE32(Structure):
    FramePointer: UInt32
    ProgramCounter: UInt32
    ReturnAddress: UInt32
    Args: UInt32 * 4
class EXTSTACKTRACE64(Structure):
    FramePointer: UInt64
    ProgramCounter: UInt64
    ReturnAddress: UInt64
    Args: UInt64 * 4
@winfunctype_pointer
def EXTS_JOB_PROCESS_CALLBACK(Job: UInt64, Process: UInt64, Context: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype_pointer
def EXTS_TABLE_ENTRY_CALLBACK(Entry: UInt64, Context: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype_pointer
def EXT_ANALYSIS_PLUGIN(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient4, CallPhase: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_EXTENSION_PLUGIN_PHASE, pAnalysis: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugFailureAnalysis2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def EXT_ANALYZER(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, BucketSuffix: win32more.Windows.Win32.Foundation.PSTR, cbBucketSuffix: UInt32, DebugText: win32more.Windows.Win32.Foundation.PSTR, cbDebugText: UInt32, Flags: POINTER(UInt32), pAnalysis: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugFailureAnalysis) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class EXT_API_VERSION(Structure):
    MajorVersion: UInt16
    MinorVersion: UInt16
    Revision: UInt16
    Reserved: UInt16
class EXT_CAB_XML_DATA(Structure):
    SizeOfStruct: UInt32
    XmlObjectTag: win32more.Windows.Win32.Foundation.PWSTR
    NumSubTags: UInt32
    SubTags: _SUBTAGS * 1
    class _SUBTAGS(Structure):
        SubTag: win32more.Windows.Win32.Foundation.PWSTR
        MatchPattern: win32more.Windows.Win32.Foundation.PWSTR
        ReturnText: win32more.Windows.Win32.Foundation.PWSTR
        ReturnTextSize: UInt32
        MatchType: Annotated[UInt32, 3]
        Reserved: Annotated[UInt32, 29]
        Reserved2: UInt32
@winfunctype_pointer
def EXT_DECODE_ERROR(pDecodeError: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_DECODE_ERROR)) -> Void: ...
class EXT_FIND_FILE(Structure):
    FileName: win32more.Windows.Win32.Foundation.PWSTR
    IndexedSize: UInt64
    ImageTimeDateStamp: UInt32
    ImageCheckSum: UInt32
    ExtraInfo: VoidPtr
    ExtraInfoSize: UInt32
    Flags: UInt32
    FileMapping: VoidPtr
    FileMappingSize: UInt64
    FileHandle: win32more.Windows.Win32.Foundation.HANDLE
    FoundFileName: win32more.Windows.Win32.Foundation.PWSTR
    FoundFileNameChars: UInt32
@winfunctype_pointer
def EXT_GET_DEBUG_FAILURE_ANALYSIS(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient4, Flags: UInt32, ClassId: Guid, ppAnalysis: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugFailureAnalysis2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def EXT_GET_ENVIRONMENT_VARIABLE(Peb: UInt64, Variable: win32more.Windows.Win32.Foundation.PSTR, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def EXT_GET_FAILURE_ANALYSIS(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient4, Flags: UInt32, ppAnalysis: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugFailureAnalysis)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def EXT_GET_FA_ENTRIES_DATA(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient4, Count: POINTER(UInt32), Entries: POINTER(POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def EXT_GET_HANDLE_TRACE(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, TraceType: UInt32, StartIndex: UInt32, HandleValue: POINTER(UInt64), StackFunctions: POINTER(UInt64), StackTraceSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class EXT_MATCH_PATTERN_A(Structure):
    Str: win32more.Windows.Win32.Foundation.PSTR
    Pattern: win32more.Windows.Win32.Foundation.PSTR
    CaseSensitive: UInt32
@winfunctype_pointer
def EXT_RELOAD_TRIAGER(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient4) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def EXT_TARGET_INFO(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient4, pTargetInfo: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TARGET_DEBUG_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
EXT_TDOP = Int32
EXT_TDOP_COPY: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 0
EXT_TDOP_RELEASE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 1
EXT_TDOP_SET_FROM_EXPR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 2
EXT_TDOP_SET_FROM_U64_EXPR: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 3
EXT_TDOP_GET_FIELD: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 4
EXT_TDOP_EVALUATE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 5
EXT_TDOP_GET_TYPE_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 6
EXT_TDOP_OUTPUT_TYPE_NAME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 7
EXT_TDOP_OUTPUT_SIMPLE_VALUE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 8
EXT_TDOP_OUTPUT_FULL_VALUE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 9
EXT_TDOP_HAS_FIELD: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 10
EXT_TDOP_GET_FIELD_OFFSET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 11
EXT_TDOP_GET_ARRAY_ELEMENT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 12
EXT_TDOP_GET_DEREFERENCE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 13
EXT_TDOP_GET_TYPE_SIZE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 14
EXT_TDOP_OUTPUT_TYPE_DEFINITION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 15
EXT_TDOP_GET_POINTER_TO: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 16
EXT_TDOP_SET_FROM_TYPE_ID_AND_U64: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 17
EXT_TDOP_SET_PTR_FROM_TYPE_ID_AND_U64: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 18
EXT_TDOP_COUNT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP = 19
@winfunctype_pointer
def EXT_TRIAGE_FOLLOWUP(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient4, SymbolName: win32more.Windows.Win32.Foundation.PSTR, OwnerInfo: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_TRIAGE_FOLLOWUP_INFO)) -> UInt32: ...
class EXT_TYPED_DATA(Structure):
    Operation: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_TDOP
    Flags: UInt32
    InData: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_TYPED_DATA
    OutData: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_TYPED_DATA
    InStrIndex: UInt32
    In32: UInt32
    Out32: UInt32
    In64: UInt64
    Out64: UInt64
    StrBufferIndex: UInt32
    StrBufferChars: UInt32
    StrCharsNeeded: UInt32
    DataBufferIndex: UInt32
    DataBufferBytes: UInt32
    DataBytesNeeded: UInt32
    Status: win32more.Windows.Win32.Foundation.HRESULT
    Reserved: UInt64 * 8
@winfunctype_pointer
def EXT_XML_DATA(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient4, pXmpData: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_CAB_XML_DATA)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
ErrorClass = Int32
ErrorClassWarning: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ErrorClass = 0
ErrorClassError: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ErrorClass = 1
class FA_ENTRY(Structure):
    Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE
    FullSize: UInt16
    DataSize: UInt16
FA_ENTRY_TYPE = Int32
DEBUG_FA_ENTRY_NO_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY_TYPE = 0
DEBUG_FA_ENTRY_ULONG: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY_TYPE = 1
DEBUG_FA_ENTRY_ULONG64: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY_TYPE = 2
DEBUG_FA_ENTRY_INSTRUCTION_OFFSET: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY_TYPE = 3
DEBUG_FA_ENTRY_POINTER: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY_TYPE = 4
DEBUG_FA_ENTRY_ANSI_STRING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY_TYPE = 5
DEBUG_FA_ENTRY_ANSI_STRINGs: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY_TYPE = 6
DEBUG_FA_ENTRY_EXTENSION_CMD: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY_TYPE = 7
DEBUG_FA_ENTRY_STRUCTURED_DATA: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY_TYPE = 8
DEBUG_FA_ENTRY_UNICODE_STRING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY_TYPE = 9
DEBUG_FA_ENTRY_ARRAY: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY_TYPE = 32768
FA_EXTENSION_PLUGIN_PHASE = Int32
FA_PLUGIN_INITIALIZATION: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_EXTENSION_PLUGIN_PHASE = 1
FA_PLUGIN_STACK_ANALYSIS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_EXTENSION_PLUGIN_PHASE = 2
FA_PLUGIN_PRE_BUCKETING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_EXTENSION_PLUGIN_PHASE = 4
FA_PLUGIN_POST_BUCKETING: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_EXTENSION_PLUGIN_PHASE = 8
class FIELD_INFO(Structure):
    fName: POINTER(Byte)
    printName: POINTER(Byte)
    size: UInt32
    fOptions: UInt32
    address: UInt64
    Anonymous: _Anonymous_e__Union
    TypeId: UInt32
    FieldOffset: UInt32
    BufferSize: UInt32
    BitField: _BitField
    fPointer: Annotated[UInt32, 2]
    fArray: Annotated[UInt32, 1]
    fStruct: Annotated[UInt32, 1]
    fConstant: Annotated[UInt32, 1]
    fStatic: Annotated[UInt32, 1]
    Reserved: Annotated[UInt32, 26]
    class _Anonymous_e__Union(Union):
        fieldCallBack: VoidPtr
        pBuffer: VoidPtr
    class _BitField(Structure):
        Position: UInt16
        Size: UInt16
class GET_CONTEXT_EX(Structure):
    Status: UInt32
    ContextSize: UInt32
    pContext: VoidPtr
class GET_CURRENT_PROCESS_ADDRESS(Structure):
    Processor: UInt32
    CurrentThread: UInt64
    Address: UInt64
class GET_CURRENT_THREAD_ADDRESS(Structure):
    Processor: UInt32
    Address: UInt64
class GET_EXPRESSION_EX(Structure):
    Expression: win32more.Windows.Win32.Foundation.PSTR
    Remainder: win32more.Windows.Win32.Foundation.PSTR
    Value: UInt64
class GET_INPUT_LINE(Structure):
    Prompt: win32more.Windows.Win32.Foundation.PSTR
    Buffer: win32more.Windows.Win32.Foundation.PSTR
    BufferSize: UInt32
    InputSize: UInt32
class GET_PEB_ADDRESS(Structure):
    CurrentThread: UInt64
    Address: UInt64
class GET_SET_SYMPATH(Structure):
    Args: win32more.Windows.Win32.Foundation.PSTR
    Result: win32more.Windows.Win32.Foundation.PSTR
    Length: Int32
class GET_TEB_ADDRESS(Structure):
    Address: UInt64
class ICodeAddressConcept(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c7371568-5c78-4a00-a4ab-6ef8823184cb}')
    @commethod(3)
    def GetContainingSymbol(self, pContextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, ppSymbol: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbol)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IComparableConcept(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a7830646-9f0c-4a31-ba19-503f33e6c8a3}')
    @commethod(3)
    def CompareObjects(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, otherObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, comparisonResult: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelConcept(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{fcb98d1d-1114-4fbf-b24c-effcb5def0d3}')
    @commethod(3)
    def InitializeObject(self, modelObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, matchingTypeSignature: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostTypeSignature, wildcardMatches: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbolEnumerator) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetName(self, modelName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{73fe19f4-a110-4500-8ed9-3c28896f508c}')
    @commethod(3)
    def Close(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateNoValue(self, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateErrorObject(self, hrError: win32more.Windows.Win32.Foundation.HRESULT, pwszMessage: win32more.Windows.Win32.Foundation.PWSTR, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateTypedObject(self, context: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext, objectLocation: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location, objectType: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreateTypedObjectReference(self, context: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext, objectLocation: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location, objectType: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateSyntheticObject(self, context: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CreateDataModelObject(self, dataModel: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelConcept, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CreateIntrinsicObject(self, objectKind: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ModelObjectKind, intrinsicData: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateTypedIntrinsicObject(self, intrinsicData: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), type: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetModelForTypeSignature(self, typeSignature: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostTypeSignature, dataModel: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetModelForType(self, type: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType, dataModel: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), typeSignature: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostTypeSignature), wildcardMatches: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbolEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def RegisterModelForTypeSignature(self, typeSignature: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostTypeSignature, dataModel: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def UnregisterModelForTypeSignature(self, dataModel: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, typeSignature: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostTypeSignature) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def RegisterExtensionForTypeSignature(self, typeSignature: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostTypeSignature, dataModel: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def UnregisterExtensionForTypeSignature(self, dataModel: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, typeSignature: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostTypeSignature) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def CreateMetadataStore(self, parentStore: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore, metadataStore: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetRootNamespace(self, rootNamespace: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def RegisterNamedModel(self, modelName: win32more.Windows.Win32.Foundation.PWSTR, modeObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def UnregisterNamedModel(self, modelName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def AcquireNamedModel(self, modelName: win32more.Windows.Win32.Foundation.PWSTR, modelObject: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelManager2(ComPtr):
    extends: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelManager
    _iid_ = Guid('{f412c5ea-2284-4622-a660-a697160d3312}')
    @commethod(23)
    def AcquireSubNamespace(self, modelName: win32more.Windows.Win32.Foundation.PWSTR, subNamespaceModelName: win32more.Windows.Win32.Foundation.PWSTR, accessName: win32more.Windows.Win32.Foundation.PWSTR, metadata: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore, namespaceModelObject: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def CreateTypedIntrinsicObjectEx(self, context: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext, intrinsicData: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), type: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelNameBinder(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{af352b7b-8292-4c01-b360-2dc3696c65e7}')
    @commethod(3)
    def BindValue(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, name: win32more.Windows.Win32.Foundation.PWSTR, value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), metadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def BindReference(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, name: win32more.Windows.Win32.Foundation.PWSTR, reference: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), metadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def EnumerateValues(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, enumerator: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def EnumerateReferences(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, enumerator: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelScript(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7b4d30fc-b14a-49f8-8d87-d9a1480c97f7}')
    @commethod(3)
    def GetName(self, scriptName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Rename(self, scriptName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Populate(self, contentStream: win32more.Windows.Win32.System.Com.IStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Execute(self, client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptClient) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Unlink(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def IsInvocable(self, isInvocable: POINTER(Boolean)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def InvokeMain(self, client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptClient) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelScriptClient(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3b362b0e-89f0-46c6-a663-dfdc95194aef}')
    @commethod(3)
    def ReportError(self, errClass: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ErrorClass, hrFail: win32more.Windows.Win32.Foundation.HRESULT, message: win32more.Windows.Win32.Foundation.PWSTR, line: UInt32, position: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelScriptDebug(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{de8e0945-9750-4471-ab76-a8f79d6ec350}')
    @commethod(3)
    def GetDebugState(self) -> win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugState: ...
    @commethod(4)
    def GetCurrentPosition(self, currentPosition: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugPosition), positionSpanEnd: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugPosition), lineText: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetStack(self, stack: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptDebugStack)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetBreakpoint(self, linePosition: UInt32, columnPosition: UInt32, breakpoint: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def FindBreakpointById(self, breakpointId: UInt64, breakpoint: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def EnumerateBreakpoints(self, breakpointEnum: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptDebugBreakpointEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetEventFilter(self, eventFilter: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugEventFilter, isBreakEnabled: POINTER(Boolean)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetEventFilter(self, eventFilter: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugEventFilter, isBreakEnabled: Byte) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def StartDebugging(self, debugClient: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptDebugClient) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def StopDebugging(self, debugClient: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptDebugClient) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelScriptDebug2(ComPtr):
    extends: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptDebug
    _iid_ = Guid('{cbb10ed3-839e-426c-9243-e23535c1ae1a}')
    @commethod(13)
    def SetBreakpointAtFunction(self, functionName: win32more.Windows.Win32.Foundation.PWSTR, breakpoint: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelScriptDebugBreakpoint(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6bb27b35-02e6-47cb-90a0-5371244032de}')
    @commethod(3)
    def GetId(self) -> UInt64: ...
    @commethod(4)
    def IsEnabled(self) -> Boolean: ...
    @commethod(5)
    def Enable(self) -> Void: ...
    @commethod(6)
    def Disable(self) -> Void: ...
    @commethod(7)
    def Remove(self) -> Void: ...
    @commethod(8)
    def GetPosition(self, position: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugPosition), positionSpanEnd: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugPosition), lineText: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelScriptDebugBreakpointEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{39484a75-b4f3-4799-86da-691afa57b299}')
    @commethod(3)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetNext(self, breakpoint: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelScriptDebugClient(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{53159b6d-d4c4-471b-a863-5b110ca800ca}')
    @commethod(3)
    def NotifyDebugEvent(self, pEventInfo: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugEventInformation), pScript: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScript, pEventDataObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, resumeEventKind: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptExecutionKind)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelScriptDebugStack(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{051364dd-e449-443e-9762-fe578f4a5473}')
    @commethod(3)
    def GetFrameCount(self) -> UInt64: ...
    @commethod(4)
    def GetStackFrame(self, frameNumber: UInt64, stackFrame: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptDebugStackFrame)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelScriptDebugStackFrame(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{dec6ed5e-6360-4941-ab4c-a26409de4f82}')
    @commethod(3)
    def GetName(self, name: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetPosition(self, position: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugPosition), positionSpanEnd: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugPosition), lineText: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def IsTransitionPoint(self, isTransitionPoint: POINTER(Boolean)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetTransition(self, transitionScript: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScript), isTransitionContiguous: POINTER(Boolean)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Evaluate(self, pwszExpression: win32more.Windows.Win32.Foundation.PWSTR, ppResult: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def EnumerateLocals(self, variablesEnum: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptDebugVariableSetEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def EnumerateArguments(self, variablesEnum: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptDebugVariableSetEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelScriptDebugVariableSetEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0f9feed7-d045-4ac3-98a8-a98942cf6a35}')
    @commethod(3)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetNext(self, variableName: POINTER(win32more.Windows.Win32.Foundation.BSTR), variableValue: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), variableMetadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelScriptHostContext(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{014d366a-1f23-4981-9219-b2db8b402054}')
    @commethod(3)
    def NotifyScriptChange(self, script: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScript, changeKind: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptChangeKind) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetNamespaceObject(self, namespaceObject: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelScriptManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6fd11e33-e5ad-410b-8011-68c6bc4bf80d}')
    @commethod(3)
    def GetDefaultNameBinder(self, ppNameBinder: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelNameBinder)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def RegisterScriptProvider(self, provider: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptProvider) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def UnregisterScriptProvider(self, provider: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptProvider) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def FindProviderForScriptType(self, scriptType: win32more.Windows.Win32.Foundation.PWSTR, provider: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptProvider)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def FindProviderForScriptExtension(self, scriptExtension: win32more.Windows.Win32.Foundation.PWSTR, provider: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptProvider)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def EnumerateScriptProviders(self, enumerator: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptProviderEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelScriptProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{513461e0-4fca-48ce-8658-32f3e2056f3b}')
    @commethod(3)
    def GetName(self, name: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetExtension(self, extension: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateScript(self, script: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScript)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetDefaultTemplateContent(self, templateContent: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptTemplate)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def EnumerateTemplates(self, enumerator: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptTemplateEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelScriptProviderEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{95ba00e2-704a-4fe2-a8f1-a7e7d8fb0941}')
    @commethod(3)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetNext(self, provider: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptProvider)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelScriptTemplate(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1303dec4-fa3b-4f1b-9224-b953d16babb5}')
    @commethod(3)
    def GetName(self, templateName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDescription(self, templateDescription: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetContent(self, contentStream: POINTER(win32more.Windows.Win32.System.Com.IStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataModelScriptTemplateEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{69ce6ae2-2268-4e6f-b062-20ce62bfe677}')
    @commethod(3)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetNext(self, templateContent: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptTemplate)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugAdvanced(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f2df5f53-071f-47bd-9de6-5734c3fed689}')
    @commethod(3)
    def GetThreadContext(self, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetThreadContext(self, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugAdvanced2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{716d14c9-119b-4ba5-af1f-0890e672416a}')
    @commethod(3)
    def GetThreadContext(self, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetThreadContext(self, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Request(self, Request: UInt32, InBuffer: VoidPtr, InBufferSize: UInt32, OutBuffer: VoidPtr, OutBufferSize: UInt32, OutSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetSourceFileInformation(self, Which: UInt32, SourceFile: win32more.Windows.Win32.Foundation.PSTR, Arg64: UInt64, Arg32: UInt32, Buffer: VoidPtr, BufferSize: UInt32, InfoSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def FindSourceFileAndToken(self, StartElement: UInt32, ModAddr: UInt64, File: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, FileToken: VoidPtr, FileTokenSize: UInt32, FoundElement: POINTER(UInt32), Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FoundSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetSymbolInformation(self, Which: UInt32, Arg64: UInt64, Arg32: UInt32, Buffer: VoidPtr, BufferSize: UInt32, InfoSize: POINTER(UInt32), StringBuffer: win32more.Windows.Win32.Foundation.PSTR, StringBufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetSystemObjectInformation(self, Which: UInt32, Arg64: UInt64, Arg32: UInt32, Buffer: VoidPtr, BufferSize: UInt32, InfoSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugAdvanced3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{cba4abb4-84c4-444d-87ca-a04e13286739}')
    @commethod(3)
    def GetThreadContext(self, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetThreadContext(self, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Request(self, Request: UInt32, InBuffer: VoidPtr, InBufferSize: UInt32, OutBuffer: VoidPtr, OutBufferSize: UInt32, OutSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetSourceFileInformation(self, Which: UInt32, SourceFile: win32more.Windows.Win32.Foundation.PSTR, Arg64: UInt64, Arg32: UInt32, Buffer: VoidPtr, BufferSize: UInt32, InfoSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def FindSourceFileAndToken(self, StartElement: UInt32, ModAddr: UInt64, File: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, FileToken: VoidPtr, FileTokenSize: UInt32, FoundElement: POINTER(UInt32), Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FoundSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetSymbolInformation(self, Which: UInt32, Arg64: UInt64, Arg32: UInt32, Buffer: VoidPtr, BufferSize: UInt32, InfoSize: POINTER(UInt32), StringBuffer: win32more.Windows.Win32.Foundation.PSTR, StringBufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetSystemObjectInformation(self, Which: UInt32, Arg64: UInt64, Arg32: UInt32, Buffer: VoidPtr, BufferSize: UInt32, InfoSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetSourceFileInformationWide(self, Which: UInt32, SourceFile: win32more.Windows.Win32.Foundation.PWSTR, Arg64: UInt64, Arg32: UInt32, Buffer: VoidPtr, BufferSize: UInt32, InfoSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def FindSourceFileAndTokenWide(self, StartElement: UInt32, ModAddr: UInt64, File: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, FileToken: VoidPtr, FileTokenSize: UInt32, FoundElement: POINTER(UInt32), Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, FoundSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetSymbolInformationWide(self, Which: UInt32, Arg64: UInt64, Arg32: UInt32, Buffer: VoidPtr, BufferSize: UInt32, InfoSize: POINTER(UInt32), StringBuffer: win32more.Windows.Win32.Foundation.PWSTR, StringBufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugAdvanced4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d1069067-2a65-4bf0-ae97-76184b67856b}')
    @commethod(3)
    def GetThreadContext(self, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetThreadContext(self, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Request(self, Request: UInt32, InBuffer: VoidPtr, InBufferSize: UInt32, OutBuffer: VoidPtr, OutBufferSize: UInt32, OutSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetSourceFileInformation(self, Which: UInt32, SourceFile: win32more.Windows.Win32.Foundation.PSTR, Arg64: UInt64, Arg32: UInt32, Buffer: VoidPtr, BufferSize: UInt32, InfoSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def FindSourceFileAndToken(self, StartElement: UInt32, ModAddr: UInt64, File: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, FileToken: VoidPtr, FileTokenSize: UInt32, FoundElement: POINTER(UInt32), Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FoundSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetSymbolInformation(self, Which: UInt32, Arg64: UInt64, Arg32: UInt32, Buffer: VoidPtr, BufferSize: UInt32, InfoSize: POINTER(UInt32), StringBuffer: win32more.Windows.Win32.Foundation.PSTR, StringBufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetSystemObjectInformation(self, Which: UInt32, Arg64: UInt64, Arg32: UInt32, Buffer: VoidPtr, BufferSize: UInt32, InfoSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetSourceFileInformationWide(self, Which: UInt32, SourceFile: win32more.Windows.Win32.Foundation.PWSTR, Arg64: UInt64, Arg32: UInt32, Buffer: VoidPtr, BufferSize: UInt32, InfoSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def FindSourceFileAndTokenWide(self, StartElement: UInt32, ModAddr: UInt64, File: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, FileToken: VoidPtr, FileTokenSize: UInt32, FoundElement: POINTER(UInt32), Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, FoundSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetSymbolInformationWide(self, Which: UInt32, Arg64: UInt64, Arg32: UInt32, Buffer: VoidPtr, BufferSize: UInt32, InfoSize: POINTER(UInt32), StringBuffer: win32more.Windows.Win32.Foundation.PWSTR, StringBufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetSymbolInformationWideEx(self, Which: UInt32, Arg64: UInt64, Arg32: UInt32, Buffer: VoidPtr, BufferSize: UInt32, InfoSize: POINTER(UInt32), StringBuffer: win32more.Windows.Win32.Foundation.PWSTR, StringBufferSize: UInt32, StringSize: POINTER(UInt32), pInfoEx: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SYMBOL_INFO_EX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugBreakpoint(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5bd9d474-5975-423a-b88b-65a8e7110e65}')
    @commethod(3)
    def GetId(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetType(self, BreakType: POINTER(UInt32), ProcType: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetAdder(self, Adder: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetFlags(self, Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def AddFlags(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def RemoveFlags(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetFlags(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetOffset(self, Offset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetDataParameters(self, Size: POINTER(UInt32), AccessType: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetDataParameters(self, Size: UInt32, AccessType: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetPassCount(self, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetPassCount(self, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetCurrentPassCount(self, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetMatchThreadId(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetMatchThreadId(self, Thread: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetCommand(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetCommand(self, Command: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetOffsetExpression(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ExpressionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def SetOffsetExpression(self, Expression: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetParameters(self, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_BREAKPOINT_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugBreakpoint2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1b278d20-79f2-426e-a3f9-c1ddf375d48e}')
    @commethod(3)
    def GetId(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetType(self, BreakType: POINTER(UInt32), ProcType: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetAdder(self, Adder: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetFlags(self, Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def AddFlags(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def RemoveFlags(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetFlags(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetOffset(self, Offset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetDataParameters(self, Size: POINTER(UInt32), AccessType: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetDataParameters(self, Size: UInt32, AccessType: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetPassCount(self, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetPassCount(self, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetCurrentPassCount(self, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetMatchThreadId(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetMatchThreadId(self, Thread: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetCommand(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetCommand(self, Command: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetOffsetExpression(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ExpressionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def SetOffsetExpression(self, Expression: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetParameters(self, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_BREAKPOINT_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetCommandWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def SetCommandWide(self, Command: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetOffsetExpressionWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, ExpressionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def SetOffsetExpressionWide(self, Expression: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugBreakpoint3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{38f5c249-b448-43bb-9835-579d4ec02249}')
    @commethod(3)
    def GetId(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetType(self, BreakType: POINTER(UInt32), ProcType: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetAdder(self, Adder: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetFlags(self, Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def AddFlags(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def RemoveFlags(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetFlags(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetOffset(self, Offset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetDataParameters(self, Size: POINTER(UInt32), AccessType: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetDataParameters(self, Size: UInt32, AccessType: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetPassCount(self, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetPassCount(self, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetCurrentPassCount(self, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetMatchThreadId(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetMatchThreadId(self, Thread: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetCommand(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetCommand(self, Command: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetOffsetExpression(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ExpressionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def SetOffsetExpression(self, Expression: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetParameters(self, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_BREAKPOINT_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetCommandWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def SetCommandWide(self, Command: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetOffsetExpressionWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, ExpressionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def SetOffsetExpressionWide(self, Expression: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def GetGuid(self, Guid: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugClient(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{27fe5639-8407-4f47-8364-ee118fb08ac8}')
    @commethod(3)
    def AttachKernel(self, Flags: UInt32, ConnectOptions: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetKernelConnectionOptions(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, OptionsSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetKernelConnectionOptions(self, Options: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def StartProcessServer(self, Flags: UInt32, Options: win32more.Windows.Win32.Foundation.PSTR, Reserved: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ConnectProcessServer(self, RemoteOptions: win32more.Windows.Win32.Foundation.PSTR, Server: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DisconnectProcessServer(self, Server: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetRunningProcessSystemIds(self, Server: UInt64, Ids: POINTER(UInt32), Count: UInt32, ActualCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetRunningProcessSystemIdByExecutableName(self, Server: UInt64, ExeName: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetRunningProcessDescription(self, Server: UInt64, SystemId: UInt32, Flags: UInt32, ExeName: win32more.Windows.Win32.Foundation.PSTR, ExeNameSize: UInt32, ActualExeNameSize: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PSTR, DescriptionSize: UInt32, ActualDescriptionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def AttachProcess(self, Server: UInt64, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateProcessA(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, CreateFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateProcessAndAttach(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, CreateFlags: UInt32, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetProcessOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def AddProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def RemoveProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def OpenDumpFile(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def WriteDumpFile(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR, Qualifier: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def ConnectSession(self, Flags: UInt32, HistoryLimit: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def StartServer(self, Options: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def OutputServers(self, OutputControl: UInt32, Machine: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def TerminateProcesses(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def DetachProcesses(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def EndSession(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetExitCode(self, Code: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def DispatchCallbacks(self, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def ExitDispatch(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def CreateClient(self, Client: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetInputCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugInputCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetInputCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugInputCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetOutputCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def SetOutputCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetOutputMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def SetOutputMask(self, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetOtherOutputMask(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def SetOtherOutputMask(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def GetOutputWidth(self, Columns: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def SetOutputWidth(self, Columns: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetOutputLinePrefix(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PrefixSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def SetOutputLinePrefix(self, Prefix: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def GetIdentity(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, IdentitySize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def OutputIdentity(self, OutputControl: UInt32, Flags: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetEventCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def SetEventCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def FlushCallbacks(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugClient2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{edbed635-372e-4dab-bbfe-ed0d2f63be81}')
    @commethod(3)
    def AttachKernel(self, Flags: UInt32, ConnectOptions: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetKernelConnectionOptions(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, OptionsSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetKernelConnectionOptions(self, Options: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def StartProcessServer(self, Flags: UInt32, Options: win32more.Windows.Win32.Foundation.PSTR, Reserved: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ConnectProcessServer(self, RemoteOptions: win32more.Windows.Win32.Foundation.PSTR, Server: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DisconnectProcessServer(self, Server: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetRunningProcessSystemIds(self, Server: UInt64, Ids: POINTER(UInt32), Count: UInt32, ActualCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetRunningProcessSystemIdByExecutableName(self, Server: UInt64, ExeName: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetRunningProcessDescription(self, Server: UInt64, SystemId: UInt32, Flags: UInt32, ExeName: win32more.Windows.Win32.Foundation.PSTR, ExeNameSize: UInt32, ActualExeNameSize: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PSTR, DescriptionSize: UInt32, ActualDescriptionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def AttachProcess(self, Server: UInt64, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateProcessA(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, CreateFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateProcessAndAttach(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, CreateFlags: UInt32, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetProcessOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def AddProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def RemoveProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def OpenDumpFile(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def WriteDumpFile(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR, Qualifier: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def ConnectSession(self, Flags: UInt32, HistoryLimit: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def StartServer(self, Options: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def OutputServers(self, OutputControl: UInt32, Machine: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def TerminateProcesses(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def DetachProcesses(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def EndSession(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetExitCode(self, Code: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def DispatchCallbacks(self, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def ExitDispatch(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def CreateClient(self, Client: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetInputCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugInputCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetInputCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugInputCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetOutputCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def SetOutputCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetOutputMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def SetOutputMask(self, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetOtherOutputMask(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def SetOtherOutputMask(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def GetOutputWidth(self, Columns: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def SetOutputWidth(self, Columns: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetOutputLinePrefix(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PrefixSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def SetOutputLinePrefix(self, Prefix: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def GetIdentity(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, IdentitySize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def OutputIdentity(self, OutputControl: UInt32, Flags: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetEventCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def SetEventCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def FlushCallbacks(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def WriteDumpFile2(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR, Qualifier: UInt32, FormatFlags: UInt32, Comment: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def AddDumpInformationFile(self, InfoFile: win32more.Windows.Win32.Foundation.PSTR, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def EndProcessServer(self, Server: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def WaitForProcessServerEnd(self, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def IsKernelDebuggerEnabled(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def TerminateCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def DetachCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def AbandonCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugClient3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{dd492d7f-71b8-4ad6-a8dc-1c887479ff91}')
    @commethod(3)
    def AttachKernel(self, Flags: UInt32, ConnectOptions: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetKernelConnectionOptions(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, OptionsSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetKernelConnectionOptions(self, Options: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def StartProcessServer(self, Flags: UInt32, Options: win32more.Windows.Win32.Foundation.PSTR, Reserved: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ConnectProcessServer(self, RemoteOptions: win32more.Windows.Win32.Foundation.PSTR, Server: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DisconnectProcessServer(self, Server: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetRunningProcessSystemIds(self, Server: UInt64, Ids: POINTER(UInt32), Count: UInt32, ActualCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetRunningProcessSystemIdByExecutableName(self, Server: UInt64, ExeName: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetRunningProcessDescription(self, Server: UInt64, SystemId: UInt32, Flags: UInt32, ExeName: win32more.Windows.Win32.Foundation.PSTR, ExeNameSize: UInt32, ActualExeNameSize: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PSTR, DescriptionSize: UInt32, ActualDescriptionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def AttachProcess(self, Server: UInt64, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateProcessA(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, CreateFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateProcessAndAttach(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, CreateFlags: UInt32, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetProcessOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def AddProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def RemoveProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def OpenDumpFile(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def WriteDumpFile(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR, Qualifier: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def ConnectSession(self, Flags: UInt32, HistoryLimit: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def StartServer(self, Options: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def OutputServers(self, OutputControl: UInt32, Machine: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def TerminateProcesses(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def DetachProcesses(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def EndSession(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetExitCode(self, Code: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def DispatchCallbacks(self, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def ExitDispatch(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def CreateClient(self, Client: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetInputCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugInputCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetInputCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugInputCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetOutputCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def SetOutputCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetOutputMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def SetOutputMask(self, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetOtherOutputMask(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def SetOtherOutputMask(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def GetOutputWidth(self, Columns: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def SetOutputWidth(self, Columns: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetOutputLinePrefix(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PrefixSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def SetOutputLinePrefix(self, Prefix: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def GetIdentity(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, IdentitySize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def OutputIdentity(self, OutputControl: UInt32, Flags: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetEventCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def SetEventCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def FlushCallbacks(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def WriteDumpFile2(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR, Qualifier: UInt32, FormatFlags: UInt32, Comment: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def AddDumpInformationFile(self, InfoFile: win32more.Windows.Win32.Foundation.PSTR, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def EndProcessServer(self, Server: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def WaitForProcessServerEnd(self, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def IsKernelDebuggerEnabled(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def TerminateCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def DetachCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def AbandonCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def GetRunningProcessSystemIdByExecutableNameWide(self, Server: UInt64, ExeName: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def GetRunningProcessDescriptionWide(self, Server: UInt64, SystemId: UInt32, Flags: UInt32, ExeName: win32more.Windows.Win32.Foundation.PWSTR, ExeNameSize: UInt32, ActualExeNameSize: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PWSTR, DescriptionSize: UInt32, ActualDescriptionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def CreateProcessWide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, CreateFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def CreateProcessAndAttachWide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, CreateFlags: UInt32, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugClient4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ca83c3de-5089-4cf8-93c8-d892387f2a5e}')
    @commethod(3)
    def AttachKernel(self, Flags: UInt32, ConnectOptions: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetKernelConnectionOptions(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, OptionsSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetKernelConnectionOptions(self, Options: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def StartProcessServer(self, Flags: UInt32, Options: win32more.Windows.Win32.Foundation.PSTR, Reserved: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ConnectProcessServer(self, RemoteOptions: win32more.Windows.Win32.Foundation.PSTR, Server: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DisconnectProcessServer(self, Server: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetRunningProcessSystemIds(self, Server: UInt64, Ids: POINTER(UInt32), Count: UInt32, ActualCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetRunningProcessSystemIdByExecutableName(self, Server: UInt64, ExeName: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetRunningProcessDescription(self, Server: UInt64, SystemId: UInt32, Flags: UInt32, ExeName: win32more.Windows.Win32.Foundation.PSTR, ExeNameSize: UInt32, ActualExeNameSize: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PSTR, DescriptionSize: UInt32, ActualDescriptionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def AttachProcess(self, Server: UInt64, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateProcessA(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, CreateFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateProcessAndAttach(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, CreateFlags: UInt32, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetProcessOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def AddProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def RemoveProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def OpenDumpFile(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def WriteDumpFile(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR, Qualifier: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def ConnectSession(self, Flags: UInt32, HistoryLimit: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def StartServer(self, Options: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def OutputServers(self, OutputControl: UInt32, Machine: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def TerminateProcesses(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def DetachProcesses(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def EndSession(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetExitCode(self, Code: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def DispatchCallbacks(self, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def ExitDispatch(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def CreateClient(self, Client: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetInputCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugInputCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetInputCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugInputCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetOutputCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def SetOutputCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetOutputMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def SetOutputMask(self, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetOtherOutputMask(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def SetOtherOutputMask(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def GetOutputWidth(self, Columns: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def SetOutputWidth(self, Columns: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetOutputLinePrefix(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PrefixSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def SetOutputLinePrefix(self, Prefix: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def GetIdentity(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, IdentitySize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def OutputIdentity(self, OutputControl: UInt32, Flags: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetEventCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def SetEventCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def FlushCallbacks(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def WriteDumpFile2(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR, Qualifier: UInt32, FormatFlags: UInt32, Comment: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def AddDumpInformationFile(self, InfoFile: win32more.Windows.Win32.Foundation.PSTR, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def EndProcessServer(self, Server: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def WaitForProcessServerEnd(self, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def IsKernelDebuggerEnabled(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def TerminateCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def DetachCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def AbandonCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def GetRunningProcessSystemIdByExecutableNameWide(self, Server: UInt64, ExeName: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def GetRunningProcessDescriptionWide(self, Server: UInt64, SystemId: UInt32, Flags: UInt32, ExeName: win32more.Windows.Win32.Foundation.PWSTR, ExeNameSize: UInt32, ActualExeNameSize: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PWSTR, DescriptionSize: UInt32, ActualDescriptionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def CreateProcessWide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, CreateFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def CreateProcessAndAttachWide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, CreateFlags: UInt32, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def OpenDumpFileWide(self, FileName: win32more.Windows.Win32.Foundation.PWSTR, FileHandle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def WriteDumpFileWide(self, FileName: win32more.Windows.Win32.Foundation.PWSTR, FileHandle: UInt64, Qualifier: UInt32, FormatFlags: UInt32, Comment: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def AddDumpInformationFileWide(self, FileName: win32more.Windows.Win32.Foundation.PWSTR, FileHandle: UInt64, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def GetNumberDumpFiles(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def GetDumpFile(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, NameSize: POINTER(UInt32), Handle: POINTER(UInt64), Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def GetDumpFileWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, NameSize: POINTER(UInt32), Handle: POINTER(UInt64), Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugClient5(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e3acb9d7-7ec2-4f0c-a0da-e81e0cbbe628}')
    @commethod(3)
    def AttachKernel(self, Flags: UInt32, ConnectOptions: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetKernelConnectionOptions(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, OptionsSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetKernelConnectionOptions(self, Options: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def StartProcessServer(self, Flags: UInt32, Options: win32more.Windows.Win32.Foundation.PSTR, Reserved: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ConnectProcessServer(self, RemoteOptions: win32more.Windows.Win32.Foundation.PSTR, Server: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DisconnectProcessServer(self, Server: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetRunningProcessSystemIds(self, Server: UInt64, Ids: POINTER(UInt32), Count: UInt32, ActualCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetRunningProcessSystemIdByExecutableName(self, Server: UInt64, ExeName: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetRunningProcessDescription(self, Server: UInt64, SystemId: UInt32, Flags: UInt32, ExeName: win32more.Windows.Win32.Foundation.PSTR, ExeNameSize: UInt32, ActualExeNameSize: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PSTR, DescriptionSize: UInt32, ActualDescriptionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def AttachProcess(self, Server: UInt64, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateProcessA(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, CreateFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateProcessAndAttach(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, CreateFlags: UInt32, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetProcessOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def AddProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def RemoveProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def OpenDumpFile(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def WriteDumpFile(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR, Qualifier: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def ConnectSession(self, Flags: UInt32, HistoryLimit: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def StartServer(self, Options: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def OutputServers(self, OutputControl: UInt32, Machine: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def TerminateProcesses(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def DetachProcesses(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def EndSession(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetExitCode(self, Code: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def DispatchCallbacks(self, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def ExitDispatch(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def CreateClient(self, Client: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetInputCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugInputCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetInputCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugInputCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetOutputCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def SetOutputCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetOutputMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def SetOutputMask(self, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetOtherOutputMask(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def SetOtherOutputMask(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def GetOutputWidth(self, Columns: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def SetOutputWidth(self, Columns: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetOutputLinePrefix(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PrefixSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def SetOutputLinePrefix(self, Prefix: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def GetIdentity(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, IdentitySize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def OutputIdentity(self, OutputControl: UInt32, Flags: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetEventCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def SetEventCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def FlushCallbacks(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def WriteDumpFile2(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR, Qualifier: UInt32, FormatFlags: UInt32, Comment: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def AddDumpInformationFile(self, InfoFile: win32more.Windows.Win32.Foundation.PSTR, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def EndProcessServer(self, Server: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def WaitForProcessServerEnd(self, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def IsKernelDebuggerEnabled(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def TerminateCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def DetachCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def AbandonCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def GetRunningProcessSystemIdByExecutableNameWide(self, Server: UInt64, ExeName: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def GetRunningProcessDescriptionWide(self, Server: UInt64, SystemId: UInt32, Flags: UInt32, ExeName: win32more.Windows.Win32.Foundation.PWSTR, ExeNameSize: UInt32, ActualExeNameSize: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PWSTR, DescriptionSize: UInt32, ActualDescriptionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def CreateProcessWide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, CreateFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def CreateProcessAndAttachWide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, CreateFlags: UInt32, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def OpenDumpFileWide(self, FileName: win32more.Windows.Win32.Foundation.PWSTR, FileHandle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def WriteDumpFileWide(self, FileName: win32more.Windows.Win32.Foundation.PWSTR, FileHandle: UInt64, Qualifier: UInt32, FormatFlags: UInt32, Comment: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def AddDumpInformationFileWide(self, FileName: win32more.Windows.Win32.Foundation.PWSTR, FileHandle: UInt64, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def GetNumberDumpFiles(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def GetDumpFile(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, NameSize: POINTER(UInt32), Handle: POINTER(UInt64), Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def GetDumpFileWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, NameSize: POINTER(UInt32), Handle: POINTER(UInt64), Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def AttachKernelWide(self, Flags: UInt32, ConnectOptions: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def GetKernelConnectionOptionsWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, OptionsSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def SetKernelConnectionOptionsWide(self, Options: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def StartProcessServerWide(self, Flags: UInt32, Options: win32more.Windows.Win32.Foundation.PWSTR, Reserved: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def ConnectProcessServerWide(self, RemoteOptions: win32more.Windows.Win32.Foundation.PWSTR, Server: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def StartServerWide(self, Options: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def OutputServersWide(self, OutputControl: UInt32, Machine: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def GetOutputCallbacksWide(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacksWide)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def SetOutputCallbacksWide(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacksWide) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def GetOutputLinePrefixWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, PrefixSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def SetOutputLinePrefixWide(self, Prefix: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def GetIdentityWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, IdentitySize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def OutputIdentityWide(self, OutputControl: UInt32, Flags: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def GetEventCallbacksWide(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacksWide)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def SetEventCallbacksWide(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacksWide) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def CreateProcess2(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, OptionsBuffer: VoidPtr, OptionsBufferSize: UInt32, InitialDirectory: win32more.Windows.Win32.Foundation.PSTR, Environment: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def CreateProcess2Wide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, OptionsBuffer: VoidPtr, OptionsBufferSize: UInt32, InitialDirectory: win32more.Windows.Win32.Foundation.PWSTR, Environment: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def CreateProcessAndAttach2(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, OptionsBuffer: VoidPtr, OptionsBufferSize: UInt32, InitialDirectory: win32more.Windows.Win32.Foundation.PSTR, Environment: win32more.Windows.Win32.Foundation.PSTR, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def CreateProcessAndAttach2Wide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, OptionsBuffer: VoidPtr, OptionsBufferSize: UInt32, InitialDirectory: win32more.Windows.Win32.Foundation.PWSTR, Environment: win32more.Windows.Win32.Foundation.PWSTR, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def PushOutputLinePrefix(self, NewPrefix: win32more.Windows.Win32.Foundation.PSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def PushOutputLinePrefixWide(self, NewPrefix: win32more.Windows.Win32.Foundation.PWSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def PopOutputLinePrefix(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def GetNumberInputCallbacks(self, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def GetNumberOutputCallbacks(self, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def GetNumberEventCallbacks(self, EventFlags: UInt32, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def GetQuitLockString(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def SetQuitLockString(self, String: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def GetQuitLockStringWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def SetQuitLockStringWide(self, String: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugClient6(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{fd28b4c5-c498-4686-a28e-62cad2154eb3}')
    @commethod(3)
    def AttachKernel(self, Flags: UInt32, ConnectOptions: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetKernelConnectionOptions(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, OptionsSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetKernelConnectionOptions(self, Options: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def StartProcessServer(self, Flags: UInt32, Options: win32more.Windows.Win32.Foundation.PSTR, Reserved: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ConnectProcessServer(self, RemoteOptions: win32more.Windows.Win32.Foundation.PSTR, Server: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DisconnectProcessServer(self, Server: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetRunningProcessSystemIds(self, Server: UInt64, Ids: POINTER(UInt32), Count: UInt32, ActualCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetRunningProcessSystemIdByExecutableName(self, Server: UInt64, ExeName: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetRunningProcessDescription(self, Server: UInt64, SystemId: UInt32, Flags: UInt32, ExeName: win32more.Windows.Win32.Foundation.PSTR, ExeNameSize: UInt32, ActualExeNameSize: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PSTR, DescriptionSize: UInt32, ActualDescriptionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def AttachProcess(self, Server: UInt64, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateProcessA(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, CreateFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateProcessAndAttach(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, CreateFlags: UInt32, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetProcessOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def AddProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def RemoveProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def OpenDumpFile(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def WriteDumpFile(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR, Qualifier: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def ConnectSession(self, Flags: UInt32, HistoryLimit: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def StartServer(self, Options: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def OutputServers(self, OutputControl: UInt32, Machine: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def TerminateProcesses(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def DetachProcesses(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def EndSession(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetExitCode(self, Code: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def DispatchCallbacks(self, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def ExitDispatch(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def CreateClient(self, Client: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetInputCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugInputCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetInputCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugInputCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetOutputCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def SetOutputCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetOutputMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def SetOutputMask(self, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetOtherOutputMask(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def SetOtherOutputMask(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def GetOutputWidth(self, Columns: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def SetOutputWidth(self, Columns: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetOutputLinePrefix(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PrefixSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def SetOutputLinePrefix(self, Prefix: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def GetIdentity(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, IdentitySize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def OutputIdentity(self, OutputControl: UInt32, Flags: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetEventCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def SetEventCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def FlushCallbacks(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def WriteDumpFile2(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR, Qualifier: UInt32, FormatFlags: UInt32, Comment: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def AddDumpInformationFile(self, InfoFile: win32more.Windows.Win32.Foundation.PSTR, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def EndProcessServer(self, Server: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def WaitForProcessServerEnd(self, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def IsKernelDebuggerEnabled(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def TerminateCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def DetachCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def AbandonCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def GetRunningProcessSystemIdByExecutableNameWide(self, Server: UInt64, ExeName: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def GetRunningProcessDescriptionWide(self, Server: UInt64, SystemId: UInt32, Flags: UInt32, ExeName: win32more.Windows.Win32.Foundation.PWSTR, ExeNameSize: UInt32, ActualExeNameSize: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PWSTR, DescriptionSize: UInt32, ActualDescriptionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def CreateProcessWide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, CreateFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def CreateProcessAndAttachWide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, CreateFlags: UInt32, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def OpenDumpFileWide(self, FileName: win32more.Windows.Win32.Foundation.PWSTR, FileHandle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def WriteDumpFileWide(self, FileName: win32more.Windows.Win32.Foundation.PWSTR, FileHandle: UInt64, Qualifier: UInt32, FormatFlags: UInt32, Comment: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def AddDumpInformationFileWide(self, FileName: win32more.Windows.Win32.Foundation.PWSTR, FileHandle: UInt64, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def GetNumberDumpFiles(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def GetDumpFile(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, NameSize: POINTER(UInt32), Handle: POINTER(UInt64), Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def GetDumpFileWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, NameSize: POINTER(UInt32), Handle: POINTER(UInt64), Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def AttachKernelWide(self, Flags: UInt32, ConnectOptions: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def GetKernelConnectionOptionsWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, OptionsSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def SetKernelConnectionOptionsWide(self, Options: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def StartProcessServerWide(self, Flags: UInt32, Options: win32more.Windows.Win32.Foundation.PWSTR, Reserved: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def ConnectProcessServerWide(self, RemoteOptions: win32more.Windows.Win32.Foundation.PWSTR, Server: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def StartServerWide(self, Options: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def OutputServersWide(self, OutputControl: UInt32, Machine: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def GetOutputCallbacksWide(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacksWide)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def SetOutputCallbacksWide(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacksWide) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def GetOutputLinePrefixWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, PrefixSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def SetOutputLinePrefixWide(self, Prefix: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def GetIdentityWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, IdentitySize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def OutputIdentityWide(self, OutputControl: UInt32, Flags: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def GetEventCallbacksWide(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacksWide)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def SetEventCallbacksWide(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacksWide) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def CreateProcess2(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, OptionsBuffer: VoidPtr, OptionsBufferSize: UInt32, InitialDirectory: win32more.Windows.Win32.Foundation.PSTR, Environment: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def CreateProcess2Wide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, OptionsBuffer: VoidPtr, OptionsBufferSize: UInt32, InitialDirectory: win32more.Windows.Win32.Foundation.PWSTR, Environment: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def CreateProcessAndAttach2(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, OptionsBuffer: VoidPtr, OptionsBufferSize: UInt32, InitialDirectory: win32more.Windows.Win32.Foundation.PSTR, Environment: win32more.Windows.Win32.Foundation.PSTR, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def CreateProcessAndAttach2Wide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, OptionsBuffer: VoidPtr, OptionsBufferSize: UInt32, InitialDirectory: win32more.Windows.Win32.Foundation.PWSTR, Environment: win32more.Windows.Win32.Foundation.PWSTR, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def PushOutputLinePrefix(self, NewPrefix: win32more.Windows.Win32.Foundation.PSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def PushOutputLinePrefixWide(self, NewPrefix: win32more.Windows.Win32.Foundation.PWSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def PopOutputLinePrefix(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def GetNumberInputCallbacks(self, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def GetNumberOutputCallbacks(self, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def GetNumberEventCallbacks(self, EventFlags: UInt32, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def GetQuitLockString(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def SetQuitLockString(self, String: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def GetQuitLockStringWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def SetQuitLockStringWide(self, String: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def SetEventContextCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventContextCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugClient7(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{13586be3-542e-481e-b1f2-8497ba74f9a9}')
    @commethod(3)
    def AttachKernel(self, Flags: UInt32, ConnectOptions: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetKernelConnectionOptions(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, OptionsSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetKernelConnectionOptions(self, Options: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def StartProcessServer(self, Flags: UInt32, Options: win32more.Windows.Win32.Foundation.PSTR, Reserved: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ConnectProcessServer(self, RemoteOptions: win32more.Windows.Win32.Foundation.PSTR, Server: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DisconnectProcessServer(self, Server: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetRunningProcessSystemIds(self, Server: UInt64, Ids: POINTER(UInt32), Count: UInt32, ActualCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetRunningProcessSystemIdByExecutableName(self, Server: UInt64, ExeName: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetRunningProcessDescription(self, Server: UInt64, SystemId: UInt32, Flags: UInt32, ExeName: win32more.Windows.Win32.Foundation.PSTR, ExeNameSize: UInt32, ActualExeNameSize: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PSTR, DescriptionSize: UInt32, ActualDescriptionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def AttachProcess(self, Server: UInt64, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateProcessA(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, CreateFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateProcessAndAttach(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, CreateFlags: UInt32, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetProcessOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def AddProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def RemoveProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def OpenDumpFile(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def WriteDumpFile(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR, Qualifier: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def ConnectSession(self, Flags: UInt32, HistoryLimit: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def StartServer(self, Options: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def OutputServers(self, OutputControl: UInt32, Machine: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def TerminateProcesses(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def DetachProcesses(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def EndSession(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetExitCode(self, Code: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def DispatchCallbacks(self, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def ExitDispatch(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def CreateClient(self, Client: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetInputCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugInputCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetInputCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugInputCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetOutputCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def SetOutputCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetOutputMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def SetOutputMask(self, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetOtherOutputMask(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def SetOtherOutputMask(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def GetOutputWidth(self, Columns: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def SetOutputWidth(self, Columns: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetOutputLinePrefix(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PrefixSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def SetOutputLinePrefix(self, Prefix: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def GetIdentity(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, IdentitySize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def OutputIdentity(self, OutputControl: UInt32, Flags: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetEventCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def SetEventCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def FlushCallbacks(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def WriteDumpFile2(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR, Qualifier: UInt32, FormatFlags: UInt32, Comment: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def AddDumpInformationFile(self, InfoFile: win32more.Windows.Win32.Foundation.PSTR, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def EndProcessServer(self, Server: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def WaitForProcessServerEnd(self, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def IsKernelDebuggerEnabled(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def TerminateCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def DetachCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def AbandonCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def GetRunningProcessSystemIdByExecutableNameWide(self, Server: UInt64, ExeName: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def GetRunningProcessDescriptionWide(self, Server: UInt64, SystemId: UInt32, Flags: UInt32, ExeName: win32more.Windows.Win32.Foundation.PWSTR, ExeNameSize: UInt32, ActualExeNameSize: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PWSTR, DescriptionSize: UInt32, ActualDescriptionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def CreateProcessWide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, CreateFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def CreateProcessAndAttachWide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, CreateFlags: UInt32, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def OpenDumpFileWide(self, FileName: win32more.Windows.Win32.Foundation.PWSTR, FileHandle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def WriteDumpFileWide(self, FileName: win32more.Windows.Win32.Foundation.PWSTR, FileHandle: UInt64, Qualifier: UInt32, FormatFlags: UInt32, Comment: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def AddDumpInformationFileWide(self, FileName: win32more.Windows.Win32.Foundation.PWSTR, FileHandle: UInt64, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def GetNumberDumpFiles(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def GetDumpFile(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, NameSize: POINTER(UInt32), Handle: POINTER(UInt64), Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def GetDumpFileWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, NameSize: POINTER(UInt32), Handle: POINTER(UInt64), Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def AttachKernelWide(self, Flags: UInt32, ConnectOptions: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def GetKernelConnectionOptionsWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, OptionsSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def SetKernelConnectionOptionsWide(self, Options: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def StartProcessServerWide(self, Flags: UInt32, Options: win32more.Windows.Win32.Foundation.PWSTR, Reserved: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def ConnectProcessServerWide(self, RemoteOptions: win32more.Windows.Win32.Foundation.PWSTR, Server: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def StartServerWide(self, Options: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def OutputServersWide(self, OutputControl: UInt32, Machine: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def GetOutputCallbacksWide(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacksWide)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def SetOutputCallbacksWide(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacksWide) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def GetOutputLinePrefixWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, PrefixSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def SetOutputLinePrefixWide(self, Prefix: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def GetIdentityWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, IdentitySize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def OutputIdentityWide(self, OutputControl: UInt32, Flags: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def GetEventCallbacksWide(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacksWide)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def SetEventCallbacksWide(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacksWide) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def CreateProcess2(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, OptionsBuffer: VoidPtr, OptionsBufferSize: UInt32, InitialDirectory: win32more.Windows.Win32.Foundation.PSTR, Environment: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def CreateProcess2Wide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, OptionsBuffer: VoidPtr, OptionsBufferSize: UInt32, InitialDirectory: win32more.Windows.Win32.Foundation.PWSTR, Environment: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def CreateProcessAndAttach2(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, OptionsBuffer: VoidPtr, OptionsBufferSize: UInt32, InitialDirectory: win32more.Windows.Win32.Foundation.PSTR, Environment: win32more.Windows.Win32.Foundation.PSTR, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def CreateProcessAndAttach2Wide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, OptionsBuffer: VoidPtr, OptionsBufferSize: UInt32, InitialDirectory: win32more.Windows.Win32.Foundation.PWSTR, Environment: win32more.Windows.Win32.Foundation.PWSTR, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def PushOutputLinePrefix(self, NewPrefix: win32more.Windows.Win32.Foundation.PSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def PushOutputLinePrefixWide(self, NewPrefix: win32more.Windows.Win32.Foundation.PWSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def PopOutputLinePrefix(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def GetNumberInputCallbacks(self, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def GetNumberOutputCallbacks(self, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def GetNumberEventCallbacks(self, EventFlags: UInt32, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def GetQuitLockString(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def SetQuitLockString(self, String: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def GetQuitLockStringWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def SetQuitLockStringWide(self, String: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def SetEventContextCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventContextCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def SetClientContext(self, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugClient8(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{cec43add-6375-469e-83d5-414e4033c19a}')
    @commethod(3)
    def AttachKernel(self, Flags: UInt32, ConnectOptions: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetKernelConnectionOptions(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, OptionsSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetKernelConnectionOptions(self, Options: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def StartProcessServer(self, Flags: UInt32, Options: win32more.Windows.Win32.Foundation.PSTR, Reserved: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ConnectProcessServer(self, RemoteOptions: win32more.Windows.Win32.Foundation.PSTR, Server: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DisconnectProcessServer(self, Server: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetRunningProcessSystemIds(self, Server: UInt64, Ids: POINTER(UInt32), Count: UInt32, ActualCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetRunningProcessSystemIdByExecutableName(self, Server: UInt64, ExeName: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetRunningProcessDescription(self, Server: UInt64, SystemId: UInt32, Flags: UInt32, ExeName: win32more.Windows.Win32.Foundation.PSTR, ExeNameSize: UInt32, ActualExeNameSize: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PSTR, DescriptionSize: UInt32, ActualDescriptionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def AttachProcess(self, Server: UInt64, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateProcessA(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, CreateFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateProcessAndAttach(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, CreateFlags: UInt32, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetProcessOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def AddProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def RemoveProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetProcessOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def OpenDumpFile(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def WriteDumpFile(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR, Qualifier: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def ConnectSession(self, Flags: UInt32, HistoryLimit: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def StartServer(self, Options: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def OutputServers(self, OutputControl: UInt32, Machine: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def TerminateProcesses(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def DetachProcesses(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def EndSession(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetExitCode(self, Code: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def DispatchCallbacks(self, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def ExitDispatch(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def CreateClient(self, Client: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetInputCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugInputCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetInputCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugInputCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetOutputCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def SetOutputCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetOutputMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def SetOutputMask(self, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetOtherOutputMask(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def SetOtherOutputMask(self, Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def GetOutputWidth(self, Columns: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def SetOutputWidth(self, Columns: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetOutputLinePrefix(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PrefixSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def SetOutputLinePrefix(self, Prefix: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def GetIdentity(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, IdentitySize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def OutputIdentity(self, OutputControl: UInt32, Flags: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetEventCallbacks(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def SetEventCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def FlushCallbacks(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def WriteDumpFile2(self, DumpFile: win32more.Windows.Win32.Foundation.PSTR, Qualifier: UInt32, FormatFlags: UInt32, Comment: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def AddDumpInformationFile(self, InfoFile: win32more.Windows.Win32.Foundation.PSTR, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def EndProcessServer(self, Server: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def WaitForProcessServerEnd(self, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def IsKernelDebuggerEnabled(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def TerminateCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def DetachCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def AbandonCurrentProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def GetRunningProcessSystemIdByExecutableNameWide(self, Server: UInt64, ExeName: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def GetRunningProcessDescriptionWide(self, Server: UInt64, SystemId: UInt32, Flags: UInt32, ExeName: win32more.Windows.Win32.Foundation.PWSTR, ExeNameSize: UInt32, ActualExeNameSize: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PWSTR, DescriptionSize: UInt32, ActualDescriptionSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def CreateProcessWide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, CreateFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def CreateProcessAndAttachWide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, CreateFlags: UInt32, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def OpenDumpFileWide(self, FileName: win32more.Windows.Win32.Foundation.PWSTR, FileHandle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def WriteDumpFileWide(self, FileName: win32more.Windows.Win32.Foundation.PWSTR, FileHandle: UInt64, Qualifier: UInt32, FormatFlags: UInt32, Comment: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def AddDumpInformationFileWide(self, FileName: win32more.Windows.Win32.Foundation.PWSTR, FileHandle: UInt64, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def GetNumberDumpFiles(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def GetDumpFile(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, NameSize: POINTER(UInt32), Handle: POINTER(UInt64), Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def GetDumpFileWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, NameSize: POINTER(UInt32), Handle: POINTER(UInt64), Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def AttachKernelWide(self, Flags: UInt32, ConnectOptions: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def GetKernelConnectionOptionsWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, OptionsSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def SetKernelConnectionOptionsWide(self, Options: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def StartProcessServerWide(self, Flags: UInt32, Options: win32more.Windows.Win32.Foundation.PWSTR, Reserved: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def ConnectProcessServerWide(self, RemoteOptions: win32more.Windows.Win32.Foundation.PWSTR, Server: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def StartServerWide(self, Options: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def OutputServersWide(self, OutputControl: UInt32, Machine: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def GetOutputCallbacksWide(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacksWide)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def SetOutputCallbacksWide(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputCallbacksWide) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def GetOutputLinePrefixWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, PrefixSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def SetOutputLinePrefixWide(self, Prefix: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def GetIdentityWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, IdentitySize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def OutputIdentityWide(self, OutputControl: UInt32, Flags: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def GetEventCallbacksWide(self, Callbacks: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacksWide)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def SetEventCallbacksWide(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventCallbacksWide) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def CreateProcess2(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, OptionsBuffer: VoidPtr, OptionsBufferSize: UInt32, InitialDirectory: win32more.Windows.Win32.Foundation.PSTR, Environment: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def CreateProcess2Wide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, OptionsBuffer: VoidPtr, OptionsBufferSize: UInt32, InitialDirectory: win32more.Windows.Win32.Foundation.PWSTR, Environment: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def CreateProcessAndAttach2(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PSTR, OptionsBuffer: VoidPtr, OptionsBufferSize: UInt32, InitialDirectory: win32more.Windows.Win32.Foundation.PSTR, Environment: win32more.Windows.Win32.Foundation.PSTR, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def CreateProcessAndAttach2Wide(self, Server: UInt64, CommandLine: win32more.Windows.Win32.Foundation.PWSTR, OptionsBuffer: VoidPtr, OptionsBufferSize: UInt32, InitialDirectory: win32more.Windows.Win32.Foundation.PWSTR, Environment: win32more.Windows.Win32.Foundation.PWSTR, ProcessId: UInt32, AttachFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def PushOutputLinePrefix(self, NewPrefix: win32more.Windows.Win32.Foundation.PSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def PushOutputLinePrefixWide(self, NewPrefix: win32more.Windows.Win32.Foundation.PWSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def PopOutputLinePrefix(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def GetNumberInputCallbacks(self, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def GetNumberOutputCallbacks(self, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def GetNumberEventCallbacks(self, EventFlags: UInt32, Count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def GetQuitLockString(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def SetQuitLockString(self, String: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def GetQuitLockStringWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def SetQuitLockStringWide(self, String: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def SetEventContextCallbacks(self, Callbacks: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugEventContextCallbacks) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def SetClientContext(self, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def OpenDumpFileWide2(self, FileName: win32more.Windows.Win32.Foundation.PWSTR, FileHandle: UInt64, AlternateArch: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugControl(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5182e668-105e-416e-ad92-24ef800424ba}')
    @commethod(3)
    def GetInterrupt(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetInterrupt(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetInterruptTimeout(self, Seconds: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetInterruptTimeout(self, Seconds: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetLogFile(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Append: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def OpenLogFile(self, File: win32more.Windows.Win32.Foundation.PSTR, Append: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CloseLogFile(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetLogMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetLogMask(self, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Input(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, InputSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def ReturnInput(self, Buffer: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Output(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def OutputVaList(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def ControlledOutput(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def ControlledOutputVaList(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def OutputPrompt(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def OutputPromptVaList(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetPromptText(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def OutputCurrentState(self, OutputControl: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def OutputVersionInformation(self, OutputControl: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetNotifyEventHandle(self, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def SetNotifyEventHandle(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def Assemble(self, Offset: UInt64, Instr: win32more.Windows.Win32.Foundation.PSTR, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def Disassemble(self, Offset: UInt64, Flags: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, DisassemblySize: POINTER(UInt32), EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetDisassembleEffectiveOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def OutputDisassembly(self, OutputControl: UInt32, Offset: UInt64, Flags: UInt32, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def OutputDisassemblyLines(self, OutputControl: UInt32, PreviousLines: UInt32, TotalLines: UInt32, Offset: UInt64, Flags: UInt32, OffsetLine: POINTER(UInt32), StartOffset: POINTER(UInt64), EndOffset: POINTER(UInt64), LineOffsets: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetNearInstruction(self, Offset: UInt64, Delta: Int32, NearOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetStackTrace(self, FrameOffset: UInt64, StackOffset: UInt64, InstructionOffset: UInt64, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, FramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def GetReturnOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def OutputStackTrace(self, OutputControl: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def GetDebuggeeType(self, Class: POINTER(UInt32), Qualifier: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetActualProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def GetExecutingProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetNumberPossibleExecutingProcessorTypes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def GetPossibleExecutingProcessorTypes(self, Start: UInt32, Count: UInt32, Types: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def GetNumberProcessors(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def GetSystemVersion(self, PlatformId: POINTER(UInt32), Major: POINTER(UInt32), Minor: POINTER(UInt32), ServicePackString: win32more.Windows.Win32.Foundation.PSTR, ServicePackStringSize: UInt32, ServicePackStringUsed: POINTER(UInt32), ServicePackNumber: POINTER(UInt32), BuildString: win32more.Windows.Win32.Foundation.PSTR, BuildStringSize: UInt32, BuildStringUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetPageSize(self, Size: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def IsPointer64Bit(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def ReadBugCheckData(self, Code: POINTER(UInt32), Arg1: POINTER(UInt64), Arg2: POINTER(UInt64), Arg3: POINTER(UInt64), Arg4: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def GetNumberSupportedProcessorTypes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetSupportedProcessorTypes(self, Start: UInt32, Count: UInt32, Types: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def GetProcessorTypeNames(self, Type: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def GetEffectiveProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def SetEffectiveProcessorType(self, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def GetExecutionStatus(self, Status: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def SetExecutionStatus(self, Status: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def GetCodeLevel(self, Level: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def SetCodeLevel(self, Level: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def GetEngineOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def AddEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def RemoveEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def SetEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def GetSystemErrorControl(self, OutputLevel: POINTER(UInt32), BreakLevel: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def SetSystemErrorControl(self, OutputLevel: UInt32, BreakLevel: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def GetTextMacro(self, Slot: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, MacroSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def SetTextMacro(self, Slot: UInt32, Macro: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def GetRadix(self, Radix: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def SetRadix(self, Radix: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def Evaluate(self, Expression: win32more.Windows.Win32.Foundation.PSTR, DesiredType: UInt32, Value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), RemainderIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def CoerceValue(self, In: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), OutType: UInt32, Out: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def CoerceValues(self, Count: UInt32, In: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), OutTypes: POINTER(UInt32), Out: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def Execute(self, OutputControl: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def ExecuteCommandFile(self, OutputControl: UInt32, CommandFile: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def GetNumberBreakpoints(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def GetBreakpointByIndex(self, Index: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def GetBreakpointById(self, Id: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def GetBreakpointParameters(self, Count: UInt32, Ids: POINTER(UInt32), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_BREAKPOINT_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def AddBreakpoint(self, Type: UInt32, DesiredId: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def RemoveBreakpoint(self, Bp: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def AddExtension(self, Path: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def RemoveExtension(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def GetExtensionByPath(self, Path: win32more.Windows.Win32.Foundation.PSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def CallExtension(self, Handle: UInt64, Function: win32more.Windows.Win32.Foundation.PSTR, Arguments: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def GetExtensionFunction(self, Handle: UInt64, FuncName: win32more.Windows.Win32.Foundation.PSTR, Function: POINTER(win32more.Windows.Win32.Foundation.FARPROC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def GetWindbgExtensionApis32(self, Api: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def GetWindbgExtensionApis64(self, Api: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def GetNumberEventFilters(self, SpecificEvents: POINTER(UInt32), SpecificExceptions: POINTER(UInt32), ArbitraryExceptions: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def GetEventFilterText(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def GetEventFilterCommand(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def SetEventFilterCommand(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def GetSpecificFilterParameters(self, Start: UInt32, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SPECIFIC_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def SetSpecificFilterParameters(self, Start: UInt32, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SPECIFIC_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def GetSpecificFilterArgument(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ArgumentSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def SetSpecificFilterArgument(self, Index: UInt32, Argument: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def GetExceptionFilterParameters(self, Count: UInt32, Codes: POINTER(UInt32), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_EXCEPTION_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def SetExceptionFilterParameters(self, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_EXCEPTION_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def GetExceptionFilterSecondCommand(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def SetExceptionFilterSecondCommand(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def WaitForEvent(self, Flags: UInt32, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def GetLastEventInformation(self, Type: POINTER(UInt32), ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32), ExtraInformation: VoidPtr, ExtraInformationSize: UInt32, ExtraInformationUsed: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PSTR, DescriptionSize: UInt32, DescriptionUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugControl2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d4366723-44df-4bed-8c7e-4c05424f4588}')
    @commethod(3)
    def GetInterrupt(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetInterrupt(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetInterruptTimeout(self, Seconds: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetInterruptTimeout(self, Seconds: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetLogFile(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Append: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def OpenLogFile(self, File: win32more.Windows.Win32.Foundation.PSTR, Append: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CloseLogFile(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetLogMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetLogMask(self, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Input(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, InputSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def ReturnInput(self, Buffer: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Output(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def OutputVaList(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def ControlledOutput(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def ControlledOutputVaList(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def OutputPrompt(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def OutputPromptVaList(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetPromptText(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def OutputCurrentState(self, OutputControl: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def OutputVersionInformation(self, OutputControl: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetNotifyEventHandle(self, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def SetNotifyEventHandle(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def Assemble(self, Offset: UInt64, Instr: win32more.Windows.Win32.Foundation.PSTR, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def Disassemble(self, Offset: UInt64, Flags: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, DisassemblySize: POINTER(UInt32), EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetDisassembleEffectiveOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def OutputDisassembly(self, OutputControl: UInt32, Offset: UInt64, Flags: UInt32, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def OutputDisassemblyLines(self, OutputControl: UInt32, PreviousLines: UInt32, TotalLines: UInt32, Offset: UInt64, Flags: UInt32, OffsetLine: POINTER(UInt32), StartOffset: POINTER(UInt64), EndOffset: POINTER(UInt64), LineOffsets: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetNearInstruction(self, Offset: UInt64, Delta: Int32, NearOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetStackTrace(self, FrameOffset: UInt64, StackOffset: UInt64, InstructionOffset: UInt64, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, FramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def GetReturnOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def OutputStackTrace(self, OutputControl: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def GetDebuggeeType(self, Class: POINTER(UInt32), Qualifier: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetActualProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def GetExecutingProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetNumberPossibleExecutingProcessorTypes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def GetPossibleExecutingProcessorTypes(self, Start: UInt32, Count: UInt32, Types: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def GetNumberProcessors(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def GetSystemVersion(self, PlatformId: POINTER(UInt32), Major: POINTER(UInt32), Minor: POINTER(UInt32), ServicePackString: win32more.Windows.Win32.Foundation.PSTR, ServicePackStringSize: UInt32, ServicePackStringUsed: POINTER(UInt32), ServicePackNumber: POINTER(UInt32), BuildString: win32more.Windows.Win32.Foundation.PSTR, BuildStringSize: UInt32, BuildStringUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetPageSize(self, Size: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def IsPointer64Bit(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def ReadBugCheckData(self, Code: POINTER(UInt32), Arg1: POINTER(UInt64), Arg2: POINTER(UInt64), Arg3: POINTER(UInt64), Arg4: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def GetNumberSupportedProcessorTypes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetSupportedProcessorTypes(self, Start: UInt32, Count: UInt32, Types: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def GetProcessorTypeNames(self, Type: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def GetEffectiveProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def SetEffectiveProcessorType(self, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def GetExecutionStatus(self, Status: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def SetExecutionStatus(self, Status: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def GetCodeLevel(self, Level: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def SetCodeLevel(self, Level: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def GetEngineOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def AddEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def RemoveEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def SetEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def GetSystemErrorControl(self, OutputLevel: POINTER(UInt32), BreakLevel: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def SetSystemErrorControl(self, OutputLevel: UInt32, BreakLevel: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def GetTextMacro(self, Slot: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, MacroSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def SetTextMacro(self, Slot: UInt32, Macro: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def GetRadix(self, Radix: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def SetRadix(self, Radix: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def Evaluate(self, Expression: win32more.Windows.Win32.Foundation.PSTR, DesiredType: UInt32, Value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), RemainderIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def CoerceValue(self, In: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), OutType: UInt32, Out: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def CoerceValues(self, Count: UInt32, In: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), OutTypes: POINTER(UInt32), Out: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def Execute(self, OutputControl: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def ExecuteCommandFile(self, OutputControl: UInt32, CommandFile: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def GetNumberBreakpoints(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def GetBreakpointByIndex(self, Index: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def GetBreakpointById(self, Id: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def GetBreakpointParameters(self, Count: UInt32, Ids: POINTER(UInt32), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_BREAKPOINT_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def AddBreakpoint(self, Type: UInt32, DesiredId: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def RemoveBreakpoint(self, Bp: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def AddExtension(self, Path: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def RemoveExtension(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def GetExtensionByPath(self, Path: win32more.Windows.Win32.Foundation.PSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def CallExtension(self, Handle: UInt64, Function: win32more.Windows.Win32.Foundation.PSTR, Arguments: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def GetExtensionFunction(self, Handle: UInt64, FuncName: win32more.Windows.Win32.Foundation.PSTR, Function: POINTER(win32more.Windows.Win32.Foundation.FARPROC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def GetWindbgExtensionApis32(self, Api: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def GetWindbgExtensionApis64(self, Api: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def GetNumberEventFilters(self, SpecificEvents: POINTER(UInt32), SpecificExceptions: POINTER(UInt32), ArbitraryExceptions: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def GetEventFilterText(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def GetEventFilterCommand(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def SetEventFilterCommand(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def GetSpecificFilterParameters(self, Start: UInt32, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SPECIFIC_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def SetSpecificFilterParameters(self, Start: UInt32, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SPECIFIC_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def GetSpecificFilterArgument(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ArgumentSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def SetSpecificFilterArgument(self, Index: UInt32, Argument: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def GetExceptionFilterParameters(self, Count: UInt32, Codes: POINTER(UInt32), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_EXCEPTION_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def SetExceptionFilterParameters(self, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_EXCEPTION_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def GetExceptionFilterSecondCommand(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def SetExceptionFilterSecondCommand(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def WaitForEvent(self, Flags: UInt32, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def GetLastEventInformation(self, Type: POINTER(UInt32), ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32), ExtraInformation: VoidPtr, ExtraInformationSize: UInt32, ExtraInformationUsed: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PSTR, DescriptionSize: UInt32, DescriptionUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def GetCurrentTimeDate(self, TimeDate: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def GetCurrentSystemUpTime(self, UpTime: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def GetDumpFormatFlags(self, FormatFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def GetNumberTextReplacements(self, NumRepl: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def GetTextReplacement(self, SrcText: win32more.Windows.Win32.Foundation.PSTR, Index: UInt32, SrcBuffer: win32more.Windows.Win32.Foundation.PSTR, SrcBufferSize: UInt32, SrcSize: POINTER(UInt32), DstBuffer: win32more.Windows.Win32.Foundation.PSTR, DstBufferSize: UInt32, DstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def SetTextReplacement(self, SrcText: win32more.Windows.Win32.Foundation.PSTR, DstText: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def RemoveTextReplacements(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def OutputTextReplacements(self, OutputControl: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugControl3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7df74a86-b03f-407f-90ab-a20dadcead08}')
    @commethod(3)
    def GetInterrupt(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetInterrupt(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetInterruptTimeout(self, Seconds: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetInterruptTimeout(self, Seconds: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetLogFile(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Append: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def OpenLogFile(self, File: win32more.Windows.Win32.Foundation.PSTR, Append: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CloseLogFile(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetLogMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetLogMask(self, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Input(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, InputSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def ReturnInput(self, Buffer: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Output(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def OutputVaList(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def ControlledOutput(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def ControlledOutputVaList(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def OutputPrompt(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def OutputPromptVaList(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetPromptText(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def OutputCurrentState(self, OutputControl: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def OutputVersionInformation(self, OutputControl: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetNotifyEventHandle(self, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def SetNotifyEventHandle(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def Assemble(self, Offset: UInt64, Instr: win32more.Windows.Win32.Foundation.PSTR, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def Disassemble(self, Offset: UInt64, Flags: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, DisassemblySize: POINTER(UInt32), EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetDisassembleEffectiveOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def OutputDisassembly(self, OutputControl: UInt32, Offset: UInt64, Flags: UInt32, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def OutputDisassemblyLines(self, OutputControl: UInt32, PreviousLines: UInt32, TotalLines: UInt32, Offset: UInt64, Flags: UInt32, OffsetLine: POINTER(UInt32), StartOffset: POINTER(UInt64), EndOffset: POINTER(UInt64), LineOffsets: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetNearInstruction(self, Offset: UInt64, Delta: Int32, NearOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetStackTrace(self, FrameOffset: UInt64, StackOffset: UInt64, InstructionOffset: UInt64, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, FramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def GetReturnOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def OutputStackTrace(self, OutputControl: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def GetDebuggeeType(self, Class: POINTER(UInt32), Qualifier: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetActualProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def GetExecutingProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetNumberPossibleExecutingProcessorTypes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def GetPossibleExecutingProcessorTypes(self, Start: UInt32, Count: UInt32, Types: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def GetNumberProcessors(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def GetSystemVersion(self, PlatformId: POINTER(UInt32), Major: POINTER(UInt32), Minor: POINTER(UInt32), ServicePackString: win32more.Windows.Win32.Foundation.PSTR, ServicePackStringSize: UInt32, ServicePackStringUsed: POINTER(UInt32), ServicePackNumber: POINTER(UInt32), BuildString: win32more.Windows.Win32.Foundation.PSTR, BuildStringSize: UInt32, BuildStringUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetPageSize(self, Size: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def IsPointer64Bit(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def ReadBugCheckData(self, Code: POINTER(UInt32), Arg1: POINTER(UInt64), Arg2: POINTER(UInt64), Arg3: POINTER(UInt64), Arg4: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def GetNumberSupportedProcessorTypes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetSupportedProcessorTypes(self, Start: UInt32, Count: UInt32, Types: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def GetProcessorTypeNames(self, Type: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def GetEffectiveProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def SetEffectiveProcessorType(self, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def GetExecutionStatus(self, Status: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def SetExecutionStatus(self, Status: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def GetCodeLevel(self, Level: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def SetCodeLevel(self, Level: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def GetEngineOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def AddEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def RemoveEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def SetEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def GetSystemErrorControl(self, OutputLevel: POINTER(UInt32), BreakLevel: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def SetSystemErrorControl(self, OutputLevel: UInt32, BreakLevel: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def GetTextMacro(self, Slot: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, MacroSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def SetTextMacro(self, Slot: UInt32, Macro: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def GetRadix(self, Radix: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def SetRadix(self, Radix: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def Evaluate(self, Expression: win32more.Windows.Win32.Foundation.PSTR, DesiredType: UInt32, Value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), RemainderIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def CoerceValue(self, In: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), OutType: UInt32, Out: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def CoerceValues(self, Count: UInt32, In: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), OutTypes: POINTER(UInt32), Out: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def Execute(self, OutputControl: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def ExecuteCommandFile(self, OutputControl: UInt32, CommandFile: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def GetNumberBreakpoints(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def GetBreakpointByIndex(self, Index: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def GetBreakpointById(self, Id: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def GetBreakpointParameters(self, Count: UInt32, Ids: POINTER(UInt32), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_BREAKPOINT_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def AddBreakpoint(self, Type: UInt32, DesiredId: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def RemoveBreakpoint(self, Bp: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def AddExtension(self, Path: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def RemoveExtension(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def GetExtensionByPath(self, Path: win32more.Windows.Win32.Foundation.PSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def CallExtension(self, Handle: UInt64, Function: win32more.Windows.Win32.Foundation.PSTR, Arguments: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def GetExtensionFunction(self, Handle: UInt64, FuncName: win32more.Windows.Win32.Foundation.PSTR, Function: POINTER(win32more.Windows.Win32.Foundation.FARPROC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def GetWindbgExtensionApis32(self, Api: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def GetWindbgExtensionApis64(self, Api: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def GetNumberEventFilters(self, SpecificEvents: POINTER(UInt32), SpecificExceptions: POINTER(UInt32), ArbitraryExceptions: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def GetEventFilterText(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def GetEventFilterCommand(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def SetEventFilterCommand(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def GetSpecificFilterParameters(self, Start: UInt32, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SPECIFIC_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def SetSpecificFilterParameters(self, Start: UInt32, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SPECIFIC_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def GetSpecificFilterArgument(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ArgumentSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def SetSpecificFilterArgument(self, Index: UInt32, Argument: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def GetExceptionFilterParameters(self, Count: UInt32, Codes: POINTER(UInt32), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_EXCEPTION_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def SetExceptionFilterParameters(self, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_EXCEPTION_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def GetExceptionFilterSecondCommand(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def SetExceptionFilterSecondCommand(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def WaitForEvent(self, Flags: UInt32, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def GetLastEventInformation(self, Type: POINTER(UInt32), ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32), ExtraInformation: VoidPtr, ExtraInformationSize: UInt32, ExtraInformationUsed: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PSTR, DescriptionSize: UInt32, DescriptionUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def GetCurrentTimeDate(self, TimeDate: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def GetCurrentSystemUpTime(self, UpTime: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def GetDumpFormatFlags(self, FormatFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def GetNumberTextReplacements(self, NumRepl: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def GetTextReplacement(self, SrcText: win32more.Windows.Win32.Foundation.PSTR, Index: UInt32, SrcBuffer: win32more.Windows.Win32.Foundation.PSTR, SrcBufferSize: UInt32, SrcSize: POINTER(UInt32), DstBuffer: win32more.Windows.Win32.Foundation.PSTR, DstBufferSize: UInt32, DstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def SetTextReplacement(self, SrcText: win32more.Windows.Win32.Foundation.PSTR, DstText: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def RemoveTextReplacements(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def OutputTextReplacements(self, OutputControl: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def GetAssemblyOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def AddAssemblyOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(105)
    def RemoveAssemblyOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(106)
    def SetAssemblyOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(107)
    def GetExpressionSyntax(self, Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(108)
    def SetExpressionSyntax(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(109)
    def SetExpressionSyntaxByName(self, AbbrevName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(110)
    def GetNumberExpressionSyntaxes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(111)
    def GetExpressionSyntaxNames(self, Index: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(112)
    def GetNumberEvents(self, Events: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(113)
    def GetEventIndexDescription(self, Index: UInt32, Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, DescSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(114)
    def GetCurrentEventIndex(self, Index: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(115)
    def SetNextEventIndex(self, Relation: UInt32, Value: UInt32, NextIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugControl4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{94e60ce9-9b41-4b19-9fc0-6d9eb35272b3}')
    @commethod(3)
    def GetInterrupt(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetInterrupt(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetInterruptTimeout(self, Seconds: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetInterruptTimeout(self, Seconds: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetLogFile(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Append: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def OpenLogFile(self, File: win32more.Windows.Win32.Foundation.PSTR, Append: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CloseLogFile(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetLogMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetLogMask(self, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Input(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, InputSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def ReturnInput(self, Buffer: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Output(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def OutputVaList(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def ControlledOutput(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def ControlledOutputVaList(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def OutputPrompt(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def OutputPromptVaList(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetPromptText(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def OutputCurrentState(self, OutputControl: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def OutputVersionInformation(self, OutputControl: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetNotifyEventHandle(self, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def SetNotifyEventHandle(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def Assemble(self, Offset: UInt64, Instr: win32more.Windows.Win32.Foundation.PSTR, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def Disassemble(self, Offset: UInt64, Flags: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, DisassemblySize: POINTER(UInt32), EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetDisassembleEffectiveOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def OutputDisassembly(self, OutputControl: UInt32, Offset: UInt64, Flags: UInt32, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def OutputDisassemblyLines(self, OutputControl: UInt32, PreviousLines: UInt32, TotalLines: UInt32, Offset: UInt64, Flags: UInt32, OffsetLine: POINTER(UInt32), StartOffset: POINTER(UInt64), EndOffset: POINTER(UInt64), LineOffsets: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetNearInstruction(self, Offset: UInt64, Delta: Int32, NearOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetStackTrace(self, FrameOffset: UInt64, StackOffset: UInt64, InstructionOffset: UInt64, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, FramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def GetReturnOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def OutputStackTrace(self, OutputControl: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def GetDebuggeeType(self, Class: POINTER(UInt32), Qualifier: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetActualProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def GetExecutingProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetNumberPossibleExecutingProcessorTypes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def GetPossibleExecutingProcessorTypes(self, Start: UInt32, Count: UInt32, Types: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def GetNumberProcessors(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def GetSystemVersion(self, PlatformId: POINTER(UInt32), Major: POINTER(UInt32), Minor: POINTER(UInt32), ServicePackString: win32more.Windows.Win32.Foundation.PSTR, ServicePackStringSize: UInt32, ServicePackStringUsed: POINTER(UInt32), ServicePackNumber: POINTER(UInt32), BuildString: win32more.Windows.Win32.Foundation.PSTR, BuildStringSize: UInt32, BuildStringUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetPageSize(self, Size: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def IsPointer64Bit(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def ReadBugCheckData(self, Code: POINTER(UInt32), Arg1: POINTER(UInt64), Arg2: POINTER(UInt64), Arg3: POINTER(UInt64), Arg4: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def GetNumberSupportedProcessorTypes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetSupportedProcessorTypes(self, Start: UInt32, Count: UInt32, Types: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def GetProcessorTypeNames(self, Type: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def GetEffectiveProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def SetEffectiveProcessorType(self, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def GetExecutionStatus(self, Status: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def SetExecutionStatus(self, Status: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def GetCodeLevel(self, Level: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def SetCodeLevel(self, Level: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def GetEngineOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def AddEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def RemoveEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def SetEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def GetSystemErrorControl(self, OutputLevel: POINTER(UInt32), BreakLevel: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def SetSystemErrorControl(self, OutputLevel: UInt32, BreakLevel: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def GetTextMacro(self, Slot: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, MacroSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def SetTextMacro(self, Slot: UInt32, Macro: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def GetRadix(self, Radix: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def SetRadix(self, Radix: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def Evaluate(self, Expression: win32more.Windows.Win32.Foundation.PSTR, DesiredType: UInt32, Value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), RemainderIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def CoerceValue(self, In: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), OutType: UInt32, Out: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def CoerceValues(self, Count: UInt32, In: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), OutTypes: POINTER(UInt32), Out: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def Execute(self, OutputControl: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def ExecuteCommandFile(self, OutputControl: UInt32, CommandFile: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def GetNumberBreakpoints(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def GetBreakpointByIndex(self, Index: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def GetBreakpointById(self, Id: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def GetBreakpointParameters(self, Count: UInt32, Ids: POINTER(UInt32), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_BREAKPOINT_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def AddBreakpoint(self, Type: UInt32, DesiredId: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def RemoveBreakpoint(self, Bp: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def AddExtension(self, Path: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def RemoveExtension(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def GetExtensionByPath(self, Path: win32more.Windows.Win32.Foundation.PSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def CallExtension(self, Handle: UInt64, Function: win32more.Windows.Win32.Foundation.PSTR, Arguments: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def GetExtensionFunction(self, Handle: UInt64, FuncName: win32more.Windows.Win32.Foundation.PSTR, Function: POINTER(win32more.Windows.Win32.Foundation.FARPROC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def GetWindbgExtensionApis32(self, Api: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def GetWindbgExtensionApis64(self, Api: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def GetNumberEventFilters(self, SpecificEvents: POINTER(UInt32), SpecificExceptions: POINTER(UInt32), ArbitraryExceptions: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def GetEventFilterText(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def GetEventFilterCommand(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def SetEventFilterCommand(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def GetSpecificFilterParameters(self, Start: UInt32, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SPECIFIC_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def SetSpecificFilterParameters(self, Start: UInt32, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SPECIFIC_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def GetSpecificFilterArgument(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ArgumentSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def SetSpecificFilterArgument(self, Index: UInt32, Argument: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def GetExceptionFilterParameters(self, Count: UInt32, Codes: POINTER(UInt32), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_EXCEPTION_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def SetExceptionFilterParameters(self, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_EXCEPTION_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def GetExceptionFilterSecondCommand(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def SetExceptionFilterSecondCommand(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def WaitForEvent(self, Flags: UInt32, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def GetLastEventInformation(self, Type: POINTER(UInt32), ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32), ExtraInformation: VoidPtr, ExtraInformationSize: UInt32, ExtraInformationUsed: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PSTR, DescriptionSize: UInt32, DescriptionUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def GetCurrentTimeDate(self, TimeDate: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def GetCurrentSystemUpTime(self, UpTime: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def GetDumpFormatFlags(self, FormatFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def GetNumberTextReplacements(self, NumRepl: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def GetTextReplacement(self, SrcText: win32more.Windows.Win32.Foundation.PSTR, Index: UInt32, SrcBuffer: win32more.Windows.Win32.Foundation.PSTR, SrcBufferSize: UInt32, SrcSize: POINTER(UInt32), DstBuffer: win32more.Windows.Win32.Foundation.PSTR, DstBufferSize: UInt32, DstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def SetTextReplacement(self, SrcText: win32more.Windows.Win32.Foundation.PSTR, DstText: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def RemoveTextReplacements(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def OutputTextReplacements(self, OutputControl: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def GetAssemblyOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def AddAssemblyOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(105)
    def RemoveAssemblyOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(106)
    def SetAssemblyOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(107)
    def GetExpressionSyntax(self, Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(108)
    def SetExpressionSyntax(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(109)
    def SetExpressionSyntaxByName(self, AbbrevName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(110)
    def GetNumberExpressionSyntaxes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(111)
    def GetExpressionSyntaxNames(self, Index: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(112)
    def GetNumberEvents(self, Events: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(113)
    def GetEventIndexDescription(self, Index: UInt32, Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, DescSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(114)
    def GetCurrentEventIndex(self, Index: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(115)
    def SetNextEventIndex(self, Relation: UInt32, Value: UInt32, NextIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(116)
    def GetLogFileWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Append: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(117)
    def OpenLogFileWide(self, File: win32more.Windows.Win32.Foundation.PWSTR, Append: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(118)
    def InputWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, InputSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(119)
    def ReturnInputWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(120)
    def OutputWide(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(121)
    def OutputVaListWide(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(122)
    def ControlledOutputWide(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(123)
    def ControlledOutputVaListWide(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(124)
    def OutputPromptWide(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(125)
    def OutputPromptVaListWide(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(126)
    def GetPromptTextWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(127)
    def AssembleWide(self, Offset: UInt64, Instr: win32more.Windows.Win32.Foundation.PWSTR, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(128)
    def DisassembleWide(self, Offset: UInt64, Flags: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, DisassemblySize: POINTER(UInt32), EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(129)
    def GetProcessorTypeNamesWide(self, Type: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(130)
    def GetTextMacroWide(self, Slot: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, MacroSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(131)
    def SetTextMacroWide(self, Slot: UInt32, Macro: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(132)
    def EvaluateWide(self, Expression: win32more.Windows.Win32.Foundation.PWSTR, DesiredType: UInt32, Value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), RemainderIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(133)
    def ExecuteWide(self, OutputControl: UInt32, Command: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(134)
    def ExecuteCommandFileWide(self, OutputControl: UInt32, CommandFile: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(135)
    def GetBreakpointByIndex2(self, Index: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(136)
    def GetBreakpointById2(self, Id: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(137)
    def AddBreakpoint2(self, Type: UInt32, DesiredId: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(138)
    def RemoveBreakpoint2(self, Bp: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(139)
    def AddExtensionWide(self, Path: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(140)
    def GetExtensionByPathWide(self, Path: win32more.Windows.Win32.Foundation.PWSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(141)
    def CallExtensionWide(self, Handle: UInt64, Function: win32more.Windows.Win32.Foundation.PWSTR, Arguments: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(142)
    def GetExtensionFunctionWide(self, Handle: UInt64, FuncName: win32more.Windows.Win32.Foundation.PWSTR, Function: POINTER(win32more.Windows.Win32.Foundation.FARPROC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(143)
    def GetEventFilterTextWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(144)
    def GetEventFilterCommandWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(145)
    def SetEventFilterCommandWide(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(146)
    def GetSpecificFilterArgumentWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, ArgumentSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(147)
    def SetSpecificFilterArgumentWide(self, Index: UInt32, Argument: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(148)
    def GetExceptionFilterSecondCommandWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(149)
    def SetExceptionFilterSecondCommandWide(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(150)
    def GetLastEventInformationWide(self, Type: POINTER(UInt32), ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32), ExtraInformation: VoidPtr, ExtraInformationSize: UInt32, ExtraInformationUsed: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PWSTR, DescriptionSize: UInt32, DescriptionUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(151)
    def GetTextReplacementWide(self, SrcText: win32more.Windows.Win32.Foundation.PWSTR, Index: UInt32, SrcBuffer: win32more.Windows.Win32.Foundation.PWSTR, SrcBufferSize: UInt32, SrcSize: POINTER(UInt32), DstBuffer: win32more.Windows.Win32.Foundation.PWSTR, DstBufferSize: UInt32, DstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(152)
    def SetTextReplacementWide(self, SrcText: win32more.Windows.Win32.Foundation.PWSTR, DstText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(153)
    def SetExpressionSyntaxByNameWide(self, AbbrevName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(154)
    def GetExpressionSyntaxNamesWide(self, Index: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(155)
    def GetEventIndexDescriptionWide(self, Index: UInt32, Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, DescSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(156)
    def GetLogFile2(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(157)
    def OpenLogFile2(self, File: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(158)
    def GetLogFile2Wide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(159)
    def OpenLogFile2Wide(self, File: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(160)
    def GetSystemVersionValues(self, PlatformId: POINTER(UInt32), Win32Major: POINTER(UInt32), Win32Minor: POINTER(UInt32), KdMajor: POINTER(UInt32), KdMinor: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(161)
    def GetSystemVersionString(self, Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(162)
    def GetSystemVersionStringWide(self, Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(163)
    def GetContextStackTrace(self, StartContext: VoidPtr, StartContextSize: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, FrameContexts: VoidPtr, FrameContextsSize: UInt32, FrameContextsEntrySize: UInt32, FramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(164)
    def OutputContextStackTrace(self, OutputControl: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, FrameContexts: VoidPtr, FrameContextsSize: UInt32, FrameContextsEntrySize: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(165)
    def GetStoredEventInformation(self, Type: POINTER(UInt32), ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32), Context: VoidPtr, ContextSize: UInt32, ContextUsed: POINTER(UInt32), ExtraInformation: VoidPtr, ExtraInformationSize: UInt32, ExtraInformationUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(166)
    def GetManagedStatus(self, Flags: POINTER(UInt32), WhichString: UInt32, String: win32more.Windows.Win32.Foundation.PSTR, StringSize: UInt32, StringNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(167)
    def GetManagedStatusWide(self, Flags: POINTER(UInt32), WhichString: UInt32, String: win32more.Windows.Win32.Foundation.PWSTR, StringSize: UInt32, StringNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(168)
    def ResetManagedStatus(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugControl5(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b2ffe162-2412-429f-8d1d-5bf6dd824696}')
    @commethod(3)
    def GetInterrupt(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetInterrupt(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetInterruptTimeout(self, Seconds: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetInterruptTimeout(self, Seconds: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetLogFile(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Append: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def OpenLogFile(self, File: win32more.Windows.Win32.Foundation.PSTR, Append: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CloseLogFile(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetLogMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetLogMask(self, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Input(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, InputSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def ReturnInput(self, Buffer: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Output(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def OutputVaList(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def ControlledOutput(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def ControlledOutputVaList(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def OutputPrompt(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def OutputPromptVaList(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetPromptText(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def OutputCurrentState(self, OutputControl: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def OutputVersionInformation(self, OutputControl: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetNotifyEventHandle(self, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def SetNotifyEventHandle(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def Assemble(self, Offset: UInt64, Instr: win32more.Windows.Win32.Foundation.PSTR, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def Disassemble(self, Offset: UInt64, Flags: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, DisassemblySize: POINTER(UInt32), EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetDisassembleEffectiveOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def OutputDisassembly(self, OutputControl: UInt32, Offset: UInt64, Flags: UInt32, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def OutputDisassemblyLines(self, OutputControl: UInt32, PreviousLines: UInt32, TotalLines: UInt32, Offset: UInt64, Flags: UInt32, OffsetLine: POINTER(UInt32), StartOffset: POINTER(UInt64), EndOffset: POINTER(UInt64), LineOffsets: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetNearInstruction(self, Offset: UInt64, Delta: Int32, NearOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetStackTrace(self, FrameOffset: UInt64, StackOffset: UInt64, InstructionOffset: UInt64, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, FramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def GetReturnOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def OutputStackTrace(self, OutputControl: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def GetDebuggeeType(self, Class: POINTER(UInt32), Qualifier: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetActualProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def GetExecutingProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetNumberPossibleExecutingProcessorTypes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def GetPossibleExecutingProcessorTypes(self, Start: UInt32, Count: UInt32, Types: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def GetNumberProcessors(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def GetSystemVersion(self, PlatformId: POINTER(UInt32), Major: POINTER(UInt32), Minor: POINTER(UInt32), ServicePackString: win32more.Windows.Win32.Foundation.PSTR, ServicePackStringSize: UInt32, ServicePackStringUsed: POINTER(UInt32), ServicePackNumber: POINTER(UInt32), BuildString: win32more.Windows.Win32.Foundation.PSTR, BuildStringSize: UInt32, BuildStringUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetPageSize(self, Size: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def IsPointer64Bit(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def ReadBugCheckData(self, Code: POINTER(UInt32), Arg1: POINTER(UInt64), Arg2: POINTER(UInt64), Arg3: POINTER(UInt64), Arg4: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def GetNumberSupportedProcessorTypes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetSupportedProcessorTypes(self, Start: UInt32, Count: UInt32, Types: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def GetProcessorTypeNames(self, Type: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def GetEffectiveProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def SetEffectiveProcessorType(self, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def GetExecutionStatus(self, Status: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def SetExecutionStatus(self, Status: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def GetCodeLevel(self, Level: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def SetCodeLevel(self, Level: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def GetEngineOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def AddEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def RemoveEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def SetEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def GetSystemErrorControl(self, OutputLevel: POINTER(UInt32), BreakLevel: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def SetSystemErrorControl(self, OutputLevel: UInt32, BreakLevel: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def GetTextMacro(self, Slot: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, MacroSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def SetTextMacro(self, Slot: UInt32, Macro: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def GetRadix(self, Radix: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def SetRadix(self, Radix: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def Evaluate(self, Expression: win32more.Windows.Win32.Foundation.PSTR, DesiredType: UInt32, Value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), RemainderIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def CoerceValue(self, In: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), OutType: UInt32, Out: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def CoerceValues(self, Count: UInt32, In: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), OutTypes: POINTER(UInt32), Out: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def Execute(self, OutputControl: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def ExecuteCommandFile(self, OutputControl: UInt32, CommandFile: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def GetNumberBreakpoints(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def GetBreakpointByIndex(self, Index: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def GetBreakpointById(self, Id: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def GetBreakpointParameters(self, Count: UInt32, Ids: POINTER(UInt32), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_BREAKPOINT_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def AddBreakpoint(self, Type: UInt32, DesiredId: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def RemoveBreakpoint(self, Bp: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def AddExtension(self, Path: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def RemoveExtension(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def GetExtensionByPath(self, Path: win32more.Windows.Win32.Foundation.PSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def CallExtension(self, Handle: UInt64, Function: win32more.Windows.Win32.Foundation.PSTR, Arguments: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def GetExtensionFunction(self, Handle: UInt64, FuncName: win32more.Windows.Win32.Foundation.PSTR, Function: POINTER(win32more.Windows.Win32.Foundation.FARPROC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def GetWindbgExtensionApis32(self, Api: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def GetWindbgExtensionApis64(self, Api: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def GetNumberEventFilters(self, SpecificEvents: POINTER(UInt32), SpecificExceptions: POINTER(UInt32), ArbitraryExceptions: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def GetEventFilterText(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def GetEventFilterCommand(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def SetEventFilterCommand(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def GetSpecificFilterParameters(self, Start: UInt32, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SPECIFIC_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def SetSpecificFilterParameters(self, Start: UInt32, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SPECIFIC_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def GetSpecificFilterArgument(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ArgumentSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def SetSpecificFilterArgument(self, Index: UInt32, Argument: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def GetExceptionFilterParameters(self, Count: UInt32, Codes: POINTER(UInt32), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_EXCEPTION_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def SetExceptionFilterParameters(self, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_EXCEPTION_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def GetExceptionFilterSecondCommand(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def SetExceptionFilterSecondCommand(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def WaitForEvent(self, Flags: UInt32, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def GetLastEventInformation(self, Type: POINTER(UInt32), ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32), ExtraInformation: VoidPtr, ExtraInformationSize: UInt32, ExtraInformationUsed: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PSTR, DescriptionSize: UInt32, DescriptionUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def GetCurrentTimeDate(self, TimeDate: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def GetCurrentSystemUpTime(self, UpTime: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def GetDumpFormatFlags(self, FormatFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def GetNumberTextReplacements(self, NumRepl: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def GetTextReplacement(self, SrcText: win32more.Windows.Win32.Foundation.PSTR, Index: UInt32, SrcBuffer: win32more.Windows.Win32.Foundation.PSTR, SrcBufferSize: UInt32, SrcSize: POINTER(UInt32), DstBuffer: win32more.Windows.Win32.Foundation.PSTR, DstBufferSize: UInt32, DstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def SetTextReplacement(self, SrcText: win32more.Windows.Win32.Foundation.PSTR, DstText: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def RemoveTextReplacements(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def OutputTextReplacements(self, OutputControl: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def GetAssemblyOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def AddAssemblyOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(105)
    def RemoveAssemblyOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(106)
    def SetAssemblyOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(107)
    def GetExpressionSyntax(self, Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(108)
    def SetExpressionSyntax(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(109)
    def SetExpressionSyntaxByName(self, AbbrevName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(110)
    def GetNumberExpressionSyntaxes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(111)
    def GetExpressionSyntaxNames(self, Index: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(112)
    def GetNumberEvents(self, Events: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(113)
    def GetEventIndexDescription(self, Index: UInt32, Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, DescSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(114)
    def GetCurrentEventIndex(self, Index: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(115)
    def SetNextEventIndex(self, Relation: UInt32, Value: UInt32, NextIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(116)
    def GetLogFileWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Append: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(117)
    def OpenLogFileWide(self, File: win32more.Windows.Win32.Foundation.PWSTR, Append: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(118)
    def InputWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, InputSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(119)
    def ReturnInputWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(120)
    def OutputWide(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(121)
    def OutputVaListWide(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(122)
    def ControlledOutputWide(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(123)
    def ControlledOutputVaListWide(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(124)
    def OutputPromptWide(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(125)
    def OutputPromptVaListWide(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(126)
    def GetPromptTextWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(127)
    def AssembleWide(self, Offset: UInt64, Instr: win32more.Windows.Win32.Foundation.PWSTR, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(128)
    def DisassembleWide(self, Offset: UInt64, Flags: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, DisassemblySize: POINTER(UInt32), EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(129)
    def GetProcessorTypeNamesWide(self, Type: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(130)
    def GetTextMacroWide(self, Slot: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, MacroSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(131)
    def SetTextMacroWide(self, Slot: UInt32, Macro: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(132)
    def EvaluateWide(self, Expression: win32more.Windows.Win32.Foundation.PWSTR, DesiredType: UInt32, Value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), RemainderIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(133)
    def ExecuteWide(self, OutputControl: UInt32, Command: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(134)
    def ExecuteCommandFileWide(self, OutputControl: UInt32, CommandFile: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(135)
    def GetBreakpointByIndex2(self, Index: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(136)
    def GetBreakpointById2(self, Id: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(137)
    def AddBreakpoint2(self, Type: UInt32, DesiredId: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(138)
    def RemoveBreakpoint2(self, Bp: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(139)
    def AddExtensionWide(self, Path: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(140)
    def GetExtensionByPathWide(self, Path: win32more.Windows.Win32.Foundation.PWSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(141)
    def CallExtensionWide(self, Handle: UInt64, Function: win32more.Windows.Win32.Foundation.PWSTR, Arguments: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(142)
    def GetExtensionFunctionWide(self, Handle: UInt64, FuncName: win32more.Windows.Win32.Foundation.PWSTR, Function: POINTER(win32more.Windows.Win32.Foundation.FARPROC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(143)
    def GetEventFilterTextWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(144)
    def GetEventFilterCommandWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(145)
    def SetEventFilterCommandWide(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(146)
    def GetSpecificFilterArgumentWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, ArgumentSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(147)
    def SetSpecificFilterArgumentWide(self, Index: UInt32, Argument: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(148)
    def GetExceptionFilterSecondCommandWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(149)
    def SetExceptionFilterSecondCommandWide(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(150)
    def GetLastEventInformationWide(self, Type: POINTER(UInt32), ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32), ExtraInformation: VoidPtr, ExtraInformationSize: UInt32, ExtraInformationUsed: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PWSTR, DescriptionSize: UInt32, DescriptionUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(151)
    def GetTextReplacementWide(self, SrcText: win32more.Windows.Win32.Foundation.PWSTR, Index: UInt32, SrcBuffer: win32more.Windows.Win32.Foundation.PWSTR, SrcBufferSize: UInt32, SrcSize: POINTER(UInt32), DstBuffer: win32more.Windows.Win32.Foundation.PWSTR, DstBufferSize: UInt32, DstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(152)
    def SetTextReplacementWide(self, SrcText: win32more.Windows.Win32.Foundation.PWSTR, DstText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(153)
    def SetExpressionSyntaxByNameWide(self, AbbrevName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(154)
    def GetExpressionSyntaxNamesWide(self, Index: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(155)
    def GetEventIndexDescriptionWide(self, Index: UInt32, Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, DescSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(156)
    def GetLogFile2(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(157)
    def OpenLogFile2(self, File: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(158)
    def GetLogFile2Wide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(159)
    def OpenLogFile2Wide(self, File: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(160)
    def GetSystemVersionValues(self, PlatformId: POINTER(UInt32), Win32Major: POINTER(UInt32), Win32Minor: POINTER(UInt32), KdMajor: POINTER(UInt32), KdMinor: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(161)
    def GetSystemVersionString(self, Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(162)
    def GetSystemVersionStringWide(self, Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(163)
    def GetContextStackTrace(self, StartContext: VoidPtr, StartContextSize: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, FrameContexts: VoidPtr, FrameContextsSize: UInt32, FrameContextsEntrySize: UInt32, FramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(164)
    def OutputContextStackTrace(self, OutputControl: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, FrameContexts: VoidPtr, FrameContextsSize: UInt32, FrameContextsEntrySize: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(165)
    def GetStoredEventInformation(self, Type: POINTER(UInt32), ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32), Context: VoidPtr, ContextSize: UInt32, ContextUsed: POINTER(UInt32), ExtraInformation: VoidPtr, ExtraInformationSize: UInt32, ExtraInformationUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(166)
    def GetManagedStatus(self, Flags: POINTER(UInt32), WhichString: UInt32, String: win32more.Windows.Win32.Foundation.PSTR, StringSize: UInt32, StringNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(167)
    def GetManagedStatusWide(self, Flags: POINTER(UInt32), WhichString: UInt32, String: win32more.Windows.Win32.Foundation.PWSTR, StringSize: UInt32, StringNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(168)
    def ResetManagedStatus(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(169)
    def GetStackTraceEx(self, FrameOffset: UInt64, StackOffset: UInt64, InstructionOffset: UInt64, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX), FramesSize: UInt32, FramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(170)
    def OutputStackTraceEx(self, OutputControl: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX), FramesSize: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(171)
    def GetContextStackTraceEx(self, StartContext: VoidPtr, StartContextSize: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX), FramesSize: UInt32, FrameContexts: VoidPtr, FrameContextsSize: UInt32, FrameContextsEntrySize: UInt32, FramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(172)
    def OutputContextStackTraceEx(self, OutputControl: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX), FramesSize: UInt32, FrameContexts: VoidPtr, FrameContextsSize: UInt32, FrameContextsEntrySize: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(173)
    def GetBreakpointByGuid(self, Guid: POINTER(Guid), Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugControl6(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bc0d583f-126d-43a1-9cc4-a860ab1d537b}')
    @commethod(3)
    def GetInterrupt(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetInterrupt(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetInterruptTimeout(self, Seconds: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetInterruptTimeout(self, Seconds: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetLogFile(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Append: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def OpenLogFile(self, File: win32more.Windows.Win32.Foundation.PSTR, Append: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CloseLogFile(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetLogMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetLogMask(self, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Input(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, InputSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def ReturnInput(self, Buffer: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Output(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def OutputVaList(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def ControlledOutput(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def ControlledOutputVaList(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def OutputPrompt(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def OutputPromptVaList(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetPromptText(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def OutputCurrentState(self, OutputControl: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def OutputVersionInformation(self, OutputControl: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetNotifyEventHandle(self, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def SetNotifyEventHandle(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def Assemble(self, Offset: UInt64, Instr: win32more.Windows.Win32.Foundation.PSTR, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def Disassemble(self, Offset: UInt64, Flags: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, DisassemblySize: POINTER(UInt32), EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetDisassembleEffectiveOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def OutputDisassembly(self, OutputControl: UInt32, Offset: UInt64, Flags: UInt32, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def OutputDisassemblyLines(self, OutputControl: UInt32, PreviousLines: UInt32, TotalLines: UInt32, Offset: UInt64, Flags: UInt32, OffsetLine: POINTER(UInt32), StartOffset: POINTER(UInt64), EndOffset: POINTER(UInt64), LineOffsets: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetNearInstruction(self, Offset: UInt64, Delta: Int32, NearOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetStackTrace(self, FrameOffset: UInt64, StackOffset: UInt64, InstructionOffset: UInt64, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, FramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def GetReturnOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def OutputStackTrace(self, OutputControl: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def GetDebuggeeType(self, Class: POINTER(UInt32), Qualifier: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetActualProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def GetExecutingProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetNumberPossibleExecutingProcessorTypes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def GetPossibleExecutingProcessorTypes(self, Start: UInt32, Count: UInt32, Types: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def GetNumberProcessors(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def GetSystemVersion(self, PlatformId: POINTER(UInt32), Major: POINTER(UInt32), Minor: POINTER(UInt32), ServicePackString: win32more.Windows.Win32.Foundation.PSTR, ServicePackStringSize: UInt32, ServicePackStringUsed: POINTER(UInt32), ServicePackNumber: POINTER(UInt32), BuildString: win32more.Windows.Win32.Foundation.PSTR, BuildStringSize: UInt32, BuildStringUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetPageSize(self, Size: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def IsPointer64Bit(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def ReadBugCheckData(self, Code: POINTER(UInt32), Arg1: POINTER(UInt64), Arg2: POINTER(UInt64), Arg3: POINTER(UInt64), Arg4: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def GetNumberSupportedProcessorTypes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetSupportedProcessorTypes(self, Start: UInt32, Count: UInt32, Types: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def GetProcessorTypeNames(self, Type: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def GetEffectiveProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def SetEffectiveProcessorType(self, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def GetExecutionStatus(self, Status: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def SetExecutionStatus(self, Status: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def GetCodeLevel(self, Level: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def SetCodeLevel(self, Level: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def GetEngineOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def AddEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def RemoveEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def SetEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def GetSystemErrorControl(self, OutputLevel: POINTER(UInt32), BreakLevel: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def SetSystemErrorControl(self, OutputLevel: UInt32, BreakLevel: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def GetTextMacro(self, Slot: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, MacroSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def SetTextMacro(self, Slot: UInt32, Macro: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def GetRadix(self, Radix: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def SetRadix(self, Radix: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def Evaluate(self, Expression: win32more.Windows.Win32.Foundation.PSTR, DesiredType: UInt32, Value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), RemainderIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def CoerceValue(self, In: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), OutType: UInt32, Out: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def CoerceValues(self, Count: UInt32, In: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), OutTypes: POINTER(UInt32), Out: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def Execute(self, OutputControl: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def ExecuteCommandFile(self, OutputControl: UInt32, CommandFile: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def GetNumberBreakpoints(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def GetBreakpointByIndex(self, Index: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def GetBreakpointById(self, Id: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def GetBreakpointParameters(self, Count: UInt32, Ids: POINTER(UInt32), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_BREAKPOINT_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def AddBreakpoint(self, Type: UInt32, DesiredId: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def RemoveBreakpoint(self, Bp: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def AddExtension(self, Path: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def RemoveExtension(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def GetExtensionByPath(self, Path: win32more.Windows.Win32.Foundation.PSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def CallExtension(self, Handle: UInt64, Function: win32more.Windows.Win32.Foundation.PSTR, Arguments: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def GetExtensionFunction(self, Handle: UInt64, FuncName: win32more.Windows.Win32.Foundation.PSTR, Function: POINTER(win32more.Windows.Win32.Foundation.FARPROC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def GetWindbgExtensionApis32(self, Api: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def GetWindbgExtensionApis64(self, Api: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def GetNumberEventFilters(self, SpecificEvents: POINTER(UInt32), SpecificExceptions: POINTER(UInt32), ArbitraryExceptions: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def GetEventFilterText(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def GetEventFilterCommand(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def SetEventFilterCommand(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def GetSpecificFilterParameters(self, Start: UInt32, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SPECIFIC_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def SetSpecificFilterParameters(self, Start: UInt32, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SPECIFIC_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def GetSpecificFilterArgument(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ArgumentSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def SetSpecificFilterArgument(self, Index: UInt32, Argument: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def GetExceptionFilterParameters(self, Count: UInt32, Codes: POINTER(UInt32), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_EXCEPTION_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def SetExceptionFilterParameters(self, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_EXCEPTION_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def GetExceptionFilterSecondCommand(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def SetExceptionFilterSecondCommand(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def WaitForEvent(self, Flags: UInt32, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def GetLastEventInformation(self, Type: POINTER(UInt32), ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32), ExtraInformation: VoidPtr, ExtraInformationSize: UInt32, ExtraInformationUsed: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PSTR, DescriptionSize: UInt32, DescriptionUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def GetCurrentTimeDate(self, TimeDate: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def GetCurrentSystemUpTime(self, UpTime: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def GetDumpFormatFlags(self, FormatFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def GetNumberTextReplacements(self, NumRepl: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def GetTextReplacement(self, SrcText: win32more.Windows.Win32.Foundation.PSTR, Index: UInt32, SrcBuffer: win32more.Windows.Win32.Foundation.PSTR, SrcBufferSize: UInt32, SrcSize: POINTER(UInt32), DstBuffer: win32more.Windows.Win32.Foundation.PSTR, DstBufferSize: UInt32, DstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def SetTextReplacement(self, SrcText: win32more.Windows.Win32.Foundation.PSTR, DstText: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def RemoveTextReplacements(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def OutputTextReplacements(self, OutputControl: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def GetAssemblyOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def AddAssemblyOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(105)
    def RemoveAssemblyOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(106)
    def SetAssemblyOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(107)
    def GetExpressionSyntax(self, Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(108)
    def SetExpressionSyntax(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(109)
    def SetExpressionSyntaxByName(self, AbbrevName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(110)
    def GetNumberExpressionSyntaxes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(111)
    def GetExpressionSyntaxNames(self, Index: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(112)
    def GetNumberEvents(self, Events: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(113)
    def GetEventIndexDescription(self, Index: UInt32, Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, DescSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(114)
    def GetCurrentEventIndex(self, Index: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(115)
    def SetNextEventIndex(self, Relation: UInt32, Value: UInt32, NextIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(116)
    def GetLogFileWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Append: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(117)
    def OpenLogFileWide(self, File: win32more.Windows.Win32.Foundation.PWSTR, Append: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(118)
    def InputWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, InputSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(119)
    def ReturnInputWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(120)
    def OutputWide(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(121)
    def OutputVaListWide(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(122)
    def ControlledOutputWide(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(123)
    def ControlledOutputVaListWide(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(124)
    def OutputPromptWide(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(125)
    def OutputPromptVaListWide(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(126)
    def GetPromptTextWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(127)
    def AssembleWide(self, Offset: UInt64, Instr: win32more.Windows.Win32.Foundation.PWSTR, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(128)
    def DisassembleWide(self, Offset: UInt64, Flags: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, DisassemblySize: POINTER(UInt32), EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(129)
    def GetProcessorTypeNamesWide(self, Type: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(130)
    def GetTextMacroWide(self, Slot: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, MacroSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(131)
    def SetTextMacroWide(self, Slot: UInt32, Macro: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(132)
    def EvaluateWide(self, Expression: win32more.Windows.Win32.Foundation.PWSTR, DesiredType: UInt32, Value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), RemainderIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(133)
    def ExecuteWide(self, OutputControl: UInt32, Command: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(134)
    def ExecuteCommandFileWide(self, OutputControl: UInt32, CommandFile: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(135)
    def GetBreakpointByIndex2(self, Index: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(136)
    def GetBreakpointById2(self, Id: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(137)
    def AddBreakpoint2(self, Type: UInt32, DesiredId: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(138)
    def RemoveBreakpoint2(self, Bp: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(139)
    def AddExtensionWide(self, Path: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(140)
    def GetExtensionByPathWide(self, Path: win32more.Windows.Win32.Foundation.PWSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(141)
    def CallExtensionWide(self, Handle: UInt64, Function: win32more.Windows.Win32.Foundation.PWSTR, Arguments: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(142)
    def GetExtensionFunctionWide(self, Handle: UInt64, FuncName: win32more.Windows.Win32.Foundation.PWSTR, Function: POINTER(win32more.Windows.Win32.Foundation.FARPROC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(143)
    def GetEventFilterTextWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(144)
    def GetEventFilterCommandWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(145)
    def SetEventFilterCommandWide(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(146)
    def GetSpecificFilterArgumentWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, ArgumentSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(147)
    def SetSpecificFilterArgumentWide(self, Index: UInt32, Argument: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(148)
    def GetExceptionFilterSecondCommandWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(149)
    def SetExceptionFilterSecondCommandWide(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(150)
    def GetLastEventInformationWide(self, Type: POINTER(UInt32), ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32), ExtraInformation: VoidPtr, ExtraInformationSize: UInt32, ExtraInformationUsed: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PWSTR, DescriptionSize: UInt32, DescriptionUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(151)
    def GetTextReplacementWide(self, SrcText: win32more.Windows.Win32.Foundation.PWSTR, Index: UInt32, SrcBuffer: win32more.Windows.Win32.Foundation.PWSTR, SrcBufferSize: UInt32, SrcSize: POINTER(UInt32), DstBuffer: win32more.Windows.Win32.Foundation.PWSTR, DstBufferSize: UInt32, DstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(152)
    def SetTextReplacementWide(self, SrcText: win32more.Windows.Win32.Foundation.PWSTR, DstText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(153)
    def SetExpressionSyntaxByNameWide(self, AbbrevName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(154)
    def GetExpressionSyntaxNamesWide(self, Index: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(155)
    def GetEventIndexDescriptionWide(self, Index: UInt32, Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, DescSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(156)
    def GetLogFile2(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(157)
    def OpenLogFile2(self, File: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(158)
    def GetLogFile2Wide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(159)
    def OpenLogFile2Wide(self, File: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(160)
    def GetSystemVersionValues(self, PlatformId: POINTER(UInt32), Win32Major: POINTER(UInt32), Win32Minor: POINTER(UInt32), KdMajor: POINTER(UInt32), KdMinor: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(161)
    def GetSystemVersionString(self, Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(162)
    def GetSystemVersionStringWide(self, Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(163)
    def GetContextStackTrace(self, StartContext: VoidPtr, StartContextSize: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, FrameContexts: VoidPtr, FrameContextsSize: UInt32, FrameContextsEntrySize: UInt32, FramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(164)
    def OutputContextStackTrace(self, OutputControl: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, FrameContexts: VoidPtr, FrameContextsSize: UInt32, FrameContextsEntrySize: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(165)
    def GetStoredEventInformation(self, Type: POINTER(UInt32), ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32), Context: VoidPtr, ContextSize: UInt32, ContextUsed: POINTER(UInt32), ExtraInformation: VoidPtr, ExtraInformationSize: UInt32, ExtraInformationUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(166)
    def GetManagedStatus(self, Flags: POINTER(UInt32), WhichString: UInt32, String: win32more.Windows.Win32.Foundation.PSTR, StringSize: UInt32, StringNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(167)
    def GetManagedStatusWide(self, Flags: POINTER(UInt32), WhichString: UInt32, String: win32more.Windows.Win32.Foundation.PWSTR, StringSize: UInt32, StringNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(168)
    def ResetManagedStatus(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(169)
    def GetStackTraceEx(self, FrameOffset: UInt64, StackOffset: UInt64, InstructionOffset: UInt64, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX), FramesSize: UInt32, FramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(170)
    def OutputStackTraceEx(self, OutputControl: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX), FramesSize: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(171)
    def GetContextStackTraceEx(self, StartContext: VoidPtr, StartContextSize: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX), FramesSize: UInt32, FrameContexts: VoidPtr, FrameContextsSize: UInt32, FrameContextsEntrySize: UInt32, FramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(172)
    def OutputContextStackTraceEx(self, OutputControl: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX), FramesSize: UInt32, FrameContexts: VoidPtr, FrameContextsSize: UInt32, FrameContextsEntrySize: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(173)
    def GetBreakpointByGuid(self, Guid: POINTER(Guid), Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(174)
    def GetExecutionStatusEx(self, Status: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(175)
    def GetSynchronizationStatus(self, SendsAttempted: POINTER(UInt32), SecondsSinceLastResponse: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugControl7(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b86fb3b1-80d4-475b-aea3-cf06539cf63a}')
    @commethod(3)
    def GetInterrupt(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetInterrupt(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetInterruptTimeout(self, Seconds: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetInterruptTimeout(self, Seconds: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetLogFile(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Append: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def OpenLogFile(self, File: win32more.Windows.Win32.Foundation.PSTR, Append: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CloseLogFile(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetLogMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetLogMask(self, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Input(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, InputSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def ReturnInput(self, Buffer: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Output(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def OutputVaList(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def ControlledOutput(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def ControlledOutputVaList(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def OutputPrompt(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def OutputPromptVaList(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetPromptText(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def OutputCurrentState(self, OutputControl: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def OutputVersionInformation(self, OutputControl: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetNotifyEventHandle(self, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def SetNotifyEventHandle(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def Assemble(self, Offset: UInt64, Instr: win32more.Windows.Win32.Foundation.PSTR, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def Disassemble(self, Offset: UInt64, Flags: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, DisassemblySize: POINTER(UInt32), EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetDisassembleEffectiveOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def OutputDisassembly(self, OutputControl: UInt32, Offset: UInt64, Flags: UInt32, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def OutputDisassemblyLines(self, OutputControl: UInt32, PreviousLines: UInt32, TotalLines: UInt32, Offset: UInt64, Flags: UInt32, OffsetLine: POINTER(UInt32), StartOffset: POINTER(UInt64), EndOffset: POINTER(UInt64), LineOffsets: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetNearInstruction(self, Offset: UInt64, Delta: Int32, NearOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetStackTrace(self, FrameOffset: UInt64, StackOffset: UInt64, InstructionOffset: UInt64, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, FramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def GetReturnOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def OutputStackTrace(self, OutputControl: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def GetDebuggeeType(self, Class: POINTER(UInt32), Qualifier: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetActualProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def GetExecutingProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetNumberPossibleExecutingProcessorTypes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def GetPossibleExecutingProcessorTypes(self, Start: UInt32, Count: UInt32, Types: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def GetNumberProcessors(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def GetSystemVersion(self, PlatformId: POINTER(UInt32), Major: POINTER(UInt32), Minor: POINTER(UInt32), ServicePackString: win32more.Windows.Win32.Foundation.PSTR, ServicePackStringSize: UInt32, ServicePackStringUsed: POINTER(UInt32), ServicePackNumber: POINTER(UInt32), BuildString: win32more.Windows.Win32.Foundation.PSTR, BuildStringSize: UInt32, BuildStringUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetPageSize(self, Size: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def IsPointer64Bit(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def ReadBugCheckData(self, Code: POINTER(UInt32), Arg1: POINTER(UInt64), Arg2: POINTER(UInt64), Arg3: POINTER(UInt64), Arg4: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def GetNumberSupportedProcessorTypes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetSupportedProcessorTypes(self, Start: UInt32, Count: UInt32, Types: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def GetProcessorTypeNames(self, Type: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def GetEffectiveProcessorType(self, Type: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def SetEffectiveProcessorType(self, Type: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def GetExecutionStatus(self, Status: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def SetExecutionStatus(self, Status: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def GetCodeLevel(self, Level: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def SetCodeLevel(self, Level: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def GetEngineOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def AddEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def RemoveEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def SetEngineOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def GetSystemErrorControl(self, OutputLevel: POINTER(UInt32), BreakLevel: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def SetSystemErrorControl(self, OutputLevel: UInt32, BreakLevel: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def GetTextMacro(self, Slot: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, MacroSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def SetTextMacro(self, Slot: UInt32, Macro: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def GetRadix(self, Radix: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def SetRadix(self, Radix: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def Evaluate(self, Expression: win32more.Windows.Win32.Foundation.PSTR, DesiredType: UInt32, Value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), RemainderIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def CoerceValue(self, In: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), OutType: UInt32, Out: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def CoerceValues(self, Count: UInt32, In: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), OutTypes: POINTER(UInt32), Out: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def Execute(self, OutputControl: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def ExecuteCommandFile(self, OutputControl: UInt32, CommandFile: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def GetNumberBreakpoints(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def GetBreakpointByIndex(self, Index: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def GetBreakpointById(self, Id: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def GetBreakpointParameters(self, Count: UInt32, Ids: POINTER(UInt32), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_BREAKPOINT_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def AddBreakpoint(self, Type: UInt32, DesiredId: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def RemoveBreakpoint(self, Bp: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def AddExtension(self, Path: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def RemoveExtension(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def GetExtensionByPath(self, Path: win32more.Windows.Win32.Foundation.PSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def CallExtension(self, Handle: UInt64, Function: win32more.Windows.Win32.Foundation.PSTR, Arguments: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def GetExtensionFunction(self, Handle: UInt64, FuncName: win32more.Windows.Win32.Foundation.PSTR, Function: POINTER(win32more.Windows.Win32.Foundation.FARPROC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def GetWindbgExtensionApis32(self, Api: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def GetWindbgExtensionApis64(self, Api: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def GetNumberEventFilters(self, SpecificEvents: POINTER(UInt32), SpecificExceptions: POINTER(UInt32), ArbitraryExceptions: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def GetEventFilterText(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def GetEventFilterCommand(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def SetEventFilterCommand(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def GetSpecificFilterParameters(self, Start: UInt32, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SPECIFIC_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def SetSpecificFilterParameters(self, Start: UInt32, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SPECIFIC_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def GetSpecificFilterArgument(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ArgumentSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def SetSpecificFilterArgument(self, Index: UInt32, Argument: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def GetExceptionFilterParameters(self, Count: UInt32, Codes: POINTER(UInt32), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_EXCEPTION_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def SetExceptionFilterParameters(self, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_EXCEPTION_FILTER_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def GetExceptionFilterSecondCommand(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def SetExceptionFilterSecondCommand(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def WaitForEvent(self, Flags: UInt32, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def GetLastEventInformation(self, Type: POINTER(UInt32), ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32), ExtraInformation: VoidPtr, ExtraInformationSize: UInt32, ExtraInformationUsed: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PSTR, DescriptionSize: UInt32, DescriptionUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def GetCurrentTimeDate(self, TimeDate: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def GetCurrentSystemUpTime(self, UpTime: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def GetDumpFormatFlags(self, FormatFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def GetNumberTextReplacements(self, NumRepl: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def GetTextReplacement(self, SrcText: win32more.Windows.Win32.Foundation.PSTR, Index: UInt32, SrcBuffer: win32more.Windows.Win32.Foundation.PSTR, SrcBufferSize: UInt32, SrcSize: POINTER(UInt32), DstBuffer: win32more.Windows.Win32.Foundation.PSTR, DstBufferSize: UInt32, DstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def SetTextReplacement(self, SrcText: win32more.Windows.Win32.Foundation.PSTR, DstText: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def RemoveTextReplacements(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def OutputTextReplacements(self, OutputControl: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def GetAssemblyOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def AddAssemblyOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(105)
    def RemoveAssemblyOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(106)
    def SetAssemblyOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(107)
    def GetExpressionSyntax(self, Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(108)
    def SetExpressionSyntax(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(109)
    def SetExpressionSyntaxByName(self, AbbrevName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(110)
    def GetNumberExpressionSyntaxes(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(111)
    def GetExpressionSyntaxNames(self, Index: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(112)
    def GetNumberEvents(self, Events: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(113)
    def GetEventIndexDescription(self, Index: UInt32, Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, DescSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(114)
    def GetCurrentEventIndex(self, Index: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(115)
    def SetNextEventIndex(self, Relation: UInt32, Value: UInt32, NextIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(116)
    def GetLogFileWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Append: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(117)
    def OpenLogFileWide(self, File: win32more.Windows.Win32.Foundation.PWSTR, Append: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(118)
    def InputWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, InputSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(119)
    def ReturnInputWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(120)
    def OutputWide(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(121)
    def OutputVaListWide(self, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(122)
    def ControlledOutputWide(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(123)
    def ControlledOutputVaListWide(self, OutputControl: UInt32, Mask: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(124)
    def OutputPromptWide(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(125)
    def OutputPromptVaListWide(self, OutputControl: UInt32, Format: win32more.Windows.Win32.Foundation.PWSTR, Args: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(126)
    def GetPromptTextWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(127)
    def AssembleWide(self, Offset: UInt64, Instr: win32more.Windows.Win32.Foundation.PWSTR, EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(128)
    def DisassembleWide(self, Offset: UInt64, Flags: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, DisassemblySize: POINTER(UInt32), EndOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(129)
    def GetProcessorTypeNamesWide(self, Type: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(130)
    def GetTextMacroWide(self, Slot: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, MacroSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(131)
    def SetTextMacroWide(self, Slot: UInt32, Macro: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(132)
    def EvaluateWide(self, Expression: win32more.Windows.Win32.Foundation.PWSTR, DesiredType: UInt32, Value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE), RemainderIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(133)
    def ExecuteWide(self, OutputControl: UInt32, Command: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(134)
    def ExecuteCommandFileWide(self, OutputControl: UInt32, CommandFile: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(135)
    def GetBreakpointByIndex2(self, Index: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(136)
    def GetBreakpointById2(self, Id: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(137)
    def AddBreakpoint2(self, Type: UInt32, DesiredId: UInt32, Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(138)
    def RemoveBreakpoint2(self, Bp: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(139)
    def AddExtensionWide(self, Path: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(140)
    def GetExtensionByPathWide(self, Path: win32more.Windows.Win32.Foundation.PWSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(141)
    def CallExtensionWide(self, Handle: UInt64, Function: win32more.Windows.Win32.Foundation.PWSTR, Arguments: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(142)
    def GetExtensionFunctionWide(self, Handle: UInt64, FuncName: win32more.Windows.Win32.Foundation.PWSTR, Function: POINTER(win32more.Windows.Win32.Foundation.FARPROC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(143)
    def GetEventFilterTextWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, TextSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(144)
    def GetEventFilterCommandWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(145)
    def SetEventFilterCommandWide(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(146)
    def GetSpecificFilterArgumentWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, ArgumentSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(147)
    def SetSpecificFilterArgumentWide(self, Index: UInt32, Argument: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(148)
    def GetExceptionFilterSecondCommandWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, CommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(149)
    def SetExceptionFilterSecondCommandWide(self, Index: UInt32, Command: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(150)
    def GetLastEventInformationWide(self, Type: POINTER(UInt32), ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32), ExtraInformation: VoidPtr, ExtraInformationSize: UInt32, ExtraInformationUsed: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PWSTR, DescriptionSize: UInt32, DescriptionUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(151)
    def GetTextReplacementWide(self, SrcText: win32more.Windows.Win32.Foundation.PWSTR, Index: UInt32, SrcBuffer: win32more.Windows.Win32.Foundation.PWSTR, SrcBufferSize: UInt32, SrcSize: POINTER(UInt32), DstBuffer: win32more.Windows.Win32.Foundation.PWSTR, DstBufferSize: UInt32, DstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(152)
    def SetTextReplacementWide(self, SrcText: win32more.Windows.Win32.Foundation.PWSTR, DstText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(153)
    def SetExpressionSyntaxByNameWide(self, AbbrevName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(154)
    def GetExpressionSyntaxNamesWide(self, Index: UInt32, FullNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, FullNameBufferSize: UInt32, FullNameSize: POINTER(UInt32), AbbrevNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, AbbrevNameBufferSize: UInt32, AbbrevNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(155)
    def GetEventIndexDescriptionWide(self, Index: UInt32, Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, DescSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(156)
    def GetLogFile2(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(157)
    def OpenLogFile2(self, File: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(158)
    def GetLogFile2Wide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, FileSize: POINTER(UInt32), Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(159)
    def OpenLogFile2Wide(self, File: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(160)
    def GetSystemVersionValues(self, PlatformId: POINTER(UInt32), Win32Major: POINTER(UInt32), Win32Minor: POINTER(UInt32), KdMajor: POINTER(UInt32), KdMinor: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(161)
    def GetSystemVersionString(self, Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(162)
    def GetSystemVersionStringWide(self, Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(163)
    def GetContextStackTrace(self, StartContext: VoidPtr, StartContextSize: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, FrameContexts: VoidPtr, FrameContextsSize: UInt32, FrameContextsEntrySize: UInt32, FramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(164)
    def OutputContextStackTrace(self, OutputControl: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), FramesSize: UInt32, FrameContexts: VoidPtr, FrameContextsSize: UInt32, FrameContextsEntrySize: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(165)
    def GetStoredEventInformation(self, Type: POINTER(UInt32), ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32), Context: VoidPtr, ContextSize: UInt32, ContextUsed: POINTER(UInt32), ExtraInformation: VoidPtr, ExtraInformationSize: UInt32, ExtraInformationUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(166)
    def GetManagedStatus(self, Flags: POINTER(UInt32), WhichString: UInt32, String: win32more.Windows.Win32.Foundation.PSTR, StringSize: UInt32, StringNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(167)
    def GetManagedStatusWide(self, Flags: POINTER(UInt32), WhichString: UInt32, String: win32more.Windows.Win32.Foundation.PWSTR, StringSize: UInt32, StringNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(168)
    def ResetManagedStatus(self, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(169)
    def GetStackTraceEx(self, FrameOffset: UInt64, StackOffset: UInt64, InstructionOffset: UInt64, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX), FramesSize: UInt32, FramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(170)
    def OutputStackTraceEx(self, OutputControl: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX), FramesSize: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(171)
    def GetContextStackTraceEx(self, StartContext: VoidPtr, StartContextSize: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX), FramesSize: UInt32, FrameContexts: VoidPtr, FrameContextsSize: UInt32, FrameContextsEntrySize: UInt32, FramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(172)
    def OutputContextStackTraceEx(self, OutputControl: UInt32, Frames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX), FramesSize: UInt32, FrameContexts: VoidPtr, FrameContextsSize: UInt32, FrameContextsEntrySize: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(173)
    def GetBreakpointByGuid(self, Guid: POINTER(Guid), Bp: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(174)
    def GetExecutionStatusEx(self, Status: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(175)
    def GetSynchronizationStatus(self, SendsAttempted: POINTER(UInt32), SecondsSinceLastResponse: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(176)
    def GetDebuggeeType2(self, Flags: UInt32, Class: POINTER(UInt32), Qualifier: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugDataSpaces(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{88f7dfab-3ea7-4c3a-aefb-c4e8106173aa}')
    @commethod(3)
    def ReadVirtual(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def WriteVirtual(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SearchVirtual(self, Offset: UInt64, Length: UInt64, Pattern: VoidPtr, PatternSize: UInt32, PatternGranularity: UInt32, MatchOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def ReadVirtualUncached(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def WriteVirtualUncached(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def ReadPointersVirtual(self, Count: UInt32, Offset: UInt64, Ptrs: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def WritePointersVirtual(self, Count: UInt32, Offset: UInt64, Ptrs: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def ReadPhysical(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def WritePhysical(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def ReadControl(self, Processor: UInt32, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def WriteControl(self, Processor: UInt32, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def ReadIo(self, InterfaceType: UInt32, BusNumber: UInt32, AddressSpace: UInt32, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def WriteIo(self, InterfaceType: UInt32, BusNumber: UInt32, AddressSpace: UInt32, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def ReadMsr(self, Msr: UInt32, Value: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def WriteMsr(self, Msr: UInt32, Value: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def ReadBusData(self, BusDataType: UInt32, BusNumber: UInt32, SlotNumber: UInt32, Offset: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def WriteBusData(self, BusDataType: UInt32, BusNumber: UInt32, SlotNumber: UInt32, Offset: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def CheckLowMemory(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def ReadDebuggerData(self, Index: UInt32, Buffer: VoidPtr, BufferSize: UInt32, DataSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def ReadProcessorSystemData(self, Processor: UInt32, Index: UInt32, Buffer: VoidPtr, BufferSize: UInt32, DataSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugDataSpaces2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7a5e852f-96e9-468f-ac1b-0b3addc4a049}')
    @commethod(3)
    def ReadVirtual(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def WriteVirtual(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SearchVirtual(self, Offset: UInt64, Length: UInt64, Pattern: VoidPtr, PatternSize: UInt32, PatternGranularity: UInt32, MatchOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def ReadVirtualUncached(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def WriteVirtualUncached(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def ReadPointersVirtual(self, Count: UInt32, Offset: UInt64, Ptrs: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def WritePointersVirtual(self, Count: UInt32, Offset: UInt64, Ptrs: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def ReadPhysical(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def WritePhysical(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def ReadControl(self, Processor: UInt32, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def WriteControl(self, Processor: UInt32, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def ReadIo(self, InterfaceType: UInt32, BusNumber: UInt32, AddressSpace: UInt32, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def WriteIo(self, InterfaceType: UInt32, BusNumber: UInt32, AddressSpace: UInt32, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def ReadMsr(self, Msr: UInt32, Value: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def WriteMsr(self, Msr: UInt32, Value: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def ReadBusData(self, BusDataType: UInt32, BusNumber: UInt32, SlotNumber: UInt32, Offset: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def WriteBusData(self, BusDataType: UInt32, BusNumber: UInt32, SlotNumber: UInt32, Offset: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def CheckLowMemory(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def ReadDebuggerData(self, Index: UInt32, Buffer: VoidPtr, BufferSize: UInt32, DataSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def ReadProcessorSystemData(self, Processor: UInt32, Index: UInt32, Buffer: VoidPtr, BufferSize: UInt32, DataSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def VirtualToPhysical(self, Virtual: UInt64, Physical: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetVirtualTranslationPhysicalOffsets(self, Virtual: UInt64, Offsets: POINTER(UInt64), OffsetsSize: UInt32, Levels: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def ReadHandleData(self, Handle: UInt64, DataType: UInt32, Buffer: VoidPtr, BufferSize: UInt32, DataSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def FillVirtual(self, Start: UInt64, Size: UInt32, Pattern: VoidPtr, PatternSize: UInt32, Filled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def FillPhysical(self, Start: UInt64, Size: UInt32, Pattern: VoidPtr, PatternSize: UInt32, Filled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def QueryVirtual(self, Offset: UInt64, Info: POINTER(win32more.Windows.Win32.System.Memory.MEMORY_BASIC_INFORMATION64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugDataSpaces3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{23f79d6c-8aaf-4f7c-a607-9995f5407e63}')
    @commethod(3)
    def ReadVirtual(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def WriteVirtual(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SearchVirtual(self, Offset: UInt64, Length: UInt64, Pattern: VoidPtr, PatternSize: UInt32, PatternGranularity: UInt32, MatchOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def ReadVirtualUncached(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def WriteVirtualUncached(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def ReadPointersVirtual(self, Count: UInt32, Offset: UInt64, Ptrs: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def WritePointersVirtual(self, Count: UInt32, Offset: UInt64, Ptrs: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def ReadPhysical(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def WritePhysical(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def ReadControl(self, Processor: UInt32, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def WriteControl(self, Processor: UInt32, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def ReadIo(self, InterfaceType: UInt32, BusNumber: UInt32, AddressSpace: UInt32, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def WriteIo(self, InterfaceType: UInt32, BusNumber: UInt32, AddressSpace: UInt32, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def ReadMsr(self, Msr: UInt32, Value: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def WriteMsr(self, Msr: UInt32, Value: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def ReadBusData(self, BusDataType: UInt32, BusNumber: UInt32, SlotNumber: UInt32, Offset: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def WriteBusData(self, BusDataType: UInt32, BusNumber: UInt32, SlotNumber: UInt32, Offset: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def CheckLowMemory(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def ReadDebuggerData(self, Index: UInt32, Buffer: VoidPtr, BufferSize: UInt32, DataSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def ReadProcessorSystemData(self, Processor: UInt32, Index: UInt32, Buffer: VoidPtr, BufferSize: UInt32, DataSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def VirtualToPhysical(self, Virtual: UInt64, Physical: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetVirtualTranslationPhysicalOffsets(self, Virtual: UInt64, Offsets: POINTER(UInt64), OffsetsSize: UInt32, Levels: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def ReadHandleData(self, Handle: UInt64, DataType: UInt32, Buffer: VoidPtr, BufferSize: UInt32, DataSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def FillVirtual(self, Start: UInt64, Size: UInt32, Pattern: VoidPtr, PatternSize: UInt32, Filled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def FillPhysical(self, Start: UInt64, Size: UInt32, Pattern: VoidPtr, PatternSize: UInt32, Filled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def QueryVirtual(self, Offset: UInt64, Info: POINTER(win32more.Windows.Win32.System.Memory.MEMORY_BASIC_INFORMATION64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def ReadImageNtHeaders(self, ImageBase: UInt64, Headers: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.IMAGE_NT_HEADERS64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def ReadTagged(self, Tag: POINTER(Guid), Offset: UInt32, Buffer: VoidPtr, BufferSize: UInt32, TotalSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def StartEnumTagged(self, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def GetNextTagged(self, Handle: UInt64, Tag: POINTER(Guid), Size: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def EndEnumTagged(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugDataSpaces4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d98ada1f-29e9-4ef5-a6c0-e53349883212}')
    @commethod(3)
    def ReadVirtual(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def WriteVirtual(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SearchVirtual(self, Offset: UInt64, Length: UInt64, Pattern: VoidPtr, PatternSize: UInt32, PatternGranularity: UInt32, MatchOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def ReadVirtualUncached(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def WriteVirtualUncached(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def ReadPointersVirtual(self, Count: UInt32, Offset: UInt64, Ptrs: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def WritePointersVirtual(self, Count: UInt32, Offset: UInt64, Ptrs: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def ReadPhysical(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def WritePhysical(self, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def ReadControl(self, Processor: UInt32, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def WriteControl(self, Processor: UInt32, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def ReadIo(self, InterfaceType: UInt32, BusNumber: UInt32, AddressSpace: UInt32, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def WriteIo(self, InterfaceType: UInt32, BusNumber: UInt32, AddressSpace: UInt32, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def ReadMsr(self, Msr: UInt32, Value: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def WriteMsr(self, Msr: UInt32, Value: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def ReadBusData(self, BusDataType: UInt32, BusNumber: UInt32, SlotNumber: UInt32, Offset: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def WriteBusData(self, BusDataType: UInt32, BusNumber: UInt32, SlotNumber: UInt32, Offset: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def CheckLowMemory(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def ReadDebuggerData(self, Index: UInt32, Buffer: VoidPtr, BufferSize: UInt32, DataSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def ReadProcessorSystemData(self, Processor: UInt32, Index: UInt32, Buffer: VoidPtr, BufferSize: UInt32, DataSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def VirtualToPhysical(self, Virtual: UInt64, Physical: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetVirtualTranslationPhysicalOffsets(self, Virtual: UInt64, Offsets: POINTER(UInt64), OffsetsSize: UInt32, Levels: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def ReadHandleData(self, Handle: UInt64, DataType: UInt32, Buffer: VoidPtr, BufferSize: UInt32, DataSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def FillVirtual(self, Start: UInt64, Size: UInt32, Pattern: VoidPtr, PatternSize: UInt32, Filled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def FillPhysical(self, Start: UInt64, Size: UInt32, Pattern: VoidPtr, PatternSize: UInt32, Filled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def QueryVirtual(self, Offset: UInt64, Info: POINTER(win32more.Windows.Win32.System.Memory.MEMORY_BASIC_INFORMATION64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def ReadImageNtHeaders(self, ImageBase: UInt64, Headers: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.IMAGE_NT_HEADERS64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def ReadTagged(self, Tag: POINTER(Guid), Offset: UInt32, Buffer: VoidPtr, BufferSize: UInt32, TotalSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def StartEnumTagged(self, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def GetNextTagged(self, Handle: UInt64, Tag: POINTER(Guid), Size: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def EndEnumTagged(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def GetOffsetInformation(self, Space: UInt32, Which: UInt32, Offset: UInt64, Buffer: VoidPtr, BufferSize: UInt32, InfoSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetNextDifferentlyValidOffsetVirtual(self, Offset: UInt64, NextOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def GetValidRegionVirtual(self, Base: UInt64, Size: UInt32, ValidBase: POINTER(UInt64), ValidSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def SearchVirtual2(self, Offset: UInt64, Length: UInt64, Flags: UInt32, Pattern: VoidPtr, PatternSize: UInt32, PatternGranularity: UInt32, MatchOffset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def ReadMultiByteStringVirtual(self, Offset: UInt64, MaxBytes: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, StringBytes: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def ReadMultiByteStringVirtualWide(self, Offset: UInt64, MaxBytes: UInt32, CodePage: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, StringBytes: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def ReadUnicodeStringVirtual(self, Offset: UInt64, MaxBytes: UInt32, CodePage: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, StringBytes: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def ReadUnicodeStringVirtualWide(self, Offset: UInt64, MaxBytes: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, StringBytes: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def ReadPhysical2(self, Offset: UInt64, Flags: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def WritePhysical2(self, Offset: UInt64, Flags: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugEventCallbacks(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{337be28b-5036-4d72-b6bf-c45fbb9f2eaa}')
    @commethod(3)
    def GetInterestMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Breakpoint(self, Bp: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Exception(self, Exception: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.EXCEPTION_RECORD64), FirstChance: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateThread(self, Handle: UInt64, DataOffset: UInt64, StartOffset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ExitThread(self, ExitCode: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateProcessA(self, ImageFileHandle: UInt64, Handle: UInt64, BaseOffset: UInt64, ModuleSize: UInt32, ModuleName: win32more.Windows.Win32.Foundation.PSTR, ImageName: win32more.Windows.Win32.Foundation.PSTR, CheckSum: UInt32, TimeDateStamp: UInt32, InitialThreadHandle: UInt64, ThreadDataOffset: UInt64, StartOffset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def ExitProcess(self, ExitCode: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def LoadModule(self, ImageFileHandle: UInt64, BaseOffset: UInt64, ModuleSize: UInt32, ModuleName: win32more.Windows.Win32.Foundation.PSTR, ImageName: win32more.Windows.Win32.Foundation.PSTR, CheckSum: UInt32, TimeDateStamp: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def UnloadModule(self, ImageBaseName: win32more.Windows.Win32.Foundation.PSTR, BaseOffset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SystemError(self, Error: UInt32, Level: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SessionStatus(self, Status: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def ChangeDebuggeeState(self, Flags: UInt32, Argument: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def ChangeEngineState(self, Flags: UInt32, Argument: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def ChangeSymbolState(self, Flags: UInt32, Argument: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugEventCallbacksWide(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0690e046-9c23-45ac-a04f-987ac29ad0d3}')
    @commethod(3)
    def GetInterestMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Breakpoint(self, Bp: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Exception(self, Exception: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.EXCEPTION_RECORD64), FirstChance: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateThread(self, Handle: UInt64, DataOffset: UInt64, StartOffset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ExitThread(self, ExitCode: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateProcessA(self, ImageFileHandle: UInt64, Handle: UInt64, BaseOffset: UInt64, ModuleSize: UInt32, ModuleName: win32more.Windows.Win32.Foundation.PWSTR, ImageName: win32more.Windows.Win32.Foundation.PWSTR, CheckSum: UInt32, TimeDateStamp: UInt32, InitialThreadHandle: UInt64, ThreadDataOffset: UInt64, StartOffset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def ExitProcess(self, ExitCode: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def LoadModule(self, ImageFileHandle: UInt64, BaseOffset: UInt64, ModuleSize: UInt32, ModuleName: win32more.Windows.Win32.Foundation.PWSTR, ImageName: win32more.Windows.Win32.Foundation.PWSTR, CheckSum: UInt32, TimeDateStamp: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def UnloadModule(self, ImageBaseName: win32more.Windows.Win32.Foundation.PWSTR, BaseOffset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SystemError(self, Error: UInt32, Level: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SessionStatus(self, Status: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def ChangeDebuggeeState(self, Flags: UInt32, Argument: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def ChangeEngineState(self, Flags: UInt32, Argument: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def ChangeSymbolState(self, Flags: UInt32, Argument: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugEventContextCallbacks(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{61a4905b-23f9-4247-b3c5-53d087529ab7}')
    @commethod(3)
    def GetInterestMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Breakpoint(self, Bp: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugBreakpoint2, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Exception(self, Exception: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.EXCEPTION_RECORD64), FirstChance: UInt32, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateThread(self, Handle: UInt64, DataOffset: UInt64, StartOffset: UInt64, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ExitThread(self, ExitCode: UInt32, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateProcessA(self, ImageFileHandle: UInt64, Handle: UInt64, BaseOffset: UInt64, ModuleSize: UInt32, ModuleName: win32more.Windows.Win32.Foundation.PWSTR, ImageName: win32more.Windows.Win32.Foundation.PWSTR, CheckSum: UInt32, TimeDateStamp: UInt32, InitialThreadHandle: UInt64, ThreadDataOffset: UInt64, StartOffset: UInt64, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def ExitProcess(self, ExitCode: UInt32, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def LoadModule(self, ImageFileHandle: UInt64, BaseOffset: UInt64, ModuleSize: UInt32, ModuleName: win32more.Windows.Win32.Foundation.PWSTR, ImageName: win32more.Windows.Win32.Foundation.PWSTR, CheckSum: UInt32, TimeDateStamp: UInt32, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def UnloadModule(self, ImageBaseName: win32more.Windows.Win32.Foundation.PWSTR, BaseOffset: UInt64, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SystemError(self, Error: UInt32, Level: UInt32, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SessionStatus(self, Status: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def ChangeDebuggeeState(self, Flags: UInt32, Argument: UInt64, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def ChangeEngineState(self, Flags: UInt32, Argument: UInt64, Context: VoidPtr, ContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def ChangeSymbolState(self, Flags: UInt32, Argument: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugFAEntryTags(ComPtr):
    extends: None
    @commethod(0)
    def GetType(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE) -> win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY_TYPE: ...
    @commethod(1)
    def SetType(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, EntryType: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY_TYPE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(2)
    def GetProperties(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Name: win32more.Windows.Win32.Foundation.PSTR, NameSize: POINTER(UInt32), Description: win32more.Windows.Win32.Foundation.PSTR, DescSize: POINTER(UInt32), Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(3)
    def SetProperties(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Name: win32more.Windows.Win32.Foundation.PSTR, Description: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetTagByName(self, PluginId: win32more.Windows.Win32.Foundation.PSTR, TagName: win32more.Windows.Win32.Foundation.PSTR, Tag: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def IsValidTagToSet(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE) -> win32more.Windows.Win32.Foundation.BOOL: ...
class IDebugFailureAnalysis(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ed0de363-451f-4943-820c-62dccdfa7e6d}')
    @commethod(3)
    def GetFailureClass(self) -> UInt32: ...
    @commethod(4)
    def GetFailureType(self) -> win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FAILURE_TYPE: ...
    @commethod(5)
    def GetFailureCode(self) -> UInt32: ...
    @commethod(6)
    def Get(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(7)
    def GetNext(self, Entry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY), Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, TagMask: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(8)
    def GetString(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Str: win32more.Windows.Win32.Foundation.PSTR, MaxSize: UInt32) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(9)
    def GetBuffer(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Buf: VoidPtr, Size: UInt32) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(10)
    def GetUlong(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Value: POINTER(UInt32)) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(11)
    def GetUlong64(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Value: POINTER(UInt64)) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(12)
    def NextEntry(self, Entry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY)) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
class IDebugFailureAnalysis2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ea15c288-8226-4b70-acf6-0be6b189e3ad}')
    @commethod(3)
    def GetFailureClass(self) -> UInt32: ...
    @commethod(4)
    def GetFailureType(self) -> win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FAILURE_TYPE: ...
    @commethod(5)
    def GetFailureCode(self) -> UInt32: ...
    @commethod(6)
    def Get(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(7)
    def GetNext(self, Entry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY), Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, TagMask: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(8)
    def GetString(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Str: win32more.Windows.Win32.Foundation.PSTR, MaxSize: UInt32) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(9)
    def GetBuffer(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Buf: VoidPtr, Size: UInt32) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(10)
    def GetUlong(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Value: POINTER(UInt32)) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(11)
    def GetUlong64(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Value: POINTER(UInt64)) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(12)
    def NextEntry(self, Entry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY)) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(13)
    def SetString(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Str: win32more.Windows.Win32.Foundation.PSTR) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(14)
    def SetExtensionCommand(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Extension: win32more.Windows.Win32.Foundation.PSTR) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(15)
    def SetUlong(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Value: UInt32) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(16)
    def SetUlong64(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Value: UInt64) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(17)
    def SetBuffer(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, EntryType: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY_TYPE, Buf: VoidPtr, Size: UInt32) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(18)
    def AddString(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Str: win32more.Windows.Win32.Foundation.PSTR) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(19)
    def AddExtensionCommand(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Extension: win32more.Windows.Win32.Foundation.PSTR) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(20)
    def AddUlong(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Value: UInt32) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(21)
    def AddUlong64(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Value: UInt64) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(22)
    def AddBuffer(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, EntryType: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY_TYPE, Buf: VoidPtr, Size: UInt32) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(23)
    def GetDebugFATagControl(self, FATagControl: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugFAEntryTags)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetAnalysisXml(self, ppXMLDOMElement: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def AddStructuredAnalysisData(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Analysis: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugFailureAnalysis2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugFailureAnalysis3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3627dc67-fd45-42ff-9ba4-4a67ee64619f}')
    @commethod(3)
    def GetFailureClass(self) -> UInt32: ...
    @commethod(4)
    def GetFailureType(self) -> win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FAILURE_TYPE: ...
    @commethod(5)
    def GetFailureCode(self) -> UInt32: ...
    @commethod(6)
    def Get(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(7)
    def GetNext(self, Entry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY), Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, TagMask: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(8)
    def GetString(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Str: win32more.Windows.Win32.Foundation.PSTR, MaxSize: UInt32) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(9)
    def GetBuffer(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Buf: VoidPtr, Size: UInt32) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(10)
    def GetUlong(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Value: POINTER(UInt32)) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(11)
    def GetUlong64(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Value: POINTER(UInt64)) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(12)
    def NextEntry(self, Entry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY)) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(13)
    def SetString(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Str: win32more.Windows.Win32.Foundation.PSTR) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(14)
    def SetExtensionCommand(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Extension: win32more.Windows.Win32.Foundation.PSTR) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(15)
    def SetUlong(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Value: UInt32) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(16)
    def SetUlong64(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Value: UInt64) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(17)
    def SetBuffer(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, EntryType: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY_TYPE, Buf: VoidPtr, Size: UInt32) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(18)
    def AddString(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Str: win32more.Windows.Win32.Foundation.PSTR) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(19)
    def AddExtensionCommand(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Extension: win32more.Windows.Win32.Foundation.PSTR) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(20)
    def AddUlong(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Value: UInt32) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(21)
    def AddUlong64(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Value: UInt64) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(22)
    def AddBuffer(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, EntryType: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY_TYPE, Buf: VoidPtr, Size: UInt32) -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FA_ENTRY): ...
    @commethod(23)
    def GetDebugFATagControl(self, FATagControl: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugFAEntryTags)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetAnalysisXml(self, ppXMLDOMElement: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def AddStructuredAnalysisData(self, Tag: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_FLR_PARAM_TYPE, Analysis: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugFailureAnalysis2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def AddThreads(self, pDebugFailureThreadEnum: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def AttributeGet(self, nIndex: UInt32, pValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def AttributeGetName(self, nIndex: UInt32, pName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def AttributeSet(self, nIndex: UInt32, Value: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def BlameApplication(self, Postfix: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def BlameProcess(self, Postfix: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def BlameThread(self, pThread: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def BlameStitch(self, pThread: win32more.Windows.Win32.System.Com.IUnknown, Stitch: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def BlameTEB(self, Address: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def BlameETHREAD(self, Address: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def ProblemClassIsSet(self, nIndex: UInt32, pSet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def ProblemClassDelete(self, nIndex: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def ProblemClassSet(self, nIndex: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def ProblemClassSetBSTR(self, nIndex: UInt32, Value: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def SetAdditionalXML(self, Key: win32more.Windows.Win32.Foundation.BSTR, pXMLDOMElement: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetAdditionalXML(self, Key: win32more.Windows.Win32.Foundation.BSTR, ppXMLDOMElement: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def DeleteAdditionalXML(self, Key: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHost(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b8c74943-6b2c-4eeb-b5c5-35d378a6d99d}')
    @commethod(3)
    def GetHostDefinedInterface(self, hostUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetCurrentContext(self, context: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetDefaultMetadata(self, defaultMetadataStore: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostBaseClass(ComPtr):
    extends: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbol
    _iid_ = Guid('{b94d57d2-390b-40f7-b5b4-b6db897d974b}')
    @commethod(10)
    def GetOffset(self, offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostConstant(ComPtr):
    extends: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbol
    _iid_ = Guid('{62787edc-fa76-4690-bd71-5e8c3e2937ec}')
    @commethod(10)
    def GetValue(self, value: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostContext(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a68c70d8-5ec0-46e5-b775-3134a48ea2e3}')
    @commethod(3)
    def IsEqualTo(self, pContext: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext, pIsEqual: POINTER(Boolean)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostData(ComPtr):
    extends: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbol
    _iid_ = Guid('{a3d64993-826c-44fa-897d-926f2fe7ad0b}')
    @commethod(10)
    def GetLocationKind(self, locationKind: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.LocationKind)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetLocation(self, location: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetValue(self, value: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostErrorSink(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c8ff0f0b-fce9-467e-8bb3-5d69ef109c00}')
    @commethod(3)
    def ReportError(self, errClass: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ErrorClass, hrError: win32more.Windows.Win32.Foundation.HRESULT, message: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostEvaluator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0fef9a21-577e-4997-ac7b-1c4883241d99}')
    @commethod(3)
    def EvaluateExpression(self, context: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext, expression: win32more.Windows.Win32.Foundation.PWSTR, bindingContext: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, result: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), metadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EvaluateExtendedExpression(self, context: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext, expression: win32more.Windows.Win32.Foundation.PWSTR, bindingContext: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, result: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), metadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostEvaluator2(ComPtr):
    extends: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostEvaluator
    _iid_ = Guid('{a117a435-1fb4-4092-a2ab-a929576c1e87}')
    @commethod(5)
    def AssignTo(self, assignmentReference: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, assignmentValue: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, assignmentResult: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), assignmentMetadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostExtensibility(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3c2b24e1-11d0-4f86-8ae5-4df166f73253}')
    @commethod(3)
    def CreateFunctionAlias(self, aliasName: win32more.Windows.Win32.Foundation.PWSTR, functionObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DestroyFunctionAlias(self, aliasName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostField(ComPtr):
    extends: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbol
    _iid_ = Guid('{e06f6495-16bc-4cc9-b11d-2a6b23fa72f3}')
    @commethod(10)
    def GetLocationKind(self, locationKind: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.LocationKind)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetOffset(self, offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetLocation(self, location: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetValue(self, value: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostMemory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{212149c9-9183-4a3e-b00e-4fd1dc95339b}')
    @commethod(3)
    def ReadBytes(self, context: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext, location: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location, buffer: VoidPtr, bufferSize: UInt64, bytesRead: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def WriteBytes(self, context: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext, location: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location, buffer: VoidPtr, bufferSize: UInt64, bytesWritten: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def ReadPointers(self, context: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext, location: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location, count: UInt64, pointers: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def WritePointers(self, context: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext, location: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location, count: UInt64, pointers: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetDisplayStringForLocation(self, context: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext, location: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location, verbose: Byte, locationName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostMemory2(ComPtr):
    extends: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostMemory
    _iid_ = Guid('{eea033de-38f6-416b-a251-1d3771001270}')
    @commethod(8)
    def LinearizeLocation(self, context: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext, location: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location, pLinearizedLocation: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostModule(ComPtr):
    extends: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbol
    _iid_ = Guid('{c9ba3e18-d070-4378-bbd0-34613b346e1e}')
    @commethod(10)
    def GetImageName(self, allowPath: Byte, imageName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetBaseLocation(self, moduleBaseLocation: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetVersion(self, fileVersion: POINTER(UInt64), productVersion: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def FindTypeByName(self, typeName: win32more.Windows.Win32.Foundation.PWSTR, type: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def FindSymbolByRVA(self, rva: UInt64, symbol: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbol)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def FindSymbolByName(self, symbolName: win32more.Windows.Win32.Foundation.PWSTR, symbol: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbol)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostModule2(ComPtr):
    extends: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostModule
    _iid_ = Guid('{b51887e8-bcd0-4e8f-a8c7-434398b78c37}')
    @commethod(16)
    def FindContainingSymbolByRVA(self, rva: UInt64, symbol: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbol), offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostModuleSignature(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{31e53a5a-01ee-4bbb-b899-4b46ae7d595c}')
    @commethod(3)
    def IsMatch(self, pModule: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostModule, isMatch: POINTER(Boolean)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostPublic(ComPtr):
    extends: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbol
    _iid_ = Guid('{6c597ac9-fb4d-4f6d-9f39-22488539f8f4}')
    @commethod(10)
    def GetLocationKind(self, locationKind: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.LocationKind)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetLocation(self, location: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostScriptHost(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b70334a4-b92c-4570-93a1-d3eb686649a0}')
    @commethod(3)
    def CreateContext(self, script: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScript, scriptContext: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelScriptHostContext)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostStatus(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4f3e1ce2-86b2-4c7a-9c65-d0a9d0eecf44}')
    @commethod(3)
    def PollUserInterrupt(self, interruptRequested: POINTER(Boolean)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostSymbol(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0f819103-87de-4e96-8277-e05cd441fb22}')
    @commethod(3)
    def GetContext(self, context: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EnumerateChildren(self, kind: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolKind, name: win32more.Windows.Win32.Foundation.PWSTR, ppEnum: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbolEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetSymbolKind(self, kind: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolKind)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetName(self, symbolName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetType(self, type: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetContainingModule(self, containingModule: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostModule)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CompareAgainst(self, pComparisonSymbol: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbol, comparisonFlags: UInt32, pMatches: POINTER(Boolean)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostSymbol2(ComPtr):
    extends: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbol
    _iid_ = Guid('{21515b67-6720-4257-8a68-077dc944471c}')
    @commethod(10)
    def GetLanguage(self, pKind: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.LanguageKind)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostSymbolEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{28d96c86-10a3-4976-b14e-eaef4790aa1f}')
    @commethod(3)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetNext(self, symbol: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbol)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostSymbols(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{854fd751-c2e1-4eb2-b525-6619cb97a588}')
    @commethod(3)
    def CreateModuleSignature(self, pwszModuleName: win32more.Windows.Win32.Foundation.PWSTR, pwszMinVersion: win32more.Windows.Win32.Foundation.PWSTR, pwszMaxVersion: win32more.Windows.Win32.Foundation.PWSTR, ppModuleSignature: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostModuleSignature)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateTypeSignature(self, signatureSpecification: win32more.Windows.Win32.Foundation.PWSTR, module: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostModule, typeSignature: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostTypeSignature)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateTypeSignatureForModuleRange(self, signatureSpecification: win32more.Windows.Win32.Foundation.PWSTR, moduleName: win32more.Windows.Win32.Foundation.PWSTR, minVersion: win32more.Windows.Win32.Foundation.PWSTR, maxVersion: win32more.Windows.Win32.Foundation.PWSTR, typeSignature: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostTypeSignature)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def EnumerateModules(self, context: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext, moduleEnum: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbolEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def FindModuleByName(self, context: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext, moduleName: win32more.Windows.Win32.Foundation.PWSTR, module: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostModule)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def FindModuleByLocation(self, context: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext, moduleLocation: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location, module: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostModule)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetMostDerivedObject(self, pContext: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext, location: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location, objectType: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType, derivedLocation: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location), derivedType: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostType(ComPtr):
    extends: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbol
    _iid_ = Guid('{3aadc353-2b14-4abb-9893-5e03458e07ee}')
    @commethod(10)
    def GetTypeKind(self, kind: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TypeKind)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetSize(self, size: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetBaseType(self, baseType: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetHashCode(self, hashCode: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetIntrinsicType(self, intrinsicKind: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IntrinsicKind), carrierType: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetBitField(self, lsbOfField: POINTER(UInt32), lengthOfField: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetPointerKind(self, pointerKind: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PointerKind)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetMemberType(self, memberType: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def CreatePointerTo(self, kind: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PointerKind, newType: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetArrayDimensionality(self, arrayDimensionality: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetArrayDimensions(self, dimensions: UInt64, pDimensions: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ArrayDimension)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def CreateArrayOf(self, dimensions: UInt64, pDimensions: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ArrayDimension), newType: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetFunctionCallingConvention(self, conventionKind: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.CallingConventionKind)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetFunctionReturnType(self, returnType: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetFunctionParameterTypeCount(self, count: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def GetFunctionParameterTypeAt(self, i: UInt64, parameterType: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def IsGeneric(self, isGeneric: POINTER(Boolean)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetGenericArgumentCount(self, argCount: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def GetGenericArgumentAt(self, i: UInt64, argument: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbol)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostType2(ComPtr):
    extends: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType
    _iid_ = Guid('{b28632b9-8506-4676-87ce-8f7e05e59876}')
    @commethod(29)
    def IsTypedef(self, isTypedef: POINTER(Boolean)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetTypedefBaseType(self, baseType: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetTypedefFinalBaseType(self, finalBaseType: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def GetFunctionVarArgsKind(self, varArgsKind: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.VarArgsKind)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetFunctionInstancePointerType(self, instancePointerType: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugHostTypeSignature(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3aadc353-2b14-4abb-9893-5e03458e07ee}')
    @commethod(3)
    def GetHashCode(self, hashCode: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def IsMatch(self, type: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType, isMatch: POINTER(Boolean), wildcardMatches: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostSymbolEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CompareAgainst(self, typeSignature: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostTypeSignature, result: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SignatureComparison)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugInputCallbacks(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9f50e42c-f136-499e-9a97-73036c94ed2d}')
    @commethod(3)
    def StartInput(self, BufferSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EndInput(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugOutputCallbacks(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4bf58045-d654-4c40-b0af-683090f356dc}')
    @commethod(3)
    def Output(self, Mask: UInt32, Text: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugOutputCallbacks2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{67721fe9-56d2-4a44-a325-2b65513ce6eb}')
    @commethod(3)
    def Output(self, Mask: UInt32, Text: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetInterestMask(self, Mask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Output2(self, Which: UInt32, Flags: UInt32, Arg: UInt64, Text: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugOutputCallbacksWide(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4c7fd663-c394-4e26-8ef1-34ad5ed3764c}')
    @commethod(3)
    def Output(self, Mask: UInt32, Text: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugOutputStream(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7782d8f2-2b85-4059-ab88-28ceddca1c80}')
    @commethod(3)
    def Write(self, psz: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugPlmClient(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a02b66c4-aea3-4234-a9f7-fe4c383d4e29}')
    @commethod(3)
    def LaunchPlmPackageForDebugWide(self, Server: UInt64, Timeout: UInt32, PackageFullName: win32more.Windows.Win32.Foundation.PWSTR, AppName: win32more.Windows.Win32.Foundation.PWSTR, Arguments: win32more.Windows.Win32.Foundation.PWSTR, ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugPlmClient2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{597c980d-e7bd-4309-962c-9d9b69a7372c}')
    @commethod(3)
    def LaunchPlmPackageForDebugWide(self, Server: UInt64, Timeout: UInt32, PackageFullName: win32more.Windows.Win32.Foundation.PWSTR, AppName: win32more.Windows.Win32.Foundation.PWSTR, Arguments: win32more.Windows.Win32.Foundation.PWSTR, ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def LaunchPlmBgTaskForDebugWide(self, Server: UInt64, Timeout: UInt32, PackageFullName: win32more.Windows.Win32.Foundation.PWSTR, BackgroundTaskId: win32more.Windows.Win32.Foundation.PWSTR, ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugPlmClient3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d4a5dbd1-ca02-4d90-856a-2a92bfd0f20f}')
    @commethod(3)
    def LaunchPlmPackageForDebugWide(self, Server: UInt64, Timeout: UInt32, PackageFullName: win32more.Windows.Win32.Foundation.PWSTR, AppName: win32more.Windows.Win32.Foundation.PWSTR, Arguments: win32more.Windows.Win32.Foundation.PWSTR, ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def LaunchPlmBgTaskForDebugWide(self, Server: UInt64, Timeout: UInt32, PackageFullName: win32more.Windows.Win32.Foundation.PWSTR, BackgroundTaskId: win32more.Windows.Win32.Foundation.PWSTR, ProcessId: POINTER(UInt32), ThreadId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def QueryPlmPackageWide(self, Server: UInt64, PackageFullName: win32more.Windows.Win32.Foundation.PWSTR, Stream: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def QueryPlmPackageList(self, Server: UInt64, Stream: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugOutputStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def EnablePlmPackageDebugWide(self, Server: UInt64, PackageFullName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DisablePlmPackageDebugWide(self, Server: UInt64, PackageFullName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SuspendPlmPackageWide(self, Server: UInt64, PackageFullName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def ResumePlmPackageWide(self, Server: UInt64, PackageFullName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def TerminatePlmPackageWide(self, Server: UInt64, PackageFullName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def LaunchAndDebugPlmAppWide(self, Server: UInt64, PackageFullName: win32more.Windows.Win32.Foundation.PWSTR, AppName: win32more.Windows.Win32.Foundation.PWSTR, Arguments: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def ActivateAndDebugPlmBgTaskWide(self, Server: UInt64, PackageFullName: win32more.Windows.Win32.Foundation.PWSTR, BackgroundTaskId: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugRegisters(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ce289126-9e84-45a7-937e-67bb18691493}')
    @commethod(3)
    def GetNumberRegisters(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDescription(self, Register: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Desc: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_REGISTER_DESCRIPTION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetIndexByName(self, Name: win32more.Windows.Win32.Foundation.PSTR, Index: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetValue(self, Register: UInt32, Value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetValue(self, Register: UInt32, Value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetValues(self, Count: UInt32, Indices: POINTER(UInt32), Start: UInt32, Values: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetValues(self, Count: UInt32, Indices: POINTER(UInt32), Start: UInt32, Values: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def OutputRegisters(self, OutputControl: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetInstructionOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetStackOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetFrameOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugRegisters2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1656afa9-19c6-4e3a-97e7-5dc9160cf9c4}')
    @commethod(3)
    def GetNumberRegisters(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDescription(self, Register: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Desc: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_REGISTER_DESCRIPTION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetIndexByName(self, Name: win32more.Windows.Win32.Foundation.PSTR, Index: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetValue(self, Register: UInt32, Value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetValue(self, Register: UInt32, Value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetValues(self, Count: UInt32, Indices: POINTER(UInt32), Start: UInt32, Values: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetValues(self, Count: UInt32, Indices: POINTER(UInt32), Start: UInt32, Values: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def OutputRegisters(self, OutputControl: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetInstructionOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetStackOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetFrameOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetDescriptionWide(self, Register: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Desc: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_REGISTER_DESCRIPTION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetIndexByNameWide(self, Name: win32more.Windows.Win32.Foundation.PWSTR, Index: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetNumberPseudoRegisters(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetPseudoDescription(self, Register: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), TypeModule: POINTER(UInt64), TypeId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetPseudoDescriptionWide(self, Register: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), TypeModule: POINTER(UInt64), TypeId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetPseudoIndexByName(self, Name: win32more.Windows.Win32.Foundation.PSTR, Index: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetPseudoIndexByNameWide(self, Name: win32more.Windows.Win32.Foundation.PWSTR, Index: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetPseudoValues(self, Source: UInt32, Count: UInt32, Indices: POINTER(UInt32), Start: UInt32, Values: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def SetPseudoValues(self, Source: UInt32, Count: UInt32, Indices: POINTER(UInt32), Start: UInt32, Values: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetValues2(self, Source: UInt32, Count: UInt32, Indices: POINTER(UInt32), Start: UInt32, Values: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def SetValues2(self, Source: UInt32, Count: UInt32, Indices: POINTER(UInt32), Start: UInt32, Values: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def OutputRegisters2(self, OutputControl: UInt32, Source: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetInstructionOffset2(self, Source: UInt32, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetStackOffset2(self, Source: UInt32, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def GetFrameOffset2(self, Source: UInt32, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugSymbolGroup(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f2528316-0f1a-4431-aeed-11d096e1e2ab}')
    @commethod(3)
    def GetNumberSymbols(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddSymbol(self, Name: win32more.Windows.Win32.Foundation.PSTR, Index: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RemoveSymbolByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def RemoveSymbolByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetSymbolName(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetSymbolParameters(self, Start: UInt32, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def ExpandSymbol(self, Index: UInt32, Expand: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def OutputSymbols(self, OutputControl: UInt32, Flags: UInt32, Start: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def WriteSymbol(self, Index: UInt32, Value: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def OutputAsType(self, Index: UInt32, Type: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugSymbolGroup2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6a7ccc5f-fb5e-4dcc-b41c-6c20307bccc7}')
    @commethod(3)
    def GetNumberSymbols(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddSymbol(self, Name: win32more.Windows.Win32.Foundation.PSTR, Index: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RemoveSymbolByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def RemoveSymbolByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetSymbolName(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetSymbolParameters(self, Start: UInt32, Count: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def ExpandSymbol(self, Index: UInt32, Expand: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def OutputSymbols(self, OutputControl: UInt32, Flags: UInt32, Start: UInt32, Count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def WriteSymbol(self, Index: UInt32, Value: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def OutputAsType(self, Index: UInt32, Type: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def AddSymbolWide(self, Name: win32more.Windows.Win32.Foundation.PWSTR, Index: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def RemoveSymbolByNameWide(self, Name: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetSymbolNameWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def WriteSymbolWide(self, Index: UInt32, Value: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def OutputAsTypeWide(self, Index: UInt32, Type: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetSymbolTypeName(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetSymbolTypeNameWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetSymbolSize(self, Index: UInt32, Size: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetSymbolOffset(self, Index: UInt32, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetSymbolRegister(self, Index: UInt32, Register: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetSymbolValueText(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetSymbolValueTextWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def GetSymbolEntryInformation(self, Index: UInt32, Entry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_ENTRY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugSymbols(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8c31e98c-983a-48a5-9016-6fe5d667a950}')
    @commethod(3)
    def GetSymbolOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddSymbolOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RemoveSymbolOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetSymbolOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetNameByOffset(self, Offset: UInt64, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetOffsetByName(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetNearNameByOffset(self, Offset: UInt64, Delta: Int32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetLineByOffset(self, Offset: UInt64, Line: POINTER(UInt32), FileBuffer: win32more.Windows.Win32.Foundation.PSTR, FileBufferSize: UInt32, FileSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetOffsetByLine(self, Line: UInt32, File: win32more.Windows.Win32.Foundation.PSTR, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetNumberModules(self, Loaded: POINTER(UInt32), Unloaded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetModuleByIndex(self, Index: UInt32, Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetModuleByModuleName(self, Name: win32more.Windows.Win32.Foundation.PSTR, StartIndex: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetModuleByOffset(self, Offset: UInt64, StartIndex: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetModuleNames(self, Index: UInt32, Base: UInt64, ImageNameBuffer: win32more.Windows.Win32.Foundation.PSTR, ImageNameBufferSize: UInt32, ImageNameSize: POINTER(UInt32), ModuleNameBuffer: win32more.Windows.Win32.Foundation.PSTR, ModuleNameBufferSize: UInt32, ModuleNameSize: POINTER(UInt32), LoadedImageNameBuffer: win32more.Windows.Win32.Foundation.PSTR, LoadedImageNameBufferSize: UInt32, LoadedImageNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetModuleParameters(self, Count: UInt32, Bases: POINTER(UInt64), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetSymbolModule(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetTypeName(self, Module: UInt64, TypeId: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetTypeId(self, Module: UInt64, Name: win32more.Windows.Win32.Foundation.PSTR, TypeId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetTypeSize(self, Module: UInt64, TypeId: UInt32, Size: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetFieldOffset(self, Module: UInt64, TypeId: UInt32, Field: win32more.Windows.Win32.Foundation.PSTR, Offset: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetSymbolTypeId(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, TypeId: POINTER(UInt32), Module: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetOffsetTypeId(self, Offset: UInt64, TypeId: POINTER(UInt32), Module: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def ReadTypedDataVirtual(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def WriteTypedDataVirtual(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def OutputTypedDataVirtual(self, OutputControl: UInt32, Offset: UInt64, Module: UInt64, TypeId: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def ReadTypedDataPhysical(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def WriteTypedDataPhysical(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def OutputTypedDataPhysical(self, OutputControl: UInt32, Offset: UInt64, Module: UInt64, TypeId: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetScope(self, InstructionOffset: POINTER(UInt64), ScopeFrame: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), ScopeContext: VoidPtr, ScopeContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetScope(self, InstructionOffset: UInt64, ScopeFrame: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), ScopeContext: VoidPtr, ScopeContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def ResetScope(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def GetScopeSymbolGroup(self, Flags: UInt32, Update: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup, Symbols: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def CreateSymbolGroup(self, Group: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def StartSymbolMatch(self, Pattern: win32more.Windows.Win32.Foundation.PSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetNextSymbolMatch(self, Handle: UInt64, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, MatchSize: POINTER(UInt32), Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def EndSymbolMatch(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def Reload(self, Module: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def GetSymbolPath(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def SetSymbolPath(self, Path: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def AppendSymbolPath(self, Addition: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def GetImagePath(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def SetImagePath(self, Path: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def AppendImagePath(self, Addition: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def GetSourcePath(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def GetSourcePathElement(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ElementSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def SetSourcePath(self, Path: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def AppendSourcePath(self, Addition: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def FindSourceFile(self, StartElement: UInt32, File: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, FoundElement: POINTER(UInt32), Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FoundSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def GetSourceFileLineOffsets(self, File: win32more.Windows.Win32.Foundation.PSTR, Buffer: POINTER(UInt64), BufferLines: UInt32, FileLines: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugSymbols2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3a707211-afdd-4495-ad4f-56fecdf8163f}')
    @commethod(3)
    def GetSymbolOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddSymbolOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RemoveSymbolOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetSymbolOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetNameByOffset(self, Offset: UInt64, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetOffsetByName(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetNearNameByOffset(self, Offset: UInt64, Delta: Int32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetLineByOffset(self, Offset: UInt64, Line: POINTER(UInt32), FileBuffer: win32more.Windows.Win32.Foundation.PSTR, FileBufferSize: UInt32, FileSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetOffsetByLine(self, Line: UInt32, File: win32more.Windows.Win32.Foundation.PSTR, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetNumberModules(self, Loaded: POINTER(UInt32), Unloaded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetModuleByIndex(self, Index: UInt32, Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetModuleByModuleName(self, Name: win32more.Windows.Win32.Foundation.PSTR, StartIndex: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetModuleByOffset(self, Offset: UInt64, StartIndex: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetModuleNames(self, Index: UInt32, Base: UInt64, ImageNameBuffer: win32more.Windows.Win32.Foundation.PSTR, ImageNameBufferSize: UInt32, ImageNameSize: POINTER(UInt32), ModuleNameBuffer: win32more.Windows.Win32.Foundation.PSTR, ModuleNameBufferSize: UInt32, ModuleNameSize: POINTER(UInt32), LoadedImageNameBuffer: win32more.Windows.Win32.Foundation.PSTR, LoadedImageNameBufferSize: UInt32, LoadedImageNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetModuleParameters(self, Count: UInt32, Bases: POINTER(UInt64), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetSymbolModule(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetTypeName(self, Module: UInt64, TypeId: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetTypeId(self, Module: UInt64, Name: win32more.Windows.Win32.Foundation.PSTR, TypeId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetTypeSize(self, Module: UInt64, TypeId: UInt32, Size: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetFieldOffset(self, Module: UInt64, TypeId: UInt32, Field: win32more.Windows.Win32.Foundation.PSTR, Offset: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetSymbolTypeId(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, TypeId: POINTER(UInt32), Module: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetOffsetTypeId(self, Offset: UInt64, TypeId: POINTER(UInt32), Module: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def ReadTypedDataVirtual(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def WriteTypedDataVirtual(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def OutputTypedDataVirtual(self, OutputControl: UInt32, Offset: UInt64, Module: UInt64, TypeId: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def ReadTypedDataPhysical(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def WriteTypedDataPhysical(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def OutputTypedDataPhysical(self, OutputControl: UInt32, Offset: UInt64, Module: UInt64, TypeId: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetScope(self, InstructionOffset: POINTER(UInt64), ScopeFrame: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), ScopeContext: VoidPtr, ScopeContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetScope(self, InstructionOffset: UInt64, ScopeFrame: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), ScopeContext: VoidPtr, ScopeContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def ResetScope(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def GetScopeSymbolGroup(self, Flags: UInt32, Update: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup, Symbols: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def CreateSymbolGroup(self, Group: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def StartSymbolMatch(self, Pattern: win32more.Windows.Win32.Foundation.PSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetNextSymbolMatch(self, Handle: UInt64, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, MatchSize: POINTER(UInt32), Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def EndSymbolMatch(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def Reload(self, Module: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def GetSymbolPath(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def SetSymbolPath(self, Path: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def AppendSymbolPath(self, Addition: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def GetImagePath(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def SetImagePath(self, Path: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def AppendImagePath(self, Addition: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def GetSourcePath(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def GetSourcePathElement(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ElementSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def SetSourcePath(self, Path: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def AppendSourcePath(self, Addition: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def FindSourceFile(self, StartElement: UInt32, File: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, FoundElement: POINTER(UInt32), Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FoundSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def GetSourceFileLineOffsets(self, File: win32more.Windows.Win32.Foundation.PSTR, Buffer: POINTER(UInt64), BufferLines: UInt32, FileLines: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def GetModuleVersionInformation(self, Index: UInt32, Base: UInt64, Item: win32more.Windows.Win32.Foundation.PSTR, Buffer: VoidPtr, BufferSize: UInt32, VerInfoSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def GetModuleNameString(self, Which: UInt32, Index: UInt32, Base: UInt64, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def GetConstantName(self, Module: UInt64, TypeId: UInt32, Value: UInt64, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def GetFieldName(self, Module: UInt64, TypeId: UInt32, FieldIndex: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def GetTypeOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def AddTypeOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def RemoveTypeOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def SetTypeOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugSymbols3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f02fbecc-50ac-4f36-9ad9-c975e8f32ff8}')
    @commethod(3)
    def GetSymbolOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddSymbolOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RemoveSymbolOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetSymbolOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetNameByOffset(self, Offset: UInt64, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetOffsetByName(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetNearNameByOffset(self, Offset: UInt64, Delta: Int32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetLineByOffset(self, Offset: UInt64, Line: POINTER(UInt32), FileBuffer: win32more.Windows.Win32.Foundation.PSTR, FileBufferSize: UInt32, FileSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetOffsetByLine(self, Line: UInt32, File: win32more.Windows.Win32.Foundation.PSTR, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetNumberModules(self, Loaded: POINTER(UInt32), Unloaded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetModuleByIndex(self, Index: UInt32, Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetModuleByModuleName(self, Name: win32more.Windows.Win32.Foundation.PSTR, StartIndex: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetModuleByOffset(self, Offset: UInt64, StartIndex: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetModuleNames(self, Index: UInt32, Base: UInt64, ImageNameBuffer: win32more.Windows.Win32.Foundation.PSTR, ImageNameBufferSize: UInt32, ImageNameSize: POINTER(UInt32), ModuleNameBuffer: win32more.Windows.Win32.Foundation.PSTR, ModuleNameBufferSize: UInt32, ModuleNameSize: POINTER(UInt32), LoadedImageNameBuffer: win32more.Windows.Win32.Foundation.PSTR, LoadedImageNameBufferSize: UInt32, LoadedImageNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetModuleParameters(self, Count: UInt32, Bases: POINTER(UInt64), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetSymbolModule(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetTypeName(self, Module: UInt64, TypeId: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetTypeId(self, Module: UInt64, Name: win32more.Windows.Win32.Foundation.PSTR, TypeId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetTypeSize(self, Module: UInt64, TypeId: UInt32, Size: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetFieldOffset(self, Module: UInt64, TypeId: UInt32, Field: win32more.Windows.Win32.Foundation.PSTR, Offset: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetSymbolTypeId(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, TypeId: POINTER(UInt32), Module: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetOffsetTypeId(self, Offset: UInt64, TypeId: POINTER(UInt32), Module: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def ReadTypedDataVirtual(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def WriteTypedDataVirtual(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def OutputTypedDataVirtual(self, OutputControl: UInt32, Offset: UInt64, Module: UInt64, TypeId: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def ReadTypedDataPhysical(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def WriteTypedDataPhysical(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def OutputTypedDataPhysical(self, OutputControl: UInt32, Offset: UInt64, Module: UInt64, TypeId: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetScope(self, InstructionOffset: POINTER(UInt64), ScopeFrame: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), ScopeContext: VoidPtr, ScopeContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetScope(self, InstructionOffset: UInt64, ScopeFrame: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), ScopeContext: VoidPtr, ScopeContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def ResetScope(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def GetScopeSymbolGroup(self, Flags: UInt32, Update: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup, Symbols: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def CreateSymbolGroup(self, Group: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def StartSymbolMatch(self, Pattern: win32more.Windows.Win32.Foundation.PSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetNextSymbolMatch(self, Handle: UInt64, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, MatchSize: POINTER(UInt32), Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def EndSymbolMatch(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def Reload(self, Module: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def GetSymbolPath(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def SetSymbolPath(self, Path: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def AppendSymbolPath(self, Addition: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def GetImagePath(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def SetImagePath(self, Path: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def AppendImagePath(self, Addition: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def GetSourcePath(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def GetSourcePathElement(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ElementSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def SetSourcePath(self, Path: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def AppendSourcePath(self, Addition: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def FindSourceFile(self, StartElement: UInt32, File: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, FoundElement: POINTER(UInt32), Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FoundSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def GetSourceFileLineOffsets(self, File: win32more.Windows.Win32.Foundation.PSTR, Buffer: POINTER(UInt64), BufferLines: UInt32, FileLines: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def GetModuleVersionInformation(self, Index: UInt32, Base: UInt64, Item: win32more.Windows.Win32.Foundation.PSTR, Buffer: VoidPtr, BufferSize: UInt32, VerInfoSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def GetModuleNameString(self, Which: UInt32, Index: UInt32, Base: UInt64, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def GetConstantName(self, Module: UInt64, TypeId: UInt32, Value: UInt64, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def GetFieldName(self, Module: UInt64, TypeId: UInt32, FieldIndex: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def GetTypeOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def AddTypeOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def RemoveTypeOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def SetTypeOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def GetNameByOffsetWide(self, Offset: UInt64, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def GetOffsetByNameWide(self, Symbol: win32more.Windows.Win32.Foundation.PWSTR, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def GetNearNameByOffsetWide(self, Offset: UInt64, Delta: Int32, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def GetLineByOffsetWide(self, Offset: UInt64, Line: POINTER(UInt32), FileBuffer: win32more.Windows.Win32.Foundation.PWSTR, FileBufferSize: UInt32, FileSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def GetOffsetByLineWide(self, Line: UInt32, File: win32more.Windows.Win32.Foundation.PWSTR, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def GetModuleByModuleNameWide(self, Name: win32more.Windows.Win32.Foundation.PWSTR, StartIndex: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def GetSymbolModuleWide(self, Symbol: win32more.Windows.Win32.Foundation.PWSTR, Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def GetTypeNameWide(self, Module: UInt64, TypeId: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def GetTypeIdWide(self, Module: UInt64, Name: win32more.Windows.Win32.Foundation.PWSTR, TypeId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def GetFieldOffsetWide(self, Module: UInt64, TypeId: UInt32, Field: win32more.Windows.Win32.Foundation.PWSTR, Offset: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def GetSymbolTypeIdWide(self, Symbol: win32more.Windows.Win32.Foundation.PWSTR, TypeId: POINTER(UInt32), Module: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def GetScopeSymbolGroup2(self, Flags: UInt32, Update: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup2, Symbols: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def CreateSymbolGroup2(self, Group: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def StartSymbolMatchWide(self, Pattern: win32more.Windows.Win32.Foundation.PWSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def GetNextSymbolMatchWide(self, Handle: UInt64, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, MatchSize: POINTER(UInt32), Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def ReloadWide(self, Module: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def GetSymbolPathWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def SetSymbolPathWide(self, Path: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def AppendSymbolPathWide(self, Addition: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def GetImagePathWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def SetImagePathWide(self, Path: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def AppendImagePathWide(self, Addition: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def GetSourcePathWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def GetSourcePathElementWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, ElementSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def SetSourcePathWide(self, Path: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def AppendSourcePathWide(self, Addition: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def FindSourceFileWide(self, StartElement: UInt32, File: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, FoundElement: POINTER(UInt32), Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, FoundSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def GetSourceFileLineOffsetsWide(self, File: win32more.Windows.Win32.Foundation.PWSTR, Buffer: POINTER(UInt64), BufferLines: UInt32, FileLines: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def GetModuleVersionInformationWide(self, Index: UInt32, Base: UInt64, Item: win32more.Windows.Win32.Foundation.PWSTR, Buffer: VoidPtr, BufferSize: UInt32, VerInfoSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def GetModuleNameStringWide(self, Which: UInt32, Index: UInt32, Base: UInt64, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def GetConstantNameWide(self, Module: UInt64, TypeId: UInt32, Value: UInt64, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def GetFieldNameWide(self, Module: UInt64, TypeId: UInt32, FieldIndex: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def IsManagedModule(self, Index: UInt32, Base: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def GetModuleByModuleName2(self, Name: win32more.Windows.Win32.Foundation.PSTR, StartIndex: UInt32, Flags: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def GetModuleByModuleName2Wide(self, Name: win32more.Windows.Win32.Foundation.PWSTR, StartIndex: UInt32, Flags: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def GetModuleByOffset2(self, Offset: UInt64, StartIndex: UInt32, Flags: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def AddSyntheticModule(self, Base: UInt64, Size: UInt32, ImagePath: win32more.Windows.Win32.Foundation.PSTR, ModuleName: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def AddSyntheticModuleWide(self, Base: UInt64, Size: UInt32, ImagePath: win32more.Windows.Win32.Foundation.PWSTR, ModuleName: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def RemoveSyntheticModule(self, Base: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def GetCurrentScopeFrameIndex(self, Index: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def SetScopeFrameByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def SetScopeFromJitDebugInfo(self, OutputControl: UInt32, InfoOffset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def SetScopeFromStoredEvent(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def OutputSymbolByOffset(self, OutputControl: UInt32, Flags: UInt32, Offset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def GetFunctionEntryByOffset(self, Offset: UInt64, Flags: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BufferNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(105)
    def GetFieldTypeAndOffset(self, Module: UInt64, ContainerTypeId: UInt32, Field: win32more.Windows.Win32.Foundation.PSTR, FieldTypeId: POINTER(UInt32), Offset: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(106)
    def GetFieldTypeAndOffsetWide(self, Module: UInt64, ContainerTypeId: UInt32, Field: win32more.Windows.Win32.Foundation.PWSTR, FieldTypeId: POINTER(UInt32), Offset: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(107)
    def AddSyntheticSymbol(self, Offset: UInt64, Size: UInt32, Name: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(108)
    def AddSyntheticSymbolWide(self, Offset: UInt64, Size: UInt32, Name: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(109)
    def RemoveSyntheticSymbol(self, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(110)
    def GetSymbolEntriesByOffset(self, Offset: UInt64, Flags: UInt32, Ids: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Displacements: POINTER(UInt64), IdsCount: UInt32, Entries: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(111)
    def GetSymbolEntriesByName(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Ids: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), IdsCount: UInt32, Entries: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(112)
    def GetSymbolEntriesByNameWide(self, Symbol: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Ids: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), IdsCount: UInt32, Entries: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(113)
    def GetSymbolEntryByToken(self, ModuleBase: UInt64, Token: UInt32, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(114)
    def GetSymbolEntryInformation(self, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Info: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_ENTRY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(115)
    def GetSymbolEntryString(self, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(116)
    def GetSymbolEntryStringWide(self, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(117)
    def GetSymbolEntryOffsetRegions(self, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Flags: UInt32, Regions: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_OFFSET_REGION), RegionsCount: UInt32, RegionsAvail: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(118)
    def GetSymbolEntryBySymbolEntry(self, FromId: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Flags: UInt32, ToId: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(119)
    def GetSourceEntriesByOffset(self, Offset: UInt64, Flags: UInt32, Entries: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), EntriesCount: UInt32, EntriesAvail: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(120)
    def GetSourceEntriesByLine(self, Line: UInt32, File: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Entries: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), EntriesCount: UInt32, EntriesAvail: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(121)
    def GetSourceEntriesByLineWide(self, Line: UInt32, File: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Entries: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), EntriesCount: UInt32, EntriesAvail: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(122)
    def GetSourceEntryString(self, Entry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(123)
    def GetSourceEntryStringWide(self, Entry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(124)
    def GetSourceEntryOffsetRegions(self, Entry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), Flags: UInt32, Regions: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_OFFSET_REGION), RegionsCount: UInt32, RegionsAvail: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(125)
    def GetSourceEntryBySourceEntry(self, FromEntry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), Flags: UInt32, ToEntry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugSymbols4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e391bbd8-9d8c-4418-840b-c006592a1752}')
    @commethod(3)
    def GetSymbolOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddSymbolOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RemoveSymbolOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetSymbolOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetNameByOffset(self, Offset: UInt64, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetOffsetByName(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetNearNameByOffset(self, Offset: UInt64, Delta: Int32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetLineByOffset(self, Offset: UInt64, Line: POINTER(UInt32), FileBuffer: win32more.Windows.Win32.Foundation.PSTR, FileBufferSize: UInt32, FileSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetOffsetByLine(self, Line: UInt32, File: win32more.Windows.Win32.Foundation.PSTR, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetNumberModules(self, Loaded: POINTER(UInt32), Unloaded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetModuleByIndex(self, Index: UInt32, Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetModuleByModuleName(self, Name: win32more.Windows.Win32.Foundation.PSTR, StartIndex: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetModuleByOffset(self, Offset: UInt64, StartIndex: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetModuleNames(self, Index: UInt32, Base: UInt64, ImageNameBuffer: win32more.Windows.Win32.Foundation.PSTR, ImageNameBufferSize: UInt32, ImageNameSize: POINTER(UInt32), ModuleNameBuffer: win32more.Windows.Win32.Foundation.PSTR, ModuleNameBufferSize: UInt32, ModuleNameSize: POINTER(UInt32), LoadedImageNameBuffer: win32more.Windows.Win32.Foundation.PSTR, LoadedImageNameBufferSize: UInt32, LoadedImageNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetModuleParameters(self, Count: UInt32, Bases: POINTER(UInt64), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetSymbolModule(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetTypeName(self, Module: UInt64, TypeId: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetTypeId(self, Module: UInt64, Name: win32more.Windows.Win32.Foundation.PSTR, TypeId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetTypeSize(self, Module: UInt64, TypeId: UInt32, Size: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetFieldOffset(self, Module: UInt64, TypeId: UInt32, Field: win32more.Windows.Win32.Foundation.PSTR, Offset: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetSymbolTypeId(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, TypeId: POINTER(UInt32), Module: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetOffsetTypeId(self, Offset: UInt64, TypeId: POINTER(UInt32), Module: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def ReadTypedDataVirtual(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def WriteTypedDataVirtual(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def OutputTypedDataVirtual(self, OutputControl: UInt32, Offset: UInt64, Module: UInt64, TypeId: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def ReadTypedDataPhysical(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def WriteTypedDataPhysical(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def OutputTypedDataPhysical(self, OutputControl: UInt32, Offset: UInt64, Module: UInt64, TypeId: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetScope(self, InstructionOffset: POINTER(UInt64), ScopeFrame: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), ScopeContext: VoidPtr, ScopeContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetScope(self, InstructionOffset: UInt64, ScopeFrame: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), ScopeContext: VoidPtr, ScopeContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def ResetScope(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def GetScopeSymbolGroup(self, Flags: UInt32, Update: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup, Symbols: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def CreateSymbolGroup(self, Group: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def StartSymbolMatch(self, Pattern: win32more.Windows.Win32.Foundation.PSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetNextSymbolMatch(self, Handle: UInt64, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, MatchSize: POINTER(UInt32), Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def EndSymbolMatch(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def Reload(self, Module: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def GetSymbolPath(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def SetSymbolPath(self, Path: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def AppendSymbolPath(self, Addition: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def GetImagePath(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def SetImagePath(self, Path: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def AppendImagePath(self, Addition: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def GetSourcePath(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def GetSourcePathElement(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ElementSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def SetSourcePath(self, Path: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def AppendSourcePath(self, Addition: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def FindSourceFile(self, StartElement: UInt32, File: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, FoundElement: POINTER(UInt32), Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FoundSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def GetSourceFileLineOffsets(self, File: win32more.Windows.Win32.Foundation.PSTR, Buffer: POINTER(UInt64), BufferLines: UInt32, FileLines: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def GetModuleVersionInformation(self, Index: UInt32, Base: UInt64, Item: win32more.Windows.Win32.Foundation.PSTR, Buffer: VoidPtr, BufferSize: UInt32, VerInfoSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def GetModuleNameString(self, Which: UInt32, Index: UInt32, Base: UInt64, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def GetConstantName(self, Module: UInt64, TypeId: UInt32, Value: UInt64, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def GetFieldName(self, Module: UInt64, TypeId: UInt32, FieldIndex: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def GetTypeOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def AddTypeOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def RemoveTypeOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def SetTypeOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def GetNameByOffsetWide(self, Offset: UInt64, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def GetOffsetByNameWide(self, Symbol: win32more.Windows.Win32.Foundation.PWSTR, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def GetNearNameByOffsetWide(self, Offset: UInt64, Delta: Int32, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def GetLineByOffsetWide(self, Offset: UInt64, Line: POINTER(UInt32), FileBuffer: win32more.Windows.Win32.Foundation.PWSTR, FileBufferSize: UInt32, FileSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def GetOffsetByLineWide(self, Line: UInt32, File: win32more.Windows.Win32.Foundation.PWSTR, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def GetModuleByModuleNameWide(self, Name: win32more.Windows.Win32.Foundation.PWSTR, StartIndex: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def GetSymbolModuleWide(self, Symbol: win32more.Windows.Win32.Foundation.PWSTR, Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def GetTypeNameWide(self, Module: UInt64, TypeId: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def GetTypeIdWide(self, Module: UInt64, Name: win32more.Windows.Win32.Foundation.PWSTR, TypeId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def GetFieldOffsetWide(self, Module: UInt64, TypeId: UInt32, Field: win32more.Windows.Win32.Foundation.PWSTR, Offset: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def GetSymbolTypeIdWide(self, Symbol: win32more.Windows.Win32.Foundation.PWSTR, TypeId: POINTER(UInt32), Module: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def GetScopeSymbolGroup2(self, Flags: UInt32, Update: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup2, Symbols: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def CreateSymbolGroup2(self, Group: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def StartSymbolMatchWide(self, Pattern: win32more.Windows.Win32.Foundation.PWSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def GetNextSymbolMatchWide(self, Handle: UInt64, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, MatchSize: POINTER(UInt32), Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def ReloadWide(self, Module: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def GetSymbolPathWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def SetSymbolPathWide(self, Path: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def AppendSymbolPathWide(self, Addition: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def GetImagePathWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def SetImagePathWide(self, Path: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def AppendImagePathWide(self, Addition: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def GetSourcePathWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def GetSourcePathElementWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, ElementSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def SetSourcePathWide(self, Path: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def AppendSourcePathWide(self, Addition: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def FindSourceFileWide(self, StartElement: UInt32, File: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, FoundElement: POINTER(UInt32), Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, FoundSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def GetSourceFileLineOffsetsWide(self, File: win32more.Windows.Win32.Foundation.PWSTR, Buffer: POINTER(UInt64), BufferLines: UInt32, FileLines: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def GetModuleVersionInformationWide(self, Index: UInt32, Base: UInt64, Item: win32more.Windows.Win32.Foundation.PWSTR, Buffer: VoidPtr, BufferSize: UInt32, VerInfoSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def GetModuleNameStringWide(self, Which: UInt32, Index: UInt32, Base: UInt64, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def GetConstantNameWide(self, Module: UInt64, TypeId: UInt32, Value: UInt64, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def GetFieldNameWide(self, Module: UInt64, TypeId: UInt32, FieldIndex: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def IsManagedModule(self, Index: UInt32, Base: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def GetModuleByModuleName2(self, Name: win32more.Windows.Win32.Foundation.PSTR, StartIndex: UInt32, Flags: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def GetModuleByModuleName2Wide(self, Name: win32more.Windows.Win32.Foundation.PWSTR, StartIndex: UInt32, Flags: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def GetModuleByOffset2(self, Offset: UInt64, StartIndex: UInt32, Flags: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def AddSyntheticModule(self, Base: UInt64, Size: UInt32, ImagePath: win32more.Windows.Win32.Foundation.PSTR, ModuleName: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def AddSyntheticModuleWide(self, Base: UInt64, Size: UInt32, ImagePath: win32more.Windows.Win32.Foundation.PWSTR, ModuleName: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def RemoveSyntheticModule(self, Base: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def GetCurrentScopeFrameIndex(self, Index: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def SetScopeFrameByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def SetScopeFromJitDebugInfo(self, OutputControl: UInt32, InfoOffset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def SetScopeFromStoredEvent(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def OutputSymbolByOffset(self, OutputControl: UInt32, Flags: UInt32, Offset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def GetFunctionEntryByOffset(self, Offset: UInt64, Flags: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BufferNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(105)
    def GetFieldTypeAndOffset(self, Module: UInt64, ContainerTypeId: UInt32, Field: win32more.Windows.Win32.Foundation.PSTR, FieldTypeId: POINTER(UInt32), Offset: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(106)
    def GetFieldTypeAndOffsetWide(self, Module: UInt64, ContainerTypeId: UInt32, Field: win32more.Windows.Win32.Foundation.PWSTR, FieldTypeId: POINTER(UInt32), Offset: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(107)
    def AddSyntheticSymbol(self, Offset: UInt64, Size: UInt32, Name: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(108)
    def AddSyntheticSymbolWide(self, Offset: UInt64, Size: UInt32, Name: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(109)
    def RemoveSyntheticSymbol(self, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(110)
    def GetSymbolEntriesByOffset(self, Offset: UInt64, Flags: UInt32, Ids: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Displacements: POINTER(UInt64), IdsCount: UInt32, Entries: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(111)
    def GetSymbolEntriesByName(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Ids: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), IdsCount: UInt32, Entries: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(112)
    def GetSymbolEntriesByNameWide(self, Symbol: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Ids: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), IdsCount: UInt32, Entries: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(113)
    def GetSymbolEntryByToken(self, ModuleBase: UInt64, Token: UInt32, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(114)
    def GetSymbolEntryInformation(self, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Info: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_ENTRY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(115)
    def GetSymbolEntryString(self, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(116)
    def GetSymbolEntryStringWide(self, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(117)
    def GetSymbolEntryOffsetRegions(self, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Flags: UInt32, Regions: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_OFFSET_REGION), RegionsCount: UInt32, RegionsAvail: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(118)
    def GetSymbolEntryBySymbolEntry(self, FromId: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Flags: UInt32, ToId: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(119)
    def GetSourceEntriesByOffset(self, Offset: UInt64, Flags: UInt32, Entries: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), EntriesCount: UInt32, EntriesAvail: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(120)
    def GetSourceEntriesByLine(self, Line: UInt32, File: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Entries: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), EntriesCount: UInt32, EntriesAvail: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(121)
    def GetSourceEntriesByLineWide(self, Line: UInt32, File: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Entries: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), EntriesCount: UInt32, EntriesAvail: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(122)
    def GetSourceEntryString(self, Entry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(123)
    def GetSourceEntryStringWide(self, Entry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(124)
    def GetSourceEntryOffsetRegions(self, Entry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), Flags: UInt32, Regions: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_OFFSET_REGION), RegionsCount: UInt32, RegionsAvail: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(125)
    def GetSourceEntryBySourceEntry(self, FromEntry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), Flags: UInt32, ToEntry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(126)
    def GetScopeEx(self, InstructionOffset: POINTER(UInt64), ScopeFrame: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX), ScopeContext: VoidPtr, ScopeContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(127)
    def SetScopeEx(self, InstructionOffset: UInt64, ScopeFrame: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX), ScopeContext: VoidPtr, ScopeContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(128)
    def GetNameByInlineContext(self, Offset: UInt64, InlineContext: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(129)
    def GetNameByInlineContextWide(self, Offset: UInt64, InlineContext: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(130)
    def GetLineByInlineContext(self, Offset: UInt64, InlineContext: UInt32, Line: POINTER(UInt32), FileBuffer: win32more.Windows.Win32.Foundation.PSTR, FileBufferSize: UInt32, FileSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(131)
    def GetLineByInlineContextWide(self, Offset: UInt64, InlineContext: UInt32, Line: POINTER(UInt32), FileBuffer: win32more.Windows.Win32.Foundation.PWSTR, FileBufferSize: UInt32, FileSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(132)
    def OutputSymbolByInlineContext(self, OutputControl: UInt32, Flags: UInt32, Offset: UInt64, InlineContext: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugSymbols5(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c65fa83e-1e69-475e-8e0e-b5d79e9cc17e}')
    @commethod(3)
    def GetSymbolOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddSymbolOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RemoveSymbolOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetSymbolOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetNameByOffset(self, Offset: UInt64, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetOffsetByName(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetNearNameByOffset(self, Offset: UInt64, Delta: Int32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetLineByOffset(self, Offset: UInt64, Line: POINTER(UInt32), FileBuffer: win32more.Windows.Win32.Foundation.PSTR, FileBufferSize: UInt32, FileSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetOffsetByLine(self, Line: UInt32, File: win32more.Windows.Win32.Foundation.PSTR, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetNumberModules(self, Loaded: POINTER(UInt32), Unloaded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetModuleByIndex(self, Index: UInt32, Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetModuleByModuleName(self, Name: win32more.Windows.Win32.Foundation.PSTR, StartIndex: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetModuleByOffset(self, Offset: UInt64, StartIndex: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetModuleNames(self, Index: UInt32, Base: UInt64, ImageNameBuffer: win32more.Windows.Win32.Foundation.PSTR, ImageNameBufferSize: UInt32, ImageNameSize: POINTER(UInt32), ModuleNameBuffer: win32more.Windows.Win32.Foundation.PSTR, ModuleNameBufferSize: UInt32, ModuleNameSize: POINTER(UInt32), LoadedImageNameBuffer: win32more.Windows.Win32.Foundation.PSTR, LoadedImageNameBufferSize: UInt32, LoadedImageNameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetModuleParameters(self, Count: UInt32, Bases: POINTER(UInt64), Start: UInt32, Params: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetSymbolModule(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetTypeName(self, Module: UInt64, TypeId: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetTypeId(self, Module: UInt64, Name: win32more.Windows.Win32.Foundation.PSTR, TypeId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetTypeSize(self, Module: UInt64, TypeId: UInt32, Size: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetFieldOffset(self, Module: UInt64, TypeId: UInt32, Field: win32more.Windows.Win32.Foundation.PSTR, Offset: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetSymbolTypeId(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, TypeId: POINTER(UInt32), Module: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetOffsetTypeId(self, Offset: UInt64, TypeId: POINTER(UInt32), Module: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def ReadTypedDataVirtual(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def WriteTypedDataVirtual(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def OutputTypedDataVirtual(self, OutputControl: UInt32, Offset: UInt64, Module: UInt64, TypeId: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def ReadTypedDataPhysical(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def WriteTypedDataPhysical(self, Offset: UInt64, Module: UInt64, TypeId: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def OutputTypedDataPhysical(self, OutputControl: UInt32, Offset: UInt64, Module: UInt64, TypeId: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetScope(self, InstructionOffset: POINTER(UInt64), ScopeFrame: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), ScopeContext: VoidPtr, ScopeContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetScope(self, InstructionOffset: UInt64, ScopeFrame: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME), ScopeContext: VoidPtr, ScopeContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def ResetScope(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def GetScopeSymbolGroup(self, Flags: UInt32, Update: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup, Symbols: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def CreateSymbolGroup(self, Group: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def StartSymbolMatch(self, Pattern: win32more.Windows.Win32.Foundation.PSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetNextSymbolMatch(self, Handle: UInt64, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, MatchSize: POINTER(UInt32), Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def EndSymbolMatch(self, Handle: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def Reload(self, Module: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def GetSymbolPath(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def SetSymbolPath(self, Path: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def AppendSymbolPath(self, Addition: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def GetImagePath(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def SetImagePath(self, Path: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def AppendImagePath(self, Addition: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def GetSourcePath(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def GetSourcePathElement(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ElementSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def SetSourcePath(self, Path: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def AppendSourcePath(self, Addition: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def FindSourceFile(self, StartElement: UInt32, File: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, FoundElement: POINTER(UInt32), Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, FoundSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def GetSourceFileLineOffsets(self, File: win32more.Windows.Win32.Foundation.PSTR, Buffer: POINTER(UInt64), BufferLines: UInt32, FileLines: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def GetModuleVersionInformation(self, Index: UInt32, Base: UInt64, Item: win32more.Windows.Win32.Foundation.PSTR, Buffer: VoidPtr, BufferSize: UInt32, VerInfoSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def GetModuleNameString(self, Which: UInt32, Index: UInt32, Base: UInt64, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def GetConstantName(self, Module: UInt64, TypeId: UInt32, Value: UInt64, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def GetFieldName(self, Module: UInt64, TypeId: UInt32, FieldIndex: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def GetTypeOptions(self, Options: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def AddTypeOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def RemoveTypeOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def SetTypeOptions(self, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def GetNameByOffsetWide(self, Offset: UInt64, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def GetOffsetByNameWide(self, Symbol: win32more.Windows.Win32.Foundation.PWSTR, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def GetNearNameByOffsetWide(self, Offset: UInt64, Delta: Int32, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def GetLineByOffsetWide(self, Offset: UInt64, Line: POINTER(UInt32), FileBuffer: win32more.Windows.Win32.Foundation.PWSTR, FileBufferSize: UInt32, FileSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def GetOffsetByLineWide(self, Line: UInt32, File: win32more.Windows.Win32.Foundation.PWSTR, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def GetModuleByModuleNameWide(self, Name: win32more.Windows.Win32.Foundation.PWSTR, StartIndex: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def GetSymbolModuleWide(self, Symbol: win32more.Windows.Win32.Foundation.PWSTR, Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def GetTypeNameWide(self, Module: UInt64, TypeId: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def GetTypeIdWide(self, Module: UInt64, Name: win32more.Windows.Win32.Foundation.PWSTR, TypeId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def GetFieldOffsetWide(self, Module: UInt64, TypeId: UInt32, Field: win32more.Windows.Win32.Foundation.PWSTR, Offset: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def GetSymbolTypeIdWide(self, Symbol: win32more.Windows.Win32.Foundation.PWSTR, TypeId: POINTER(UInt32), Module: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def GetScopeSymbolGroup2(self, Flags: UInt32, Update: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup2, Symbols: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def CreateSymbolGroup2(self, Group: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugSymbolGroup2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def StartSymbolMatchWide(self, Pattern: win32more.Windows.Win32.Foundation.PWSTR, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def GetNextSymbolMatchWide(self, Handle: UInt64, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, MatchSize: POINTER(UInt32), Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def ReloadWide(self, Module: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def GetSymbolPathWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def SetSymbolPathWide(self, Path: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def AppendSymbolPathWide(self, Addition: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def GetImagePathWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def SetImagePathWide(self, Path: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def AppendImagePathWide(self, Addition: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def GetSourcePathWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, PathSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def GetSourcePathElementWide(self, Index: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, ElementSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def SetSourcePathWide(self, Path: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def AppendSourcePathWide(self, Addition: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def FindSourceFileWide(self, StartElement: UInt32, File: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, FoundElement: POINTER(UInt32), Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, FoundSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def GetSourceFileLineOffsetsWide(self, File: win32more.Windows.Win32.Foundation.PWSTR, Buffer: POINTER(UInt64), BufferLines: UInt32, FileLines: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def GetModuleVersionInformationWide(self, Index: UInt32, Base: UInt64, Item: win32more.Windows.Win32.Foundation.PWSTR, Buffer: VoidPtr, BufferSize: UInt32, VerInfoSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def GetModuleNameStringWide(self, Which: UInt32, Index: UInt32, Base: UInt64, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def GetConstantNameWide(self, Module: UInt64, TypeId: UInt32, Value: UInt64, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def GetFieldNameWide(self, Module: UInt64, TypeId: UInt32, FieldIndex: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def IsManagedModule(self, Index: UInt32, Base: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def GetModuleByModuleName2(self, Name: win32more.Windows.Win32.Foundation.PSTR, StartIndex: UInt32, Flags: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def GetModuleByModuleName2Wide(self, Name: win32more.Windows.Win32.Foundation.PWSTR, StartIndex: UInt32, Flags: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def GetModuleByOffset2(self, Offset: UInt64, StartIndex: UInt32, Flags: UInt32, Index: POINTER(UInt32), Base: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def AddSyntheticModule(self, Base: UInt64, Size: UInt32, ImagePath: win32more.Windows.Win32.Foundation.PSTR, ModuleName: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def AddSyntheticModuleWide(self, Base: UInt64, Size: UInt32, ImagePath: win32more.Windows.Win32.Foundation.PWSTR, ModuleName: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def RemoveSyntheticModule(self, Base: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def GetCurrentScopeFrameIndex(self, Index: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def SetScopeFrameByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def SetScopeFromJitDebugInfo(self, OutputControl: UInt32, InfoOffset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def SetScopeFromStoredEvent(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def OutputSymbolByOffset(self, OutputControl: UInt32, Flags: UInt32, Offset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def GetFunctionEntryByOffset(self, Offset: UInt64, Flags: UInt32, Buffer: VoidPtr, BufferSize: UInt32, BufferNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(105)
    def GetFieldTypeAndOffset(self, Module: UInt64, ContainerTypeId: UInt32, Field: win32more.Windows.Win32.Foundation.PSTR, FieldTypeId: POINTER(UInt32), Offset: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(106)
    def GetFieldTypeAndOffsetWide(self, Module: UInt64, ContainerTypeId: UInt32, Field: win32more.Windows.Win32.Foundation.PWSTR, FieldTypeId: POINTER(UInt32), Offset: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(107)
    def AddSyntheticSymbol(self, Offset: UInt64, Size: UInt32, Name: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(108)
    def AddSyntheticSymbolWide(self, Offset: UInt64, Size: UInt32, Name: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(109)
    def RemoveSyntheticSymbol(self, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(110)
    def GetSymbolEntriesByOffset(self, Offset: UInt64, Flags: UInt32, Ids: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Displacements: POINTER(UInt64), IdsCount: UInt32, Entries: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(111)
    def GetSymbolEntriesByName(self, Symbol: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Ids: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), IdsCount: UInt32, Entries: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(112)
    def GetSymbolEntriesByNameWide(self, Symbol: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Ids: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), IdsCount: UInt32, Entries: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(113)
    def GetSymbolEntryByToken(self, ModuleBase: UInt64, Token: UInt32, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(114)
    def GetSymbolEntryInformation(self, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Info: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_ENTRY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(115)
    def GetSymbolEntryString(self, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(116)
    def GetSymbolEntryStringWide(self, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(117)
    def GetSymbolEntryOffsetRegions(self, Id: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Flags: UInt32, Regions: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_OFFSET_REGION), RegionsCount: UInt32, RegionsAvail: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(118)
    def GetSymbolEntryBySymbolEntry(self, FromId: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID), Flags: UInt32, ToId: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_MODULE_AND_ID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(119)
    def GetSourceEntriesByOffset(self, Offset: UInt64, Flags: UInt32, Entries: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), EntriesCount: UInt32, EntriesAvail: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(120)
    def GetSourceEntriesByLine(self, Line: UInt32, File: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32, Entries: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), EntriesCount: UInt32, EntriesAvail: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(121)
    def GetSourceEntriesByLineWide(self, Line: UInt32, File: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, Entries: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), EntriesCount: UInt32, EntriesAvail: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(122)
    def GetSourceEntryString(self, Entry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(123)
    def GetSourceEntryStringWide(self, Entry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), Which: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, StringSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(124)
    def GetSourceEntryOffsetRegions(self, Entry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), Flags: UInt32, Regions: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_OFFSET_REGION), RegionsCount: UInt32, RegionsAvail: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(125)
    def GetSourceEntryBySourceEntry(self, FromEntry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY), Flags: UInt32, ToEntry: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SYMBOL_SOURCE_ENTRY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(126)
    def GetScopeEx(self, InstructionOffset: POINTER(UInt64), ScopeFrame: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX), ScopeContext: VoidPtr, ScopeContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(127)
    def SetScopeEx(self, InstructionOffset: UInt64, ScopeFrame: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX), ScopeContext: VoidPtr, ScopeContextSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(128)
    def GetNameByInlineContext(self, Offset: UInt64, InlineContext: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(129)
    def GetNameByInlineContextWide(self, Offset: UInt64, InlineContext: UInt32, NameBuffer: win32more.Windows.Win32.Foundation.PWSTR, NameBufferSize: UInt32, NameSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(130)
    def GetLineByInlineContext(self, Offset: UInt64, InlineContext: UInt32, Line: POINTER(UInt32), FileBuffer: win32more.Windows.Win32.Foundation.PSTR, FileBufferSize: UInt32, FileSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(131)
    def GetLineByInlineContextWide(self, Offset: UInt64, InlineContext: UInt32, Line: POINTER(UInt32), FileBuffer: win32more.Windows.Win32.Foundation.PWSTR, FileBufferSize: UInt32, FileSize: POINTER(UInt32), Displacement: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(132)
    def OutputSymbolByInlineContext(self, OutputControl: UInt32, Flags: UInt32, Offset: UInt64, InlineContext: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(133)
    def GetCurrentScopeFrameIndexEx(self, Flags: UInt32, Index: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(134)
    def SetScopeFrameByIndexEx(self, Flags: UInt32, Index: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugSystemObjects(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6b86fe2c-2c4f-4f0c-9da2-174311acc327}')
    @commethod(3)
    def GetEventThread(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetEventProcess(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCurrentThreadId(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetCurrentThreadId(self, Id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetCurrentProcessId(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetCurrentProcessId(self, Id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetNumberThreads(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetTotalNumberThreads(self, Total: POINTER(UInt32), LargestProcess: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetThreadIdsByIndex(self, Start: UInt32, Count: UInt32, Ids: POINTER(UInt32), SysIds: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetThreadIdByProcessor(self, Processor: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetCurrentThreadDataOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetThreadIdByDataOffset(self, Offset: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetCurrentThreadTeb(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetThreadIdByTeb(self, Offset: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetCurrentThreadSystemId(self, SysId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetThreadIdBySystemId(self, SysId: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetCurrentThreadHandle(self, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetThreadIdByHandle(self, Handle: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetNumberProcesses(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetProcessIdsByIndex(self, Start: UInt32, Count: UInt32, Ids: POINTER(UInt32), SysIds: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetCurrentProcessDataOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetProcessIdByDataOffset(self, Offset: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def GetCurrentProcessPeb(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetProcessIdByPeb(self, Offset: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetCurrentProcessSystemId(self, SysId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def GetProcessIdBySystemId(self, SysId: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def GetCurrentProcessHandle(self, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetProcessIdByHandle(self, Handle: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetCurrentProcessExecutableName(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ExeSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugSystemObjects2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0ae9f5ff-1852-4679-b055-494bee6407ee}')
    @commethod(3)
    def GetEventThread(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetEventProcess(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCurrentThreadId(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetCurrentThreadId(self, Id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetCurrentProcessId(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetCurrentProcessId(self, Id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetNumberThreads(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetTotalNumberThreads(self, Total: POINTER(UInt32), LargestProcess: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetThreadIdsByIndex(self, Start: UInt32, Count: UInt32, Ids: POINTER(UInt32), SysIds: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetThreadIdByProcessor(self, Processor: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetCurrentThreadDataOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetThreadIdByDataOffset(self, Offset: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetCurrentThreadTeb(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetThreadIdByTeb(self, Offset: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetCurrentThreadSystemId(self, SysId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetThreadIdBySystemId(self, SysId: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetCurrentThreadHandle(self, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetThreadIdByHandle(self, Handle: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetNumberProcesses(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetProcessIdsByIndex(self, Start: UInt32, Count: UInt32, Ids: POINTER(UInt32), SysIds: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetCurrentProcessDataOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetProcessIdByDataOffset(self, Offset: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def GetCurrentProcessPeb(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetProcessIdByPeb(self, Offset: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetCurrentProcessSystemId(self, SysId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def GetProcessIdBySystemId(self, SysId: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def GetCurrentProcessHandle(self, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetProcessIdByHandle(self, Handle: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetCurrentProcessExecutableName(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ExeSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def GetCurrentProcessUpTime(self, UpTime: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetImplicitThreadDataOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def SetImplicitThreadDataOffset(self, Offset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetImplicitProcessDataOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def SetImplicitProcessDataOffset(self, Offset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugSystemObjects3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e9676e2f-e286-4ea3-b0f9-dfe5d9fc330e}')
    @commethod(3)
    def GetEventThread(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetEventProcess(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCurrentThreadId(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetCurrentThreadId(self, Id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetCurrentProcessId(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetCurrentProcessId(self, Id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetNumberThreads(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetTotalNumberThreads(self, Total: POINTER(UInt32), LargestProcess: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetThreadIdsByIndex(self, Start: UInt32, Count: UInt32, Ids: POINTER(UInt32), SysIds: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetThreadIdByProcessor(self, Processor: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetCurrentThreadDataOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetThreadIdByDataOffset(self, Offset: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetCurrentThreadTeb(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetThreadIdByTeb(self, Offset: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetCurrentThreadSystemId(self, SysId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetThreadIdBySystemId(self, SysId: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetCurrentThreadHandle(self, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetThreadIdByHandle(self, Handle: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetNumberProcesses(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetProcessIdsByIndex(self, Start: UInt32, Count: UInt32, Ids: POINTER(UInt32), SysIds: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetCurrentProcessDataOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetProcessIdByDataOffset(self, Offset: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def GetCurrentProcessPeb(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetProcessIdByPeb(self, Offset: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetCurrentProcessSystemId(self, SysId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def GetProcessIdBySystemId(self, SysId: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def GetCurrentProcessHandle(self, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetProcessIdByHandle(self, Handle: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetCurrentProcessExecutableName(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ExeSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def GetCurrentProcessUpTime(self, UpTime: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetImplicitThreadDataOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def SetImplicitThreadDataOffset(self, Offset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetImplicitProcessDataOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def SetImplicitProcessDataOffset(self, Offset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetEventSystem(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def GetCurrentSystemId(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def SetCurrentSystemId(self, Id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def GetNumberSystems(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetSystemIdsByIndex(self, Start: UInt32, Count: UInt32, Ids: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def GetTotalNumberThreadsAndProcesses(self, TotalThreads: POINTER(UInt32), TotalProcesses: POINTER(UInt32), LargestProcessThreads: POINTER(UInt32), LargestSystemThreads: POINTER(UInt32), LargestSystemProcesses: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def GetCurrentSystemServer(self, Server: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def GetSystemByServer(self, Server: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetCurrentSystemServerName(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugSystemObjects4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{489468e6-7d0f-4af5-87ab-25207454d553}')
    @commethod(3)
    def GetEventThread(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetEventProcess(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCurrentThreadId(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetCurrentThreadId(self, Id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetCurrentProcessId(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetCurrentProcessId(self, Id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetNumberThreads(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetTotalNumberThreads(self, Total: POINTER(UInt32), LargestProcess: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetThreadIdsByIndex(self, Start: UInt32, Count: UInt32, Ids: POINTER(UInt32), SysIds: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetThreadIdByProcessor(self, Processor: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetCurrentThreadDataOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetThreadIdByDataOffset(self, Offset: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetCurrentThreadTeb(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetThreadIdByTeb(self, Offset: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetCurrentThreadSystemId(self, SysId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetThreadIdBySystemId(self, SysId: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetCurrentThreadHandle(self, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetThreadIdByHandle(self, Handle: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetNumberProcesses(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetProcessIdsByIndex(self, Start: UInt32, Count: UInt32, Ids: POINTER(UInt32), SysIds: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetCurrentProcessDataOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetProcessIdByDataOffset(self, Offset: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def GetCurrentProcessPeb(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def GetProcessIdByPeb(self, Offset: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetCurrentProcessSystemId(self, SysId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def GetProcessIdBySystemId(self, SysId: UInt32, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def GetCurrentProcessHandle(self, Handle: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetProcessIdByHandle(self, Handle: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetCurrentProcessExecutableName(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, ExeSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def GetCurrentProcessUpTime(self, UpTime: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetImplicitThreadDataOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def SetImplicitThreadDataOffset(self, Offset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GetImplicitProcessDataOffset(self, Offset: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def SetImplicitProcessDataOffset(self, Offset: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetEventSystem(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def GetCurrentSystemId(self, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def SetCurrentSystemId(self, Id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def GetNumberSystems(self, Number: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def GetSystemIdsByIndex(self, Start: UInt32, Count: UInt32, Ids: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def GetTotalNumberThreadsAndProcesses(self, TotalThreads: POINTER(UInt32), TotalProcesses: POINTER(UInt32), LargestProcessThreads: POINTER(UInt32), LargestSystemThreads: POINTER(UInt32), LargestSystemProcesses: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def GetCurrentSystemServer(self, Server: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def GetSystemByServer(self, Server: UInt64, Id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetCurrentSystemServerName(self, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def GetCurrentProcessExecutableNameWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, ExeSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def GetCurrentSystemServerNameWide(self, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferSize: UInt32, NameSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDynamicConceptProviderConcept(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{95a7f7dd-602e-483f-9d06-a15c0ee13174}')
    @commethod(3)
    def GetConcept(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, conceptId: POINTER(Guid), conceptInterface: POINTER(win32more.Windows.Win32.System.Com.IUnknown), conceptMetadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore), hasConcept: POINTER(Boolean)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetConcept(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, conceptId: POINTER(Guid), conceptInterface: win32more.Windows.Win32.System.Com.IUnknown, conceptMetadata: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def NotifyParent(self, parentModel: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def NotifyParentChange(self, parentModel: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def NotifyDestruct(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDynamicKeyProviderConcept(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e7983fa1-80a7-498c-988f-518ddc5d4025}')
    @commethod(3)
    def GetKey(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, key: win32more.Windows.Win32.Foundation.PWSTR, keyValue: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), metadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore), hasKey: POINTER(Boolean)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetKey(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, key: win32more.Windows.Win32.Foundation.PWSTR, keyValue: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, metadata: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def EnumerateKeys(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, ppEnumerator: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEquatableConcept(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c52d5d3d-609d-4d5d-8a82-46b0acdec4f4}')
    @commethod(3)
    def AreObjectsEqual(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, otherObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, isEqual: POINTER(Boolean)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHostDataModelAccess(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f2bce54e-4835-4f8a-836e-7981e29904d1}')
    @commethod(3)
    def GetDataModel(self, manager: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDataModelManager), host: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHost)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IIndexableConcept(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d1fad99f-3f53-4457-850c-8051df2d3fb5}')
    @commethod(3)
    def GetDimensionality(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, dimensionality: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetAt(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, indexerCount: UInt64, indexers: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), metadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetAt(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, indexerCount: UInt64, indexers: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), value: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IIterableConcept(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f5d49d0c-0b02-4301-9c9b-b3a6037628f3}')
    @commethod(3)
    def GetDefaultIndexDimensionality(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, dimensionality: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetIterator(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, iterator: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelIterator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKeyEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{345fa92e-5e00-4319-9cae-971f7601cdcf}')
    @commethod(3)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetNext(self, key: POINTER(win32more.Windows.Win32.Foundation.BSTR), value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), metadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKeyStore(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0fc7557d-401d-4fca-9365-da1e9850697c}')
    @commethod(3)
    def GetKey(self, key: win32more.Windows.Win32.Foundation.PWSTR, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), metadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetKey(self, key: win32more.Windows.Win32.Foundation.PWSTR, object: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, metadata: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetKeyValue(self, key: win32more.Windows.Win32.Foundation.PWSTR, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), metadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetKeyValue(self, key: win32more.Windows.Win32.Foundation.PWSTR, object: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ClearKeys(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IModelIterator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e4622136-927d-4490-874f-581f3e4e3688}')
    @commethod(3)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetNext(self, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), dimensions: UInt64, indexers: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), metadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IModelKeyReference(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5253dcf8-5aff-4c62-b302-56a289e00998}')
    @commethod(3)
    def GetKeyName(self, keyName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetOriginalObject(self, originalObject: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetContextObject(self, containingObject: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetKey(self, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), metadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetKeyValue(self, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), metadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetKey(self, object: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, metadata: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetKeyValue(self, object: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IModelKeyReference2(ComPtr):
    extends: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelKeyReference
    _iid_ = Guid('{80e2f7c5-7159-4e92-887e-7e0347e88406}')
    @commethod(10)
    def OverrideContextObject(self, newContextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IModelMethod(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{80600c1f-b90b-4896-82ad-1c00207909e8}')
    @commethod(3)
    def Call(self, pContextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, argCount: UInt64, ppArguments: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), ppResult: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), ppMetadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IModelObject(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e28c7893-3f4b-4b96-baca-293cdc55f45d}')
    @commethod(3)
    def GetContext(self, context: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostContext)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetKind(self, kind: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ModelObjectKind)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetIntrinsicValue(self, intrinsicData: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetIntrinsicValueAs(self, vt: win32more.Windows.Win32.System.Variant.VARENUM, intrinsicData: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetKeyValue(self, key: win32more.Windows.Win32.Foundation.PWSTR, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), metadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetKeyValue(self, key: win32more.Windows.Win32.Foundation.PWSTR, object: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def EnumerateKeyValues(self, enumerator: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetRawValue(self, kind: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolKind, name: win32more.Windows.Win32.Foundation.PWSTR, searchFlags: UInt32, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def EnumerateRawValues(self, kind: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolKind, searchFlags: UInt32, enumerator: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IRawEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Dereference(self, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def TryCastToRuntimeType(self, runtimeTypedObject: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetConcept(self, conceptId: POINTER(Guid), conceptInterface: POINTER(win32more.Windows.Win32.System.Com.IUnknown), conceptMetadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetLocation(self, location: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetTypeInfo(self, type: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetTargetInfo(self, location: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.Location), type: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugHostType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetNumberOfParentModels(self, numModels: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetParentModel(self, i: UInt64, model: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), contextObject: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def AddParentModel(self, model: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, override: Byte) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def RemoveParentModel(self, model: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetKey(self, key: win32more.Windows.Win32.Foundation.PWSTR, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), metadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetKeyReference(self, key: win32more.Windows.Win32.Foundation.PWSTR, objectReference: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject), metadata: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def SetKey(self, key: win32more.Windows.Win32.Foundation.PWSTR, object: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, metadata: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def ClearKeys(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def EnumerateKeys(self, enumerator: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def EnumerateKeyReferences(self, enumerator: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def SetConcept(self, conceptId: POINTER(Guid), conceptInterface: win32more.Windows.Win32.System.Com.IUnknown, conceptMetadata: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def ClearConcepts(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetRawReference(self, kind: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolKind, name: win32more.Windows.Win32.Foundation.PWSTR, searchFlags: UInt32, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def EnumerateRawReferences(self, kind: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolKind, searchFlags: UInt32, enumerator: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IRawEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetContextForDataModel(self, dataModelObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, context: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetContextForDataModel(self, dataModelObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, context: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def Compare(self, other: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, ppResult: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def IsEqualTo(self, other: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, equal: POINTER(Boolean)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IModelPropertyAccessor(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5a0c63d9-0526-42b8-960c-9516a3254c85}')
    @commethod(3)
    def GetValue(self, key: win32more.Windows.Win32.Foundation.PWSTR, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetValue(self, key: win32more.Windows.Win32.Foundation.PWSTR, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, value: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INLINE_FRAME_CONTEXT(Union):
    ContextValue: UInt32
    Anonymous: _Anonymous_e__Struct
    class _Anonymous_e__Struct(Structure):
        FrameId: Byte
        FrameType: Byte
        FrameSignature: UInt16
class IOSPACE(Structure):
    Address: UInt32
    Length: UInt32
    Data: UInt32
class IOSPACE32(Structure):
    Address: UInt32
    Length: UInt32
    Data: UInt32
class IOSPACE64(Structure):
    Address: UInt64
    Length: UInt32
    Data: UInt32
class IOSPACE_EX(Structure):
    Address: UInt32
    Length: UInt32
    Data: UInt32
    InterfaceType: UInt32
    BusNumber: UInt32
    AddressSpace: UInt32
class IOSPACE_EX32(Structure):
    Address: UInt32
    Length: UInt32
    Data: UInt32
    InterfaceType: UInt32
    BusNumber: UInt32
    AddressSpace: UInt32
class IOSPACE_EX64(Structure):
    Address: UInt64
    Length: UInt32
    Data: UInt32
    InterfaceType: UInt32
    BusNumber: UInt32
    AddressSpace: UInt32
class IPreferredRuntimeTypeConcept(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9d6c1d7b-a76f-4618-8068-5f76bd9a4e8a}')
    @commethod(3)
    def CastToPreferredRuntimeType(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, object: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRawEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e13613f9-3a3c-40b5-8f48-1e5ebfb9b21b}')
    @commethod(3)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetNext(self, name: POINTER(win32more.Windows.Win32.Foundation.BSTR), kind: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolKind), value: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IStringDisplayableConcept(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d28e8d70-6c00-4205-940d-501016601ea3}')
    @commethod(3)
    def ToDisplayString(self, contextObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IModelObject, metadata: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IKeyStore, displayString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
IntrinsicKind = Int32
IntrinsicVoid: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IntrinsicKind = 0
IntrinsicBool: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IntrinsicKind = 1
IntrinsicChar: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IntrinsicKind = 2
IntrinsicWChar: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IntrinsicKind = 3
IntrinsicInt: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IntrinsicKind = 4
IntrinsicUInt: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IntrinsicKind = 5
IntrinsicLong: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IntrinsicKind = 6
IntrinsicULong: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IntrinsicKind = 7
IntrinsicFloat: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IntrinsicKind = 8
IntrinsicHRESULT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IntrinsicKind = 9
IntrinsicChar16: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IntrinsicKind = 10
IntrinsicChar32: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IntrinsicKind = 11
class KDDEBUGGER_DATA32(Structure):
    Header: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DBGKD_DEBUG_DATA_HEADER32
    KernBase: UInt32
    BreakpointWithStatus: UInt32
    SavedContext: UInt32
    ThCallbackStack: UInt16
    NextCallback: UInt16
    FramePointer: UInt16
    PaeEnabled: Annotated[UInt16, 1]
    KiCallUserMode: UInt32
    KeUserCallbackDispatcher: UInt32
    PsLoadedModuleList: UInt32
    PsActiveProcessHead: UInt32
    PspCidTable: UInt32
    ExpSystemResourcesList: UInt32
    ExpPagedPoolDescriptor: UInt32
    ExpNumberOfPagedPools: UInt32
    KeTimeIncrement: UInt32
    KeBugCheckCallbackListHead: UInt32
    KiBugcheckData: UInt32
    IopErrorLogListHead: UInt32
    ObpRootDirectoryObject: UInt32
    ObpTypeObjectType: UInt32
    MmSystemCacheStart: UInt32
    MmSystemCacheEnd: UInt32
    MmSystemCacheWs: UInt32
    MmPfnDatabase: UInt32
    MmSystemPtesStart: UInt32
    MmSystemPtesEnd: UInt32
    MmSubsectionBase: UInt32
    MmNumberOfPagingFiles: UInt32
    MmLowestPhysicalPage: UInt32
    MmHighestPhysicalPage: UInt32
    MmNumberOfPhysicalPages: UInt32
    MmMaximumNonPagedPoolInBytes: UInt32
    MmNonPagedSystemStart: UInt32
    MmNonPagedPoolStart: UInt32
    MmNonPagedPoolEnd: UInt32
    MmPagedPoolStart: UInt32
    MmPagedPoolEnd: UInt32
    MmPagedPoolInformation: UInt32
    MmPageSize: UInt32
    MmSizeOfPagedPoolInBytes: UInt32
    MmTotalCommitLimit: UInt32
    MmTotalCommittedPages: UInt32
    MmSharedCommit: UInt32
    MmDriverCommit: UInt32
    MmProcessCommit: UInt32
    MmPagedPoolCommit: UInt32
    MmExtendedCommit: UInt32
    MmZeroedPageListHead: UInt32
    MmFreePageListHead: UInt32
    MmStandbyPageListHead: UInt32
    MmModifiedPageListHead: UInt32
    MmModifiedNoWritePageListHead: UInt32
    MmAvailablePages: UInt32
    MmResidentAvailablePages: UInt32
    PoolTrackTable: UInt32
    NonPagedPoolDescriptor: UInt32
    MmHighestUserAddress: UInt32
    MmSystemRangeStart: UInt32
    MmUserProbeAddress: UInt32
    KdPrintCircularBuffer: UInt32
    KdPrintCircularBufferEnd: UInt32
    KdPrintWritePointer: UInt32
    KdPrintRolloverCount: UInt32
    MmLoadedUserImageList: UInt32
class KDDEBUGGER_DATA64(Structure):
    Header: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DBGKD_DEBUG_DATA_HEADER64
    KernBase: UInt64
    BreakpointWithStatus: UInt64
    SavedContext: UInt64
    ThCallbackStack: UInt16
    NextCallback: UInt16
    FramePointer: UInt16
    PaeEnabled: Annotated[UInt16, 1]
    KiBugCheckRecoveryActive: Annotated[UInt16, 1]
    PagingLevels: Annotated[UInt16, 4]
    KiCallUserMode: UInt64
    KeUserCallbackDispatcher: UInt64
    PsLoadedModuleList: UInt64
    PsActiveProcessHead: UInt64
    PspCidTable: UInt64
    ExpSystemResourcesList: UInt64
    ExpPagedPoolDescriptor: UInt64
    ExpNumberOfPagedPools: UInt64
    KeTimeIncrement: UInt64
    KeBugCheckCallbackListHead: UInt64
    KiBugcheckData: UInt64
    IopErrorLogListHead: UInt64
    ObpRootDirectoryObject: UInt64
    ObpTypeObjectType: UInt64
    MmSystemCacheStart: UInt64
    MmSystemCacheEnd: UInt64
    MmSystemCacheWs: UInt64
    MmPfnDatabase: UInt64
    MmSystemPtesStart: UInt64
    MmSystemPtesEnd: UInt64
    MmSubsectionBase: UInt64
    MmNumberOfPagingFiles: UInt64
    MmLowestPhysicalPage: UInt64
    MmHighestPhysicalPage: UInt64
    MmNumberOfPhysicalPages: UInt64
    MmMaximumNonPagedPoolInBytes: UInt64
    MmNonPagedSystemStart: UInt64
    MmNonPagedPoolStart: UInt64
    MmNonPagedPoolEnd: UInt64
    MmPagedPoolStart: UInt64
    MmPagedPoolEnd: UInt64
    MmPagedPoolInformation: UInt64
    MmPageSize: UInt64
    MmSizeOfPagedPoolInBytes: UInt64
    MmTotalCommitLimit: UInt64
    MmTotalCommittedPages: UInt64
    MmSharedCommit: UInt64
    MmDriverCommit: UInt64
    MmProcessCommit: UInt64
    MmPagedPoolCommit: UInt64
    MmExtendedCommit: UInt64
    MmZeroedPageListHead: UInt64
    MmFreePageListHead: UInt64
    MmStandbyPageListHead: UInt64
    MmModifiedPageListHead: UInt64
    MmModifiedNoWritePageListHead: UInt64
    MmAvailablePages: UInt64
    MmResidentAvailablePages: UInt64
    PoolTrackTable: UInt64
    NonPagedPoolDescriptor: UInt64
    MmHighestUserAddress: UInt64
    MmSystemRangeStart: UInt64
    MmUserProbeAddress: UInt64
    KdPrintCircularBuffer: UInt64
    KdPrintCircularBufferEnd: UInt64
    KdPrintWritePointer: UInt64
    KdPrintRolloverCount: UInt64
    MmLoadedUserImageList: UInt64
    NtBuildLab: UInt64
    KiNormalSystemCall: UInt64
    KiProcessorBlock: UInt64
    MmUnloadedDrivers: UInt64
    MmLastUnloadedDriver: UInt64
    MmTriageActionTaken: UInt64
    MmSpecialPoolTag: UInt64
    KernelVerifier: UInt64
    MmVerifierData: UInt64
    MmAllocatedNonPagedPool: UInt64
    MmPeakCommitment: UInt64
    MmTotalCommitLimitMaximum: UInt64
    CmNtCSDVersion: UInt64
    MmPhysicalMemoryBlock: UInt64
    MmSessionBase: UInt64
    MmSessionSize: UInt64
    MmSystemParentTablePage: UInt64
    MmVirtualTranslationBase: UInt64
    OffsetKThreadNextProcessor: UInt16
    OffsetKThreadTeb: UInt16
    OffsetKThreadKernelStack: UInt16
    OffsetKThreadInitialStack: UInt16
    OffsetKThreadApcProcess: UInt16
    OffsetKThreadState: UInt16
    OffsetKThreadBStore: UInt16
    OffsetKThreadBStoreLimit: UInt16
    SizeEProcess: UInt16
    OffsetEprocessPeb: UInt16
    OffsetEprocessParentCID: UInt16
    OffsetEprocessDirectoryTableBase: UInt16
    SizePrcb: UInt16
    OffsetPrcbDpcRoutine: UInt16
    OffsetPrcbCurrentThread: UInt16
    OffsetPrcbMhz: UInt16
    OffsetPrcbCpuType: UInt16
    OffsetPrcbVendorString: UInt16
    OffsetPrcbProcStateContext: UInt16
    OffsetPrcbNumber: UInt16
    SizeEThread: UInt16
    L1tfHighPhysicalBitIndex: Byte
    L1tfSwizzleBitIndex: Byte
    Padding0: UInt32
    KdPrintCircularBufferPtr: UInt64
    KdPrintBufferSize: UInt64
    KeLoaderBlock: UInt64
    SizePcr: UInt16
    OffsetPcrSelfPcr: UInt16
    OffsetPcrCurrentPrcb: UInt16
    OffsetPcrContainedPrcb: UInt16
    OffsetPcrInitialBStore: UInt16
    OffsetPcrBStoreLimit: UInt16
    OffsetPcrInitialStack: UInt16
    OffsetPcrStackLimit: UInt16
    OffsetPrcbPcrPage: UInt16
    OffsetPrcbProcStateSpecialReg: UInt16
    GdtR0Code: UInt16
    GdtR0Data: UInt16
    GdtR0Pcr: UInt16
    GdtR3Code: UInt16
    GdtR3Data: UInt16
    GdtR3Teb: UInt16
    GdtLdt: UInt16
    GdtTss: UInt16
    Gdt64R3CmCode: UInt16
    Gdt64R3CmTeb: UInt16
    IopNumTriageDumpDataBlocks: UInt64
    IopTriageDumpDataBlocks: UInt64
    VfCrashDataBlock: UInt64
    MmBadPagesDetected: UInt64
    MmZeroedPageSingleBitErrorsDetected: UInt64
    EtwpDebuggerData: UInt64
    OffsetPrcbContext: UInt16
    OffsetPrcbMaxBreakpoints: UInt16
    OffsetPrcbMaxWatchpoints: UInt16
    OffsetKThreadStackLimit: UInt32
    OffsetKThreadStackBase: UInt32
    OffsetKThreadQueueListEntry: UInt32
    OffsetEThreadIrpList: UInt32
    OffsetPrcbIdleThread: UInt16
    OffsetPrcbNormalDpcState: UInt16
    OffsetPrcbDpcStack: UInt16
    OffsetPrcbIsrStack: UInt16
    SizeKDPC_STACK_FRAME: UInt16
    OffsetKPriQueueThreadListHead: UInt16
    OffsetKThreadWaitReason: UInt16
    Padding1: UInt16
    PteBase: UInt64
    RetpolineStubFunctionTable: UInt64
    RetpolineStubFunctionTableSize: UInt32
    RetpolineStubOffset: UInt32
    RetpolineStubSize: UInt32
    OffsetEProcessMmHotPatchContext: UInt16
    OffsetKThreadShadowStackLimit: UInt32
    OffsetKThreadShadowStackBase: UInt32
    ShadowStackEnabled: UInt64
    PointerAuthMask: UInt64
    OffsetPrcbExceptionStack: UInt16
@winfunctype_pointer
def KDEXTS_LOCK_CALLBACKROUTINE(pLock: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.KDEXTS_LOCK_INFO), Context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class KDEXTS_LOCK_INFO(Structure):
    SizeOfStruct: UInt32
    Address: UInt64
    OwningThread: UInt64
    ExclusiveOwned: win32more.Windows.Win32.Foundation.BOOL
    NumOwners: UInt32
    ContentionCount: UInt32
    NumExclusiveWaiters: UInt32
    NumSharedWaiters: UInt32
    pOwnerThreads: POINTER(UInt64)
    pWaiterThreads: POINTER(UInt64)
class KDEXTS_PTE_INFO(Structure):
    SizeOfStruct: UInt32
    VirtualAddress: UInt64
    PpeAddress: UInt64
    PdeAddress: UInt64
    PteAddress: UInt64
    Pfn: UInt64
    Levels: UInt64
    PteValid: Annotated[UInt32, 1]
    PteTransition: Annotated[UInt32, 1]
    Prototype: Annotated[UInt32, 1]
    Protection: Annotated[UInt32, 1]
    Reserved: Annotated[UInt32, 28]
    ReadInProgress: Annotated[UInt32, 1]
    WriteInProgress: Annotated[UInt32, 1]
    Modified: Annotated[UInt32, 1]
@winfunctype_pointer
def KDEXT_DUMP_HANDLE_CALLBACK(HandleInfo: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.KDEXT_HANDLE_INFORMATION), Flags: UInt32, Context: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
class KDEXT_FILELOCK_OWNER(Structure):
    Sizeofstruct: UInt32
    FileObject: UInt64
    OwnerThread: UInt64
    WaitIrp: UInt64
    DeviceObject: UInt64
    BlockingDirver: win32more.Windows.Win32.Foundation.CHAR * 32
class KDEXT_HANDLE_INFORMATION(Structure):
    HandleTableEntry: UInt64
    Handle: UInt64
    Object: UInt64
    ObjectBody: UInt64
    GrantedAccess: UInt64
    HandleAttributes: UInt32
    PagedOut: win32more.Windows.Win32.Foundation.BOOLEAN
class KDEXT_PROCESS_FIND_PARAMS(Structure):
    SizeofStruct: UInt32
    Pid: UInt32
    Session: UInt32
    ImageName: win32more.Windows.Win32.Foundation.PSTR
class KDEXT_THREAD_FIND_PARAMS(Structure):
    SizeofStruct: UInt32
    StackPointer: UInt64
    Cid: UInt32
    Thread: UInt64
LanguageKind = Int32
LanguageUnknown: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.LanguageKind = 0
LanguageC: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.LanguageKind = 1
LanguageCPP: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.LanguageKind = 2
LanguageAssembly: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.LanguageKind = 3
class Location(Structure):
    HostDefined: UInt64
    Offset: UInt64
LocationKind = Int32
LocationMember: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.LocationKind = 0
LocationStatic: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.LocationKind = 1
LocationConstant: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.LocationKind = 2
LocationNone: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.LocationKind = 3
ModelObjectKind = Int32
ObjectPropertyAccessor: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ModelObjectKind = 0
ObjectContext: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ModelObjectKind = 1
ObjectTargetObject: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ModelObjectKind = 2
ObjectTargetObjectReference: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ModelObjectKind = 3
ObjectSynthetic: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ModelObjectKind = 4
ObjectNoValue: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ModelObjectKind = 5
ObjectError: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ModelObjectKind = 6
ObjectIntrinsic: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ModelObjectKind = 7
ObjectMethod: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ModelObjectKind = 8
ObjectKeyReference: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ModelObjectKind = 9
class OS_INFO(Structure):
    MajorVer: UInt32
    MinorVer: UInt32
    Build: UInt32
    BuildQfe: UInt32
    ProductType: UInt32
    Suite: UInt32
    Revision: UInt32
    s: _s_e__Struct
    SrvPackNumber: UInt32
    ServicePackBuild: UInt32
    Architecture: UInt32
    Lcid: UInt32
    Name: win32more.Windows.Win32.Foundation.CHAR * 64
    FullName: win32more.Windows.Win32.Foundation.CHAR * 256
    Language: win32more.Windows.Win32.Foundation.CHAR * 30
    BuildVersion: win32more.Windows.Win32.Foundation.CHAR * 64
    ServicePackString: win32more.Windows.Win32.Foundation.CHAR * 64
    class _s_e__Struct(Structure):
        Checked: Annotated[UInt32, 1]
        Pae: Annotated[UInt32, 1]
        MultiProc: Annotated[UInt32, 1]
        Reserved: Annotated[UInt32, 29]
class OS_INFO_v1(Structure):
    Type: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.OS_TYPE
    Anonymous: _Anonymous_e__Union
    ProductType: UInt32
    Suite: UInt32
    s: _s_e__Struct
    SrvPackNumber: UInt32
    Language: win32more.Windows.Win32.Foundation.CHAR * 30
    OsString: win32more.Windows.Win32.Foundation.CHAR * 64
    ServicePackString: win32more.Windows.Win32.Foundation.CHAR * 64
    class _Anonymous_e__Union(Union):
        Version: _Version_e__Struct
        Ver64: UInt64
        class _Version_e__Struct(Structure):
            Major: UInt32
            Minor: UInt32
    class _s_e__Struct(Structure):
        Checked: Annotated[UInt32, 1]
        Pae: Annotated[UInt32, 1]
        MultiProc: Annotated[UInt32, 1]
        Reserved: Annotated[UInt32, 29]
OS_TYPE = Int32
WIN_95: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.OS_TYPE = 0
WIN_98: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.OS_TYPE = 1
WIN_ME: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.OS_TYPE = 2
WIN_NT4: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.OS_TYPE = 3
WIN_NT5: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.OS_TYPE = 4
WIN_NT5_1: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.OS_TYPE = 5
WIN_NT5_2: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.OS_TYPE = 6
WIN_NT6_0: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.OS_TYPE = 7
WIN_NT6_1: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.OS_TYPE = 8
WIN_UNDEFINED: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.OS_TYPE = 255
@winfunctype_pointer
def PDEBUG_EXTENSION_CALL(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Args: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PDEBUG_EXTENSION_CANUNLOAD() -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PDEBUG_EXTENSION_INITIALIZE(Version: POINTER(UInt32), Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PDEBUG_EXTENSION_KNOWN_STRUCT(Flags: UInt32, Offset: UInt64, TypeName: win32more.Windows.Win32.Foundation.PSTR, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferChars: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PDEBUG_EXTENSION_KNOWN_STRUCT_EX(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Flags: UInt32, Offset: UInt64, TypeName: win32more.Windows.Win32.Foundation.PSTR, Buffer: win32more.Windows.Win32.Foundation.PSTR, BufferChars: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PDEBUG_EXTENSION_NOTIFY(Notify: UInt32, Argument: UInt64) -> Void: ...
@winfunctype_pointer
def PDEBUG_EXTENSION_PROVIDE_VALUE(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Flags: UInt32, Name: win32more.Windows.Win32.Foundation.PWSTR, Value: POINTER(UInt64), TypeModBase: POINTER(UInt64), TypeId: POINTER(UInt32), TypeFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PDEBUG_EXTENSION_QUERY_VALUE_NAMES(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Flags: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferChars: UInt32, BufferNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PDEBUG_EXTENSION_UNINITIALIZE() -> Void: ...
@winfunctype_pointer
def PDEBUG_EXTENSION_UNLOAD() -> Void: ...
@winfunctype_pointer
def PDEBUG_STACK_PROVIDER_BEGINTHREADSTACKRECONSTRUCTION(StreamType: UInt32, MiniDumpStreamBuffer: VoidPtr, BufferSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PDEBUG_STACK_PROVIDER_ENDTHREADSTACKRECONSTRUCTION() -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PDEBUG_STACK_PROVIDER_FREESTACKSYMFRAMES(StackSymFrames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.STACK_SYM_FRAME_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PDEBUG_STACK_PROVIDER_RECONSTRUCTSTACK(SystemThreadId: UInt32, NativeFrames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX), CountNativeFrames: UInt32, StackSymFrames: POINTER(POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.STACK_SYM_FRAME_INFO)), StackSymFramesFilled: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PENUMERATE_HANDLES(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Process: UInt64, HandleToDump: UInt64, Flags: UInt32, Callback: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.KDEXT_DUMP_HANDLE_CALLBACK, Context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PENUMERATE_HASH_TABLE(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, HashTable: UInt64, Callback: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXTS_TABLE_ENTRY_CALLBACK, Context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PENUMERATE_JOB_PROCESSES(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Job: UInt64, Callback: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXTS_JOB_PROCESS_CALLBACK, Context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PENUMERATE_SYSTEM_LOCKS(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Flags: UInt32, Callback: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.KDEXTS_LOCK_CALLBACKROUTINE, Context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFIND_FILELOCK_OWNERINFO(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, pFileLockOwner: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.KDEXT_FILELOCK_OWNER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFIND_MATCHING_PROCESS(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, ProcessInfo: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.KDEXT_PROCESS_FIND_PARAMS), Process: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFIND_MATCHING_THREAD(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, ThreadInfo: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.KDEXT_THREAD_FIND_PARAMS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PGET_CPU_MICROCODE_VERSION(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, pCpuMicrocodeVersion: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_CPU_MICROCODE_VERSION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PGET_CPU_PSPEED_INFO(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, pCpuSpeedInfo: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_CPU_SPEED_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PGET_DEVICE_OBJECT_INFO(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, DeviceObject: UInt64, pDevObjInfo: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_DEVICE_OBJECT_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PGET_DRIVER_OBJECT_INFO(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, DriverObject: UInt64, pDrvObjInfo: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_DRIVER_OBJECT_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PGET_FULL_IMAGE_NAME(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Process: UInt64, FullImageName: POINTER(win32more.Windows.Win32.Foundation.PSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PGET_IRP_INFO(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Irp: UInt64, IrpInfo: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_IRP_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PGET_PNP_TRIAGE_INFO(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, pPNPTriageInfo: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_PNP_TRIAGE_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PGET_POOL_DATA(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Pool: UInt64, PoolData: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_POOL_DATA)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PGET_POOL_REGION(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Pool: UInt64, PoolRegion: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_POOL_REGION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PGET_POOL_TAG_DESCRIPTION(PoolTag: UInt32, pDescription: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_POOLTAG_DESCRIPTION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PGET_PROCESS_COMMIT(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, TotalCommitCharge: POINTER(UInt64), NumberOfProcesses: POINTER(UInt32), CommitData: POINTER(POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PROCESS_COMMIT_USAGE))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PGET_SMBIOS_INFO(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, pSmbiosInfo: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_SMBIOS_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class PHYSICAL(Structure):
    Address: UInt64
    BufLen: UInt32
    Buf: Byte * 1
class PHYSICAL_TO_VIRTUAL(Structure):
    Status: UInt32
    Size: UInt32
    PdeAddress: UInt64
class PHYSICAL_WITH_FLAGS(Structure):
    Address: UInt64
    BufLen: UInt32
    Flags: UInt32
    Buf: Byte * 1
@winfunctype_pointer
def PKDEXTS_GET_PTE_INFO(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Virtual: UInt64, PteInfo: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.KDEXTS_PTE_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class POINTER_SEARCH_PHYSICAL(Structure):
    Offset: UInt64
    Length: UInt64
    PointerMin: UInt64
    PointerMax: UInt64
    Flags: UInt32
    MatchOffsets: POINTER(UInt64)
    MatchOffsetsSize: UInt32
    MatchOffsetsCount: UInt32
class PROCESSORINFO(Structure):
    Processor: UInt16
    NumberProcessors: UInt16
class PROCESS_COMMIT_USAGE(Structure):
    ImageFileName: Byte * 16
    ClientId: UInt64
    ProcessAddress: UInt64
    CommitCharge: UInt64
    SharedCommitCharge: UInt64
    ReleasedCommitDebt: UInt64
    Reserved: UInt64
class PROCESS_NAME_ENTRY(Structure):
    ProcessId: UInt32
    NameOffset: UInt32
    NameSize: UInt32
    NextEntry: UInt32
@winfunctype_pointer
def PSYM_DUMP_FIELD_CALLBACK(pField: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FIELD_INFO), UserContext: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_CHECK_CONTROL_C() -> UInt32: ...
@winfunctype_pointer
def PWINDBG_CHECK_VERSION() -> UInt32: ...
@winfunctype_pointer
def PWINDBG_DISASM(lpOffset: POINTER(UIntPtr), lpBuffer: win32more.Windows.Win32.Foundation.PSTR, fShowEffectiveAddress: UInt32) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_DISASM32(lpOffset: POINTER(UInt32), lpBuffer: win32more.Windows.Win32.Foundation.PSTR, fShowEffectiveAddress: UInt32) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_DISASM64(lpOffset: POINTER(UInt64), lpBuffer: win32more.Windows.Win32.Foundation.PSTR, fShowEffectiveAddress: UInt32) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_EXTENSION_API_VERSION() -> POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXT_API_VERSION): ...
@winfunctype_pointer
def PWINDBG_EXTENSION_DLL_INIT(lpExtensionApis: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS), MajorVersion: UInt16, MinorVersion: UInt16) -> Void: ...
@winfunctype_pointer
def PWINDBG_EXTENSION_DLL_INIT32(lpExtensionApis: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS32), MajorVersion: UInt16, MinorVersion: UInt16) -> Void: ...
@winfunctype_pointer
def PWINDBG_EXTENSION_DLL_INIT64(lpExtensionApis: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS64), MajorVersion: UInt16, MinorVersion: UInt16) -> Void: ...
@winfunctype_pointer
def PWINDBG_EXTENSION_ROUTINE(hCurrentProcess: win32more.Windows.Win32.Foundation.HANDLE, hCurrentThread: win32more.Windows.Win32.Foundation.HANDLE, dwCurrentPc: UInt32, dwProcessor: UInt32, lpArgumentString: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype_pointer
def PWINDBG_EXTENSION_ROUTINE32(hCurrentProcess: win32more.Windows.Win32.Foundation.HANDLE, hCurrentThread: win32more.Windows.Win32.Foundation.HANDLE, dwCurrentPc: UInt32, dwProcessor: UInt32, lpArgumentString: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype_pointer
def PWINDBG_EXTENSION_ROUTINE64(hCurrentProcess: win32more.Windows.Win32.Foundation.HANDLE, hCurrentThread: win32more.Windows.Win32.Foundation.HANDLE, dwCurrentPc: UInt64, dwProcessor: UInt32, lpArgumentString: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype_pointer
def PWINDBG_GET_EXPRESSION(lpExpression: win32more.Windows.Win32.Foundation.PSTR) -> UIntPtr: ...
@winfunctype_pointer
def PWINDBG_GET_EXPRESSION32(lpExpression: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_GET_EXPRESSION64(lpExpression: win32more.Windows.Win32.Foundation.PSTR) -> UInt64: ...
@winfunctype_pointer
def PWINDBG_GET_SYMBOL(offset: VoidPtr, pchBuffer: win32more.Windows.Win32.Foundation.PSTR, pDisplacement: POINTER(UIntPtr)) -> Void: ...
@winfunctype_pointer
def PWINDBG_GET_SYMBOL32(offset: UInt32, pchBuffer: win32more.Windows.Win32.Foundation.PSTR, pDisplacement: POINTER(UInt32)) -> Void: ...
@winfunctype_pointer
def PWINDBG_GET_SYMBOL64(offset: UInt64, pchBuffer: win32more.Windows.Win32.Foundation.PSTR, pDisplacement: POINTER(UInt64)) -> Void: ...
@winfunctype_pointer
def PWINDBG_GET_THREAD_CONTEXT_ROUTINE(Processor: UInt32, lpContext: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.CONTEXT), cbSizeOfContext: UInt32) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_IOCTL_ROUTINE(IoctlType: UInt16, lpvData: VoidPtr, cbSize: UInt32) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_OLDKD_EXTENSION_ROUTINE(dwCurrentPc: UInt32, lpExtensionApis: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_OLDKD_EXTENSION_APIS), lpArgumentString: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype_pointer
def PWINDBG_OLDKD_READ_PHYSICAL_MEMORY(address: UInt64, buffer: VoidPtr, count: UInt32, bytesread: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_OLDKD_WRITE_PHYSICAL_MEMORY(address: UInt64, buffer: VoidPtr, length: UInt32, byteswritten: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_OLD_EXTENSION_ROUTINE(dwCurrentPc: UInt32, lpExtensionApis: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.WINDBG_EXTENSION_APIS), lpArgumentString: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@cfunctype_pointer
def PWINDBG_OUTPUT_ROUTINE(lpFormat: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@winfunctype_pointer
def PWINDBG_READ_PROCESS_MEMORY_ROUTINE(offset: UIntPtr, lpBuffer: VoidPtr, cb: UInt32, lpcbBytesRead: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_READ_PROCESS_MEMORY_ROUTINE32(offset: UInt32, lpBuffer: VoidPtr, cb: UInt32, lpcbBytesRead: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_READ_PROCESS_MEMORY_ROUTINE64(offset: UInt64, lpBuffer: VoidPtr, cb: UInt32, lpcbBytesRead: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_SET_THREAD_CONTEXT_ROUTINE(Processor: UInt32, lpContext: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.CONTEXT), cbSizeOfContext: UInt32) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_STACKTRACE_ROUTINE(FramePointer: UInt32, StackPointer: UInt32, ProgramCounter: UInt32, StackFrames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXTSTACKTRACE), Frames: UInt32) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_STACKTRACE_ROUTINE32(FramePointer: UInt32, StackPointer: UInt32, ProgramCounter: UInt32, StackFrames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXTSTACKTRACE32), Frames: UInt32) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_STACKTRACE_ROUTINE64(FramePointer: UInt64, StackPointer: UInt64, ProgramCounter: UInt64, StackFrames: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.EXTSTACKTRACE64), Frames: UInt32) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_WRITE_PROCESS_MEMORY_ROUTINE(offset: UIntPtr, lpBuffer: VoidPtr, cb: UInt32, lpcbBytesWritten: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_WRITE_PROCESS_MEMORY_ROUTINE32(offset: UInt32, lpBuffer: VoidPtr, cb: UInt32, lpcbBytesWritten: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PWINDBG_WRITE_PROCESS_MEMORY_ROUTINE64(offset: UInt64, lpBuffer: VoidPtr, cb: UInt32, lpcbBytesWritten: POINTER(UInt32)) -> UInt32: ...
PointerKind = Int32
PointerStandard: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PointerKind = 0
PointerReference: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PointerKind = 1
PointerRValueReference: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PointerKind = 2
PointerCXHat: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PointerKind = 3
PointerManagedReference: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PointerKind = 4
PreferredFormat = Int32
FormatNone: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PreferredFormat = 0
FormatSingleCharacter: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PreferredFormat = 1
FormatQuotedString: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PreferredFormat = 2
FormatString: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PreferredFormat = 3
FormatQuotedUnicodeString: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PreferredFormat = 4
FormatUnicodeString: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PreferredFormat = 5
FormatQuotedUTF8String: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PreferredFormat = 6
FormatUTF8String: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PreferredFormat = 7
FormatBSTRString: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PreferredFormat = 8
FormatQuotedHString: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PreferredFormat = 9
FormatHString: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PreferredFormat = 10
FormatRaw: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PreferredFormat = 11
FormatEnumNameOnly: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PreferredFormat = 12
FormatEscapedStringWithQuote: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PreferredFormat = 13
FormatUTF32String: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PreferredFormat = 14
FormatQuotedUTF32String: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PreferredFormat = 15
class READCONTROLSPACE(Structure):
    Processor: UInt16
    Address: UInt32
    BufLen: UInt32
    Buf: Byte * 1
class READCONTROLSPACE32(Structure):
    Processor: UInt16
    Address: UInt32
    BufLen: UInt32
    Buf: Byte * 1
class READCONTROLSPACE64(Structure):
    Processor: UInt16
    Address: UInt64
    BufLen: UInt32
    Buf: Byte * 1
class READ_WRITE_MSR(Structure):
    Msr: UInt32
    Value: Int64
RawSearchFlags = Int32
RawSearchNone: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.RawSearchFlags = 0
RawSearchNoBases: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.RawSearchFlags = 1
class SEARCHMEMORY(Structure):
    SearchAddress: UInt64
    SearchLength: UInt64
    FoundAddress: UInt64
    PatternLength: UInt32
    Pattern: VoidPtr
class STACK_SRC_INFO(Structure):
    ImagePath: win32more.Windows.Win32.Foundation.PWSTR
    ModuleName: win32more.Windows.Win32.Foundation.PWSTR
    Function: win32more.Windows.Win32.Foundation.PWSTR
    Displacement: UInt32
    Row: UInt32
    Column: UInt32
class STACK_SYM_FRAME_INFO(Structure):
    StackFrameEx: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.DEBUG_STACK_FRAME_EX
    SrcInfo: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.STACK_SRC_INFO
class SYMBOL_INFO_EX(Structure):
    SizeOfStruct: UInt32
    TypeOfInfo: UInt32
    Offset: UInt64
    Line: UInt32
    Displacement: UInt32
    Reserved: UInt32 * 4
class SYM_DUMP_PARAM(Structure):
    size: UInt32
    sName: POINTER(Byte)
    Options: UInt32
    addr: UInt64
    listLink: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FIELD_INFO)
    Anonymous: _Anonymous_e__Union
    CallbackRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PSYM_DUMP_FIELD_CALLBACK
    nFields: UInt32
    Fields: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.FIELD_INFO)
    ModBase: UInt64
    TypeId: UInt32
    TypeSize: UInt32
    BufferSize: UInt32
    fPointer: Annotated[UInt32, 2]
    fArray: Annotated[UInt32, 1]
    fStruct: Annotated[UInt32, 1]
    fConstant: Annotated[UInt32, 1]
    Reserved: Annotated[UInt32, 27]
    class _Anonymous_e__Union(Union):
        Context: VoidPtr
        pBuffer: VoidPtr
ScriptChangeKind = Int32
ScriptRename: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptChangeKind = 0
ScriptDebugEvent = Int32
ScriptDebugBreakpoint: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugEvent = 0
ScriptDebugStep: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugEvent = 1
ScriptDebugException: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugEvent = 2
ScriptDebugAsyncBreak: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugEvent = 3
ScriptDebugEventFilter = Int32
ScriptDebugEventFilterEntry: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugEventFilter = 0
ScriptDebugEventFilterException: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugEventFilter = 1
ScriptDebugEventFilterUnhandledException: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugEventFilter = 2
ScriptDebugEventFilterAbort: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugEventFilter = 3
class ScriptDebugEventInformation(Structure):
    DebugEvent: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugEvent
    EventPosition: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugPosition
    EventSpanEnd: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugPosition
    u: _u_e__Union
    class _u_e__Union(Union):
        ExceptionInformation: _ExceptionInformation_e__Struct
        BreakpointInformation: _BreakpointInformation_e__Struct
        class _ExceptionInformation_e__Struct(Structure):
            IsUncaught: Byte
        class _BreakpointInformation_e__Struct(Structure):
            BreakpointId: UInt64
class ScriptDebugPosition(Structure):
    Line: UInt32
    Column: UInt32
ScriptDebugState = Int32
ScriptDebugNoDebugger: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugState = 0
ScriptDebugNotExecuting: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugState = 1
ScriptDebugExecuting: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugState = 2
ScriptDebugBreak: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptDebugState = 3
ScriptExecutionKind = Int32
ScriptExecutionNormal: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptExecutionKind = 0
ScriptExecutionStepIn: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptExecutionKind = 1
ScriptExecutionStepOut: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptExecutionKind = 2
ScriptExecutionStepOver: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.ScriptExecutionKind = 3
SignatureComparison = Int32
Unrelated: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SignatureComparison = 0
Ambiguous: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SignatureComparison = 1
LessSpecific: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SignatureComparison = 2
MoreSpecific: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SignatureComparison = 3
Identical: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SignatureComparison = 4
SymbolKind = Int32
Symbol: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolKind = 0
SymbolModule: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolKind = 1
SymbolType: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolKind = 2
SymbolField: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolKind = 3
SymbolConstant: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolKind = 4
SymbolData: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolKind = 5
SymbolBaseClass: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolKind = 6
SymbolPublic: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolKind = 7
SymbolFunction: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolKind = 8
SymbolSearchOptions = Int32
SymbolSearchNone: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolSearchOptions = 0
SymbolSearchCompletion: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolSearchOptions = 1
SymbolSearchCaseInsensitive: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.SymbolSearchOptions = 2
TANALYZE_RETURN = Int32
NO_TYPE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TANALYZE_RETURN = 0
PROCESS_END: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TANALYZE_RETURN = 1
EXIT_STATUS: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TANALYZE_RETURN = 2
DISK_READ_0_BYTES: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TANALYZE_RETURN = 3
DISK_WRITE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TANALYZE_RETURN = 4
NT_STATUS_CODE: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TANALYZE_RETURN = 5
class TARGET_DEBUG_INFO(Structure):
    SizeOfStruct: UInt32
    EntryDate: UInt64
    DebugeeClass: UInt32
    SysUpTime: UInt64
    AppUpTime: UInt64
    CrashTime: UInt64
    OsInfo: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.OS_INFO
    Cpu: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.CPU_INFO
    DumpFile: win32more.Windows.Win32.Foundation.CHAR * 260
class TARGET_DEBUG_INFO_v1(Structure):
    SizeOfStruct: UInt32
    Id: UInt64
    Source: UInt64
    EntryDate: UInt64
    SysUpTime: UInt64
    AppUpTime: UInt64
    CrashTime: UInt64
    Mode: UInt64
    OsInfo: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.OS_INFO_v1
    Cpu: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.CPU_INFO_v1
    DumpFile: win32more.Windows.Win32.Foundation.CHAR * 260
    FailureData: VoidPtr
    StackTr: win32more.Windows.Win32.Foundation.CHAR * 4096
class TARGET_DEBUG_INFO_v2(Structure):
    SizeOfStruct: UInt32
    EntryDate: UInt64
    DebugeeClass: UInt32
    SysUpTime: UInt64
    AppUpTime: UInt64
    CrashTime: UInt64
    OsInfo: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.OS_INFO
    Cpu: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.CPU_INFO_v2
    DumpFile: win32more.Windows.Win32.Foundation.CHAR * 260
class TRANSLATE_VIRTUAL_TO_PHYSICAL(Structure):
    Virtual: UInt64
    Physical: UInt64
TypeKind = Int32
TypeUDT: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TypeKind = 0
TypePointer: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TypeKind = 1
TypeMemberPointer: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TypeKind = 2
TypeArray: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TypeKind = 3
TypeFunction: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TypeKind = 4
TypeTypedef: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TypeKind = 5
TypeEnum: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TypeKind = 6
TypeIntrinsic: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TypeKind = 7
TypeExtendedArray: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.TypeKind = 8
class VIRTUAL_TO_PHYSICAL(Structure):
    Status: UInt32
    Size: UInt32
    PdeAddress: UInt64
    Virtual: UInt64
    Physical: UInt64
VarArgsKind = Int32
VarArgsNone: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.VarArgsKind = 0
VarArgsCStyle: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.VarArgsKind = 1
class WDBGEXTS_CLR_DATA_INTERFACE(Structure):
    Iid: POINTER(Guid)
    Iface: VoidPtr
class WDBGEXTS_DISASSEMBLE_BUFFER(Structure):
    InOffset: UInt64
    OutOffset: UInt64
    AddrFlags: UInt32
    FormatFlags: UInt32
    DataBufferBytes: UInt32
    DisasmBufferChars: UInt32
    DataBuffer: VoidPtr
    DisasmBuffer: win32more.Windows.Win32.Foundation.PWSTR
    Reserved0: UInt64 * 3
class WDBGEXTS_MODULE_IN_RANGE(Structure):
    Start: UInt64
    End: UInt64
    FoundModBase: UInt64
    FoundModSize: UInt32
class WDBGEXTS_QUERY_INTERFACE(Structure):
    Iid: POINTER(Guid)
    Iface: VoidPtr
class WDBGEXTS_THREAD_OS_INFO(Structure):
    ThreadId: UInt32
    ExitStatus: UInt32
    PriorityClass: UInt32
    Priority: UInt32
    CreateTime: UInt64
    ExitTime: UInt64
    KernelTime: UInt64
    UserTime: UInt64
    StartOffset: UInt64
    Affinity: UInt64
class WINDBG_EXTENSION_APIS(Structure):
    nSize: UInt32
    lpOutputRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_OUTPUT_ROUTINE
    lpGetExpressionRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_GET_EXPRESSION
    lpGetSymbolRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_GET_SYMBOL
    lpDisasmRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_DISASM
    lpCheckControlCRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_CHECK_CONTROL_C
    lpReadProcessMemoryRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_READ_PROCESS_MEMORY_ROUTINE
    lpWriteProcessMemoryRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_WRITE_PROCESS_MEMORY_ROUTINE
    lpGetThreadContextRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_GET_THREAD_CONTEXT_ROUTINE
    lpSetThreadContextRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_SET_THREAD_CONTEXT_ROUTINE
    lpIoctlRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_IOCTL_ROUTINE
    lpStackTraceRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_STACKTRACE_ROUTINE
class WINDBG_EXTENSION_APIS32(Structure):
    nSize: UInt32
    lpOutputRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_OUTPUT_ROUTINE
    lpGetExpressionRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_GET_EXPRESSION32
    lpGetSymbolRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_GET_SYMBOL32
    lpDisasmRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_DISASM32
    lpCheckControlCRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_CHECK_CONTROL_C
    lpReadProcessMemoryRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_READ_PROCESS_MEMORY_ROUTINE32
    lpWriteProcessMemoryRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_WRITE_PROCESS_MEMORY_ROUTINE32
    lpGetThreadContextRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_GET_THREAD_CONTEXT_ROUTINE
    lpSetThreadContextRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_SET_THREAD_CONTEXT_ROUTINE
    lpIoctlRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_IOCTL_ROUTINE
    lpStackTraceRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_STACKTRACE_ROUTINE32
class WINDBG_EXTENSION_APIS64(Structure):
    nSize: UInt32
    lpOutputRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_OUTPUT_ROUTINE
    lpGetExpressionRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_GET_EXPRESSION64
    lpGetSymbolRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_GET_SYMBOL64
    lpDisasmRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_DISASM64
    lpCheckControlCRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_CHECK_CONTROL_C
    lpReadProcessMemoryRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_READ_PROCESS_MEMORY_ROUTINE64
    lpWriteProcessMemoryRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_WRITE_PROCESS_MEMORY_ROUTINE64
    lpGetThreadContextRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_GET_THREAD_CONTEXT_ROUTINE
    lpSetThreadContextRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_SET_THREAD_CONTEXT_ROUTINE
    lpIoctlRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_IOCTL_ROUTINE
    lpStackTraceRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_STACKTRACE_ROUTINE64
class WINDBG_OLDKD_EXTENSION_APIS(Structure):
    nSize: UInt32
    lpOutputRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_OUTPUT_ROUTINE
    lpGetExpressionRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_GET_EXPRESSION32
    lpGetSymbolRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_GET_SYMBOL32
    lpDisasmRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_DISASM32
    lpCheckControlCRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_CHECK_CONTROL_C
    lpReadVirtualMemRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_READ_PROCESS_MEMORY_ROUTINE32
    lpWriteVirtualMemRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_WRITE_PROCESS_MEMORY_ROUTINE32
    lpReadPhysicalMemRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_OLDKD_READ_PHYSICAL_MEMORY
    lpWritePhysicalMemRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_OLDKD_WRITE_PHYSICAL_MEMORY
class WINDBG_OLD_EXTENSION_APIS(Structure):
    nSize: UInt32
    lpOutputRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_OUTPUT_ROUTINE
    lpGetExpressionRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_GET_EXPRESSION
    lpGetSymbolRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_GET_SYMBOL
    lpDisasmRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_DISASM
    lpCheckControlCRoutine: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.PWINDBG_CHECK_CONTROL_C
class XML_DRIVER_NODE_INFO(Structure):
    FileName: win32more.Windows.Win32.Foundation.CHAR * 64
    FileSize: UInt64
    CreationDate: UInt64
    Version: win32more.Windows.Win32.Foundation.CHAR * 64
    Manufacturer: win32more.Windows.Win32.Foundation.CHAR * 260
    ProductName: win32more.Windows.Win32.Foundation.CHAR * 260
    Group: win32more.Windows.Win32.Foundation.CHAR * 260
    Altitude: win32more.Windows.Win32.Foundation.CHAR * 260
@winfunctype_pointer
def fnDebugFailureAnalysisCreateInstance(Client: win32more.Windows.Win32.System.Diagnostics.Debug.Extensions.IDebugClient, Args: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, rclsid: POINTER(Guid), riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)
