from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security.Cryptography
import win32more.Windows.Win32.System.ApplicationInstallationAndServicing
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Registry
import win32more.Windows.Win32.System.WindowsProgramming
class ACTCTXA(Structure):
    cbSize: UInt32
    dwFlags: UInt32
    lpSource: win32more.Windows.Win32.Foundation.PSTR
    wProcessorArchitecture: UInt16
    wLangId: UInt16
    lpAssemblyDirectory: win32more.Windows.Win32.Foundation.PSTR
    lpResourceName: win32more.Windows.Win32.Foundation.PSTR
    lpApplicationName: win32more.Windows.Win32.Foundation.PSTR
    hModule: win32more.Windows.Win32.Foundation.HMODULE
class ACTCTXW(Structure):
    cbSize: UInt32
    dwFlags: UInt32
    lpSource: win32more.Windows.Win32.Foundation.PWSTR
    wProcessorArchitecture: UInt16
    wLangId: UInt16
    lpAssemblyDirectory: win32more.Windows.Win32.Foundation.PWSTR
    lpResourceName: win32more.Windows.Win32.Foundation.PWSTR
    lpApplicationName: win32more.Windows.Win32.Foundation.PWSTR
    hModule: win32more.Windows.Win32.Foundation.HMODULE
ACTCTX = UnicodeAlias('ACTCTXW')
ACTCTX_COMPATIBILITY_ELEMENT_TYPE = Int32
ACTCTX_COMPATIBILITY_ELEMENT_TYPE_UNKNOWN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ACTCTX_COMPATIBILITY_ELEMENT_TYPE = 0
ACTCTX_COMPATIBILITY_ELEMENT_TYPE_OS: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ACTCTX_COMPATIBILITY_ELEMENT_TYPE = 1
ACTCTX_COMPATIBILITY_ELEMENT_TYPE_MITIGATION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ACTCTX_COMPATIBILITY_ELEMENT_TYPE = 2
ACTCTX_COMPATIBILITY_ELEMENT_TYPE_MAXVERSIONTESTED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ACTCTX_COMPATIBILITY_ELEMENT_TYPE = 3
ACTCTX_REQUESTED_RUN_LEVEL = Int32
ACTCTX_RUN_LEVEL_UNSPECIFIED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ACTCTX_REQUESTED_RUN_LEVEL = 0
ACTCTX_RUN_LEVEL_AS_INVOKER: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ACTCTX_REQUESTED_RUN_LEVEL = 1
ACTCTX_RUN_LEVEL_HIGHEST_AVAILABLE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ACTCTX_REQUESTED_RUN_LEVEL = 2
ACTCTX_RUN_LEVEL_REQUIRE_ADMIN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ACTCTX_REQUESTED_RUN_LEVEL = 3
ACTCTX_RUN_LEVEL_NUMBERS: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ACTCTX_REQUESTED_RUN_LEVEL = 4
class ACTCTX_SECTION_KEYED_DATA(Structure):
    cbSize: UInt32
    ulDataFormatVersion: UInt32
    lpData: VoidPtr
    ulLength: UInt32
    lpSectionGlobalData: VoidPtr
    ulSectionGlobalDataLength: UInt32
    lpSectionBase: VoidPtr
    ulSectionTotalLength: UInt32
    hActCtx: win32more.Windows.Win32.Foundation.HANDLE
    ulAssemblyRosterIndex: UInt32
    ulFlags: UInt32
    AssemblyMetadata: win32more.Windows.Win32.System.WindowsProgramming.ACTCTX_SECTION_KEYED_DATA_ASSEMBLY_METADATA
class ACTIVATION_CONTEXT_ASSEMBLY_DETAILED_INFORMATION(Structure):
    ulFlags: UInt32
    ulEncodedAssemblyIdentityLength: UInt32
    ulManifestPathType: UInt32
    ulManifestPathLength: UInt32
    liManifestLastWriteTime: Int64
    ulPolicyPathType: UInt32
    ulPolicyPathLength: UInt32
    liPolicyLastWriteTime: Int64
    ulMetadataSatelliteRosterIndex: UInt32
    ulManifestVersionMajor: UInt32
    ulManifestVersionMinor: UInt32
    ulPolicyVersionMajor: UInt32
    ulPolicyVersionMinor: UInt32
    ulAssemblyDirectoryNameLength: UInt32
    lpAssemblyEncodedAssemblyIdentity: win32more.Windows.Win32.Foundation.PWSTR
    lpAssemblyManifestPath: win32more.Windows.Win32.Foundation.PWSTR
    lpAssemblyPolicyPath: win32more.Windows.Win32.Foundation.PWSTR
    lpAssemblyDirectoryName: win32more.Windows.Win32.Foundation.PWSTR
    ulFileCount: UInt32
class ACTIVATION_CONTEXT_COMPATIBILITY_INFORMATION(Structure):
    ElementCount: UInt32
    Elements: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.COMPATIBILITY_CONTEXT_ELEMENT * 1
class ACTIVATION_CONTEXT_DETAILED_INFORMATION(Structure):
    dwFlags: UInt32
    ulFormatVersion: UInt32
    ulAssemblyCount: UInt32
    ulRootManifestPathType: UInt32
    ulRootManifestPathChars: UInt32
    ulRootConfigurationPathType: UInt32
    ulRootConfigurationPathChars: UInt32
    ulAppDirPathType: UInt32
    ulAppDirPathChars: UInt32
    lpRootManifestPath: win32more.Windows.Win32.Foundation.PWSTR
    lpRootConfigurationPath: win32more.Windows.Win32.Foundation.PWSTR
    lpAppDirPath: win32more.Windows.Win32.Foundation.PWSTR
class ACTIVATION_CONTEXT_QUERY_INDEX(Structure):
    ulAssemblyIndex: UInt32
    ulFileIndexInAssembly: UInt32
class ACTIVATION_CONTEXT_RUN_LEVEL_INFORMATION(Structure):
    ulFlags: UInt32
    RunLevel: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ACTCTX_REQUESTED_RUN_LEVEL
    UiAccess: UInt32
ADVERTISEFLAGS = Int32
ADVERTISEFLAGS_MACHINEASSIGN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ADVERTISEFLAGS = 0
ADVERTISEFLAGS_USERASSIGN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ADVERTISEFLAGS = 1
ASM_BIND_FLAGS = Int32
ASM_BINDF_FORCE_CACHE_INSTALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_BIND_FLAGS = 1
ASM_BINDF_RFS_INTEGRITY_CHECK: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_BIND_FLAGS = 2
ASM_BINDF_RFS_MODULE_CHECK: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_BIND_FLAGS = 4
ASM_BINDF_BINPATH_PROBE_ONLY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_BIND_FLAGS = 8
ASM_BINDF_SHARED_BINPATH_HINT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_BIND_FLAGS = 16
ASM_BINDF_PARENT_ASM_HINT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_BIND_FLAGS = 32
ASM_CMP_FLAGS = Int32
ASM_CMPF_NAME: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_CMP_FLAGS = 1
ASM_CMPF_MAJOR_VERSION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_CMP_FLAGS = 2
ASM_CMPF_MINOR_VERSION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_CMP_FLAGS = 4
ASM_CMPF_BUILD_NUMBER: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_CMP_FLAGS = 8
ASM_CMPF_REVISION_NUMBER: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_CMP_FLAGS = 16
ASM_CMPF_PUBLIC_KEY_TOKEN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_CMP_FLAGS = 32
ASM_CMPF_CULTURE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_CMP_FLAGS = 64
ASM_CMPF_CUSTOM: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_CMP_FLAGS = 128
ASM_CMPF_ALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_CMP_FLAGS = 255
ASM_CMPF_DEFAULT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_CMP_FLAGS = 256
ASM_DISPLAY_FLAGS = Int32
ASM_DISPLAYF_VERSION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_DISPLAY_FLAGS = 1
ASM_DISPLAYF_CULTURE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_DISPLAY_FLAGS = 2
ASM_DISPLAYF_PUBLIC_KEY_TOKEN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_DISPLAY_FLAGS = 4
ASM_DISPLAYF_PUBLIC_KEY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_DISPLAY_FLAGS = 8
ASM_DISPLAYF_CUSTOM: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_DISPLAY_FLAGS = 16
ASM_DISPLAYF_PROCESSORARCHITECTURE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_DISPLAY_FLAGS = 32
ASM_DISPLAYF_LANGUAGEID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_DISPLAY_FLAGS = 64
ASM_NAME = Int32
ASM_NAME_PUBLIC_KEY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 0
ASM_NAME_PUBLIC_KEY_TOKEN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 1
ASM_NAME_HASH_VALUE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 2
ASM_NAME_NAME: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 3
ASM_NAME_MAJOR_VERSION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 4
ASM_NAME_MINOR_VERSION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 5
ASM_NAME_BUILD_NUMBER: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 6
ASM_NAME_REVISION_NUMBER: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 7
ASM_NAME_CULTURE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 8
ASM_NAME_PROCESSOR_ID_ARRAY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 9
ASM_NAME_OSINFO_ARRAY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 10
ASM_NAME_HASH_ALGID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 11
ASM_NAME_ALIAS: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 12
ASM_NAME_CODEBASE_URL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 13
ASM_NAME_CODEBASE_LASTMOD: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 14
ASM_NAME_NULL_PUBLIC_KEY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 15
ASM_NAME_NULL_PUBLIC_KEY_TOKEN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 16
ASM_NAME_CUSTOM: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 17
ASM_NAME_NULL_CUSTOM: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 18
ASM_NAME_MVID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 19
ASM_NAME_MAX_PARAMS: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASM_NAME = 20
class ASSEMBLY_FILE_DETAILED_INFORMATION(Structure):
    ulFlags: UInt32
    ulFilenameLength: UInt32
    ulPathLength: UInt32
    lpFileName: win32more.Windows.Win32.Foundation.PWSTR
    lpFilePath: win32more.Windows.Win32.Foundation.PWSTR
class ASSEMBLY_INFO(Structure):
    cbAssemblyInfo: UInt32
    dwAssemblyFlags: UInt32
    uliAssemblySizeInKB: UInt64
    pszCurrentAssemblyPathBuf: win32more.Windows.Win32.Foundation.PWSTR
    cchBuf: UInt32
MSIDBOPEN_READONLY: win32more.Windows.Win32.Foundation.PWSTR = 0
MSIDBOPEN_TRANSACT: win32more.Windows.Win32.Foundation.PWSTR = 1
MSIDBOPEN_DIRECT: win32more.Windows.Win32.Foundation.PWSTR = 2
MSIDBOPEN_CREATE: win32more.Windows.Win32.Foundation.PWSTR = 3
MSIDBOPEN_CREATEDIRECT: win32more.Windows.Win32.Foundation.PWSTR = 4
MSIDBOPEN_PATCHFILE: Int32 = 16
UIALL: UInt32 = 32768
LOGTOKEN_TYPE_MASK: UInt32 = 3
LOGTOKEN_UNSPECIFIED: UInt32 = 0
LOGTOKEN_NO_LOG: UInt32 = 1
LOGTOKEN_SETUPAPI_APPLOG: UInt32 = 2
LOGTOKEN_SETUPAPI_DEVLOG: UInt32 = 3
TXTLOG_SETUPAPI_DEVLOG: UInt32 = 1
TXTLOG_SETUPAPI_CMDLINE: UInt32 = 2
TXTLOG_SETUPAPI_BITS: UInt32 = 3
TXTLOG_ERROR: UInt32 = 1
TXTLOG_WARNING: UInt32 = 2
TXTLOG_SYSTEM_STATE_CHANGE: UInt32 = 3
TXTLOG_SUMMARY: UInt32 = 4
TXTLOG_DETAILS: UInt32 = 5
TXTLOG_VERBOSE: UInt32 = 6
TXTLOG_VERY_VERBOSE: UInt32 = 7
TXTLOG_RESERVED_FLAGS: UInt32 = 65520
TXTLOG_TIMESTAMP: UInt32 = 65536
TXTLOG_DEPTH_INCR: UInt32 = 131072
TXTLOG_DEPTH_DECR: UInt32 = 262144
TXTLOG_TAB_1: UInt32 = 524288
TXTLOG_FLUSH_FILE: UInt32 = 1048576
TXTLOG_DEVINST: UInt32 = 1
TXTLOG_INF: UInt32 = 2
TXTLOG_FILEQ: UInt32 = 4
TXTLOG_COPYFILES: UInt32 = 8
TXTLOG_SIGVERIF: UInt32 = 32
TXTLOG_BACKUP: UInt32 = 128
TXTLOG_UI: UInt32 = 256
TXTLOG_UTIL: UInt32 = 512
TXTLOG_INFDB: UInt32 = 1024
TXTLOG_DRVSETUP: UInt32 = 4194304
TXTLOG_POLICY: UInt32 = 8388608
TXTLOG_NEWDEV: UInt32 = 16777216
TXTLOG_UMPNPMGR: UInt32 = 33554432
TXTLOG_DRIVER_STORE: UInt32 = 67108864
TXTLOG_SETUP: UInt32 = 134217728
TXTLOG_CMI: UInt32 = 268435456
TXTLOG_DEVMGR: UInt32 = 536870912
TXTLOG_INSTALLER: UInt32 = 1073741824
TXTLOG_VENDOR: UInt32 = 2147483648
CLSID_EvalCom2: Guid = Guid('{6e5e1910-8053-4660-b795-6b612e29bc58}')
_WIN32_MSM: UInt32 = 100
LIBID_MsmMergeTypeLib: Guid = Guid('{0adda82f-2c26-11d2-ad65-00a0c9af11a6}')
CLSID_MsmMerge2: Guid = Guid('{f94985d5-29f9-4743-9805-99bc3f35b678}')
_WIN32_MSI: UInt32 = 500
MAX_GUID_CHARS: UInt32 = 38
MAX_FEATURE_CHARS: UInt32 = 38
INSTALLPROPERTY_PACKAGENAME: String = 'PackageName'
INSTALLPROPERTY_TRANSFORMS: String = 'Transforms'
INSTALLPROPERTY_LANGUAGE: String = 'Language'
INSTALLPROPERTY_PRODUCTNAME: String = 'ProductName'
INSTALLPROPERTY_ASSIGNMENTTYPE: String = 'AssignmentType'
INSTALLPROPERTY_INSTANCETYPE: String = 'InstanceType'
INSTALLPROPERTY_AUTHORIZED_LUA_APP: String = 'AuthorizedLUAApp'
INSTALLPROPERTY_PACKAGECODE: String = 'PackageCode'
INSTALLPROPERTY_VERSION: String = 'Version'
INSTALLPROPERTY_PRODUCTICON: String = 'ProductIcon'
INSTALLPROPERTY_INSTALLEDPRODUCTNAME: String = 'InstalledProductName'
INSTALLPROPERTY_VERSIONSTRING: String = 'VersionString'
INSTALLPROPERTY_HELPLINK: String = 'HelpLink'
INSTALLPROPERTY_HELPTELEPHONE: String = 'HelpTelephone'
INSTALLPROPERTY_INSTALLLOCATION: String = 'InstallLocation'
INSTALLPROPERTY_INSTALLSOURCE: String = 'InstallSource'
INSTALLPROPERTY_INSTALLDATE: String = 'InstallDate'
INSTALLPROPERTY_PUBLISHER: String = 'Publisher'
INSTALLPROPERTY_LOCALPACKAGE: String = 'LocalPackage'
INSTALLPROPERTY_URLINFOABOUT: String = 'URLInfoAbout'
INSTALLPROPERTY_URLUPDATEINFO: String = 'URLUpdateInfo'
INSTALLPROPERTY_VERSIONMINOR: String = 'VersionMinor'
INSTALLPROPERTY_VERSIONMAJOR: String = 'VersionMajor'
INSTALLPROPERTY_PRODUCTID: String = 'ProductID'
INSTALLPROPERTY_REGCOMPANY: String = 'RegCompany'
INSTALLPROPERTY_REGOWNER: String = 'RegOwner'
INSTALLPROPERTY_INSTALLEDLANGUAGE: String = 'InstalledLanguage'
INSTALLPROPERTY_UNINSTALLABLE: String = 'Uninstallable'
INSTALLPROPERTY_PRODUCTSTATE: String = 'State'
INSTALLPROPERTY_PATCHSTATE: String = 'State'
INSTALLPROPERTY_PATCHTYPE: String = 'PatchType'
INSTALLPROPERTY_LUAENABLED: String = 'LUAEnabled'
INSTALLPROPERTY_DISPLAYNAME: String = 'DisplayName'
INSTALLPROPERTY_MOREINFOURL: String = 'MoreInfoURL'
INSTALLPROPERTY_LASTUSEDSOURCE: String = 'LastUsedSource'
INSTALLPROPERTY_LASTUSEDTYPE: String = 'LastUsedType'
INSTALLPROPERTY_MEDIAPACKAGEPATH: String = 'MediaPackagePath'
INSTALLPROPERTY_DISKPROMPT: String = 'DiskPrompt'
MSI_INVALID_HASH_IS_FATAL: UInt32 = 1
ERROR_ROLLBACK_DISABLED: UInt32 = 1653
MSI_NULL_INTEGER: UInt32 = 2147483648
INSTALLMESSAGE_TYPEMASK: Int32 = -16777216
STREAM_FORMAT_COMPLIB_MODULE: UInt32 = 0
STREAM_FORMAT_COMPLIB_MANIFEST: UInt32 = 1
STREAM_FORMAT_WIN32_MODULE: UInt32 = 2
STREAM_FORMAT_WIN32_MANIFEST: UInt32 = 4
IASSEMBLYCACHEITEM_COMMIT_FLAG_REFRESH: UInt32 = 1
ASSEMBLYINFO_FLAG_INSTALLED: UInt32 = 1
ASSEMBLYINFO_FLAG_PAYLOADRESIDENT: UInt32 = 2
IASSEMBLYCACHEITEM_COMMIT_DISPOSITION_INSTALLED: UInt32 = 1
IASSEMBLYCACHEITEM_COMMIT_DISPOSITION_REFRESHED: UInt32 = 2
IASSEMBLYCACHEITEM_COMMIT_DISPOSITION_ALREADY_INSTALLED: UInt32 = 3
FUSION_REFCOUNT_UNINSTALL_SUBKEY_GUID: Guid = Guid('{8cedc215-ac4b-488b-93c0-a50a49cb2fb8}')
FUSION_REFCOUNT_FILEPATH_GUID: Guid = Guid('{b02f9d65-fb77-4f7a-afa5-b391309f11c9}')
FUSION_REFCOUNT_OPAQUE_STRING_GUID: Guid = Guid('{2ec93463-b0c3-45e1-8364-327e96aea856}')
SFC_DISABLE_NORMAL: UInt32 = 0
SFC_DISABLE_ASK: UInt32 = 1
SFC_DISABLE_ONCE: UInt32 = 2
SFC_DISABLE_SETUP: UInt32 = 3
SFC_DISABLE_NOPOPUPS: UInt32 = 4
SFC_SCAN_NORMAL: UInt32 = 0
SFC_SCAN_ALWAYS: UInt32 = 1
SFC_SCAN_ONCE: UInt32 = 2
SFC_SCAN_IMMEDIATE: UInt32 = 3
SFC_QUOTA_DEFAULT: UInt32 = 50
SFC_IDLE_TRIGGER: String = 'WFP_IDLE_TRIGGER'
IPROPNAME_PRODUCTNAME: String = 'ProductName'
IPROPNAME_PRODUCTCODE: String = 'ProductCode'
IPROPNAME_PRODUCTVERSION: String = 'ProductVersion'
IPROPNAME_INSTALLLANGUAGE: String = 'ProductLanguage'
IPROPNAME_MANUFACTURER: String = 'Manufacturer'
IPROPNAME_UPGRADECODE: String = 'UpgradeCode'
IPROPNAME_PIDTEMPLATE: String = 'PIDTemplate'
IPROPNAME_DISKPROMPT: String = 'DiskPrompt'
IPROPNAME_LEFTUNIT: String = 'LeftUnit'
IPROPNAME_ADMIN_PROPERTIES: String = 'AdminProperties'
IPROPNAME_DEFAULTUIFONT: String = 'DefaultUIFont'
IPROPNAME_ALLOWEDPROPERTIES: String = 'SecureCustomProperties'
IPROPNAME_ENABLEUSERCONTROL: String = 'EnableUserControl'
IPROPNAME_HIDDEN_PROPERTIES: String = 'MsiHiddenProperties'
IPROPNAME_USERNAME: String = 'USERNAME'
IPROPNAME_COMPANYNAME: String = 'COMPANYNAME'
IPROPNAME_PIDKEY: String = 'PIDKEY'
IPROPNAME_PATCH: String = 'PATCH'
IPROPNAME_MSIPATCHREMOVE: String = 'MSIPATCHREMOVE'
IPROPNAME_TARGETDIR: String = 'TARGETDIR'
IPROPNAME_ACTION: String = 'ACTION'
IPROPNAME_LIMITUI: String = 'LIMITUI'
IPROPNAME_LOGACTION: String = 'LOGACTION'
IPROPNAME_ALLUSERS: String = 'ALLUSERS'
IPROPNAME_INSTALLLEVEL: String = 'INSTALLLEVEL'
IPROPNAME_REBOOT: String = 'REBOOT'
IPROPNAME_REBOOTPROMPT: String = 'REBOOTPROMPT'
IPROPNAME_EXECUTEMODE: String = 'EXECUTEMODE'
IPROPVALUE_EXECUTEMODE_NONE: String = 'NONE'
IPROPVALUE_EXECUTEMODE_SCRIPT: String = 'SCRIPT'
IPROPNAME_EXECUTEACTION: String = 'EXECUTEACTION'
IPROPNAME_SOURCELIST: String = 'SOURCELIST'
IPROPNAME_ROOTDRIVE: String = 'ROOTDRIVE'
IPROPNAME_TRANSFORMS: String = 'TRANSFORMS'
IPROPNAME_TRANSFORMSATSOURCE: String = 'TRANSFORMSATSOURCE'
IPROPNAME_TRANSFORMSSECURE: String = 'TRANSFORMSSECURE'
IPROPNAME_SEQUENCE: String = 'SEQUENCE'
IPROPNAME_SHORTFILENAMES: String = 'SHORTFILENAMES'
IPROPNAME_PRIMARYFOLDER: String = 'PRIMARYFOLDER'
IPROPNAME_AFTERREBOOT: String = 'AFTERREBOOT'
IPROPNAME_NOCOMPANYNAME: String = 'NOCOMPANYNAME'
IPROPNAME_NOUSERNAME: String = 'NOUSERNAME'
IPROPNAME_DISABLEROLLBACK: String = 'DISABLEROLLBACK'
IPROPNAME_AVAILABLEFREEREG: String = 'AVAILABLEFREEREG'
IPROPNAME_DISABLEADVTSHORTCUTS: String = 'DISABLEADVTSHORTCUTS'
IPROPNAME_PATCHNEWPACKAGECODE: String = 'PATCHNEWPACKAGECODE'
IPROPNAME_PATCHNEWSUMMARYSUBJECT: String = 'PATCHNEWSUMMARYSUBJECT'
IPROPNAME_PATCHNEWSUMMARYCOMMENTS: String = 'PATCHNEWSUMMARYCOMMENTS'
IPROPNAME_PRODUCTLANGUAGE: String = 'PRODUCTLANGUAGE'
IPROPNAME_CHECKCRCS: String = 'MSICHECKCRCS'
IPROPNAME_MSINODISABLEMEDIA: String = 'MSINODISABLEMEDIA'
IPROPNAME_CARRYINGNDP: String = 'CARRYINGNDP'
IPROPVALUE__CARRYINGNDP_URTREINSTALL: String = 'URTREINSTALL'
IPROPVALUE__CARRYINGNDP_URTUPGRADE: String = 'URTUPGRADE'
IPROPNAME_ENFORCE_UPGRADE_COMPONENT_RULES: String = 'MSIENFORCEUPGRADECOMPONENTRULES'
IPROPNAME_MSINEWINSTANCE: String = 'MSINEWINSTANCE'
IPROPNAME_MSIINSTANCEGUID: String = 'MSIINSTANCEGUID'
IPROPNAME_MSIPACKAGEDOWNLOADLOCALCOPY: String = 'MSIPACKAGEDOWNLOADLOCALCOPY'
IPROPNAME_MSIPATCHDOWNLOADLOCALCOPY: String = 'MSIPATCHDOWNLOADLOCALCOPY'
IPROPNAME_MSIDISABLELUAPATCHING: String = 'MSIDISABLELUAPATCHING'
IPROPNAME_MSILOGGINGMODE: String = 'MsiLogging'
IPROPNAME_MSILOGFILELOCATION: String = 'MsiLogFileLocation'
IPROPNAME_MSI_RM_CONTROL: String = 'MSIRESTARTMANAGERCONTROL'
IPROPVALUE_MSI_RM_CONTROL_DISABLE: String = 'Disable'
IPROPVALUE_MSI_RM_CONTROL_DISABLESHUTDOWN: String = 'DisableShutdown'
IPROPNAME_MSI_RM_SESSION_KEY: String = 'MsiRestartManagerSessionKey'
IPROPNAME_MSI_REBOOT_PENDING: String = 'MsiSystemRebootPending'
IPROPNAME_MSI_RM_SHUTDOWN: String = 'MSIRMSHUTDOWN'
IPROPNAME_MSI_RM_DISABLE_RESTART: String = 'MSIDISABLERMRESTART'
IPROPNAME_MSI_UAC_DEPLOYMENT_COMPLIANT: String = 'MSIDEPLOYMENTCOMPLIANT'
IPROPNAME_MSI_USE_REAL_ADMIN_DETECTION: String = 'MSIUSEREALADMINDETECTION'
IPROPNAME_MSI_UNINSTALL_SUPERSEDED_COMPONENTS: String = 'MSIUNINSTALLSUPERSEDEDCOMPONENTS'
IPROPNAME_MSIDISABLEEEUI: String = 'MSIDISABLEEEUI'
IPROPNAME_MSI_FASTINSTALL: String = 'MSIFASTINSTALL'
IPROPNAME_INSTALLPERUSER: String = 'MSIINSTALLPERUSER'
IPROPNAME_INTERNALINSTALLEDPERUSER: String = 'MSIINTERNALINSTALLEDPERUSER'
IPROPNAME_ARPAUTHORIZEDCDFPREFIX: String = 'ARPAUTHORIZEDCDFPREFIX'
IPROPNAME_ARPCOMMENTS: String = 'ARPCOMMENTS'
IPROPNAME_ARPCONTACT: String = 'ARPCONTACT'
IPROPNAME_ARPHELPLINK: String = 'ARPHELPLINK'
IPROPNAME_ARPHELPTELEPHONE: String = 'ARPHELPTELEPHONE'
IPROPNAME_ARPINSTALLLOCATION: String = 'ARPINSTALLLOCATION'
IPROPNAME_ARPNOMODIFY: String = 'ARPNOMODIFY'
IPROPNAME_ARPNOREMOVE: String = 'ARPNOREMOVE'
IPROPNAME_ARPNOREPAIR: String = 'ARPNOREPAIR'
IPROPNAME_ARPREADME: String = 'ARPREADME'
IPROPNAME_ARPSIZE: String = 'ARPSIZE'
IPROPNAME_ARPSYSTEMCOMPONENT: String = 'ARPSYSTEMCOMPONENT'
IPROPNAME_ARPURLINFOABOUT: String = 'ARPURLINFOABOUT'
IPROPNAME_ARPURLUPDATEINFO: String = 'ARPURLUPDATEINFO'
IPROPNAME_ARPPRODUCTICON: String = 'ARPPRODUCTICON'
IPROPNAME_ARPSETTINGSIDENTIFIER: String = 'MSIARPSETTINGSIDENTIFIER'
IPROPNAME_ARPSHIMFLAGS: String = 'SHIMFLAGS'
IPROPNAME_ARPSHIMVERSIONNT: String = 'SHIMVERSIONNT'
IPROPNAME_ARPSHIMSERVICEPACKLEVEL: String = 'SHIMSERVICEPACKLEVEL'
IPROPNAME_INSTALLED: String = 'Installed'
IPROPNAME_PRODUCTSTATE: String = 'ProductState'
IPROPNAME_PRESELECTED: String = 'Preselected'
IPROPNAME_RESUME: String = 'RESUME'
IPROPNAME_UPDATESTARTED: String = 'UpdateStarted'
IPROPNAME_PRODUCTID: String = 'ProductID'
IPROPNAME_OUTOFDISKSPACE: String = 'OutOfDiskSpace'
IPROPNAME_OUTOFNORBDISKSPACE: String = 'OutOfNoRbDiskSpace'
IPROPNAME_COSTINGCOMPLETE: String = 'CostingComplete'
IPROPNAME_SOURCEDIR: String = 'SourceDir'
IPROPNAME_REPLACEDINUSEFILES: String = 'ReplacedInUseFiles'
IPROPNAME_PRIMARYFOLDER_PATH: String = 'PrimaryVolumePath'
IPROPNAME_PRIMARYFOLDER_SPACEAVAILABLE: String = 'PrimaryVolumeSpaceAvailable'
IPROPNAME_PRIMARYFOLDER_SPACEREQUIRED: String = 'PrimaryVolumeSpaceRequired'
IPROPNAME_PRIMARYFOLDER_SPACEREMAINING: String = 'PrimaryVolumeSpaceRemaining'
IPROPNAME_ISADMINPACKAGE: String = 'IsAdminPackage'
IPROPNAME_ROLLBACKDISABLED: String = 'RollbackDisabled'
IPROPNAME_RESTRICTEDUSERCONTROL: String = 'RestrictedUserControl'
IPROPNAME_SOURCERESONLY: String = 'MsiUISourceResOnly'
IPROPNAME_HIDECANCEL: String = 'MsiUIHideCancel'
IPROPNAME_PROGRESSONLY: String = 'MsiUIProgressOnly'
IPROPNAME_UACONLY: String = 'MsiUIUACOnly'
IPROPNAME_TIME: String = 'Time'
IPROPNAME_DATE: String = 'Date'
IPROPNAME_DATETIME: String = 'DateTime'
IPROPNAME_ARM: String = 'Arm'
IPROPNAME_ARM64: String = 'Arm64'
IPROPNAME_INTEL: String = 'Intel'
IPROPNAME_TEMPLATE_AMD64: String = 'AMD64'
IPROPNAME_TEMPLATE_X64: String = 'x64'
IPROPNAME_MSIAMD64: String = 'MsiAMD64'
IPROPNAME_MSIX64: String = 'Msix64'
IPROPNAME_INTEL64: String = 'Intel64'
IPROPNAME_IA64: String = 'IA64'
IPROPNAME_TEXTHEIGHT: String = 'TextHeight'
IPROPNAME_TEXTINTERNALLEADING: String = 'TextInternalLeading'
IPROPNAME_SCREENX: String = 'ScreenX'
IPROPNAME_SCREENY: String = 'ScreenY'
IPROPNAME_CAPTIONHEIGHT: String = 'CaptionHeight'
IPROPNAME_BORDERTOP: String = 'BorderTop'
IPROPNAME_BORDERSIDE: String = 'BorderSide'
IPROPNAME_COLORBITS: String = 'ColorBits'
IPROPNAME_PHYSICALMEMORY: String = 'PhysicalMemory'
IPROPNAME_VIRTUALMEMORY: String = 'VirtualMemory'
IPROPNAME_TEXTHEIGHT_CORRECTION: String = 'TextHeightCorrection'
IPROPNAME_MSITABLETPC: String = 'MsiTabletPC'
IPROPNAME_VERSIONNT: String = 'VersionNT'
IPROPNAME_VERSION9X: String = 'Version9X'
IPROPNAME_VERSIONNT64: String = 'VersionNT64'
IPROPNAME_WINDOWSBUILD: String = 'WindowsBuild'
IPROPNAME_SERVICEPACKLEVEL: String = 'ServicePackLevel'
IPROPNAME_SERVICEPACKLEVELMINOR: String = 'ServicePackLevelMinor'
IPROPNAME_SHAREDWINDOWS: String = 'SharedWindows'
IPROPNAME_COMPUTERNAME: String = 'ComputerName'
IPROPNAME_SHELLADVTSUPPORT: String = 'ShellAdvtSupport'
IPROPNAME_OLEADVTSUPPORT: String = 'OLEAdvtSupport'
IPROPNAME_SYSTEMLANGUAGEID: String = 'SystemLanguageID'
IPROPNAME_TTCSUPPORT: String = 'TTCSupport'
IPROPNAME_TERMSERVER: String = 'TerminalServer'
IPROPNAME_REMOTEADMINTS: String = 'RemoteAdminTS'
IPROPNAME_REDIRECTEDDLLSUPPORT: String = 'RedirectedDllSupport'
IPROPNAME_NTPRODUCTTYPE: String = 'MsiNTProductType'
IPROPNAME_NTSUITEBACKOFFICE: String = 'MsiNTSuiteBackOffice'
IPROPNAME_NTSUITEDATACENTER: String = 'MsiNTSuiteDataCenter'
IPROPNAME_NTSUITEENTERPRISE: String = 'MsiNTSuiteEnterprise'
IPROPNAME_NTSUITESMALLBUSINESS: String = 'MsiNTSuiteSmallBusiness'
IPROPNAME_NTSUITESMALLBUSINESSRESTRICTED: String = 'MsiNTSuiteSmallBusinessRestricted'
IPROPNAME_NTSUITEPERSONAL: String = 'MsiNTSuitePersonal'
IPROPNAME_NTSUITEWEBSERVER: String = 'MsiNTSuiteWebServer'
IPROPNAME_NETASSEMBLYSUPPORT: String = 'MsiNetAssemblySupport'
IPROPNAME_WIN32ASSEMBLYSUPPORT: String = 'MsiWin32AssemblySupport'
IPROPNAME_LOGONUSER: String = 'LogonUser'
IPROPNAME_USERSID: String = 'UserSID'
IPROPNAME_ADMINUSER: String = 'AdminUser'
IPROPNAME_USERLANGUAGEID: String = 'UserLanguageID'
IPROPNAME_PRIVILEGED: String = 'Privileged'
IPROPNAME_RUNNINGELEVATED: String = 'MsiRunningElevated'
IPROPNAME_TRUEADMINUSER: String = 'MsiTrueAdminUser'
IPROPNAME_WINDOWS_FOLDER: String = 'WindowsFolder'
IPROPNAME_SYSTEM_FOLDER: String = 'SystemFolder'
IPROPNAME_SYSTEM16_FOLDER: String = 'System16Folder'
IPROPNAME_WINDOWS_VOLUME: String = 'WindowsVolume'
IPROPNAME_TEMP_FOLDER: String = 'TempFolder'
IPROPNAME_PROGRAMFILES_FOLDER: String = 'ProgramFilesFolder'
IPROPNAME_COMMONFILES_FOLDER: String = 'CommonFilesFolder'
IPROPNAME_SYSTEM64_FOLDER: String = 'System64Folder'
IPROPNAME_PROGRAMFILES64_FOLDER: String = 'ProgramFiles64Folder'
IPROPNAME_COMMONFILES64_FOLDER: String = 'CommonFiles64Folder'
IPROPNAME_STARTMENU_FOLDER: String = 'StartMenuFolder'
IPROPNAME_PROGRAMMENU_FOLDER: String = 'ProgramMenuFolder'
IPROPNAME_STARTUP_FOLDER: String = 'StartupFolder'
IPROPNAME_NETHOOD_FOLDER: String = 'NetHoodFolder'
IPROPNAME_PERSONAL_FOLDER: String = 'PersonalFolder'
IPROPNAME_SENDTO_FOLDER: String = 'SendToFolder'
IPROPNAME_DESKTOP_FOLDER: String = 'DesktopFolder'
IPROPNAME_TEMPLATE_FOLDER: String = 'TemplateFolder'
IPROPNAME_FONTS_FOLDER: String = 'FontsFolder'
IPROPNAME_FAVORITES_FOLDER: String = 'FavoritesFolder'
IPROPNAME_RECENT_FOLDER: String = 'RecentFolder'
IPROPNAME_APPDATA_FOLDER: String = 'AppDataFolder'
IPROPNAME_PRINTHOOD_FOLDER: String = 'PrintHoodFolder'
IPROPNAME_ADMINTOOLS_FOLDER: String = 'AdminToolsFolder'
IPROPNAME_COMMONAPPDATA_FOLDER: String = 'CommonAppDataFolder'
IPROPNAME_LOCALAPPDATA_FOLDER: String = 'LocalAppDataFolder'
IPROPNAME_MYPICTURES_FOLDER: String = 'MyPicturesFolder'
IPROPNAME_FEATUREADDLOCAL: String = 'ADDLOCAL'
IPROPNAME_FEATUREADDSOURCE: String = 'ADDSOURCE'
IPROPNAME_FEATUREADDDEFAULT: String = 'ADDDEFAULT'
IPROPNAME_FEATUREREMOVE: String = 'REMOVE'
IPROPNAME_FEATUREADVERTISE: String = 'ADVERTISE'
IPROPVALUE_FEATURE_ALL: String = 'ALL'
IPROPNAME_COMPONENTADDLOCAL: String = 'COMPADDLOCAL'
IPROPNAME_COMPONENTADDSOURCE: String = 'COMPADDSOURCE'
IPROPNAME_COMPONENTADDDEFAULT: String = 'COMPADDDEFAULT'
IPROPNAME_FILEADDLOCAL: String = 'FILEADDLOCAL'
IPROPNAME_FILEADDSOURCE: String = 'FILEADDSOURCE'
IPROPNAME_FILEADDDEFAULT: String = 'FILEADDDEFAULT'
IPROPNAME_REINSTALL: String = 'REINSTALL'
IPROPNAME_REINSTALLMODE: String = 'REINSTALLMODE'
IPROPNAME_PROMPTROLLBACKCOST: String = 'PROMPTROLLBACKCOST'
IPROPVALUE_RBCOST_PROMPT: String = 'P'
IPROPVALUE_RBCOST_SILENT: String = 'D'
IPROPVALUE_RBCOST_FAIL: String = 'F'
IPROPNAME_CUSTOMACTIONDATA: String = 'CustomActionData'
IACTIONNAME_INSTALL: String = 'INSTALL'
IACTIONNAME_ADVERTISE: String = 'ADVERTISE'
IACTIONNAME_ADMIN: String = 'ADMIN'
IACTIONNAME_SEQUENCE: String = 'SEQUENCE'
IACTIONNAME_COLLECTUSERINFO: String = 'CollectUserInfo'
IACTIONNAME_FIRSTRUN: String = 'FirstRun'
PID_TITLE: UInt32 = 2
PID_SUBJECT: UInt32 = 3
PID_AUTHOR: UInt32 = 4
PID_KEYWORDS: UInt32 = 5
PID_COMMENTS: UInt32 = 6
PID_TEMPLATE: UInt32 = 7
PID_LASTAUTHOR: UInt32 = 8
PID_REVNUMBER: UInt32 = 9
PID_EDITTIME: UInt32 = 10
PID_LASTPRINTED: UInt32 = 11
PID_CREATE_DTM: UInt32 = 12
PID_LASTSAVE_DTM: UInt32 = 13
PID_PAGECOUNT: UInt32 = 14
PID_WORDCOUNT: UInt32 = 15
PID_CHARCOUNT: UInt32 = 16
PID_THUMBNAIL: UInt32 = 17
PID_APPNAME: UInt32 = 18
PID_MSIVERSION: UInt32 = 14
PID_MSISOURCE: UInt32 = 15
PID_MSIRESTRICT: UInt32 = 16
PATCH_OPTION_USE_BEST: UInt32 = 0
PATCH_OPTION_USE_LZX_BEST: UInt32 = 3
PATCH_OPTION_USE_LZX_A: UInt32 = 1
PATCH_OPTION_USE_LZX_B: UInt32 = 2
PATCH_OPTION_USE_LZX_LARGE: UInt32 = 4
PATCH_OPTION_NO_BINDFIX: UInt32 = 65536
PATCH_OPTION_NO_LOCKFIX: UInt32 = 131072
PATCH_OPTION_NO_REBASE: UInt32 = 262144
PATCH_OPTION_FAIL_IF_SAME_FILE: UInt32 = 524288
PATCH_OPTION_FAIL_IF_BIGGER: UInt32 = 1048576
PATCH_OPTION_NO_CHECKSUM: UInt32 = 2097152
PATCH_OPTION_NO_RESTIMEFIX: UInt32 = 4194304
PATCH_OPTION_NO_TIMESTAMP: UInt32 = 8388608
PATCH_OPTION_SIGNATURE_MD5: UInt32 = 16777216
PATCH_OPTION_INTERLEAVE_FILES: UInt32 = 1073741824
PATCH_OPTION_RESERVED1: UInt32 = 2147483648
PATCH_OPTION_VALID_FLAGS: UInt32 = 3237937159
PATCH_SYMBOL_NO_IMAGEHLP: UInt32 = 1
PATCH_SYMBOL_NO_FAILURES: UInt32 = 2
PATCH_SYMBOL_UNDECORATED_TOO: UInt32 = 4
PATCH_SYMBOL_RESERVED1: UInt32 = 2147483648
PATCH_TRANSFORM_PE_RESOURCE_2: UInt32 = 256
PATCH_TRANSFORM_PE_IRELOC_2: UInt32 = 512
APPLY_OPTION_FAIL_IF_EXACT: UInt32 = 1
APPLY_OPTION_FAIL_IF_CLOSE: UInt32 = 2
APPLY_OPTION_TEST_ONLY: UInt32 = 4
APPLY_OPTION_VALID_FLAGS: UInt32 = 7
ERROR_PATCH_ENCODE_FAILURE: UInt32 = 3222155521
ERROR_PATCH_INVALID_OPTIONS: UInt32 = 3222155522
ERROR_PATCH_SAME_FILE: UInt32 = 3222155523
ERROR_PATCH_RETAIN_RANGES_DIFFER: UInt32 = 3222155524
ERROR_PATCH_BIGGER_THAN_COMPRESSED: UInt32 = 3222155525
ERROR_PATCH_IMAGEHLP_FAILURE: UInt32 = 3222155526
ERROR_PATCH_DECODE_FAILURE: UInt32 = 3222159617
ERROR_PATCH_CORRUPT: UInt32 = 3222159618
ERROR_PATCH_NEWER_FORMAT: UInt32 = 3222159619
ERROR_PATCH_WRONG_FILE: UInt32 = 3222159620
ERROR_PATCH_NOT_NECESSARY: UInt32 = 3222159621
ERROR_PATCH_NOT_AVAILABLE: UInt32 = 3222159622
ERROR_PCW_BASE: UInt32 = 3222163713
ERROR_PCW_PCP_DOESNT_EXIST: UInt32 = 3222163713
ERROR_PCW_PCP_BAD_FORMAT: UInt32 = 3222163714
ERROR_PCW_CANT_CREATE_TEMP_FOLDER: UInt32 = 3222163715
ERROR_PCW_MISSING_PATCH_PATH: UInt32 = 3222163716
ERROR_PCW_CANT_OVERWRITE_PATCH: UInt32 = 3222163717
ERROR_PCW_CANT_CREATE_PATCH_FILE: UInt32 = 3222163718
ERROR_PCW_MISSING_PATCH_GUID: UInt32 = 3222163719
ERROR_PCW_BAD_PATCH_GUID: UInt32 = 3222163720
ERROR_PCW_BAD_GUIDS_TO_REPLACE: UInt32 = 3222163721
ERROR_PCW_BAD_TARGET_PRODUCT_CODE_LIST: UInt32 = 3222163722
ERROR_PCW_NO_UPGRADED_IMAGES_TO_PATCH: UInt32 = 3222163723
ERROR_PCW_BAD_API_PATCHING_SYMBOL_FLAGS: UInt32 = 3222163725
ERROR_PCW_OODS_COPYING_MSI: UInt32 = 3222163726
ERROR_PCW_UPGRADED_IMAGE_NAME_TOO_LONG: UInt32 = 3222163727
ERROR_PCW_BAD_UPGRADED_IMAGE_NAME: UInt32 = 3222163728
ERROR_PCW_DUP_UPGRADED_IMAGE_NAME: UInt32 = 3222163729
ERROR_PCW_UPGRADED_IMAGE_PATH_TOO_LONG: UInt32 = 3222163730
ERROR_PCW_UPGRADED_IMAGE_PATH_EMPTY: UInt32 = 3222163731
ERROR_PCW_UPGRADED_IMAGE_PATH_NOT_EXIST: UInt32 = 3222163732
ERROR_PCW_UPGRADED_IMAGE_PATH_NOT_MSI: UInt32 = 3222163733
ERROR_PCW_UPGRADED_IMAGE_COMPRESSED: UInt32 = 3222163734
ERROR_PCW_TARGET_IMAGE_NAME_TOO_LONG: UInt32 = 3222163735
ERROR_PCW_BAD_TARGET_IMAGE_NAME: UInt32 = 3222163736
ERROR_PCW_DUP_TARGET_IMAGE_NAME: UInt32 = 3222163737
ERROR_PCW_TARGET_IMAGE_PATH_TOO_LONG: UInt32 = 3222163738
ERROR_PCW_TARGET_IMAGE_PATH_EMPTY: UInt32 = 3222163739
ERROR_PCW_TARGET_IMAGE_PATH_NOT_EXIST: UInt32 = 3222163740
ERROR_PCW_TARGET_IMAGE_PATH_NOT_MSI: UInt32 = 3222163741
ERROR_PCW_TARGET_IMAGE_COMPRESSED: UInt32 = 3222163742
ERROR_PCW_TARGET_BAD_PROD_VALIDATE: UInt32 = 3222163743
ERROR_PCW_TARGET_BAD_PROD_CODE_VAL: UInt32 = 3222163744
ERROR_PCW_UPGRADED_MISSING_SRC_FILES: UInt32 = 3222163745
ERROR_PCW_TARGET_MISSING_SRC_FILES: UInt32 = 3222163746
ERROR_PCW_IMAGE_FAMILY_NAME_TOO_LONG: UInt32 = 3222163747
ERROR_PCW_BAD_IMAGE_FAMILY_NAME: UInt32 = 3222163748
ERROR_PCW_DUP_IMAGE_FAMILY_NAME: UInt32 = 3222163749
ERROR_PCW_BAD_IMAGE_FAMILY_SRC_PROP: UInt32 = 3222163750
ERROR_PCW_UFILEDATA_LONG_FILE_TABLE_KEY: UInt32 = 3222163751
ERROR_PCW_UFILEDATA_BLANK_FILE_TABLE_KEY: UInt32 = 3222163752
ERROR_PCW_UFILEDATA_MISSING_FILE_TABLE_KEY: UInt32 = 3222163753
ERROR_PCW_EXTFILE_LONG_FILE_TABLE_KEY: UInt32 = 3222163754
ERROR_PCW_EXTFILE_BLANK_FILE_TABLE_KEY: UInt32 = 3222163755
ERROR_PCW_EXTFILE_BAD_FAMILY_FIELD: UInt32 = 3222163756
ERROR_PCW_EXTFILE_LONG_PATH_TO_FILE: UInt32 = 3222163757
ERROR_PCW_EXTFILE_BLANK_PATH_TO_FILE: UInt32 = 3222163758
ERROR_PCW_EXTFILE_MISSING_FILE: UInt32 = 3222163759
ERROR_PCW_BAD_FILE_SEQUENCE_START: UInt32 = 3222163770
ERROR_PCW_CANT_COPY_FILE_TO_TEMP_FOLDER: UInt32 = 3222163771
ERROR_PCW_CANT_CREATE_ONE_PATCH_FILE: UInt32 = 3222163772
ERROR_PCW_BAD_IMAGE_FAMILY_DISKID: UInt32 = 3222163773
ERROR_PCW_BAD_IMAGE_FAMILY_FILESEQSTART: UInt32 = 3222163774
ERROR_PCW_BAD_UPGRADED_IMAGE_FAMILY: UInt32 = 3222163775
ERROR_PCW_BAD_TARGET_IMAGE_UPGRADED: UInt32 = 3222163776
ERROR_PCW_DUP_TARGET_IMAGE_PACKCODE: UInt32 = 3222163777
ERROR_PCW_UFILEDATA_BAD_UPGRADED_FIELD: UInt32 = 3222163778
ERROR_PCW_MISMATCHED_PRODUCT_CODES: UInt32 = 3222163779
ERROR_PCW_MISMATCHED_PRODUCT_VERSIONS: UInt32 = 3222163780
ERROR_PCW_CANNOT_WRITE_DDF: UInt32 = 3222163781
ERROR_PCW_CANNOT_RUN_MAKECAB: UInt32 = 3222163782
ERROR_PCW_WRITE_SUMMARY_PROPERTIES: UInt32 = 3222163787
ERROR_PCW_TFILEDATA_LONG_FILE_TABLE_KEY: UInt32 = 3222163788
ERROR_PCW_TFILEDATA_BLANK_FILE_TABLE_KEY: UInt32 = 3222163789
ERROR_PCW_TFILEDATA_MISSING_FILE_TABLE_KEY: UInt32 = 3222163790
ERROR_PCW_TFILEDATA_BAD_TARGET_FIELD: UInt32 = 3222163791
ERROR_PCW_UPGRADED_IMAGE_PATCH_PATH_TOO_LONG: UInt32 = 3222163792
ERROR_PCW_UPGRADED_IMAGE_PATCH_PATH_NOT_EXIST: UInt32 = 3222163793
ERROR_PCW_UPGRADED_IMAGE_PATCH_PATH_NOT_MSI: UInt32 = 3222163794
ERROR_PCW_DUP_UPGRADED_IMAGE_PACKCODE: UInt32 = 3222163795
ERROR_PCW_UFILEIGNORE_BAD_UPGRADED_FIELD: UInt32 = 3222163796
ERROR_PCW_UFILEIGNORE_LONG_FILE_TABLE_KEY: UInt32 = 3222163797
ERROR_PCW_UFILEIGNORE_BLANK_FILE_TABLE_KEY: UInt32 = 3222163798
ERROR_PCW_UFILEIGNORE_BAD_FILE_TABLE_KEY: UInt32 = 3222163799
ERROR_PCW_FAMILY_RANGE_NAME_TOO_LONG: UInt32 = 3222163800
ERROR_PCW_BAD_FAMILY_RANGE_NAME: UInt32 = 3222163801
ERROR_PCW_FAMILY_RANGE_LONG_FILE_TABLE_KEY: UInt32 = 3222163802
ERROR_PCW_FAMILY_RANGE_BLANK_FILE_TABLE_KEY: UInt32 = 3222163803
ERROR_PCW_FAMILY_RANGE_LONG_RETAIN_OFFSETS: UInt32 = 3222163804
ERROR_PCW_FAMILY_RANGE_BLANK_RETAIN_OFFSETS: UInt32 = 3222163805
ERROR_PCW_FAMILY_RANGE_BAD_RETAIN_OFFSETS: UInt32 = 3222163806
ERROR_PCW_FAMILY_RANGE_LONG_RETAIN_LENGTHS: UInt32 = 3222163807
ERROR_PCW_FAMILY_RANGE_BLANK_RETAIN_LENGTHS: UInt32 = 3222163808
ERROR_PCW_FAMILY_RANGE_BAD_RETAIN_LENGTHS: UInt32 = 3222163809
ERROR_PCW_FAMILY_RANGE_COUNT_MISMATCH: UInt32 = 3222163810
ERROR_PCW_EXTFILE_LONG_IGNORE_OFFSETS: UInt32 = 3222163811
ERROR_PCW_EXTFILE_BAD_IGNORE_OFFSETS: UInt32 = 3222163812
ERROR_PCW_EXTFILE_LONG_IGNORE_LENGTHS: UInt32 = 3222163813
ERROR_PCW_EXTFILE_BAD_IGNORE_LENGTHS: UInt32 = 3222163814
ERROR_PCW_EXTFILE_IGNORE_COUNT_MISMATCH: UInt32 = 3222163815
ERROR_PCW_EXTFILE_LONG_RETAIN_OFFSETS: UInt32 = 3222163816
ERROR_PCW_EXTFILE_BAD_RETAIN_OFFSETS: UInt32 = 3222163817
ERROR_PCW_TFILEDATA_LONG_IGNORE_OFFSETS: UInt32 = 3222163819
ERROR_PCW_TFILEDATA_BAD_IGNORE_OFFSETS: UInt32 = 3222163820
ERROR_PCW_TFILEDATA_LONG_IGNORE_LENGTHS: UInt32 = 3222163821
ERROR_PCW_TFILEDATA_BAD_IGNORE_LENGTHS: UInt32 = 3222163822
ERROR_PCW_TFILEDATA_IGNORE_COUNT_MISMATCH: UInt32 = 3222163823
ERROR_PCW_TFILEDATA_LONG_RETAIN_OFFSETS: UInt32 = 3222163824
ERROR_PCW_TFILEDATA_BAD_RETAIN_OFFSETS: UInt32 = 3222163825
ERROR_PCW_CANT_GENERATE_TRANSFORM: UInt32 = 3222163827
ERROR_PCW_CANT_CREATE_SUMMARY_INFO: UInt32 = 3222163828
ERROR_PCW_CANT_GENERATE_TRANSFORM_POUND: UInt32 = 3222163829
ERROR_PCW_CANT_CREATE_SUMMARY_INFO_POUND: UInt32 = 3222163830
ERROR_PCW_BAD_UPGRADED_IMAGE_PRODUCT_CODE: UInt32 = 3222163831
ERROR_PCW_BAD_UPGRADED_IMAGE_PRODUCT_VERSION: UInt32 = 3222163832
ERROR_PCW_BAD_UPGRADED_IMAGE_UPGRADE_CODE: UInt32 = 3222163833
ERROR_PCW_BAD_TARGET_IMAGE_PRODUCT_CODE: UInt32 = 3222163834
ERROR_PCW_BAD_TARGET_IMAGE_PRODUCT_VERSION: UInt32 = 3222163835
ERROR_PCW_BAD_TARGET_IMAGE_UPGRADE_CODE: UInt32 = 3222163836
ERROR_PCW_MATCHED_PRODUCT_VERSIONS: UInt32 = 3222163837
ERROR_PCW_OBSOLETION_WITH_SEQUENCE_DATA: UInt32 = 3222163838
ERROR_PCW_OBSOLETION_WITH_MSI30: UInt32 = 3222163839
ERROR_PCW_OBSOLETION_WITH_PATCHSEQUENCE: UInt32 = 3222163840
ERROR_PCW_CANNOT_CREATE_TABLE: UInt32 = 3222163841
ERROR_PCW_CANT_GENERATE_SEQUENCEINFO_MAJORUPGD: UInt32 = 3222163842
ERROR_PCW_MAJOR_UPGD_WITHOUT_SEQUENCING: UInt32 = 3222163843
ERROR_PCW_BAD_PRODUCTVERSION_VALIDATION: UInt32 = 3222163844
ERROR_PCW_BAD_TRANSFORMSET: UInt32 = 3222163845
ERROR_PCW_BAD_TGT_UPD_IMAGES: UInt32 = 3222163846
ERROR_PCW_BAD_SUPERCEDENCE: UInt32 = 3222163847
ERROR_PCW_BAD_SEQUENCE: UInt32 = 3222163848
ERROR_PCW_BAD_TARGET: UInt32 = 3222163849
ERROR_PCW_NULL_PATCHFAMILY: UInt32 = 3222163850
ERROR_PCW_NULL_SEQUENCE_NUMBER: UInt32 = 3222163851
ERROR_PCW_BAD_VERSION_STRING: UInt32 = 3222163852
ERROR_PCW_BAD_MAJOR_VERSION: UInt32 = 3222163853
ERROR_PCW_SEQUENCING_BAD_TARGET: UInt32 = 3222163854
ERROR_PCW_PATCHMETADATA_PROP_NOT_SET: UInt32 = 3222163855
ERROR_PCW_INVALID_PATCHMETADATA_PROP: UInt32 = 3222163856
ERROR_PCW_INVALID_SUPERCEDENCE: UInt32 = 3222163857
ERROR_PCW_DUPLICATE_SEQUENCE_RECORD: UInt32 = 3222163858
ERROR_PCW_WRONG_PATCHMETADATA_STRD_PROP: UInt32 = 3222163859
ERROR_PCW_INVALID_PARAMETER: UInt32 = 3222163860
ERROR_PCW_CREATEFILE_LOG_FAILED: UInt32 = 3222163861
ERROR_PCW_INVALID_LOG_LEVEL: UInt32 = 3222163862
ERROR_PCW_INVALID_UI_LEVEL: UInt32 = 3222163863
ERROR_PCW_ERROR_WRITING_TO_LOG: UInt32 = 3222163864
ERROR_PCW_OUT_OF_MEMORY: UInt32 = 3222163865
ERROR_PCW_UNKNOWN_ERROR: UInt32 = 3222163866
ERROR_PCW_UNKNOWN_INFO: UInt32 = 3222163867
ERROR_PCW_UNKNOWN_WARN: UInt32 = 3222163868
ERROR_PCW_OPEN_VIEW: UInt32 = 3222163869
ERROR_PCW_EXECUTE_VIEW: UInt32 = 3222163870
ERROR_PCW_VIEW_FETCH: UInt32 = 3222163871
ERROR_PCW_FAILED_EXPAND_PATH: UInt32 = 3222163872
ERROR_PCW_INTERNAL_ERROR: UInt32 = 3222163969
ERROR_PCW_INVALID_PCP_PROPERTY: UInt32 = 3222163970
ERROR_PCW_INVALID_PCP_TARGETIMAGES: UInt32 = 3222163971
ERROR_PCW_LAX_VALIDATION_FLAGS: UInt32 = 3222163972
ERROR_PCW_FAILED_CREATE_TRANSFORM: UInt32 = 3222163973
ERROR_PCW_CANT_DELETE_TEMP_FOLDER: UInt32 = 3222163974
ERROR_PCW_MISSING_DIRECTORY_TABLE: UInt32 = 3222163975
ERROR_PCW_INVALID_SUPERSEDENCE_VALUE: UInt32 = 3222163976
ERROR_PCW_INVALID_PATCH_TYPE_SEQUENCING: UInt32 = 3222163977
ERROR_PCW_CANT_READ_FILE: UInt32 = 3222163978
ERROR_PCW_TARGET_WRONG_PRODUCT_VERSION_COMP: UInt32 = 3222163979
ERROR_PCW_INVALID_PCP_UPGRADEDFILESTOIGNORE: UInt32 = 3222163980
ERROR_PCW_INVALID_PCP_UPGRADEDIMAGES: UInt32 = 3222163981
ERROR_PCW_INVALID_PCP_EXTERNALFILES: UInt32 = 3222163982
ERROR_PCW_INVALID_PCP_IMAGEFAMILIES: UInt32 = 3222163983
ERROR_PCW_INVALID_PCP_PATCHSEQUENCE: UInt32 = 3222163984
ERROR_PCW_INVALID_PCP_TARGETFILES_OPTIONALDATA: UInt32 = 3222163985
ERROR_PCW_INVALID_PCP_UPGRADEDFILES_OPTIONALDATA: UInt32 = 3222163986
ERROR_PCW_MISSING_PATCHMETADATA: UInt32 = 3222163987
ERROR_PCW_IMAGE_PATH_NOT_EXIST: UInt32 = 3222163988
ERROR_PCW_INVALID_RANGE_ELEMENT: UInt32 = 3222163989
ERROR_PCW_INVALID_MAJOR_VERSION: UInt32 = 3222163990
ERROR_PCW_INVALID_PCP_PROPERTIES: UInt32 = 3222163991
ERROR_PCW_INVALID_PCP_FAMILYFILERANGES: UInt32 = 3222163992
INFO_BASE: UInt32 = 3222229249
INFO_PASSED_MAIN_CONTROL: UInt32 = 3222229249
INFO_ENTERING_PHASE_I_VALIDATION: UInt32 = 3222229250
INFO_ENTERING_PHASE_I: UInt32 = 3222229251
INFO_PCP_PATH: UInt32 = 3222229252
INFO_TEMP_DIR: UInt32 = 3222229253
INFO_SET_OPTIONS: UInt32 = 3222229254
INFO_PROPERTY: UInt32 = 3222229255
INFO_ENTERING_PHASE_II: UInt32 = 3222229256
INFO_ENTERING_PHASE_III: UInt32 = 3222229257
INFO_ENTERING_PHASE_IV: UInt32 = 3222229258
INFO_ENTERING_PHASE_V: UInt32 = 3222229259
INFO_GENERATING_METADATA: UInt32 = 3222229265
INFO_TEMP_DIR_CLEANUP: UInt32 = 3222229266
INFO_PATCHCACHE_FILEINFO_FAILURE: UInt32 = 3222229267
INFO_PATCHCACHE_PCI_READFAILURE: UInt32 = 3222229268
INFO_PATCHCACHE_PCI_WRITEFAILURE: UInt32 = 3222229269
INFO_USING_USER_MSI_FOR_PATCH_TABLES: UInt32 = 3222229270
INFO_SUCCESSFUL_PATCH_CREATION: UInt32 = 3222229271
WARN_BASE: UInt32 = 3222294785
WARN_MAJOR_UPGRADE_PATCH: UInt32 = 3222294785
WARN_SEQUENCE_DATA_GENERATION_DISABLED: UInt32 = 3222294786
WARN_SEQUENCE_DATA_SUPERSEDENCE_IGNORED: UInt32 = 3222294787
WARN_IMPROPER_TRANSFORM_VALIDATION: UInt32 = 3222294788
WARN_PCW_MISMATCHED_PRODUCT_CODES: UInt32 = 3222294789
WARN_PCW_MISMATCHED_PRODUCT_VERSIONS: UInt32 = 3222294790
WARN_INVALID_TRANSFORM_VALIDATION: UInt32 = 3222294791
WARN_BAD_MAJOR_VERSION: UInt32 = 3222294792
WARN_FILE_VERSION_DOWNREV: UInt32 = 3222294793
WARN_EQUAL_FILE_VERSION: UInt32 = 3222294794
WARN_PATCHPROPERTYNOTSET: UInt32 = 3222294795
WARN_OBSOLETION_WITH_SEQUENCE_DATA: UInt32 = 3222294802
WARN_OBSOLETION_WITH_MSI30: UInt32 = 3222294801
WARN_OBSOLETION_WITH_PATCHSEQUENCE: UInt32 = 3222294803
DELTA_MAX_HASH_SIZE: UInt32 = 32
cchMaxInteger: Int32 = 12
LOGNONE: UInt32 = 0
LOGINFO: UInt32 = 1
LOGWARN: UInt32 = 2
LOGERR: UInt32 = 4
LOGPERFMESSAGES: UInt32 = 8
LOGALL: UInt32 = 15
UINONE: UInt32 = 0
UILOGBITS: UInt32 = 15
DEFAULT_MINIMUM_REQUIRED_MSI_VERSION: UInt32 = 100
DEFAULT_FILE_SEQUENCE_START: UInt32 = 2
DEFAULT_DISK_ID: UInt32 = 2
@winfunctype('msi.dll')
def MsiCloseHandle(hAny: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE) -> UInt32: ...
@winfunctype('msi.dll')
def MsiCloseAllHandles() -> UInt32: ...
@winfunctype('msi.dll')
def MsiSetInternalUI(dwUILevel: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLUILEVEL, phWnd: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLUILEVEL: ...
@winfunctype('msi.dll')
def MsiSetExternalUIA(puiHandler: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLUI_HANDLERA, dwMessageFilter: UInt32, pvContext: VoidPtr) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLUI_HANDLERA: ...
@winfunctype('msi.dll')
def MsiSetExternalUIW(puiHandler: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLUI_HANDLERW, dwMessageFilter: UInt32, pvContext: VoidPtr) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLUI_HANDLERW: ...
MsiSetExternalUI = UnicodeAlias('MsiSetExternalUIW')
@winfunctype('msi.dll')
def MsiSetExternalUIRecord(puiHandler: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PINSTALLUI_HANDLER_RECORD, dwMessageFilter: UInt32, pvContext: VoidPtr, ppuiPrevHandler: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PINSTALLUI_HANDLER_RECORD) -> UInt32: ...
@winfunctype('msi.dll')
def MsiEnableLogA(dwLogMode: UInt32, szLogFile: win32more.Windows.Win32.Foundation.PSTR, dwLogAttributes: UInt32) -> UInt32: ...
@winfunctype('msi.dll')
def MsiEnableLogW(dwLogMode: UInt32, szLogFile: win32more.Windows.Win32.Foundation.PWSTR, dwLogAttributes: UInt32) -> UInt32: ...
MsiEnableLog = UnicodeAlias('MsiEnableLogW')
@winfunctype('msi.dll')
def MsiQueryProductStateA(szProduct: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE: ...
@winfunctype('msi.dll')
def MsiQueryProductStateW(szProduct: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE: ...
MsiQueryProductState = UnicodeAlias('MsiQueryProductStateW')
@winfunctype('msi.dll')
def MsiGetProductInfoA(szProduct: win32more.Windows.Win32.Foundation.PSTR, szAttribute: win32more.Windows.Win32.Foundation.PSTR, lpValueBuf: win32more.Windows.Win32.Foundation.PSTR, pcchValueBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetProductInfoW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, szAttribute: win32more.Windows.Win32.Foundation.PWSTR, lpValueBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchValueBuf: POINTER(UInt32)) -> UInt32: ...
MsiGetProductInfo = UnicodeAlias('MsiGetProductInfoW')
@winfunctype('msi.dll')
def MsiGetProductInfoExA(szProductCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, szProperty: win32more.Windows.Win32.Foundation.PSTR, szValue: win32more.Windows.Win32.Foundation.PSTR, pcchValue: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetProductInfoExW(szProductCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, szProperty: win32more.Windows.Win32.Foundation.PWSTR, szValue: win32more.Windows.Win32.Foundation.PWSTR, pcchValue: POINTER(UInt32)) -> UInt32: ...
MsiGetProductInfoEx = UnicodeAlias('MsiGetProductInfoExW')
@winfunctype('msi.dll')
def MsiInstallProductA(szPackagePath: win32more.Windows.Win32.Foundation.PSTR, szCommandLine: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiInstallProductW(szPackagePath: win32more.Windows.Win32.Foundation.PWSTR, szCommandLine: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiInstallProduct = UnicodeAlias('MsiInstallProductW')
@winfunctype('msi.dll')
def MsiConfigureProductA(szProduct: win32more.Windows.Win32.Foundation.PSTR, iInstallLevel: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLEVEL, eInstallState: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE) -> UInt32: ...
@winfunctype('msi.dll')
def MsiConfigureProductW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, iInstallLevel: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLEVEL, eInstallState: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE) -> UInt32: ...
MsiConfigureProduct = UnicodeAlias('MsiConfigureProductW')
@winfunctype('msi.dll')
def MsiConfigureProductExA(szProduct: win32more.Windows.Win32.Foundation.PSTR, iInstallLevel: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLEVEL, eInstallState: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE, szCommandLine: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiConfigureProductExW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, iInstallLevel: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLEVEL, eInstallState: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE, szCommandLine: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiConfigureProductEx = UnicodeAlias('MsiConfigureProductExW')
@winfunctype('msi.dll')
def MsiReinstallProductA(szProduct: win32more.Windows.Win32.Foundation.PSTR, szReinstallMode: UInt32) -> UInt32: ...
@winfunctype('msi.dll')
def MsiReinstallProductW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, szReinstallMode: UInt32) -> UInt32: ...
MsiReinstallProduct = UnicodeAlias('MsiReinstallProductW')
@winfunctype('msi.dll')
def MsiAdvertiseProductExA(szPackagePath: win32more.Windows.Win32.Foundation.PSTR, szScriptfilePath: win32more.Windows.Win32.Foundation.PSTR, szTransforms: win32more.Windows.Win32.Foundation.PSTR, lgidLanguage: UInt16, dwPlatform: UInt32, dwOptions: UInt32) -> UInt32: ...
@winfunctype('msi.dll')
def MsiAdvertiseProductExW(szPackagePath: win32more.Windows.Win32.Foundation.PWSTR, szScriptfilePath: win32more.Windows.Win32.Foundation.PWSTR, szTransforms: win32more.Windows.Win32.Foundation.PWSTR, lgidLanguage: UInt16, dwPlatform: UInt32, dwOptions: UInt32) -> UInt32: ...
MsiAdvertiseProductEx = UnicodeAlias('MsiAdvertiseProductExW')
@winfunctype('msi.dll')
def MsiAdvertiseProductA(szPackagePath: win32more.Windows.Win32.Foundation.PSTR, szScriptfilePath: win32more.Windows.Win32.Foundation.PSTR, szTransforms: win32more.Windows.Win32.Foundation.PSTR, lgidLanguage: UInt16) -> UInt32: ...
@winfunctype('msi.dll')
def MsiAdvertiseProductW(szPackagePath: win32more.Windows.Win32.Foundation.PWSTR, szScriptfilePath: win32more.Windows.Win32.Foundation.PWSTR, szTransforms: win32more.Windows.Win32.Foundation.PWSTR, lgidLanguage: UInt16) -> UInt32: ...
MsiAdvertiseProduct = UnicodeAlias('MsiAdvertiseProductW')
@winfunctype('msi.dll')
def MsiProcessAdvertiseScriptA(szScriptFile: win32more.Windows.Win32.Foundation.PSTR, szIconFolder: win32more.Windows.Win32.Foundation.PSTR, hRegData: win32more.Windows.Win32.System.Registry.HKEY, fShortcuts: win32more.Windows.Win32.Foundation.BOOL, fRemoveItems: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype('msi.dll')
def MsiProcessAdvertiseScriptW(szScriptFile: win32more.Windows.Win32.Foundation.PWSTR, szIconFolder: win32more.Windows.Win32.Foundation.PWSTR, hRegData: win32more.Windows.Win32.System.Registry.HKEY, fShortcuts: win32more.Windows.Win32.Foundation.BOOL, fRemoveItems: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
MsiProcessAdvertiseScript = UnicodeAlias('MsiProcessAdvertiseScriptW')
@winfunctype('msi.dll')
def MsiAdvertiseScriptA(szScriptFile: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32, phRegData: POINTER(win32more.Windows.Win32.System.Registry.HKEY), fRemoveItems: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype('msi.dll')
def MsiAdvertiseScriptW(szScriptFile: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, phRegData: POINTER(win32more.Windows.Win32.System.Registry.HKEY), fRemoveItems: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
MsiAdvertiseScript = UnicodeAlias('MsiAdvertiseScriptW')
@winfunctype('msi.dll')
def MsiGetProductInfoFromScriptA(szScriptFile: win32more.Windows.Win32.Foundation.PSTR, lpProductBuf39: win32more.Windows.Win32.Foundation.PSTR, plgidLanguage: POINTER(UInt16), pdwVersion: POINTER(UInt32), lpNameBuf: win32more.Windows.Win32.Foundation.PSTR, pcchNameBuf: POINTER(UInt32), lpPackageBuf: win32more.Windows.Win32.Foundation.PSTR, pcchPackageBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetProductInfoFromScriptW(szScriptFile: win32more.Windows.Win32.Foundation.PWSTR, lpProductBuf39: win32more.Windows.Win32.Foundation.PWSTR, plgidLanguage: POINTER(UInt16), pdwVersion: POINTER(UInt32), lpNameBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchNameBuf: POINTER(UInt32), lpPackageBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchPackageBuf: POINTER(UInt32)) -> UInt32: ...
MsiGetProductInfoFromScript = UnicodeAlias('MsiGetProductInfoFromScriptW')
@winfunctype('msi.dll')
def MsiGetProductCodeA(szComponent: win32more.Windows.Win32.Foundation.PSTR, lpBuf39: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetProductCodeW(szComponent: win32more.Windows.Win32.Foundation.PWSTR, lpBuf39: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiGetProductCode = UnicodeAlias('MsiGetProductCodeW')
@winfunctype('msi.dll')
def MsiGetUserInfoA(szProduct: win32more.Windows.Win32.Foundation.PSTR, lpUserNameBuf: win32more.Windows.Win32.Foundation.PSTR, pcchUserNameBuf: POINTER(UInt32), lpOrgNameBuf: win32more.Windows.Win32.Foundation.PSTR, pcchOrgNameBuf: POINTER(UInt32), lpSerialBuf: win32more.Windows.Win32.Foundation.PSTR, pcchSerialBuf: POINTER(UInt32)) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.USERINFOSTATE: ...
@winfunctype('msi.dll')
def MsiGetUserInfoW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, lpUserNameBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchUserNameBuf: POINTER(UInt32), lpOrgNameBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchOrgNameBuf: POINTER(UInt32), lpSerialBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchSerialBuf: POINTER(UInt32)) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.USERINFOSTATE: ...
MsiGetUserInfo = UnicodeAlias('MsiGetUserInfoW')
@winfunctype('msi.dll')
def MsiCollectUserInfoA(szProduct: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiCollectUserInfoW(szProduct: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiCollectUserInfo = UnicodeAlias('MsiCollectUserInfoW')
@winfunctype('msi.dll')
def MsiApplyPatchA(szPatchPackage: win32more.Windows.Win32.Foundation.PSTR, szInstallPackage: win32more.Windows.Win32.Foundation.PSTR, eInstallType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLTYPE, szCommandLine: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiApplyPatchW(szPatchPackage: win32more.Windows.Win32.Foundation.PWSTR, szInstallPackage: win32more.Windows.Win32.Foundation.PWSTR, eInstallType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLTYPE, szCommandLine: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiApplyPatch = UnicodeAlias('MsiApplyPatchW')
@winfunctype('msi.dll')
def MsiGetPatchInfoA(szPatch: win32more.Windows.Win32.Foundation.PSTR, szAttribute: win32more.Windows.Win32.Foundation.PSTR, lpValueBuf: win32more.Windows.Win32.Foundation.PSTR, pcchValueBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetPatchInfoW(szPatch: win32more.Windows.Win32.Foundation.PWSTR, szAttribute: win32more.Windows.Win32.Foundation.PWSTR, lpValueBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchValueBuf: POINTER(UInt32)) -> UInt32: ...
MsiGetPatchInfo = UnicodeAlias('MsiGetPatchInfoW')
@winfunctype('msi.dll')
def MsiEnumPatchesA(szProduct: win32more.Windows.Win32.Foundation.PSTR, iPatchIndex: UInt32, lpPatchBuf: win32more.Windows.Win32.Foundation.PSTR, lpTransformsBuf: win32more.Windows.Win32.Foundation.PSTR, pcchTransformsBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiEnumPatchesW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, iPatchIndex: UInt32, lpPatchBuf: win32more.Windows.Win32.Foundation.PWSTR, lpTransformsBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchTransformsBuf: POINTER(UInt32)) -> UInt32: ...
MsiEnumPatches = UnicodeAlias('MsiEnumPatchesW')
@winfunctype('msi.dll')
def MsiRemovePatchesA(szPatchList: win32more.Windows.Win32.Foundation.PSTR, szProductCode: win32more.Windows.Win32.Foundation.PSTR, eUninstallType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLTYPE, szPropertyList: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiRemovePatchesW(szPatchList: win32more.Windows.Win32.Foundation.PWSTR, szProductCode: win32more.Windows.Win32.Foundation.PWSTR, eUninstallType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLTYPE, szPropertyList: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiRemovePatches = UnicodeAlias('MsiRemovePatchesW')
@winfunctype('msi.dll')
def MsiExtractPatchXMLDataA(szPatchPath: win32more.Windows.Win32.Foundation.PSTR, dwReserved: UInt32, szXMLData: win32more.Windows.Win32.Foundation.PSTR, pcchXMLData: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiExtractPatchXMLDataW(szPatchPath: win32more.Windows.Win32.Foundation.PWSTR, dwReserved: UInt32, szXMLData: win32more.Windows.Win32.Foundation.PWSTR, pcchXMLData: POINTER(UInt32)) -> UInt32: ...
MsiExtractPatchXMLData = UnicodeAlias('MsiExtractPatchXMLDataW')
@winfunctype('msi.dll')
def MsiGetPatchInfoExA(szPatchCode: win32more.Windows.Win32.Foundation.PSTR, szProductCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, szProperty: win32more.Windows.Win32.Foundation.PSTR, lpValue: win32more.Windows.Win32.Foundation.PSTR, pcchValue: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetPatchInfoExW(szPatchCode: win32more.Windows.Win32.Foundation.PWSTR, szProductCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, szProperty: win32more.Windows.Win32.Foundation.PWSTR, lpValue: win32more.Windows.Win32.Foundation.PWSTR, pcchValue: POINTER(UInt32)) -> UInt32: ...
MsiGetPatchInfoEx = UnicodeAlias('MsiGetPatchInfoExW')
@winfunctype('msi.dll')
def MsiApplyMultiplePatchesA(szPatchPackages: win32more.Windows.Win32.Foundation.PSTR, szProductCode: win32more.Windows.Win32.Foundation.PSTR, szPropertiesList: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiApplyMultiplePatchesW(szPatchPackages: win32more.Windows.Win32.Foundation.PWSTR, szProductCode: win32more.Windows.Win32.Foundation.PWSTR, szPropertiesList: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiApplyMultiplePatches = UnicodeAlias('MsiApplyMultiplePatchesW')
@winfunctype('msi.dll')
def MsiDeterminePatchSequenceA(szProductCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, cPatchInfo: UInt32, pPatchInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIPATCHSEQUENCEINFOA)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiDeterminePatchSequenceW(szProductCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, cPatchInfo: UInt32, pPatchInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIPATCHSEQUENCEINFOW)) -> UInt32: ...
MsiDeterminePatchSequence = UnicodeAlias('MsiDeterminePatchSequenceW')
@winfunctype('msi.dll')
def MsiDetermineApplicablePatchesA(szProductPackagePath: win32more.Windows.Win32.Foundation.PSTR, cPatchInfo: UInt32, pPatchInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIPATCHSEQUENCEINFOA)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiDetermineApplicablePatchesW(szProductPackagePath: win32more.Windows.Win32.Foundation.PWSTR, cPatchInfo: UInt32, pPatchInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIPATCHSEQUENCEINFOW)) -> UInt32: ...
MsiDetermineApplicablePatches = UnicodeAlias('MsiDetermineApplicablePatchesW')
@winfunctype('msi.dll')
def MsiEnumPatchesExA(szProductCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: UInt32, dwFilter: UInt32, dwIndex: UInt32, szPatchCode: win32more.Windows.Win32.Foundation.PSTR, szTargetProductCode: win32more.Windows.Win32.Foundation.PSTR, pdwTargetProductContext: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT), szTargetUserSid: win32more.Windows.Win32.Foundation.PSTR, pcchTargetUserSid: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiEnumPatchesExW(szProductCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: UInt32, dwFilter: UInt32, dwIndex: UInt32, szPatchCode: win32more.Windows.Win32.Foundation.PWSTR, szTargetProductCode: win32more.Windows.Win32.Foundation.PWSTR, pdwTargetProductContext: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT), szTargetUserSid: win32more.Windows.Win32.Foundation.PWSTR, pcchTargetUserSid: POINTER(UInt32)) -> UInt32: ...
MsiEnumPatchesEx = UnicodeAlias('MsiEnumPatchesExW')
@winfunctype('msi.dll')
def MsiQueryFeatureStateA(szProduct: win32more.Windows.Win32.Foundation.PSTR, szFeature: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE: ...
@winfunctype('msi.dll')
def MsiQueryFeatureStateW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, szFeature: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE: ...
MsiQueryFeatureState = UnicodeAlias('MsiQueryFeatureStateW')
@winfunctype('msi.dll')
def MsiQueryFeatureStateExA(szProductCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, szFeature: win32more.Windows.Win32.Foundation.PSTR, pdwState: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiQueryFeatureStateExW(szProductCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, szFeature: win32more.Windows.Win32.Foundation.PWSTR, pdwState: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE)) -> UInt32: ...
MsiQueryFeatureStateEx = UnicodeAlias('MsiQueryFeatureStateExW')
@winfunctype('msi.dll')
def MsiUseFeatureA(szProduct: win32more.Windows.Win32.Foundation.PSTR, szFeature: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE: ...
@winfunctype('msi.dll')
def MsiUseFeatureW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, szFeature: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE: ...
MsiUseFeature = UnicodeAlias('MsiUseFeatureW')
@winfunctype('msi.dll')
def MsiUseFeatureExA(szProduct: win32more.Windows.Win32.Foundation.PSTR, szFeature: win32more.Windows.Win32.Foundation.PSTR, dwInstallMode: UInt32, dwReserved: UInt32) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE: ...
@winfunctype('msi.dll')
def MsiUseFeatureExW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, szFeature: win32more.Windows.Win32.Foundation.PWSTR, dwInstallMode: UInt32, dwReserved: UInt32) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE: ...
MsiUseFeatureEx = UnicodeAlias('MsiUseFeatureExW')
@winfunctype('msi.dll')
def MsiGetFeatureUsageA(szProduct: win32more.Windows.Win32.Foundation.PSTR, szFeature: win32more.Windows.Win32.Foundation.PSTR, pdwUseCount: POINTER(UInt32), pwDateUsed: POINTER(UInt16)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetFeatureUsageW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, szFeature: win32more.Windows.Win32.Foundation.PWSTR, pdwUseCount: POINTER(UInt32), pwDateUsed: POINTER(UInt16)) -> UInt32: ...
MsiGetFeatureUsage = UnicodeAlias('MsiGetFeatureUsageW')
@winfunctype('msi.dll')
def MsiConfigureFeatureA(szProduct: win32more.Windows.Win32.Foundation.PSTR, szFeature: win32more.Windows.Win32.Foundation.PSTR, eInstallState: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE) -> UInt32: ...
@winfunctype('msi.dll')
def MsiConfigureFeatureW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, szFeature: win32more.Windows.Win32.Foundation.PWSTR, eInstallState: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE) -> UInt32: ...
MsiConfigureFeature = UnicodeAlias('MsiConfigureFeatureW')
@winfunctype('msi.dll')
def MsiReinstallFeatureA(szProduct: win32more.Windows.Win32.Foundation.PSTR, szFeature: win32more.Windows.Win32.Foundation.PSTR, dwReinstallMode: UInt32) -> UInt32: ...
@winfunctype('msi.dll')
def MsiReinstallFeatureW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, szFeature: win32more.Windows.Win32.Foundation.PWSTR, dwReinstallMode: UInt32) -> UInt32: ...
MsiReinstallFeature = UnicodeAlias('MsiReinstallFeatureW')
@winfunctype('msi.dll')
def MsiProvideComponentA(szProduct: win32more.Windows.Win32.Foundation.PSTR, szFeature: win32more.Windows.Win32.Foundation.PSTR, szComponent: win32more.Windows.Win32.Foundation.PSTR, dwInstallMode: UInt32, lpPathBuf: win32more.Windows.Win32.Foundation.PSTR, pcchPathBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiProvideComponentW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, szFeature: win32more.Windows.Win32.Foundation.PWSTR, szComponent: win32more.Windows.Win32.Foundation.PWSTR, dwInstallMode: UInt32, lpPathBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchPathBuf: POINTER(UInt32)) -> UInt32: ...
MsiProvideComponent = UnicodeAlias('MsiProvideComponentW')
@winfunctype('msi.dll')
def MsiProvideQualifiedComponentA(szCategory: win32more.Windows.Win32.Foundation.PSTR, szQualifier: win32more.Windows.Win32.Foundation.PSTR, dwInstallMode: UInt32, lpPathBuf: win32more.Windows.Win32.Foundation.PSTR, pcchPathBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiProvideQualifiedComponentW(szCategory: win32more.Windows.Win32.Foundation.PWSTR, szQualifier: win32more.Windows.Win32.Foundation.PWSTR, dwInstallMode: UInt32, lpPathBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchPathBuf: POINTER(UInt32)) -> UInt32: ...
MsiProvideQualifiedComponent = UnicodeAlias('MsiProvideQualifiedComponentW')
@winfunctype('msi.dll')
def MsiProvideQualifiedComponentExA(szCategory: win32more.Windows.Win32.Foundation.PSTR, szQualifier: win32more.Windows.Win32.Foundation.PSTR, dwInstallMode: UInt32, szProduct: win32more.Windows.Win32.Foundation.PSTR, dwUnused1: UInt32, dwUnused2: UInt32, lpPathBuf: win32more.Windows.Win32.Foundation.PSTR, pcchPathBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiProvideQualifiedComponentExW(szCategory: win32more.Windows.Win32.Foundation.PWSTR, szQualifier: win32more.Windows.Win32.Foundation.PWSTR, dwInstallMode: UInt32, szProduct: win32more.Windows.Win32.Foundation.PWSTR, dwUnused1: UInt32, dwUnused2: UInt32, lpPathBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchPathBuf: POINTER(UInt32)) -> UInt32: ...
MsiProvideQualifiedComponentEx = UnicodeAlias('MsiProvideQualifiedComponentExW')
@winfunctype('msi.dll')
def MsiGetComponentPathA(szProduct: win32more.Windows.Win32.Foundation.PSTR, szComponent: win32more.Windows.Win32.Foundation.PSTR, lpPathBuf: win32more.Windows.Win32.Foundation.PSTR, pcchBuf: POINTER(UInt32)) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE: ...
@winfunctype('msi.dll')
def MsiGetComponentPathW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, szComponent: win32more.Windows.Win32.Foundation.PWSTR, lpPathBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchBuf: POINTER(UInt32)) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE: ...
MsiGetComponentPath = UnicodeAlias('MsiGetComponentPathW')
@winfunctype('msi.dll')
def MsiGetComponentPathExA(szProductCode: win32more.Windows.Win32.Foundation.PSTR, szComponentCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, lpOutPathBuffer: win32more.Windows.Win32.Foundation.PSTR, pcchOutPathBuffer: POINTER(UInt32)) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE: ...
@winfunctype('msi.dll')
def MsiGetComponentPathExW(szProductCode: win32more.Windows.Win32.Foundation.PWSTR, szComponentCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, lpOutPathBuffer: win32more.Windows.Win32.Foundation.PWSTR, pcchOutPathBuffer: POINTER(UInt32)) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE: ...
MsiGetComponentPathEx = UnicodeAlias('MsiGetComponentPathExW')
@winfunctype('msi.dll')
def MsiProvideAssemblyA(szAssemblyName: win32more.Windows.Win32.Foundation.PSTR, szAppContext: win32more.Windows.Win32.Foundation.PSTR, dwInstallMode: UInt32, dwAssemblyInfo: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIASSEMBLYINFO, lpPathBuf: win32more.Windows.Win32.Foundation.PSTR, pcchPathBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiProvideAssemblyW(szAssemblyName: win32more.Windows.Win32.Foundation.PWSTR, szAppContext: win32more.Windows.Win32.Foundation.PWSTR, dwInstallMode: UInt32, dwAssemblyInfo: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIASSEMBLYINFO, lpPathBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchPathBuf: POINTER(UInt32)) -> UInt32: ...
MsiProvideAssembly = UnicodeAlias('MsiProvideAssemblyW')
@winfunctype('msi.dll')
def MsiQueryComponentStateA(szProductCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, szComponentCode: win32more.Windows.Win32.Foundation.PSTR, pdwState: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiQueryComponentStateW(szProductCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, szComponentCode: win32more.Windows.Win32.Foundation.PWSTR, pdwState: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE)) -> UInt32: ...
MsiQueryComponentState = UnicodeAlias('MsiQueryComponentStateW')
@winfunctype('msi.dll')
def MsiEnumProductsA(iProductIndex: UInt32, lpProductBuf: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiEnumProductsW(iProductIndex: UInt32, lpProductBuf: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiEnumProducts = UnicodeAlias('MsiEnumProductsW')
@winfunctype('msi.dll')
def MsiEnumProductsExA(szProductCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: UInt32, dwIndex: UInt32, szInstalledProductCode: win32more.Windows.Win32.Foundation.PSTR, pdwInstalledContext: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT), szSid: win32more.Windows.Win32.Foundation.PSTR, pcchSid: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiEnumProductsExW(szProductCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: UInt32, dwIndex: UInt32, szInstalledProductCode: win32more.Windows.Win32.Foundation.PWSTR, pdwInstalledContext: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT), szSid: win32more.Windows.Win32.Foundation.PWSTR, pcchSid: POINTER(UInt32)) -> UInt32: ...
MsiEnumProductsEx = UnicodeAlias('MsiEnumProductsExW')
@winfunctype('msi.dll')
def MsiEnumRelatedProductsA(lpUpgradeCode: win32more.Windows.Win32.Foundation.PSTR, dwReserved: UInt32, iProductIndex: UInt32, lpProductBuf: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiEnumRelatedProductsW(lpUpgradeCode: win32more.Windows.Win32.Foundation.PWSTR, dwReserved: UInt32, iProductIndex: UInt32, lpProductBuf: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiEnumRelatedProducts = UnicodeAlias('MsiEnumRelatedProductsW')
@winfunctype('msi.dll')
def MsiEnumFeaturesA(szProduct: win32more.Windows.Win32.Foundation.PSTR, iFeatureIndex: UInt32, lpFeatureBuf: win32more.Windows.Win32.Foundation.PSTR, lpParentBuf: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiEnumFeaturesW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, iFeatureIndex: UInt32, lpFeatureBuf: win32more.Windows.Win32.Foundation.PWSTR, lpParentBuf: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiEnumFeatures = UnicodeAlias('MsiEnumFeaturesW')
@winfunctype('msi.dll')
def MsiEnumComponentsA(iComponentIndex: UInt32, lpComponentBuf: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiEnumComponentsW(iComponentIndex: UInt32, lpComponentBuf: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiEnumComponents = UnicodeAlias('MsiEnumComponentsW')
@winfunctype('msi.dll')
def MsiEnumComponentsExA(szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: UInt32, dwIndex: UInt32, szInstalledComponentCode: win32more.Windows.Win32.Foundation.PSTR, pdwInstalledContext: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT), szSid: win32more.Windows.Win32.Foundation.PSTR, pcchSid: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiEnumComponentsExW(szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: UInt32, dwIndex: UInt32, szInstalledComponentCode: win32more.Windows.Win32.Foundation.PWSTR, pdwInstalledContext: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT), szSid: win32more.Windows.Win32.Foundation.PWSTR, pcchSid: POINTER(UInt32)) -> UInt32: ...
MsiEnumComponentsEx = UnicodeAlias('MsiEnumComponentsExW')
@winfunctype('msi.dll')
def MsiEnumClientsA(szComponent: win32more.Windows.Win32.Foundation.PSTR, iProductIndex: UInt32, lpProductBuf: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiEnumClientsW(szComponent: win32more.Windows.Win32.Foundation.PWSTR, iProductIndex: UInt32, lpProductBuf: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiEnumClients = UnicodeAlias('MsiEnumClientsW')
@winfunctype('msi.dll')
def MsiEnumClientsExA(szComponent: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: UInt32, dwProductIndex: UInt32, szProductBuf: win32more.Windows.Win32.Foundation.PSTR, pdwInstalledContext: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT), szSid: win32more.Windows.Win32.Foundation.PSTR, pcchSid: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiEnumClientsExW(szComponent: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: UInt32, dwProductIndex: UInt32, szProductBuf: win32more.Windows.Win32.Foundation.PWSTR, pdwInstalledContext: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT), szSid: win32more.Windows.Win32.Foundation.PWSTR, pcchSid: POINTER(UInt32)) -> UInt32: ...
MsiEnumClientsEx = UnicodeAlias('MsiEnumClientsExW')
@winfunctype('msi.dll')
def MsiEnumComponentQualifiersA(szComponent: win32more.Windows.Win32.Foundation.PSTR, iIndex: UInt32, lpQualifierBuf: win32more.Windows.Win32.Foundation.PSTR, pcchQualifierBuf: POINTER(UInt32), lpApplicationDataBuf: win32more.Windows.Win32.Foundation.PSTR, pcchApplicationDataBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiEnumComponentQualifiersW(szComponent: win32more.Windows.Win32.Foundation.PWSTR, iIndex: UInt32, lpQualifierBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchQualifierBuf: POINTER(UInt32), lpApplicationDataBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchApplicationDataBuf: POINTER(UInt32)) -> UInt32: ...
MsiEnumComponentQualifiers = UnicodeAlias('MsiEnumComponentQualifiersW')
@winfunctype('msi.dll')
def MsiOpenProductA(szProduct: win32more.Windows.Win32.Foundation.PSTR, hProduct: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiOpenProductW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, hProduct: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE)) -> UInt32: ...
MsiOpenProduct = UnicodeAlias('MsiOpenProductW')
@winfunctype('msi.dll')
def MsiOpenPackageA(szPackagePath: win32more.Windows.Win32.Foundation.PSTR, hProduct: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiOpenPackageW(szPackagePath: win32more.Windows.Win32.Foundation.PWSTR, hProduct: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE)) -> UInt32: ...
MsiOpenPackage = UnicodeAlias('MsiOpenPackageW')
@winfunctype('msi.dll')
def MsiOpenPackageExA(szPackagePath: win32more.Windows.Win32.Foundation.PSTR, dwOptions: UInt32, hProduct: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiOpenPackageExW(szPackagePath: win32more.Windows.Win32.Foundation.PWSTR, dwOptions: UInt32, hProduct: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE)) -> UInt32: ...
MsiOpenPackageEx = UnicodeAlias('MsiOpenPackageExW')
@winfunctype('msi.dll')
def MsiGetPatchFileListA(szProductCode: win32more.Windows.Win32.Foundation.PSTR, szPatchPackages: win32more.Windows.Win32.Foundation.PSTR, pcFiles: POINTER(UInt32), pphFileRecords: POINTER(POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE))) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetPatchFileListW(szProductCode: win32more.Windows.Win32.Foundation.PWSTR, szPatchPackages: win32more.Windows.Win32.Foundation.PWSTR, pcFiles: POINTER(UInt32), pphFileRecords: POINTER(POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE))) -> UInt32: ...
MsiGetPatchFileList = UnicodeAlias('MsiGetPatchFileListW')
@winfunctype('msi.dll')
def MsiGetProductPropertyA(hProduct: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szProperty: win32more.Windows.Win32.Foundation.PSTR, lpValueBuf: win32more.Windows.Win32.Foundation.PSTR, pcchValueBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetProductPropertyW(hProduct: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szProperty: win32more.Windows.Win32.Foundation.PWSTR, lpValueBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchValueBuf: POINTER(UInt32)) -> UInt32: ...
MsiGetProductProperty = UnicodeAlias('MsiGetProductPropertyW')
@winfunctype('msi.dll')
def MsiVerifyPackageA(szPackagePath: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiVerifyPackageW(szPackagePath: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiVerifyPackage = UnicodeAlias('MsiVerifyPackageW')
@winfunctype('msi.dll')
def MsiGetFeatureInfoA(hProduct: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFeature: win32more.Windows.Win32.Foundation.PSTR, lpAttributes: POINTER(UInt32), lpTitleBuf: win32more.Windows.Win32.Foundation.PSTR, pcchTitleBuf: POINTER(UInt32), lpHelpBuf: win32more.Windows.Win32.Foundation.PSTR, pcchHelpBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetFeatureInfoW(hProduct: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFeature: win32more.Windows.Win32.Foundation.PWSTR, lpAttributes: POINTER(UInt32), lpTitleBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchTitleBuf: POINTER(UInt32), lpHelpBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchHelpBuf: POINTER(UInt32)) -> UInt32: ...
MsiGetFeatureInfo = UnicodeAlias('MsiGetFeatureInfoW')
@winfunctype('msi.dll')
def MsiInstallMissingComponentA(szProduct: win32more.Windows.Win32.Foundation.PSTR, szComponent: win32more.Windows.Win32.Foundation.PSTR, eInstallState: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE) -> UInt32: ...
@winfunctype('msi.dll')
def MsiInstallMissingComponentW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, szComponent: win32more.Windows.Win32.Foundation.PWSTR, eInstallState: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE) -> UInt32: ...
MsiInstallMissingComponent = UnicodeAlias('MsiInstallMissingComponentW')
@winfunctype('msi.dll')
def MsiInstallMissingFileA(szProduct: win32more.Windows.Win32.Foundation.PSTR, szFile: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiInstallMissingFileW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, szFile: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiInstallMissingFile = UnicodeAlias('MsiInstallMissingFileW')
@winfunctype('msi.dll')
def MsiLocateComponentA(szComponent: win32more.Windows.Win32.Foundation.PSTR, lpPathBuf: win32more.Windows.Win32.Foundation.PSTR, pcchBuf: POINTER(UInt32)) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE: ...
@winfunctype('msi.dll')
def MsiLocateComponentW(szComponent: win32more.Windows.Win32.Foundation.PWSTR, lpPathBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchBuf: POINTER(UInt32)) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE: ...
MsiLocateComponent = UnicodeAlias('MsiLocateComponentW')
@winfunctype('msi.dll')
def MsiSourceListClearAllA(szProduct: win32more.Windows.Win32.Foundation.PSTR, szUserName: win32more.Windows.Win32.Foundation.PSTR, dwReserved: UInt32) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSourceListClearAllW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, szUserName: win32more.Windows.Win32.Foundation.PWSTR, dwReserved: UInt32) -> UInt32: ...
MsiSourceListClearAll = UnicodeAlias('MsiSourceListClearAllW')
@winfunctype('msi.dll')
def MsiSourceListAddSourceA(szProduct: win32more.Windows.Win32.Foundation.PSTR, szUserName: win32more.Windows.Win32.Foundation.PSTR, dwReserved: UInt32, szSource: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSourceListAddSourceW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, szUserName: win32more.Windows.Win32.Foundation.PWSTR, dwReserved: UInt32, szSource: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiSourceListAddSource = UnicodeAlias('MsiSourceListAddSourceW')
@winfunctype('msi.dll')
def MsiSourceListForceResolutionA(szProduct: win32more.Windows.Win32.Foundation.PSTR, szUserName: win32more.Windows.Win32.Foundation.PSTR, dwReserved: UInt32) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSourceListForceResolutionW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, szUserName: win32more.Windows.Win32.Foundation.PWSTR, dwReserved: UInt32) -> UInt32: ...
MsiSourceListForceResolution = UnicodeAlias('MsiSourceListForceResolutionW')
@winfunctype('msi.dll')
def MsiSourceListAddSourceExA(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32, szSource: win32more.Windows.Win32.Foundation.PSTR, dwIndex: UInt32) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSourceListAddSourceExW(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32, szSource: win32more.Windows.Win32.Foundation.PWSTR, dwIndex: UInt32) -> UInt32: ...
MsiSourceListAddSourceEx = UnicodeAlias('MsiSourceListAddSourceExW')
@winfunctype('msi.dll')
def MsiSourceListAddMediaDiskA(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32, dwDiskId: UInt32, szVolumeLabel: win32more.Windows.Win32.Foundation.PSTR, szDiskPrompt: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSourceListAddMediaDiskW(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32, dwDiskId: UInt32, szVolumeLabel: win32more.Windows.Win32.Foundation.PWSTR, szDiskPrompt: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiSourceListAddMediaDisk = UnicodeAlias('MsiSourceListAddMediaDiskW')
@winfunctype('msi.dll')
def MsiSourceListClearSourceA(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32, szSource: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSourceListClearSourceW(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32, szSource: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiSourceListClearSource = UnicodeAlias('MsiSourceListClearSourceW')
@winfunctype('msi.dll')
def MsiSourceListClearMediaDiskA(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32, dwDiskId: UInt32) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSourceListClearMediaDiskW(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32, dwDiskId: UInt32) -> UInt32: ...
MsiSourceListClearMediaDisk = UnicodeAlias('MsiSourceListClearMediaDiskW')
@winfunctype('msi.dll')
def MsiSourceListClearAllExA(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSourceListClearAllExW(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32) -> UInt32: ...
MsiSourceListClearAllEx = UnicodeAlias('MsiSourceListClearAllExW')
@winfunctype('msi.dll')
def MsiSourceListForceResolutionExA(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSourceListForceResolutionExW(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32) -> UInt32: ...
MsiSourceListForceResolutionEx = UnicodeAlias('MsiSourceListForceResolutionExW')
@winfunctype('msi.dll')
def MsiSourceListSetInfoA(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32, szProperty: win32more.Windows.Win32.Foundation.PSTR, szValue: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSourceListSetInfoW(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32, szProperty: win32more.Windows.Win32.Foundation.PWSTR, szValue: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiSourceListSetInfo = UnicodeAlias('MsiSourceListSetInfoW')
@winfunctype('msi.dll')
def MsiSourceListGetInfoA(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32, szProperty: win32more.Windows.Win32.Foundation.PSTR, szValue: win32more.Windows.Win32.Foundation.PSTR, pcchValue: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSourceListGetInfoW(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32, szProperty: win32more.Windows.Win32.Foundation.PWSTR, szValue: win32more.Windows.Win32.Foundation.PWSTR, pcchValue: POINTER(UInt32)) -> UInt32: ...
MsiSourceListGetInfo = UnicodeAlias('MsiSourceListGetInfoW')
@winfunctype('msi.dll')
def MsiSourceListEnumSourcesA(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32, dwIndex: UInt32, szSource: win32more.Windows.Win32.Foundation.PSTR, pcchSource: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSourceListEnumSourcesW(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32, dwIndex: UInt32, szSource: win32more.Windows.Win32.Foundation.PWSTR, pcchSource: POINTER(UInt32)) -> UInt32: ...
MsiSourceListEnumSources = UnicodeAlias('MsiSourceListEnumSourcesW')
@winfunctype('msi.dll')
def MsiSourceListEnumMediaDisksA(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PSTR, szUserSid: win32more.Windows.Win32.Foundation.PSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32, dwIndex: UInt32, pdwDiskId: POINTER(UInt32), szVolumeLabel: win32more.Windows.Win32.Foundation.PSTR, pcchVolumeLabel: POINTER(UInt32), szDiskPrompt: win32more.Windows.Win32.Foundation.PSTR, pcchDiskPrompt: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSourceListEnumMediaDisksW(szProductCodeOrPatchCode: win32more.Windows.Win32.Foundation.PWSTR, szUserSid: win32more.Windows.Win32.Foundation.PWSTR, dwContext: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT, dwOptions: UInt32, dwIndex: UInt32, pdwDiskId: POINTER(UInt32), szVolumeLabel: win32more.Windows.Win32.Foundation.PWSTR, pcchVolumeLabel: POINTER(UInt32), szDiskPrompt: win32more.Windows.Win32.Foundation.PWSTR, pcchDiskPrompt: POINTER(UInt32)) -> UInt32: ...
MsiSourceListEnumMediaDisks = UnicodeAlias('MsiSourceListEnumMediaDisksW')
@winfunctype('msi.dll')
def MsiGetFileVersionA(szFilePath: win32more.Windows.Win32.Foundation.PSTR, lpVersionBuf: win32more.Windows.Win32.Foundation.PSTR, pcchVersionBuf: POINTER(UInt32), lpLangBuf: win32more.Windows.Win32.Foundation.PSTR, pcchLangBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetFileVersionW(szFilePath: win32more.Windows.Win32.Foundation.PWSTR, lpVersionBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchVersionBuf: POINTER(UInt32), lpLangBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchLangBuf: POINTER(UInt32)) -> UInt32: ...
MsiGetFileVersion = UnicodeAlias('MsiGetFileVersionW')
@winfunctype('msi.dll')
def MsiGetFileHashA(szFilePath: win32more.Windows.Win32.Foundation.PSTR, dwOptions: UInt32, pHash: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIFILEHASHINFO)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetFileHashW(szFilePath: win32more.Windows.Win32.Foundation.PWSTR, dwOptions: UInt32, pHash: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIFILEHASHINFO)) -> UInt32: ...
MsiGetFileHash = UnicodeAlias('MsiGetFileHashW')
@winfunctype('msi.dll')
def MsiGetFileSignatureInformationA(szSignedObjectPath: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32, ppcCertContext: POINTER(POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_CONTEXT)), pbHashData: POINTER(Byte), pcbHashData: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msi.dll')
def MsiGetFileSignatureInformationW(szSignedObjectPath: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, ppcCertContext: POINTER(POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_CONTEXT)), pbHashData: POINTER(Byte), pcbHashData: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
MsiGetFileSignatureInformation = UnicodeAlias('MsiGetFileSignatureInformationW')
@winfunctype('msi.dll')
def MsiGetShortcutTargetA(szShortcutPath: win32more.Windows.Win32.Foundation.PSTR, szProductCode: win32more.Windows.Win32.Foundation.PSTR, szFeatureId: win32more.Windows.Win32.Foundation.PSTR, szComponentCode: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetShortcutTargetW(szShortcutPath: win32more.Windows.Win32.Foundation.PWSTR, szProductCode: win32more.Windows.Win32.Foundation.PWSTR, szFeatureId: win32more.Windows.Win32.Foundation.PWSTR, szComponentCode: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiGetShortcutTarget = UnicodeAlias('MsiGetShortcutTargetW')
@winfunctype('msi.dll')
def MsiIsProductElevatedA(szProduct: win32more.Windows.Win32.Foundation.PSTR, pfElevated: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiIsProductElevatedW(szProduct: win32more.Windows.Win32.Foundation.PWSTR, pfElevated: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> UInt32: ...
MsiIsProductElevated = UnicodeAlias('MsiIsProductElevatedW')
@winfunctype('msi.dll')
def MsiNotifySidChangeA(pOldSid: win32more.Windows.Win32.Foundation.PSTR, pNewSid: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiNotifySidChangeW(pOldSid: win32more.Windows.Win32.Foundation.PWSTR, pNewSid: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiNotifySidChange = UnicodeAlias('MsiNotifySidChangeW')
@winfunctype('msi.dll')
def MsiBeginTransactionA(szName: win32more.Windows.Win32.Foundation.PSTR, dwTransactionAttributes: UInt32, phTransactionHandle: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE), phChangeOfOwnerEvent: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiBeginTransactionW(szName: win32more.Windows.Win32.Foundation.PWSTR, dwTransactionAttributes: UInt32, phTransactionHandle: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE), phChangeOfOwnerEvent: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
MsiBeginTransaction = UnicodeAlias('MsiBeginTransactionW')
@winfunctype('msi.dll')
def MsiEndTransaction(dwTransactionState: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSACTIONSTATE) -> UInt32: ...
@winfunctype('msi.dll')
def MsiJoinTransaction(hTransactionHandle: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, dwTransactionAttributes: UInt32, phChangeOfOwnerEvent: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiDatabaseOpenViewA(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szQuery: win32more.Windows.Win32.Foundation.PSTR, phView: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiDatabaseOpenViewW(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szQuery: win32more.Windows.Win32.Foundation.PWSTR, phView: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE)) -> UInt32: ...
MsiDatabaseOpenView = UnicodeAlias('MsiDatabaseOpenViewW')
@winfunctype('msi.dll')
def MsiViewGetErrorA(hView: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szColumnNameBuffer: win32more.Windows.Win32.Foundation.PSTR, pcchBuf: POINTER(UInt32)) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR: ...
@winfunctype('msi.dll')
def MsiViewGetErrorW(hView: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szColumnNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, pcchBuf: POINTER(UInt32)) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR: ...
MsiViewGetError = UnicodeAlias('MsiViewGetErrorW')
@winfunctype('msi.dll')
def MsiViewExecute(hView: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE) -> UInt32: ...
@winfunctype('msi.dll')
def MsiViewFetch(hView: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, phRecord: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiViewModify(hView: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, eModifyMode: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIMODIFY, hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE) -> UInt32: ...
@winfunctype('msi.dll')
def MsiViewGetColumnInfo(hView: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, eColumnInfo: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICOLINFO, phRecord: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiViewClose(hView: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE) -> UInt32: ...
@winfunctype('msi.dll')
def MsiDatabaseGetPrimaryKeysA(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szTableName: win32more.Windows.Win32.Foundation.PSTR, phRecord: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiDatabaseGetPrimaryKeysW(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szTableName: win32more.Windows.Win32.Foundation.PWSTR, phRecord: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE)) -> UInt32: ...
MsiDatabaseGetPrimaryKeys = UnicodeAlias('MsiDatabaseGetPrimaryKeysW')
@winfunctype('msi.dll')
def MsiDatabaseIsTablePersistentA(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szTableName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICONDITION: ...
@winfunctype('msi.dll')
def MsiDatabaseIsTablePersistentW(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szTableName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICONDITION: ...
MsiDatabaseIsTablePersistent = UnicodeAlias('MsiDatabaseIsTablePersistentW')
@winfunctype('msi.dll')
def MsiGetSummaryInformationA(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szDatabasePath: win32more.Windows.Win32.Foundation.PSTR, uiUpdateCount: UInt32, phSummaryInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetSummaryInformationW(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szDatabasePath: win32more.Windows.Win32.Foundation.PWSTR, uiUpdateCount: UInt32, phSummaryInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE)) -> UInt32: ...
MsiGetSummaryInformation = UnicodeAlias('MsiGetSummaryInformationW')
@winfunctype('msi.dll')
def MsiSummaryInfoGetPropertyCount(hSummaryInfo: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, puiPropertyCount: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSummaryInfoSetPropertyA(hSummaryInfo: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, uiProperty: UInt32, uiDataType: UInt32, iValue: Int32, pftValue: POINTER(win32more.Windows.Win32.Foundation.FILETIME), szValue: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSummaryInfoSetPropertyW(hSummaryInfo: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, uiProperty: UInt32, uiDataType: UInt32, iValue: Int32, pftValue: POINTER(win32more.Windows.Win32.Foundation.FILETIME), szValue: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiSummaryInfoSetProperty = UnicodeAlias('MsiSummaryInfoSetPropertyW')
@winfunctype('msi.dll')
def MsiSummaryInfoGetPropertyA(hSummaryInfo: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, uiProperty: UInt32, puiDataType: POINTER(UInt32), piValue: POINTER(Int32), pftValue: POINTER(win32more.Windows.Win32.Foundation.FILETIME), szValueBuf: win32more.Windows.Win32.Foundation.PSTR, pcchValueBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSummaryInfoGetPropertyW(hSummaryInfo: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, uiProperty: UInt32, puiDataType: POINTER(UInt32), piValue: POINTER(Int32), pftValue: POINTER(win32more.Windows.Win32.Foundation.FILETIME), szValueBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchValueBuf: POINTER(UInt32)) -> UInt32: ...
MsiSummaryInfoGetProperty = UnicodeAlias('MsiSummaryInfoGetPropertyW')
@winfunctype('msi.dll')
def MsiSummaryInfoPersist(hSummaryInfo: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE) -> UInt32: ...
@winfunctype('msi.dll')
def MsiOpenDatabaseA(szDatabasePath: win32more.Windows.Win32.Foundation.PSTR, szPersist: win32more.Windows.Win32.Foundation.PSTR, phDatabase: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiOpenDatabaseW(szDatabasePath: win32more.Windows.Win32.Foundation.PWSTR, szPersist: win32more.Windows.Win32.Foundation.PWSTR, phDatabase: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE)) -> UInt32: ...
MsiOpenDatabase = UnicodeAlias('MsiOpenDatabaseW')
@winfunctype('msi.dll')
def MsiDatabaseImportA(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFolderPath: win32more.Windows.Win32.Foundation.PSTR, szFileName: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiDatabaseImportW(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFolderPath: win32more.Windows.Win32.Foundation.PWSTR, szFileName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiDatabaseImport = UnicodeAlias('MsiDatabaseImportW')
@winfunctype('msi.dll')
def MsiDatabaseExportA(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szTableName: win32more.Windows.Win32.Foundation.PSTR, szFolderPath: win32more.Windows.Win32.Foundation.PSTR, szFileName: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiDatabaseExportW(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szTableName: win32more.Windows.Win32.Foundation.PWSTR, szFolderPath: win32more.Windows.Win32.Foundation.PWSTR, szFileName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiDatabaseExport = UnicodeAlias('MsiDatabaseExportW')
@winfunctype('msi.dll')
def MsiDatabaseMergeA(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, hDatabaseMerge: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szTableName: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiDatabaseMergeW(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, hDatabaseMerge: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szTableName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiDatabaseMerge = UnicodeAlias('MsiDatabaseMergeW')
@winfunctype('msi.dll')
def MsiDatabaseGenerateTransformA(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, hDatabaseReference: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szTransformFile: win32more.Windows.Win32.Foundation.PSTR, iReserved1: Int32, iReserved2: Int32) -> UInt32: ...
@winfunctype('msi.dll')
def MsiDatabaseGenerateTransformW(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, hDatabaseReference: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szTransformFile: win32more.Windows.Win32.Foundation.PWSTR, iReserved1: Int32, iReserved2: Int32) -> UInt32: ...
MsiDatabaseGenerateTransform = UnicodeAlias('MsiDatabaseGenerateTransformW')
@winfunctype('msi.dll')
def MsiDatabaseApplyTransformA(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szTransformFile: win32more.Windows.Win32.Foundation.PSTR, iErrorConditions: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_ERROR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiDatabaseApplyTransformW(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szTransformFile: win32more.Windows.Win32.Foundation.PWSTR, iErrorConditions: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_ERROR) -> UInt32: ...
MsiDatabaseApplyTransform = UnicodeAlias('MsiDatabaseApplyTransformW')
@winfunctype('msi.dll')
def MsiCreateTransformSummaryInfoA(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, hDatabaseReference: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szTransformFile: win32more.Windows.Win32.Foundation.PSTR, iErrorConditions: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_ERROR, iValidation: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_VALIDATE) -> UInt32: ...
@winfunctype('msi.dll')
def MsiCreateTransformSummaryInfoW(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, hDatabaseReference: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szTransformFile: win32more.Windows.Win32.Foundation.PWSTR, iErrorConditions: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_ERROR, iValidation: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_VALIDATE) -> UInt32: ...
MsiCreateTransformSummaryInfo = UnicodeAlias('MsiCreateTransformSummaryInfoW')
@winfunctype('msi.dll')
def MsiDatabaseCommit(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetDatabaseState(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBSTATE: ...
@winfunctype('msi.dll')
def MsiCreateRecord(cParams: UInt32) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE: ...
@winfunctype('msi.dll')
def MsiRecordIsNull(hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, iField: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('msi.dll')
def MsiRecordDataSize(hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, iField: UInt32) -> UInt32: ...
@winfunctype('msi.dll')
def MsiRecordSetInteger(hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, iField: UInt32, iValue: Int32) -> UInt32: ...
@winfunctype('msi.dll')
def MsiRecordSetStringA(hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, iField: UInt32, szValue: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiRecordSetStringW(hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, iField: UInt32, szValue: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiRecordSetString = UnicodeAlias('MsiRecordSetStringW')
@winfunctype('msi.dll')
def MsiRecordGetInteger(hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, iField: UInt32) -> Int32: ...
@winfunctype('msi.dll')
def MsiRecordGetStringA(hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, iField: UInt32, szValueBuf: win32more.Windows.Win32.Foundation.PSTR, pcchValueBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiRecordGetStringW(hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, iField: UInt32, szValueBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchValueBuf: POINTER(UInt32)) -> UInt32: ...
MsiRecordGetString = UnicodeAlias('MsiRecordGetStringW')
@winfunctype('msi.dll')
def MsiRecordGetFieldCount(hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE) -> UInt32: ...
@winfunctype('msi.dll')
def MsiRecordSetStreamA(hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, iField: UInt32, szFilePath: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiRecordSetStreamW(hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, iField: UInt32, szFilePath: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiRecordSetStream = UnicodeAlias('MsiRecordSetStreamW')
@winfunctype('msi.dll')
def MsiRecordReadStream(hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, iField: UInt32, szDataBuf: win32more.Windows.Win32.Foundation.PSTR, pcbDataBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiRecordClearData(hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetActiveDatabase(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE: ...
@winfunctype('msi.dll')
def MsiSetPropertyA(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szName: win32more.Windows.Win32.Foundation.PSTR, szValue: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSetPropertyW(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szName: win32more.Windows.Win32.Foundation.PWSTR, szValue: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiSetProperty = UnicodeAlias('MsiSetPropertyW')
@winfunctype('msi.dll')
def MsiGetPropertyA(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szName: win32more.Windows.Win32.Foundation.PSTR, szValueBuf: win32more.Windows.Win32.Foundation.PSTR, pcchValueBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetPropertyW(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szName: win32more.Windows.Win32.Foundation.PWSTR, szValueBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchValueBuf: POINTER(UInt32)) -> UInt32: ...
MsiGetProperty = UnicodeAlias('MsiGetPropertyW')
@winfunctype('msi.dll')
def MsiGetLanguage(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE) -> UInt16: ...
@winfunctype('msi.dll')
def MsiGetMode(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, eRunMode: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('msi.dll')
def MsiSetMode(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, eRunMode: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE, fState: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype('msi.dll')
def MsiFormatRecordA(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szResultBuf: win32more.Windows.Win32.Foundation.PSTR, pcchResultBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiFormatRecordW(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szResultBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchResultBuf: POINTER(UInt32)) -> UInt32: ...
MsiFormatRecord = UnicodeAlias('MsiFormatRecordW')
@winfunctype('msi.dll')
def MsiDoActionA(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szAction: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiDoActionW(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szAction: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiDoAction = UnicodeAlias('MsiDoActionW')
@winfunctype('msi.dll')
def MsiSequenceA(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szTable: win32more.Windows.Win32.Foundation.PSTR, iSequenceMode: Int32) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSequenceW(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szTable: win32more.Windows.Win32.Foundation.PWSTR, iSequenceMode: Int32) -> UInt32: ...
MsiSequence = UnicodeAlias('MsiSequenceW')
@winfunctype('msi.dll')
def MsiProcessMessage(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, eMessageType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE, hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE) -> Int32: ...
@winfunctype('msi.dll')
def MsiEvaluateConditionA(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szCondition: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICONDITION: ...
@winfunctype('msi.dll')
def MsiEvaluateConditionW(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szCondition: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICONDITION: ...
MsiEvaluateCondition = UnicodeAlias('MsiEvaluateConditionW')
@winfunctype('msi.dll')
def MsiGetFeatureStateA(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFeature: win32more.Windows.Win32.Foundation.PSTR, piInstalled: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE), piAction: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetFeatureStateW(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFeature: win32more.Windows.Win32.Foundation.PWSTR, piInstalled: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE), piAction: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE)) -> UInt32: ...
MsiGetFeatureState = UnicodeAlias('MsiGetFeatureStateW')
@winfunctype('msi.dll')
def MsiSetFeatureStateA(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFeature: win32more.Windows.Win32.Foundation.PSTR, iState: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSetFeatureStateW(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFeature: win32more.Windows.Win32.Foundation.PWSTR, iState: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE) -> UInt32: ...
MsiSetFeatureState = UnicodeAlias('MsiSetFeatureStateW')
@winfunctype('msi.dll')
def MsiSetFeatureAttributesA(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFeature: win32more.Windows.Win32.Foundation.PSTR, dwAttributes: UInt32) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSetFeatureAttributesW(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFeature: win32more.Windows.Win32.Foundation.PWSTR, dwAttributes: UInt32) -> UInt32: ...
MsiSetFeatureAttributes = UnicodeAlias('MsiSetFeatureAttributesW')
@winfunctype('msi.dll')
def MsiGetComponentStateA(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szComponent: win32more.Windows.Win32.Foundation.PSTR, piInstalled: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE), piAction: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetComponentStateW(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szComponent: win32more.Windows.Win32.Foundation.PWSTR, piInstalled: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE), piAction: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE)) -> UInt32: ...
MsiGetComponentState = UnicodeAlias('MsiGetComponentStateW')
@winfunctype('msi.dll')
def MsiSetComponentStateA(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szComponent: win32more.Windows.Win32.Foundation.PSTR, iState: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSetComponentStateW(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szComponent: win32more.Windows.Win32.Foundation.PWSTR, iState: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE) -> UInt32: ...
MsiSetComponentState = UnicodeAlias('MsiSetComponentStateW')
@winfunctype('msi.dll')
def MsiGetFeatureCostA(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFeature: win32more.Windows.Win32.Foundation.PSTR, iCostTree: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICOSTTREE, iState: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE, piCost: POINTER(Int32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetFeatureCostW(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFeature: win32more.Windows.Win32.Foundation.PWSTR, iCostTree: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICOSTTREE, iState: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE, piCost: POINTER(Int32)) -> UInt32: ...
MsiGetFeatureCost = UnicodeAlias('MsiGetFeatureCostW')
@winfunctype('msi.dll')
def MsiEnumComponentCostsA(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szComponent: win32more.Windows.Win32.Foundation.PSTR, dwIndex: UInt32, iState: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE, szDriveBuf: win32more.Windows.Win32.Foundation.PSTR, pcchDriveBuf: POINTER(UInt32), piCost: POINTER(Int32), piTempCost: POINTER(Int32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiEnumComponentCostsW(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szComponent: win32more.Windows.Win32.Foundation.PWSTR, dwIndex: UInt32, iState: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE, szDriveBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchDriveBuf: POINTER(UInt32), piCost: POINTER(Int32), piTempCost: POINTER(Int32)) -> UInt32: ...
MsiEnumComponentCosts = UnicodeAlias('MsiEnumComponentCostsW')
@winfunctype('msi.dll')
def MsiSetInstallLevel(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, iInstallLevel: Int32) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetFeatureValidStatesA(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFeature: win32more.Windows.Win32.Foundation.PSTR, lpInstallStates: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetFeatureValidStatesW(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFeature: win32more.Windows.Win32.Foundation.PWSTR, lpInstallStates: POINTER(UInt32)) -> UInt32: ...
MsiGetFeatureValidStates = UnicodeAlias('MsiGetFeatureValidStatesW')
@winfunctype('msi.dll')
def MsiGetSourcePathA(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFolder: win32more.Windows.Win32.Foundation.PSTR, szPathBuf: win32more.Windows.Win32.Foundation.PSTR, pcchPathBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetSourcePathW(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFolder: win32more.Windows.Win32.Foundation.PWSTR, szPathBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchPathBuf: POINTER(UInt32)) -> UInt32: ...
MsiGetSourcePath = UnicodeAlias('MsiGetSourcePathW')
@winfunctype('msi.dll')
def MsiGetTargetPathA(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFolder: win32more.Windows.Win32.Foundation.PSTR, szPathBuf: win32more.Windows.Win32.Foundation.PSTR, pcchPathBuf: POINTER(UInt32)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiGetTargetPathW(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFolder: win32more.Windows.Win32.Foundation.PWSTR, szPathBuf: win32more.Windows.Win32.Foundation.PWSTR, pcchPathBuf: POINTER(UInt32)) -> UInt32: ...
MsiGetTargetPath = UnicodeAlias('MsiGetTargetPathW')
@winfunctype('msi.dll')
def MsiSetTargetPathA(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFolder: win32more.Windows.Win32.Foundation.PSTR, szFolderPath: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiSetTargetPathW(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szFolder: win32more.Windows.Win32.Foundation.PWSTR, szFolderPath: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiSetTargetPath = UnicodeAlias('MsiSetTargetPathW')
@winfunctype('msi.dll')
def MsiVerifyDiskSpace(hInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE) -> UInt32: ...
@winfunctype('msi.dll')
def MsiEnableUIPreview(hDatabase: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, phPreview: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE)) -> UInt32: ...
@winfunctype('msi.dll')
def MsiPreviewDialogA(hPreview: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szDialogName: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiPreviewDialogW(hPreview: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szDialogName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiPreviewDialog = UnicodeAlias('MsiPreviewDialogW')
@winfunctype('msi.dll')
def MsiPreviewBillboardA(hPreview: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szControlName: win32more.Windows.Win32.Foundation.PSTR, szBillboard: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('msi.dll')
def MsiPreviewBillboardW(hPreview: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE, szControlName: win32more.Windows.Win32.Foundation.PWSTR, szBillboard: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
MsiPreviewBillboard = UnicodeAlias('MsiPreviewBillboardW')
@winfunctype('msi.dll')
def MsiGetLastErrorRecord() -> win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE: ...
@winfunctype('sfc.dll')
def SfcGetNextProtectedFile(RpcHandle: win32more.Windows.Win32.Foundation.HANDLE, ProtFileData: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PROTECTED_FILE_DATA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('sfc.dll')
def SfcIsFileProtected(RpcHandle: win32more.Windows.Win32.Foundation.HANDLE, ProtFileName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('sfc.dll')
def SfcIsKeyProtected(KeyHandle: win32more.Windows.Win32.System.Registry.HKEY, SubKeyName: win32more.Windows.Win32.Foundation.PWSTR, KeySam: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('sfc.dll')
def SfpVerifyFile(pszFileName: win32more.Windows.Win32.Foundation.PSTR, pszError: win32more.Windows.Win32.Foundation.PSTR, dwErrSize: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatchc.dll')
def CreatePatchFileA(OldFileName: win32more.Windows.Win32.Foundation.PSTR, NewFileName: win32more.Windows.Win32.Foundation.PSTR, PatchFileName: win32more.Windows.Win32.Foundation.PSTR, OptionFlags: UInt32, OptionData: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_OPTION_DATA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatchc.dll')
def CreatePatchFileW(OldFileName: win32more.Windows.Win32.Foundation.PWSTR, NewFileName: win32more.Windows.Win32.Foundation.PWSTR, PatchFileName: win32more.Windows.Win32.Foundation.PWSTR, OptionFlags: UInt32, OptionData: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_OPTION_DATA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
CreatePatchFile = UnicodeAlias('CreatePatchFileW')
@winfunctype('mspatchc.dll')
def CreatePatchFileByHandles(OldFileHandle: win32more.Windows.Win32.Foundation.HANDLE, NewFileHandle: win32more.Windows.Win32.Foundation.HANDLE, PatchFileHandle: win32more.Windows.Win32.Foundation.HANDLE, OptionFlags: UInt32, OptionData: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_OPTION_DATA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatchc.dll')
def CreatePatchFileExA(OldFileCount: UInt32, OldFileInfoArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_OLD_FILE_INFO_A), NewFileName: win32more.Windows.Win32.Foundation.PSTR, PatchFileName: win32more.Windows.Win32.Foundation.PSTR, OptionFlags: UInt32, OptionData: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_OPTION_DATA), ProgressCallback: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PPATCH_PROGRESS_CALLBACK, CallbackContext: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatchc.dll')
def CreatePatchFileExW(OldFileCount: UInt32, OldFileInfoArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_OLD_FILE_INFO_W), NewFileName: win32more.Windows.Win32.Foundation.PWSTR, PatchFileName: win32more.Windows.Win32.Foundation.PWSTR, OptionFlags: UInt32, OptionData: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_OPTION_DATA), ProgressCallback: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PPATCH_PROGRESS_CALLBACK, CallbackContext: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
CreatePatchFileEx = UnicodeAlias('CreatePatchFileExW')
@winfunctype('mspatchc.dll')
def CreatePatchFileByHandlesEx(OldFileCount: UInt32, OldFileInfoArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_OLD_FILE_INFO_H), NewFileHandle: win32more.Windows.Win32.Foundation.HANDLE, PatchFileHandle: win32more.Windows.Win32.Foundation.HANDLE, OptionFlags: UInt32, OptionData: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_OPTION_DATA), ProgressCallback: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PPATCH_PROGRESS_CALLBACK, CallbackContext: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatchc.dll')
def ExtractPatchHeaderToFileA(PatchFileName: win32more.Windows.Win32.Foundation.PSTR, PatchHeaderFileName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatchc.dll')
def ExtractPatchHeaderToFileW(PatchFileName: win32more.Windows.Win32.Foundation.PWSTR, PatchHeaderFileName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
ExtractPatchHeaderToFile = UnicodeAlias('ExtractPatchHeaderToFileW')
@winfunctype('mspatchc.dll')
def ExtractPatchHeaderToFileByHandles(PatchFileHandle: win32more.Windows.Win32.Foundation.HANDLE, PatchHeaderFileHandle: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatcha.dll')
def TestApplyPatchToFileA(PatchFileName: win32more.Windows.Win32.Foundation.PSTR, OldFileName: win32more.Windows.Win32.Foundation.PSTR, ApplyOptionFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatcha.dll')
def TestApplyPatchToFileW(PatchFileName: win32more.Windows.Win32.Foundation.PWSTR, OldFileName: win32more.Windows.Win32.Foundation.PWSTR, ApplyOptionFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
TestApplyPatchToFile = UnicodeAlias('TestApplyPatchToFileW')
@winfunctype('mspatcha.dll')
def TestApplyPatchToFileByHandles(PatchFileHandle: win32more.Windows.Win32.Foundation.HANDLE, OldFileHandle: win32more.Windows.Win32.Foundation.HANDLE, ApplyOptionFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatcha.dll')
def TestApplyPatchToFileByBuffers(PatchFileBuffer: POINTER(Byte), PatchFileSize: UInt32, OldFileBuffer: POINTER(Byte), OldFileSize: UInt32, NewFileSize: POINTER(UInt32), ApplyOptionFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatcha.dll')
def ApplyPatchToFileA(PatchFileName: win32more.Windows.Win32.Foundation.PSTR, OldFileName: win32more.Windows.Win32.Foundation.PSTR, NewFileName: win32more.Windows.Win32.Foundation.PSTR, ApplyOptionFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatcha.dll')
def ApplyPatchToFileW(PatchFileName: win32more.Windows.Win32.Foundation.PWSTR, OldFileName: win32more.Windows.Win32.Foundation.PWSTR, NewFileName: win32more.Windows.Win32.Foundation.PWSTR, ApplyOptionFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
ApplyPatchToFile = UnicodeAlias('ApplyPatchToFileW')
@winfunctype('mspatcha.dll')
def ApplyPatchToFileByHandles(PatchFileHandle: win32more.Windows.Win32.Foundation.HANDLE, OldFileHandle: win32more.Windows.Win32.Foundation.HANDLE, NewFileHandle: win32more.Windows.Win32.Foundation.HANDLE, ApplyOptionFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatcha.dll')
def ApplyPatchToFileExA(PatchFileName: win32more.Windows.Win32.Foundation.PSTR, OldFileName: win32more.Windows.Win32.Foundation.PSTR, NewFileName: win32more.Windows.Win32.Foundation.PSTR, ApplyOptionFlags: UInt32, ProgressCallback: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PPATCH_PROGRESS_CALLBACK, CallbackContext: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatcha.dll')
def ApplyPatchToFileExW(PatchFileName: win32more.Windows.Win32.Foundation.PWSTR, OldFileName: win32more.Windows.Win32.Foundation.PWSTR, NewFileName: win32more.Windows.Win32.Foundation.PWSTR, ApplyOptionFlags: UInt32, ProgressCallback: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PPATCH_PROGRESS_CALLBACK, CallbackContext: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
ApplyPatchToFileEx = UnicodeAlias('ApplyPatchToFileExW')
@winfunctype('mspatcha.dll')
def ApplyPatchToFileByHandlesEx(PatchFileHandle: win32more.Windows.Win32.Foundation.HANDLE, OldFileHandle: win32more.Windows.Win32.Foundation.HANDLE, NewFileHandle: win32more.Windows.Win32.Foundation.HANDLE, ApplyOptionFlags: UInt32, ProgressCallback: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PPATCH_PROGRESS_CALLBACK, CallbackContext: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatcha.dll')
def ApplyPatchToFileByBuffers(PatchFileMapped: POINTER(Byte), PatchFileSize: UInt32, OldFileMapped: POINTER(Byte), OldFileSize: UInt32, NewFileBuffer: POINTER(POINTER(Byte)), NewFileBufferSize: UInt32, NewFileActualSize: POINTER(UInt32), NewFileTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME), ApplyOptionFlags: UInt32, ProgressCallback: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PPATCH_PROGRESS_CALLBACK, CallbackContext: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatcha.dll')
def GetFilePatchSignatureA(FileName: win32more.Windows.Win32.Foundation.PSTR, OptionFlags: UInt32, OptionData: VoidPtr, IgnoreRangeCount: UInt32, IgnoreRangeArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_IGNORE_RANGE), RetainRangeCount: UInt32, RetainRangeArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_RETAIN_RANGE), SignatureBufferSize: UInt32, SignatureBuffer: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatcha.dll')
def GetFilePatchSignatureW(FileName: win32more.Windows.Win32.Foundation.PWSTR, OptionFlags: UInt32, OptionData: VoidPtr, IgnoreRangeCount: UInt32, IgnoreRangeArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_IGNORE_RANGE), RetainRangeCount: UInt32, RetainRangeArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_RETAIN_RANGE), SignatureBufferSize: UInt32, SignatureBuffer: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetFilePatchSignature = UnicodeAlias('GetFilePatchSignatureW')
@winfunctype('mspatcha.dll')
def GetFilePatchSignatureByHandle(FileHandle: win32more.Windows.Win32.Foundation.HANDLE, OptionFlags: UInt32, OptionData: VoidPtr, IgnoreRangeCount: UInt32, IgnoreRangeArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_IGNORE_RANGE), RetainRangeCount: UInt32, RetainRangeArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_RETAIN_RANGE), SignatureBufferSize: UInt32, SignatureBuffer: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatcha.dll')
def GetFilePatchSignatureByBuffer(FileBufferWritable: POINTER(Byte), FileSize: UInt32, OptionFlags: UInt32, OptionData: VoidPtr, IgnoreRangeCount: UInt32, IgnoreRangeArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_IGNORE_RANGE), RetainRangeCount: UInt32, RetainRangeArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_RETAIN_RANGE), SignatureBufferSize: UInt32, SignatureBuffer: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mspatcha.dll')
def NormalizeFileForPatchSignature(FileBuffer: VoidPtr, FileSize: UInt32, OptionFlags: UInt32, OptionData: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_OPTION_DATA), NewFileCoffBase: UInt32, NewFileCoffTime: UInt32, IgnoreRangeCount: UInt32, IgnoreRangeArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_IGNORE_RANGE), RetainRangeCount: UInt32, RetainRangeArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_RETAIN_RANGE)) -> Int32: ...
@winfunctype('msdelta.dll')
def GetDeltaInfoB(Delta: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_INPUT, lpHeaderInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_HEADER_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('msdelta.dll')
def GetDeltaInfoA(lpDeltaName: win32more.Windows.Win32.Foundation.PSTR, lpHeaderInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_HEADER_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('msdelta.dll')
def GetDeltaInfoW(lpDeltaName: win32more.Windows.Win32.Foundation.PWSTR, lpHeaderInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_HEADER_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetDeltaInfo = UnicodeAlias('GetDeltaInfoW')
@winfunctype('msdelta.dll')
def ApplyDeltaGetReverseB(ApplyFlags: Int64, Source: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_INPUT, Delta: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_INPUT, lpReverseFileTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME), lpTarget: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_OUTPUT), lpTargetReverse: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_OUTPUT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('msdelta.dll')
def ApplyDeltaB(ApplyFlags: Int64, Source: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_INPUT, Delta: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_INPUT, lpTarget: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_OUTPUT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('msdelta.dll')
def ApplyDeltaProvidedB(ApplyFlags: Int64, Source: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_INPUT, Delta: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_INPUT, lpTarget: VoidPtr, uTargetSize: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('msdelta.dll')
def ApplyDeltaA(ApplyFlags: Int64, lpSourceName: win32more.Windows.Win32.Foundation.PSTR, lpDeltaName: win32more.Windows.Win32.Foundation.PSTR, lpTargetName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('msdelta.dll')
def ApplyDeltaW(ApplyFlags: Int64, lpSourceName: win32more.Windows.Win32.Foundation.PWSTR, lpDeltaName: win32more.Windows.Win32.Foundation.PWSTR, lpTargetName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
ApplyDelta = UnicodeAlias('ApplyDeltaW')
@winfunctype('msdelta.dll')
def CreateDeltaB(FileTypeSet: Int64, SetFlags: Int64, ResetFlags: Int64, Source: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_INPUT, Target: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_INPUT, SourceOptions: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_INPUT, TargetOptions: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_INPUT, GlobalOptions: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_INPUT, lpTargetFileTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME), HashAlgId: win32more.Windows.Win32.Security.Cryptography.ALG_ID, lpDelta: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_OUTPUT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('msdelta.dll')
def CreateDeltaA(FileTypeSet: Int64, SetFlags: Int64, ResetFlags: Int64, lpSourceName: win32more.Windows.Win32.Foundation.PSTR, lpTargetName: win32more.Windows.Win32.Foundation.PSTR, lpSourceOptionsName: win32more.Windows.Win32.Foundation.PSTR, lpTargetOptionsName: win32more.Windows.Win32.Foundation.PSTR, GlobalOptions: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_INPUT, lpTargetFileTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME), HashAlgId: win32more.Windows.Win32.Security.Cryptography.ALG_ID, lpDeltaName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('msdelta.dll')
def CreateDeltaW(FileTypeSet: Int64, SetFlags: Int64, ResetFlags: Int64, lpSourceName: win32more.Windows.Win32.Foundation.PWSTR, lpTargetName: win32more.Windows.Win32.Foundation.PWSTR, lpSourceOptionsName: win32more.Windows.Win32.Foundation.PWSTR, lpTargetOptionsName: win32more.Windows.Win32.Foundation.PWSTR, GlobalOptions: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_INPUT, lpTargetFileTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME), HashAlgId: win32more.Windows.Win32.Security.Cryptography.ALG_ID, lpDeltaName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
CreateDelta = UnicodeAlias('CreateDeltaW')
@winfunctype('msdelta.dll')
def GetDeltaSignatureB(FileTypeSet: Int64, HashAlgId: win32more.Windows.Win32.Security.Cryptography.ALG_ID, Source: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_INPUT, lpHash: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_HASH)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('msdelta.dll')
def GetDeltaSignatureA(FileTypeSet: Int64, HashAlgId: win32more.Windows.Win32.Security.Cryptography.ALG_ID, lpSourceName: win32more.Windows.Win32.Foundation.PSTR, lpHash: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_HASH)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('msdelta.dll')
def GetDeltaSignatureW(FileTypeSet: Int64, HashAlgId: win32more.Windows.Win32.Security.Cryptography.ALG_ID, lpSourceName: win32more.Windows.Win32.Foundation.PWSTR, lpHash: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_HASH)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetDeltaSignature = UnicodeAlias('GetDeltaSignatureW')
@winfunctype('msdelta.dll')
def DeltaNormalizeProvidedB(FileTypeSet: Int64, NormalizeFlags: Int64, NormalizeOptions: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_INPUT, lpSource: VoidPtr, uSourceSize: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('msdelta.dll')
def DeltaFree(lpMemory: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def CreateActCtxA(pActCtx: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ACTCTXA)) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('KERNEL32.dll')
def CreateActCtxW(pActCtx: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ACTCTXW)) -> win32more.Windows.Win32.Foundation.HANDLE: ...
CreateActCtx = UnicodeAlias('CreateActCtxW')
@winfunctype('KERNEL32.dll')
def AddRefActCtx(hActCtx: win32more.Windows.Win32.Foundation.HANDLE) -> Void: ...
@winfunctype('KERNEL32.dll')
def ReleaseActCtx(hActCtx: win32more.Windows.Win32.Foundation.HANDLE) -> Void: ...
@winfunctype('KERNEL32.dll')
def ZombifyActCtx(hActCtx: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def ActivateActCtx(hActCtx: win32more.Windows.Win32.Foundation.HANDLE, lpCookie: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def DeactivateActCtx(dwFlags: UInt32, ulCookie: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetCurrentActCtx(lphActCtx: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def FindActCtxSectionStringA(dwFlags: UInt32, lpExtensionGuid: POINTER(Guid), ulSectionId: UInt32, lpStringToFind: win32more.Windows.Win32.Foundation.PSTR, ReturnedData: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ACTCTX_SECTION_KEYED_DATA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def FindActCtxSectionStringW(dwFlags: UInt32, lpExtensionGuid: POINTER(Guid), ulSectionId: UInt32, lpStringToFind: win32more.Windows.Win32.Foundation.PWSTR, ReturnedData: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ACTCTX_SECTION_KEYED_DATA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
FindActCtxSectionString = UnicodeAlias('FindActCtxSectionStringW')
@winfunctype('KERNEL32.dll')
def FindActCtxSectionGuid(dwFlags: UInt32, lpExtensionGuid: POINTER(Guid), ulSectionId: UInt32, lpGuidToFind: POINTER(Guid), ReturnedData: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ACTCTX_SECTION_KEYED_DATA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def QueryActCtxW(dwFlags: UInt32, hActCtx: win32more.Windows.Win32.Foundation.HANDLE, pvSubInstance: VoidPtr, ulInfoClass: UInt32, pvBuffer: VoidPtr, cbBuffer: UIntPtr, pcbWrittenOrRequired: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def QueryActCtxSettingsW(dwFlags: UInt32, hActCtx: win32more.Windows.Win32.Foundation.HANDLE, settingsNameSpace: win32more.Windows.Win32.Foundation.PWSTR, settingName: win32more.Windows.Win32.Foundation.PWSTR, pvBuffer: win32more.Windows.Win32.Foundation.PWSTR, dwBuffer: UIntPtr, pdwWrittenOrRequired: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.BOOL: ...
class COMPATIBILITY_CONTEXT_ELEMENT(Structure):
    Id: Guid
    Type: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ACTCTX_COMPATIBILITY_ELEMENT_TYPE
    MaxVersionTested: UInt64
CREATE_ASM_NAME_OBJ_FLAGS = Int32
CANOF_PARSE_DISPLAY_NAME: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.CREATE_ASM_NAME_OBJ_FLAGS = 1
CANOF_SET_DEFAULT_VALUES: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.CREATE_ASM_NAME_OBJ_FLAGS = 2
class DELTA_HASH(Structure):
    HashSize: UInt32
    HashValue: Byte * 32
class DELTA_HEADER_INFO(Structure):
    FileTypeSet: Int64
    FileType: Int64
    Flags: Int64
    TargetSize: UIntPtr
    TargetFileTime: win32more.Windows.Win32.Foundation.FILETIME
    TargetHashAlgId: win32more.Windows.Win32.Security.Cryptography.ALG_ID
    TargetHash: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.DELTA_HASH
class DELTA_INPUT(Structure):
    Anonymous: _Anonymous_e__Union
    uSize: UIntPtr
    Editable: win32more.Windows.Win32.Foundation.BOOL
    class _Anonymous_e__Union(Union):
        lpcStart: VoidPtr
        lpStart: VoidPtr
class DELTA_OUTPUT(Structure):
    lpStart: VoidPtr
    uSize: UIntPtr
class FUSION_INSTALL_REFERENCE(Structure):
    cbSize: UInt32
    dwFlags: UInt32
    guidScheme: Guid
    szIdentifier: win32more.Windows.Win32.Foundation.PWSTR
    szNonCannonicalData: win32more.Windows.Win32.Foundation.PWSTR
IASSEMBLYCACHE_UNINSTALL_DISPOSITION = UInt32
IASSEMBLYCACHE_UNINSTALL_DISPOSITION_UNINSTALLED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IASSEMBLYCACHE_UNINSTALL_DISPOSITION = 1
IASSEMBLYCACHE_UNINSTALL_DISPOSITION_STILL_IN_USE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IASSEMBLYCACHE_UNINSTALL_DISPOSITION = 2
IASSEMBLYCACHE_UNINSTALL_DISPOSITION_ALREADY_UNINSTALLED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IASSEMBLYCACHE_UNINSTALL_DISPOSITION = 3
IASSEMBLYCACHE_UNINSTALL_DISPOSITION_DELETE_PENDING: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IASSEMBLYCACHE_UNINSTALL_DISPOSITION = 4
class IAssemblyCache(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e707dcde-d1cd-11d2-bab9-00c04f8eceae}')
    @commethod(3)
    def UninstallAssembly(self, dwFlags: UInt32, pszAssemblyName: win32more.Windows.Win32.Foundation.PWSTR, pRefData: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.FUSION_INSTALL_REFERENCE), pulDisposition: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IASSEMBLYCACHE_UNINSTALL_DISPOSITION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def QueryAssemblyInfo(self, dwFlags: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.QUERYASMINFO_FLAGS, pszAssemblyName: win32more.Windows.Win32.Foundation.PWSTR, pAsmInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.ASSEMBLY_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateAssemblyCacheItem(self, dwFlags: UInt32, pvReserved: VoidPtr, ppAsmItem: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IAssemblyCacheItem), pszAssemblyName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Reserved(self, ppUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def InstallAssembly(self, dwFlags: UInt32, pszManifestFilePath: win32more.Windows.Win32.Foundation.PWSTR, pRefData: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.FUSION_INSTALL_REFERENCE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAssemblyCacheItem(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9e3aaeb4-d1cd-11d2-bab9-00c04f8eceae}')
    @commethod(3)
    def CreateStream(self, dwFlags: UInt32, pszStreamName: win32more.Windows.Win32.Foundation.PWSTR, dwFormat: UInt32, dwFormatFlags: UInt32, ppIStream: POINTER(win32more.Windows.Win32.System.Com.IStream), puliMaxSize: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Commit(self, dwFlags: UInt32, pulDisposition: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def AbortItem(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAssemblyName(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{cd193bc0-b4bc-11d2-9833-00c04fc31d2e}')
    @commethod(3)
    def SetProperty(self, PropertyId: UInt32, pvProperty: VoidPtr, cbProperty: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetProperty(self, PropertyId: UInt32, pvProperty: VoidPtr, pcbProperty: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Finalize(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetDisplayName(self, szDisplayName: win32more.Windows.Win32.Foundation.PWSTR, pccDisplayName: POINTER(UInt32), dwDisplayFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Reserved(self, refIID: POINTER(Guid), pUnkReserved1: win32more.Windows.Win32.System.Com.IUnknown, pUnkReserved2: win32more.Windows.Win32.System.Com.IUnknown, szReserved: win32more.Windows.Win32.Foundation.PWSTR, llReserved: Int64, pvReserved: VoidPtr, cbReserved: UInt32, ppReserved: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetName(self, lpcwBuffer: POINTER(UInt32), pwzName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetVersion(self, pdwVersionHi: POINTER(UInt32), pdwVersionLow: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def IsEqual(self, pName: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IAssemblyName, dwCmpFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Clone(self, pName: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IAssemblyName)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumMsmDependency(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0adda82c-2c26-11d2-ad65-00a0c9af11a6}')
    @commethod(3)
    def Next(self, cFetch: UInt32, rgmsmDependencies: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IMsmDependency), pcFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Skip(self, cSkip: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, pemsmDependencies: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IEnumMsmDependency)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumMsmError(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0adda829-2c26-11d2-ad65-00a0c9af11a6}')
    @commethod(3)
    def Next(self, cFetch: UInt32, rgmsmErrors: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IMsmError), pcFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Skip(self, cSkip: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, pemsmErrors: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IEnumMsmError)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumMsmString(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0adda826-2c26-11d2-ad65-00a0c9af11a6}')
    @commethod(3)
    def Next(self, cFetch: UInt32, rgbstrStrings: POINTER(win32more.Windows.Win32.Foundation.BSTR), pcFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Skip(self, cSkip: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, pemsmStrings: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IEnumMsmString)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMsmDependencies(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{0adda82d-2c26-11d2-ad65-00a0c9af11a6}')
    @commethod(7)
    def get_Item(self, Item: Int32, Return: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IMsmDependency)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Count(self, Count: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get__NewEnum(self, NewEnum: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMsmDependency(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{0adda82b-2c26-11d2-ad65-00a0c9af11a6}')
    @commethod(7)
    def get_Module(self, Module: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Language(self, Language: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Version(self, Version: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMsmError(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{0adda828-2c26-11d2-ad65-00a0c9af11a6}')
    @commethod(7)
    def get_Type(self, ErrorType: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msmErrorType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Path(self, ErrorPath: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Language(self, ErrorLanguage: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_DatabaseTable(self, ErrorTable: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_DatabaseKeys(self, ErrorKeys: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IMsmStrings)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_ModuleTable(self, ErrorTable: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_ModuleKeys(self, ErrorKeys: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IMsmStrings)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMsmErrors(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{0adda82a-2c26-11d2-ad65-00a0c9af11a6}')
    @commethod(7)
    def get_Item(self, Item: Int32, Return: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IMsmError)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Count(self, Count: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get__NewEnum(self, NewEnum: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMsmGetFiles(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{7041ae26-2d78-11d2-888a-00a0c981b015}')
    @commethod(7)
    def get_ModuleFiles(self, Files: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IMsmStrings)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMsmMerge(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{0adda82e-2c26-11d2-ad65-00a0c9af11a6}')
    @commethod(7)
    def OpenDatabase(self, Path: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def OpenModule(self, Path: win32more.Windows.Win32.Foundation.BSTR, Language: Int16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CloseDatabase(self, Commit: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CloseModule(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def OpenLog(self, Path: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def CloseLog(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def Log(self, Message: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_Errors(self, Errors: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IMsmErrors)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_Dependencies(self, Dependencies: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IMsmDependencies)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def Merge(self, Feature: win32more.Windows.Win32.Foundation.BSTR, RedirectDir: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def Connect(self, Feature: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def ExtractCAB(self, FileName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def ExtractFiles(self, Path: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMsmStrings(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{0adda827-2c26-11d2-ad65-00a0c9af11a6}')
    @commethod(7)
    def get_Item(self, Item: Int32, Return: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Count(self, Count: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get__NewEnum(self, NewEnum: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
INSTALLFEATUREATTRIBUTE = Int32
INSTALLFEATUREATTRIBUTE_FAVORLOCAL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLFEATUREATTRIBUTE = 1
INSTALLFEATUREATTRIBUTE_FAVORSOURCE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLFEATUREATTRIBUTE = 2
INSTALLFEATUREATTRIBUTE_FOLLOWPARENT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLFEATUREATTRIBUTE = 4
INSTALLFEATUREATTRIBUTE_FAVORADVERTISE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLFEATUREATTRIBUTE = 8
INSTALLFEATUREATTRIBUTE_DISALLOWADVERTISE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLFEATUREATTRIBUTE = 16
INSTALLFEATUREATTRIBUTE_NOUNSUPPORTEDADVERTISE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLFEATUREATTRIBUTE = 32
INSTALLLEVEL = Int32
INSTALLLEVEL_DEFAULT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLEVEL = 0
INSTALLLEVEL_MINIMUM: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLEVEL = 1
INSTALLLEVEL_MAXIMUM: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLEVEL = 65535
INSTALLLOGATTRIBUTES = Int32
INSTALLLOGATTRIBUTES_APPEND: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGATTRIBUTES = 1
INSTALLLOGATTRIBUTES_FLUSHEACHLINE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGATTRIBUTES = 2
INSTALLLOGMODE = Int32
INSTALLLOGMODE_FATALEXIT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 1
INSTALLLOGMODE_ERROR: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 2
INSTALLLOGMODE_WARNING: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 4
INSTALLLOGMODE_USER: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 8
INSTALLLOGMODE_INFO: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 16
INSTALLLOGMODE_RESOLVESOURCE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 64
INSTALLLOGMODE_OUTOFDISKSPACE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 128
INSTALLLOGMODE_ACTIONSTART: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 256
INSTALLLOGMODE_ACTIONDATA: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 512
INSTALLLOGMODE_COMMONDATA: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 2048
INSTALLLOGMODE_PROPERTYDUMP: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 1024
INSTALLLOGMODE_VERBOSE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 4096
INSTALLLOGMODE_EXTRADEBUG: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 8192
INSTALLLOGMODE_LOGONLYONERROR: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 16384
INSTALLLOGMODE_LOGPERFORMANCE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 32768
INSTALLLOGMODE_PROGRESS: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 1024
INSTALLLOGMODE_INITIALIZE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 4096
INSTALLLOGMODE_TERMINATE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 8192
INSTALLLOGMODE_SHOWDIALOG: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 16384
INSTALLLOGMODE_FILESINUSE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 32
INSTALLLOGMODE_RMFILESINUSE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 33554432
INSTALLLOGMODE_INSTALLSTART: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 67108864
INSTALLLOGMODE_INSTALLEND: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLLOGMODE = 134217728
INSTALLMESSAGE = Int32
INSTALLMESSAGE_FATALEXIT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 0
INSTALLMESSAGE_ERROR: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 16777216
INSTALLMESSAGE_WARNING: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 33554432
INSTALLMESSAGE_USER: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 50331648
INSTALLMESSAGE_INFO: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 67108864
INSTALLMESSAGE_FILESINUSE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 83886080
INSTALLMESSAGE_RESOLVESOURCE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 100663296
INSTALLMESSAGE_OUTOFDISKSPACE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 117440512
INSTALLMESSAGE_ACTIONSTART: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 134217728
INSTALLMESSAGE_ACTIONDATA: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 150994944
INSTALLMESSAGE_PROGRESS: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 167772160
INSTALLMESSAGE_COMMONDATA: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 184549376
INSTALLMESSAGE_INITIALIZE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 201326592
INSTALLMESSAGE_TERMINATE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 218103808
INSTALLMESSAGE_SHOWDIALOG: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 234881024
INSTALLMESSAGE_PERFORMANCE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 251658240
INSTALLMESSAGE_RMFILESINUSE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 419430400
INSTALLMESSAGE_INSTALLSTART: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 436207616
INSTALLMESSAGE_INSTALLEND: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMESSAGE = 452984832
INSTALLMODE = Int32
INSTALLMODE_NODETECTION_ANY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMODE = -4
INSTALLMODE_NOSOURCERESOLUTION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMODE = -3
INSTALLMODE_NODETECTION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMODE = -2
INSTALLMODE_EXISTING: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMODE = -1
INSTALLMODE_DEFAULT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLMODE = 0
INSTALLSTATE = Int32
INSTALLSTATE_NOTUSED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE = -7
INSTALLSTATE_BADCONFIG: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE = -6
INSTALLSTATE_INCOMPLETE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE = -5
INSTALLSTATE_SOURCEABSENT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE = -4
INSTALLSTATE_MOREDATA: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE = -3
INSTALLSTATE_INVALIDARG: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE = -2
INSTALLSTATE_UNKNOWN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE = -1
INSTALLSTATE_BROKEN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE = 0
INSTALLSTATE_ADVERTISED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE = 1
INSTALLSTATE_REMOVED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE = 1
INSTALLSTATE_ABSENT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE = 2
INSTALLSTATE_LOCAL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE = 3
INSTALLSTATE_SOURCE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE = 4
INSTALLSTATE_DEFAULT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLSTATE = 5
INSTALLTYPE = Int32
INSTALLTYPE_DEFAULT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLTYPE = 0
INSTALLTYPE_NETWORK_IMAGE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLTYPE = 1
INSTALLTYPE_SINGLE_INSTANCE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLTYPE = 2
INSTALLUILEVEL = Int32
INSTALLUILEVEL_NOCHANGE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLUILEVEL = 0
INSTALLUILEVEL_DEFAULT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLUILEVEL = 1
INSTALLUILEVEL_NONE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLUILEVEL = 2
INSTALLUILEVEL_BASIC: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLUILEVEL = 3
INSTALLUILEVEL_REDUCED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLUILEVEL = 4
INSTALLUILEVEL_FULL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLUILEVEL = 5
INSTALLUILEVEL_ENDDIALOG: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLUILEVEL = 128
INSTALLUILEVEL_PROGRESSONLY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLUILEVEL = 64
INSTALLUILEVEL_HIDECANCEL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLUILEVEL = 32
INSTALLUILEVEL_SOURCERESONLY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLUILEVEL = 256
INSTALLUILEVEL_UACONLY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.INSTALLUILEVEL = 512
@winfunctype_pointer
def INSTALLUI_HANDLERA(pvContext: VoidPtr, iMessageType: UInt32, szMessage: win32more.Windows.Win32.Foundation.PSTR) -> Int32: ...
@winfunctype_pointer
def INSTALLUI_HANDLERW(pvContext: VoidPtr, iMessageType: UInt32, szMessage: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
INSTALLUI_HANDLER = UnicodeAlias('INSTALLUI_HANDLERW')
class IPMApplicationInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{50afb58a-438c-4088-9789-f8c4899829c7}')
    @commethod(3)
    def get_ProductID(self, pProductID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_InstanceID(self, pInstanceID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_OfferID(self, pOfferID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def get_DefaultTask(self, pDefaultTask: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def get_AppTitle(self, pAppTitle: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_IconPath(self, pAppIconPath: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_NotificationState(self, pIsNotified: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_AppInstallType(self, pAppInstallType: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_INSTALL_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_State(self, pState: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_STATE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_IsRevoked(self, pIsRevoked: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_UpdateAvailable(self, pIsUpdateAvailable: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_InstallDate(self, pInstallDate: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_IsUninstallable(self, pIsUninstallable: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_IsThemable(self, pIsThemable: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_IsTrial(self, pIsTrial: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_InstallPath(self, pInstallPath: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_DataRoot(self, pDataRoot: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_Genre(self, pGenre: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APP_GENRE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_Publisher(self, pPublisher: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_Author(self, pAuthor: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_Description(self, pDescription: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_Version(self, pVersion: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_InvocationInfo(self, pImageUrn: POINTER(win32more.Windows.Win32.Foundation.BSTR), pParameters: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_AppPlatMajorVersion(self, pMajorVer: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_AppPlatMinorVersion(self, pMinorVer: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_PublisherID(self, pPublisherID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_IsMultiCore(self, pIsMultiCore: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_SID(self, pSID: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_AppPlatMajorVersionLightUp(self, pMajorVer: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_AppPlatMinorVersionLightUp(self, pMinorVer: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def set_UpdateAvailable(self, IsUpdateAvailable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def set_NotificationState(self, IsNotified: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def set_IconPath(self, AppIconPath: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def set_UninstallableState(self, IsUninstallable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_IsPinableOnKidZone(self, pIsPinable: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_IsOriginallyPreInstalled(self, pIsPreinstalled: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_IsInstallOnSD(self, pIsInstallOnSD: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_IsOptoutOnSD(self, pIsOptoutOnSD: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_IsOptoutBackupRestore(self, pIsOptoutBackupRestore: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def set_EnterpriseDisabled(self, IsDisabled: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def set_EnterpriseUninstallable(self, IsUninstallable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_EnterpriseDisabled(self, IsDisabled: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_EnterpriseUninstallable(self, IsUninstallable: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_IsVisibleOnAppList(self, pIsVisible: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def get_IsInboxApp(self, pIsInboxApp: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_StorageID(self, pStorageID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def get_StartAppBlob(self, pBlob: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_STARTAPPBLOB)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def get_IsMovable(self, pIsMovable: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def get_DeploymentAppEnumerationHubFilter(self, HubType: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_HUBTYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_ModifiedDate(self, pModifiedDate: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def get_IsOriginallyRestored(self, pIsRestored: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_ShouldDeferMdilBind(self, pfDeferMdilBind: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def get_IsFullyPreInstall(self, pfIsFullyPreInstall: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def set_IsMdilMaintenanceNeeded(self, fIsMdilMaintenanceNeeded: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def set_Title(self, AppTitle: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMApplicationInfoEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0ec42a96-4d46-4dc6-a3d9-a7acaac0f5fa}')
    @commethod(3)
    def get_Next(self, ppAppInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMApplicationInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMBackgroundServiceAgentInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3a8b46da-928c-4879-998c-09dc96f3d490}')
    @commethod(3)
    def get_ProductID(self, pProductID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_TaskID(self, pTaskID: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_BSAID(self, pBSAID: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def get_BGSpecifier(self, pBGSpecifier: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def get_BGName(self, pBGName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_BGSource(self, pBGSource: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_BGType(self, pBGType: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_IsPeriodic(self, pIsPeriodic: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_IsScheduled(self, pIsScheduled: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_IsScheduleAllowed(self, pIsScheduleAllowed: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_Description(self, pDescription: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_IsLaunchOnBoot(self, pLaunchOnBoot: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def set_IsScheduled(self, IsScheduled: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def set_IsScheduleAllowed(self, IsScheduleAllowed: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMBackgroundServiceAgentInfoEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{18eb2072-ab56-43b3-872c-beafb7a6b391}')
    @commethod(3)
    def get_Next(self, ppBSAInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMBackgroundServiceAgentInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMBackgroundWorkerInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7dd4531b-d3bf-4b6b-94f3-69c098b1497d}')
    @commethod(3)
    def get_ProductID(self, pProductID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_TaskID(self, pTaskID: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_BGName(self, pBGName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def get_MaxStartupLatency(self, pMaxStartupLatency: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def get_ExpectedRuntime(self, pExpectedRuntime: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_IsBootWorker(self, pIsBootWorker: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMBackgroundWorkerInfoEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{87f479f8-90d8-4ec7-92b9-72787e2f636b}')
    @commethod(3)
    def get_Next(self, ppBWInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMBackgroundWorkerInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMDeploymentManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{35f785fa-1979-4a8b-bc8f-fd70eb0d1544}')
    @commethod(3)
    def ReportDownloadBegin(self, productID: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ReportDownloadProgress(self, productID: Guid, usProgress: UInt16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def ReportDownloadComplete(self, productID: Guid, hrResult: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def BeginInstall(self, pInstallInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_INSTALLINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def BeginUpdate(self, pUpdateInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_UPDATEINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def BeginDeployPackage(self, pInstallInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_INSTALLINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def BeginUpdateDeployedPackageLegacy(self, pUpdateInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_UPDATEINFO_LEGACY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def BeginUninstall(self, productID: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def BeginEnterpriseAppInstall(self, pInstallInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_INSTALLINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def BeginEnterpriseAppUpdate(self, pUpdateInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_UPDATEINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def BeginUpdateLicense(self, productID: Guid, offerID: Guid, pbLicense: POINTER(Byte), cbLicense: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetLicenseChallenge(self, PackagePath: win32more.Windows.Win32.Foundation.BSTR, ppbChallenge: POINTER(POINTER(Byte)), pcbChallenge: POINTER(UInt32), ppbKID: POINTER(POINTER(Byte)), pcbKID: POINTER(UInt32), ppbDeviceID: POINTER(POINTER(Byte)), pcbDeviceID: POINTER(UInt32), ppbSaltValue: POINTER(POINTER(Byte)), pcbSaltValue: POINTER(UInt32), ppbKGVValue: POINTER(POINTER(Byte)), pcbKGVValue: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetLicenseChallengeByProductID(self, ProductID: Guid, ppbChallenge: POINTER(POINTER(Byte)), pcbLicense: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetLicenseChallengeByProductID2(self, ProductID: Guid, ppbChallenge: POINTER(POINTER(Byte)), pcbLicense: POINTER(UInt32), ppbKID: POINTER(POINTER(Byte)), pcbKID: POINTER(UInt32), ppbDeviceID: POINTER(POINTER(Byte)), pcbDeviceID: POINTER(UInt32), ppbSaltValue: POINTER(POINTER(Byte)), pcbSaltValue: POINTER(UInt32), ppbKGVValue: POINTER(POINTER(Byte)), pcbKGVValue: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def RevokeLicense(self, productID: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def RebindMdilBinaries(self, ProductID: Guid, FileNames: POINTER(win32more.Windows.Win32.System.Com.SAFEARRAY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def RebindAllMdilBinaries(self, ProductID: Guid, InstanceID: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def RegenerateXbf(self, ProductID: Guid, AssemblyPaths: POINTER(win32more.Windows.Win32.System.Com.SAFEARRAY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GenerateXbfForCurrentLocale(self, ProductID: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def BeginProvision(self, ProductID: Guid, XMLpath: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def BeginDeprovision(self, ProductID: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def ReindexSQLCEDatabases(self, ProductID: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def SetApplicationsNeedMaintenance(self, RequiredMaintenanceOperations: UInt32, pcApplications: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def UpdateChamberProfile(self, ProductID: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def EnterprisePolicyIsApplicationAllowed(self, productId: Guid, publisherName: win32more.Windows.Win32.Foundation.PWSTR, pIsAllowed: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def BeginUpdateDeployedPackage(self, pUpdateInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_UPDATEINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def ReportRestoreCancelled(self, productID: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def ResolveResourceString(self, resourceString: win32more.Windows.Win32.Foundation.PWSTR, pResolvedResourceString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def UpdateCapabilitiesForModernApps(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def ReportDownloadStatusUpdate(self, productId: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def BeginUninstallWithOptions(self, productID: Guid, removalOptions: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def BindDeferredMdilBinaries(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def GenerateXamlLightupXbfForCurrentLocale(self, PackageFamilyName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def AddLicenseForAppx(self, productID: Guid, pbLicense: POINTER(Byte), cbLicense: UInt32, pbPlayReadyHeader: POINTER(Byte), cbPlayReadyHeader: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def FixJunctionsForAppsOnSDCard(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMEnumerationManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{698d57c2-292d-4cf3-b73c-d95a6922ed9a}')
    @commethod(3)
    def get_AllApplications(self, ppAppEnum: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMApplicationInfoEnumerator), Filter: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_FILTER) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_AllTiles(self, ppTileEnum: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMTileInfoEnumerator), Filter: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_FILTER) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_AllTasks(self, ppTaskEnum: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMTaskInfoEnumerator), Filter: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_FILTER) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def get_AllExtensions(self, ppExtensionEnum: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMExtensionInfoEnumerator), Filter: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_FILTER) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def get_AllBackgroundServiceAgents(self, ppBSAEnum: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMBackgroundServiceAgentInfoEnumerator), Filter: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_FILTER) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_AllBackgroundWorkers(self, ppBSWEnum: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMBackgroundWorkerInfoEnumerator), Filter: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_FILTER) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_ApplicationInfo(self, ProductID: Guid, ppAppInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMApplicationInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_TileInfo(self, ProductID: Guid, TileID: win32more.Windows.Win32.Foundation.BSTR, ppTileInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMTileInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_TaskInfo(self, ProductID: Guid, TaskID: win32more.Windows.Win32.Foundation.BSTR, ppTaskInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMTaskInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_TaskInfoEx(self, ProductID: Guid, TaskID: win32more.Windows.Win32.Foundation.PWSTR, ppTaskInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMTaskInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_BackgroundServiceAgentInfo(self, BSAID: UInt32, ppTaskInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMBackgroundServiceAgentInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_AllLiveTileJobs(self, ppLiveTileJobEnum: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMLiveTileJobInfoEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_LiveTileJob(self, ProductID: Guid, TileID: win32more.Windows.Win32.Foundation.BSTR, RecurrenceType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_LIVETILE_RECURRENCE_TYPE, ppLiveTileJobInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMLiveTileJobInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_ApplicationInfoExternal(self, ProductID: Guid, ppAppInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMApplicationInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_FileHandlerGenericLogo(self, FileType: win32more.Windows.Win32.Foundation.BSTR, LogoSize: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_LOGO_SIZE, pLogo: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_ApplicationInfoFromAccessClaims(self, SysAppID0: win32more.Windows.Win32.Foundation.BSTR, SysAppID1: win32more.Windows.Win32.Foundation.BSTR, ppAppInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMApplicationInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_StartTileEnumeratorBlob(self, Filter: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_FILTER, pcTiles: POINTER(UInt32), ppTileBlobs: POINTER(POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_STARTTILEBLOB))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_StartAppEnumeratorBlob(self, Filter: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_FILTER, pcApps: POINTER(UInt32), ppAppBlobs: POINTER(POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_STARTAPPBLOB))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMExtensionCachedFileUpdaterInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e2d77509-4e58-4ba9-af7e-b642e370e1b0}')
    @commethod(3)
    def get_SupportsUpdates(self, pSupportsUpdates: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMExtensionContractInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e5666373-7ba1-467c-b819-b175db1c295b}')
    @commethod(3)
    def get_InvocationInfo(self, pAUMID: POINTER(win32more.Windows.Win32.Foundation.BSTR), pArgs: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMExtensionFileExtensionInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6b87cb6c-0b88-4989-a4ec-033714f710d4}')
    @commethod(3)
    def get_Name(self, pName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_DisplayName(self, pDisplayName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_Logo(self, LogoSize: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_LOGO_SIZE, pLogo: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def get_ContentType(self, FileType: win32more.Windows.Win32.Foundation.BSTR, pContentType: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def get_FileType(self, ContentType: win32more.Windows.Win32.Foundation.BSTR, pFileType: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_InvocationInfo(self, pImageUrn: POINTER(win32more.Windows.Win32.Foundation.BSTR), pParameters: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_AllFileTypes(self, pcbTypes: POINTER(UInt32), ppTypes: POINTER(POINTER(win32more.Windows.Win32.Foundation.BSTR))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMExtensionFileOpenPickerInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6dc91d25-9606-420c-9a78-e034a3418345}')
    @commethod(3)
    def get_AllFileTypes(self, pcTypes: POINTER(UInt32), ppTypes: POINTER(POINTER(win32more.Windows.Win32.Foundation.BSTR))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_SupportsAllFileTypes(self, pSupportsAllTypes: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMExtensionFileSavePickerInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{38005cba-f81a-493e-a0f8-922c8680da43}')
    @commethod(3)
    def get_AllFileTypes(self, pcTypes: POINTER(UInt32), ppTypes: POINTER(POINTER(win32more.Windows.Win32.Foundation.BSTR))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_SupportsAllFileTypes(self, pSupportsAllTypes: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMExtensionInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{49acde79-9788-4d0a-8aa0-1746afdb9e9d}')
    @commethod(3)
    def get_SupplierPID(self, pSupplierPID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_SupplierTaskID(self, pSupplierTID: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_Title(self, pTitle: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def get_IconPath(self, pIconPath: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def get_ExtraFile(self, pFilePath: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_InvocationInfo(self, pImageUrn: POINTER(win32more.Windows.Win32.Foundation.BSTR), pParameters: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMExtensionInfoEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{403b9e82-1171-4573-8e6f-6f33f39b83dd}')
    @commethod(3)
    def get_Next(self, ppExtensionInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMExtensionInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMExtensionProtocolInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1e3fa036-51eb-4453-baff-b8d8e4b46c8e}')
    @commethod(3)
    def get_Protocol(self, pProtocol: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_InvocationInfo(self, pImageUrn: POINTER(win32more.Windows.Win32.Foundation.BSTR), pParameters: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMExtensionShareTargetInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5471f48b-c65c-4656-8c70-242e31195fea}')
    @commethod(3)
    def get_AllFileTypes(self, pcTypes: POINTER(UInt32), ppTypes: POINTER(POINTER(win32more.Windows.Win32.Foundation.BSTR))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_AllDataFormats(self, pcDataFormats: POINTER(UInt32), ppDataFormats: POINTER(POINTER(win32more.Windows.Win32.Foundation.BSTR))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_SupportsAllFileTypes(self, pSupportsAllTypes: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMLiveTileJobInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6009a81f-4710-4697-b5f6-2208f6057b8e}')
    @commethod(3)
    def get_ProductID(self, pProductID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_TileID(self, pTileID: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_NextSchedule(self, pNextSchedule: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def set_NextSchedule(self, ftNextSchedule: win32more.Windows.Win32.Foundation.FILETIME) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def get_StartSchedule(self, pStartSchedule: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def set_StartSchedule(self, ftStartSchedule: win32more.Windows.Win32.Foundation.FILETIME) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_IntervalDuration(self, pIntervalDuration: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def set_IntervalDuration(self, ulIntervalDuration: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_RunForever(self, IsRunForever: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def set_RunForever(self, fRunForever: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_MaxRunCount(self, pMaxRunCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def set_MaxRunCount(self, ulMaxRunCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_RunCount(self, pRunCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def set_RunCount(self, ulRunCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_RecurrenceType(self, pRecurrenceType: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def set_RecurrenceType(self, ulRecurrenceType: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_TileXML(self, pTileXml: POINTER(POINTER(Byte)), pcbTileXml: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def set_TileXML(self, pTileXml: POINTER(Byte), cbTileXml: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_UrlXML(self, pUrlXML: POINTER(POINTER(Byte)), pcbUrlXML: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def set_UrlXML(self, pUrlXML: POINTER(Byte), cbUrlXML: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_AttemptCount(self, pAttemptCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def set_AttemptCount(self, ulAttemptCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_DownloadState(self, pDownloadState: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def set_DownloadState(self, ulDownloadState: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMLiveTileJobInfoEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bc042582-9415-4f36-9f99-06f104c07c03}')
    @commethod(3)
    def get_Next(self, ppLiveTileJobInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMLiveTileJobInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMTaskInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bf1d8c33-1bf5-4ee0-b549-6b9dd3834942}')
    @commethod(3)
    def get_ProductID(self, pProductID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_TaskID(self, pTaskID: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_NavigationPage(self, pNavigationPage: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def get_TaskTransition(self, pTaskTransition: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TRANSITION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def get_RuntimeType(self, pRuntimetype: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PACKMAN_RUNTIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ActivationPolicy(self, pActivationPolicy: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ACTIVATION_POLICY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_TaskType(self, pTaskType: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_InvocationInfo(self, pImageUrn: POINTER(win32more.Windows.Win32.Foundation.BSTR), pParameters: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_ImagePath(self, pImagePath: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_ImageParams(self, pImageParams: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_InstallRootFolder(self, pInstallRootFolder: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_DataRootFolder(self, pDataRootFolder: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_IsSingleInstanceHost(self, pIsSingleInstanceHost: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_IsInteropEnabled(self, pIsInteropEnabled: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_ApplicationState(self, pApplicationState: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_STATE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_InstallType(self, pInstallType: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_INSTALL_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_Version(self, pTargetMajorVersion: POINTER(Byte), pTargetMinorVersion: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_BitsPerPixel(self, pBitsPerPixel: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_SuppressesDehydration(self, pSuppressesDehydration: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_BackgroundExecutionAbilities(self, pBackgroundExecutionAbilities: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_IsOptedForExtendedMem(self, pIsOptedIn: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMTaskInfoEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0630b0f8-0bbc-4821-be74-c7995166ed2a}')
    @commethod(3)
    def get_Next(self, ppTaskInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMTaskInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMTileInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d1604833-2b08-4001-82cd-183ad734f752}')
    @commethod(3)
    def get_ProductID(self, pProductID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_TileID(self, pTileID: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_TemplateType(self, pTemplateType: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def get_HubPinnedState(self, HubType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_HUBTYPE, pPinned: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def get_HubPosition(self, HubType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_HUBTYPE, pPosition: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_IsNotified(self, pIsNotified: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_IsDefault(self, pIsDefault: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_TaskID(self, pTaskID: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_TileType(self, pStartTileType: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_STARTTILE_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_IsThemable(self, pIsThemable: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_PropertyById(self, PropID: UInt32, ppPropInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMTilePropertyInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_InvocationInfo(self, pImageUrn: POINTER(win32more.Windows.Win32.Foundation.BSTR), pParameters: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_PropertyEnum(self, ppTilePropEnum: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMTilePropertyEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_HubTileSize(self, HubType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_HUBTYPE, pSize: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_SIZE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def set_HubPosition(self, HubType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_HUBTYPE, Position: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def set_NotifiedState(self, Notified: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def set_HubPinnedState(self, HubType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_HUBTYPE, Pinned: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def set_HubTileSize(self, HubType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_HUBTYPE, Size: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_SIZE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def set_InvocationInfo(self, TaskName: win32more.Windows.Win32.Foundation.BSTR, TaskParameters: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_StartTileBlob(self, pBlob: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_STARTTILEBLOB)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_IsRestoring(self, pIsRestoring: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_IsAutoRestoreDisabled(self, pIsAutoRestoreDisabled: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def set_IsRestoring(self, Restoring: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def set_IsAutoRestoreDisabled(self, AutoRestoreDisabled: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMTileInfoEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ded83065-e462-4b2c-acb5-e39cea61c874}')
    @commethod(3)
    def get_Next(self, ppTileInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMTileInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMTilePropertyEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{cc4cd629-9047-4250-aac8-930e47812421}')
    @commethod(3)
    def get_Next(self, ppPropInfo: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.IPMTilePropertyInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPMTilePropertyInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6c2b8017-1efa-42a7-86c0-6d4b640bf528}')
    @commethod(3)
    def get_PropertyID(self, pPropID: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_PropertyValue(self, pPropValue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def set_Property(self, PropValue: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IValidate(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e482e5c6-e31e-4143-a2e6-dbc3d8e4b8d3}')
    @commethod(3)
    def OpenDatabase(self, szDatabase: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OpenCUB(self, szCUBFile: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CloseDatabase(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CloseCUB(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetDisplay(self, pDisplayFunction: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.LPDISPLAYVAL, pContext: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetStatus(self, pStatusFunction: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.LPEVALCOMCALLBACK, pContext: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Validate(self, wzICEs: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def LPDISPLAYVAL(pContext: VoidPtr, uiType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.RESULTTYPES, szwVal: win32more.Windows.Win32.Foundation.PWSTR, szwDescription: win32more.Windows.Win32.Foundation.PWSTR, szwLocation: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LPEVALCOMCALLBACK(iStatus: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.STATUSTYPES, szData: win32more.Windows.Win32.Foundation.PWSTR, pContext: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
MSIADVERTISEOPTIONFLAGS = Int32
MSIADVERTISEOPTIONFLAGS_INSTANCE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIADVERTISEOPTIONFLAGS = 1
MSIARCHITECTUREFLAGS = Int32
MSIARCHITECTUREFLAGS_X86: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIARCHITECTUREFLAGS = 1
MSIARCHITECTUREFLAGS_IA64: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIARCHITECTUREFLAGS = 2
MSIARCHITECTUREFLAGS_AMD64: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIARCHITECTUREFLAGS = 4
MSIARCHITECTUREFLAGS_ARM: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIARCHITECTUREFLAGS = 8
MSIASSEMBLYINFO = UInt32
MSIASSEMBLYINFO_NETASSEMBLY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIASSEMBLYINFO = 0
MSIASSEMBLYINFO_WIN32ASSEMBLY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIASSEMBLYINFO = 1
MSICODE = Int32
MSICODE_PRODUCT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICODE = 0
MSICODE_PATCH: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICODE = 1073741824
MSICOLINFO = Int32
MSICOLINFO_NAMES: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICOLINFO = 0
MSICOLINFO_TYPES: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICOLINFO = 1
MSICONDITION = Int32
MSICONDITION_FALSE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICONDITION = 0
MSICONDITION_TRUE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICONDITION = 1
MSICONDITION_NONE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICONDITION = 2
MSICONDITION_ERROR: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICONDITION = 3
MSICOSTTREE = Int32
MSICOSTTREE_SELFONLY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICOSTTREE = 0
MSICOSTTREE_CHILDREN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICOSTTREE = 1
MSICOSTTREE_PARENTS: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICOSTTREE = 2
MSICOSTTREE_RESERVED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSICOSTTREE = 3
MSIDBERROR = Int32
MSIDBERROR_INVALIDARG: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = -3
MSIDBERROR_MOREDATA: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = -2
MSIDBERROR_FUNCTIONERROR: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = -1
MSIDBERROR_NOERROR: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 0
MSIDBERROR_DUPLICATEKEY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 1
MSIDBERROR_REQUIRED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 2
MSIDBERROR_BADLINK: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 3
MSIDBERROR_OVERFLOW: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 4
MSIDBERROR_UNDERFLOW: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 5
MSIDBERROR_NOTINSET: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 6
MSIDBERROR_BADVERSION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 7
MSIDBERROR_BADCASE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 8
MSIDBERROR_BADGUID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 9
MSIDBERROR_BADWILDCARD: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 10
MSIDBERROR_BADIDENTIFIER: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 11
MSIDBERROR_BADLANGUAGE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 12
MSIDBERROR_BADFILENAME: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 13
MSIDBERROR_BADPATH: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 14
MSIDBERROR_BADCONDITION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 15
MSIDBERROR_BADFORMATTED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 16
MSIDBERROR_BADTEMPLATE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 17
MSIDBERROR_BADDEFAULTDIR: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 18
MSIDBERROR_BADREGPATH: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 19
MSIDBERROR_BADCUSTOMSOURCE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 20
MSIDBERROR_BADPROPERTY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 21
MSIDBERROR_MISSINGDATA: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 22
MSIDBERROR_BADCATEGORY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 23
MSIDBERROR_BADKEYTABLE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 24
MSIDBERROR_BADMAXMINVALUES: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 25
MSIDBERROR_BADCABINET: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 26
MSIDBERROR_BADSHORTCUT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 27
MSIDBERROR_STRINGOVERFLOW: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 28
MSIDBERROR_BADLOCALIZEATTRIB: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBERROR = 29
MSIDBSTATE = Int32
MSIDBSTATE_ERROR: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBSTATE = -1
MSIDBSTATE_READ: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBSTATE = 0
MSIDBSTATE_WRITE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIDBSTATE = 1
class MSIFILEHASHINFO(Structure):
    dwFileHashInfoSize: UInt32
    dwData: UInt32 * 4
MSIHANDLE = UInt32
MSIINSTALLCONTEXT = Int32
MSIINSTALLCONTEXT_FIRSTVISIBLE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT = 0
MSIINSTALLCONTEXT_NONE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT = 0
MSIINSTALLCONTEXT_USERMANAGED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT = 1
MSIINSTALLCONTEXT_USERUNMANAGED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT = 2
MSIINSTALLCONTEXT_MACHINE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT = 4
MSIINSTALLCONTEXT_ALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT = 7
MSIINSTALLCONTEXT_ALLUSERMANAGED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIINSTALLCONTEXT = 8
MSIMODIFY = Int32
MSIMODIFY_SEEK: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIMODIFY = -1
MSIMODIFY_REFRESH: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIMODIFY = 0
MSIMODIFY_INSERT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIMODIFY = 1
MSIMODIFY_UPDATE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIMODIFY = 2
MSIMODIFY_ASSIGN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIMODIFY = 3
MSIMODIFY_REPLACE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIMODIFY = 4
MSIMODIFY_MERGE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIMODIFY = 5
MSIMODIFY_DELETE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIMODIFY = 6
MSIMODIFY_INSERT_TEMPORARY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIMODIFY = 7
MSIMODIFY_VALIDATE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIMODIFY = 8
MSIMODIFY_VALIDATE_NEW: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIMODIFY = 9
MSIMODIFY_VALIDATE_FIELD: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIMODIFY = 10
MSIMODIFY_VALIDATE_DELETE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIMODIFY = 11
MSIOPENPACKAGEFLAGS = Int32
MSIOPENPACKAGEFLAGS_IGNOREMACHINESTATE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIOPENPACKAGEFLAGS = 1
MSIPATCHDATATYPE = Int32
MSIPATCH_DATATYPE_PATCHFILE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIPATCHDATATYPE = 0
MSIPATCH_DATATYPE_XMLPATH: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIPATCHDATATYPE = 1
MSIPATCH_DATATYPE_XMLBLOB: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIPATCHDATATYPE = 2
class MSIPATCHSEQUENCEINFOA(Structure):
    szPatchData: win32more.Windows.Win32.Foundation.PSTR
    ePatchDataType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIPATCHDATATYPE
    dwOrder: UInt32
    uStatus: UInt32
class MSIPATCHSEQUENCEINFOW(Structure):
    szPatchData: win32more.Windows.Win32.Foundation.PWSTR
    ePatchDataType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIPATCHDATATYPE
    dwOrder: UInt32
    uStatus: UInt32
MSIPATCHSEQUENCEINFO = UnicodeAlias('MSIPATCHSEQUENCEINFOW')
MSIPATCHSTATE = Int32
MSIPATCHSTATE_INVALID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIPATCHSTATE = 0
MSIPATCHSTATE_APPLIED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIPATCHSTATE = 1
MSIPATCHSTATE_SUPERSEDED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIPATCHSTATE = 2
MSIPATCHSTATE_OBSOLETED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIPATCHSTATE = 4
MSIPATCHSTATE_REGISTERED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIPATCHSTATE = 8
MSIPATCHSTATE_ALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIPATCHSTATE = 15
MSIRUNMODE = Int32
MSIRUNMODE_ADMIN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 0
MSIRUNMODE_ADVERTISE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 1
MSIRUNMODE_MAINTENANCE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 2
MSIRUNMODE_ROLLBACKENABLED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 3
MSIRUNMODE_LOGENABLED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 4
MSIRUNMODE_OPERATIONS: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 5
MSIRUNMODE_REBOOTATEND: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 6
MSIRUNMODE_REBOOTNOW: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 7
MSIRUNMODE_CABINET: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 8
MSIRUNMODE_SOURCESHORTNAMES: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 9
MSIRUNMODE_TARGETSHORTNAMES: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 10
MSIRUNMODE_RESERVED11: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 11
MSIRUNMODE_WINDOWS9X: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 12
MSIRUNMODE_ZAWENABLED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 13
MSIRUNMODE_RESERVED14: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 14
MSIRUNMODE_RESERVED15: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 15
MSIRUNMODE_SCHEDULED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 16
MSIRUNMODE_ROLLBACK: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 17
MSIRUNMODE_COMMIT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIRUNMODE = 18
MSISOURCETYPE = Int32
MSISOURCETYPE_UNKNOWN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSISOURCETYPE = 0
MSISOURCETYPE_NETWORK: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSISOURCETYPE = 1
MSISOURCETYPE_URL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSISOURCETYPE = 2
MSISOURCETYPE_MEDIA: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSISOURCETYPE = 4
MSITRANSACTION = Int32
MSITRANSACTION_CHAIN_EMBEDDEDUI: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSACTION = 1
MSITRANSACTION_JOIN_EXISTING_EMBEDDEDUI: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSACTION = 2
MSITRANSACTIONSTATE = UInt32
MSITRANSACTIONSTATE_ROLLBACK: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSACTIONSTATE = 0
MSITRANSACTIONSTATE_COMMIT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSACTIONSTATE = 1
MSITRANSFORM_ERROR = Int32
MSITRANSFORM_ERROR_ADDEXISTINGROW: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_ERROR = 1
MSITRANSFORM_ERROR_DELMISSINGROW: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_ERROR = 2
MSITRANSFORM_ERROR_ADDEXISTINGTABLE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_ERROR = 4
MSITRANSFORM_ERROR_DELMISSINGTABLE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_ERROR = 8
MSITRANSFORM_ERROR_UPDATEMISSINGROW: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_ERROR = 16
MSITRANSFORM_ERROR_CHANGECODEPAGE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_ERROR = 32
MSITRANSFORM_ERROR_VIEWTRANSFORM: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_ERROR = 256
MSITRANSFORM_ERROR_NONE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_ERROR = 0
MSITRANSFORM_VALIDATE = Int32
MSITRANSFORM_VALIDATE_LANGUAGE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_VALIDATE = 1
MSITRANSFORM_VALIDATE_PRODUCT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_VALIDATE = 2
MSITRANSFORM_VALIDATE_PLATFORM: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_VALIDATE = 4
MSITRANSFORM_VALIDATE_MAJORVERSION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_VALIDATE = 8
MSITRANSFORM_VALIDATE_MINORVERSION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_VALIDATE = 16
MSITRANSFORM_VALIDATE_UPDATEVERSION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_VALIDATE = 32
MSITRANSFORM_VALIDATE_NEWLESSBASEVERSION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_VALIDATE = 64
MSITRANSFORM_VALIDATE_NEWLESSEQUALBASEVERSION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_VALIDATE = 128
MSITRANSFORM_VALIDATE_NEWEQUALBASEVERSION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_VALIDATE = 256
MSITRANSFORM_VALIDATE_NEWGREATEREQUALBASEVERSION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_VALIDATE = 512
MSITRANSFORM_VALIDATE_NEWGREATERBASEVERSION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_VALIDATE = 1024
MSITRANSFORM_VALIDATE_UPGRADECODE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSITRANSFORM_VALIDATE = 2048
MsmMerge = Guid('{0adda830-2c26-11d2-ad65-00a0c9af11a6}')
PACKMAN_RUNTIME = Int32
PACKMAN_RUNTIME_NATIVE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PACKMAN_RUNTIME = 1
PACKMAN_RUNTIME_SILVERLIGHTMOBILE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PACKMAN_RUNTIME = 2
PACKMAN_RUNTIME_XNA: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PACKMAN_RUNTIME = 3
PACKMAN_RUNTIME_MODERN_NATIVE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PACKMAN_RUNTIME = 4
PACKMAN_RUNTIME_JUPITER: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PACKMAN_RUNTIME = 5
PACKMAN_RUNTIME_INVALID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PACKMAN_RUNTIME = 6
class PATCH_IGNORE_RANGE(Structure):
    OffsetInOldFile: UInt32
    LengthInBytes: UInt32
class PATCH_INTERLEAVE_MAP(Structure):
    CountRanges: UInt32
    Range: _Anonymous_e__Struct * 1
    class _Anonymous_e__Struct(Structure):
        OldOffset: UInt32
        OldLength: UInt32
        NewLength: UInt32
class PATCH_OLD_FILE_INFO_A(Structure):
    SizeOfThisStruct: UInt32
    OldFileName: win32more.Windows.Win32.Foundation.PSTR
    IgnoreRangeCount: UInt32
    IgnoreRangeArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_IGNORE_RANGE)
    RetainRangeCount: UInt32
    RetainRangeArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_RETAIN_RANGE)
class PATCH_OLD_FILE_INFO_H(Structure):
    SizeOfThisStruct: UInt32
    OldFileHandle: win32more.Windows.Win32.Foundation.HANDLE
    IgnoreRangeCount: UInt32
    IgnoreRangeArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_IGNORE_RANGE)
    RetainRangeCount: UInt32
    RetainRangeArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_RETAIN_RANGE)
class PATCH_OLD_FILE_INFO_W(Structure):
    SizeOfThisStruct: UInt32
    OldFileName: win32more.Windows.Win32.Foundation.PWSTR
    IgnoreRangeCount: UInt32
    IgnoreRangeArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_IGNORE_RANGE)
    RetainRangeCount: UInt32
    RetainRangeArray: POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_RETAIN_RANGE)
PATCH_OLD_FILE_INFO = UnicodeAlias('PATCH_OLD_FILE_INFO_W')
class PATCH_OPTION_DATA(Structure):
    SizeOfThisStruct: UInt32
    SymbolOptionFlags: UInt32
    NewFileSymbolPath: win32more.Windows.Win32.Foundation.PSTR
    OldFileSymbolPathArray: POINTER(win32more.Windows.Win32.Foundation.PSTR)
    ExtendedOptionFlags: UInt32
    SymLoadCallback: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PPATCH_SYMLOAD_CALLBACK
    SymLoadContext: VoidPtr
    InterleaveMapArray: POINTER(POINTER(win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PATCH_INTERLEAVE_MAP))
    MaxLzxWindowSize: UInt32
class PATCH_RETAIN_RANGE(Structure):
    OffsetInOldFile: UInt32
    LengthInBytes: UInt32
    OffsetInNewFile: UInt32
@winfunctype_pointer
def PINSTALLUI_HANDLER_RECORD(pvContext: VoidPtr, iMessageType: UInt32, hRecord: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE) -> Int32: ...
class PMSIHANDLE(Structure):
    m_h: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.MSIHANDLE
PMSvc = Guid('{b9e511fc-e364-497a-a121-b7b3612cedce}')
PM_ACTIVATION_POLICY = Int32
PM_ACTIVATION_POLICY_RESUME: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ACTIVATION_POLICY = 0
PM_ACTIVATION_POLICY_RESUMESAMEPARAMS: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ACTIVATION_POLICY = 1
PM_ACTIVATION_POLICY_REPLACE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ACTIVATION_POLICY = 2
PM_ACTIVATION_POLICY_REPLACESAMEPARAMS: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ACTIVATION_POLICY = 3
PM_ACTIVATION_POLICY_MULTISESSION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ACTIVATION_POLICY = 4
PM_ACTIVATION_POLICY_REPLACE_IGNOREFOREGROUND: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ACTIVATION_POLICY = 5
PM_ACTIVATION_POLICY_UNKNOWN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ACTIVATION_POLICY = 6
PM_ACTIVATION_POLICY_INVALID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ACTIVATION_POLICY = 7
PM_APPLICATION_HUBTYPE = Int32
PM_APPLICATION_HUBTYPE_NONMUSIC: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_HUBTYPE = 0
PM_APPLICATION_HUBTYPE_MUSIC: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_HUBTYPE = 1
PM_APPLICATION_HUBTYPE_INVALID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_HUBTYPE = 2
PM_APPLICATION_INSTALL_TYPE = Int32
PM_APPLICATION_INSTALL_NORMAL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_INSTALL_TYPE = 0
PM_APPLICATION_INSTALL_IN_ROM: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_INSTALL_TYPE = 1
PM_APPLICATION_INSTALL_PA: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_INSTALL_TYPE = 2
PM_APPLICATION_INSTALL_DEBUG: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_INSTALL_TYPE = 3
PM_APPLICATION_INSTALL_ENTERPRISE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_INSTALL_TYPE = 4
PM_APPLICATION_INSTALL_INVALID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_INSTALL_TYPE = 5
PM_APPLICATION_STATE = Int32
PM_APPLICATION_STATE_MIN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_STATE = 0
PM_APPLICATION_STATE_INSTALLED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_STATE = 1
PM_APPLICATION_STATE_INSTALLING: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_STATE = 2
PM_APPLICATION_STATE_UPDATING: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_STATE = 3
PM_APPLICATION_STATE_UNINSTALLING: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_STATE = 4
PM_APPLICATION_STATE_LICENSE_UPDATING: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_STATE = 5
PM_APPLICATION_STATE_MOVING: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_STATE = 6
PM_APPLICATION_STATE_DISABLED_SD_CARD: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_STATE = 7
PM_APPLICATION_STATE_DISABLED_ENTERPRISE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_STATE = 8
PM_APPLICATION_STATE_DISABLED_BACKING_UP: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_STATE = 9
PM_APPLICATION_STATE_DISABLED_MDIL_BINDING: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_STATE = 10
PM_APPLICATION_STATE_MAX: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_STATE = 10
PM_APPLICATION_STATE_INVALID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_STATE = 11
class PM_APPTASKTYPE(Structure):
    ProductID: Guid
    TaskType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TYPE
PM_APP_GENRE = Int32
PM_APP_GENRE_GAMES: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APP_GENRE = 0
PM_APP_GENRE_OTHER: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APP_GENRE = 1
PM_APP_GENRE_INVALID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APP_GENRE = 2
class PM_BSATASKID(Structure):
    ProductID: Guid
    TaskID: win32more.Windows.Win32.Foundation.BSTR
class PM_BWTASKID(Structure):
    ProductID: Guid
    TaskID: win32more.Windows.Win32.Foundation.BSTR
PM_ENUM_APP_FILTER = Int32
PM_APP_FILTER_ALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_APP_FILTER = 0
PM_APP_FILTER_VISIBLE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_APP_FILTER = 1
PM_APP_FILTER_GENRE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_APP_FILTER = 2
PM_APP_FILTER_NONGAMES: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_APP_FILTER = 3
PM_APP_FILTER_HUBTYPE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_APP_FILTER = 4
PM_APP_FILTER_PINABLEONKIDZONE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_APP_FILTER = 5
PM_APP_FILTER_ALL_INCLUDE_MODERN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_APP_FILTER = 6
PM_APP_FILTER_FRAMEWORK: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_APP_FILTER = 7
PM_APP_FILTER_MAX: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_APP_FILTER = 8
PM_ENUM_BSA_FILTER = Int32
PM_ENUM_BSA_FILTER_ALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_BSA_FILTER = 26
PM_ENUM_BSA_FILTER_BY_TASKID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_BSA_FILTER = 27
PM_ENUM_BSA_FILTER_BY_PRODUCTID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_BSA_FILTER = 28
PM_ENUM_BSA_FILTER_BY_PERIODIC: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_BSA_FILTER = 29
PM_ENUM_BSA_FILTER_BY_ALL_LAUNCHONBOOT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_BSA_FILTER = 30
PM_ENUM_BSA_FILTER_MAX: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_BSA_FILTER = 31
PM_ENUM_BW_FILTER = Int32
PM_ENUM_BW_FILTER_BOOTWORKER_ALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_BW_FILTER = 31
PM_ENUM_BW_FILTER_BY_TASKID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_BW_FILTER = 32
PM_ENUM_BW_FILTER_MAX: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_BW_FILTER = 33
PM_ENUM_EXTENSION_FILTER = Int32
PM_ENUM_EXTENSION_FILTER_BY_CONSUMER: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_EXTENSION_FILTER = 17
PM_ENUM_EXTENSION_FILTER_APPCONNECT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_EXTENSION_FILTER = 17
PM_ENUM_EXTENSION_FILTER_PROTOCOL_ALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_EXTENSION_FILTER = 18
PM_ENUM_EXTENSION_FILTER_FTASSOC_FILETYPE_ALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_EXTENSION_FILTER = 19
PM_ENUM_EXTENSION_FILTER_FTASSOC_CONTENTTYPE_ALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_EXTENSION_FILTER = 20
PM_ENUM_EXTENSION_FILTER_FTASSOC_APPLICATION_ALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_EXTENSION_FILTER = 21
PM_ENUM_EXTENSION_FILTER_SHARETARGET_ALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_EXTENSION_FILTER = 22
PM_ENUM_EXTENSION_FILTER_FILEOPENPICKER_ALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_EXTENSION_FILTER = 23
PM_ENUM_EXTENSION_FILTER_FILESAVEPICKER_ALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_EXTENSION_FILTER = 24
PM_ENUM_EXTENSION_FILTER_CACHEDFILEUPDATER_ALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_EXTENSION_FILTER = 25
PM_ENUM_EXTENSION_FILTER_MAX: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_EXTENSION_FILTER = 26
class PM_ENUM_FILTER(Structure):
    FilterType: Int32
    FilterParameter: _FilterParameter_e__Union
    class _FilterParameter_e__Union(Union):
        Dummy: Int32
        Genre: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APP_GENRE
        AppHubType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_HUBTYPE
        HubType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_HUBTYPE
        Tasktype: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TYPE
        TaskProductID: Guid
        TileProductID: Guid
        AppTaskType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPTASKTYPE
        Consumer: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_EXTENSIONCONSUMER
        BSATask: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_BSATASKID
        BSAProductID: Guid
        BWTask: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_BWTASKID
        ProtocolName: win32more.Windows.Win32.Foundation.BSTR
        FileType: win32more.Windows.Win32.Foundation.BSTR
        ContentType: win32more.Windows.Win32.Foundation.BSTR
        AppSupportedFileExtPID: Guid
        ShareTargetFileType: win32more.Windows.Win32.Foundation.BSTR
PM_ENUM_TASK_FILTER = Int32
PM_TASK_FILTER_APP_ALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_TASK_FILTER = 12
PM_TASK_FILTER_TASK_TYPE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_TASK_FILTER = 13
PM_TASK_FILTER_DEHYD_SUPRESSING: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_TASK_FILTER = 14
PM_TASK_FILTER_APP_TASK_TYPE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_TASK_FILTER = 15
PM_TASK_FILTER_BGEXECUTION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_TASK_FILTER = 16
PM_TASK_FILTER_MAX: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_TASK_FILTER = 17
PM_ENUM_TILE_FILTER = Int32
PM_TILE_FILTER_APPLIST: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_TILE_FILTER = 8
PM_TILE_FILTER_PINNED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_TILE_FILTER = 9
PM_TILE_FILTER_HUBTYPE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_TILE_FILTER = 10
PM_TILE_FILTER_APP_ALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_TILE_FILTER = 11
PM_TILE_FILTER_MAX: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_ENUM_TILE_FILTER = 12
class PM_EXTENSIONCONSUMER(Structure):
    ConsumerPID: Guid
    ExtensionID: win32more.Windows.Win32.Foundation.BSTR
class PM_INSTALLINFO(Structure):
    ProductID: Guid
    PackagePath: win32more.Windows.Win32.Foundation.BSTR
    InstanceID: Guid
    pbLicense: POINTER(Byte)
    cbLicense: UInt32
    IsUninstallDisabled: win32more.Windows.Win32.Foundation.BOOL
    DeploymentOptions: UInt32
    OfferID: Guid
    MarketplaceAppVersion: win32more.Windows.Win32.Foundation.BSTR
class PM_INVOCATIONINFO(Structure):
    URIBaseOrAUMID: win32more.Windows.Win32.Foundation.BSTR
    URIFragmentOrArgs: win32more.Windows.Win32.Foundation.BSTR
PM_LIVETILE_RECURRENCE_TYPE = Int32
PM_LIVETILE_RECURRENCE_TYPE_INSTANT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_LIVETILE_RECURRENCE_TYPE = 0
PM_LIVETILE_RECURRENCE_TYPE_ONETIME: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_LIVETILE_RECURRENCE_TYPE = 1
PM_LIVETILE_RECURRENCE_TYPE_INTERVAL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_LIVETILE_RECURRENCE_TYPE = 2
PM_LIVETILE_RECURRENCE_TYPE_MAX: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_LIVETILE_RECURRENCE_TYPE = 2
PM_LOGO_SIZE = Int32
PM_LOGO_SIZE_SMALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_LOGO_SIZE = 0
PM_LOGO_SIZE_MEDIUM: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_LOGO_SIZE = 1
PM_LOGO_SIZE_LARGE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_LOGO_SIZE = 2
PM_LOGO_SIZE_INVALID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_LOGO_SIZE = 3
class PM_STARTAPPBLOB(Structure):
    cbSize: UInt32
    ProductID: Guid
    AppTitle: win32more.Windows.Win32.Foundation.BSTR
    IconPath: win32more.Windows.Win32.Foundation.BSTR
    IsUninstallable: win32more.Windows.Win32.Foundation.BOOL
    AppInstallType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_INSTALL_TYPE
    InstanceID: Guid
    State: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_APPLICATION_STATE
    IsModern: win32more.Windows.Win32.Foundation.BOOL
    IsModernLightUp: win32more.Windows.Win32.Foundation.BOOL
    LightUpSupportMask: UInt16
class PM_STARTTILEBLOB(Structure):
    cbSize: UInt32
    ProductID: Guid
    TileID: win32more.Windows.Win32.Foundation.BSTR
    TemplateType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE
    HubPosition: UInt32 * 32
    HubVisibilityBitmask: UInt32
    IsDefault: win32more.Windows.Win32.Foundation.BOOL
    TileType: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_STARTTILE_TYPE
    pbPropBlob: POINTER(Byte)
    cbPropBlob: UInt32
    IsRestoring: win32more.Windows.Win32.Foundation.BOOL
    IsModern: win32more.Windows.Win32.Foundation.BOOL
    InvocationInfo: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_INVOCATIONINFO
PM_STARTTILE_TYPE = Int32
PM_STARTTILE_TYPE_PRIMARY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_STARTTILE_TYPE = 1
PM_STARTTILE_TYPE_SECONDARY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_STARTTILE_TYPE = 2
PM_STARTTILE_TYPE_APPLIST: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_STARTTILE_TYPE = 3
PM_STARTTILE_TYPE_APPLISTPRIMARY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_STARTTILE_TYPE = 4
PM_STARTTILE_TYPE_INVALID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_STARTTILE_TYPE = 5
PM_TASK_TRANSITION = Int32
PM_TASK_TRANSITION_DEFAULT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TRANSITION = 0
PM_TASK_TRANSITION_NONE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TRANSITION = 1
PM_TASK_TRANSITION_TURNSTILE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TRANSITION = 2
PM_TASK_TRANSITION_SLIDE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TRANSITION = 3
PM_TASK_TRANSITION_SWIVEL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TRANSITION = 4
PM_TASK_TRANSITION_READERBOARD: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TRANSITION = 5
PM_TASK_TRANSITION_CUSTOM: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TRANSITION = 6
PM_TASK_TRANSITION_INVALID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TRANSITION = 7
PM_TASK_TYPE = Int32
PM_TASK_TYPE_NORMAL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TYPE = 0
PM_TASK_TYPE_DEFAULT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TYPE = 1
PM_TASK_TYPE_SETTINGS: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TYPE = 2
PM_TASK_TYPE_BACKGROUNDSERVICEAGENT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TYPE = 3
PM_TASK_TYPE_BACKGROUNDWORKER: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TYPE = 4
PM_TASK_TYPE_INVALID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TASK_TYPE = 5
PM_TILE_HUBTYPE = Int32
PM_TILE_HUBTYPE_MUSIC: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_HUBTYPE = 1
PM_TILE_HUBTYPE_MOSETTINGS: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_HUBTYPE = 268435456
PM_TILE_HUBTYPE_GAMES: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_HUBTYPE = 536870912
PM_TILE_HUBTYPE_APPLIST: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_HUBTYPE = 1073741824
PM_TILE_HUBTYPE_STARTMENU: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_HUBTYPE = -2147483648
PM_TILE_HUBTYPE_LOCKSCREEN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_HUBTYPE = 16777216
PM_TILE_HUBTYPE_KIDZONE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_HUBTYPE = 33554432
PM_TILE_HUBTYPE_CACHED: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_HUBTYPE = 67108864
PM_TILE_HUBTYPE_INVALID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_HUBTYPE = 67108865
PM_TILE_SIZE = Int32
PM_TILE_SIZE_SMALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_SIZE = 0
PM_TILE_SIZE_MEDIUM: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_SIZE = 1
PM_TILE_SIZE_LARGE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_SIZE = 2
PM_TILE_SIZE_SQUARE310X310: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_SIZE = 3
PM_TILE_SIZE_TALL150X310: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_SIZE = 4
PM_TILE_SIZE_INVALID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.PM_TILE_SIZE = 5
class PM_UPDATEINFO(Structure):
    ProductID: Guid
    PackagePath: win32more.Windows.Win32.Foundation.BSTR
    InstanceID: Guid
    pbLicense: POINTER(Byte)
    cbLicense: UInt32
    MarketplaceAppVersion: win32more.Windows.Win32.Foundation.BSTR
    DeploymentOptions: UInt32
class PM_UPDATEINFO_LEGACY(Structure):
    ProductID: Guid
    PackagePath: win32more.Windows.Win32.Foundation.BSTR
    InstanceID: Guid
    pbLicense: POINTER(Byte)
    cbLicense: UInt32
    MarketplaceAppVersion: win32more.Windows.Win32.Foundation.BSTR
@winfunctype_pointer
def PPATCH_PROGRESS_CALLBACK(CallbackContext: VoidPtr, CurrentPosition: UInt32, MaximumPosition: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PPATCH_SYMLOAD_CALLBACK(WhichFile: UInt32, SymbolFileName: win32more.Windows.Win32.Foundation.PSTR, SymType: UInt32, SymbolFileCheckSum: UInt32, SymbolFileTimeDate: UInt32, ImageFileCheckSum: UInt32, ImageFileTimeDate: UInt32, CallbackContext: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
class PROTECTED_FILE_DATA(Structure):
    FileName: Char * 260
    FileNumber: UInt32
QUERYASMINFO_FLAGS = UInt32
QUERYASMINFO_FLAG_VALIDATE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.QUERYASMINFO_FLAGS = 1
REINSTALLMODE = Int32
REINSTALLMODE_REPAIR: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.REINSTALLMODE = 1
REINSTALLMODE_FILEMISSING: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.REINSTALLMODE = 2
REINSTALLMODE_FILEOLDERVERSION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.REINSTALLMODE = 4
REINSTALLMODE_FILEEQUALVERSION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.REINSTALLMODE = 8
REINSTALLMODE_FILEEXACT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.REINSTALLMODE = 16
REINSTALLMODE_FILEVERIFY: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.REINSTALLMODE = 32
REINSTALLMODE_FILEREPLACE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.REINSTALLMODE = 64
REINSTALLMODE_MACHINEDATA: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.REINSTALLMODE = 128
REINSTALLMODE_USERDATA: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.REINSTALLMODE = 256
REINSTALLMODE_SHORTCUT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.REINSTALLMODE = 512
REINSTALLMODE_PACKAGE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.REINSTALLMODE = 1024
RESULTTYPES = Int32
ieUnknown: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.RESULTTYPES = 0
ieError: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.RESULTTYPES = 1
ieWarning: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.RESULTTYPES = 2
ieInfo: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.RESULTTYPES = 3
SCRIPTFLAGS = Int32
SCRIPTFLAGS_CACHEINFO: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.SCRIPTFLAGS = 1
SCRIPTFLAGS_SHORTCUTS: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.SCRIPTFLAGS = 4
SCRIPTFLAGS_MACHINEASSIGN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.SCRIPTFLAGS = 8
SCRIPTFLAGS_REGDATA_CNFGINFO: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.SCRIPTFLAGS = 32
SCRIPTFLAGS_VALIDATE_TRANSFORMS_LIST: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.SCRIPTFLAGS = 64
SCRIPTFLAGS_REGDATA_CLASSINFO: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.SCRIPTFLAGS = 128
SCRIPTFLAGS_REGDATA_EXTENSIONINFO: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.SCRIPTFLAGS = 256
SCRIPTFLAGS_REGDATA_APPINFO: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.SCRIPTFLAGS = 384
SCRIPTFLAGS_REGDATA: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.SCRIPTFLAGS = 416
STATUSTYPES = Int32
ieStatusGetCUB: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.STATUSTYPES = 0
ieStatusICECount: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.STATUSTYPES = 1
ieStatusMerge: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.STATUSTYPES = 2
ieStatusSummaryInfo: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.STATUSTYPES = 3
ieStatusCreateEngine: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.STATUSTYPES = 4
ieStatusStarting: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.STATUSTYPES = 5
ieStatusRunICE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.STATUSTYPES = 6
ieStatusShutdown: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.STATUSTYPES = 7
ieStatusSuccess: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.STATUSTYPES = 8
ieStatusFail: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.STATUSTYPES = 9
ieStatusCancel: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.STATUSTYPES = 10
TILE_TEMPLATE_TYPE = Int32
TILE_TEMPLATE_INVALID: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 0
TILE_TEMPLATE_FLIP: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 5
TILE_TEMPLATE_DEEPLINK: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 13
TILE_TEMPLATE_CYCLE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 14
TILE_TEMPLATE_METROCOUNT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 1
TILE_TEMPLATE_AGILESTORE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 2
TILE_TEMPLATE_GAMES: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 3
TILE_TEMPLATE_CALENDAR: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 4
TILE_TEMPLATE_MUSICVIDEO: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 7
TILE_TEMPLATE_PEOPLE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 10
TILE_TEMPLATE_CONTACT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 11
TILE_TEMPLATE_GROUP: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 12
TILE_TEMPLATE_DEFAULT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 15
TILE_TEMPLATE_BADGE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 16
TILE_TEMPLATE_BLOCK: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 17
TILE_TEMPLATE_TEXT01: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 18
TILE_TEMPLATE_TEXT02: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 19
TILE_TEMPLATE_TEXT03: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 20
TILE_TEMPLATE_TEXT04: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 21
TILE_TEMPLATE_TEXT05: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 22
TILE_TEMPLATE_TEXT06: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 23
TILE_TEMPLATE_TEXT07: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 24
TILE_TEMPLATE_TEXT08: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 25
TILE_TEMPLATE_TEXT09: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 26
TILE_TEMPLATE_TEXT10: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 27
TILE_TEMPLATE_TEXT11: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 28
TILE_TEMPLATE_IMAGE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 29
TILE_TEMPLATE_IMAGECOLLECTION: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 30
TILE_TEMPLATE_IMAGEANDTEXT01: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 31
TILE_TEMPLATE_IMAGEANDTEXT02: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 32
TILE_TEMPLATE_BLOCKANDTEXT01: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 33
TILE_TEMPLATE_BLOCKANDTEXT02: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 34
TILE_TEMPLATE_PEEKIMAGEANDTEXT01: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 35
TILE_TEMPLATE_PEEKIMAGEANDTEXT02: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 36
TILE_TEMPLATE_PEEKIMAGEANDTEXT03: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 37
TILE_TEMPLATE_PEEKIMAGEANDTEXT04: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 38
TILE_TEMPLATE_PEEKIMAGE01: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 39
TILE_TEMPLATE_PEEKIMAGE02: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 40
TILE_TEMPLATE_PEEKIMAGE03: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 41
TILE_TEMPLATE_PEEKIMAGE04: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 42
TILE_TEMPLATE_PEEKIMAGE05: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 43
TILE_TEMPLATE_PEEKIMAGE06: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 44
TILE_TEMPLATE_PEEKIMAGECOLLECTION01: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 45
TILE_TEMPLATE_PEEKIMAGECOLLECTION02: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 46
TILE_TEMPLATE_PEEKIMAGECOLLECTION03: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 47
TILE_TEMPLATE_PEEKIMAGECOLLECTION04: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 48
TILE_TEMPLATE_PEEKIMAGECOLLECTION05: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 49
TILE_TEMPLATE_PEEKIMAGECOLLECTION06: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 50
TILE_TEMPLATE_SMALLIMAGEANDTEXT01: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 51
TILE_TEMPLATE_SMALLIMAGEANDTEXT02: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 52
TILE_TEMPLATE_SMALLIMAGEANDTEXT03: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 53
TILE_TEMPLATE_SMALLIMAGEANDTEXT04: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 54
TILE_TEMPLATE_SMALLIMAGEANDTEXT05: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 55
TILE_TEMPLATE_METROCOUNTQUEUE: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 56
TILE_TEMPLATE_SEARCH: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 57
TILE_TEMPLATE_TILEFLYOUT01: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 58
TILE_TEMPLATE_FOLDER: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 59
TILE_TEMPLATE_ALL: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.TILE_TEMPLATE_TYPE = 100
USERINFOSTATE = Int32
USERINFOSTATE_MOREDATA: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.USERINFOSTATE = -3
USERINFOSTATE_INVALIDARG: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.USERINFOSTATE = -2
USERINFOSTATE_UNKNOWN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.USERINFOSTATE = -1
USERINFOSTATE_ABSENT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.USERINFOSTATE = 0
USERINFOSTATE_PRESENT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.USERINFOSTATE = 1
msidbAssemblyAttributes = Int32
msidbAssemblyAttributesURT: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbAssemblyAttributes = 0
msidbAssemblyAttributesWin32: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbAssemblyAttributes = 1
msidbClassAttributes = Int32
msidbClassAttributesRelativePath: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbClassAttributes = 1
msidbComponentAttributes = Int32
msidbComponentAttributesLocalOnly: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbComponentAttributes = 0
msidbComponentAttributesSourceOnly: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbComponentAttributes = 1
msidbComponentAttributesOptional: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbComponentAttributes = 2
msidbComponentAttributesRegistryKeyPath: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbComponentAttributes = 4
msidbComponentAttributesSharedDllRefCount: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbComponentAttributes = 8
msidbComponentAttributesPermanent: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbComponentAttributes = 16
msidbComponentAttributesODBCDataSource: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbComponentAttributes = 32
msidbComponentAttributesTransitive: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbComponentAttributes = 64
msidbComponentAttributesNeverOverwrite: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbComponentAttributes = 128
msidbComponentAttributes64bit: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbComponentAttributes = 256
msidbComponentAttributesDisableRegistryReflection: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbComponentAttributes = 512
msidbComponentAttributesUninstallOnSupersedence: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbComponentAttributes = 1024
msidbComponentAttributesShared: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbComponentAttributes = 2048
msidbControlAttributes = Int32
msidbControlAttributesVisible: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 1
msidbControlAttributesEnabled: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 2
msidbControlAttributesSunken: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 4
msidbControlAttributesIndirect: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 8
msidbControlAttributesInteger: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 16
msidbControlAttributesRTLRO: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 32
msidbControlAttributesRightAligned: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 64
msidbControlAttributesLeftScroll: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 128
msidbControlAttributesBiDi: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 224
msidbControlAttributesTransparent: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 65536
msidbControlAttributesNoPrefix: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 131072
msidbControlAttributesNoWrap: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 262144
msidbControlAttributesFormatSize: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 524288
msidbControlAttributesUsersLanguage: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 1048576
msidbControlAttributesMultiline: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 65536
msidbControlAttributesPasswordInput: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 2097152
msidbControlAttributesProgress95: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 65536
msidbControlAttributesRemovableVolume: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 65536
msidbControlAttributesFixedVolume: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 131072
msidbControlAttributesRemoteVolume: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 262144
msidbControlAttributesCDROMVolume: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 524288
msidbControlAttributesRAMDiskVolume: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 1048576
msidbControlAttributesFloppyVolume: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 2097152
msidbControlShowRollbackCost: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 4194304
msidbControlAttributesSorted: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 65536
msidbControlAttributesComboList: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 131072
msidbControlAttributesImageHandle: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 65536
msidbControlAttributesPushLike: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 131072
msidbControlAttributesBitmap: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 262144
msidbControlAttributesIcon: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 524288
msidbControlAttributesFixedSize: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 1048576
msidbControlAttributesIconSize16: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 2097152
msidbControlAttributesIconSize32: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 4194304
msidbControlAttributesIconSize48: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 6291456
msidbControlAttributesElevationShield: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 8388608
msidbControlAttributesHasBorder: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbControlAttributes = 16777216
msidbCustomActionType = Int32
msidbCustomActionTypeDll: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 1
msidbCustomActionTypeExe: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 2
msidbCustomActionTypeTextData: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 3
msidbCustomActionTypeJScript: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 5
msidbCustomActionTypeVBScript: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 6
msidbCustomActionTypeInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 7
msidbCustomActionTypeBinaryData: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 0
msidbCustomActionTypeSourceFile: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 16
msidbCustomActionTypeDirectory: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 32
msidbCustomActionTypeProperty: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 48
msidbCustomActionTypeContinue: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 64
msidbCustomActionTypeAsync: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 128
msidbCustomActionTypeFirstSequence: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 256
msidbCustomActionTypeOncePerProcess: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 512
msidbCustomActionTypeClientRepeat: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 768
msidbCustomActionTypeInScript: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 1024
msidbCustomActionTypeRollback: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 256
msidbCustomActionTypeCommit: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 512
msidbCustomActionTypeNoImpersonate: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 2048
msidbCustomActionTypeTSAware: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 16384
msidbCustomActionType64BitScript: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 4096
msidbCustomActionTypeHideTarget: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 8192
msidbCustomActionTypePatchUninstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbCustomActionType = 32768
msidbDialogAttributes = Int32
msidbDialogAttributesVisible: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbDialogAttributes = 1
msidbDialogAttributesModal: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbDialogAttributes = 2
msidbDialogAttributesMinimize: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbDialogAttributes = 4
msidbDialogAttributesSysModal: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbDialogAttributes = 8
msidbDialogAttributesKeepModeless: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbDialogAttributes = 16
msidbDialogAttributesTrackDiskSpace: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbDialogAttributes = 32
msidbDialogAttributesUseCustomPalette: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbDialogAttributes = 64
msidbDialogAttributesRTLRO: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbDialogAttributes = 128
msidbDialogAttributesRightAligned: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbDialogAttributes = 256
msidbDialogAttributesLeftScroll: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbDialogAttributes = 512
msidbDialogAttributesBiDi: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbDialogAttributes = 896
msidbDialogAttributesError: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbDialogAttributes = 65536
msidbEmbeddedUIAttributes = Int32
msidbEmbeddedUI: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbEmbeddedUIAttributes = 1
msidbEmbeddedHandlesBasic: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbEmbeddedUIAttributes = 2
msidbFeatureAttributes = Int32
msidbFeatureAttributesFavorLocal: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFeatureAttributes = 0
msidbFeatureAttributesFavorSource: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFeatureAttributes = 1
msidbFeatureAttributesFollowParent: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFeatureAttributes = 2
msidbFeatureAttributesFavorAdvertise: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFeatureAttributes = 4
msidbFeatureAttributesDisallowAdvertise: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFeatureAttributes = 8
msidbFeatureAttributesUIDisallowAbsent: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFeatureAttributes = 16
msidbFeatureAttributesNoUnsupportedAdvertise: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFeatureAttributes = 32
msidbFileAttributes = Int32
msidbFileAttributesReadOnly: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFileAttributes = 1
msidbFileAttributesHidden: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFileAttributes = 2
msidbFileAttributesSystem: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFileAttributes = 4
msidbFileAttributesReserved0: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFileAttributes = 8
msidbFileAttributesIsolatedComp: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFileAttributes = 16
msidbFileAttributesReserved1: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFileAttributes = 64
msidbFileAttributesReserved2: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFileAttributes = 128
msidbFileAttributesReserved3: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFileAttributes = 256
msidbFileAttributesVital: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFileAttributes = 512
msidbFileAttributesChecksum: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFileAttributes = 1024
msidbFileAttributesPatchAdded: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFileAttributes = 4096
msidbFileAttributesNoncompressed: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFileAttributes = 8192
msidbFileAttributesCompressed: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFileAttributes = 16384
msidbFileAttributesReserved4: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbFileAttributes = 32768
msidbIniFileAction = Int32
msidbIniFileActionAddLine: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbIniFileAction = 0
msidbIniFileActionCreateLine: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbIniFileAction = 1
msidbIniFileActionRemoveLine: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbIniFileAction = 2
msidbIniFileActionAddTag: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbIniFileAction = 3
msidbIniFileActionRemoveTag: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbIniFileAction = 4
msidbLocatorType = Int32
msidbLocatorTypeDirectory: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbLocatorType = 0
msidbLocatorTypeFileName: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbLocatorType = 1
msidbLocatorTypeRawValue: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbLocatorType = 2
msidbLocatorType64bit: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbLocatorType = 16
msidbMoveFileOptions = Int32
msidbMoveFileOptionsMove: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbMoveFileOptions = 1
msidbODBCDataSourceRegistration = Int32
msidbODBCDataSourceRegistrationPerMachine: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbODBCDataSourceRegistration = 0
msidbODBCDataSourceRegistrationPerUser: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbODBCDataSourceRegistration = 1
msidbPatchAttributes = Int32
msidbPatchAttributesNonVital: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbPatchAttributes = 1
msidbRegistryRoot = Int32
msidbRegistryRootClassesRoot: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbRegistryRoot = 0
msidbRegistryRootCurrentUser: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbRegistryRoot = 1
msidbRegistryRootLocalMachine: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbRegistryRoot = 2
msidbRegistryRootUsers: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbRegistryRoot = 3
msidbRemoveFileInstallMode = Int32
msidbRemoveFileInstallModeOnInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbRemoveFileInstallMode = 1
msidbRemoveFileInstallModeOnRemove: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbRemoveFileInstallMode = 2
msidbRemoveFileInstallModeOnBoth: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbRemoveFileInstallMode = 3
msidbServiceConfigEvent = Int32
msidbServiceConfigEventInstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbServiceConfigEvent = 1
msidbServiceConfigEventUninstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbServiceConfigEvent = 2
msidbServiceConfigEventReinstall: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbServiceConfigEvent = 4
msidbServiceControlEvent = Int32
msidbServiceControlEventStart: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbServiceControlEvent = 1
msidbServiceControlEventStop: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbServiceControlEvent = 2
msidbServiceControlEventDelete: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbServiceControlEvent = 8
msidbServiceControlEventUninstallStart: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbServiceControlEvent = 16
msidbServiceControlEventUninstallStop: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbServiceControlEvent = 32
msidbServiceControlEventUninstallDelete: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbServiceControlEvent = 128
msidbServiceInstallErrorControl = Int32
msidbServiceInstallErrorControlVital: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbServiceInstallErrorControl = 32768
msidbSumInfoSourceType = Int32
msidbSumInfoSourceTypeSFN: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbSumInfoSourceType = 1
msidbSumInfoSourceTypeCompressed: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbSumInfoSourceType = 2
msidbSumInfoSourceTypeAdminImage: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbSumInfoSourceType = 4
msidbSumInfoSourceTypeLUAPackage: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbSumInfoSourceType = 8
msidbTextStyleStyleBits = Int32
msidbTextStyleStyleBitsBold: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbTextStyleStyleBits = 1
msidbTextStyleStyleBitsItalic: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbTextStyleStyleBits = 2
msidbTextStyleStyleBitsUnderline: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbTextStyleStyleBits = 4
msidbTextStyleStyleBitsStrike: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbTextStyleStyleBits = 8
msidbUpgradeAttributes = Int32
msidbUpgradeAttributesMigrateFeatures: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbUpgradeAttributes = 1
msidbUpgradeAttributesOnlyDetect: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbUpgradeAttributes = 2
msidbUpgradeAttributesIgnoreRemoveFailure: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbUpgradeAttributes = 4
msidbUpgradeAttributesVersionMinInclusive: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbUpgradeAttributes = 256
msidbUpgradeAttributesVersionMaxInclusive: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbUpgradeAttributes = 512
msidbUpgradeAttributesLanguagesExclusive: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msidbUpgradeAttributes = 1024
msifiFastInstallBits = Int32
msifiFastInstallNoSR: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msifiFastInstallBits = 1
msifiFastInstallQuickCosting: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msifiFastInstallBits = 2
msifiFastInstallLessPrgMsg: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msifiFastInstallBits = 4
msirbRebootReason = Int32
msirbRebootUndeterminedReason: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msirbRebootReason = 0
msirbRebootInUseFilesReason: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msirbRebootReason = 1
msirbRebootScheduleRebootReason: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msirbRebootReason = 2
msirbRebootForceRebootReason: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msirbRebootReason = 3
msirbRebootCustomActionReason: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msirbRebootReason = 4
msirbRebootType = Int32
msirbRebootImmediate: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msirbRebootType = 1
msirbRebootDeferred: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msirbRebootType = 2
msmErrorType = Int32
msmErrorLanguageUnsupported: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msmErrorType = 1
msmErrorLanguageFailed: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msmErrorType = 2
msmErrorExclusion: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msmErrorType = 3
msmErrorTableMerge: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msmErrorType = 4
msmErrorResequenceMerge: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msmErrorType = 5
msmErrorFileCreate: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msmErrorType = 6
msmErrorDirCreate: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msmErrorType = 7
msmErrorFeatureRequired: win32more.Windows.Win32.System.ApplicationInstallationAndServicing.msmErrorType = 8


make_ready(__name__)
