from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Dxgi.Common
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Diagnostics.Debug.ActiveScript
import win32more.Windows.Win32.System.Ole
import win32more.Windows.Win32.System.Variant
import win32more.Windows.Win32.UI.Input.Ime
import win32more.Windows.Win32.UI.WindowsAndMessaging
import win32more.Windows.Win32.Web.MsHtml
DISPID_STYLESHEETSCOLLECTION_NAMED_MAX: UInt32 = 1999999
IDM_UNKNOWN: UInt32 = 0
IDM_ALIGNBOTTOM: UInt32 = 1
IDM_ALIGNHORIZONTALCENTERS: UInt32 = 2
IDM_ALIGNLEFT: UInt32 = 3
IDM_ALIGNRIGHT: UInt32 = 4
IDM_ALIGNTOGRID: UInt32 = 5
IDM_ALIGNTOP: UInt32 = 6
IDM_ALIGNVERTICALCENTERS: UInt32 = 7
IDM_ARRANGEBOTTOM: UInt32 = 8
IDM_ARRANGERIGHT: UInt32 = 9
IDM_BRINGFORWARD: UInt32 = 10
IDM_BRINGTOFRONT: UInt32 = 11
IDM_CENTERHORIZONTALLY: UInt32 = 12
IDM_CENTERVERTICALLY: UInt32 = 13
IDM_CODE: UInt32 = 14
IDM_DELETE: UInt32 = 17
IDM_FONTNAME: UInt32 = 18
IDM_FONTSIZE: UInt32 = 19
IDM_GROUP: UInt32 = 20
IDM_HORIZSPACECONCATENATE: UInt32 = 21
IDM_HORIZSPACEDECREASE: UInt32 = 22
IDM_HORIZSPACEINCREASE: UInt32 = 23
IDM_HORIZSPACEMAKEEQUAL: UInt32 = 24
IDM_INSERTOBJECT: UInt32 = 25
IDM_MULTILEVELREDO: UInt32 = 30
IDM_SENDBACKWARD: UInt32 = 32
IDM_SENDTOBACK: UInt32 = 33
IDM_SHOWTABLE: UInt32 = 34
IDM_SIZETOCONTROL: UInt32 = 35
IDM_SIZETOCONTROLHEIGHT: UInt32 = 36
IDM_SIZETOCONTROLWIDTH: UInt32 = 37
IDM_SIZETOFIT: UInt32 = 38
IDM_SIZETOGRID: UInt32 = 39
IDM_SNAPTOGRID: UInt32 = 40
IDM_TABORDER: UInt32 = 41
IDM_TOOLBOX: UInt32 = 42
IDM_MULTILEVELUNDO: UInt32 = 44
IDM_UNGROUP: UInt32 = 45
IDM_VERTSPACECONCATENATE: UInt32 = 46
IDM_VERTSPACEDECREASE: UInt32 = 47
IDM_VERTSPACEINCREASE: UInt32 = 48
IDM_VERTSPACEMAKEEQUAL: UInt32 = 49
IDM_JUSTIFYFULL: UInt32 = 50
IDM_BACKCOLOR: UInt32 = 51
IDM_BOLD: UInt32 = 52
IDM_BORDERCOLOR: UInt32 = 53
IDM_FLAT: UInt32 = 54
IDM_FORECOLOR: UInt32 = 55
IDM_ITALIC: UInt32 = 56
IDM_JUSTIFYCENTER: UInt32 = 57
IDM_JUSTIFYGENERAL: UInt32 = 58
IDM_JUSTIFYLEFT: UInt32 = 59
IDM_JUSTIFYRIGHT: UInt32 = 60
IDM_RAISED: UInt32 = 61
IDM_SUNKEN: UInt32 = 62
IDM_UNDERLINE: UInt32 = 63
IDM_CHISELED: UInt32 = 64
IDM_ETCHED: UInt32 = 65
IDM_SHADOWED: UInt32 = 66
IDM_FIND: UInt32 = 67
IDM_SHOWGRID: UInt32 = 69
IDM_OBJECTVERBLIST0: UInt32 = 72
IDM_OBJECTVERBLIST1: UInt32 = 73
IDM_OBJECTVERBLIST2: UInt32 = 74
IDM_OBJECTVERBLIST3: UInt32 = 75
IDM_OBJECTVERBLIST4: UInt32 = 76
IDM_OBJECTVERBLIST5: UInt32 = 77
IDM_OBJECTVERBLIST6: UInt32 = 78
IDM_OBJECTVERBLIST7: UInt32 = 79
IDM_OBJECTVERBLIST8: UInt32 = 80
IDM_OBJECTVERBLIST9: UInt32 = 81
IDM_OBJECTVERBLISTLAST: UInt32 = 81
IDM_CONVERTOBJECT: UInt32 = 82
IDM_CUSTOMCONTROL: UInt32 = 83
IDM_CUSTOMIZEITEM: UInt32 = 84
IDM_RENAME: UInt32 = 85
IDM_IMPORT: UInt32 = 86
IDM_NEWPAGE: UInt32 = 87
IDM_MOVE: UInt32 = 88
IDM_CANCEL: UInt32 = 89
IDM_FONT: UInt32 = 90
IDM_STRIKETHROUGH: UInt32 = 91
IDM_DELETEWORD: UInt32 = 92
IDM_EXECPRINT: UInt32 = 93
IDM_JUSTIFYNONE: UInt32 = 94
IDM_TRISTATEBOLD: UInt32 = 95
IDM_TRISTATEITALIC: UInt32 = 96
IDM_TRISTATEUNDERLINE: UInt32 = 97
IDM_FORWARDDELETE: UInt32 = 98
IDM_FOLLOW_ANCHOR: UInt32 = 2008
IDM_INSINPUTIMAGE: UInt32 = 2114
IDM_INSINPUTBUTTON: UInt32 = 2115
IDM_INSINPUTRESET: UInt32 = 2116
IDM_INSINPUTSUBMIT: UInt32 = 2117
IDM_INSINPUTUPLOAD: UInt32 = 2118
IDM_INSFIELDSET: UInt32 = 2119
IDM_PASTEINSERT: UInt32 = 2120
IDM_REPLACE: UInt32 = 2121
IDM_EDITSOURCE: UInt32 = 2122
IDM_BOOKMARK: UInt32 = 2123
IDM_HYPERLINK: UInt32 = 2124
IDM_UNLINK: UInt32 = 2125
IDM_BROWSEMODE: UInt32 = 2126
IDM_EDITMODE: UInt32 = 2127
IDM_UNBOOKMARK: UInt32 = 2128
IDM_TOOLBARS: UInt32 = 2130
IDM_STATUSBAR: UInt32 = 2131
IDM_FORMATMARK: UInt32 = 2132
IDM_TEXTONLY: UInt32 = 2133
IDM_OPTIONS: UInt32 = 2135
IDM_FOLLOWLINKC: UInt32 = 2136
IDM_FOLLOWLINKN: UInt32 = 2137
IDM_VIEWSOURCE: UInt32 = 2139
IDM_ZOOMPOPUP: UInt32 = 2140
IDM_BASELINEFONT1: UInt32 = 2141
IDM_BASELINEFONT2: UInt32 = 2142
IDM_BASELINEFONT3: UInt32 = 2143
IDM_BASELINEFONT4: UInt32 = 2144
IDM_BASELINEFONT5: UInt32 = 2145
IDM_HORIZONTALLINE: UInt32 = 2150
IDM_LINEBREAKNORMAL: UInt32 = 2151
IDM_LINEBREAKLEFT: UInt32 = 2152
IDM_LINEBREAKRIGHT: UInt32 = 2153
IDM_LINEBREAKBOTH: UInt32 = 2154
IDM_NONBREAK: UInt32 = 2155
IDM_SPECIALCHAR: UInt32 = 2156
IDM_HTMLSOURCE: UInt32 = 2157
IDM_IFRAME: UInt32 = 2158
IDM_HTMLCONTAIN: UInt32 = 2159
IDM_TEXTBOX: UInt32 = 2161
IDM_TEXTAREA: UInt32 = 2162
IDM_CHECKBOX: UInt32 = 2163
IDM_RADIOBUTTON: UInt32 = 2164
IDM_DROPDOWNBOX: UInt32 = 2165
IDM_LISTBOX: UInt32 = 2166
IDM_BUTTON: UInt32 = 2167
IDM_IMAGE: UInt32 = 2168
IDM_OBJECT: UInt32 = 2169
IDM_1D: UInt32 = 2170
IDM_IMAGEMAP: UInt32 = 2171
IDM_FILE: UInt32 = 2172
IDM_COMMENT: UInt32 = 2173
IDM_SCRIPT: UInt32 = 2174
IDM_JAVAAPPLET: UInt32 = 2175
IDM_PLUGIN: UInt32 = 2176
IDM_PAGEBREAK: UInt32 = 2177
IDM_HTMLAREA: UInt32 = 2178
IDM_PARAGRAPH: UInt32 = 2180
IDM_FORM: UInt32 = 2181
IDM_MARQUEE: UInt32 = 2182
IDM_LIST: UInt32 = 2183
IDM_ORDERLIST: UInt32 = 2184
IDM_UNORDERLIST: UInt32 = 2185
IDM_INDENT: UInt32 = 2186
IDM_OUTDENT: UInt32 = 2187
IDM_PREFORMATTED: UInt32 = 2188
IDM_ADDRESS: UInt32 = 2189
IDM_BLINK: UInt32 = 2190
IDM_DIV: UInt32 = 2191
IDM_TABLEINSERT: UInt32 = 2200
IDM_RCINSERT: UInt32 = 2201
IDM_CELLINSERT: UInt32 = 2202
IDM_CAPTIONINSERT: UInt32 = 2203
IDM_CELLMERGE: UInt32 = 2204
IDM_CELLSPLIT: UInt32 = 2205
IDM_CELLSELECT: UInt32 = 2206
IDM_ROWSELECT: UInt32 = 2207
IDM_COLUMNSELECT: UInt32 = 2208
IDM_TABLESELECT: UInt32 = 2209
IDM_TABLEPROPERTIES: UInt32 = 2210
IDM_CELLPROPERTIES: UInt32 = 2211
IDM_ROWINSERT: UInt32 = 2212
IDM_COLUMNINSERT: UInt32 = 2213
IDM_HELP_CONTENT: UInt32 = 2220
IDM_HELP_ABOUT: UInt32 = 2221
IDM_HELP_README: UInt32 = 2222
IDM_REMOVEFORMAT: UInt32 = 2230
IDM_PAGEINFO: UInt32 = 2231
IDM_TELETYPE: UInt32 = 2232
IDM_GETBLOCKFMTS: UInt32 = 2233
IDM_BLOCKFMT: UInt32 = 2234
IDM_SHOWHIDE_CODE: UInt32 = 2235
IDM_TABLE: UInt32 = 2236
IDM_COPYFORMAT: UInt32 = 2237
IDM_PASTEFORMAT: UInt32 = 2238
IDM_GOTO: UInt32 = 2239
IDM_CHANGEFONT: UInt32 = 2240
IDM_CHANGEFONTSIZE: UInt32 = 2241
IDM_CHANGECASE: UInt32 = 2246
IDM_SHOWSPECIALCHAR: UInt32 = 2249
IDM_SUBSCRIPT: UInt32 = 2247
IDM_SUPERSCRIPT: UInt32 = 2248
IDM_CENTERALIGNPARA: UInt32 = 2250
IDM_LEFTALIGNPARA: UInt32 = 2251
IDM_RIGHTALIGNPARA: UInt32 = 2252
IDM_REMOVEPARAFORMAT: UInt32 = 2253
IDM_APPLYNORMAL: UInt32 = 2254
IDM_APPLYHEADING1: UInt32 = 2255
IDM_APPLYHEADING2: UInt32 = 2256
IDM_APPLYHEADING3: UInt32 = 2257
IDM_DOCPROPERTIES: UInt32 = 2260
IDM_ADDFAVORITES: UInt32 = 2261
IDM_COPYSHORTCUT: UInt32 = 2262
IDM_SAVEBACKGROUND: UInt32 = 2263
IDM_SETWALLPAPER: UInt32 = 2264
IDM_COPYBACKGROUND: UInt32 = 2265
IDM_CREATESHORTCUT: UInt32 = 2266
IDM_PAGE: UInt32 = 2267
IDM_SAVETARGET: UInt32 = 2268
IDM_SHOWPICTURE: UInt32 = 2269
IDM_SAVEPICTURE: UInt32 = 2270
IDM_DYNSRCPLAY: UInt32 = 2271
IDM_DYNSRCSTOP: UInt32 = 2272
IDM_PRINTTARGET: UInt32 = 2273
IDM_IMGARTPLAY: UInt32 = 2274
IDM_IMGARTSTOP: UInt32 = 2275
IDM_IMGARTREWIND: UInt32 = 2276
IDM_PRINTQUERYJOBSPENDING: UInt32 = 2277
IDM_SETDESKTOPITEM: UInt32 = 2278
IDM_CONTEXTMENU: UInt32 = 2280
IDM_GOBACKWARD: UInt32 = 2282
IDM_GOFORWARD: UInt32 = 2283
IDM_PRESTOP: UInt32 = 2284
IDM_GOTOCLIPBOARDADDRESS: UInt32 = 2285
IDM_GOTOCLIPBOARDTEXT: UInt32 = 2286
IDM_MP_MYPICS: UInt32 = 2287
IDM_MP_EMAILPICTURE: UInt32 = 2288
IDM_MP_PRINTPICTURE: UInt32 = 2289
IDM_CREATELINK: UInt32 = 2290
IDM_COPYCONTENT: UInt32 = 2291
IDM_LANGUAGE: UInt32 = 2292
IDM_GETPRINTTEMPLATE: UInt32 = 2295
IDM_SETPRINTTEMPLATE: UInt32 = 2296
IDM_TEMPLATE_PAGESETUP: UInt32 = 2298
IDM_REFRESH: UInt32 = 2300
IDM_STOPDOWNLOAD: UInt32 = 2301
IDM_ENABLE_INTERACTION: UInt32 = 2302
IDM_LAUNCHDEBUGGER: UInt32 = 2310
IDM_BREAKATNEXT: UInt32 = 2311
IDM_INSINPUTHIDDEN: UInt32 = 2312
IDM_INSINPUTPASSWORD: UInt32 = 2313
IDM_OVERWRITE: UInt32 = 2314
IDM_PARSECOMPLETE: UInt32 = 2315
IDM_HTMLEDITMODE: UInt32 = 2316
IDM_REGISTRYREFRESH: UInt32 = 2317
IDM_COMPOSESETTINGS: UInt32 = 2318
IDM_SHOWALLTAGS: UInt32 = 2327
IDM_SHOWALIGNEDSITETAGS: UInt32 = 2321
IDM_SHOWSCRIPTTAGS: UInt32 = 2322
IDM_SHOWSTYLETAGS: UInt32 = 2323
IDM_SHOWCOMMENTTAGS: UInt32 = 2324
IDM_SHOWAREATAGS: UInt32 = 2325
IDM_SHOWUNKNOWNTAGS: UInt32 = 2326
IDM_SHOWMISCTAGS: UInt32 = 2320
IDM_SHOWZEROBORDERATDESIGNTIME: UInt32 = 2328
IDM_AUTODETECT: UInt32 = 2329
IDM_SCRIPTDEBUGGER: UInt32 = 2330
IDM_GETBYTESDOWNLOADED: UInt32 = 2331
IDM_NOACTIVATENORMALOLECONTROLS: UInt32 = 2332
IDM_NOACTIVATEDESIGNTIMECONTROLS: UInt32 = 2333
IDM_NOACTIVATEJAVAAPPLETS: UInt32 = 2334
IDM_NOFIXUPURLSONPASTE: UInt32 = 2335
IDM_EMPTYGLYPHTABLE: UInt32 = 2336
IDM_ADDTOGLYPHTABLE: UInt32 = 2337
IDM_REMOVEFROMGLYPHTABLE: UInt32 = 2338
IDM_REPLACEGLYPHCONTENTS: UInt32 = 2339
IDM_SHOWWBRTAGS: UInt32 = 2340
IDM_PERSISTSTREAMSYNC: UInt32 = 2341
IDM_SETDIRTY: UInt32 = 2342
IDM_RUNURLSCRIPT: UInt32 = 2343
IDM_ZOOMRATIO: UInt32 = 2344
IDM_GETZOOMNUMERATOR: UInt32 = 2345
IDM_GETZOOMDENOMINATOR: UInt32 = 2346
IDM_DIRLTR: UInt32 = 2350
IDM_DIRRTL: UInt32 = 2351
IDM_BLOCKDIRLTR: UInt32 = 2352
IDM_BLOCKDIRRTL: UInt32 = 2353
IDM_INLINEDIRLTR: UInt32 = 2354
IDM_INLINEDIRRTL: UInt32 = 2355
IDM_ISTRUSTEDDLG: UInt32 = 2356
IDM_INSERTSPAN: UInt32 = 2357
IDM_LOCALIZEEDITOR: UInt32 = 2358
IDM_SAVEPRETRANSFORMSOURCE: UInt32 = 2370
IDM_VIEWPRETRANSFORMSOURCE: UInt32 = 2371
IDM_SCROLL_HERE: UInt32 = 2380
IDM_SCROLL_TOP: UInt32 = 2381
IDM_SCROLL_BOTTOM: UInt32 = 2382
IDM_SCROLL_PAGEUP: UInt32 = 2383
IDM_SCROLL_PAGEDOWN: UInt32 = 2384
IDM_SCROLL_UP: UInt32 = 2385
IDM_SCROLL_DOWN: UInt32 = 2386
IDM_SCROLL_LEFTEDGE: UInt32 = 2387
IDM_SCROLL_RIGHTEDGE: UInt32 = 2388
IDM_SCROLL_PAGELEFT: UInt32 = 2389
IDM_SCROLL_PAGERIGHT: UInt32 = 2390
IDM_SCROLL_LEFT: UInt32 = 2391
IDM_SCROLL_RIGHT: UInt32 = 2392
IDM_MULTIPLESELECTION: UInt32 = 2393
IDM_2D_POSITION: UInt32 = 2394
IDM_2D_ELEMENT: UInt32 = 2395
IDM_1D_ELEMENT: UInt32 = 2396
IDM_ABSOLUTE_POSITION: UInt32 = 2397
IDM_LIVERESIZE: UInt32 = 2398
IDM_ATOMICSELECTION: UInt32 = 2399
IDM_AUTOURLDETECT_MODE: UInt32 = 2400
IDM_IE50_PASTE: UInt32 = 2401
IDM_IE50_PASTE_MODE: UInt32 = 2402
IDM_GETIPRINT: UInt32 = 2403
IDM_DISABLE_EDITFOCUS_UI: UInt32 = 2404
IDM_RESPECTVISIBILITY_INDESIGN: UInt32 = 2405
IDM_CSSEDITING_LEVEL: UInt32 = 2406
IDM_UI_OUTDENT: UInt32 = 2407
IDM_UPDATEPAGESTATUS: UInt32 = 2408
IDM_IME_ENABLE_RECONVERSION: UInt32 = 2409
IDM_KEEPSELECTION: UInt32 = 2410
IDM_UNLOADDOCUMENT: UInt32 = 2411
IDM_OVERRIDE_CURSOR: UInt32 = 2420
IDM_PEERHITTESTSAMEINEDIT: UInt32 = 2423
IDM_TRUSTAPPCACHE: UInt32 = 2425
IDM_BACKGROUNDIMAGECACHE: UInt32 = 2430
IDM_GETUSERACTIONTIME: UInt32 = 2431
IDM_BEGINUSERACTION: UInt32 = 2432
IDM_ENDUSERACTION: UInt32 = 2433
IDM_SETCUSTOMCURSOR: UInt32 = 2434
IDM_FOLLOWLINKT: UInt32 = 2435
IDM_CARETBROWSINGMODE: UInt32 = 2436
IDM_STYLEMENU_SETNOSTYLE: UInt32 = 2437
IDM_STYLEMENU_GETNOSTYLE: UInt32 = 2438
IDM_STYLEMENU_GETPREFSTYLE: UInt32 = 2439
IDM_STYLEMENU_CHANGESELECTEDSTYLE: UInt32 = 2440
IDM_MEDIA_PLAYPAUSE: UInt32 = 2441
IDM_MEDIA_MUTEUNMUTE: UInt32 = 2442
IDM_MEDIA_PLAY: UInt32 = 2443
IDM_MEDIA_PAUSE: UInt32 = 2444
IDM_MEDIA_STOP: UInt32 = 2445
IDM_MEDIA_FULLSCREEN_TOGGLE: UInt32 = 2446
IDM_MEDIA_FULLSCREEN_EXIT: UInt32 = 2447
IDM_MEDIA_VOLUME_UP: UInt32 = 2448
IDM_MEDIA_VOLUME_DOWN: UInt32 = 2449
IDM_MEDIA_SEEK_TO_START: UInt32 = 2450
IDM_MEDIA_SEEK_TO_END: UInt32 = 2451
IDM_MEDIA_SEEK_FWD_SMALL: UInt32 = 2452
IDM_MEDIA_SEEK_BACK_SMALL: UInt32 = 2453
IDM_MEDIA_SEEK_FWD_LARGE: UInt32 = 2454
IDM_MEDIA_SEEK_BACK_LARGE: UInt32 = 2455
IDM_MEDIA_RATE_FASTER: UInt32 = 2456
IDM_MEDIA_RATE_SLOWER: UInt32 = 2457
IDM_MEDIA_SHOWCONTROLS_TOGGLE: UInt32 = 2458
IDM_MEDIA_ZOOMMODE_TOGGLE: UInt32 = 2459
IDM_MEDIA_FRAMESTEP_FWD: UInt32 = 2460
IDM_MEDIA_FRAMESTEP_BACK: UInt32 = 2461
IDM_MEDIA_MUTE: UInt32 = 2462
IDM_MEDIA_UNMUTE: UInt32 = 2463
IDM_MEDIA_SHOW_AUDIO_ACCESS: UInt32 = 2464
IDM_MEDIA_SHOW_SUBTITLE_ACCESS: UInt32 = 2465
IDM_MEDIA_PLAYRATE0: UInt32 = 2480
IDM_MEDIA_PLAYRATE1: UInt32 = 2481
IDM_MEDIA_PLAYRATE2: UInt32 = 2482
IDM_MEDIA_PLAYRATE3: UInt32 = 2483
IDM_MEDIA_PLAYRATE4: UInt32 = 2484
IDM_MEDIA_PLAYRATE5: UInt32 = 2485
IDM_MEDIA_PLAYRATE6: UInt32 = 2486
IDM_MEDIA_PLAYRATE7: UInt32 = 2487
IDM_MEDIA_PLAYRATE8: UInt32 = 2488
IDM_MEDIA_PLAYRATE9: UInt32 = 2489
IDM_PASTECONTENTONLY: UInt32 = 2500
IDM_PASTETEXTONLY: UInt32 = 2501
IDM_INSERTHTML: UInt32 = 2502
IDM_DEFAULTBLOCK: UInt32 = 6046
IDM_MIMECSET__FIRST__: UInt32 = 3609
IDM_MIMECSET__LAST__: UInt32 = 3699
IDM_MENUEXT_FIRST__: UInt32 = 3700
IDM_MENUEXT_LAST__: UInt32 = 3732
IDM_MENUEXT_COUNT: UInt32 = 3733
IDM_ADDCONSOLEMESSAGERECEIVER: UInt32 = 3800
IDM_REMOVECONSOLEMESSAGERECEIVER: UInt32 = 3801
IDM_STARTDIAGNOSTICSMODE: UInt32 = 3802
IDM_GETSCRIPTENGINE: UInt32 = 3803
IDM_ADDDEBUGCALLBACKRECEIVER: UInt32 = 3804
IDM_REMOVEDEBUGCALLBACKRECEIVER: UInt32 = 3805
IDM_DEFAULTPARAGRAPHSEPARATOR: UInt32 = 3900
IDM_BEGINUNDOUNIT: UInt32 = 3901
IDM_ENDUNDOUNIT: UInt32 = 3902
IDM_CLEARUNDO: UInt32 = 3903
IDM_INSPECTELEMENT: UInt32 = 3904
IDM_SHAREPICTURE: UInt32 = 3905
IDM_ENABLE_OBJECT_RESIZING: UInt32 = 3906
IDM_INSERTTEXT: UInt32 = 3907
IDM_LAUNCHURICALLBACK: UInt32 = 3908
IDM_FOLLOWLINKN_INPRIVATE: UInt32 = 3909
IDM_FOLLOWLINKT_INPRIVATE: UInt32 = 3910
IDM_FOLLOWLINKEDGE: UInt32 = 3911
IDM_OPEN: UInt32 = 2000
IDM_NEW: UInt32 = 2001
IDM_SAVE: UInt32 = 70
IDM_SAVEAS: UInt32 = 71
IDM_SAVECOPYAS: UInt32 = 2002
IDM_PRINTPREVIEW: UInt32 = 2003
IDM_SHOWPRINT: UInt32 = 2010
IDM_SHOWPAGESETUP: UInt32 = 2011
IDM_PRINT: UInt32 = 27
IDM_PAGESETUP: UInt32 = 2004
IDM_SPELL: UInt32 = 2005
IDM_PASTESPECIAL: UInt32 = 2006
IDM_CLEARSELECTION: UInt32 = 2007
IDM_PROPERTIES: UInt32 = 28
IDM_REDO: UInt32 = 29
IDM_UNDO: UInt32 = 43
IDM_SELECTALL: UInt32 = 31
IDM_ZOOMPERCENT: UInt32 = 50
IDM_GETZOOM: UInt32 = 68
IDM_STOP: UInt32 = 2138
IDM_COPY: UInt32 = 15
IDM_CUT: UInt32 = 16
IDM_PASTE: UInt32 = 26
IDM_SAVEPDF: UInt32 = 99
IDM_TOGGLEREADINGBAR: UInt32 = 15209
IDM_ADDPDFHIGHLIGHT: UInt32 = 15210
IDM_DELETEPDFHIGHLIGHT: UInt32 = 15211
IDM_ADDPDFNOTE: UInt32 = 15212
IDM_OPENPDFNOTE: UInt32 = 15213
IDM_EDITPDFHIGHLIGHT: UInt32 = 15214
IDM_PINKHIGHLIGHT: UInt32 = 15215
IDM_BLUEHIGHLIGHT: UInt32 = 15216
IDM_GREENHIGHLIGHT: UInt32 = 15217
IDM_YELLOWHIGHLIGHT: UInt32 = 15218
IDM_NONEHIGHLIGHT: UInt32 = 15219
IDM_PDFREADALOUD: UInt32 = 15220
IDM_SHAREPDF: UInt32 = 15221
IDM_PDFDEFINE: UInt32 = 15222
CMD_ZOOM_PAGEWIDTH: Int32 = -1
CMD_ZOOM_ONEPAGE: Int32 = -2
CMD_ZOOM_TWOPAGES: Int32 = -3
CMD_ZOOM_SELECTION: Int32 = -4
CMD_ZOOM_FIT: Int32 = -5
IDM_CONTEXT: UInt32 = 1
IDM_HWND: UInt32 = 2
IDM_NEW_TOPLEVELWINDOW: UInt32 = 7050
IDM_PRESERVEUNDOALWAYS: UInt32 = 6049
IDM_PERSISTDEFAULTVALUES: UInt32 = 7100
IDM_PROTECTMETATAGS: UInt32 = 7101
IDM_GETFRAMEZONE: UInt32 = 6037
IDM_REFRESH_THIS: UInt32 = 6042
IDM_MENUEXT_PLACEHOLDER: UInt32 = 6047
IDM_FIRE_PRINTTEMPLATEUP: UInt32 = 15000
IDM_FIRE_PRINTTEMPLATEDOWN: UInt32 = 15001
IDM_SETPRINTHANDLES: UInt32 = 15002
IDM_CLEARAUTHENTICATIONCACHE: UInt32 = 15003
IDM_GETUSERINITFLAGS: UInt32 = 15004
IDM_GETDOCDLGFLAGS: UInt32 = 15005
IDM_OLEWINDOWSTATECHANGED: UInt32 = 15006
IDM_ACTIVEXINSTALLSCOPE: UInt32 = 15007
IDM_SETSESSIONDOCUMENTMODE: UInt32 = 15008
IDM_GETSESSIONDOCUMENTMODE: UInt32 = 15009
IDM_SETPROFILINGONSTART: UInt32 = 15010
IDM_GETPROFILINGONSTART: UInt32 = 15011
IDM_SETSCRIPTCONSOLE: UInt32 = 15012
IDM_SETNAVIGATEEVENTSINK: UInt32 = 15013
IDM_SETDEVTOOLBARCONSOLE: UInt32 = 15016
IDM_POPSTATEEVENT: UInt32 = 15017
IDM_SETPARTIALLAYOUTSTATUS: UInt32 = 15021
IDM_GETPARTIALLAYOUTSTATUS: UInt32 = 15022
IDM_ADDPARTIALTESTSTEPCOUNT: UInt32 = 15023
IDM_SETL9QUIRKSEMULATIONENABLED: UInt32 = 15024
IDM_GETL9QUIRKSEMULATIONENABLED: UInt32 = 15025
IDM_SETPOINTERLOCKCONSENT: UInt32 = 15026
IDM_GETDEFAULTZOOMLEVEL: UInt32 = 15027
IDM_GETELEMENTBOUNDINGBOX: UInt32 = 15028
IDM_SETGEOLOCATIONCONSENT: UInt32 = 15029
IDM_ACTIVEXFILTERINGENABLED: UInt32 = 15030
IDM_SHARE: UInt32 = 15031
IDM_SHAREAPPCACHEEVENT: UInt32 = 15033
IDM_GETPRINTMANAGERDOCSOURCE: UInt32 = 15038
IDM_SETEXTRAHEADERS: UInt32 = 15039
IDM_SETACCESSIBILITYNAME: UInt32 = 15040
IDM_UPDATESETTINGSFROMREGISTRY: UInt32 = 15041
IDM_PERFORMEDITACTIVATION: UInt32 = 15042
IDM_SETDEFAULTBACKGROUNDCOLOR: UInt32 = 15043
IDM_GETDEFAULTBACKGROUNDCOLOR: UInt32 = 15044
IDM_NOTIFYZOOMANDSCROLLANIMATIONEND: UInt32 = 15045
IDM_NOTIFYCONTEXTMENUDISMISSED: UInt32 = 15046
IDM_GETPRINTMANAGERDOCSOURCEASYNC: UInt32 = 15047
IDM_SETPAGEACTIONALLOWEDFLAGS: UInt32 = 15100
IDM_INVOKEFLIPAHEADTARGET: UInt32 = 15200
IDM_ENABLEFLIPAHEADTARGET: UInt32 = 15201
IDM_DEBUGGERDYNAMICATTACH: UInt32 = 15202
IDM_DEBUGGERDYNAMICDETACH: UInt32 = 15203
IDM_DEBUGGERDYNAMICATTACHSOURCERUNDOWN: UInt32 = 15204
IDM_GETDEBUGGERSTATE: UInt32 = 15205
IDM_SELECTIONSEARCH: UInt32 = 15206
IDM_SHOWSHAREUI: UInt32 = 15207
IDM_RUNFLASH: UInt32 = 15208
DISPID_INTERNAL_CELEMENTCLASSCACHE: UInt32 = 2147483648
DISPID_HTMLOBJECT: UInt32 = 66036
DISPID_ELEMENT: UInt32 = 66536
DISPID_SITE: UInt32 = 67536
DISPID_OBJECT: UInt32 = 68536
DISPID_STYLE: UInt32 = 69536
DISPID_BASE_STYLE: UInt32 = 70036
DISPID_ATTRS: UInt32 = 70536
DISPID_EVENTS: UInt32 = 71536
DISPID_XOBJ_EXPANDO: UInt32 = 72536
DISPID_XOBJ_ORDINAL: UInt32 = 73536
DISPID_ACTIVEX_EXPANDO_BASE: UInt32 = 72536
DISPID_ACTIVEX_EXPANDO_MAX: UInt32 = 73535
DISPID_OBJECT_ORDINAL_BASE: UInt32 = 73536
DISPID_OBJECT_ORDINAL_MAX: UInt32 = 74535
DISPID_COLLECTION_MIN: UInt32 = 1000000
DISPID_COLLECTION_MAX: UInt32 = 2999999
DISPID_STYLESHEETSCOLLECTION_NAMED_BASE: UInt32 = 1000000
DISPID_STYLESHEETSCOLLECTION_ORDINAL_BASE: UInt32 = 2000000
DISPID_STYLESHEETSCOLLECTION_ORDINAL_MAX: UInt32 = 2999999
DISPID_EXPANDO_BASE: UInt32 = 3000000
DISPID_EXPANDO_MAX: UInt32 = 3999999
DISPID_EVENTHOOK_SENSITIVE_BASE: UInt32 = 4000000
DISPID_EVENTHOOK_SENSITIVE_MAX: UInt32 = 4499999
DISPID_EVENTHOOK_INSENSITIVE_BASE: UInt32 = 4500000
DISPID_EVENTHOOK_INSENSITIVE_MAX: UInt32 = 4999999
DISPID_PEER_HOLDER_BASE: UInt32 = 5000000
DISPID_CANVASPIXELARRAY_BASE: UInt32 = 5000000
DISPID_CANVASPIXELARRAY_MAX: UInt32 = 2000000000
DISPID_CommonCtrl_FONTNAME: UInt32 = 1
DISPID_CommonCtrl_FONTSIZE: UInt32 = 2
DISPID_CommonCtrl_FONTBOLD: UInt32 = 3
DISPID_CommonCtrl_FONTITAL: UInt32 = 4
DISPID_CommonCtrl_FONTUNDER: UInt32 = 5
DISPID_CommonCtrl_FONTSTRIKE: UInt32 = 6
DISPID_CommonCtrl_FONTWEIGHT: UInt32 = 7
DISPID_CommonCtrl_FONTCHARSET: UInt32 = 8
DISPID_CommonCtrl_FONTSUPERSCRIPT: UInt32 = 9
DISPID_CommonCtrl_FONTSUBSCRIPT: UInt32 = 10
DISPID_MSDATASRCINTERFACE: Int32 = -3900
DISPID_ADVISEDATASRCCHANGEEVENT: Int32 = -3901
DISPID_HTMLDLG: UInt32 = 25000
DISPID_HTMLDLGMODEL: UInt32 = 26000
DISPID_HTMLPOPUP: UInt32 = 27000
DISPID_HTMLAPP: UInt32 = 5000
STDPROPID_XOBJ_NAME: UInt32 = 65536
STDPROPID_XOBJ_INDEX: UInt32 = 65537
STDPROPID_IE3XOBJ_OBJECTALIGN: UInt32 = 65537
STDPROPID_XOBJ_BASEHREF: UInt32 = 65538
STDPROPID_XOBJ_LEFT: UInt32 = 65539
STDPROPID_XOBJ_TOP: UInt32 = 65540
STDPROPID_XOBJ_WIDTH: UInt32 = 65541
STDPROPID_XOBJ_HEIGHT: UInt32 = 65542
STDPROPID_XOBJ_VISIBLE: UInt32 = 65543
STDPROPID_XOBJ_PARENT: UInt32 = 65544
STDPROPID_XOBJ_DRAGMODE: UInt32 = 65545
STDPROPID_XOBJ_DRAGICON: UInt32 = 65546
STDPROPID_XOBJ_TAG: UInt32 = 65547
STDPROPID_XOBJ_TABSTOP: UInt32 = 65550
STDPROPID_XOBJ_TABINDEX: UInt32 = 65551
STDPROPID_XOBJ_HELPCONTEXTID: UInt32 = 65586
STDPROPID_XOBJ_DEFAULT: UInt32 = 65591
STDPROPID_XOBJ_CANCEL: UInt32 = 65592
STDPROPID_XOBJ_LEFTNORUN: UInt32 = 65593
STDPROPID_XOBJ_TOPNORUN: UInt32 = 65594
STDPROPID_XOBJ_ALIGNPERSIST: UInt32 = 65596
STDPROPID_XOBJ_LINKTIMEOUT: UInt32 = 65597
STDPROPID_XOBJ_LINKTOPIC: UInt32 = 65598
STDPROPID_XOBJ_LINKITEM: UInt32 = 65599
STDPROPID_XOBJ_LINKMODE: UInt32 = 65600
STDPROPID_XOBJ_DATACHANGED: UInt32 = 65601
STDPROPID_XOBJ_DATAFIELD: UInt32 = 65602
STDPROPID_XOBJ_DATASOURCE: UInt32 = 65603
STDPROPID_XOBJ_WHATSTHISHELPID: UInt32 = 65604
STDPROPID_XOBJ_CONTROLTIPTEXT: UInt32 = 65605
STDPROPID_XOBJ_STATUSBARTEXT: UInt32 = 65606
STDPROPID_XOBJ_APPLICATION: UInt32 = 65607
STDPROPID_XOBJ_BLOCKALIGN: UInt32 = 65608
STDPROPID_XOBJ_CONTROLALIGN: UInt32 = 65609
STDPROPID_XOBJ_STYLE: UInt32 = 65610
STDPROPID_XOBJ_COUNT: UInt32 = 65611
STDPROPID_XOBJ_DISABLED: UInt32 = 65612
STDPROPID_XOBJ_RIGHT: UInt32 = 65613
STDPROPID_XOBJ_BOTTOM: UInt32 = 65614
STDPROPID_XOBJ_GETSVGDOCUMENT: UInt32 = 65615
STDDISPID_XOBJ_ONFOCUS: UInt32 = 65537
STDDISPID_XOBJ_BEFOREUPDATE: UInt32 = 65540
STDDISPID_XOBJ_AFTERUPDATE: UInt32 = 65541
STDDISPID_XOBJ_ONROWEXIT: UInt32 = 65542
STDDISPID_XOBJ_ONROWENTER: UInt32 = 65543
STDDISPID_XOBJ_ONMOUSEOVER: UInt32 = 65544
STDDISPID_XOBJ_ONMOUSEOUT: UInt32 = 65545
STDDISPID_XOBJ_ONHELP: UInt32 = 65546
STDDISPID_XOBJ_ONDRAGSTART: UInt32 = 65547
STDDISPID_XOBJ_ONSELECTSTART: UInt32 = 65548
STDDISPID_XOBJ_ERRORUPDATE: UInt32 = 65549
STDDISPID_XOBJ_ONDATASETCHANGED: UInt32 = 65550
STDDISPID_XOBJ_ONDATAAVAILABLE: UInt32 = 65551
STDDISPID_XOBJ_ONDATASETCOMPLETE: UInt32 = 65552
STDDISPID_XOBJ_ONFILTER: UInt32 = 65553
STDDISPID_XOBJ_ONLOSECAPTURE: UInt32 = 65554
STDDISPID_XOBJ_ONPROPERTYCHANGE: UInt32 = 65555
STDDISPID_XOBJ_ONDRAG: UInt32 = 65556
STDDISPID_XOBJ_ONDRAGEND: UInt32 = 65557
STDDISPID_XOBJ_ONDRAGENTER: UInt32 = 65558
STDDISPID_XOBJ_ONDRAGOVER: UInt32 = 65559
STDDISPID_XOBJ_ONDRAGLEAVE: UInt32 = 65560
STDDISPID_XOBJ_ONDROP: UInt32 = 65561
STDDISPID_XOBJ_ONCUT: UInt32 = 65562
STDDISPID_XOBJ_ONCOPY: UInt32 = 65563
STDDISPID_XOBJ_ONPASTE: UInt32 = 65564
STDDISPID_XOBJ_ONBEFORECUT: UInt32 = 65565
STDDISPID_XOBJ_ONBEFORECOPY: UInt32 = 65566
STDDISPID_XOBJ_ONBEFOREPASTE: UInt32 = 65567
STDDISPID_XOBJ_ONROWSDELETE: UInt32 = 65568
STDDISPID_XOBJ_ONROWSINSERTED: UInt32 = 65569
STDDISPID_XOBJ_ONCELLCHANGE: UInt32 = 65570
DISPID_NORMAL_FIRST: UInt32 = 1000
DISPID_IE8_NORMAL_FIRST: UInt32 = 1150
DISPID_ANCHOR: UInt32 = 1000
DISPID_BLOCK: UInt32 = 1000
DISPID_BODY: UInt32 = 2000
DISPID_BR: UInt32 = 1000
DISPID_BGSOUND: UInt32 = 1000
DISPID_DD: UInt32 = 1000
DISPID_DIR: UInt32 = 1000
DISPID_DIV: UInt32 = 1000
DISPID_DL: UInt32 = 1000
DISPID_DT: UInt32 = 1000
DISPID_EFONT: UInt32 = 1000
DISPID_FORM: UInt32 = 1000
DISPID_HEADER: UInt32 = 1000
DISPID_HEDELEMS: UInt32 = 1000
DISPID_HR: UInt32 = 1000
DISPID_LABEL: UInt32 = 1000
DISPID_LI: UInt32 = 1000
DISPID_IMGBASE: UInt32 = 1000
DISPID_IMG: UInt32 = 2000
DISPID_INPUTIMAGE: UInt32 = 2000
DISPID_INPUT: UInt32 = 2000
DISPID_INPUTTEXTBASE: UInt32 = 3000
DISPID_INPUTTEXT: UInt32 = 4000
DISPID_MENU: UInt32 = 1000
DISPID_OL: UInt32 = 1000
DISPID_PARA: UInt32 = 1000
DISPID_SELECT: UInt32 = 1000
DISPID_SELECTOBJ: UInt32 = 1000
DISPID_TABLE: UInt32 = 1000
DISPID_TEXTSITE: UInt32 = 1000
DISPID_TEXTAREA: UInt32 = 5000
DISPID_MARQUEE: UInt32 = 6000
DISPID_RICHTEXT: UInt32 = 7000
DISPID_BUTTON: UInt32 = 8000
DISPID_UL: UInt32 = 1000
DISPID_PHRASE: UInt32 = 1000
DISPID_UNKNOWNPDL: UInt32 = 1000
DISPID_COMMENTPDL: UInt32 = 1000
DISPID_TABLECELL: UInt32 = 2000
DISPID_RANGE: UInt32 = 1000
DISPID_SELECTION: UInt32 = 1000
DISPID_OPTION: UInt32 = 1000
DISPID_1D: UInt32 = 2000
DISPID_MAP: UInt32 = 1000
DISPID_AREA: UInt32 = 1000
DISPID_PARAM: UInt32 = 1000
DISPID_TABLESECTION: UInt32 = 1000
DISPID_TABLEROW: UInt32 = 1000
DISPID_TABLECOL: UInt32 = 1000
DISPID_SCRIPT: UInt32 = 1000
DISPID_STYLESHEET: UInt32 = 1000
DISPID_STYLERULE: UInt32 = 1000
DISPID_BASE_STYLERULE: UInt32 = 1100
DISPID_STYLEPAGE: UInt32 = 1000
DISPID_STYLESHEETS_COL: UInt32 = 1000
DISPID_STYLERULES_COL: UInt32 = 1000
DISPID_STYLEPAGES_COL: UInt32 = 1000
DISPID_MEDIALIST: UInt32 = 1000
DISPID_MIMETYPES_COL: UInt32 = 1000
DISPID_PLUGINS_COL: UInt32 = 1000
DISPID_2D: UInt32 = 1000
DISPID_OMWINDOW: UInt32 = 1000
DISPID_EVENTOBJ: UInt32 = 1000
DISPID_PERSISTDATA: UInt32 = 1000
DISPID_OLESITE: UInt32 = 1000
DISPID_FRAMESET: UInt32 = 1000
DISPID_LINK: UInt32 = 1000
DISPID_STYLEELEMENT: UInt32 = 1000
DISPID_FILTERS: UInt32 = 1000
DISPID_OMRECT: UInt32 = 1000
DISPID_DOMATTRIBUTE: UInt32 = 1000
DISPID_DOMTEXTNODE: UInt32 = 1000
DISPID_GENERIC: UInt32 = 1000
DISPID_URN_COLL: UInt32 = 1000
DISPID_NAMESPACE_COLLECTION: UInt32 = 1000
DISPID_NAMESPACE: UInt32 = 1000
DISPID_TAGNAMES_COLLECTION: UInt32 = 1000
DISPID_XMLHTTPREQUEST: UInt32 = 1000
DISPID_XMLSERIALIZER: UInt32 = 1000
DISPID_DOMPARSER: UInt32 = 1000
DISPID_DOCUMENTCOMPATIBLEINFO_COLLECTION: UInt32 = 1000
DISPID_DOCUMENTCOMPATIBLEINFO: UInt32 = 1000
DISPID_XDOMAINREQUEST: UInt32 = 1000
DISPID_DOMSTORAGEITEM: UInt32 = 1000
DISPID_DOMSTORAGE: UInt32 = 1000
DISPID_DOMSTORAGELIST: UInt32 = 1000
DISPID_RULESAPPLIED: UInt32 = 1000
DISPID_RULESAPPLIED_COLLECTION: UInt32 = 1000
DISPID_STYLESHEETRULESAPPLIED_COLLECTION: UInt32 = 1000
DISPID_PROCESSINGINSTRUCTION: UInt32 = 1000
DISPID_MSPOINTERPOINT: UInt32 = 1000
DISPID_WEBSOCKET: UInt32 = 1000
DISPID_APPLICATIONCACHE: UInt32 = 1000
DISPID_DOMEVENT: UInt32 = 1000
DISPID_DOMUIEVENT: UInt32 = 1025
DISPID_DOMMOUSEEVENT: UInt32 = 1050
DISPID_DOMMOUSEWHEELEVENT: UInt32 = 1075
DISPID_DOMWHEELEVENT: UInt32 = 1100
DISPID_DOMTEXTEVENT: UInt32 = 1125
DISPID_DOMKEYBOARDEVENT: UInt32 = 1150
DISPID_DOMCOMPOSITIONEVENT: UInt32 = 1175
DISPID_DOMCUSTOMEVENT: UInt32 = 1200
DISPID_DOMMUTATIONEVENT: UInt32 = 1225
DISPID_DOMFOCUSEVENT: UInt32 = 1250
DISPID_SVGZOOMEVENT: UInt32 = 1275
DISPID_DOMSITEMODEEVENT: UInt32 = 1300
DISPID_DOMMESSAGEEVENT: UInt32 = 1325
DISPID_DOMSTORAGEEVENT: UInt32 = 1350
DISPID_DOMBEFOREUNLOADEVENT: UInt32 = 1375
DISPID_DOMDRAGEVENT: UInt32 = 1400
DISPID_DOMMSPOINTEREVENT: UInt32 = 1425
DISPID_DOMMSGESTUREEVENT: UInt32 = 1450
DISPID_DOMMSTRANSITIONEVENT: UInt32 = 1475
DISPID_DOMMSANIMATIONEVENT: UInt32 = 1500
DISPID_DOMMSMANIPULATIONEVENT: UInt32 = 1525
DISPID_DOMPROGRESSEVENT: UInt32 = 1550
DISPID_DOMCLOSEEVENT: UInt32 = 1525
DISPID_HTMLDOCUMENT: UInt32 = 1000
DISPID_OMDOCUMENT: UInt32 = 1000
DISPID_DATATRANSFER: UInt32 = 1000
DISPID_XMLDECL: UInt32 = 1000
DISPID_DOCFRAG: UInt32 = 1000
DISPID_ILINEINFO: UInt32 = 1000
DISPID_IHTMLCOMPUTEDSTYLE: UInt32 = 1000
DISPID_DOMRANGE: UInt32 = 1000
DISPID_HTMLSELECTION: UInt32 = 1000
DISPID_DOMTRAVERSAL: UInt32 = 1000
DISPID_DOMEXCEPTION: UInt32 = 1000
DISPID_SVGEXCEPTION: UInt32 = 1000
DISPID_RANGEEXCEPTION: UInt32 = 1000
DISPID_EVENTEXCEPTION: UInt32 = 1000
DISPID_DOCUMENTTYPE: UInt32 = 1000
DISPID_MEDIA: UInt32 = 1000
DISPID_MEDIAERROR: UInt32 = 1000
DISPID_TIMERANGES: UInt32 = 1000
DISPID_SOURCE: UInt32 = 1000
DISPID_TRACK: UInt32 = 1000
DISPID_AUDIO: UInt32 = 1050
DISPID_VIDEO: UInt32 = 1050
DISPID_STYLEMEDIA: UInt32 = 1000
DISPID_PROGRESS: UInt32 = 1000
DISPID_PLAYTO: UInt32 = 1000
DISPID_PLAYTODEVICE: UInt32 = 1000
DISPID_WINDOW: UInt32 = 1
DISPID_SCREEN: UInt32 = 1000
DISPID_FRAMESCOLLECTION: UInt32 = 1000
DISPID_HISTORY: UInt32 = 1
DISPID_LOCATION: UInt32 = 1
DISPID_NAVIGATOR: UInt32 = 1
DISPID_CLIENTCAPS: UInt32 = 1
DISPID_TEMPLATE_PRINTER: UInt32 = 1
DISPID_PRINTMANAGER_TEMPLATE_PRINTER: UInt32 = 501
DISPID_COLLECTION: UInt32 = 1500
DISPID_OPTIONS_COL: UInt32 = 1500
DISPID_CHECKBOX: UInt32 = 1000
DISPID_RADIO: UInt32 = 2000
DISPID_FRAMESITE: UInt32 = 68536
DISPID_FRAME: UInt32 = 69536
DISPID_IFRAME: UInt32 = 69536
WEBOC_DISPIDBASE: UInt32 = 70536
WEBOC_DISPIDMAX: UInt32 = 70636
DISPID_PROTECTEDELEMENT: UInt32 = 1000
DISPID_DEFAULTS: UInt32 = 1000
DISPID_MARKUP: UInt32 = 1000
DISPID_DOMIMPLEMENTATION: UInt32 = 1000
DISPID_MEDIAQUERY: UInt32 = 1000
DISPID_HTML5ATTRIBUTESELECTORCI: UInt32 = 1000
DISPID_SVGMIXINS: UInt32 = 1000
DISPID_SVGELEMENT: UInt32 = 1030
DISPID_SVGELEMENT_BASE: UInt32 = 1050
DISPID_SVGAELEMENT: UInt32 = 1050
DISPID_SVGALTGLYPHDEFELEMENT: UInt32 = 1050
DISPID_SVGALTGLYPHELEMENT: UInt32 = 1050
DISPID_SVGALTGLYPHITEMELEMENT: UInt32 = 1050
DISPID_SVGANGLE: UInt32 = 1000
DISPID_SVGANIMATECOLORELEMENT: UInt32 = 1050
DISPID_SVGANIMATEDANGLE: UInt32 = 1000
DISPID_SVGANIMATEDBOOLEAN: UInt32 = 1000
DISPID_SVGANIMATEDENUMERATION: UInt32 = 1000
DISPID_SVGANIMATEDINTEGER: UInt32 = 1000
DISPID_SVGANIMATEDLENGTH: UInt32 = 1000
DISPID_SVGANIMATEDLENGTHLIST: UInt32 = 1000
DISPID_SVGANIMATEDNUMBER: UInt32 = 1000
DISPID_SVGANIMATEDNUMBERLIST: UInt32 = 1000
DISPID_SVGANIMATEDPOINTS: UInt32 = 1000
DISPID_SVGANIMATEDRECT: UInt32 = 1000
DISPID_SVGANIMATEDSTRING: UInt32 = 1000
DISPID_SVGANIMATEELEMENT: UInt32 = 1050
DISPID_SVGANIMATEMOTIONELEMENT: UInt32 = 1050
DISPID_SVGANIMATETRANSFORMELEMENT: UInt32 = 1050
DISPID_SVGCIRCLEELEMENT: UInt32 = 1050
DISPID_SVGCLIPPATHELEMENT: UInt32 = 1050
DISPID_SVGCOLOR_PROFILEELEMENT: UInt32 = 1050
DISPID_SVGCURSORELEMENT: UInt32 = 1050
DISPID_SVGDEFINITION_SRCELEMENT: UInt32 = 1050
DISPID_SVGDEFSELEMENT: UInt32 = 1050
DISPID_SVGDESCELEMENT: UInt32 = 1050
DISPID_SVGELEMENTINSTANCE: UInt32 = 1000
DISPID_SVGELEMENTINSTANCELIST: UInt32 = 1000
DISPID_SVGELLIPSEELEMENT: UInt32 = 1050
DISPID_SVGFEBLENDELEMENT: UInt32 = 1050
DISPID_SVGFECOLORMATRIXELEMENT: UInt32 = 1050
DISPID_SVGFECOMPONENTTRANSFERELEMENT: UInt32 = 1050
DISPID_SVGCOMPONENTTRANSFERFUNCTIONELEMENT: UInt32 = 1050
DISPID_SVGFECOMPOSITEELEMENT: UInt32 = 1050
DISPID_SVGFECONVOLVEMATRIXELEMENT: UInt32 = 1050
DISPID_SVGFEDIFFUSELIGHTINGELEMENT: UInt32 = 1050
DISPID_SVGFEDISPLACEMENTMAPELEMENT: UInt32 = 1050
DISPID_SVGFEDISTANTLIGHTELEMENT: UInt32 = 1050
DISPID_SVGFEFLOODELEMENT: UInt32 = 1050
DISPID_SVGFEFUNCAELEMENT: UInt32 = 1050
DISPID_SVGFEFUNCBELEMENT: UInt32 = 1050
DISPID_SVGFEFUNCGELEMENT: UInt32 = 1050
DISPID_SVGFEFUNCRELEMENT: UInt32 = 1050
DISPID_SVGFEGAUSSIANBLURELEMENT: UInt32 = 1050
DISPID_SVGFEIMAGEELEMENT: UInt32 = 1050
DISPID_SVGFEMERGEELEMENT: UInt32 = 1050
DISPID_SVGFEMERGENODEELEMENT: UInt32 = 1050
DISPID_SVGFEMORPHOLOGYELEMENT: UInt32 = 1050
DISPID_SVGFEOFFSETELEMENT: UInt32 = 1050
DISPID_SVGFEPOINTLIGHTELEMENT: UInt32 = 1050
DISPID_SVGFESPECULARLIGHTINGELEMENT: UInt32 = 1050
DISPID_SVGFESPOTLIGHTELEMENT: UInt32 = 1050
DISPID_SVGFETILEELEMENT: UInt32 = 1050
DISPID_SVGFETURBULENCEELEMENT: UInt32 = 1050
DISPID_SVGFILTERELEMENT: UInt32 = 1050
DISPID_SVGFONT_FACE_FORMATELEMENT: UInt32 = 1050
DISPID_SVGFONT_FACE_NAMEELEMENT: UInt32 = 1050
DISPID_SVGFONT_FACE_SRCELEMENT: UInt32 = 1050
DISPID_SVGFONT_FACE_URIELEMENT: UInt32 = 1050
DISPID_SVGFONT_FACEELEMENT: UInt32 = 1050
DISPID_SVGFONTELEMENT: UInt32 = 1050
DISPID_SVGFOREIGNOBJECTELEMENT: UInt32 = 1050
DISPID_SVGGELEMENT: UInt32 = 1050
DISPID_SVGGLYPHELEMENT: UInt32 = 1050
DISPID_SVGGLYPHREFELEMENT: UInt32 = 1050
DISPID_SVGGRADIENTELEMENT: UInt32 = 1050
DISPID_SVGHKERNELEMENT: UInt32 = 1050
DISPID_SVGIMAGEELEMENT: UInt32 = 1050
DISPID_SVGLENGTH: UInt32 = 1000
DISPID_SVGLENGTHLIST: UInt32 = 1000
DISPID_SVGPRESERVEASPECTRATIO: UInt32 = 1000
DISPID_SVGANIMATEDPRESERVEASPECTRATIO: UInt32 = 1000
DISPID_SVGPOINT: UInt32 = 1000
DISPID_SVGPOINTLIST: UInt32 = 1000
DISPID_SVGLINEARGRADIENTELEMENT: UInt32 = 1070
DISPID_SVGLINEELEMENT: UInt32 = 1050
DISPID_SVGMARKERELEMENT: UInt32 = 1050
DISPID_SVGMASKELEMENT: UInt32 = 1050
DISPID_SVGMETADATAELEMENT: UInt32 = 1050
DISPID_SVGMISSING_GLYPHELEMENT: UInt32 = 1050
DISPID_SVGMPATHELEMENT: UInt32 = 1050
DISPID_SVGNUMBER: UInt32 = 1000
DISPID_SVGNUMBERLIST: UInt32 = 1000
DISPID_SVGPATHELEMENT: UInt32 = 1050
DISPID_SVGPATTERNELEMENT: UInt32 = 1050
DISPID_SVGPOLYGONELEMENT: UInt32 = 1050
DISPID_SVGPOLYLINEELEMENT: UInt32 = 1050
DISPID_SVGRADIALGRADIENTELEMENT: UInt32 = 1070
DISPID_SVGRECT: UInt32 = 1000
DISPID_SVGRECTELEMENT: UInt32 = 1050
DISPID_SVGSCRIPTELEMENT: UInt32 = 1050
DISPID_SVGSETELEMENT: UInt32 = 1050
DISPID_SVGSTOPELEMENT: UInt32 = 1050
DISPID_SVGSTRINGLIST: UInt32 = 1000
DISPID_SVGSTYLEELEMENT: UInt32 = 1050
DISPID_SVGSVGELEMENT: UInt32 = 1050
DISPID_SVGSWITCHELEMENT: UInt32 = 1050
DISPID_SVGSYMBOLELEMENT: UInt32 = 1050
DISPID_SVGTITLEELEMENT: UInt32 = 1050
DISPID_SVGTREFELEMENT: UInt32 = 1050
DISPID_SVGTEXTCONTENTELEMENT: UInt32 = 1050
DISPID_SVGTEXTCONTENTELEMENT_BASE: UInt32 = 1070
DISPID_SVGTEXTPOSITIONINGELEMENT: UInt32 = 1070
DISPID_SVGTEXTPOSITIONINGELEMENT_BASE: UInt32 = 1090
DISPID_SVGTEXTELEMENT: UInt32 = 1090
DISPID_SVGTSPANELEMENT: UInt32 = 1090
DISPID_SVGTEXTPATHELEMENT: UInt32 = 1070
DISPID_SVGUSEELEMENT: UInt32 = 1050
DISPID_SVGVIEWELEMENT: UInt32 = 1050
DISPID_SVGVKERNELEMENT: UInt32 = 1050
DISPID_SVGMATRIX: UInt32 = 1000
DISPID_SVGTRANSFORM: UInt32 = 1000
DISPID_SVGTRANSFORMLIST: UInt32 = 1000
DISPID_SVGANIMATEDTRANSFORMLIST: UInt32 = 1000
DISPID_SVGPATHSEG: UInt32 = 1000
DISPID_SVGPATHSEG_BASE: UInt32 = 1020
DISPID_SVGPATHSEGLIST: UInt32 = 1000
DISPID_SVGPATHSEGARCABS: UInt32 = 1020
DISPID_SVGPATHSEGARCREL: UInt32 = 1020
DISPID_SVGPATHSEGCLOSEPATH: UInt32 = 1020
DISPID_SVGPATHSEGMOVETOABS: UInt32 = 1020
DISPID_SVGPATHSEGMOVETOREL: UInt32 = 1020
DISPID_SVGPATHSEGLINETOABS: UInt32 = 1020
DISPID_SVGPATHSEGLINETOREL: UInt32 = 1020
DISPID_SVGPATHSEGCURVETOCUBICABS: UInt32 = 1020
DISPID_SVGPATHSEGCURVETOCUBICREL: UInt32 = 1020
DISPID_SVGPATHSEGCURVETOCUBICSMOOTHABS: UInt32 = 1020
DISPID_SVGPATHSEGCURVETOCUBICSMOOTHREL: UInt32 = 1020
DISPID_SVGPATHSEGCURVETOQUADRATICABS: UInt32 = 1020
DISPID_SVGPATHSEGCURVETOQUADRATICREL: UInt32 = 1020
DISPID_SVGPATHSEGCURVETOQUADRATICSMOOTHABS: UInt32 = 1020
DISPID_SVGPATHSEGCURVETOQUADRATICSMOOTHREL: UInt32 = 1020
DISPID_SVGPATHSEGLINETOHORIZONTALABS: UInt32 = 1020
DISPID_SVGPATHSEGLINETOHORIZONTALREL: UInt32 = 1020
DISPID_SVGPATHSEGLINETOVERTICALABS: UInt32 = 1020
DISPID_SVGPATHSEGLINETOVERTICALREL: UInt32 = 1020
DISPID_CANVASELEMENT: UInt32 = 1000
DISPID_CANVASRENDERCONTEXT2D: UInt32 = 1000
DISPID_CANVASGRADIENT: UInt32 = 1000
DISPID_CANVASTEXTMETRICS: UInt32 = 1000
DISPID_CANVASIMAGEDATA: UInt32 = 1000
DISPID_CANVASPIXELARRAY: UInt32 = 1000
DISPID_PERFORMANCE: UInt32 = 1000
DISPID_PERFORMANCENAVIGATION: UInt32 = 1000
DISPID_PERFORMANCETIMING: UInt32 = 1000
DISPID_MSHTMLWEBVIEWELEMENT: UInt32 = 1000
DISPID_WEBGEOLOCATION: UInt32 = 1000
DISPID_WEBGEOPOSITION: UInt32 = 1000
DISPID_WEBGEOCOORDINATES: UInt32 = 1000
DISPID_WEBGEOPOSITION_ERROR: UInt32 = 1000
DISPID_DATALIST: UInt32 = 1000
DISPID_IE8_ANCHOR: UInt32 = 1150
DISPID_IE8_AREA: UInt32 = 1150
DISPID_IE8_BASE: UInt32 = 1150
DISPID_IE8_BODY: UInt32 = 1150
DISPID_IE8_FORM: UInt32 = 1150
DISPID_IE8_HEAD: UInt32 = 1150
DISPID_IE8_IMG: UInt32 = 1150
DISPID_IE8_INPUT: UInt32 = 1150
DISPID_IE8_LINK: UInt32 = 1150
DISPID_IE8_MOD: UInt32 = 1150
DISPID_IE8_SCRIPT: UInt32 = 1150
DISPID_IE8_ATTR: UInt32 = 1150
DISPID_IE8_NAMEDNODEMAP: UInt32 = 1150
DISPID_IE8_COLLECTION: UInt32 = 1150
DISPID_IE8_PARAM: UInt32 = 1150
DISPID_IE8_EMBED: UInt32 = 1150
DISPID_IE8_BLOCK: UInt32 = 1150
DISPID_IE8_META: UInt32 = 1150
DISPID_IE8_STYLE: UInt32 = 1150
DISPID_IE8_SELECT: UInt32 = 1150
DISPID_IE8_ELEMENTBASE: UInt32 = 66736
DISPID_IE8_ELEMENTMAX: UInt32 = 66776
DISPID_IE8_ELEMENT: UInt32 = 66736
DISPID_IE8_FRAMESITEBASE: UInt32 = 69656
DISPID_IE8_FRAMEMAX: UInt32 = 70535
DISPID_IE8_FRAME: UInt32 = 69656
DISPID_IE8_IFRAME: UInt32 = 69656
DISPID_IE8_OBJECTBASE: UInt32 = 68566
DISPID_IE8_OBJECTMAX: UInt32 = 69535
DISPID_IE8_OBJECT: UInt32 = 68566
DISPID_IE9_ELEMENTBASE: UInt32 = 66786
DISPID_IE9_ELEMENTMAX: UInt32 = 66821
DISPID_IE9_ELEMENT: UInt32 = 66786
DISPID_IE10_ELEMENTBASE: UInt32 = 66822
DISPID_IE10_ELEMENTMAX: UInt32 = 67535
DISPID_IE10_ELEMENT: UInt32 = 66822
DISP10_IE10_XMSARIAFLOWFROM: UInt32 = 66835
DISPID_WINDOWOBJECT: Int32 = -5500
DISPID_PERFORMANCEOBJECT: Int32 = -5505
DISPID_LOCATIONOBJECT: Int32 = -5506
DISPID_HISTORYOBJECT: Int32 = -5507
DISPID_NAVIGATOROBJECT: Int32 = -5508
DISPID_SECURITYCTX: Int32 = -5511
DISPID_AMBIENT_DLCONTROL: Int32 = -5512
DISPID_AMBIENT_USERAGENT: Int32 = -5513
DISPID_SECURITYDOMAIN: Int32 = -5514
DISPID_DEBUG_ISSECUREPROXY: Int32 = -5515
DISPID_DEBUG_TRUSTEDPROXY: Int32 = -5516
DISPID_DEBUG_INTERNALWINDOW: Int32 = -5517
DISPID_DEBUG_ENABLESECUREPROXYASSERTS: Int32 = -5518
DLCTL_DLIMAGES: UInt32 = 16
DLCTL_VIDEOS: UInt32 = 32
DLCTL_BGSOUNDS: UInt32 = 64
DLCTL_NO_SCRIPTS: UInt32 = 128
DLCTL_NO_JAVA: UInt32 = 256
DLCTL_NO_RUNACTIVEXCTLS: UInt32 = 512
DLCTL_NO_DLACTIVEXCTLS: UInt32 = 1024
DLCTL_DOWNLOADONLY: UInt32 = 2048
DLCTL_NO_FRAMEDOWNLOAD: UInt32 = 4096
DLCTL_RESYNCHRONIZE: UInt32 = 8192
DLCTL_PRAGMA_NO_CACHE: UInt32 = 16384
DLCTL_NO_BEHAVIORS: UInt32 = 32768
DLCTL_NO_METACHARSET: UInt32 = 65536
DLCTL_URL_ENCODING_DISABLE_UTF8: UInt32 = 131072
DLCTL_URL_ENCODING_ENABLE_UTF8: UInt32 = 262144
DLCTL_NOFRAMES: UInt32 = 524288
DLCTL_FORCEOFFLINE: UInt32 = 268435456
DLCTL_NO_CLIENTPULL: UInt32 = 536870912
DLCTL_SILENT: UInt32 = 1073741824
DLCTL_OFFLINEIFNOTCONNECTED: UInt32 = 2147483648
DLCTL_OFFLINE: UInt32 = 2147483648
DISPID_ONABORT: UInt32 = 1000
DISPID_ONCHANGE: UInt32 = 1001
DISPID_ONERROR: UInt32 = 1002
DISPID_ONLOAD: UInt32 = 1003
DISPID_ONSELECT: UInt32 = 1006
DISPID_ONSUBMIT: UInt32 = 1007
DISPID_ONUNLOAD: UInt32 = 1008
DISPID_ONBOUNCE: UInt32 = 1009
DISPID_ONFINISH: UInt32 = 1010
DISPID_ONSTART: UInt32 = 1011
DISPID_ONLAYOUT: UInt32 = 1013
DISPID_ONSCROLL: UInt32 = 1014
DISPID_ONRESET: UInt32 = 1015
DISPID_ONRESIZE: UInt32 = 1016
DISPID_ONBEFOREUNLOAD: UInt32 = 1017
DISPID_ONCHANGEFOCUS: UInt32 = 1018
DISPID_ONCHANGEBLUR: UInt32 = 1019
DISPID_ONPERSIST: UInt32 = 1020
DISPID_ONPERSISTSAVE: UInt32 = 1021
DISPID_ONPERSISTLOAD: UInt32 = 1022
DISPID_ONCONTEXTMENU: UInt32 = 1023
DISPID_ONBEFOREPRINT: UInt32 = 1024
DISPID_ONAFTERPRINT: UInt32 = 1025
DISPID_ONSTOP: UInt32 = 1026
DISPID_ONBEFOREEDITFOCUS: UInt32 = 1027
DISPID_ONMOUSEHOVER: UInt32 = 1028
DISPID_ONCONTENTREADY: UInt32 = 1029
DISPID_ONLAYOUTCOMPLETE: UInt32 = 1030
DISPID_ONPAGE: UInt32 = 1031
DISPID_ONLINKEDOVERFLOW: UInt32 = 1032
DISPID_ONMOUSEWHEEL: UInt32 = 1033
DISPID_ONBEFOREDEACTIVATE: UInt32 = 1034
DISPID_ONMOVE: UInt32 = 1035
DISPID_ONCONTROLSELECT: UInt32 = 1036
DISPID_ONSELECTIONCHANGE: UInt32 = 1037
DISPID_ONMOVESTART: UInt32 = 1038
DISPID_ONMOVEEND: UInt32 = 1039
DISPID_ONRESIZESTART: UInt32 = 1040
DISPID_ONRESIZEEND: UInt32 = 1041
DISPID_ONMOUSEENTER: UInt32 = 1042
DISPID_ONMOUSELEAVE: UInt32 = 1043
DISPID_ONACTIVATE: UInt32 = 1044
DISPID_ONDEACTIVATE: UInt32 = 1045
DISPID_ONMULTILAYOUTCLEANUP: UInt32 = 1046
DISPID_ONBEFOREACTIVATE: UInt32 = 1047
DISPID_ONFOCUSIN: UInt32 = 1048
DISPID_ONFOCUSOUT: UInt32 = 1049
DISPID_ONVALUECHANGE: UInt32 = 1050
DISPID_ONSELECTADD: UInt32 = 1051
DISPID_ONSELECTREMOVE: UInt32 = 1052
DISPID_ONSELECTWITHIN: UInt32 = 1053
DISPID_ONSYSTEMSCROLLINGSTART: UInt32 = 1054
DISPID_ONSYSTEMSCROLLINGEND: UInt32 = 1055
DISPID_ONOBJECTCONTENTSCROLLED: UInt32 = 1056
DISPID_ONSTORAGE: UInt32 = 1057
DISPID_ONSTORAGECOMMIT: UInt32 = 1058
DISPID_ONSHOW: UInt32 = 1059
DISPID_ONHIDE: UInt32 = 1060
DISPID_ONALERT: UInt32 = 1061
DISPID_ONPOPUPMENUSTART: UInt32 = 1062
DISPID_ONPOPUPMENUEND: UInt32 = 1063
DISPID_ONONLINE: UInt32 = 1064
DISPID_ONOFFLINE: UInt32 = 1065
DISPID_ONHASHCHANGE: UInt32 = 1066
DISPID_ONMESSAGE: UInt32 = 1067
DISPID_ONDOMMUTATION: UInt32 = 1068
DISPID_SVGLOAD: UInt32 = 1069
DISPID_SVGUNLOAD: UInt32 = 1070
DISPID_SVGABORT: UInt32 = 1071
DISPID_SVGERROR: UInt32 = 1072
DISPID_SVGRESIZE: UInt32 = 1073
DISPID_SVGSCROLL: UInt32 = 1074
DISPID_SVGZOOM: UInt32 = 1075
DISPID_MSPOINTERDOWN: UInt32 = 1076
DISPID_MSPOINTERMOVE: UInt32 = 1077
DISPID_MSPOINTERUP: UInt32 = 1078
DISPID_MSPOINTEROVER: UInt32 = 1079
DISPID_MSPOINTEROUT: UInt32 = 1080
DISPID_MSPOINTERCANCEL: UInt32 = 1081
DISPID_MSPOINTERHOVER: UInt32 = 1082
DISPID_MSGESTURESTART: UInt32 = 1083
DISPID_MSGESTURECHANGE: UInt32 = 1084
DISPID_MSGESTUREEND: UInt32 = 1085
DISPID_MSGESTUREHOLD: UInt32 = 1086
DISPID_MSGESTURETAP: UInt32 = 1087
DISPID_MSGESTUREDOUBLETAP: UInt32 = 1088
DISPID_MSINERTIASTART: UInt32 = 1089
DISPID_MSLOSTPOINTERCAPTURE: UInt32 = 1090
DISPID_MSGOTPOINTERCAPTURE: UInt32 = 1091
DISPID_MSTRANSITIONSTART: UInt32 = 1092
DISPID_MSTRANSITIONEND: UInt32 = 1093
DISPID_MSANIMATIONSTART: UInt32 = 1094
DISPID_MSANIMATIONEND: UInt32 = 1095
DISPID_MSANIMATIONITERATION: UInt32 = 1096
DISPID_MSGESTUREINIT: UInt32 = 1097
DISPID_MSMANIPULATIONSTATECHANGED: UInt32 = 1098
DISPID_ONOPEN: UInt32 = 1099
DISPID_ONCLOSE: UInt32 = 1100
DISPID_MSPOINTERENTER: UInt32 = 1101
DISPID_MSPOINTERLEAVE: UInt32 = 1102
DISPID_MSORIENTATIONCHANGE: UInt32 = 1103
DISPID_ONDEVICEORIENTATION: UInt32 = 1104
DISPID_ONDEVICEMOTION: UInt32 = 1105
DISPID_ONPAGESHOW: UInt32 = 1106
DISPID_ONPAGEHIDE: UInt32 = 1107
DISPID_ONCOMPASSNEEDSCALIBRATION: UInt32 = 1108
DISPID_A_FIRST: UInt32 = 70536
DISPID_A_MIN: UInt32 = 70536
DISPID_A_MAX: UInt32 = 71535
DISPID_A_BACKGROUNDIMAGE: UInt32 = 70537
DISPID_A_COLOR: UInt32 = 70538
DISPID_A_TEXTTRANSFORM: UInt32 = 70540
DISPID_A_NOWRAP: UInt32 = 70541
DISPID_A_LINEHEIGHT: UInt32 = 70542
DISPID_A_TEXTINDENT: UInt32 = 70543
DISPID_A_LETTERSPACING: UInt32 = 70544
DISPID_A_LANG: UInt32 = 70545
DISPID_A_OVERFLOW: UInt32 = 70546
DISPID_A_PADDING: UInt32 = 70547
DISPID_A_PADDINGTOP: UInt32 = 70548
DISPID_A_PADDINGRIGHT: UInt32 = 70549
DISPID_A_PADDINGBOTTOM: UInt32 = 70550
DISPID_A_PADDINGLEFT: UInt32 = 70551
DISPID_A_CLEAR: UInt32 = 70552
DISPID_A_LISTTYPE: UInt32 = 70553
DISPID_A_FONTFACE: UInt32 = 70554
DISPID_A_FONTSIZE: UInt32 = 70555
DISPID_A_TEXTDECORATIONLINETHROUGH: UInt32 = 70556
DISPID_A_TEXTDECORATIONUNDERLINE: UInt32 = 70557
DISPID_A_TEXTDECORATIONBLINK: UInt32 = 70558
DISPID_A_TEXTDECORATIONNONE: UInt32 = 70559
DISPID_A_FONTSTYLE: UInt32 = 70560
DISPID_A_FONTVARIANT: UInt32 = 70561
DISPID_A_BASEFONT: UInt32 = 70562
DISPID_A_FONTWEIGHT: UInt32 = 70563
DISPID_A_TABLEBORDERCOLOR: UInt32 = 70564
DISPID_A_TABLEBORDERCOLORLIGHT: UInt32 = 70565
DISPID_A_TABLEBORDERCOLORDARK: UInt32 = 70566
DISPID_A_TABLEVALIGN: UInt32 = 70567
DISPID_A_BACKGROUND: UInt32 = 70568
DISPID_A_BACKGROUNDPOSX: UInt32 = 70569
DISPID_A_BACKGROUNDPOSY: UInt32 = 70570
DISPID_A_TEXTDECORATION: UInt32 = 70571
DISPID_A_MARGIN: UInt32 = 70572
DISPID_A_MARGINTOP: UInt32 = 70573
DISPID_A_MARGINRIGHT: UInt32 = 70574
DISPID_A_MARGINBOTTOM: UInt32 = 70575
DISPID_A_MARGINLEFT: UInt32 = 70576
DISPID_A_FONT: UInt32 = 70577
DISPID_A_FONTSIZEKEYWORD: UInt32 = 70578
DISPID_A_FONTSIZECOMBINE: UInt32 = 70579
DISPID_A_BACKGROUNDREPEAT: UInt32 = 70580
DISPID_A_BACKGROUNDATTACHMENT: UInt32 = 70581
DISPID_A_BACKGROUNDPOSITION: UInt32 = 70582
DISPID_A_WORDSPACING: UInt32 = 70583
DISPID_A_VERTICALALIGN: UInt32 = 70584
DISPID_A_BORDER: UInt32 = 70585
DISPID_A_BORDERTOP: UInt32 = 70586
DISPID_A_BORDERRIGHT: UInt32 = 70587
DISPID_A_BORDERBOTTOM: UInt32 = 70588
DISPID_A_BORDERLEFT: UInt32 = 70589
DISPID_A_BORDERCOLOR: UInt32 = 70590
DISPID_A_BORDERTOPCOLOR: UInt32 = 70591
DISPID_A_BORDERRIGHTCOLOR: UInt32 = 70592
DISPID_A_BORDERBOTTOMCOLOR: UInt32 = 70593
DISPID_A_BORDERLEFTCOLOR: UInt32 = 70594
DISPID_A_BORDERWIDTH: UInt32 = 70595
DISPID_A_BORDERTOPWIDTH: UInt32 = 70596
DISPID_A_BORDERRIGHTWIDTH: UInt32 = 70597
DISPID_A_BORDERBOTTOMWIDTH: UInt32 = 70598
DISPID_A_BORDERLEFTWIDTH: UInt32 = 70599
DISPID_A_BORDERSTYLE: UInt32 = 70600
DISPID_A_BORDERTOPSTYLE: UInt32 = 70601
DISPID_A_BORDERRIGHTSTYLE: UInt32 = 70602
DISPID_A_BORDERBOTTOMSTYLE: UInt32 = 70603
DISPID_A_BORDERLEFTSTYLE: UInt32 = 70604
DISPID_A_TEXTDECORATIONOVERLINE: UInt32 = 70605
DISPID_A_FLOAT: UInt32 = 70606
DISPID_A_DISPLAY: UInt32 = 70607
DISPID_A_LISTSTYLETYPE: UInt32 = 70608
DISPID_A_LISTSTYLEPOSITION: UInt32 = 70609
DISPID_A_LISTSTYLEIMAGE: UInt32 = 70610
DISPID_A_LISTSTYLE: UInt32 = 70611
DISPID_A_WHITESPACE: UInt32 = 70612
DISPID_A_PAGEBREAKBEFORE: UInt32 = 70613
DISPID_A_PAGEBREAKAFTER: UInt32 = 70614
DISPID_A_SCROLL: UInt32 = 70615
DISPID_A_VISIBILITY: UInt32 = 70616
DISPID_A_HIDDEN: UInt32 = 70617
DISPID_A_FILTER: UInt32 = 70618
DISPID_DEFAULTVALUE: UInt32 = 70619
DISPID_A_BORDERCOLLAPSE: UInt32 = 70620
DISPID_A_POSITION: UInt32 = 70626
DISPID_A_ZINDEX: UInt32 = 70627
DISPID_A_CLIP: UInt32 = 70628
DISPID_A_CLIPRECTTOP: UInt32 = 70629
DISPID_A_CLIPRECTRIGHT: UInt32 = 70630
DISPID_A_CLIPRECTBOTTOM: UInt32 = 70631
DISPID_A_CLIPRECTLEFT: UInt32 = 70632
DISPID_A_FONTFACESRC: UInt32 = 70633
DISPID_A_TABLELAYOUT: UInt32 = 70634
DISPID_A_STYLETEXT: UInt32 = 70635
DISPID_A_LANGUAGE: UInt32 = 70636
DISPID_A_VALUE: UInt32 = 70637
DISPID_A_CURSOR: UInt32 = 70638
DISPID_A_EVENTSINK: UInt32 = 70639
DISPID_A_PROPNOTIFYSINK: UInt32 = 70640
DISPID_A_ROWSETNOTIFYSINK: UInt32 = 70641
DISPID_INTERNAL_INLINESTYLEAA: UInt32 = 70642
DISPID_INTERNAL_CSTYLEPTRCACHE: UInt32 = 70643
DISPID_INTERNAL_CRUNTIMESTYLEPTRCACHE: UInt32 = 70644
DISPID_INTERNAL_INVOKECONTEXT: UInt32 = 70645
DISPID_A_BGURLIMGCTXCACHEINDEX: UInt32 = 70646
DISPID_A_LIURLIMGCTXCACHEINDEX: UInt32 = 70647
DISPID_A_ROWSETASYNCHNOTIFYSINK: UInt32 = 70648
DISPID_INTERNAL_FILTERPTRCACHE: UInt32 = 70649
DISPID_A_ROWPOSITIONCHANGESINK: UInt32 = 70650
DISPID_A_BEHAVIOR: UInt32 = 70651
DISPID_A_READYSTATE: UInt32 = 70652
DISPID_A_DIR: UInt32 = 70653
DISPID_A_UNICODEBIDI: UInt32 = 70654
DISPID_A_DIRECTION: UInt32 = 70655
DISPID_A_IMEMODE: UInt32 = 70656
DISPID_A_RUBYALIGN: UInt32 = 70657
DISPID_A_RUBYPOSITION: UInt32 = 70658
DISPID_A_RUBYOVERHANG: UInt32 = 70659
DISPID_INTERNAL_ONBEHAVIOR_CONTENTREADY: UInt32 = 70660
DISPID_INTERNAL_ONBEHAVIOR_DOCUMENTREADY: UInt32 = 70661
DISPID_INTERNAL_CDOMCHILDRENPTRCACHE: UInt32 = 70662
DISPID_A_LAYOUTGRIDCHAR: UInt32 = 70663
DISPID_A_LAYOUTGRIDLINE: UInt32 = 70664
DISPID_A_LAYOUTGRIDMODE: UInt32 = 70665
DISPID_A_LAYOUTGRIDTYPE: UInt32 = 70666
DISPID_A_LAYOUTGRID: UInt32 = 70667
DISPID_A_TEXTAUTOSPACE: UInt32 = 70668
DISPID_A_LINEBREAK: UInt32 = 70669
DISPID_A_WORDBREAK: UInt32 = 70670
DISPID_A_TEXTJUSTIFY: UInt32 = 70671
DISPID_A_TEXTJUSTIFYTRIM: UInt32 = 70672
DISPID_A_TEXTKASHIDA: UInt32 = 70673
DISPID_A_OVERFLOWX: UInt32 = 70675
DISPID_A_OVERFLOWY: UInt32 = 70676
DISPID_A_HTCDISPATCHITEM_VALUE: UInt32 = 70677
DISPID_A_DOCFRAGMENT: UInt32 = 70678
DISPID_A_HTCDD_ELEMENT: UInt32 = 70679
DISPID_A_HTCDD_CREATEEVENTOBJECT: UInt32 = 70680
DISPID_A_URNATOM: UInt32 = 70681
DISPID_A_UNIQUEPEERNUMBER: UInt32 = 70682
DISPID_A_ACCELERATOR: UInt32 = 70683
DISPID_INTERNAL_ONBEHAVIOR_APPLYSTYLE: UInt32 = 70684
DISPID_INTERNAL_RUNTIMESTYLEAA: UInt32 = 70685
DISPID_A_HTCDISPATCHITEM_VALUE_SCRIPTSONLY: UInt32 = 70686
DISPID_A_EXTENDEDTAGDESC: UInt32 = 70687
DISPID_A_ROTATE: UInt32 = 70688
DISPID_A_ZOOM: UInt32 = 70689
DISPID_A_HTCDD_PROTECTEDELEMENT: UInt32 = 70690
DISPID_A_LAYOUTFLOW: UInt32 = 70691
DISPID_INTERNAL_FILTERNATIVEINFOPTRCACHE: UInt32 = 70692
DISPID_A_HTCDD_ISMARKUPSHARED: UInt32 = 70693
DISPID_A_WORDWRAP: UInt32 = 70694
DISPID_A_TEXTUNDERLINEPOSITION: UInt32 = 70695
DISPID_A_HASLAYOUT: UInt32 = 70696
DISPID_A_MEDIA: UInt32 = 70697
DISPID_A_EDITABLE: UInt32 = 70698
DISPID_A_HIDEFOCUS: UInt32 = 70699
DISPID_INTERNAL_LAYOUTRECTREGISTRYPTRCACHE: UInt32 = 70700
DISPID_A_HTCDD_DEFAULTS: UInt32 = 70701
DISPID_A_TEXTLINETHROUGHSTYLE: UInt32 = 70702
DISPID_A_TEXTUNDERLINESTYLE: UInt32 = 70703
DISPID_A_TEXTEFFECT: UInt32 = 70704
DISPID_A_TEXTBACKGROUNDCOLOR: UInt32 = 70705
DISPID_A_RENDERINGPRIORITY: UInt32 = 70706
DISPID_INTERNAL_DWNPOSTPTRCACHE: UInt32 = 70707
DISPID_INTERNAL_CODEPAGESETTINGSPTRCACHE: UInt32 = 70708
DISPID_INTERNAL_DWNDOCPTRCACHE: UInt32 = 70709
DISPID_INTERNAL_DATABINDTASKPTRCACHE: UInt32 = 70710
DISPID_INTERNAL_URLLOCATIONCACHE: UInt32 = 70711
DISPID_INTERNAL_ARYELEMENTRELEASENOTIFYPTRCACHE: UInt32 = 70712
DISPID_INTERNAL_PEERFACTORYURLMAPPTRCACHE: UInt32 = 70713
DISPID_INTERNAL_STMDIRTYPTRCACHE: UInt32 = 70714
DISPID_INTERNAL_COMPUTEFORMATSTATECACHE: UInt32 = 70715
DISPID_A_SCROLLBARBASECOLOR: UInt32 = 70716
DISPID_A_SCROLLBARFACECOLOR: UInt32 = 70717
DISPID_A_SCROLLBAR3DLIGHTCOLOR: UInt32 = 70718
DISPID_A_SCROLLBARSHADOWCOLOR: UInt32 = 70719
DISPID_A_SCROLLBARHIGHLIGHTCOLOR: UInt32 = 70720
DISPID_A_SCROLLBARDARKSHADOWCOLOR: UInt32 = 70721
DISPID_A_SCROLLBARARROWCOLOR: UInt32 = 70722
DISPID_INTERNAL_ONBEHAVIOR_CONTENTSAVE: UInt32 = 70723
DISPID_A_DEFAULTTEXTSELECTION: UInt32 = 70724
DISPID_A_TEXTDECORATIONCOLOR: UInt32 = 70725
DISPID_A_TEXTCOLOR: UInt32 = 70726
DISPID_A_STYLETEXTDECORATION: UInt32 = 70727
DISPID_A_WRITINGMODE: UInt32 = 70728
DISPID_INTERNAL_MEDIA_REFERENCE: UInt32 = 70729
DISPID_INTERNAL_GENERICCOMPLUSREF: UInt32 = 70730
DISPID_INTERNAL_FOCUSITEMS: UInt32 = 70731
DISPID_A_SCROLLBARTRACKCOLOR: UInt32 = 70732
DISPID_INTERNAL_DWNHEADERCACHE: UInt32 = 70733
DISPID_A_FROZEN: UInt32 = 70734
DISPID_A_VIEWINHERITSTYLE: UInt32 = 70735
DISPID_INTERNAL_FRAMESCOLLECTION: UInt32 = 70736
DISPID_A_BGURLIMGCTXCACHEINDEX_FLINE: UInt32 = 70737
DISPID_A_BGURLIMGCTXCACHEINDEX_FLETTER: UInt32 = 70738
DISPID_A_TEXTALIGNLAST: UInt32 = 70739
DISPID_A_TEXTKASHIDASPACE: UInt32 = 70740
DISPID_INTERNAL_FONTHISTORYINDEX: UInt32 = 70741
DISPID_A_ALLOWTRANSPARENCY: UInt32 = 70742
DISPID_INTERNAL_URLSEARCHCACHE: UInt32 = 70743
DISPID_A_ISBLOCK: UInt32 = 70744
DISPID_A_TEXTOVERFLOW: UInt32 = 70745
DISPID_INTERNAL_CATTRIBUTECOLLPTRCACHE: UInt32 = 70746
DISPID_A_MINHEIGHT: UInt32 = 70747
DISPID_INTERNAL_INVOKECONTEXTDOCUMENT: UInt32 = 70748
DISPID_A_INTERPOLATION: UInt32 = 70749
DISPID_A_MAXHEIGHT: UInt32 = 70750
DISPID_A_MINWIDTH: UInt32 = 70751
DISPID_A_MAXWIDTH: UInt32 = 70752
DISPID_INTERNAL_ARYOBJECTRELEASECLEANUPPTRCACHE: UInt32 = 70753
DISPID_A_CONTENT: UInt32 = 70754
DISPID_A_CAPTIONSIDE: UInt32 = 70755
DISPID_A_COUNTERINCREMENT: UInt32 = 70756
DISPID_A_COUNTERRESET: UInt32 = 70757
DISPID_A_OUTLINE: UInt32 = 70758
DISPID_A_OUTLINEWIDTH: UInt32 = 70759
DISPID_A_OUTLINESTYLE: UInt32 = 70760
DISPID_A_OUTLINECOLOR: UInt32 = 70761
DISPID_A_BOXSIZING: UInt32 = 70762
DISPID_A_BORDERSPACING: UInt32 = 70763
DISPID_A_ORPHANS: UInt32 = 70764
DISPID_A_WIDOWS: UInt32 = 70765
DISPID_A_PAGEBREAKINSIDE: UInt32 = 70766
DISPID_A_MS_BEHAVIOR: UInt32 = 70767
DISPID_A_MS_SCROLLBARBASECOLOR: UInt32 = 70768
DISPID_A_MS_SCROLLBARFACECOLOR: UInt32 = 70769
DISPID_A_MS_SCROLLBAR3DLIGHTCOLOR: UInt32 = 70770
DISPID_A_MS_SCROLLBARSHADOWCOLOR: UInt32 = 70771
DISPID_A_MS_SCROLLBARHIGHLIGHTCOLOR: UInt32 = 70772
DISPID_A_MS_SCROLLBARDARKSHADOWCOLOR: UInt32 = 70773
DISPID_A_MS_SCROLLBARARROWCOLOR: UInt32 = 70774
DISPID_A_MS_SCROLLBARTRACKCOLOR: UInt32 = 70775
DISPID_A_MS_TEXTALIGNLAST: UInt32 = 70776
DISPID_A_MS_TEXTOVERFLOW: UInt32 = 70777
DISPID_A_MS_TEXTUNDERLINEPOSITION: UInt32 = 70778
DISPID_A_MS_WRITINGMODE: UInt32 = 70779
DISPID_A_MS_IMEMODE: UInt32 = 70780
DISPID_A_MS_BACKGROUNDPOSX: UInt32 = 70781
DISPID_A_MS_BACKGROUNDPOSY: UInt32 = 70782
DISPID_A_MS_ACCELERATOR: UInt32 = 70783
DISPID_A_MS_LAYOUTFLOW: UInt32 = 70784
DISPID_A_MS_ZOOM: UInt32 = 70785
DISPID_A_EMPTYCELLS: UInt32 = 70786
DISPID_A_MS_BLOCKPROGRESSION: UInt32 = 70787
DISPID_A_QUOTES: UInt32 = 70788
DISPID_INTERNAL_BGURLIMGCTXCACHEINDEX_GCBEFORE: UInt32 = 70789
DISPID_INTERNAL_BGURLIMGCTXCACHEINDEX_GCAFTER: UInt32 = 70790
DISPID_INTERNAL_BGURLIMGCTXCACHEINDEX_URLBEFORE: UInt32 = 70791
DISPID_INTERNAL_BGURLIMGCTXCACHEINDEX_URLAFTER: UInt32 = 70792
DISPID_AAHEADER: UInt32 = 70793
DISPID_INTERNAL_GETTERSETTERCOLLECTION: UInt32 = 70794
DISPID_A_MS_LAYOUTGRIDCHAR: UInt32 = 70795
DISPID_A_MS_LAYOUTGRIDLINE: UInt32 = 70796
DISPID_A_MS_LAYOUTGRIDMODE: UInt32 = 70797
DISPID_A_MS_LAYOUTGRIDTYPE: UInt32 = 70798
DISPID_A_MS_LAYOUTGRID: UInt32 = 70799
DISPID_A_MS_LINEBREAK: UInt32 = 70800
DISPID_A_MS_FILTER: UInt32 = 70801
DISPID_A_MS_OVERFLOWX: UInt32 = 70802
DISPID_A_MS_OVERFLOWY: UInt32 = 70803
DISPID_A_MS_TEXTAUTOSPACE: UInt32 = 70804
DISPID_A_MS_TEXTJUSTIFY: UInt32 = 70805
DISPID_A_MS_TEXTKASHIDASPACE: UInt32 = 70806
DISPID_A_MS_WORDBREAK: UInt32 = 70807
DISPID_A_MS_WORDWRAP: UInt32 = 70808
DISPID_INTERNAL_URIBEFOREREDIRECT: UInt32 = 70809
DISPID_A_ALIGNMENTBASELINE: UInt32 = 70814
DISPID_A_BASELINESHIFT: UInt32 = 70815
DISPID_A_DOMINANTBASELINE: UInt32 = 70816
DISPID_A_FONTSIZEADJUST: UInt32 = 70817
DISPID_A_FONTSTRETCH: UInt32 = 70818
DISPID_A_OPACITY: UInt32 = 70819
DISPID_A_CLIPPATH: UInt32 = 70820
DISPID_A_CLIPRULE: UInt32 = 70821
DISPID_A_FILL: UInt32 = 70822
DISPID_A_FILLOPACITY: UInt32 = 70823
DISPID_A_FILLRULE: UInt32 = 70824
DISPID_A_KERNING: UInt32 = 70825
DISPID_A_MARKER: UInt32 = 70826
DISPID_A_MARKEREND: UInt32 = 70827
DISPID_A_MARKERMID: UInt32 = 70828
DISPID_A_MARKERSTART: UInt32 = 70829
DISPID_A_MASK: UInt32 = 70830
DISPID_A_POINTEREVENTS: UInt32 = 70831
DISPID_A_STOPCOLOR: UInt32 = 70832
DISPID_A_STOPOPACITY: UInt32 = 70833
DISPID_A_STROKE: UInt32 = 70834
DISPID_A_STROKEDASHARRAY: UInt32 = 70835
DISPID_A_STROKEDASHOFFSET: UInt32 = 70836
DISPID_A_STROKELINECAP: UInt32 = 70837
DISPID_A_STROKELINEJOIN: UInt32 = 70838
DISPID_A_STROKEMITERLIMIT: UInt32 = 70839
DISPID_A_STROKEOPACITY: UInt32 = 70840
DISPID_A_STROKEWIDTH: UInt32 = 70841
DISPID_A_TEXTANCHOR: UInt32 = 70842
DISPID_A_GLYPHORIENTATIONHORIZONTAL: UInt32 = 70843
DISPID_A_GLYPHORIENTATIONVERTICAL: UInt32 = 70844
DISPID_A_CSSFLOAT: UInt32 = 70845
DISPID_A_BORDERRADIUS: UInt32 = 70846
DISPID_A_BORDERTOPLEFTRADIUS: UInt32 = 70847
DISPID_A_BORDERTOPRIGHTRADIUS: UInt32 = 70848
DISPID_A_BORDERBOTTOMRIGHTRADIUS: UInt32 = 70849
DISPID_A_BORDERBOTTOMLEFTRADIUS: UInt32 = 70850
DISPID_A_MS_TRANSFORM: UInt32 = 70851
DISPID_A_IE9_BACKGROUNDCLIP: UInt32 = 70852
DISPID_A_IE9_BACKGROUNDORIGIN: UInt32 = 70853
DISPID_A_IE9_BACKGROUNDSIZE: UInt32 = 70854
DISPID_A_IE9_BOXSHADOW: UInt32 = 70855
DISPID_A_MS_TRANSFORMORIGIN: UInt32 = 70861
DISPID_A_MS_TRANSFORMORIGINX: UInt32 = 70862
DISPID_A_MS_TRANSFORMORIGINY: UInt32 = 70863
DISPID_A_MS_TEXTSIZEADJUST: UInt32 = 70864
DISPID_A_MS_TRANSITIONPROPERTY: UInt32 = 70866
DISPID_A_MS_TRANSITIONDURATION: UInt32 = 70867
DISPID_A_MS_TRANSITIONTIMINGFUNCTION: UInt32 = 70868
DISPID_A_MS_TRANSITIONDELAY: UInt32 = 70869
DISPID_A_MS_TRANSITION: UInt32 = 70870
DISPID_A_COLUMNS: UInt32 = 70871
DISPID_A_COLUMNCOUNT: UInt32 = 70872
DISPID_A_COLUMNWIDTH: UInt32 = 70873
DISPID_A_COLUMNGAP: UInt32 = 70874
DISPID_A_COLUMNFILL: UInt32 = 70875
DISPID_A_COLUMNSPAN: UInt32 = 70876
DISPID_A_COLUMNRULE: UInt32 = 70877
DISPID_A_COLUMNRULESTYLE: UInt32 = 70878
DISPID_A_COLUMNRULEWIDTH: UInt32 = 70879
DISPID_A_COLUMNRULECOLOR: UInt32 = 70880
DISPID_A_BREAKBEFORE: UInt32 = 70881
DISPID_A_BREAKAFTER: UInt32 = 70882
DISPID_A_BREAKINSIDE: UInt32 = 70883
DISPID_A_MS_TRANSFORMORIGINZ: UInt32 = 70884
DISPID_A_MS_PERSPECTIVE: UInt32 = 70885
DISPID_A_MS_PERSPECTIVEORIGIN: UInt32 = 70886
DISPID_A_MS_PERSPECTIVEORIGINX: UInt32 = 70887
DISPID_A_MS_PERSPECTIVEORIGINY: UInt32 = 70888
DISPID_A_MS_TRANSFORMSTYLE: UInt32 = 70889
DISPID_A_MS_BACKFACEVISIBILITY: UInt32 = 70890
DISPID_A_MS_SCROLLCHAINING: UInt32 = 70891
DISPID_A_MS_CONTENTZOOMING: UInt32 = 70892
DISPID_A_MS_CONTENTZOOMSNAPTYPE: UInt32 = 70893
DISPID_A_MS_SCROLLRAILS: UInt32 = 70894
DISPID_A_MS_CONTENTZOOMCHAINING: UInt32 = 70895
DISPID_A_MS_SCROLLSNAPTYPE: UInt32 = 70896
DISPID_A_MS_CONTENTZOOMLIMIT: UInt32 = 70897
DISPID_A_MS_CONTENTZOOMSNAP: UInt32 = 70898
DISPID_A_MS_CONTENTZOOMSNAPPOINTS: UInt32 = 70899
DISPID_A_MS_CONTENTZOOMFACTOR: UInt32 = 70900
DISPID_A_MS_CONTENTZOOMLIMITMIN: UInt32 = 70901
DISPID_A_MS_CONTENTZOOMLIMITMAX: UInt32 = 70902
DISPID_A_MS_SCROLLSNAPX: UInt32 = 70903
DISPID_A_MS_SCROLLSNAPY: UInt32 = 70904
DISPID_A_MS_SCROLLSNAPPOINTSX: UInt32 = 70905
DISPID_A_MS_SCROLLSNAPPOINTSY: UInt32 = 70906
DISPID_A_SPELLCHECK: UInt32 = 70907
DISPID_A_MS_GRIDCOLUMN: UInt32 = 70908
DISPID_A_MS_GRIDCOLUMNALIGN: UInt32 = 70909
DISPID_A_MS_GRIDCOLUMNS: UInt32 = 70910
DISPID_A_MS_GRIDCOLUMNSPAN: UInt32 = 70911
DISPID_A_MS_GRIDROW: UInt32 = 70913
DISPID_A_MS_GRIDROWALIGN: UInt32 = 70914
DISPID_A_MS_GRIDROWS: UInt32 = 70915
DISPID_A_MS_GRIDROWSPAN: UInt32 = 70916
DISPID_A_MS_ANIMATIONNAME: UInt32 = 70917
DISPID_A_MS_ANIMATIONDURATION: UInt32 = 70918
DISPID_A_MS_ANIMATIONTIMINGFUNCTION: UInt32 = 70919
DISPID_A_MS_ANIMATIONDELAY: UInt32 = 70920
DISPID_A_MS_ANIMATIONDIRECTION: UInt32 = 70921
DISPID_A_MS_ANIMATIONPLAYSTATE: UInt32 = 70922
DISPID_A_MS_ANIMATIONITERATIONCOUNT: UInt32 = 70923
DISPID_A_MS_ANIMATION: UInt32 = 70924
DISPID_A_MS_ANIMATIONFILLMODE: UInt32 = 70925
DISPID_A_FLOODCOLOR: UInt32 = 70926
DISPID_A_FLOODOPACITY: UInt32 = 70927
DISPID_A_COLORINTERPOLATIONFILTERS: UInt32 = 70928
DISPID_A_LIGHTINGCOLOR: UInt32 = 70929
DISPID_A_MS_SCROLLLIMITXMIN: UInt32 = 70930
DISPID_A_MS_SCROLLLIMITYMIN: UInt32 = 70931
DISPID_A_MS_SCROLLLIMITXMAX: UInt32 = 70932
DISPID_A_MS_SCROLLLIMITYMAX: UInt32 = 70933
DISPID_A_MS_SCROLLLIMIT: UInt32 = 70934
DISPID_A_MS_OVERFLOWSTYLE: UInt32 = 70935
DISPID_A_TEXTSHADOW: UInt32 = 70936
DISPID_A_MS_WRAPTHROUGH: UInt32 = 70937
DISPID_A_MS_FLOWFROM: UInt32 = 70938
DISPID_A_MS_FLOWINTO: UInt32 = 70939
DISPID_A_MS_HYPHENS: UInt32 = 70940
DISPID_A_MS_HYPHENATE_LIMIT_ZONE: UInt32 = 70941
DISPID_A_MS_HYPHENATE_LIMIT_CHARS: UInt32 = 70942
DISPID_A_MS_HYPHENATE_LIMIT_LINES: UInt32 = 70943
DISPID_A_DRAGGABLE: UInt32 = 70944
DISPID_A_MS_HIGHCONTRASTADJUST: UInt32 = 70945
DISPID_A_ENABLEBACKGROUND: UInt32 = 70946
DISPID_A_MS_WRAPMARGIN: UInt32 = 70947
DISPID_A_MS_WRAPFLOW: UInt32 = 70949
DISPID_A_MS_FONTFEATURESETTINGS: UInt32 = 70950
DISPID_A_MS_USERSELECT: UInt32 = 70951
DISPID_A_MS_TOUCHACTION: UInt32 = 70952
DISPID_A_CLASSLIST: UInt32 = 70953
DISPID_A_MS_SCROLLTRANSLATION: UInt32 = 70954
DISPID_A_MS_FLEX: UInt32 = 70955
DISPID_A_MS_FLEXPOSITIVE: UInt32 = 70956
DISPID_A_MS_FLEXNEGATIVE: UInt32 = 70957
DISPID_A_MS_FLEXPREFERREDSIZE: UInt32 = 70958
DISPID_A_MS_FLEXFLOW: UInt32 = 70959
DISPID_A_MS_FLEXDIRECTION: UInt32 = 70960
DISPID_A_MS_FLEXWRAP: UInt32 = 70961
DISPID_A_MS_FLEXALIGN: UInt32 = 70962
DISPID_A_MS_FLEXITEMALIGN: UInt32 = 70963
DISPID_A_MS_FLEXPACK: UInt32 = 70964
DISPID_A_MS_FLEXLINEPACK: UInt32 = 70965
DISPID_A_MS_FLEXORDER: UInt32 = 70966
DISPID_A_TRANSFORM: UInt32 = 70967
DISPID_A_TRANSFORMORIGIN: UInt32 = 70968
DISPID_A_TRANSITIONPROPERTY: UInt32 = 70969
DISPID_A_TRANSITIONDURATION: UInt32 = 70970
DISPID_A_TRANSITIONTIMINGFUNCTION: UInt32 = 70971
DISPID_A_TRANSITIONDELAY: UInt32 = 70972
DISPID_A_TRANSITION: UInt32 = 70973
DISPID_A_PERSPECTIVE: UInt32 = 70974
DISPID_A_PERSPECTIVEORIGIN: UInt32 = 70975
DISPID_A_TRANSFORMSTYLE: UInt32 = 70976
DISPID_A_BACKFACEVISIBILITY: UInt32 = 70977
DISPID_A_ANIMATIONNAME: UInt32 = 70978
DISPID_A_ANIMATIONDURATION: UInt32 = 70979
DISPID_A_ANIMATIONTIMINGFUNCTION: UInt32 = 70980
DISPID_A_ANIMATIONDELAY: UInt32 = 70981
DISPID_A_ANIMATIONDIRECTION: UInt32 = 70982
DISPID_A_ANIMATIONPLAYSTATE: UInt32 = 70983
DISPID_A_ANIMATIONITERATIONCOUNT: UInt32 = 70984
DISPID_A_ANIMATION: UInt32 = 70985
DISPID_A_ANIMATIONFILLMODE: UInt32 = 70986
DISPID_A_FONTFEATURESETTINGS: UInt32 = 70987
DISPID_A_TRANSFORMORIGINX: UInt32 = 70988
DISPID_A_TRANSFORMORIGINY: UInt32 = 70989
DISPID_A_TRANSFORMORIGINZ: UInt32 = 70990
DISPID_A_PERSPECTIVEORIGINX: UInt32 = 70992
DISPID_A_PERSPECTIVEORIGINY: UInt32 = 70993
DISPID_A_MS_TOUCHSELECT: UInt32 = 70994
DISPID_INTERNAL_ERRORPAGEREFRESHURL: UInt32 = 70995
DISPID_INTERNAL_ERRORPAGEREASON: UInt32 = 70996
DISPID_INTERNAL_ERRORPAGEDWNPOST: UInt32 = 70997
DISPID_A_FLEXDIRECTION: UInt32 = 70998
DISPID_A_FLEXWRAP: UInt32 = 70999
DISPID_A_FLEXFLOW: UInt32 = 71000
DISPID_A_ORDER: UInt32 = 71001
DISPID_A_FLEX: UInt32 = 71002
DISPID_A_FLEXGROW: UInt32 = 71003
DISPID_A_FLEXSHRINK: UInt32 = 71004
DISPID_A_FLEXBASIS: UInt32 = 71005
DISPID_A_JUSTIFYCONTENT: UInt32 = 71006
DISPID_A_ALIGNITEMS: UInt32 = 71007
DISPID_A_ALIGNSELF: UInt32 = 71008
DISPID_A_ALIGNCONTENT: UInt32 = 71009
DISPID_A_BORDERIMAGE: UInt32 = 71010
DISPID_A_BORDERIMAGESOURCE: UInt32 = 71011
DISPID_A_BORDERIMAGESLICE: UInt32 = 71012
DISPID_A_BORDERIMAGEWIDTH: UInt32 = 71013
DISPID_A_BORDERIMAGEOUTSET: UInt32 = 71014
DISPID_A_BORDERIMAGEREPEAT: UInt32 = 71015
DISPID_A_DATASET: UInt32 = 71016
DISPID_A_MS_IMEALIGN: UInt32 = 71017
DISPID_A_MS_TEXTCOMBINEHORIZONTAL: UInt32 = 71018
DISPID_A_TOUCHACTION: UInt32 = 71019
DISPID_A_WEBKIT_APPEARANCE: UInt32 = 71020
DISPID_A_WEBKIT_BOXALIGN: UInt32 = 71021
DISPID_A_WEBKIT_BOXORDINALGROUP: UInt32 = 71022
DISPID_A_WEBKIT_BOXPACK: UInt32 = 71023
DISPID_A_WEBKIT_BOXFLEX: UInt32 = 71024
DISPID_A_WEBKIT_BOXORIENT: UInt32 = 71025
DISPID_A_WEBKIT_BOXDIRECTION: UInt32 = 71026
DISPID_A_WEBKIT_ANIMATIONFILLMODE: UInt32 = 71027
DISPID_A_WEBKIT_TRANSFORM: UInt32 = 71028
DISPID_A_WEBKIT_BACKGROUNDSIZE: UInt32 = 71029
DISPID_A_WEBKIT_BACKFACEVISIBILITY: UInt32 = 71030
DISPID_A_WEBKIT_BOXSIZING: UInt32 = 71031
DISPID_A_WEBKIT_USERSELECT: UInt32 = 71032
DISPID_A_WEBKIT_ANIMATION: UInt32 = 71033
DISPID_A_WEBKIT_TRANSITION: UInt32 = 71034
DISPID_A_WEBKIT_ANIMATIONNAME: UInt32 = 71035
DISPID_A_WEBKIT_ANIMATIONDURATION: UInt32 = 71036
DISPID_A_WEBKIT_ANIMATIONTIMINGFUNCTION: UInt32 = 71037
DISPID_A_WEBKIT_ANIMATIONDELAY: UInt32 = 71038
DISPID_A_WEBKIT_ANIMATIONITERATIONCOUNT: UInt32 = 71039
DISPID_A_WEBKIT_ANIMATIONDIRECTION: UInt32 = 71040
DISPID_A_WEBKIT_ANIMATIONPLAYSTATE: UInt32 = 71041
DISPID_A_WEBKIT_TRANSITIONPROPERTY: UInt32 = 71042
DISPID_A_WEBKIT_TRANSITIONDURATION: UInt32 = 71043
DISPID_A_WEBKIT_TRANSITIONTIMINGFUNCTION: UInt32 = 71044
DISPID_A_WEBKIT_TRANSITIONDELAY: UInt32 = 71045
DISPID_A_WEBKIT_BACKGROUNDATTACHMENT: UInt32 = 71046
DISPID_A_WEBKIT_BACKGROUNDCOLOR: UInt32 = 71047
DISPID_A_WEBKIT_BACKGROUNDCLIP: UInt32 = 71048
DISPID_A_WEBKIT_BACKGROUNDIMAGE: UInt32 = 71049
DISPID_A_WEBKIT_BACKGROUNDREPEAT: UInt32 = 71050
DISPID_A_WEBKIT_BACKGROUNDORIGIN: UInt32 = 71051
DISPID_A_WEBKIT_BACKGROUNDPOSITION: UInt32 = 71052
DISPID_A_WEBKIT_BACKGROUNDPOSITIONX: UInt32 = 71053
DISPID_A_WEBKIT_BACKGROUNDPOSITIONY: UInt32 = 71054
DISPID_A_WEBKIT_BACKGROUND: UInt32 = 71055
DISPID_A_WEBKIT_TRANSFORMORIGIN: UInt32 = 71056
DISPID_A_WEBKIT_TRANSFORMORIGINX: UInt32 = 71057
DISPID_A_WEBKIT_TRANSFORMORIGINY: UInt32 = 71058
DISPID_A_WEBKIT_TRANSFORMORIGINZ: UInt32 = 71059
DISPID_A_WEBKIT_TEXTSIZEADJUST: UInt32 = 71060
DISPID_A_WEBKIT_BORDERIMAGE: UInt32 = 71061
DISPID_A_WEBKIT_BORDERIMAGESOURCE: UInt32 = 71062
DISPID_A_WEBKIT_BORDERIMAGESLICE: UInt32 = 71063
DISPID_A_WEBKIT_BORDERIMAGEWIDTH: UInt32 = 71064
DISPID_A_WEBKIT_BORDERIMAGEOUTSET: UInt32 = 71065
DISPID_A_WEBKIT_BORDERIMAGEREPEAT: UInt32 = 71066
DISPID_INTERNAL_FIRST: UInt32 = 71136
DISPID_INTERNAL_BACKGROUNDDEFINITION: UInt32 = 71137
DISPID_A_MEDIAORIENTATION: UInt32 = 71138
DISPID_A_MEDIAMAXWIDTH: UInt32 = 71139
DISPID_A_MEDIAMINWIDTH: UInt32 = 71140
DISPID_A_MEDIAWIDTH: UInt32 = 71141
DISPID_A_MEDIAMAXHEIGHT: UInt32 = 71142
DISPID_A_MEDIAMINHEIGHT: UInt32 = 71143
DISPID_A_MEDIAHEIGHT: UInt32 = 71144
DISPID_A_MEDIAMAXDEVICEWIDTH: UInt32 = 71145
DISPID_A_MEDIAMINDEVICEWIDTH: UInt32 = 71146
DISPID_A_MEDIADEVICEWIDTH: UInt32 = 71147
DISPID_A_MEDIAMAXDEVICEHEIGHT: UInt32 = 71148
DISPID_A_MEDIAMINDEVICEHEIGHT: UInt32 = 71149
DISPID_A_MEDIADEVICEHEIGHT: UInt32 = 71150
DISPID_A_MEDIAMAXASPECTRATIO: UInt32 = 71151
DISPID_A_MEDIAMINASPECTRATIO: UInt32 = 71152
DISPID_A_MEDIAASPECTRATIO: UInt32 = 71153
DISPID_A_MEDIAMAXDEVICEASPECTRATIO: UInt32 = 71154
DISPID_A_MEDIAMINDEVICEASPECTRATIO: UInt32 = 71155
DISPID_A_MEDIADEVICEASPECTRATIO: UInt32 = 71156
DISPID_A_MEDIAMAXCOLOR: UInt32 = 71157
DISPID_A_MEDIAMINCOLOR: UInt32 = 71158
DISPID_A_MEDIACOLOR: UInt32 = 71159
DISPID_A_MEDIAMAXCOLORINDEX: UInt32 = 71160
DISPID_A_MEDIAMINCOLORINDEX: UInt32 = 71161
DISPID_A_MEDIACOLORINDEX: UInt32 = 71162
DISPID_A_MEDIAMAXMONOCHROME: UInt32 = 71163
DISPID_A_MEDIAMINMONOCHROME: UInt32 = 71164
DISPID_A_MEDIAMONOCHROME: UInt32 = 71165
DISPID_A_MEDIAMAXRESOLUTION: UInt32 = 71166
DISPID_A_MEDIAMINRESOLUTION: UInt32 = 71167
DISPID_A_MEDIARESOLUTION: UInt32 = 71168
DISPID_INTERNAL_CATTRIBUTEPTRCACHE: UInt32 = 71169
DISPID_INTERNAL_FONTFACEUNICODERANGE: UInt32 = 71170
DISPID_INTERNAL_TOUCHTARGETHANDLER: UInt32 = 71171
DISPID_INTERNAL_PAGEFLOWCOLLECTION: UInt32 = 71172
DISPID_INTERNAL_NAMEDFLOWCOLLECTION: UInt32 = 71173
DISPID_A_MEDIAMSHIGHCONTRAST: UInt32 = 71174
DISPID_INTERNAL_A_MS_HYPHENATE_LIMIT_WORDS: UInt32 = 71175
DISPID_INTERNAL_A_MS_HYPHENATE_LIMIT_BEFORE: UInt32 = 71176
DISPID_INTERNAL_A_MS_HYPHENATE_LIMIT_AFTER: UInt32 = 71177
DISPID_A_MEDIAMSVIEWSTATE: UInt32 = 71178
DISPID_INTERNAL_ARIAATOMIC: UInt32 = 71179
DISPID_INTERNAL_ARIAAUTOCOMPLETE: UInt32 = 71180
DISPID_INTERNAL_ARIADROPEFFECT: UInt32 = 71181
DISPID_INTERNAL_ARIAGRABBED: UInt32 = 71182
DISPID_INTERNAL_ARIALABEL: UInt32 = 71183
DISPID_INTERNAL_ARIAMULTILINE: UInt32 = 71184
DISPID_INTERNAL_ARIAORIENTATION: UInt32 = 71185
DISPID_INTERNAL_ARIASORT: UInt32 = 71186
DISPID_INTERNAL_ARIAVALUETEXT: UInt32 = 71187
DISPID_A_MEDIAGRID: UInt32 = 71188
DISPID_A_MEDIASCAN: UInt32 = 71189
DISPID_A_ACCEVENTRECORDID_START: UInt32 = 71190
DISPID_A_ACCEVENTRECORDID_END: UInt32 = 71209
DISPID_INTERNAL_REQUIRED: UInt32 = 71210
DISPID_INTERNAL_CSS_PARSEDARY: UInt32 = 71211
DISPID_INTERNAL_SOURCELOCATION: UInt32 = 71212
DISPID_INTERNAL_CSS_TRACEDSTYLES: UInt32 = 71213
DISPID_A_BDURLIMGCTXCACHEINDEX: UInt32 = 71214
DISPID_A_MEDIAWEBKITDEVICEPIXELRATIO: UInt32 = 71215
DISPID_A_MEDIAWEBKITMAXDEVICEPIXELRATIO: UInt32 = 71216
DISPID_A_MEDIAWEBKITMINDEVICEPIXELRATIO: UInt32 = 71217
DISPID_SVGSTYLABLE_CLASSNAME_PROP: UInt32 = 1001
DISPID_SVGLOCATABLE_NEARESTVIEWPORTELEMENT: UInt32 = 1002
DISPID_SVGLOCATABLE_FARTHESTVIEWPORTELEMENT: UInt32 = 1003
DISPID_SVGLOCATABLE_GETBBOX: UInt32 = 1004
DISPID_SVGLOCATABLE_GETCTM: UInt32 = 1005
DISPID_SVGLOCATABLE_GETSCREENCTM: UInt32 = 1006
DISPID_SVGLOCATABLE_GETTRANSFORMTOELEMENT: UInt32 = 1007
DISPID_SVGTRANSFORMABLE_TRANSFORM_ATTR: UInt32 = 1008
DISPID_SVGTRANSFORMABLE_TRANSFORM_PROP: UInt32 = 1009
DISPID_SVGTESTS_REQUIREDFEATURES_ATTR: UInt32 = 1010
DISPID_SVGTESTS_REQUIREDFEATURES_PROP: UInt32 = 1011
DISPID_SVGTESTS_REQUIREDEXTENSIONS_ATTR: UInt32 = 1012
DISPID_SVGTESTS_REQUIREDEXTENSIONS_PROP: UInt32 = 1013
DISPID_SVGTESTS_SYSTEMLANGUAGE_ATTR: UInt32 = 1014
DISPID_SVGTESTS_SYSTEMLANGUAGE_PROP: UInt32 = 1015
DISPID_SVGTESTS_HASEXTENSION: UInt32 = 1016
DISPID_SVGLANGSPACE_XMLLANG: UInt32 = 1017
DISPID_SVGLANGSPACE_XMLSPACE: UInt32 = 1018
DISPID_SVGEXTERNALRESOURCESREQUIRED_EXTERNALRESOURCESREQUIRED_ATTR: UInt32 = 1019
DISPID_SVGEXTERNALRESOURCESREQUIRED_EXTERNALRESOURCESREQUIRED_PROP: UInt32 = 1020
DISPID_SVGFITTOVIEWBOX_VIEWBOX_ATTR: UInt32 = 1021
DISPID_SVGFITTOVIEWBOX_VIEWBOX_PROP: UInt32 = 1022
DISPID_SVGFITTOVIEWBOX_PRESERVEASPECTRATIO_ATTR: UInt32 = 1023
DISPID_SVGFITTOVIEWBOX_PRESERVEASPECTRATIO_PROP: UInt32 = 1024
DISPID_SVGZOOMANDPAN_ZOOMANDPAN: UInt32 = 1025
DISPID_SVGURIREFERENCE_HREF: UInt32 = 1026
DISPID_EVPROP_ONMOUSEOVER: UInt32 = 71536
DISPID_EVMETH_ONMOUSEOVER: UInt32 = 65544
DISPID_EVPROP_ONMOUSEOUT: UInt32 = 71537
DISPID_EVMETH_ONMOUSEOUT: UInt32 = 65545
DISPID_EVPROP_ONMOUSEDOWN: UInt32 = 71538
DISPID_EVMETH_ONMOUSEDOWN: Int32 = -605
DISPID_EVPROP_ONMOUSEUP: UInt32 = 71539
DISPID_EVMETH_ONMOUSEUP: Int32 = -607
DISPID_EVPROP_ONMOUSEMOVE: UInt32 = 71540
DISPID_EVMETH_ONMOUSEMOVE: Int32 = -606
DISPID_EVPROP_ONKEYDOWN: UInt32 = 71541
DISPID_EVMETH_ONKEYDOWN: Int32 = -602
DISPID_EVPROP_ONKEYUP: UInt32 = 71542
DISPID_EVMETH_ONKEYUP: Int32 = -604
DISPID_EVPROP_ONKEYPRESS: UInt32 = 71543
DISPID_EVMETH_ONKEYPRESS: Int32 = -603
DISPID_EVPROP_ONCLICK: UInt32 = 71544
DISPID_EVMETH_ONCLICK: Int32 = -600
DISPID_EVPROP_ONDBLCLICK: UInt32 = 71545
DISPID_EVMETH_ONDBLCLICK: Int32 = -601
DISPID_EVPROP_ONSELECT: UInt32 = 71546
DISPID_EVMETH_ONSELECT: UInt32 = 1006
DISPID_EVPROP_ONSUBMIT: UInt32 = 71547
DISPID_EVMETH_ONSUBMIT: UInt32 = 1007
DISPID_EVPROP_ONRESET: UInt32 = 71548
DISPID_EVMETH_ONRESET: UInt32 = 1015
DISPID_EVPROP_ONHELP: UInt32 = 71549
DISPID_EVMETH_ONHELP: UInt32 = 65546
DISPID_EVPROP_ONFOCUS: UInt32 = 71550
DISPID_EVMETH_ONFOCUS: UInt32 = 65537
DISPID_EVPROP_ONBLUR: UInt32 = 71551
DISPID_EVPROP_ONROWEXIT: UInt32 = 71554
DISPID_EVMETH_ONROWEXIT: UInt32 = 65542
DISPID_EVPROP_ONROWENTER: UInt32 = 71555
DISPID_EVMETH_ONROWENTER: UInt32 = 65543
DISPID_EVPROP_ONBOUNCE: UInt32 = 71556
DISPID_EVMETH_ONBOUNCE: UInt32 = 1009
DISPID_EVPROP_ONBEFOREUPDATE: UInt32 = 71557
DISPID_EVMETH_ONBEFOREUPDATE: UInt32 = 65540
DISPID_EVPROP_ONAFTERUPDATE: UInt32 = 71558
DISPID_EVMETH_ONAFTERUPDATE: UInt32 = 65541
DISPID_EVPROP_ONBEFOREDRAGOVER: UInt32 = 71559
DISPID_EVPROP_ONBEFOREDROPORPASTE: UInt32 = 71560
DISPID_EVPROP_ONREADYSTATECHANGE: UInt32 = 71561
DISPID_EVMETH_ONREADYSTATECHANGE: Int32 = -609
DISPID_EVPROP_ONFINISH: UInt32 = 71562
DISPID_EVMETH_ONFINISH: UInt32 = 1010
DISPID_EVPROP_ONSTART: UInt32 = 71563
DISPID_EVMETH_ONSTART: UInt32 = 1011
DISPID_EVPROP_ONABORT: UInt32 = 71564
DISPID_EVMETH_ONABORT: UInt32 = 1000
DISPID_EVPROP_ONERROR: UInt32 = 71565
DISPID_EVMETH_ONERROR: UInt32 = 1002
DISPID_EVPROP_ONCHANGE: UInt32 = 71566
DISPID_EVMETH_ONCHANGE: UInt32 = 1001
DISPID_EVPROP_ONSCROLL: UInt32 = 71567
DISPID_EVMETH_ONSCROLL: UInt32 = 1014
DISPID_EVPROP_ONLOAD: UInt32 = 71568
DISPID_EVMETH_ONLOAD: UInt32 = 1003
DISPID_EVPROP_ONUNLOAD: UInt32 = 71569
DISPID_EVMETH_ONUNLOAD: UInt32 = 1008
DISPID_EVPROP_ONLAYOUT: UInt32 = 71570
DISPID_EVMETH_ONLAYOUT: UInt32 = 1013
DISPID_EVPROP_ONDRAGSTART: UInt32 = 71571
DISPID_EVMETH_ONDRAGSTART: UInt32 = 65547
DISPID_EVPROP_ONRESIZE: UInt32 = 71572
DISPID_EVMETH_ONRESIZE: UInt32 = 1016
DISPID_EVPROP_ONSELECTSTART: UInt32 = 71573
DISPID_EVMETH_ONSELECTSTART: UInt32 = 65548
DISPID_EVPROP_ONERRORUPDATE: UInt32 = 71574
DISPID_EVMETH_ONERRORUPDATE: UInt32 = 65549
DISPID_EVPROP_ONBEFOREUNLOAD: UInt32 = 71575
DISPID_EVMETH_ONBEFOREUNLOAD: UInt32 = 1017
DISPID_EVPROP_ONDATASETCHANGED: UInt32 = 71576
DISPID_EVMETH_ONDATASETCHANGED: UInt32 = 65550
DISPID_EVPROP_ONDATAAVAILABLE: UInt32 = 71577
DISPID_EVMETH_ONDATAAVAILABLE: UInt32 = 65551
DISPID_EVPROP_ONDATASETCOMPLETE: UInt32 = 71578
DISPID_EVMETH_ONDATASETCOMPLETE: UInt32 = 65552
DISPID_EVPROP_ONFILTER: UInt32 = 71579
DISPID_EVMETH_ONFILTER: UInt32 = 65553
DISPID_EVPROP_ONCHANGEFOCUS: UInt32 = 71580
DISPID_EVMETH_ONCHANGEFOCUS: UInt32 = 1018
DISPID_EVPROP_ONCHANGEBLUR: UInt32 = 71581
DISPID_EVMETH_ONCHANGEBLUR: UInt32 = 1019
DISPID_EVPROP_ONLOSECAPTURE: UInt32 = 71582
DISPID_EVMETH_ONLOSECAPTURE: UInt32 = 65554
DISPID_EVPROP_ONPROPERTYCHANGE: UInt32 = 71583
DISPID_EVMETH_ONPROPERTYCHANGE: UInt32 = 65555
DISPID_EVPROP_ONPERSISTSAVE: UInt32 = 71584
DISPID_EVMETH_ONPERSISTSAVE: UInt32 = 1021
DISPID_EVPROP_ONDRAG: UInt32 = 71585
DISPID_EVMETH_ONDRAG: UInt32 = 65556
DISPID_EVPROP_ONDRAGEND: UInt32 = 71586
DISPID_EVMETH_ONDRAGEND: UInt32 = 65557
DISPID_EVPROP_ONDRAGENTER: UInt32 = 71587
DISPID_EVMETH_ONDRAGENTER: UInt32 = 65558
DISPID_EVPROP_ONDRAGOVER: UInt32 = 71588
DISPID_EVMETH_ONDRAGOVER: UInt32 = 65559
DISPID_EVPROP_ONDRAGLEAVE: UInt32 = 71589
DISPID_EVMETH_ONDRAGLEAVE: UInt32 = 65560
DISPID_EVPROP_ONDROP: UInt32 = 71590
DISPID_EVMETH_ONDROP: UInt32 = 65561
DISPID_EVPROP_ONCUT: UInt32 = 71591
DISPID_EVMETH_ONCUT: UInt32 = 65562
DISPID_EVPROP_ONCOPY: UInt32 = 71592
DISPID_EVMETH_ONCOPY: UInt32 = 65563
DISPID_EVPROP_ONPASTE: UInt32 = 71593
DISPID_EVMETH_ONPASTE: UInt32 = 65564
DISPID_EVPROP_ONBEFORECUT: UInt32 = 71594
DISPID_EVMETH_ONBEFORECUT: UInt32 = 65565
DISPID_EVPROP_ONBEFORECOPY: UInt32 = 71595
DISPID_EVMETH_ONBEFORECOPY: UInt32 = 65566
DISPID_EVPROP_ONBEFOREPASTE: UInt32 = 71596
DISPID_EVMETH_ONBEFOREPASTE: UInt32 = 65567
DISPID_EVPROP_ONPERSISTLOAD: UInt32 = 71597
DISPID_EVMETH_ONPERSISTLOAD: UInt32 = 1022
DISPID_EVPROP_ONROWSDELETE: UInt32 = 71598
DISPID_EVMETH_ONROWSDELETE: UInt32 = 65568
DISPID_EVPROP_ONROWSINSERTED: UInt32 = 71599
DISPID_EVMETH_ONROWSINSERTED: UInt32 = 65569
DISPID_EVPROP_ONCELLCHANGE: UInt32 = 71600
DISPID_EVMETH_ONCELLCHANGE: UInt32 = 65570
DISPID_EVPROP_ONCONTEXTMENU: UInt32 = 71601
DISPID_EVMETH_ONCONTEXTMENU: UInt32 = 1023
DISPID_EVPROP_ONBEFOREPRINT: UInt32 = 71602
DISPID_EVMETH_ONBEFOREPRINT: UInt32 = 1024
DISPID_EVPROP_ONAFTERPRINT: UInt32 = 71603
DISPID_EVMETH_ONAFTERPRINT: UInt32 = 1025
DISPID_EVPROP_ONSTOP: UInt32 = 71604
DISPID_EVMETH_ONSTOP: UInt32 = 1026
DISPID_EVPROP_ONBEFOREEDITFOCUS: UInt32 = 71605
DISPID_EVMETH_ONBEFOREEDITFOCUS: UInt32 = 1027
DISPID_EVPROP_ONATTACHEVENT: UInt32 = 71606
DISPID_EVPROP_ONMOUSEHOVER: UInt32 = 71607
DISPID_EVMETH_ONMOUSEHOVER: UInt32 = 1028
DISPID_EVPROP_ONCONTENTREADY: UInt32 = 71608
DISPID_EVMETH_ONCONTENTREADY: UInt32 = 1029
DISPID_EVPROP_ONLAYOUTCOMPLETE: UInt32 = 71609
DISPID_EVMETH_ONLAYOUTCOMPLETE: UInt32 = 1030
DISPID_EVPROP_ONPAGE: UInt32 = 71610
DISPID_EVMETH_ONPAGE: UInt32 = 1031
DISPID_EVPROP_ONLINKEDOVERFLOW: UInt32 = 71611
DISPID_EVMETH_ONLINKEDOVERFLOW: UInt32 = 1032
DISPID_EVPROP_ONMOUSEWHEEL: UInt32 = 71612
DISPID_EVMETH_ONMOUSEWHEEL: UInt32 = 1033
DISPID_EVPROP_ONBEFOREDEACTIVATE: UInt32 = 71613
DISPID_EVMETH_ONBEFOREDEACTIVATE: UInt32 = 1034
DISPID_EVPROP_ONMOVE: UInt32 = 71614
DISPID_EVMETH_ONMOVE: UInt32 = 1035
DISPID_EVPROP_ONCONTROLSELECT: UInt32 = 71615
DISPID_EVMETH_ONCONTROLSELECT: UInt32 = 1036
DISPID_EVPROP_ONSELECTIONCHANGE: UInt32 = 71616
DISPID_EVMETH_ONSELECTIONCHANGE: UInt32 = 1037
DISPID_EVPROP_ONMOVESTART: UInt32 = 71617
DISPID_EVMETH_ONMOVESTART: UInt32 = 1038
DISPID_EVPROP_ONMOVEEND: UInt32 = 71618
DISPID_EVMETH_ONMOVEEND: UInt32 = 1039
DISPID_EVPROP_ONRESIZESTART: UInt32 = 71619
DISPID_EVMETH_ONRESIZESTART: UInt32 = 1040
DISPID_EVPROP_ONRESIZEEND: UInt32 = 71620
DISPID_EVMETH_ONRESIZEEND: UInt32 = 1041
DISPID_EVPROP_ONMOUSEENTER: UInt32 = 71621
DISPID_EVMETH_ONMOUSEENTER: UInt32 = 1042
DISPID_EVPROP_ONMOUSELEAVE: UInt32 = 71622
DISPID_EVMETH_ONMOUSELEAVE: UInt32 = 1043
DISPID_EVPROP_ONACTIVATE: UInt32 = 71623
DISPID_EVMETH_ONACTIVATE: UInt32 = 1044
DISPID_EVPROP_ONDEACTIVATE: UInt32 = 71624
DISPID_EVMETH_ONDEACTIVATE: UInt32 = 1045
DISPID_EVPROP_ONMULTILAYOUTCLEANUP: UInt32 = 71625
DISPID_EVMETH_ONMULTILAYOUTCLEANUP: UInt32 = 1046
DISPID_EVPROP_ONBEFOREACTIVATE: UInt32 = 71626
DISPID_EVMETH_ONBEFOREACTIVATE: UInt32 = 1047
DISPID_EVPROP_ONFOCUSIN: UInt32 = 71627
DISPID_EVMETH_ONFOCUSIN: UInt32 = 1048
DISPID_EVPROP_ONFOCUSOUT: UInt32 = 71628
DISPID_EVMETH_ONFOCUSOUT: UInt32 = 1049
DISPID_EVPROP_ONVALUECHANGE: UInt32 = 71629
DISPID_EVMETH_ONVALUECHANGE: UInt32 = 1050
DISPID_EVPROP_ONSELECTADD: UInt32 = 71630
DISPID_EVMETH_ONSELECTADD: UInt32 = 1051
DISPID_EVPROP_ONSELECTREMOVE: UInt32 = 71631
DISPID_EVMETH_ONSELECTREMOVE: UInt32 = 1052
DISPID_EVPROP_ONSELECTWITHIN: UInt32 = 71632
DISPID_EVMETH_ONSELECTWITHIN: UInt32 = 1053
DISPID_EVPROP_ONSYSTEMSCROLLINGSTART: UInt32 = 71633
DISPID_EVMETH_ONSYSTEMSCROLLINGSTART: UInt32 = 1054
DISPID_EVPROP_ONSYSTEMSCROLLINGEND: UInt32 = 71634
DISPID_EVMETH_ONSYSTEMSCROLLINGEND: UInt32 = 1055
DISPID_EVPROP_ONOBJECTCONTENTSCROLLED: UInt32 = 71635
DISPID_EVMETH_ONOBJECTCONTENTSCROLLED: UInt32 = 1056
DISPID_EVPROP_ONSTORAGE: UInt32 = 71636
DISPID_EVMETH_ONSTORAGE: UInt32 = 1057
DISPID_EVPROP_ONSTORAGECOMMIT: UInt32 = 71637
DISPID_EVMETH_ONSTORAGECOMMIT: UInt32 = 1058
DISPID_EVPROP_ONSHOW: UInt32 = 71638
DISPID_EVMETH_ONSHOW: UInt32 = 1059
DISPID_EVPROP_ONHIDE: UInt32 = 71639
DISPID_EVMETH_ONHIDE: UInt32 = 1060
DISPID_EVPROP_ONALERT: UInt32 = 71640
DISPID_EVMETH_ONALERT: UInt32 = 1061
DISPID_EVPROP_ONPOPUPMENUSTART: UInt32 = 71641
DISPID_EVMETH_ONPOPUPMENUSTART: UInt32 = 1062
DISPID_EVPROP_ONPOPUPMENUEND: UInt32 = 71642
DISPID_EVMETH_ONPOPUPMENUEND: UInt32 = 1063
DISPID_EVPROP_ONONLINE: UInt32 = 71643
DISPID_EVMETH_ONONLINE: UInt32 = 1064
DISPID_EVPROP_ONOFFLINE: UInt32 = 71644
DISPID_EVMETH_ONOFFLINE: UInt32 = 1065
DISPID_EVPROP_ONHASHCHANGE: UInt32 = 71645
DISPID_EVMETH_ONHASHCHANGE: UInt32 = 1066
DISPID_EVPROP_ONMESSAGE: UInt32 = 71646
DISPID_EVMETH_ONMESSAGE: UInt32 = 1067
DISPID_EVPROP_ONDOMMUTATION: UInt32 = 71647
DISPID_EVMETH_ONDOMMUTATION: UInt32 = 1068
DISPID_EVPROP_SINKLIMIT: UInt32 = 71647
DISPID_EVPROP_TIMEOUT: UInt32 = 71648
DISPID_EVPROP_WHEEL: UInt32 = 71649
DISPID_EVPROP_SVGLOAD: UInt32 = 71650
DISPID_EVPROP_SVGUNLOAD: UInt32 = 71651
DISPID_EVPROP_SVGABORT: UInt32 = 71652
DISPID_EVPROP_SVGERROR: UInt32 = 71653
DISPID_EVPROP_SVGRESIZE: UInt32 = 71654
DISPID_EVPROP_SVGSCROLL: UInt32 = 71655
DISPID_EVPROP_SVGZOOM: UInt32 = 71656
DISPID_EVPROP_ONMSTHUMBNAILCLICK: UInt32 = 71657
DISPID_EVPROP_COMPOSITIONSTART: UInt32 = 71658
DISPID_EVPROP_COMPOSITIONUPDATE: UInt32 = 71659
DISPID_EVPROP_COMPOSITIONEND: UInt32 = 71660
DISPID_EVPROP_DOMATTRMODIFIED: UInt32 = 71661
DISPID_EVPROP_DOMCONTENTLOADED: UInt32 = 71662
DISPID_EVPROP_INPUT: UInt32 = 71663
DISPID_EVPROP_DOMCHARDATAMODIFIED: UInt32 = 71664
DISPID_EVPROP_TEXTINPUT: UInt32 = 71665
DISPID_EVPROP_ONMSSITEMODEJUMPLISTITEMREMOVED: UInt32 = 71666
DISPID_EVPROP_DOMNODEINSERTED: UInt32 = 71667
DISPID_EVPROP_DOMNODEREMOVED: UInt32 = 71668
DISPID_EVPROP_DOMSUBTREEMODIFIED: UInt32 = 71669
DISPID_EVPROP_CANPLAY: UInt32 = 71670
DISPID_EVPROP_CANPLAYTHROUGH: UInt32 = 71671
DISPID_EVPROP_DURATIONCHANGE: UInt32 = 71672
DISPID_EVPROP_EMPTIED: UInt32 = 71673
DISPID_EVPROP_ENDED: UInt32 = 71674
DISPID_EVPROP_LOADEDDATA: UInt32 = 71675
DISPID_EVPROP_LOADEDMETADATA: UInt32 = 71676
DISPID_EVPROP_LOADSTART: UInt32 = 71677
DISPID_EVPROP_PAUSE: UInt32 = 71678
DISPID_EVPROP_PLAY: UInt32 = 71679
DISPID_EVPROP_PLAYING: UInt32 = 71680
DISPID_EVPROP_PROGRESS: UInt32 = 71681
DISPID_EVPROP_RATECHANGE: UInt32 = 71682
DISPID_EVPROP_SEEKED: UInt32 = 71683
DISPID_EVPROP_SEEKING: UInt32 = 71684
DISPID_EVPROP_STALLED: UInt32 = 71685
DISPID_EVPROP_SUSPEND: UInt32 = 71686
DISPID_EVPROP_TIMEUPDATE: UInt32 = 71687
DISPID_EVPROP_VOLUMECHANGE: UInt32 = 71688
DISPID_EVPROP_WAITING: UInt32 = 71689
DISPID_EVPROP_ONMSPOINTERDOWN: UInt32 = 71690
DISPID_EVPROP_ONMSPOINTERMOVE: UInt32 = 71691
DISPID_EVPROP_ONMSPOINTERUP: UInt32 = 71692
DISPID_EVPROP_ONMSPOINTEROVER: UInt32 = 71693
DISPID_EVPROP_ONMSPOINTEROUT: UInt32 = 71694
DISPID_EVPROP_ONMSPOINTERCANCEL: UInt32 = 71695
DISPID_EVPROP_ONMSPOINTERHOVER: UInt32 = 71696
DISPID_EVPROP_MSCONNECT: UInt32 = 71697
DISPID_EVPROP_MSDISCONNECT: UInt32 = 71698
DISPID_EVPROP_ONMSGESTURESTART: UInt32 = 71699
DISPID_EVPROP_ONMSGESTURECHANGE: UInt32 = 71700
DISPID_EVPROP_ONMSGESTUREEND: UInt32 = 71701
DISPID_EVPROP_ONMSGESTUREHOLD: UInt32 = 71702
DISPID_EVPROP_ONMSGESTURETAP: UInt32 = 71703
DISPID_EVPROP_ONMSGESTUREDOUBLETAP: UInt32 = 71704
DISPID_EVPROP_ONMSINERTIASTART: UInt32 = 71705
DISPID_EVPROP_ONMSLOSTPOINTERCAPTURE: UInt32 = 71706
DISPID_EVPROP_ONMSGOTPOINTERCAPTURE: UInt32 = 71707
DISPID_EVPROP_ONMSCONTENTZOOM: UInt32 = 71708
DISPID_EVPROP_ONTRANSITIONSTART: UInt32 = 71709
DISPID_EVPROP_ONTRANSITIONEND: UInt32 = 71710
DISPID_EVPROP_ONANIMATIONSTART: UInt32 = 71711
DISPID_EVPROP_ONANIMATIONEND: UInt32 = 71712
DISPID_EVPROP_ONANIMATIONITERATION: UInt32 = 71713
DISPID_EVPROP_ONMSMANIPULATIONSTATECHANGED: UInt32 = 71714
DISPID_EVPROP_ONOPEN: UInt32 = 71715
DISPID_EVPROP_ONCLOSE: UInt32 = 71716
DISPID_EVPROP_CHECKING: UInt32 = 71717
DISPID_EVPROP_NOUPDATE: UInt32 = 71718
DISPID_EVPROP_DOWNLOADING: UInt32 = 71719
DISPID_EVPROP_UPDATEREADY: UInt32 = 71720
DISPID_EVPROP_CACHED: UInt32 = 71721
DISPID_EVPROP_OBSOLETE: UInt32 = 71722
DISPID_EVPROP_LOADEND: UInt32 = 71723
DISPID_EVPROP_INVALID: UInt32 = 71724
DISPID_EVPROP_ONSUCCESS: UInt32 = 71725
DISPID_EVPROP_ONBLOCKED: UInt32 = 71726
DISPID_EVPROP_ONCOMPLETE: UInt32 = 71727
DISPID_EVPROP_ONPOPSTATE: UInt32 = 71728
DISPID_EVPROP_ONCUECHANGE: UInt32 = 71729
DISPID_EVPROP_ONENTER: UInt32 = 71730
DISPID_EVPROP_ONEXIT: UInt32 = 71731
DISPID_EVPROP_VISIBILITYCHANGE: UInt32 = 71732
DISPID_EVPROP_ONMSREGIONUPDATE: UInt32 = 71733
DISPID_EVPROP_ONUPGRADENEEDED: UInt32 = 71734
DISPID_EVPROP_ONMSVIDEOFORMATCHANGED: UInt32 = 71735
DISPID_EVPROP_ADDTRACK: UInt32 = 71736
DISPID_EVPROP_ONMSVIDEOFRAMESTEPCOMPLETED: UInt32 = 71737
DISPID_EVPROP_ONMSHOLDVISUAL: UInt32 = 71738
DISPID_EVPROP_ONMSVIDEOOPTIMALLAYOUTCHANGED: UInt32 = 71739
DISPID_EVPROP_ONMSFULLSCREENCHANGE: UInt32 = 71740
DISPID_EVPROP_ONMSFULLSCREENERROR: UInt32 = 71741
DISPID_EVPROP_MSELEMENTRESIZE: UInt32 = 71742
DISPID_EVPROP_ONSOURCEOPEN: UInt32 = 71743
DISPID_EVPROP_ONSOURCECLOSE: UInt32 = 71744
DISPID_EVPROP_ONSOURCEENDED: UInt32 = 71745
DISPID_EVPROP_ONADDSOURCEBUFFER: UInt32 = 71746
DISPID_EVPROP_ONREMOVESOURCEBUFFER: UInt32 = 71747
DISPID_EVPROP_ONMSNEEDKEY: UInt32 = 71748
DISPID_EVPROP_ONMSKEYMESSAGE: UInt32 = 71749
DISPID_EVPROP_ONMSKEYERROR: UInt32 = 71750
DISPID_EVPROP_ONMSKEYADDED: UInt32 = 71751
DISPID_EVPROP_MSHTMLWEBVIEW_ONDOMCONTENTLOADED: UInt32 = 71752
DISPID_EVPROP_MSHTMLWEBVIEW_ONCONTENTLOADING: UInt32 = 71753
DISPID_EVPROP_MSHTMLWEBVIEW_ONNAVIGATIONSTARTING: UInt32 = 71754
DISPID_EVPROP_MSHTMLWEBVIEW_ONNAVIGATIONCOMPLETED: UInt32 = 71755
DISPID_EVPROP_MSHTMLWEBVIEW_ONFRAMEDOMCONTENTLOADED: UInt32 = 71756
DISPID_EVPROP_MSHTMLWEBVIEW_ONFRAMECONTENTLOADING: UInt32 = 71757
DISPID_EVPROP_MSHTMLWEBVIEW_ONFRAMENAVIGATIONSTARTING: UInt32 = 71758
DISPID_EVPROP_MSHTMLWEBVIEW_ONFRAMENAVIGATIONCOMPLETED: UInt32 = 71759
DISPID_EVPROP_MSHTMLWEBVIEW_ONSCRIPTNOTIFY: UInt32 = 71760
DISPID_EVPROP_MSHTMLWEBVIEW_ONUNVIEWABLECONTENT: UInt32 = 71761
DISPID_EVPROP_MSHTMLWEBVIEW_ONUNSAFECONTENTWARNINGDISPLAYING: UInt32 = 71762
DISPID_EVPROP_MSHTMLWEBVIEW_ONLONGRUNNINGSCRIPTDETECTED: UInt32 = 71763
DISPID_EVPROP_WEBGLCONTEXTLOST: UInt32 = 71764
DISPID_EVPROP_WEBGLCONTEXTRESTORED: UInt32 = 71765
DISPID_EVPROP_ONUPDATESTART: UInt32 = 71766
DISPID_EVPROP_ONUPDATE: UInt32 = 71767
DISPID_EVPROP_ONUPDATEEND: UInt32 = 71768
DISPID_EVPROP_ONMSPOINTERENTER: UInt32 = 71769
DISPID_EVPROP_ONMSPOINTERLEAVE: UInt32 = 71770
DISPID_EVPROP_ONMSSITEPINNED: UInt32 = 71771
DISPID_EVPROP_MSORIENTATIONCHANGE: UInt32 = 71772
DISPID_EVPROP_ONDEVICEORIENTATION: UInt32 = 71773
DISPID_EVPROP_ONDEVICEMOTION: UInt32 = 71774
DISPID_EVPROP_ONPAGESHOW: UInt32 = 71775
DISPID_EVPROP_ONPAGEHIDE: UInt32 = 71776
DISPID_EVPROP_ONMSCANDIDATEWINDOWSHOW: UInt32 = 71777
DISPID_EVPROP_ONMSCANDIDATEWINDOWUPDATE: UInt32 = 71778
DISPID_EVPROP_ONMSCANDIDATEWINDOWHIDE: UInt32 = 71779
DISPID_EVPROP_HTML5ONREADYSTATECHANGE: UInt32 = 71780
DISPID_EVPROP_REMOVETRACK: UInt32 = 71781
DISPID_EVPROP_ONCOMPASSNEEDSCALIBRATION: UInt32 = 71782
DISPID_EVPROP_MSHTMLWEBVIEW_ONCONTAINSFULLSCREENELEMENTCHANGED: UInt32 = 71783
DISPID_EVPROP_ONTOUCHSTART: UInt32 = 71784
DISPID_EVPROP_ONTOUCHEND: UInt32 = 71785
DISPID_EVPROP_ONTOUCHMOVE: UInt32 = 71786
DISPID_EVPROP_ONTOUCHCANCEL: UInt32 = 71787
DISPID_EVPROP_ONWEBKITTRANSITIONEND: UInt32 = 71788
DISPID_EVPROP_ONWEBKITANIMATIONSTART: UInt32 = 71789
DISPID_EVPROP_ONWEBKITANIMATIONEND: UInt32 = 71790
DISPID_EVPROP_ONWEBKITANIMATIONITERATION: UInt32 = 71791
DISPID_EVPROP_WEBGLCONTEXTCREATIONERROR: UInt32 = 71792
DISPID_EVPROP_ONDOMFOCUSIN: UInt32 = 71793
DISPID_EVPROP_ONDOMFOCUSOUT: UInt32 = 71794
DISPID_EVPROP_ORIENTATIONCHANGE: UInt32 = 71795
DISPID_EVPROPS_COUNT: UInt32 = 260
DISPID_IHTMLFILTERSCOLLECTION_LENGTH: UInt32 = 1001
DISPID_IHTMLFILTERSCOLLECTION__NEWENUM: Int32 = -4
DISPID_IHTMLFILTERSCOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLDOMCONSTRUCTOR_CONSTRUCTOR: UInt32 = 66045
DISPID_IHTMLCSSSTYLEDECLARATION_LENGTH: UInt32 = 70037
DISPID_IHTMLCSSSTYLEDECLARATION_PARENTRULE: UInt32 = 70038
DISPID_IHTMLCSSSTYLEDECLARATION_GETPROPERTYVALUE: UInt32 = 70039
DISPID_IHTMLCSSSTYLEDECLARATION_GETPROPERTYPRIORITY: UInt32 = 70040
DISPID_IHTMLCSSSTYLEDECLARATION_REMOVEPROPERTY: UInt32 = 70041
DISPID_IHTMLCSSSTYLEDECLARATION_SETPROPERTY: UInt32 = 70042
DISPID_IHTMLCSSSTYLEDECLARATION_ITEM: UInt32 = 0
DISPID_IHTMLCSSSTYLEDECLARATION_FONTFAMILY: UInt32 = 70554
DISPID_IHTMLCSSSTYLEDECLARATION_FONTSTYLE: UInt32 = 70560
DISPID_IHTMLCSSSTYLEDECLARATION_FONTVARIANT: UInt32 = 70561
DISPID_IHTMLCSSSTYLEDECLARATION_FONTWEIGHT: UInt32 = 70563
DISPID_IHTMLCSSSTYLEDECLARATION_FONTSIZE: UInt32 = 70555
DISPID_IHTMLCSSSTYLEDECLARATION_FONT: UInt32 = 70577
DISPID_IHTMLCSSSTYLEDECLARATION_COLOR: UInt32 = 70538
DISPID_IHTMLCSSSTYLEDECLARATION_BACKGROUND: UInt32 = 70568
DISPID_IHTMLCSSSTYLEDECLARATION_BACKGROUNDCOLOR: Int32 = -501
DISPID_IHTMLCSSSTYLEDECLARATION_BACKGROUNDIMAGE: UInt32 = 70537
DISPID_IHTMLCSSSTYLEDECLARATION_BACKGROUNDREPEAT: UInt32 = 70580
DISPID_IHTMLCSSSTYLEDECLARATION_BACKGROUNDATTACHMENT: UInt32 = 70581
DISPID_IHTMLCSSSTYLEDECLARATION_BACKGROUNDPOSITION: UInt32 = 70582
DISPID_IHTMLCSSSTYLEDECLARATION_BACKGROUNDPOSITIONX: UInt32 = 70569
DISPID_IHTMLCSSSTYLEDECLARATION_BACKGROUNDPOSITIONY: UInt32 = 70570
DISPID_IHTMLCSSSTYLEDECLARATION_WORDSPACING: UInt32 = 70583
DISPID_IHTMLCSSSTYLEDECLARATION_LETTERSPACING: UInt32 = 70544
DISPID_IHTMLCSSSTYLEDECLARATION_TEXTDECORATION: UInt32 = 70571
DISPID_IHTMLCSSSTYLEDECLARATION_VERTICALALIGN: UInt32 = 70584
DISPID_IHTMLCSSSTYLEDECLARATION_TEXTTRANSFORM: UInt32 = 70540
DISPID_IHTMLCSSSTYLEDECLARATION_TEXTALIGN: UInt32 = 65608
DISPID_IHTMLCSSSTYLEDECLARATION_TEXTINDENT: UInt32 = 70543
DISPID_IHTMLCSSSTYLEDECLARATION_LINEHEIGHT: UInt32 = 70542
DISPID_IHTMLCSSSTYLEDECLARATION_MARGINTOP: UInt32 = 70573
DISPID_IHTMLCSSSTYLEDECLARATION_MARGINRIGHT: UInt32 = 70574
DISPID_IHTMLCSSSTYLEDECLARATION_MARGINBOTTOM: UInt32 = 70575
DISPID_IHTMLCSSSTYLEDECLARATION_MARGINLEFT: UInt32 = 70576
DISPID_IHTMLCSSSTYLEDECLARATION_MARGIN: UInt32 = 70572
DISPID_IHTMLCSSSTYLEDECLARATION_PADDINGTOP: UInt32 = 70548
DISPID_IHTMLCSSSTYLEDECLARATION_PADDINGRIGHT: UInt32 = 70549
DISPID_IHTMLCSSSTYLEDECLARATION_PADDINGBOTTOM: UInt32 = 70550
DISPID_IHTMLCSSSTYLEDECLARATION_PADDINGLEFT: UInt32 = 70551
DISPID_IHTMLCSSSTYLEDECLARATION_PADDING: UInt32 = 70547
DISPID_IHTMLCSSSTYLEDECLARATION_BORDER: UInt32 = 70585
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERTOP: UInt32 = 70586
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERRIGHT: UInt32 = 70587
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERBOTTOM: UInt32 = 70588
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERLEFT: UInt32 = 70589
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERCOLOR: UInt32 = 70590
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERTOPCOLOR: UInt32 = 70591
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERRIGHTCOLOR: UInt32 = 70592
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERBOTTOMCOLOR: UInt32 = 70593
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERLEFTCOLOR: UInt32 = 70594
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERWIDTH: UInt32 = 70595
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERTOPWIDTH: UInt32 = 70596
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERRIGHTWIDTH: UInt32 = 70597
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERBOTTOMWIDTH: UInt32 = 70598
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERLEFTWIDTH: UInt32 = 70599
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERSTYLE: UInt32 = 70600
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERTOPSTYLE: UInt32 = 70601
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERRIGHTSTYLE: UInt32 = 70602
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERBOTTOMSTYLE: UInt32 = 70603
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERLEFTSTYLE: UInt32 = 70604
DISPID_IHTMLCSSSTYLEDECLARATION_WIDTH: UInt32 = 65541
DISPID_IHTMLCSSSTYLEDECLARATION_HEIGHT: UInt32 = 65542
DISPID_IHTMLCSSSTYLEDECLARATION_STYLEFLOAT: UInt32 = 70606
DISPID_IHTMLCSSSTYLEDECLARATION_CLEAR: UInt32 = 70552
DISPID_IHTMLCSSSTYLEDECLARATION_DISPLAY: UInt32 = 70607
DISPID_IHTMLCSSSTYLEDECLARATION_VISIBILITY: UInt32 = 70616
DISPID_IHTMLCSSSTYLEDECLARATION_LISTSTYLETYPE: UInt32 = 70608
DISPID_IHTMLCSSSTYLEDECLARATION_LISTSTYLEPOSITION: UInt32 = 70609
DISPID_IHTMLCSSSTYLEDECLARATION_LISTSTYLEIMAGE: UInt32 = 70610
DISPID_IHTMLCSSSTYLEDECLARATION_LISTSTYLE: UInt32 = 70611
DISPID_IHTMLCSSSTYLEDECLARATION_WHITESPACE: UInt32 = 70612
DISPID_IHTMLCSSSTYLEDECLARATION_TOP: UInt32 = 65540
DISPID_IHTMLCSSSTYLEDECLARATION_LEFT: UInt32 = 65539
DISPID_IHTMLCSSSTYLEDECLARATION_ZINDEX: UInt32 = 70627
DISPID_IHTMLCSSSTYLEDECLARATION_OVERFLOW: UInt32 = 70546
DISPID_IHTMLCSSSTYLEDECLARATION_PAGEBREAKBEFORE: UInt32 = 70613
DISPID_IHTMLCSSSTYLEDECLARATION_PAGEBREAKAFTER: UInt32 = 70614
DISPID_IHTMLCSSSTYLEDECLARATION_CSSTEXT: UInt32 = 70635
DISPID_IHTMLCSSSTYLEDECLARATION_CURSOR: UInt32 = 70638
DISPID_IHTMLCSSSTYLEDECLARATION_CLIP: UInt32 = 70628
DISPID_IHTMLCSSSTYLEDECLARATION_FILTER: UInt32 = 70618
DISPID_IHTMLCSSSTYLEDECLARATION_TABLELAYOUT: UInt32 = 70634
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERCOLLAPSE: UInt32 = 70620
DISPID_IHTMLCSSSTYLEDECLARATION_DIRECTION: UInt32 = 70655
DISPID_IHTMLCSSSTYLEDECLARATION_BEHAVIOR: UInt32 = 70651
DISPID_IHTMLCSSSTYLEDECLARATION_POSITION: UInt32 = 70626
DISPID_IHTMLCSSSTYLEDECLARATION_UNICODEBIDI: UInt32 = 70654
DISPID_IHTMLCSSSTYLEDECLARATION_BOTTOM: UInt32 = 65614
DISPID_IHTMLCSSSTYLEDECLARATION_RIGHT: UInt32 = 65613
DISPID_IHTMLCSSSTYLEDECLARATION_IMEMODE: UInt32 = 70656
DISPID_IHTMLCSSSTYLEDECLARATION_RUBYALIGN: UInt32 = 70657
DISPID_IHTMLCSSSTYLEDECLARATION_RUBYPOSITION: UInt32 = 70658
DISPID_IHTMLCSSSTYLEDECLARATION_RUBYOVERHANG: UInt32 = 70659
DISPID_IHTMLCSSSTYLEDECLARATION_LAYOUTGRIDCHAR: UInt32 = 70663
DISPID_IHTMLCSSSTYLEDECLARATION_LAYOUTGRIDLINE: UInt32 = 70664
DISPID_IHTMLCSSSTYLEDECLARATION_LAYOUTGRIDMODE: UInt32 = 70665
DISPID_IHTMLCSSSTYLEDECLARATION_LAYOUTGRIDTYPE: UInt32 = 70666
DISPID_IHTMLCSSSTYLEDECLARATION_LAYOUTGRID: UInt32 = 70667
DISPID_IHTMLCSSSTYLEDECLARATION_TEXTAUTOSPACE: UInt32 = 70668
DISPID_IHTMLCSSSTYLEDECLARATION_WORDBREAK: UInt32 = 70670
DISPID_IHTMLCSSSTYLEDECLARATION_LINEBREAK: UInt32 = 70669
DISPID_IHTMLCSSSTYLEDECLARATION_TEXTJUSTIFY: UInt32 = 70671
DISPID_IHTMLCSSSTYLEDECLARATION_TEXTJUSTIFYTRIM: UInt32 = 70672
DISPID_IHTMLCSSSTYLEDECLARATION_TEXTKASHIDA: UInt32 = 70673
DISPID_IHTMLCSSSTYLEDECLARATION_OVERFLOWX: UInt32 = 70675
DISPID_IHTMLCSSSTYLEDECLARATION_OVERFLOWY: UInt32 = 70676
DISPID_IHTMLCSSSTYLEDECLARATION_ACCELERATOR: UInt32 = 70683
DISPID_IHTMLCSSSTYLEDECLARATION_LAYOUTFLOW: UInt32 = 70691
DISPID_IHTMLCSSSTYLEDECLARATION_ZOOM: UInt32 = 70689
DISPID_IHTMLCSSSTYLEDECLARATION_WORDWRAP: UInt32 = 70694
DISPID_IHTMLCSSSTYLEDECLARATION_TEXTUNDERLINEPOSITION: UInt32 = 70695
DISPID_IHTMLCSSSTYLEDECLARATION_SCROLLBARBASECOLOR: UInt32 = 70716
DISPID_IHTMLCSSSTYLEDECLARATION_SCROLLBARFACECOLOR: UInt32 = 70717
DISPID_IHTMLCSSSTYLEDECLARATION_SCROLLBAR3DLIGHTCOLOR: UInt32 = 70718
DISPID_IHTMLCSSSTYLEDECLARATION_SCROLLBARSHADOWCOLOR: UInt32 = 70719
DISPID_IHTMLCSSSTYLEDECLARATION_SCROLLBARHIGHLIGHTCOLOR: UInt32 = 70720
DISPID_IHTMLCSSSTYLEDECLARATION_SCROLLBARDARKSHADOWCOLOR: UInt32 = 70721
DISPID_IHTMLCSSSTYLEDECLARATION_SCROLLBARARROWCOLOR: UInt32 = 70722
DISPID_IHTMLCSSSTYLEDECLARATION_SCROLLBARTRACKCOLOR: UInt32 = 70732
DISPID_IHTMLCSSSTYLEDECLARATION_WRITINGMODE: UInt32 = 70728
DISPID_IHTMLCSSSTYLEDECLARATION_TEXTALIGNLAST: UInt32 = 70739
DISPID_IHTMLCSSSTYLEDECLARATION_TEXTKASHIDASPACE: UInt32 = 70740
DISPID_IHTMLCSSSTYLEDECLARATION_TEXTOVERFLOW: UInt32 = 70745
DISPID_IHTMLCSSSTYLEDECLARATION_MINHEIGHT: UInt32 = 70747
DISPID_IHTMLCSSSTYLEDECLARATION_MSINTERPOLATIONMODE: UInt32 = 70749
DISPID_IHTMLCSSSTYLEDECLARATION_MAXHEIGHT: UInt32 = 70750
DISPID_IHTMLCSSSTYLEDECLARATION_MINWIDTH: UInt32 = 70751
DISPID_IHTMLCSSSTYLEDECLARATION_MAXWIDTH: UInt32 = 70752
DISPID_IHTMLCSSSTYLEDECLARATION_CONTENT: UInt32 = 70754
DISPID_IHTMLCSSSTYLEDECLARATION_CAPTIONSIDE: UInt32 = 70755
DISPID_IHTMLCSSSTYLEDECLARATION_COUNTERINCREMENT: UInt32 = 70756
DISPID_IHTMLCSSSTYLEDECLARATION_COUNTERRESET: UInt32 = 70757
DISPID_IHTMLCSSSTYLEDECLARATION_OUTLINE: UInt32 = 70758
DISPID_IHTMLCSSSTYLEDECLARATION_OUTLINEWIDTH: UInt32 = 70759
DISPID_IHTMLCSSSTYLEDECLARATION_OUTLINESTYLE: UInt32 = 70760
DISPID_IHTMLCSSSTYLEDECLARATION_OUTLINECOLOR: UInt32 = 70761
DISPID_IHTMLCSSSTYLEDECLARATION_BOXSIZING: UInt32 = 70762
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERSPACING: UInt32 = 70763
DISPID_IHTMLCSSSTYLEDECLARATION_ORPHANS: UInt32 = 70764
DISPID_IHTMLCSSSTYLEDECLARATION_WIDOWS: UInt32 = 70765
DISPID_IHTMLCSSSTYLEDECLARATION_PAGEBREAKINSIDE: UInt32 = 70766
DISPID_IHTMLCSSSTYLEDECLARATION_EMPTYCELLS: UInt32 = 70786
DISPID_IHTMLCSSSTYLEDECLARATION_MSBLOCKPROGRESSION: UInt32 = 70787
DISPID_IHTMLCSSSTYLEDECLARATION_QUOTES: UInt32 = 70788
DISPID_IHTMLCSSSTYLEDECLARATION_ALIGNMENTBASELINE: UInt32 = 70814
DISPID_IHTMLCSSSTYLEDECLARATION_BASELINESHIFT: UInt32 = 70815
DISPID_IHTMLCSSSTYLEDECLARATION_DOMINANTBASELINE: UInt32 = 70816
DISPID_IHTMLCSSSTYLEDECLARATION_FONTSIZEADJUST: UInt32 = 70817
DISPID_IHTMLCSSSTYLEDECLARATION_FONTSTRETCH: UInt32 = 70818
DISPID_IHTMLCSSSTYLEDECLARATION_OPACITY: UInt32 = 70819
DISPID_IHTMLCSSSTYLEDECLARATION_CLIPPATH: UInt32 = 70820
DISPID_IHTMLCSSSTYLEDECLARATION_CLIPRULE: UInt32 = 70821
DISPID_IHTMLCSSSTYLEDECLARATION_FILL: UInt32 = 70822
DISPID_IHTMLCSSSTYLEDECLARATION_FILLOPACITY: UInt32 = 70823
DISPID_IHTMLCSSSTYLEDECLARATION_FILLRULE: UInt32 = 70824
DISPID_IHTMLCSSSTYLEDECLARATION_KERNING: UInt32 = 70825
DISPID_IHTMLCSSSTYLEDECLARATION_MARKER: UInt32 = 70826
DISPID_IHTMLCSSSTYLEDECLARATION_MARKEREND: UInt32 = 70827
DISPID_IHTMLCSSSTYLEDECLARATION_MARKERMID: UInt32 = 70828
DISPID_IHTMLCSSSTYLEDECLARATION_MARKERSTART: UInt32 = 70829
DISPID_IHTMLCSSSTYLEDECLARATION_MASK: UInt32 = 70830
DISPID_IHTMLCSSSTYLEDECLARATION_POINTEREVENTS: UInt32 = 70831
DISPID_IHTMLCSSSTYLEDECLARATION_STOPCOLOR: UInt32 = 70832
DISPID_IHTMLCSSSTYLEDECLARATION_STOPOPACITY: UInt32 = 70833
DISPID_IHTMLCSSSTYLEDECLARATION_STROKE: UInt32 = 70834
DISPID_IHTMLCSSSTYLEDECLARATION_STROKEDASHARRAY: UInt32 = 70835
DISPID_IHTMLCSSSTYLEDECLARATION_STROKEDASHOFFSET: UInt32 = 70836
DISPID_IHTMLCSSSTYLEDECLARATION_STROKELINECAP: UInt32 = 70837
DISPID_IHTMLCSSSTYLEDECLARATION_STROKELINEJOIN: UInt32 = 70838
DISPID_IHTMLCSSSTYLEDECLARATION_STROKEMITERLIMIT: UInt32 = 70839
DISPID_IHTMLCSSSTYLEDECLARATION_STROKEOPACITY: UInt32 = 70840
DISPID_IHTMLCSSSTYLEDECLARATION_STROKEWIDTH: UInt32 = 70841
DISPID_IHTMLCSSSTYLEDECLARATION_TEXTANCHOR: UInt32 = 70842
DISPID_IHTMLCSSSTYLEDECLARATION_GLYPHORIENTATIONHORIZONTAL: UInt32 = 70843
DISPID_IHTMLCSSSTYLEDECLARATION_GLYPHORIENTATIONVERTICAL: UInt32 = 70844
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERRADIUS: UInt32 = 70846
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERTOPLEFTRADIUS: UInt32 = 70847
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERTOPRIGHTRADIUS: UInt32 = 70848
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERBOTTOMRIGHTRADIUS: UInt32 = 70849
DISPID_IHTMLCSSSTYLEDECLARATION_BORDERBOTTOMLEFTRADIUS: UInt32 = 70850
DISPID_IHTMLCSSSTYLEDECLARATION_CLIPTOP: UInt32 = 70629
DISPID_IHTMLCSSSTYLEDECLARATION_CLIPRIGHT: UInt32 = 70630
DISPID_IHTMLCSSSTYLEDECLARATION_CLIPBOTTOM: UInt32 = 70631
DISPID_IHTMLCSSSTYLEDECLARATION_CLIPLEFT: UInt32 = 70632
DISPID_IHTMLCSSSTYLEDECLARATION_CSSFLOAT: UInt32 = 70845
DISPID_IHTMLCSSSTYLEDECLARATION_BACKGROUNDCLIP: UInt32 = 70852
DISPID_IHTMLCSSSTYLEDECLARATION_BACKGROUNDORIGIN: UInt32 = 70853
DISPID_IHTMLCSSSTYLEDECLARATION_BACKGROUNDSIZE: UInt32 = 70854
DISPID_IHTMLCSSSTYLEDECLARATION_BOXSHADOW: UInt32 = 70855
DISPID_IHTMLCSSSTYLEDECLARATION_MSTRANSFORM: UInt32 = 70851
DISPID_IHTMLCSSSTYLEDECLARATION_MSTRANSFORMORIGIN: UInt32 = 70861
DISPID_IHTMLCSSSTYLEDECLARATION2_MSSCROLLCHAINING: UInt32 = 70891
DISPID_IHTMLCSSSTYLEDECLARATION2_MSCONTENTZOOMING: UInt32 = 70892
DISPID_IHTMLCSSSTYLEDECLARATION2_MSCONTENTZOOMSNAPTYPE: UInt32 = 70893
DISPID_IHTMLCSSSTYLEDECLARATION2_MSSCROLLRAILS: UInt32 = 70894
DISPID_IHTMLCSSSTYLEDECLARATION2_MSCONTENTZOOMCHAINING: UInt32 = 70895
DISPID_IHTMLCSSSTYLEDECLARATION2_MSSCROLLSNAPTYPE: UInt32 = 70896
DISPID_IHTMLCSSSTYLEDECLARATION2_MSCONTENTZOOMLIMIT: UInt32 = 70897
DISPID_IHTMLCSSSTYLEDECLARATION2_MSCONTENTZOOMSNAP: UInt32 = 70898
DISPID_IHTMLCSSSTYLEDECLARATION2_MSCONTENTZOOMSNAPPOINTS: UInt32 = 70899
DISPID_IHTMLCSSSTYLEDECLARATION2_MSCONTENTZOOMLIMITMIN: UInt32 = 70901
DISPID_IHTMLCSSSTYLEDECLARATION2_MSCONTENTZOOMLIMITMAX: UInt32 = 70902
DISPID_IHTMLCSSSTYLEDECLARATION2_MSSCROLLSNAPX: UInt32 = 70903
DISPID_IHTMLCSSSTYLEDECLARATION2_MSSCROLLSNAPY: UInt32 = 70904
DISPID_IHTMLCSSSTYLEDECLARATION2_MSSCROLLSNAPPOINTSX: UInt32 = 70905
DISPID_IHTMLCSSSTYLEDECLARATION2_MSSCROLLSNAPPOINTSY: UInt32 = 70906
DISPID_IHTMLCSSSTYLEDECLARATION2_MSGRIDCOLUMN: UInt32 = 70908
DISPID_IHTMLCSSSTYLEDECLARATION2_MSGRIDCOLUMNALIGN: UInt32 = 70909
DISPID_IHTMLCSSSTYLEDECLARATION2_MSGRIDCOLUMNS: UInt32 = 70910
DISPID_IHTMLCSSSTYLEDECLARATION2_MSGRIDCOLUMNSPAN: UInt32 = 70911
DISPID_IHTMLCSSSTYLEDECLARATION2_MSGRIDROW: UInt32 = 70913
DISPID_IHTMLCSSSTYLEDECLARATION2_MSGRIDROWALIGN: UInt32 = 70914
DISPID_IHTMLCSSSTYLEDECLARATION2_MSGRIDROWS: UInt32 = 70915
DISPID_IHTMLCSSSTYLEDECLARATION2_MSGRIDROWSPAN: UInt32 = 70916
DISPID_IHTMLCSSSTYLEDECLARATION2_MSWRAPTHROUGH: UInt32 = 70937
DISPID_IHTMLCSSSTYLEDECLARATION2_MSWRAPMARGIN: UInt32 = 70947
DISPID_IHTMLCSSSTYLEDECLARATION2_MSWRAPFLOW: UInt32 = 70949
DISPID_IHTMLCSSSTYLEDECLARATION2_MSANIMATIONNAME: UInt32 = 70917
DISPID_IHTMLCSSSTYLEDECLARATION2_MSANIMATIONDURATION: UInt32 = 70918
DISPID_IHTMLCSSSTYLEDECLARATION2_MSANIMATIONTIMINGFUNCTION: UInt32 = 70919
DISPID_IHTMLCSSSTYLEDECLARATION2_MSANIMATIONDELAY: UInt32 = 70920
DISPID_IHTMLCSSSTYLEDECLARATION2_MSANIMATIONDIRECTION: UInt32 = 70921
DISPID_IHTMLCSSSTYLEDECLARATION2_MSANIMATIONPLAYSTATE: UInt32 = 70922
DISPID_IHTMLCSSSTYLEDECLARATION2_MSANIMATIONITERATIONCOUNT: UInt32 = 70923
DISPID_IHTMLCSSSTYLEDECLARATION2_MSANIMATION: UInt32 = 70924
DISPID_IHTMLCSSSTYLEDECLARATION2_MSANIMATIONFILLMODE: UInt32 = 70925
DISPID_IHTMLCSSSTYLEDECLARATION2_COLORINTERPOLATIONFILTERS: UInt32 = 70928
DISPID_IHTMLCSSSTYLEDECLARATION2_COLUMNCOUNT: UInt32 = 70872
DISPID_IHTMLCSSSTYLEDECLARATION2_COLUMNWIDTH: UInt32 = 70873
DISPID_IHTMLCSSSTYLEDECLARATION2_COLUMNGAP: UInt32 = 70874
DISPID_IHTMLCSSSTYLEDECLARATION2_COLUMNFILL: UInt32 = 70875
DISPID_IHTMLCSSSTYLEDECLARATION2_COLUMNSPAN: UInt32 = 70876
DISPID_IHTMLCSSSTYLEDECLARATION2_COLUMNS: UInt32 = 70871
DISPID_IHTMLCSSSTYLEDECLARATION2_COLUMNRULE: UInt32 = 70877
DISPID_IHTMLCSSSTYLEDECLARATION2_COLUMNRULECOLOR: UInt32 = 70880
DISPID_IHTMLCSSSTYLEDECLARATION2_COLUMNRULESTYLE: UInt32 = 70878
DISPID_IHTMLCSSSTYLEDECLARATION2_COLUMNRULEWIDTH: UInt32 = 70879
DISPID_IHTMLCSSSTYLEDECLARATION2_BREAKBEFORE: UInt32 = 70881
DISPID_IHTMLCSSSTYLEDECLARATION2_BREAKAFTER: UInt32 = 70882
DISPID_IHTMLCSSSTYLEDECLARATION2_BREAKINSIDE: UInt32 = 70883
DISPID_IHTMLCSSSTYLEDECLARATION2_FLOODCOLOR: UInt32 = 70926
DISPID_IHTMLCSSSTYLEDECLARATION2_FLOODOPACITY: UInt32 = 70927
DISPID_IHTMLCSSSTYLEDECLARATION2_LIGHTINGCOLOR: UInt32 = 70929
DISPID_IHTMLCSSSTYLEDECLARATION2_MSSCROLLLIMITXMIN: UInt32 = 70930
DISPID_IHTMLCSSSTYLEDECLARATION2_MSSCROLLLIMITYMIN: UInt32 = 70931
DISPID_IHTMLCSSSTYLEDECLARATION2_MSSCROLLLIMITXMAX: UInt32 = 70932
DISPID_IHTMLCSSSTYLEDECLARATION2_MSSCROLLLIMITYMAX: UInt32 = 70933
DISPID_IHTMLCSSSTYLEDECLARATION2_MSSCROLLLIMIT: UInt32 = 70934
DISPID_IHTMLCSSSTYLEDECLARATION2_TEXTSHADOW: UInt32 = 70936
DISPID_IHTMLCSSSTYLEDECLARATION2_MSFLOWFROM: UInt32 = 70938
DISPID_IHTMLCSSSTYLEDECLARATION2_MSFLOWINTO: UInt32 = 70939
DISPID_IHTMLCSSSTYLEDECLARATION2_MSHYPHENS: UInt32 = 70940
DISPID_IHTMLCSSSTYLEDECLARATION2_MSHYPHENATELIMITZONE: UInt32 = 70941
DISPID_IHTMLCSSSTYLEDECLARATION2_MSHYPHENATELIMITCHARS: UInt32 = 70942
DISPID_IHTMLCSSSTYLEDECLARATION2_MSHYPHENATELIMITLINES: UInt32 = 70943
DISPID_IHTMLCSSSTYLEDECLARATION2_MSHIGHCONTRASTADJUST: UInt32 = 70945
DISPID_IHTMLCSSSTYLEDECLARATION2_ENABLEBACKGROUND: UInt32 = 70946
DISPID_IHTMLCSSSTYLEDECLARATION2_MSFONTFEATURESETTINGS: UInt32 = 70950
DISPID_IHTMLCSSSTYLEDECLARATION2_MSUSERSELECT: UInt32 = 70951
DISPID_IHTMLCSSSTYLEDECLARATION2_MSOVERFLOWSTYLE: UInt32 = 70935
DISPID_IHTMLCSSSTYLEDECLARATION2_MSTRANSFORMSTYLE: UInt32 = 70889
DISPID_IHTMLCSSSTYLEDECLARATION2_MSBACKFACEVISIBILITY: UInt32 = 70890
DISPID_IHTMLCSSSTYLEDECLARATION2_MSPERSPECTIVE: UInt32 = 70885
DISPID_IHTMLCSSSTYLEDECLARATION2_MSPERSPECTIVEORIGIN: UInt32 = 70886
DISPID_IHTMLCSSSTYLEDECLARATION2_MSTRANSITIONPROPERTY: UInt32 = 70866
DISPID_IHTMLCSSSTYLEDECLARATION2_MSTRANSITIONDURATION: UInt32 = 70867
DISPID_IHTMLCSSSTYLEDECLARATION2_MSTRANSITIONTIMINGFUNCTION: UInt32 = 70868
DISPID_IHTMLCSSSTYLEDECLARATION2_MSTRANSITIONDELAY: UInt32 = 70869
DISPID_IHTMLCSSSTYLEDECLARATION2_MSTRANSITION: UInt32 = 70870
DISPID_IHTMLCSSSTYLEDECLARATION2_MSTOUCHACTION: UInt32 = 70952
DISPID_IHTMLCSSSTYLEDECLARATION2_MSSCROLLTRANSLATION: UInt32 = 70954
DISPID_IHTMLCSSSTYLEDECLARATION2_MSFLEX: UInt32 = 70955
DISPID_IHTMLCSSSTYLEDECLARATION2_MSFLEXPOSITIVE: UInt32 = 70956
DISPID_IHTMLCSSSTYLEDECLARATION2_MSFLEXNEGATIVE: UInt32 = 70957
DISPID_IHTMLCSSSTYLEDECLARATION2_MSFLEXPREFERREDSIZE: UInt32 = 70958
DISPID_IHTMLCSSSTYLEDECLARATION2_MSFLEXFLOW: UInt32 = 70959
DISPID_IHTMLCSSSTYLEDECLARATION2_MSFLEXDIRECTION: UInt32 = 70960
DISPID_IHTMLCSSSTYLEDECLARATION2_MSFLEXWRAP: UInt32 = 70961
DISPID_IHTMLCSSSTYLEDECLARATION2_MSFLEXALIGN: UInt32 = 70962
DISPID_IHTMLCSSSTYLEDECLARATION2_MSFLEXITEMALIGN: UInt32 = 70963
DISPID_IHTMLCSSSTYLEDECLARATION2_MSFLEXPACK: UInt32 = 70964
DISPID_IHTMLCSSSTYLEDECLARATION2_MSFLEXLINEPACK: UInt32 = 70965
DISPID_IHTMLCSSSTYLEDECLARATION2_MSFLEXORDER: UInt32 = 70966
DISPID_IHTMLCSSSTYLEDECLARATION2_MSTOUCHSELECT: UInt32 = 70994
DISPID_IHTMLCSSSTYLEDECLARATION2_TRANSFORM: UInt32 = 70967
DISPID_IHTMLCSSSTYLEDECLARATION2_TRANSFORMORIGIN: UInt32 = 70968
DISPID_IHTMLCSSSTYLEDECLARATION2_TRANSFORMSTYLE: UInt32 = 70976
DISPID_IHTMLCSSSTYLEDECLARATION2_BACKFACEVISIBILITY: UInt32 = 70977
DISPID_IHTMLCSSSTYLEDECLARATION2_PERSPECTIVE: UInt32 = 70974
DISPID_IHTMLCSSSTYLEDECLARATION2_PERSPECTIVEORIGIN: UInt32 = 70975
DISPID_IHTMLCSSSTYLEDECLARATION2_TRANSITIONPROPERTY: UInt32 = 70969
DISPID_IHTMLCSSSTYLEDECLARATION2_TRANSITIONDURATION: UInt32 = 70970
DISPID_IHTMLCSSSTYLEDECLARATION2_TRANSITIONTIMINGFUNCTION: UInt32 = 70971
DISPID_IHTMLCSSSTYLEDECLARATION2_TRANSITIONDELAY: UInt32 = 70972
DISPID_IHTMLCSSSTYLEDECLARATION2_TRANSITION: UInt32 = 70973
DISPID_IHTMLCSSSTYLEDECLARATION2_FONTFEATURESETTINGS: UInt32 = 70987
DISPID_IHTMLCSSSTYLEDECLARATION2_ANIMATIONNAME: UInt32 = 70978
DISPID_IHTMLCSSSTYLEDECLARATION2_ANIMATIONDURATION: UInt32 = 70979
DISPID_IHTMLCSSSTYLEDECLARATION2_ANIMATIONTIMINGFUNCTION: UInt32 = 70980
DISPID_IHTMLCSSSTYLEDECLARATION2_ANIMATIONDELAY: UInt32 = 70981
DISPID_IHTMLCSSSTYLEDECLARATION2_ANIMATIONDIRECTION: UInt32 = 70982
DISPID_IHTMLCSSSTYLEDECLARATION2_ANIMATIONPLAYSTATE: UInt32 = 70983
DISPID_IHTMLCSSSTYLEDECLARATION2_ANIMATIONITERATIONCOUNT: UInt32 = 70984
DISPID_IHTMLCSSSTYLEDECLARATION2_ANIMATION: UInt32 = 70985
DISPID_IHTMLCSSSTYLEDECLARATION2_ANIMATIONFILLMODE: UInt32 = 70986
DISPID_IHTMLCSSSTYLEDECLARATION3_FLEX: UInt32 = 71002
DISPID_IHTMLCSSSTYLEDECLARATION3_FLEXDIRECTION: UInt32 = 70998
DISPID_IHTMLCSSSTYLEDECLARATION3_FLEXWRAP: UInt32 = 70999
DISPID_IHTMLCSSSTYLEDECLARATION3_FLEXFLOW: UInt32 = 71000
DISPID_IHTMLCSSSTYLEDECLARATION3_FLEXGROW: UInt32 = 71003
DISPID_IHTMLCSSSTYLEDECLARATION3_FLEXSHRINK: UInt32 = 71004
DISPID_IHTMLCSSSTYLEDECLARATION3_FLEXBASIS: UInt32 = 71005
DISPID_IHTMLCSSSTYLEDECLARATION3_JUSTIFYCONTENT: UInt32 = 71006
DISPID_IHTMLCSSSTYLEDECLARATION3_ALIGNITEMS: UInt32 = 71007
DISPID_IHTMLCSSSTYLEDECLARATION3_ALIGNSELF: UInt32 = 71008
DISPID_IHTMLCSSSTYLEDECLARATION3_ALIGNCONTENT: UInt32 = 71009
DISPID_IHTMLCSSSTYLEDECLARATION3_BORDERIMAGE: UInt32 = 71010
DISPID_IHTMLCSSSTYLEDECLARATION3_BORDERIMAGESOURCE: UInt32 = 71011
DISPID_IHTMLCSSSTYLEDECLARATION3_BORDERIMAGESLICE: UInt32 = 71012
DISPID_IHTMLCSSSTYLEDECLARATION3_BORDERIMAGEWIDTH: UInt32 = 71013
DISPID_IHTMLCSSSTYLEDECLARATION3_BORDERIMAGEOUTSET: UInt32 = 71014
DISPID_IHTMLCSSSTYLEDECLARATION3_BORDERIMAGEREPEAT: UInt32 = 71015
DISPID_IHTMLCSSSTYLEDECLARATION3_MSIMEALIGN: UInt32 = 71017
DISPID_IHTMLCSSSTYLEDECLARATION3_MSTEXTCOMBINEHORIZONTAL: UInt32 = 71018
DISPID_IHTMLCSSSTYLEDECLARATION3_TOUCHACTION: UInt32 = 71019
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITAPPEARANCE: UInt32 = 71020
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITUSERSELECT: UInt32 = 71032
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBOXALIGN: UInt32 = 71021
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBOXORDINALGROUP: UInt32 = 71022
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBOXPACK: UInt32 = 71023
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBOXFLEX: UInt32 = 71024
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBOXORIENT: UInt32 = 71025
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBOXDIRECTION: UInt32 = 71026
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITTRANSFORM: UInt32 = 71028
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBACKGROUNDSIZE: UInt32 = 71029
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBACKFACEVISIBILITY: UInt32 = 71030
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITANIMATION: UInt32 = 71033
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITTRANSITION: UInt32 = 71034
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITANIMATIONNAME: UInt32 = 71035
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITANIMATIONDURATION: UInt32 = 71036
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITANIMATIONTIMINGFUNCTION: UInt32 = 71037
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITANIMATIONDELAY: UInt32 = 71038
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITANIMATIONITERATIONCOUNT: UInt32 = 71039
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITANIMATIONDIRECTION: UInt32 = 71040
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITANIMATIONPLAYSTATE: UInt32 = 71041
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITTRANSITIONPROPERTY: UInt32 = 71042
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITTRANSITIONDURATION: UInt32 = 71043
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITTRANSITIONTIMINGFUNCTION: UInt32 = 71044
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITTRANSITIONDELAY: UInt32 = 71045
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBACKGROUNDATTACHMENT: UInt32 = 71046
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBACKGROUNDCOLOR: UInt32 = 71047
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBACKGROUNDCLIP: UInt32 = 71048
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBACKGROUNDIMAGE: UInt32 = 71049
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBACKGROUNDREPEAT: UInt32 = 71050
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBACKGROUNDORIGIN: UInt32 = 71051
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBACKGROUNDPOSITION: UInt32 = 71052
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBACKGROUNDPOSITIONX: UInt32 = 71053
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBACKGROUNDPOSITIONY: UInt32 = 71054
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBACKGROUND: UInt32 = 71055
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITTRANSFORMORIGIN: UInt32 = 71056
DISPID_IHTMLCSSSTYLEDECLARATION4_MSTEXTSIZEADJUST: UInt32 = 70864
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITTEXTSIZEADJUST: UInt32 = 71060
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBORDERIMAGE: UInt32 = 71061
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBORDERIMAGESOURCE: UInt32 = 71062
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBORDERIMAGESLICE: UInt32 = 71063
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBORDERIMAGEWIDTH: UInt32 = 71064
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBORDERIMAGEOUTSET: UInt32 = 71065
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBORDERIMAGEREPEAT: UInt32 = 71066
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITBOXSIZING: UInt32 = 71031
DISPID_IHTMLCSSSTYLEDECLARATION4_WEBKITANIMATIONFILLMODE: UInt32 = 71027
DISPID_IHTMLSTYLEENABLED_MSGETPROPERTYENABLED: UInt32 = 70043
DISPID_IHTMLSTYLEENABLED_MSPUTPROPERTYENABLED: UInt32 = 70044
DISPID_IHTMLSTYLE_FONTFAMILY: UInt32 = 70554
DISPID_IHTMLSTYLE_FONTSTYLE: UInt32 = 70560
DISPID_IHTMLSTYLE_FONTVARIANT: UInt32 = 70561
DISPID_IHTMLSTYLE_FONTWEIGHT: UInt32 = 70563
DISPID_IHTMLSTYLE_FONTSIZE: UInt32 = 70555
DISPID_IHTMLSTYLE_FONT: UInt32 = 70577
DISPID_IHTMLSTYLE_COLOR: UInt32 = 70538
DISPID_IHTMLSTYLE_BACKGROUND: UInt32 = 70568
DISPID_IHTMLSTYLE_BACKGROUNDCOLOR: Int32 = -501
DISPID_IHTMLSTYLE_BACKGROUNDIMAGE: UInt32 = 70537
DISPID_IHTMLSTYLE_BACKGROUNDREPEAT: UInt32 = 70580
DISPID_IHTMLSTYLE_BACKGROUNDATTACHMENT: UInt32 = 70581
DISPID_IHTMLSTYLE_BACKGROUNDPOSITION: UInt32 = 70582
DISPID_IHTMLSTYLE_BACKGROUNDPOSITIONX: UInt32 = 70569
DISPID_IHTMLSTYLE_BACKGROUNDPOSITIONY: UInt32 = 70570
DISPID_IHTMLSTYLE_WORDSPACING: UInt32 = 70583
DISPID_IHTMLSTYLE_LETTERSPACING: UInt32 = 70544
DISPID_IHTMLSTYLE_TEXTDECORATION: UInt32 = 70571
DISPID_IHTMLSTYLE_TEXTDECORATIONNONE: UInt32 = 70559
DISPID_IHTMLSTYLE_TEXTDECORATIONUNDERLINE: UInt32 = 70557
DISPID_IHTMLSTYLE_TEXTDECORATIONOVERLINE: UInt32 = 70605
DISPID_IHTMLSTYLE_TEXTDECORATIONLINETHROUGH: UInt32 = 70556
DISPID_IHTMLSTYLE_TEXTDECORATIONBLINK: UInt32 = 70558
DISPID_IHTMLSTYLE_VERTICALALIGN: UInt32 = 70584
DISPID_IHTMLSTYLE_TEXTTRANSFORM: UInt32 = 70540
DISPID_IHTMLSTYLE_TEXTALIGN: UInt32 = 65608
DISPID_IHTMLSTYLE_TEXTINDENT: UInt32 = 70543
DISPID_IHTMLSTYLE_LINEHEIGHT: UInt32 = 70542
DISPID_IHTMLSTYLE_MARGINTOP: UInt32 = 70573
DISPID_IHTMLSTYLE_MARGINRIGHT: UInt32 = 70574
DISPID_IHTMLSTYLE_MARGINBOTTOM: UInt32 = 70575
DISPID_IHTMLSTYLE_MARGINLEFT: UInt32 = 70576
DISPID_IHTMLSTYLE_MARGIN: UInt32 = 70572
DISPID_IHTMLSTYLE_PADDINGTOP: UInt32 = 70548
DISPID_IHTMLSTYLE_PADDINGRIGHT: UInt32 = 70549
DISPID_IHTMLSTYLE_PADDINGBOTTOM: UInt32 = 70550
DISPID_IHTMLSTYLE_PADDINGLEFT: UInt32 = 70551
DISPID_IHTMLSTYLE_PADDING: UInt32 = 70547
DISPID_IHTMLSTYLE_BORDER: UInt32 = 70585
DISPID_IHTMLSTYLE_BORDERTOP: UInt32 = 70586
DISPID_IHTMLSTYLE_BORDERRIGHT: UInt32 = 70587
DISPID_IHTMLSTYLE_BORDERBOTTOM: UInt32 = 70588
DISPID_IHTMLSTYLE_BORDERLEFT: UInt32 = 70589
DISPID_IHTMLSTYLE_BORDERCOLOR: UInt32 = 70590
DISPID_IHTMLSTYLE_BORDERTOPCOLOR: UInt32 = 70591
DISPID_IHTMLSTYLE_BORDERRIGHTCOLOR: UInt32 = 70592
DISPID_IHTMLSTYLE_BORDERBOTTOMCOLOR: UInt32 = 70593
DISPID_IHTMLSTYLE_BORDERLEFTCOLOR: UInt32 = 70594
DISPID_IHTMLSTYLE_BORDERWIDTH: UInt32 = 70595
DISPID_IHTMLSTYLE_BORDERTOPWIDTH: UInt32 = 70596
DISPID_IHTMLSTYLE_BORDERRIGHTWIDTH: UInt32 = 70597
DISPID_IHTMLSTYLE_BORDERBOTTOMWIDTH: UInt32 = 70598
DISPID_IHTMLSTYLE_BORDERLEFTWIDTH: UInt32 = 70599
DISPID_IHTMLSTYLE_BORDERSTYLE: UInt32 = 70600
DISPID_IHTMLSTYLE_BORDERTOPSTYLE: UInt32 = 70601
DISPID_IHTMLSTYLE_BORDERRIGHTSTYLE: UInt32 = 70602
DISPID_IHTMLSTYLE_BORDERBOTTOMSTYLE: UInt32 = 70603
DISPID_IHTMLSTYLE_BORDERLEFTSTYLE: UInt32 = 70604
DISPID_IHTMLSTYLE_WIDTH: UInt32 = 65541
DISPID_IHTMLSTYLE_HEIGHT: UInt32 = 65542
DISPID_IHTMLSTYLE_STYLEFLOAT: UInt32 = 70606
DISPID_IHTMLSTYLE_CLEAR: UInt32 = 70552
DISPID_IHTMLSTYLE_DISPLAY: UInt32 = 70607
DISPID_IHTMLSTYLE_VISIBILITY: UInt32 = 70616
DISPID_IHTMLSTYLE_LISTSTYLETYPE: UInt32 = 70608
DISPID_IHTMLSTYLE_LISTSTYLEPOSITION: UInt32 = 70609
DISPID_IHTMLSTYLE_LISTSTYLEIMAGE: UInt32 = 70610
DISPID_IHTMLSTYLE_LISTSTYLE: UInt32 = 70611
DISPID_IHTMLSTYLE_WHITESPACE: UInt32 = 70612
DISPID_IHTMLSTYLE_TOP: UInt32 = 65540
DISPID_IHTMLSTYLE_LEFT: UInt32 = 65539
DISPID_IHTMLSTYLE_POSITION: UInt32 = 70626
DISPID_IHTMLSTYLE_ZINDEX: UInt32 = 70627
DISPID_IHTMLSTYLE_OVERFLOW: UInt32 = 70546
DISPID_IHTMLSTYLE_PAGEBREAKBEFORE: UInt32 = 70613
DISPID_IHTMLSTYLE_PAGEBREAKAFTER: UInt32 = 70614
DISPID_IHTMLSTYLE_CSSTEXT: UInt32 = 70635
DISPID_IHTMLSTYLE_PIXELTOP: UInt32 = 69536
DISPID_IHTMLSTYLE_PIXELLEFT: UInt32 = 69537
DISPID_IHTMLSTYLE_PIXELWIDTH: UInt32 = 69538
DISPID_IHTMLSTYLE_PIXELHEIGHT: UInt32 = 69539
DISPID_IHTMLSTYLE_POSTOP: UInt32 = 69540
DISPID_IHTMLSTYLE_POSLEFT: UInt32 = 69541
DISPID_IHTMLSTYLE_POSWIDTH: UInt32 = 69542
DISPID_IHTMLSTYLE_POSHEIGHT: UInt32 = 69543
DISPID_IHTMLSTYLE_CURSOR: UInt32 = 70638
DISPID_IHTMLSTYLE_CLIP: UInt32 = 70628
DISPID_IHTMLSTYLE_FILTER: UInt32 = 70618
DISPID_IHTMLSTYLE_SETATTRIBUTE: UInt32 = 66037
DISPID_IHTMLSTYLE_GETATTRIBUTE: UInt32 = 66038
DISPID_IHTMLSTYLE_REMOVEATTRIBUTE: UInt32 = 66039
DISPID_IHTMLSTYLE_TOSTRING: UInt32 = 69544
DISPID_IHTMLSTYLE2_TABLELAYOUT: UInt32 = 70634
DISPID_IHTMLSTYLE2_BORDERCOLLAPSE: UInt32 = 70620
DISPID_IHTMLSTYLE2_DIRECTION: UInt32 = 70655
DISPID_IHTMLSTYLE2_BEHAVIOR: UInt32 = 70651
DISPID_IHTMLSTYLE2_SETEXPRESSION: UInt32 = 66040
DISPID_IHTMLSTYLE2_GETEXPRESSION: UInt32 = 66041
DISPID_IHTMLSTYLE2_REMOVEEXPRESSION: UInt32 = 66042
DISPID_IHTMLSTYLE2_POSITION: UInt32 = 70626
DISPID_IHTMLSTYLE2_UNICODEBIDI: UInt32 = 70654
DISPID_IHTMLSTYLE2_BOTTOM: UInt32 = 65614
DISPID_IHTMLSTYLE2_RIGHT: UInt32 = 65613
DISPID_IHTMLSTYLE2_PIXELBOTTOM: UInt32 = 69545
DISPID_IHTMLSTYLE2_PIXELRIGHT: UInt32 = 69546
DISPID_IHTMLSTYLE2_POSBOTTOM: UInt32 = 69547
DISPID_IHTMLSTYLE2_POSRIGHT: UInt32 = 69548
DISPID_IHTMLSTYLE2_IMEMODE: UInt32 = 70656
DISPID_IHTMLSTYLE2_RUBYALIGN: UInt32 = 70657
DISPID_IHTMLSTYLE2_RUBYPOSITION: UInt32 = 70658
DISPID_IHTMLSTYLE2_RUBYOVERHANG: UInt32 = 70659
DISPID_IHTMLSTYLE2_LAYOUTGRIDCHAR: UInt32 = 70663
DISPID_IHTMLSTYLE2_LAYOUTGRIDLINE: UInt32 = 70664
DISPID_IHTMLSTYLE2_LAYOUTGRIDMODE: UInt32 = 70665
DISPID_IHTMLSTYLE2_LAYOUTGRIDTYPE: UInt32 = 70666
DISPID_IHTMLSTYLE2_LAYOUTGRID: UInt32 = 70667
DISPID_IHTMLSTYLE2_WORDBREAK: UInt32 = 70670
DISPID_IHTMLSTYLE2_LINEBREAK: UInt32 = 70669
DISPID_IHTMLSTYLE2_TEXTJUSTIFY: UInt32 = 70671
DISPID_IHTMLSTYLE2_TEXTJUSTIFYTRIM: UInt32 = 70672
DISPID_IHTMLSTYLE2_TEXTKASHIDA: UInt32 = 70673
DISPID_IHTMLSTYLE2_TEXTAUTOSPACE: UInt32 = 70668
DISPID_IHTMLSTYLE2_OVERFLOWX: UInt32 = 70675
DISPID_IHTMLSTYLE2_OVERFLOWY: UInt32 = 70676
DISPID_IHTMLSTYLE2_ACCELERATOR: UInt32 = 70683
DISPID_IHTMLSTYLE3_LAYOUTFLOW: UInt32 = 70691
DISPID_IHTMLSTYLE3_ZOOM: UInt32 = 70689
DISPID_IHTMLSTYLE3_WORDWRAP: UInt32 = 70694
DISPID_IHTMLSTYLE3_TEXTUNDERLINEPOSITION: UInt32 = 70695
DISPID_IHTMLSTYLE3_SCROLLBARBASECOLOR: UInt32 = 70716
DISPID_IHTMLSTYLE3_SCROLLBARFACECOLOR: UInt32 = 70717
DISPID_IHTMLSTYLE3_SCROLLBAR3DLIGHTCOLOR: UInt32 = 70718
DISPID_IHTMLSTYLE3_SCROLLBARSHADOWCOLOR: UInt32 = 70719
DISPID_IHTMLSTYLE3_SCROLLBARHIGHLIGHTCOLOR: UInt32 = 70720
DISPID_IHTMLSTYLE3_SCROLLBARDARKSHADOWCOLOR: UInt32 = 70721
DISPID_IHTMLSTYLE3_SCROLLBARARROWCOLOR: UInt32 = 70722
DISPID_IHTMLSTYLE3_SCROLLBARTRACKCOLOR: UInt32 = 70732
DISPID_IHTMLSTYLE3_WRITINGMODE: UInt32 = 70728
DISPID_IHTMLSTYLE3_TEXTALIGNLAST: UInt32 = 70739
DISPID_IHTMLSTYLE3_TEXTKASHIDASPACE: UInt32 = 70740
DISPID_IHTMLSTYLE4_TEXTOVERFLOW: UInt32 = 70745
DISPID_IHTMLSTYLE4_MINHEIGHT: UInt32 = 70747
DISPID_IHTMLSTYLE5_MSINTERPOLATIONMODE: UInt32 = 70749
DISPID_IHTMLSTYLE5_MAXHEIGHT: UInt32 = 70750
DISPID_IHTMLSTYLE5_MINWIDTH: UInt32 = 70751
DISPID_IHTMLSTYLE5_MAXWIDTH: UInt32 = 70752
DISPID_IHTMLSTYLE6_CONTENT: UInt32 = 70754
DISPID_IHTMLSTYLE6_CAPTIONSIDE: UInt32 = 70755
DISPID_IHTMLSTYLE6_COUNTERINCREMENT: UInt32 = 70756
DISPID_IHTMLSTYLE6_COUNTERRESET: UInt32 = 70757
DISPID_IHTMLSTYLE6_OUTLINE: UInt32 = 70758
DISPID_IHTMLSTYLE6_OUTLINEWIDTH: UInt32 = 70759
DISPID_IHTMLSTYLE6_OUTLINESTYLE: UInt32 = 70760
DISPID_IHTMLSTYLE6_OUTLINECOLOR: UInt32 = 70761
DISPID_IHTMLSTYLE6_BOXSIZING: UInt32 = 70762
DISPID_IHTMLSTYLE6_BORDERSPACING: UInt32 = 70763
DISPID_IHTMLSTYLE6_ORPHANS: UInt32 = 70764
DISPID_IHTMLSTYLE6_WIDOWS: UInt32 = 70765
DISPID_IHTMLSTYLE6_PAGEBREAKINSIDE: UInt32 = 70766
DISPID_IHTMLSTYLE6_EMPTYCELLS: UInt32 = 70786
DISPID_IHTMLSTYLE6_MSBLOCKPROGRESSION: UInt32 = 70787
DISPID_IHTMLSTYLE6_QUOTES: UInt32 = 70788
DISPID_IHTMLRULESTYLE_FONTFAMILY: UInt32 = 70554
DISPID_IHTMLRULESTYLE_FONTSTYLE: UInt32 = 70560
DISPID_IHTMLRULESTYLE_FONTVARIANT: UInt32 = 70561
DISPID_IHTMLRULESTYLE_FONTWEIGHT: UInt32 = 70563
DISPID_IHTMLRULESTYLE_FONTSIZE: UInt32 = 70555
DISPID_IHTMLRULESTYLE_FONT: UInt32 = 70577
DISPID_IHTMLRULESTYLE_COLOR: UInt32 = 70538
DISPID_IHTMLRULESTYLE_BACKGROUND: UInt32 = 70568
DISPID_IHTMLRULESTYLE_BACKGROUNDCOLOR: Int32 = -501
DISPID_IHTMLRULESTYLE_BACKGROUNDIMAGE: UInt32 = 70537
DISPID_IHTMLRULESTYLE_BACKGROUNDREPEAT: UInt32 = 70580
DISPID_IHTMLRULESTYLE_BACKGROUNDATTACHMENT: UInt32 = 70581
DISPID_IHTMLRULESTYLE_BACKGROUNDPOSITION: UInt32 = 70582
DISPID_IHTMLRULESTYLE_BACKGROUNDPOSITIONX: UInt32 = 70569
DISPID_IHTMLRULESTYLE_BACKGROUNDPOSITIONY: UInt32 = 70570
DISPID_IHTMLRULESTYLE_WORDSPACING: UInt32 = 70583
DISPID_IHTMLRULESTYLE_LETTERSPACING: UInt32 = 70544
DISPID_IHTMLRULESTYLE_TEXTDECORATION: UInt32 = 70571
DISPID_IHTMLRULESTYLE_TEXTDECORATIONNONE: UInt32 = 70559
DISPID_IHTMLRULESTYLE_TEXTDECORATIONUNDERLINE: UInt32 = 70557
DISPID_IHTMLRULESTYLE_TEXTDECORATIONOVERLINE: UInt32 = 70605
DISPID_IHTMLRULESTYLE_TEXTDECORATIONLINETHROUGH: UInt32 = 70556
DISPID_IHTMLRULESTYLE_TEXTDECORATIONBLINK: UInt32 = 70558
DISPID_IHTMLRULESTYLE_VERTICALALIGN: UInt32 = 70584
DISPID_IHTMLRULESTYLE_TEXTTRANSFORM: UInt32 = 70540
DISPID_IHTMLRULESTYLE_TEXTALIGN: UInt32 = 65608
DISPID_IHTMLRULESTYLE_TEXTINDENT: UInt32 = 70543
DISPID_IHTMLRULESTYLE_LINEHEIGHT: UInt32 = 70542
DISPID_IHTMLRULESTYLE_MARGINTOP: UInt32 = 70573
DISPID_IHTMLRULESTYLE_MARGINRIGHT: UInt32 = 70574
DISPID_IHTMLRULESTYLE_MARGINBOTTOM: UInt32 = 70575
DISPID_IHTMLRULESTYLE_MARGINLEFT: UInt32 = 70576
DISPID_IHTMLRULESTYLE_MARGIN: UInt32 = 70572
DISPID_IHTMLRULESTYLE_PADDINGTOP: UInt32 = 70548
DISPID_IHTMLRULESTYLE_PADDINGRIGHT: UInt32 = 70549
DISPID_IHTMLRULESTYLE_PADDINGBOTTOM: UInt32 = 70550
DISPID_IHTMLRULESTYLE_PADDINGLEFT: UInt32 = 70551
DISPID_IHTMLRULESTYLE_PADDING: UInt32 = 70547
DISPID_IHTMLRULESTYLE_BORDER: UInt32 = 70585
DISPID_IHTMLRULESTYLE_BORDERTOP: UInt32 = 70586
DISPID_IHTMLRULESTYLE_BORDERRIGHT: UInt32 = 70587
DISPID_IHTMLRULESTYLE_BORDERBOTTOM: UInt32 = 70588
DISPID_IHTMLRULESTYLE_BORDERLEFT: UInt32 = 70589
DISPID_IHTMLRULESTYLE_BORDERCOLOR: UInt32 = 70590
DISPID_IHTMLRULESTYLE_BORDERTOPCOLOR: UInt32 = 70591
DISPID_IHTMLRULESTYLE_BORDERRIGHTCOLOR: UInt32 = 70592
DISPID_IHTMLRULESTYLE_BORDERBOTTOMCOLOR: UInt32 = 70593
DISPID_IHTMLRULESTYLE_BORDERLEFTCOLOR: UInt32 = 70594
DISPID_IHTMLRULESTYLE_BORDERWIDTH: UInt32 = 70595
DISPID_IHTMLRULESTYLE_BORDERTOPWIDTH: UInt32 = 70596
DISPID_IHTMLRULESTYLE_BORDERRIGHTWIDTH: UInt32 = 70597
DISPID_IHTMLRULESTYLE_BORDERBOTTOMWIDTH: UInt32 = 70598
DISPID_IHTMLRULESTYLE_BORDERLEFTWIDTH: UInt32 = 70599
DISPID_IHTMLRULESTYLE_BORDERSTYLE: UInt32 = 70600
DISPID_IHTMLRULESTYLE_BORDERTOPSTYLE: UInt32 = 70601
DISPID_IHTMLRULESTYLE_BORDERRIGHTSTYLE: UInt32 = 70602
DISPID_IHTMLRULESTYLE_BORDERBOTTOMSTYLE: UInt32 = 70603
DISPID_IHTMLRULESTYLE_BORDERLEFTSTYLE: UInt32 = 70604
DISPID_IHTMLRULESTYLE_WIDTH: UInt32 = 65541
DISPID_IHTMLRULESTYLE_HEIGHT: UInt32 = 65542
DISPID_IHTMLRULESTYLE_STYLEFLOAT: UInt32 = 70606
DISPID_IHTMLRULESTYLE_CLEAR: UInt32 = 70552
DISPID_IHTMLRULESTYLE_DISPLAY: UInt32 = 70607
DISPID_IHTMLRULESTYLE_VISIBILITY: UInt32 = 70616
DISPID_IHTMLRULESTYLE_LISTSTYLETYPE: UInt32 = 70608
DISPID_IHTMLRULESTYLE_LISTSTYLEPOSITION: UInt32 = 70609
DISPID_IHTMLRULESTYLE_LISTSTYLEIMAGE: UInt32 = 70610
DISPID_IHTMLRULESTYLE_LISTSTYLE: UInt32 = 70611
DISPID_IHTMLRULESTYLE_WHITESPACE: UInt32 = 70612
DISPID_IHTMLRULESTYLE_TOP: UInt32 = 65540
DISPID_IHTMLRULESTYLE_LEFT: UInt32 = 65539
DISPID_IHTMLRULESTYLE_POSITION: UInt32 = 70626
DISPID_IHTMLRULESTYLE_ZINDEX: UInt32 = 70627
DISPID_IHTMLRULESTYLE_OVERFLOW: UInt32 = 70546
DISPID_IHTMLRULESTYLE_PAGEBREAKBEFORE: UInt32 = 70613
DISPID_IHTMLRULESTYLE_PAGEBREAKAFTER: UInt32 = 70614
DISPID_IHTMLRULESTYLE_CSSTEXT: UInt32 = 70635
DISPID_IHTMLRULESTYLE_CURSOR: UInt32 = 70638
DISPID_IHTMLRULESTYLE_CLIP: UInt32 = 70628
DISPID_IHTMLRULESTYLE_FILTER: UInt32 = 70618
DISPID_IHTMLRULESTYLE_SETATTRIBUTE: UInt32 = 66037
DISPID_IHTMLRULESTYLE_GETATTRIBUTE: UInt32 = 66038
DISPID_IHTMLRULESTYLE_REMOVEATTRIBUTE: UInt32 = 66039
DISPID_IHTMLRULESTYLE2_TABLELAYOUT: UInt32 = 70634
DISPID_IHTMLRULESTYLE2_BORDERCOLLAPSE: UInt32 = 70620
DISPID_IHTMLRULESTYLE2_DIRECTION: UInt32 = 70655
DISPID_IHTMLRULESTYLE2_BEHAVIOR: UInt32 = 70651
DISPID_IHTMLRULESTYLE2_POSITION: UInt32 = 70626
DISPID_IHTMLRULESTYLE2_UNICODEBIDI: UInt32 = 70654
DISPID_IHTMLRULESTYLE2_BOTTOM: UInt32 = 65614
DISPID_IHTMLRULESTYLE2_RIGHT: UInt32 = 65613
DISPID_IHTMLRULESTYLE2_PIXELBOTTOM: UInt32 = 69545
DISPID_IHTMLRULESTYLE2_PIXELRIGHT: UInt32 = 69546
DISPID_IHTMLRULESTYLE2_POSBOTTOM: UInt32 = 69547
DISPID_IHTMLRULESTYLE2_POSRIGHT: UInt32 = 69548
DISPID_IHTMLRULESTYLE2_IMEMODE: UInt32 = 70656
DISPID_IHTMLRULESTYLE2_RUBYALIGN: UInt32 = 70657
DISPID_IHTMLRULESTYLE2_RUBYPOSITION: UInt32 = 70658
DISPID_IHTMLRULESTYLE2_RUBYOVERHANG: UInt32 = 70659
DISPID_IHTMLRULESTYLE2_LAYOUTGRIDCHAR: UInt32 = 70663
DISPID_IHTMLRULESTYLE2_LAYOUTGRIDLINE: UInt32 = 70664
DISPID_IHTMLRULESTYLE2_LAYOUTGRIDMODE: UInt32 = 70665
DISPID_IHTMLRULESTYLE2_LAYOUTGRIDTYPE: UInt32 = 70666
DISPID_IHTMLRULESTYLE2_LAYOUTGRID: UInt32 = 70667
DISPID_IHTMLRULESTYLE2_TEXTAUTOSPACE: UInt32 = 70668
DISPID_IHTMLRULESTYLE2_WORDBREAK: UInt32 = 70670
DISPID_IHTMLRULESTYLE2_LINEBREAK: UInt32 = 70669
DISPID_IHTMLRULESTYLE2_TEXTJUSTIFY: UInt32 = 70671
DISPID_IHTMLRULESTYLE2_TEXTJUSTIFYTRIM: UInt32 = 70672
DISPID_IHTMLRULESTYLE2_TEXTKASHIDA: UInt32 = 70673
DISPID_IHTMLRULESTYLE2_OVERFLOWX: UInt32 = 70675
DISPID_IHTMLRULESTYLE2_OVERFLOWY: UInt32 = 70676
DISPID_IHTMLRULESTYLE2_ACCELERATOR: UInt32 = 70683
DISPID_IHTMLRULESTYLE3_LAYOUTFLOW: UInt32 = 70691
DISPID_IHTMLRULESTYLE3_ZOOM: UInt32 = 70689
DISPID_IHTMLRULESTYLE3_WORDWRAP: UInt32 = 70694
DISPID_IHTMLRULESTYLE3_TEXTUNDERLINEPOSITION: UInt32 = 70695
DISPID_IHTMLRULESTYLE3_SCROLLBARBASECOLOR: UInt32 = 70716
DISPID_IHTMLRULESTYLE3_SCROLLBARFACECOLOR: UInt32 = 70717
DISPID_IHTMLRULESTYLE3_SCROLLBAR3DLIGHTCOLOR: UInt32 = 70718
DISPID_IHTMLRULESTYLE3_SCROLLBARSHADOWCOLOR: UInt32 = 70719
DISPID_IHTMLRULESTYLE3_SCROLLBARHIGHLIGHTCOLOR: UInt32 = 70720
DISPID_IHTMLRULESTYLE3_SCROLLBARDARKSHADOWCOLOR: UInt32 = 70721
DISPID_IHTMLRULESTYLE3_SCROLLBARARROWCOLOR: UInt32 = 70722
DISPID_IHTMLRULESTYLE3_SCROLLBARTRACKCOLOR: UInt32 = 70732
DISPID_IHTMLRULESTYLE3_WRITINGMODE: UInt32 = 70728
DISPID_IHTMLRULESTYLE3_TEXTALIGNLAST: UInt32 = 70739
DISPID_IHTMLRULESTYLE3_TEXTKASHIDASPACE: UInt32 = 70740
DISPID_IHTMLRULESTYLE4_TEXTOVERFLOW: UInt32 = 70745
DISPID_IHTMLRULESTYLE4_MINHEIGHT: UInt32 = 70747
DISPID_IHTMLRULESTYLE5_MSINTERPOLATIONMODE: UInt32 = 70749
DISPID_IHTMLRULESTYLE5_MAXHEIGHT: UInt32 = 70750
DISPID_IHTMLRULESTYLE5_MINWIDTH: UInt32 = 70751
DISPID_IHTMLRULESTYLE5_MAXWIDTH: UInt32 = 70752
DISPID_IHTMLRULESTYLE6_CONTENT: UInt32 = 70754
DISPID_IHTMLRULESTYLE6_CAPTIONSIDE: UInt32 = 70755
DISPID_IHTMLRULESTYLE6_COUNTERINCREMENT: UInt32 = 70756
DISPID_IHTMLRULESTYLE6_COUNTERRESET: UInt32 = 70757
DISPID_IHTMLRULESTYLE6_OUTLINE: UInt32 = 70758
DISPID_IHTMLRULESTYLE6_OUTLINEWIDTH: UInt32 = 70759
DISPID_IHTMLRULESTYLE6_OUTLINESTYLE: UInt32 = 70760
DISPID_IHTMLRULESTYLE6_OUTLINECOLOR: UInt32 = 70761
DISPID_IHTMLRULESTYLE6_BOXSIZING: UInt32 = 70762
DISPID_IHTMLRULESTYLE6_BORDERSPACING: UInt32 = 70763
DISPID_IHTMLRULESTYLE6_ORPHANS: UInt32 = 70764
DISPID_IHTMLRULESTYLE6_WIDOWS: UInt32 = 70765
DISPID_IHTMLRULESTYLE6_PAGEBREAKINSIDE: UInt32 = 70766
DISPID_IHTMLRULESTYLE6_EMPTYCELLS: UInt32 = 70786
DISPID_IHTMLRULESTYLE6_MSBLOCKPROGRESSION: UInt32 = 70787
DISPID_IHTMLRULESTYLE6_QUOTES: UInt32 = 70788
DISPID_IHTMLCSSRULE_TYPE: UInt32 = 1101
DISPID_IHTMLCSSRULE_CSSTEXT: UInt32 = 1102
DISPID_IHTMLCSSRULE_PARENTRULE: UInt32 = 1103
DISPID_IHTMLCSSRULE_PARENTSTYLESHEET: UInt32 = 1104
DISPID_IHTMLCSSIMPORTRULE_HREF: UInt32 = 1001
DISPID_IHTMLCSSIMPORTRULE_MEDIA: UInt32 = 1002
DISPID_IHTMLCSSIMPORTRULE_STYLESHEET: UInt32 = 1003
DISPID_IHTMLCSSMEDIARULE_MEDIA: UInt32 = 1001
DISPID_IHTMLCSSMEDIARULE_CSSRULES: UInt32 = 1002
DISPID_IHTMLCSSMEDIARULE_INSERTRULE: UInt32 = 1003
DISPID_IHTMLCSSMEDIARULE_DELETERULE: UInt32 = 1004
DISPID_IHTMLCSSMEDIALIST_MEDIATEXT: UInt32 = 1001
DISPID_IHTMLCSSMEDIALIST_LENGTH: UInt32 = 1002
DISPID_IHTMLCSSMEDIALIST_ITEM: UInt32 = 1003
DISPID_IHTMLCSSMEDIALIST_APPENDMEDIUM: UInt32 = 1004
DISPID_IHTMLCSSMEDIALIST_DELETEMEDIUM: UInt32 = 1005
DISPID_IHTMLCSSNAMESPACERULE_NAMESPACEURI: UInt32 = 1001
DISPID_IHTMLCSSNAMESPACERULE_PREFIX: UInt32 = 1002
DISPID_IHTMLMSCSSKEYFRAMERULE_KEYTEXT: UInt32 = 1001
DISPID_IHTMLMSCSSKEYFRAMERULE_STYLE: UInt32 = 1002
DISPID_IHTMLMSCSSKEYFRAMESRULE_NAME: UInt32 = 1001
DISPID_IHTMLMSCSSKEYFRAMESRULE_CSSRULES: UInt32 = 1002
DISPID_IHTMLMSCSSKEYFRAMESRULE_APPENDRULE: UInt32 = 1003
DISPID_IHTMLMSCSSKEYFRAMESRULE_DELETERULE: UInt32 = 1004
DISPID_IHTMLMSCSSKEYFRAMESRULE_FINDRULE: UInt32 = 1005
DISPID_IHTMLRENDERSTYLE_TEXTLINETHROUGHSTYLE: UInt32 = 70702
DISPID_IHTMLRENDERSTYLE_TEXTUNDERLINESTYLE: UInt32 = 70703
DISPID_IHTMLRENDERSTYLE_TEXTEFFECT: UInt32 = 70704
DISPID_IHTMLRENDERSTYLE_TEXTCOLOR: UInt32 = 70726
DISPID_IHTMLRENDERSTYLE_TEXTBACKGROUNDCOLOR: UInt32 = 70705
DISPID_IHTMLRENDERSTYLE_TEXTDECORATIONCOLOR: UInt32 = 70725
DISPID_IHTMLRENDERSTYLE_RENDERINGPRIORITY: UInt32 = 70706
DISPID_IHTMLRENDERSTYLE_DEFAULTTEXTSELECTION: UInt32 = 70724
DISPID_IHTMLRENDERSTYLE_TEXTDECORATION: UInt32 = 70727
DISPID_IHTMLCURRENTSTYLE_POSITION: UInt32 = 70626
DISPID_IHTMLCURRENTSTYLE_STYLEFLOAT: UInt32 = 70606
DISPID_IHTMLCURRENTSTYLE_COLOR: UInt32 = 70538
DISPID_IHTMLCURRENTSTYLE_BACKGROUNDCOLOR: Int32 = -501
DISPID_IHTMLCURRENTSTYLE_FONTFAMILY: UInt32 = 70554
DISPID_IHTMLCURRENTSTYLE_FONTSTYLE: UInt32 = 70560
DISPID_IHTMLCURRENTSTYLE_FONTVARIANT: UInt32 = 70561
DISPID_IHTMLCURRENTSTYLE_FONTWEIGHT: UInt32 = 70563
DISPID_IHTMLCURRENTSTYLE_FONTSIZE: UInt32 = 70555
DISPID_IHTMLCURRENTSTYLE_BACKGROUNDIMAGE: UInt32 = 70537
DISPID_IHTMLCURRENTSTYLE_BACKGROUNDPOSITIONX: UInt32 = 70569
DISPID_IHTMLCURRENTSTYLE_BACKGROUNDPOSITIONY: UInt32 = 70570
DISPID_IHTMLCURRENTSTYLE_BACKGROUNDREPEAT: UInt32 = 70580
DISPID_IHTMLCURRENTSTYLE_BORDERLEFTCOLOR: UInt32 = 70594
DISPID_IHTMLCURRENTSTYLE_BORDERTOPCOLOR: UInt32 = 70591
DISPID_IHTMLCURRENTSTYLE_BORDERRIGHTCOLOR: UInt32 = 70592
DISPID_IHTMLCURRENTSTYLE_BORDERBOTTOMCOLOR: UInt32 = 70593
DISPID_IHTMLCURRENTSTYLE_BORDERTOPSTYLE: UInt32 = 70601
DISPID_IHTMLCURRENTSTYLE_BORDERRIGHTSTYLE: UInt32 = 70602
DISPID_IHTMLCURRENTSTYLE_BORDERBOTTOMSTYLE: UInt32 = 70603
DISPID_IHTMLCURRENTSTYLE_BORDERLEFTSTYLE: UInt32 = 70604
DISPID_IHTMLCURRENTSTYLE_BORDERTOPWIDTH: UInt32 = 70596
DISPID_IHTMLCURRENTSTYLE_BORDERRIGHTWIDTH: UInt32 = 70597
DISPID_IHTMLCURRENTSTYLE_BORDERBOTTOMWIDTH: UInt32 = 70598
DISPID_IHTMLCURRENTSTYLE_BORDERLEFTWIDTH: UInt32 = 70599
DISPID_IHTMLCURRENTSTYLE_LEFT: UInt32 = 65539
DISPID_IHTMLCURRENTSTYLE_TOP: UInt32 = 65540
DISPID_IHTMLCURRENTSTYLE_WIDTH: UInt32 = 65541
DISPID_IHTMLCURRENTSTYLE_HEIGHT: UInt32 = 65542
DISPID_IHTMLCURRENTSTYLE_PADDINGLEFT: UInt32 = 70551
DISPID_IHTMLCURRENTSTYLE_PADDINGTOP: UInt32 = 70548
DISPID_IHTMLCURRENTSTYLE_PADDINGRIGHT: UInt32 = 70549
DISPID_IHTMLCURRENTSTYLE_PADDINGBOTTOM: UInt32 = 70550
DISPID_IHTMLCURRENTSTYLE_TEXTALIGN: UInt32 = 65608
DISPID_IHTMLCURRENTSTYLE_TEXTDECORATION: UInt32 = 70571
DISPID_IHTMLCURRENTSTYLE_DISPLAY: UInt32 = 70607
DISPID_IHTMLCURRENTSTYLE_VISIBILITY: UInt32 = 70616
DISPID_IHTMLCURRENTSTYLE_ZINDEX: UInt32 = 70627
DISPID_IHTMLCURRENTSTYLE_LETTERSPACING: UInt32 = 70544
DISPID_IHTMLCURRENTSTYLE_LINEHEIGHT: UInt32 = 70542
DISPID_IHTMLCURRENTSTYLE_TEXTINDENT: UInt32 = 70543
DISPID_IHTMLCURRENTSTYLE_VERTICALALIGN: UInt32 = 70584
DISPID_IHTMLCURRENTSTYLE_BACKGROUNDATTACHMENT: UInt32 = 70581
DISPID_IHTMLCURRENTSTYLE_MARGINTOP: UInt32 = 70573
DISPID_IHTMLCURRENTSTYLE_MARGINRIGHT: UInt32 = 70574
DISPID_IHTMLCURRENTSTYLE_MARGINBOTTOM: UInt32 = 70575
DISPID_IHTMLCURRENTSTYLE_MARGINLEFT: UInt32 = 70576
DISPID_IHTMLCURRENTSTYLE_CLEAR: UInt32 = 70552
DISPID_IHTMLCURRENTSTYLE_LISTSTYLETYPE: UInt32 = 70608
DISPID_IHTMLCURRENTSTYLE_LISTSTYLEPOSITION: UInt32 = 70609
DISPID_IHTMLCURRENTSTYLE_LISTSTYLEIMAGE: UInt32 = 70610
DISPID_IHTMLCURRENTSTYLE_CLIPTOP: UInt32 = 70629
DISPID_IHTMLCURRENTSTYLE_CLIPRIGHT: UInt32 = 70630
DISPID_IHTMLCURRENTSTYLE_CLIPBOTTOM: UInt32 = 70631
DISPID_IHTMLCURRENTSTYLE_CLIPLEFT: UInt32 = 70632
DISPID_IHTMLCURRENTSTYLE_OVERFLOW: UInt32 = 70546
DISPID_IHTMLCURRENTSTYLE_PAGEBREAKBEFORE: UInt32 = 70613
DISPID_IHTMLCURRENTSTYLE_PAGEBREAKAFTER: UInt32 = 70614
DISPID_IHTMLCURRENTSTYLE_CURSOR: UInt32 = 70638
DISPID_IHTMLCURRENTSTYLE_TABLELAYOUT: UInt32 = 70634
DISPID_IHTMLCURRENTSTYLE_BORDERCOLLAPSE: UInt32 = 70620
DISPID_IHTMLCURRENTSTYLE_DIRECTION: UInt32 = 70655
DISPID_IHTMLCURRENTSTYLE_BEHAVIOR: UInt32 = 70651
DISPID_IHTMLCURRENTSTYLE_GETATTRIBUTE: UInt32 = 66038
DISPID_IHTMLCURRENTSTYLE_UNICODEBIDI: UInt32 = 70654
DISPID_IHTMLCURRENTSTYLE_RIGHT: UInt32 = 65613
DISPID_IHTMLCURRENTSTYLE_BOTTOM: UInt32 = 65614
DISPID_IHTMLCURRENTSTYLE_IMEMODE: UInt32 = 70656
DISPID_IHTMLCURRENTSTYLE_RUBYALIGN: UInt32 = 70657
DISPID_IHTMLCURRENTSTYLE_RUBYPOSITION: UInt32 = 70658
DISPID_IHTMLCURRENTSTYLE_RUBYOVERHANG: UInt32 = 70659
DISPID_IHTMLCURRENTSTYLE_TEXTAUTOSPACE: UInt32 = 70668
DISPID_IHTMLCURRENTSTYLE_LINEBREAK: UInt32 = 70669
DISPID_IHTMLCURRENTSTYLE_WORDBREAK: UInt32 = 70670
DISPID_IHTMLCURRENTSTYLE_TEXTJUSTIFY: UInt32 = 70671
DISPID_IHTMLCURRENTSTYLE_TEXTJUSTIFYTRIM: UInt32 = 70672
DISPID_IHTMLCURRENTSTYLE_TEXTKASHIDA: UInt32 = 70673
DISPID_IHTMLCURRENTSTYLE_BLOCKDIRECTION: UInt32 = 70653
DISPID_IHTMLCURRENTSTYLE_LAYOUTGRIDCHAR: UInt32 = 70663
DISPID_IHTMLCURRENTSTYLE_LAYOUTGRIDLINE: UInt32 = 70664
DISPID_IHTMLCURRENTSTYLE_LAYOUTGRIDMODE: UInt32 = 70665
DISPID_IHTMLCURRENTSTYLE_LAYOUTGRIDTYPE: UInt32 = 70666
DISPID_IHTMLCURRENTSTYLE_BORDERSTYLE: UInt32 = 70600
DISPID_IHTMLCURRENTSTYLE_BORDERCOLOR: UInt32 = 70590
DISPID_IHTMLCURRENTSTYLE_BORDERWIDTH: UInt32 = 70595
DISPID_IHTMLCURRENTSTYLE_PADDING: UInt32 = 70547
DISPID_IHTMLCURRENTSTYLE_MARGIN: UInt32 = 70572
DISPID_IHTMLCURRENTSTYLE_ACCELERATOR: UInt32 = 70683
DISPID_IHTMLCURRENTSTYLE_OVERFLOWX: UInt32 = 70675
DISPID_IHTMLCURRENTSTYLE_OVERFLOWY: UInt32 = 70676
DISPID_IHTMLCURRENTSTYLE_TEXTTRANSFORM: UInt32 = 70540
DISPID_IHTMLCURRENTSTYLE2_LAYOUTFLOW: UInt32 = 70691
DISPID_IHTMLCURRENTSTYLE2_WORDWRAP: UInt32 = 70694
DISPID_IHTMLCURRENTSTYLE2_TEXTUNDERLINEPOSITION: UInt32 = 70695
DISPID_IHTMLCURRENTSTYLE2_HASLAYOUT: UInt32 = 70696
DISPID_IHTMLCURRENTSTYLE2_SCROLLBARBASECOLOR: UInt32 = 70716
DISPID_IHTMLCURRENTSTYLE2_SCROLLBARFACECOLOR: UInt32 = 70717
DISPID_IHTMLCURRENTSTYLE2_SCROLLBAR3DLIGHTCOLOR: UInt32 = 70718
DISPID_IHTMLCURRENTSTYLE2_SCROLLBARSHADOWCOLOR: UInt32 = 70719
DISPID_IHTMLCURRENTSTYLE2_SCROLLBARHIGHLIGHTCOLOR: UInt32 = 70720
DISPID_IHTMLCURRENTSTYLE2_SCROLLBARDARKSHADOWCOLOR: UInt32 = 70721
DISPID_IHTMLCURRENTSTYLE2_SCROLLBARARROWCOLOR: UInt32 = 70722
DISPID_IHTMLCURRENTSTYLE2_SCROLLBARTRACKCOLOR: UInt32 = 70732
DISPID_IHTMLCURRENTSTYLE2_WRITINGMODE: UInt32 = 70728
DISPID_IHTMLCURRENTSTYLE2_ZOOM: UInt32 = 70689
DISPID_IHTMLCURRENTSTYLE2_FILTER: UInt32 = 70618
DISPID_IHTMLCURRENTSTYLE2_TEXTALIGNLAST: UInt32 = 70739
DISPID_IHTMLCURRENTSTYLE2_TEXTKASHIDASPACE: UInt32 = 70740
DISPID_IHTMLCURRENTSTYLE2_ISBLOCK: UInt32 = 70744
DISPID_IHTMLCURRENTSTYLE3_TEXTOVERFLOW: UInt32 = 70745
DISPID_IHTMLCURRENTSTYLE3_MINHEIGHT: UInt32 = 70747
DISPID_IHTMLCURRENTSTYLE3_WORDSPACING: UInt32 = 70583
DISPID_IHTMLCURRENTSTYLE3_WHITESPACE: UInt32 = 70612
DISPID_IHTMLCURRENTSTYLE4_MSINTERPOLATIONMODE: UInt32 = 70749
DISPID_IHTMLCURRENTSTYLE4_MAXHEIGHT: UInt32 = 70750
DISPID_IHTMLCURRENTSTYLE4_MINWIDTH: UInt32 = 70751
DISPID_IHTMLCURRENTSTYLE4_MAXWIDTH: UInt32 = 70752
DISPID_IHTMLCURRENTSTYLE5_CAPTIONSIDE: UInt32 = 70755
DISPID_IHTMLCURRENTSTYLE5_OUTLINE: UInt32 = 70758
DISPID_IHTMLCURRENTSTYLE5_OUTLINEWIDTH: UInt32 = 70759
DISPID_IHTMLCURRENTSTYLE5_OUTLINESTYLE: UInt32 = 70760
DISPID_IHTMLCURRENTSTYLE5_OUTLINECOLOR: UInt32 = 70761
DISPID_IHTMLCURRENTSTYLE5_BOXSIZING: UInt32 = 70762
DISPID_IHTMLCURRENTSTYLE5_BORDERSPACING: UInt32 = 70763
DISPID_IHTMLCURRENTSTYLE5_ORPHANS: UInt32 = 70764
DISPID_IHTMLCURRENTSTYLE5_WIDOWS: UInt32 = 70765
DISPID_IHTMLCURRENTSTYLE5_PAGEBREAKINSIDE: UInt32 = 70766
DISPID_IHTMLCURRENTSTYLE5_EMPTYCELLS: UInt32 = 70786
DISPID_IHTMLCURRENTSTYLE5_MSBLOCKPROGRESSION: UInt32 = 70787
DISPID_IHTMLCURRENTSTYLE5_QUOTES: UInt32 = 70788
DISPID_IHTMLRECT_LEFT: UInt32 = 1001
DISPID_IHTMLRECT_TOP: UInt32 = 1002
DISPID_IHTMLRECT_RIGHT: UInt32 = 1003
DISPID_IHTMLRECT_BOTTOM: UInt32 = 1004
DISPID_IHTMLRECT2_WIDTH: UInt32 = 1005
DISPID_IHTMLRECT2_HEIGHT: UInt32 = 1006
DISPID_IHTMLRECTCOLLECTION_LENGTH: UInt32 = 1500
DISPID_IHTMLRECTCOLLECTION__NEWENUM: Int32 = -4
DISPID_IHTMLRECTCOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLDOMNODE_NODETYPE: UInt32 = 66582
DISPID_IHTMLDOMNODE_PARENTNODE: UInt32 = 66583
DISPID_IHTMLDOMNODE_HASCHILDNODES: UInt32 = 66584
DISPID_IHTMLDOMNODE_CHILDNODES: UInt32 = 66585
DISPID_IHTMLDOMNODE_ATTRIBUTES: UInt32 = 66586
DISPID_IHTMLDOMNODE_INSERTBEFORE: UInt32 = 66587
DISPID_IHTMLDOMNODE_REMOVECHILD: UInt32 = 66588
DISPID_IHTMLDOMNODE_REPLACECHILD: UInt32 = 66589
DISPID_IHTMLDOMNODE_CLONENODE: UInt32 = 66597
DISPID_IHTMLDOMNODE_REMOVENODE: UInt32 = 66602
DISPID_IHTMLDOMNODE_SWAPNODE: UInt32 = 66604
DISPID_IHTMLDOMNODE_REPLACENODE: UInt32 = 66603
DISPID_IHTMLDOMNODE_APPENDCHILD: UInt32 = 66609
DISPID_IHTMLDOMNODE_NODENAME: UInt32 = 66610
DISPID_IHTMLDOMNODE_NODEVALUE: UInt32 = 66611
DISPID_IHTMLDOMNODE_FIRSTCHILD: UInt32 = 66612
DISPID_IHTMLDOMNODE_LASTCHILD: UInt32 = 66613
DISPID_IHTMLDOMNODE_PREVIOUSSIBLING: UInt32 = 66614
DISPID_IHTMLDOMNODE_NEXTSIBLING: UInt32 = 66615
DISPID_IHTMLDOMNODE2_OWNERDOCUMENT: UInt32 = 66649
DISPID_IHTMLDOMNODE3_PREFIX: UInt32 = 66656
DISPID_IHTMLDOMNODE3_LOCALNAME: UInt32 = 66654
DISPID_IHTMLDOMNODE3_NAMESPACEURI: UInt32 = 66655
DISPID_IHTMLDOMNODE3_TEXTCONTENT: UInt32 = 66663
DISPID_IHTMLDOMNODE3_ISEQUALNODE: UInt32 = 66657
DISPID_IHTMLDOMNODE3_LOOKUPNAMESPACEURI: UInt32 = 66658
DISPID_IHTMLDOMNODE3_LOOKUPPREFIX: UInt32 = 66659
DISPID_IHTMLDOMNODE3_ISDEFAULTNAMESPACE: UInt32 = 66660
DISPID_IHTMLDOMNODE3_IE9_APPENDCHILD: UInt32 = 66804
DISPID_IHTMLDOMNODE3_IE9_INSERTBEFORE: UInt32 = 66805
DISPID_IHTMLDOMNODE3_IE9_REMOVECHILD: UInt32 = 66806
DISPID_IHTMLDOMNODE3_IE9_REPLACECHILD: UInt32 = 66807
DISPID_IHTMLDOMNODE3_ISSAMENODE: UInt32 = 66661
DISPID_IHTMLDOMNODE3_COMPAREDOCUMENTPOSITION: UInt32 = 66662
DISPID_IHTMLDOMNODE3_ISSUPPORTED: UInt32 = 66813
DISPID_IHTMLDOMATTRIBUTE_NODENAME: UInt32 = 1000
DISPID_IHTMLDOMATTRIBUTE_NODEVALUE: UInt32 = 1002
DISPID_IHTMLDOMATTRIBUTE_SPECIFIED: UInt32 = 1001
DISPID_IHTMLDOMATTRIBUTE2_NAME: UInt32 = 1003
DISPID_IHTMLDOMATTRIBUTE2_VALUE: UInt32 = 1004
DISPID_IHTMLDOMATTRIBUTE2_EXPANDO: UInt32 = 1005
DISPID_IHTMLDOMATTRIBUTE2_NODETYPE: UInt32 = 1006
DISPID_IHTMLDOMATTRIBUTE2_PARENTNODE: UInt32 = 1007
DISPID_IHTMLDOMATTRIBUTE2_CHILDNODES: UInt32 = 1008
DISPID_IHTMLDOMATTRIBUTE2_FIRSTCHILD: UInt32 = 1009
DISPID_IHTMLDOMATTRIBUTE2_LASTCHILD: UInt32 = 1010
DISPID_IHTMLDOMATTRIBUTE2_PREVIOUSSIBLING: UInt32 = 1011
DISPID_IHTMLDOMATTRIBUTE2_NEXTSIBLING: UInt32 = 1012
DISPID_IHTMLDOMATTRIBUTE2_ATTRIBUTES: UInt32 = 1013
DISPID_IHTMLDOMATTRIBUTE2_OWNERDOCUMENT: UInt32 = 1014
DISPID_IHTMLDOMATTRIBUTE2_INSERTBEFORE: UInt32 = 1015
DISPID_IHTMLDOMATTRIBUTE2_REPLACECHILD: UInt32 = 1016
DISPID_IHTMLDOMATTRIBUTE2_REMOVECHILD: UInt32 = 1017
DISPID_IHTMLDOMATTRIBUTE2_APPENDCHILD: UInt32 = 1018
DISPID_IHTMLDOMATTRIBUTE2_HASCHILDNODES: UInt32 = 1019
DISPID_IHTMLDOMATTRIBUTE2_CLONENODE: UInt32 = 1020
DISPID_IHTMLDOMATTRIBUTE3_IE8_NODEVALUE: UInt32 = 1153
DISPID_IHTMLDOMATTRIBUTE3_IE8_VALUE: UInt32 = 1154
DISPID_IHTMLDOMATTRIBUTE3_IE8_SPECIFIED: UInt32 = 1150
DISPID_IHTMLDOMATTRIBUTE3_OWNERELEMENT: UInt32 = 1151
DISPID_IHTMLDOMATTRIBUTE4_IE9_NODEVALUE: UInt32 = 1159
DISPID_IHTMLDOMATTRIBUTE4_IE9_NODENAME: UInt32 = 1160
DISPID_IHTMLDOMATTRIBUTE4_IE9_NAME: UInt32 = 1161
DISPID_IHTMLDOMATTRIBUTE4_IE9_VALUE: UInt32 = 1162
DISPID_IHTMLDOMATTRIBUTE4_IE9_FIRSTCHILD: UInt32 = 1163
DISPID_IHTMLDOMATTRIBUTE4_IE9_LASTCHILD: UInt32 = 1164
DISPID_IHTMLDOMATTRIBUTE4_IE9_CHILDNODES: UInt32 = 1165
DISPID_IHTMLDOMATTRIBUTE4_HASATTRIBUTES: UInt32 = 1166
DISPID_IHTMLDOMATTRIBUTE4_IE9_HASCHILDNODES: UInt32 = 1167
DISPID_IHTMLDOMATTRIBUTE4_NORMALIZE: UInt32 = 1170
DISPID_IHTMLDOMATTRIBUTE4_IE9_SPECIFIED: UInt32 = 1171
DISPID_IHTMLDOMTEXTNODE_DATA: UInt32 = 1000
DISPID_IHTMLDOMTEXTNODE_TOSTRING: UInt32 = 1001
DISPID_IHTMLDOMTEXTNODE_LENGTH: UInt32 = 1002
DISPID_IHTMLDOMTEXTNODE_SPLITTEXT: UInt32 = 1003
DISPID_IHTMLDOMTEXTNODE2_SUBSTRINGDATA: UInt32 = 1004
DISPID_IHTMLDOMTEXTNODE2_APPENDDATA: UInt32 = 1005
DISPID_IHTMLDOMTEXTNODE2_INSERTDATA: UInt32 = 1006
DISPID_IHTMLDOMTEXTNODE2_DELETEDATA: UInt32 = 1007
DISPID_IHTMLDOMTEXTNODE2_REPLACEDATA: UInt32 = 1008
DISPID_IHTMLDOMTEXTNODE3_IE9_SUBSTRINGDATA: UInt32 = 1010
DISPID_IHTMLDOMTEXTNODE3_IE9_INSERTDATA: UInt32 = 1011
DISPID_IHTMLDOMTEXTNODE3_IE9_DELETEDATA: UInt32 = 1012
DISPID_IHTMLDOMTEXTNODE3_IE9_REPLACEDATA: UInt32 = 1013
DISPID_IHTMLDOMTEXTNODE3_IE9_SPLITTEXT: UInt32 = 1009
DISPID_IHTMLDOMTEXTNODE3_WHOLETEXT: UInt32 = 1014
DISPID_IHTMLDOMTEXTNODE3_REPLACEWHOLETEXT: UInt32 = 1015
DISPID_IHTMLDOMTEXTNODE3_HASATTRIBUTES: UInt32 = 1017
DISPID_IHTMLDOMTEXTNODE3_NORMALIZE: UInt32 = 1019
DISPID_IHTMLDOMIMPLEMENTATION_HASFEATURE: UInt32 = 1000
DISPID_IHTMLDOMIMPLEMENTATION2_CREATEDOCUMENTTYPE: UInt32 = 1001
DISPID_IHTMLDOMIMPLEMENTATION2_CREATEDOCUMENT: UInt32 = 1002
DISPID_IHTMLDOMIMPLEMENTATION2_CREATEHTMLDOCUMENT: UInt32 = 1003
DISPID_IHTMLDOMIMPLEMENTATION2_IE9_HASFEATURE: UInt32 = 1004
DISPID_IHTMLATTRIBUTECOLLECTION_LENGTH: UInt32 = 1500
DISPID_IHTMLATTRIBUTECOLLECTION__NEWENUM: Int32 = -4
DISPID_IHTMLATTRIBUTECOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLATTRIBUTECOLLECTION2_GETNAMEDITEM: UInt32 = 1501
DISPID_IHTMLATTRIBUTECOLLECTION2_SETNAMEDITEM: UInt32 = 1502
DISPID_IHTMLATTRIBUTECOLLECTION2_REMOVENAMEDITEM: UInt32 = 1503
DISPID_IHTMLATTRIBUTECOLLECTION3_IE8_GETNAMEDITEM: UInt32 = 1150
DISPID_IHTMLATTRIBUTECOLLECTION3_IE8_SETNAMEDITEM: UInt32 = 1151
DISPID_IHTMLATTRIBUTECOLLECTION3_IE8_REMOVENAMEDITEM: UInt32 = 1152
DISPID_IHTMLATTRIBUTECOLLECTION3_IE8_ITEM: UInt32 = 1154
DISPID_IHTMLATTRIBUTECOLLECTION3_IE8_LENGTH: UInt32 = 1153
DISPID_IHTMLATTRIBUTECOLLECTION4_GETNAMEDITEMNS: UInt32 = 1155
DISPID_IHTMLATTRIBUTECOLLECTION4_SETNAMEDITEMNS: UInt32 = 1156
DISPID_IHTMLATTRIBUTECOLLECTION4_REMOVENAMEDITEMNS: UInt32 = 1157
DISPID_IHTMLATTRIBUTECOLLECTION4_IE9_GETNAMEDITEM: UInt32 = 1158
DISPID_IHTMLATTRIBUTECOLLECTION4_IE9_SETNAMEDITEM: UInt32 = 1159
DISPID_IHTMLATTRIBUTECOLLECTION4_IE9_REMOVENAMEDITEM: UInt32 = 1160
DISPID_IHTMLATTRIBUTECOLLECTION4_IE9_ITEM: UInt32 = 1161
DISPID_IHTMLATTRIBUTECOLLECTION4_IE9_LENGTH: UInt32 = 1162
DISPID_IHTMLDOMCHILDRENCOLLECTION_LENGTH: UInt32 = 1500
DISPID_IHTMLDOMCHILDRENCOLLECTION__NEWENUM: Int32 = -4
DISPID_IHTMLDOMCHILDRENCOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLDOMCHILDRENCOLLECTION2_IE9_ITEM: UInt32 = 1
DISPID_IHTMLELEMENT_SETATTRIBUTE: UInt32 = 66037
DISPID_IHTMLELEMENT_GETATTRIBUTE: UInt32 = 66038
DISPID_IHTMLELEMENT_REMOVEATTRIBUTE: UInt32 = 66039
DISPID_IHTMLELEMENT_CLASSNAME: UInt32 = 66537
DISPID_IHTMLELEMENT_ID: UInt32 = 66538
DISPID_IHTMLELEMENT_TAGNAME: UInt32 = 66540
DISPID_IHTMLELEMENT_PARENTELEMENT: UInt32 = 65544
DISPID_IHTMLELEMENT_STYLE: UInt32 = 65610
DISPID_IHTMLELEMENT_ONHELP: UInt32 = 71549
DISPID_IHTMLELEMENT_ONCLICK: UInt32 = 71544
DISPID_IHTMLELEMENT_ONDBLCLICK: UInt32 = 71545
DISPID_IHTMLELEMENT_ONKEYDOWN: UInt32 = 71541
DISPID_IHTMLELEMENT_ONKEYUP: UInt32 = 71542
DISPID_IHTMLELEMENT_ONKEYPRESS: UInt32 = 71543
DISPID_IHTMLELEMENT_ONMOUSEOUT: UInt32 = 71537
DISPID_IHTMLELEMENT_ONMOUSEOVER: UInt32 = 71536
DISPID_IHTMLELEMENT_ONMOUSEMOVE: UInt32 = 71540
DISPID_IHTMLELEMENT_ONMOUSEDOWN: UInt32 = 71538
DISPID_IHTMLELEMENT_ONMOUSEUP: UInt32 = 71539
DISPID_IHTMLELEMENT_DOCUMENT: UInt32 = 66554
DISPID_IHTMLELEMENT_TITLE: UInt32 = 65605
DISPID_IHTMLELEMENT_LANGUAGE: UInt32 = 70636
DISPID_IHTMLELEMENT_ONSELECTSTART: UInt32 = 71573
DISPID_IHTMLELEMENT_SCROLLINTOVIEW: UInt32 = 66555
DISPID_IHTMLELEMENT_CONTAINS: UInt32 = 66556
DISPID_IHTMLELEMENT_SOURCEINDEX: UInt32 = 66560
DISPID_IHTMLELEMENT_RECORDNUMBER: UInt32 = 66561
DISPID_IHTMLELEMENT_LANG: UInt32 = 70545
DISPID_IHTMLELEMENT_OFFSETLEFT: UInt32 = 66544
DISPID_IHTMLELEMENT_OFFSETTOP: UInt32 = 66545
DISPID_IHTMLELEMENT_OFFSETWIDTH: UInt32 = 66546
DISPID_IHTMLELEMENT_OFFSETHEIGHT: UInt32 = 66547
DISPID_IHTMLELEMENT_OFFSETPARENT: UInt32 = 66548
DISPID_IHTMLELEMENT_INNERHTML: UInt32 = 66562
DISPID_IHTMLELEMENT_INNERTEXT: UInt32 = 66563
DISPID_IHTMLELEMENT_OUTERHTML: UInt32 = 66564
DISPID_IHTMLELEMENT_OUTERTEXT: UInt32 = 66565
DISPID_IHTMLELEMENT_INSERTADJACENTHTML: UInt32 = 66566
DISPID_IHTMLELEMENT_INSERTADJACENTTEXT: UInt32 = 66567
DISPID_IHTMLELEMENT_PARENTTEXTEDIT: UInt32 = 66568
DISPID_IHTMLELEMENT_ISTEXTEDIT: UInt32 = 66570
DISPID_IHTMLELEMENT_CLICK: UInt32 = 66569
DISPID_IHTMLELEMENT_FILTERS: UInt32 = 66571
DISPID_IHTMLELEMENT_ONDRAGSTART: UInt32 = 71571
DISPID_IHTMLELEMENT_TOSTRING: UInt32 = 66572
DISPID_IHTMLELEMENT_ONBEFOREUPDATE: UInt32 = 71557
DISPID_IHTMLELEMENT_ONAFTERUPDATE: UInt32 = 71558
DISPID_IHTMLELEMENT_ONERRORUPDATE: UInt32 = 71574
DISPID_IHTMLELEMENT_ONROWEXIT: UInt32 = 71554
DISPID_IHTMLELEMENT_ONROWENTER: UInt32 = 71555
DISPID_IHTMLELEMENT_ONDATASETCHANGED: UInt32 = 71576
DISPID_IHTMLELEMENT_ONDATAAVAILABLE: UInt32 = 71577
DISPID_IHTMLELEMENT_ONDATASETCOMPLETE: UInt32 = 71578
DISPID_IHTMLELEMENT_ONFILTERCHANGE: UInt32 = 71579
DISPID_IHTMLELEMENT_CHILDREN: UInt32 = 66573
DISPID_IHTMLELEMENT_ALL: UInt32 = 66574
DISPID_IHTMLELEMENT2_SCOPENAME: UInt32 = 66575
DISPID_IHTMLELEMENT2_SETCAPTURE: UInt32 = 66576
DISPID_IHTMLELEMENT2_RELEASECAPTURE: UInt32 = 66577
DISPID_IHTMLELEMENT2_ONLOSECAPTURE: UInt32 = 71582
DISPID_IHTMLELEMENT2_COMPONENTFROMPOINT: UInt32 = 66578
DISPID_IHTMLELEMENT2_DOSCROLL: UInt32 = 66579
DISPID_IHTMLELEMENT2_ONSCROLL: UInt32 = 71567
DISPID_IHTMLELEMENT2_ONDRAG: UInt32 = 71585
DISPID_IHTMLELEMENT2_ONDRAGEND: UInt32 = 71586
DISPID_IHTMLELEMENT2_ONDRAGENTER: UInt32 = 71587
DISPID_IHTMLELEMENT2_ONDRAGOVER: UInt32 = 71588
DISPID_IHTMLELEMENT2_ONDRAGLEAVE: UInt32 = 71589
DISPID_IHTMLELEMENT2_ONDROP: UInt32 = 71590
DISPID_IHTMLELEMENT2_ONBEFORECUT: UInt32 = 71594
DISPID_IHTMLELEMENT2_ONCUT: UInt32 = 71591
DISPID_IHTMLELEMENT2_ONBEFORECOPY: UInt32 = 71595
DISPID_IHTMLELEMENT2_ONCOPY: UInt32 = 71592
DISPID_IHTMLELEMENT2_ONBEFOREPASTE: UInt32 = 71596
DISPID_IHTMLELEMENT2_ONPASTE: UInt32 = 71593
DISPID_IHTMLELEMENT2_CURRENTSTYLE: UInt32 = 66543
DISPID_IHTMLELEMENT2_ONPROPERTYCHANGE: UInt32 = 71583
DISPID_IHTMLELEMENT2_GETCLIENTRECTS: UInt32 = 66580
DISPID_IHTMLELEMENT2_GETBOUNDINGCLIENTRECT: UInt32 = 66581
DISPID_IHTMLELEMENT2_SETEXPRESSION: UInt32 = 66040
DISPID_IHTMLELEMENT2_GETEXPRESSION: UInt32 = 66041
DISPID_IHTMLELEMENT2_REMOVEEXPRESSION: UInt32 = 66042
DISPID_IHTMLELEMENT2_TABINDEX: UInt32 = 65551
DISPID_IHTMLELEMENT2_FOCUS: UInt32 = 67536
DISPID_IHTMLELEMENT2_ACCESSKEY: UInt32 = 67541
DISPID_IHTMLELEMENT2_ONBLUR: UInt32 = 71551
DISPID_IHTMLELEMENT2_ONFOCUS: UInt32 = 71550
DISPID_IHTMLELEMENT2_ONRESIZE: UInt32 = 71572
DISPID_IHTMLELEMENT2_BLUR: UInt32 = 67538
DISPID_IHTMLELEMENT2_ADDFILTER: UInt32 = 67553
DISPID_IHTMLELEMENT2_REMOVEFILTER: UInt32 = 67554
DISPID_IHTMLELEMENT2_CLIENTHEIGHT: UInt32 = 67555
DISPID_IHTMLELEMENT2_CLIENTWIDTH: UInt32 = 67556
DISPID_IHTMLELEMENT2_CLIENTTOP: UInt32 = 67557
DISPID_IHTMLELEMENT2_CLIENTLEFT: UInt32 = 67558
DISPID_IHTMLELEMENT2_ATTACHEVENT: UInt32 = 66043
DISPID_IHTMLELEMENT2_DETACHEVENT: UInt32 = 66044
DISPID_IHTMLELEMENT2_READYSTATE: UInt32 = 70652
DISPID_IHTMLELEMENT2_ONREADYSTATECHANGE: UInt32 = 71561
DISPID_IHTMLELEMENT2_ONROWSDELETE: UInt32 = 71598
DISPID_IHTMLELEMENT2_ONROWSINSERTED: UInt32 = 71599
DISPID_IHTMLELEMENT2_ONCELLCHANGE: UInt32 = 71600
DISPID_IHTMLELEMENT2_DIR: UInt32 = 70653
DISPID_IHTMLELEMENT2_CREATECONTROLRANGE: UInt32 = 66592
DISPID_IHTMLELEMENT2_SCROLLHEIGHT: UInt32 = 66593
DISPID_IHTMLELEMENT2_SCROLLWIDTH: UInt32 = 66594
DISPID_IHTMLELEMENT2_SCROLLTOP: UInt32 = 66595
DISPID_IHTMLELEMENT2_SCROLLLEFT: UInt32 = 66596
DISPID_IHTMLELEMENT2_CLEARATTRIBUTES: UInt32 = 66598
DISPID_IHTMLELEMENT2_MERGEATTRIBUTES: UInt32 = 66599
DISPID_IHTMLELEMENT2_ONCONTEXTMENU: UInt32 = 71601
DISPID_IHTMLELEMENT2_INSERTADJACENTELEMENT: UInt32 = 66605
DISPID_IHTMLELEMENT2_APPLYELEMENT: UInt32 = 66601
DISPID_IHTMLELEMENT2_GETADJACENTTEXT: UInt32 = 66606
DISPID_IHTMLELEMENT2_REPLACEADJACENTTEXT: UInt32 = 66607
DISPID_IHTMLELEMENT2_CANHAVECHILDREN: UInt32 = 66608
DISPID_IHTMLELEMENT2_ADDBEHAVIOR: UInt32 = 66616
DISPID_IHTMLELEMENT2_REMOVEBEHAVIOR: UInt32 = 66617
DISPID_IHTMLELEMENT2_RUNTIMESTYLE: UInt32 = 66600
DISPID_IHTMLELEMENT2_BEHAVIORURNS: UInt32 = 66618
DISPID_IHTMLELEMENT2_TAGURN: UInt32 = 66619
DISPID_IHTMLELEMENT2_ONBEFOREEDITFOCUS: UInt32 = 71605
DISPID_IHTMLELEMENT2_READYSTATEVALUE: UInt32 = 66620
DISPID_IHTMLELEMENT2_GETELEMENTSBYTAGNAME: UInt32 = 66621
DISPID_IHTMLELEMENT3_MERGEATTRIBUTES: UInt32 = 66632
DISPID_IHTMLELEMENT3_ISMULTILINE: UInt32 = 66633
DISPID_IHTMLELEMENT3_CANHAVEHTML: UInt32 = 66634
DISPID_IHTMLELEMENT3_ONLAYOUTCOMPLETE: UInt32 = 71609
DISPID_IHTMLELEMENT3_ONPAGE: UInt32 = 71610
DISPID_IHTMLELEMENT3_INFLATEBLOCK: UInt32 = 66636
DISPID_IHTMLELEMENT3_ONBEFOREDEACTIVATE: UInt32 = 71613
DISPID_IHTMLELEMENT3_SETACTIVE: UInt32 = 66637
DISPID_IHTMLELEMENT3_CONTENTEDITABLE: UInt32 = 70698
DISPID_IHTMLELEMENT3_ISCONTENTEDITABLE: UInt32 = 66638
DISPID_IHTMLELEMENT3_HIDEFOCUS: UInt32 = 70699
DISPID_IHTMLELEMENT3_DISABLED: UInt32 = 65612
DISPID_IHTMLELEMENT3_ISDISABLED: UInt32 = 66641
DISPID_IHTMLELEMENT3_ONMOVE: UInt32 = 71614
DISPID_IHTMLELEMENT3_ONCONTROLSELECT: UInt32 = 71615
DISPID_IHTMLELEMENT3_FIREEVENT: UInt32 = 66642
DISPID_IHTMLELEMENT3_ONRESIZESTART: UInt32 = 71619
DISPID_IHTMLELEMENT3_ONRESIZEEND: UInt32 = 71620
DISPID_IHTMLELEMENT3_ONMOVESTART: UInt32 = 71617
DISPID_IHTMLELEMENT3_ONMOVEEND: UInt32 = 71618
DISPID_IHTMLELEMENT3_ONMOUSEENTER: UInt32 = 71621
DISPID_IHTMLELEMENT3_ONMOUSELEAVE: UInt32 = 71622
DISPID_IHTMLELEMENT3_ONACTIVATE: UInt32 = 71623
DISPID_IHTMLELEMENT3_ONDEACTIVATE: UInt32 = 71624
DISPID_IHTMLELEMENT3_DRAGDROP: UInt32 = 66643
DISPID_IHTMLELEMENT3_GLYPHMODE: UInt32 = 66644
DISPID_IHTMLELEMENT4_ONMOUSEWHEEL: UInt32 = 71612
DISPID_IHTMLELEMENT4_NORMALIZE: UInt32 = 66648
DISPID_IHTMLELEMENT4_GETATTRIBUTENODE: UInt32 = 66645
DISPID_IHTMLELEMENT4_SETATTRIBUTENODE: UInt32 = 66646
DISPID_IHTMLELEMENT4_REMOVEATTRIBUTENODE: UInt32 = 66647
DISPID_IHTMLELEMENT4_ONBEFOREACTIVATE: UInt32 = 71626
DISPID_IHTMLELEMENT4_ONFOCUSIN: UInt32 = 71627
DISPID_IHTMLELEMENT4_ONFOCUSOUT: UInt32 = 71628
DISPID_IELEMENTSELECTOR_QUERYSELECTOR: UInt32 = 66650
DISPID_IELEMENTSELECTOR_QUERYSELECTORALL: UInt32 = 66651
DISPID_IHTMLUNIQUENAME_UNIQUENUMBER: UInt32 = 66590
DISPID_IHTMLUNIQUENAME_UNIQUEID: UInt32 = 66591
DISPID_IHTMLELEMENT5_IE8_GETATTRIBUTENODE: UInt32 = 66736
DISPID_IHTMLELEMENT5_IE8_SETATTRIBUTENODE: UInt32 = 66737
DISPID_IHTMLELEMENT5_IE8_REMOVEATTRIBUTENODE: UInt32 = 66738
DISPID_IHTMLELEMENT5_HASATTRIBUTE: UInt32 = 66739
DISPID_IHTMLELEMENT5_ROLE: UInt32 = 66740
DISPID_IHTMLELEMENT5_ARIABUSY: UInt32 = 66741
DISPID_IHTMLELEMENT5_ARIACHECKED: UInt32 = 66742
DISPID_IHTMLELEMENT5_ARIADISABLED: UInt32 = 66743
DISPID_IHTMLELEMENT5_ARIAEXPANDED: UInt32 = 66744
DISPID_IHTMLELEMENT5_ARIAHASPOPUP: UInt32 = 66745
DISPID_IHTMLELEMENT5_ARIAHIDDEN: UInt32 = 66746
DISPID_IHTMLELEMENT5_ARIAINVALID: UInt32 = 66747
DISPID_IHTMLELEMENT5_ARIAMULTISELECTABLE: UInt32 = 66748
DISPID_IHTMLELEMENT5_ARIAPRESSED: UInt32 = 66749
DISPID_IHTMLELEMENT5_ARIAREADONLY: UInt32 = 66750
DISPID_IHTMLELEMENT5_ARIAREQUIRED: UInt32 = 66751
DISPID_IHTMLELEMENT5_ARIASECRET: UInt32 = 66752
DISPID_IHTMLELEMENT5_ARIASELECTED: UInt32 = 66753
DISPID_IHTMLELEMENT5_IE8_GETATTRIBUTE: UInt32 = 66754
DISPID_IHTMLELEMENT5_IE8_SETATTRIBUTE: UInt32 = 66755
DISPID_IHTMLELEMENT5_IE8_REMOVEATTRIBUTE: UInt32 = 66756
DISPID_IHTMLELEMENT5_IE8_ATTRIBUTES: UInt32 = 66757
DISPID_IHTMLELEMENT5_ARIAVALUENOW: UInt32 = 66758
DISPID_IHTMLELEMENT5_ARIAPOSINSET: UInt32 = 66759
DISPID_IHTMLELEMENT5_ARIASETSIZE: UInt32 = 66760
DISPID_IHTMLELEMENT5_ARIALEVEL: UInt32 = 66761
DISPID_IHTMLELEMENT5_ARIAVALUEMIN: UInt32 = 66762
DISPID_IHTMLELEMENT5_ARIAVALUEMAX: UInt32 = 66763
DISPID_IHTMLELEMENT5_ARIACONTROLS: UInt32 = 66764
DISPID_IHTMLELEMENT5_ARIADESCRIBEDBY: UInt32 = 66765
DISPID_IHTMLELEMENT5_ARIAFLOWTO: UInt32 = 66766
DISPID_IHTMLELEMENT5_ARIALABELLEDBY: UInt32 = 66767
DISPID_IHTMLELEMENT5_ARIAACTIVEDESCENDANT: UInt32 = 66768
DISPID_IHTMLELEMENT5_ARIAOWNS: UInt32 = 66769
DISPID_IHTMLELEMENT5_HASATTRIBUTES: UInt32 = 66770
DISPID_IHTMLELEMENT5_ARIALIVE: UInt32 = 66771
DISPID_IHTMLELEMENT5_ARIARELEVANT: UInt32 = 66772
DISPID_IHTMLELEMENT6_GETATTRIBUTENS: UInt32 = 66789
DISPID_IHTMLELEMENT6_SETATTRIBUTENS: UInt32 = 66790
DISPID_IHTMLELEMENT6_REMOVEATTRIBUTENS: UInt32 = 66791
DISPID_IHTMLELEMENT6_GETATTRIBUTENODENS: UInt32 = 66786
DISPID_IHTMLELEMENT6_SETATTRIBUTENODENS: UInt32 = 66787
DISPID_IHTMLELEMENT6_HASATTRIBUTENS: UInt32 = 66788
DISPID_IHTMLELEMENT6_IE9_GETATTRIBUTE: UInt32 = 66796
DISPID_IHTMLELEMENT6_IE9_SETATTRIBUTE: UInt32 = 66797
DISPID_IHTMLELEMENT6_IE9_REMOVEATTRIBUTE: UInt32 = 66798
DISPID_IHTMLELEMENT6_IE9_GETATTRIBUTENODE: UInt32 = 66792
DISPID_IHTMLELEMENT6_IE9_SETATTRIBUTENODE: UInt32 = 66793
DISPID_IHTMLELEMENT6_IE9_REMOVEATTRIBUTENODE: UInt32 = 66794
DISPID_IHTMLELEMENT6_IE9_HASATTRIBUTE: UInt32 = 66795
DISPID_IHTMLELEMENT6_GETELEMENTSBYTAGNAMENS: UInt32 = 66799
DISPID_IHTMLELEMENT6_IE9_TAGNAME: UInt32 = 66801
DISPID_IHTMLELEMENT6_IE9_NODENAME: UInt32 = 66802
DISPID_IHTMLELEMENT6_GETELEMENTSBYCLASSNAME: UInt32 = 66803
DISPID_IHTMLELEMENT6_MSMATCHESSELECTOR: UInt32 = 66814
DISPID_IHTMLELEMENT6_ONABORT: UInt32 = 71564
DISPID_IHTMLELEMENT6_ONCANPLAY: UInt32 = 71670
DISPID_IHTMLELEMENT6_ONCANPLAYTHROUGH: UInt32 = 71671
DISPID_IHTMLELEMENT6_ONCHANGE: UInt32 = 71566
DISPID_IHTMLELEMENT6_ONDURATIONCHANGE: UInt32 = 71672
DISPID_IHTMLELEMENT6_ONEMPTIED: UInt32 = 71673
DISPID_IHTMLELEMENT6_ONENDED: UInt32 = 71674
DISPID_IHTMLELEMENT6_ONERROR: UInt32 = 71565
DISPID_IHTMLELEMENT6_ONINPUT: UInt32 = 71663
DISPID_IHTMLELEMENT6_ONLOAD: UInt32 = 71568
DISPID_IHTMLELEMENT6_ONLOADEDDATA: UInt32 = 71675
DISPID_IHTMLELEMENT6_ONLOADEDMETADATA: UInt32 = 71676
DISPID_IHTMLELEMENT6_ONLOADSTART: UInt32 = 71677
DISPID_IHTMLELEMENT6_ONPAUSE: UInt32 = 71678
DISPID_IHTMLELEMENT6_ONPLAY: UInt32 = 71679
DISPID_IHTMLELEMENT6_ONPLAYING: UInt32 = 71680
DISPID_IHTMLELEMENT6_ONPROGRESS: UInt32 = 71681
DISPID_IHTMLELEMENT6_ONRATECHANGE: UInt32 = 71682
DISPID_IHTMLELEMENT6_ONRESET: UInt32 = 71548
DISPID_IHTMLELEMENT6_ONSEEKED: UInt32 = 71683
DISPID_IHTMLELEMENT6_ONSEEKING: UInt32 = 71684
DISPID_IHTMLELEMENT6_ONSELECT: UInt32 = 71546
DISPID_IHTMLELEMENT6_ONSTALLED: UInt32 = 71685
DISPID_IHTMLELEMENT6_ONSUBMIT: UInt32 = 71547
DISPID_IHTMLELEMENT6_ONSUSPEND: UInt32 = 71686
DISPID_IHTMLELEMENT6_ONTIMEUPDATE: UInt32 = 71687
DISPID_IHTMLELEMENT6_ONVOLUMECHANGE: UInt32 = 71688
DISPID_IHTMLELEMENT6_ONWAITING: UInt32 = 71689
DISPID_IHTMLELEMENT6_IE9_HASATTRIBUTES: UInt32 = 66815
DISPID_IHTMLELEMENT7_ONMSPOINTERDOWN: UInt32 = 71690
DISPID_IHTMLELEMENT7_ONMSPOINTERMOVE: UInt32 = 71691
DISPID_IHTMLELEMENT7_ONMSPOINTERUP: UInt32 = 71692
DISPID_IHTMLELEMENT7_ONMSPOINTEROVER: UInt32 = 71693
DISPID_IHTMLELEMENT7_ONMSPOINTEROUT: UInt32 = 71694
DISPID_IHTMLELEMENT7_ONMSPOINTERCANCEL: UInt32 = 71695
DISPID_IHTMLELEMENT7_ONMSPOINTERHOVER: UInt32 = 71696
DISPID_IHTMLELEMENT7_ONMSLOSTPOINTERCAPTURE: UInt32 = 71706
DISPID_IHTMLELEMENT7_ONMSGOTPOINTERCAPTURE: UInt32 = 71707
DISPID_IHTMLELEMENT7_ONMSGESTURESTART: UInt32 = 71699
DISPID_IHTMLELEMENT7_ONMSGESTURECHANGE: UInt32 = 71700
DISPID_IHTMLELEMENT7_ONMSGESTUREEND: UInt32 = 71701
DISPID_IHTMLELEMENT7_ONMSGESTUREHOLD: UInt32 = 71702
DISPID_IHTMLELEMENT7_ONMSGESTURETAP: UInt32 = 71703
DISPID_IHTMLELEMENT7_ONMSGESTUREDOUBLETAP: UInt32 = 71704
DISPID_IHTMLELEMENT7_ONMSINERTIASTART: UInt32 = 71705
DISPID_IHTMLELEMENT7_MSSETPOINTERCAPTURE: UInt32 = 66822
DISPID_IHTMLELEMENT7_MSRELEASEPOINTERCAPTURE: UInt32 = 66823
DISPID_IHTMLELEMENT7_ONMSTRANSITIONSTART: UInt32 = 71709
DISPID_IHTMLELEMENT7_ONMSTRANSITIONEND: UInt32 = 71710
DISPID_IHTMLELEMENT7_ONMSANIMATIONSTART: UInt32 = 71711
DISPID_IHTMLELEMENT7_ONMSANIMATIONEND: UInt32 = 71712
DISPID_IHTMLELEMENT7_ONMSANIMATIONITERATION: UInt32 = 71713
DISPID_IHTMLELEMENT7_ONINVALID: UInt32 = 71724
DISPID_IHTMLELEMENT7_XMSACCELERATORKEY: UInt32 = 66834
DISPID_IHTMLELEMENT7_SPELLCHECK: UInt32 = 70907
DISPID_IHTMLELEMENT7_ONMSMANIPULATIONSTATECHANGED: UInt32 = 71714
DISPID_IHTMLELEMENT7_ONCUECHANGE: UInt32 = 71729
DISPID_IHTMLELEMENTAPPLIEDSTYLES_MSGETRULESAPPLIED: UInt32 = 66652
DISPID_IHTMLELEMENTAPPLIEDSTYLES_MSGETRULESAPPLIEDWITHANCESTOR: UInt32 = 66653
DISPID_IELEMENTTRAVERSAL_FIRSTELEMENTCHILD: UInt32 = 66808
DISPID_IELEMENTTRAVERSAL_LASTELEMENTCHILD: UInt32 = 66809
DISPID_IELEMENTTRAVERSAL_PREVIOUSELEMENTSIBLING: UInt32 = 66810
DISPID_IELEMENTTRAVERSAL_NEXTELEMENTSIBLING: UInt32 = 66811
DISPID_IELEMENTTRAVERSAL_CHILDELEMENTCOUNT: UInt32 = 66812
DISPID_IHTMLDATABINDING_DATAFLD: UInt32 = 66557
DISPID_IHTMLDATABINDING_DATASRC: UInt32 = 66558
DISPID_IHTMLDATABINDING_DATAFORMATAS: UInt32 = 66559
DISPID_HTMLELEMENTEVENTS4_ONABORT: UInt32 = 1000
DISPID_HTMLELEMENTEVENTS4_ONCHANGE: UInt32 = 1001
DISPID_HTMLELEMENTEVENTS4_ONERROR: UInt32 = 1002
DISPID_HTMLELEMENTEVENTS4_ONLOAD: UInt32 = 1003
DISPID_HTMLELEMENTEVENTS4_ONRESET: UInt32 = 1015
DISPID_HTMLELEMENTEVENTS4_ONSELECT: UInt32 = 1006
DISPID_HTMLELEMENTEVENTS4_ONSUBMIT: UInt32 = 1007
DISPID_HTMLELEMENTEVENTS4_ONMSCONTENTZOOM: UInt32 = 71708
DISPID_HTMLELEMENTEVENTS3_ONONLINE: UInt32 = 1064
DISPID_HTMLELEMENTEVENTS3_ONOFFLINE: UInt32 = 1065
DISPID_HTMLELEMENTEVENTS2_ONHELP: UInt32 = 65546
DISPID_HTMLELEMENTEVENTS2_ONCLICK: Int32 = -600
DISPID_HTMLELEMENTEVENTS2_ONDBLCLICK: Int32 = -601
DISPID_HTMLELEMENTEVENTS2_ONKEYPRESS: Int32 = -603
DISPID_HTMLELEMENTEVENTS2_ONKEYDOWN: Int32 = -602
DISPID_HTMLELEMENTEVENTS2_ONKEYUP: Int32 = -604
DISPID_HTMLELEMENTEVENTS2_ONMOUSEOUT: UInt32 = 65545
DISPID_HTMLELEMENTEVENTS2_ONMOUSEOVER: UInt32 = 65544
DISPID_HTMLELEMENTEVENTS2_ONMOUSEMOVE: Int32 = -606
DISPID_HTMLELEMENTEVENTS2_ONMOUSEDOWN: Int32 = -605
DISPID_HTMLELEMENTEVENTS2_ONMOUSEUP: Int32 = -607
DISPID_HTMLELEMENTEVENTS2_ONSELECTSTART: UInt32 = 65548
DISPID_HTMLELEMENTEVENTS2_ONFILTERCHANGE: UInt32 = 65553
DISPID_HTMLELEMENTEVENTS2_ONDRAGSTART: UInt32 = 65547
DISPID_HTMLELEMENTEVENTS2_ONBEFOREUPDATE: UInt32 = 65540
DISPID_HTMLELEMENTEVENTS2_ONAFTERUPDATE: UInt32 = 65541
DISPID_HTMLELEMENTEVENTS2_ONERRORUPDATE: UInt32 = 65549
DISPID_HTMLELEMENTEVENTS2_ONROWEXIT: UInt32 = 65542
DISPID_HTMLELEMENTEVENTS2_ONROWENTER: UInt32 = 65543
DISPID_HTMLELEMENTEVENTS2_ONDATASETCHANGED: UInt32 = 65550
DISPID_HTMLELEMENTEVENTS2_ONDATAAVAILABLE: UInt32 = 65551
DISPID_HTMLELEMENTEVENTS2_ONDATASETCOMPLETE: UInt32 = 65552
DISPID_HTMLELEMENTEVENTS2_ONLOSECAPTURE: UInt32 = 65554
DISPID_HTMLELEMENTEVENTS2_ONPROPERTYCHANGE: UInt32 = 65555
DISPID_HTMLELEMENTEVENTS2_ONSCROLL: UInt32 = 1014
DISPID_HTMLELEMENTEVENTS2_ONFOCUS: UInt32 = 65537
DISPID_HTMLELEMENTEVENTS2_ONRESIZE: UInt32 = 1016
DISPID_HTMLELEMENTEVENTS2_ONDRAG: UInt32 = 65556
DISPID_HTMLELEMENTEVENTS2_ONDRAGEND: UInt32 = 65557
DISPID_HTMLELEMENTEVENTS2_ONDRAGENTER: UInt32 = 65558
DISPID_HTMLELEMENTEVENTS2_ONDRAGOVER: UInt32 = 65559
DISPID_HTMLELEMENTEVENTS2_ONDRAGLEAVE: UInt32 = 65560
DISPID_HTMLELEMENTEVENTS2_ONDROP: UInt32 = 65561
DISPID_HTMLELEMENTEVENTS2_ONBEFORECUT: UInt32 = 65565
DISPID_HTMLELEMENTEVENTS2_ONCUT: UInt32 = 65562
DISPID_HTMLELEMENTEVENTS2_ONBEFORECOPY: UInt32 = 65566
DISPID_HTMLELEMENTEVENTS2_ONCOPY: UInt32 = 65563
DISPID_HTMLELEMENTEVENTS2_ONBEFOREPASTE: UInt32 = 65567
DISPID_HTMLELEMENTEVENTS2_ONPASTE: UInt32 = 65564
DISPID_HTMLELEMENTEVENTS2_ONCONTEXTMENU: UInt32 = 1023
DISPID_HTMLELEMENTEVENTS2_ONROWSDELETE: UInt32 = 65568
DISPID_HTMLELEMENTEVENTS2_ONROWSINSERTED: UInt32 = 65569
DISPID_HTMLELEMENTEVENTS2_ONCELLCHANGE: UInt32 = 65570
DISPID_HTMLELEMENTEVENTS2_ONREADYSTATECHANGE: Int32 = -609
DISPID_HTMLELEMENTEVENTS2_ONLAYOUTCOMPLETE: UInt32 = 1030
DISPID_HTMLELEMENTEVENTS2_ONPAGE: UInt32 = 1031
DISPID_HTMLELEMENTEVENTS2_ONMOUSEENTER: UInt32 = 1042
DISPID_HTMLELEMENTEVENTS2_ONMOUSELEAVE: UInt32 = 1043
DISPID_HTMLELEMENTEVENTS2_ONACTIVATE: UInt32 = 1044
DISPID_HTMLELEMENTEVENTS2_ONDEACTIVATE: UInt32 = 1045
DISPID_HTMLELEMENTEVENTS2_ONBEFOREDEACTIVATE: UInt32 = 1034
DISPID_HTMLELEMENTEVENTS2_ONBEFOREACTIVATE: UInt32 = 1047
DISPID_HTMLELEMENTEVENTS2_ONFOCUSIN: UInt32 = 1048
DISPID_HTMLELEMENTEVENTS2_ONFOCUSOUT: UInt32 = 1049
DISPID_HTMLELEMENTEVENTS2_ONMOVE: UInt32 = 1035
DISPID_HTMLELEMENTEVENTS2_ONCONTROLSELECT: UInt32 = 1036
DISPID_HTMLELEMENTEVENTS2_ONMOVESTART: UInt32 = 1038
DISPID_HTMLELEMENTEVENTS2_ONMOVEEND: UInt32 = 1039
DISPID_HTMLELEMENTEVENTS2_ONRESIZESTART: UInt32 = 1040
DISPID_HTMLELEMENTEVENTS2_ONRESIZEEND: UInt32 = 1041
DISPID_HTMLELEMENTEVENTS2_ONMOUSEWHEEL: UInt32 = 1033
DISPID_HTMLELEMENTEVENTS_ONHELP: UInt32 = 65546
DISPID_HTMLELEMENTEVENTS_ONCLICK: Int32 = -600
DISPID_HTMLELEMENTEVENTS_ONDBLCLICK: Int32 = -601
DISPID_HTMLELEMENTEVENTS_ONKEYPRESS: Int32 = -603
DISPID_HTMLELEMENTEVENTS_ONKEYDOWN: Int32 = -602
DISPID_HTMLELEMENTEVENTS_ONKEYUP: Int32 = -604
DISPID_HTMLELEMENTEVENTS_ONMOUSEOUT: UInt32 = 65545
DISPID_HTMLELEMENTEVENTS_ONMOUSEOVER: UInt32 = 65544
DISPID_HTMLELEMENTEVENTS_ONMOUSEMOVE: Int32 = -606
DISPID_HTMLELEMENTEVENTS_ONMOUSEDOWN: Int32 = -605
DISPID_HTMLELEMENTEVENTS_ONMOUSEUP: Int32 = -607
DISPID_HTMLELEMENTEVENTS_ONSELECTSTART: UInt32 = 65548
DISPID_HTMLELEMENTEVENTS_ONFILTERCHANGE: UInt32 = 65553
DISPID_HTMLELEMENTEVENTS_ONDRAGSTART: UInt32 = 65547
DISPID_HTMLELEMENTEVENTS_ONBEFOREUPDATE: UInt32 = 65540
DISPID_HTMLELEMENTEVENTS_ONAFTERUPDATE: UInt32 = 65541
DISPID_HTMLELEMENTEVENTS_ONERRORUPDATE: UInt32 = 65549
DISPID_HTMLELEMENTEVENTS_ONROWEXIT: UInt32 = 65542
DISPID_HTMLELEMENTEVENTS_ONROWENTER: UInt32 = 65543
DISPID_HTMLELEMENTEVENTS_ONDATASETCHANGED: UInt32 = 65550
DISPID_HTMLELEMENTEVENTS_ONDATAAVAILABLE: UInt32 = 65551
DISPID_HTMLELEMENTEVENTS_ONDATASETCOMPLETE: UInt32 = 65552
DISPID_HTMLELEMENTEVENTS_ONLOSECAPTURE: UInt32 = 65554
DISPID_HTMLELEMENTEVENTS_ONPROPERTYCHANGE: UInt32 = 65555
DISPID_HTMLELEMENTEVENTS_ONSCROLL: UInt32 = 1014
DISPID_HTMLELEMENTEVENTS_ONFOCUS: UInt32 = 65537
DISPID_HTMLELEMENTEVENTS_ONRESIZE: UInt32 = 1016
DISPID_HTMLELEMENTEVENTS_ONDRAG: UInt32 = 65556
DISPID_HTMLELEMENTEVENTS_ONDRAGEND: UInt32 = 65557
DISPID_HTMLELEMENTEVENTS_ONDRAGENTER: UInt32 = 65558
DISPID_HTMLELEMENTEVENTS_ONDRAGOVER: UInt32 = 65559
DISPID_HTMLELEMENTEVENTS_ONDRAGLEAVE: UInt32 = 65560
DISPID_HTMLELEMENTEVENTS_ONDROP: UInt32 = 65561
DISPID_HTMLELEMENTEVENTS_ONBEFORECUT: UInt32 = 65565
DISPID_HTMLELEMENTEVENTS_ONCUT: UInt32 = 65562
DISPID_HTMLELEMENTEVENTS_ONBEFORECOPY: UInt32 = 65566
DISPID_HTMLELEMENTEVENTS_ONCOPY: UInt32 = 65563
DISPID_HTMLELEMENTEVENTS_ONBEFOREPASTE: UInt32 = 65567
DISPID_HTMLELEMENTEVENTS_ONPASTE: UInt32 = 65564
DISPID_HTMLELEMENTEVENTS_ONCONTEXTMENU: UInt32 = 1023
DISPID_HTMLELEMENTEVENTS_ONROWSDELETE: UInt32 = 65568
DISPID_HTMLELEMENTEVENTS_ONROWSINSERTED: UInt32 = 65569
DISPID_HTMLELEMENTEVENTS_ONCELLCHANGE: UInt32 = 65570
DISPID_HTMLELEMENTEVENTS_ONREADYSTATECHANGE: Int32 = -609
DISPID_HTMLELEMENTEVENTS_ONBEFOREEDITFOCUS: UInt32 = 1027
DISPID_HTMLELEMENTEVENTS_ONLAYOUTCOMPLETE: UInt32 = 1030
DISPID_HTMLELEMENTEVENTS_ONPAGE: UInt32 = 1031
DISPID_HTMLELEMENTEVENTS_ONBEFOREDEACTIVATE: UInt32 = 1034
DISPID_HTMLELEMENTEVENTS_ONBEFOREACTIVATE: UInt32 = 1047
DISPID_HTMLELEMENTEVENTS_ONMOVE: UInt32 = 1035
DISPID_HTMLELEMENTEVENTS_ONCONTROLSELECT: UInt32 = 1036
DISPID_HTMLELEMENTEVENTS_ONMOVESTART: UInt32 = 1038
DISPID_HTMLELEMENTEVENTS_ONMOVEEND: UInt32 = 1039
DISPID_HTMLELEMENTEVENTS_ONRESIZESTART: UInt32 = 1040
DISPID_HTMLELEMENTEVENTS_ONRESIZEEND: UInt32 = 1041
DISPID_HTMLELEMENTEVENTS_ONMOUSEENTER: UInt32 = 1042
DISPID_HTMLELEMENTEVENTS_ONMOUSELEAVE: UInt32 = 1043
DISPID_HTMLELEMENTEVENTS_ONMOUSEWHEEL: UInt32 = 1033
DISPID_HTMLELEMENTEVENTS_ONACTIVATE: UInt32 = 1044
DISPID_HTMLELEMENTEVENTS_ONDEACTIVATE: UInt32 = 1045
DISPID_HTMLELEMENTEVENTS_ONFOCUSIN: UInt32 = 1048
DISPID_HTMLELEMENTEVENTS_ONFOCUSOUT: UInt32 = 1049
DISPID_IHTMLELEMENTDEFAULTS_STYLE: UInt32 = 1001
DISPID_IHTMLELEMENTDEFAULTS_TABSTOP: UInt32 = 1002
DISPID_IHTMLELEMENTDEFAULTS_VIEWINHERITSTYLE: UInt32 = 70735
DISPID_IHTMLELEMENTDEFAULTS_VIEWMASTERTAB: UInt32 = 1006
DISPID_IHTMLELEMENTDEFAULTS_SCROLLSEGMENTX: UInt32 = 1003
DISPID_IHTMLELEMENTDEFAULTS_SCROLLSEGMENTY: UInt32 = 1004
DISPID_IHTMLELEMENTDEFAULTS_ISMULTILINE: UInt32 = 1008
DISPID_IHTMLELEMENTDEFAULTS_CONTENTEDITABLE: UInt32 = 70698
DISPID_IHTMLELEMENTDEFAULTS_CANHAVEHTML: UInt32 = 1009
DISPID_IHTMLELEMENTDEFAULTS_VIEWLINK: UInt32 = 1011
DISPID_IHTMLELEMENTDEFAULTS_FROZEN: UInt32 = 70734
DISPID_IHTCDEFAULTDISPATCH_ELEMENT: UInt32 = 70679
DISPID_IHTCDEFAULTDISPATCH_CREATEEVENTOBJECT: UInt32 = 70680
DISPID_IHTCDEFAULTDISPATCH_DEFAULTS: UInt32 = 70701
DISPID_IHTCDEFAULTDISPATCH_DOCUMENT: UInt32 = 70678
DISPID_IHTCPROPERTYBEHAVIOR_FIRECHANGE: UInt32 = 66036
DISPID_IHTCPROPERTYBEHAVIOR_VALUE: UInt32 = 70677
DISPID_IHTCEVENTBEHAVIOR_FIRE: UInt32 = 66036
DISPID_IHTCATTACHBEHAVIOR_FIREEVENT: UInt32 = 0
DISPID_IHTCATTACHBEHAVIOR_DETACHEVENT: UInt32 = 66036
DISPID_IHTCATTACHBEHAVIOR2_FIREEVENT: UInt32 = 0
DISPID_IHTCDESCBEHAVIOR_URN: UInt32 = 66036
DISPID_IHTCDESCBEHAVIOR_NAME: UInt32 = 66037
DISPID_IHTMLURNCOLLECTION_LENGTH: UInt32 = 1001
DISPID_IHTMLURNCOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLGENERICELEMENT_RECORDSET: UInt32 = 1001
DISPID_IHTMLGENERICELEMENT_NAMEDRECORDSET: UInt32 = 1002
DISPID_IHTMLSTYLESHEETRULE_SELECTORTEXT: UInt32 = 1001
DISPID_IHTMLSTYLESHEETRULE_STYLE: UInt32 = 65610
DISPID_IHTMLSTYLESHEETRULE_READONLY: UInt32 = 1002
DISPID_IHTMLSTYLESHEETRULEAPPLIED_MSSPECIFICITY: UInt32 = 1003
DISPID_IHTMLSTYLESHEETRULEAPPLIED_MSGETSPECIFICITY: UInt32 = 1004
DISPID_IHTMLSTYLESHEETRULE2_IE9_SELECTORTEXT: UInt32 = 1005
DISPID_IHTMLSTYLESHEETRULESCOLLECTION_LENGTH: UInt32 = 1001
DISPID_IHTMLSTYLESHEETRULESCOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLSTYLESHEETRULESCOLLECTION2_IE9_LENGTH: UInt32 = 1003
DISPID_IHTMLSTYLESHEETRULESCOLLECTION2_IE9_ITEM: UInt32 = 1002
DISPID_IHTMLSTYLESHEETPAGE_SELECTOR: UInt32 = 1001
DISPID_IHTMLSTYLESHEETPAGE_PSEUDOCLASS: UInt32 = 1002
DISPID_IHTMLSTYLESHEETPAGE2_SELECTORTEXT: UInt32 = 1003
DISPID_IHTMLSTYLESHEETPAGE2_STYLE: UInt32 = 65610
DISPID_IHTMLSTYLESHEETPAGESCOLLECTION_LENGTH: UInt32 = 1001
DISPID_IHTMLSTYLESHEETPAGESCOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLSTYLESHEET_TITLE: UInt32 = 1001
DISPID_IHTMLSTYLESHEET_PARENTSTYLESHEET: UInt32 = 1002
DISPID_IHTMLSTYLESHEET_OWNINGELEMENT: UInt32 = 1003
DISPID_IHTMLSTYLESHEET_DISABLED: UInt32 = 65612
DISPID_IHTMLSTYLESHEET_READONLY: UInt32 = 1004
DISPID_IHTMLSTYLESHEET_IMPORTS: UInt32 = 1005
DISPID_IHTMLSTYLESHEET_HREF: UInt32 = 1006
DISPID_IHTMLSTYLESHEET_TYPE: UInt32 = 1007
DISPID_IHTMLSTYLESHEET_ID: UInt32 = 1008
DISPID_IHTMLSTYLESHEET_ADDIMPORT: UInt32 = 1009
DISPID_IHTMLSTYLESHEET_ADDRULE: UInt32 = 1010
DISPID_IHTMLSTYLESHEET_REMOVEIMPORT: UInt32 = 1011
DISPID_IHTMLSTYLESHEET_REMOVERULE: UInt32 = 1012
DISPID_IHTMLSTYLESHEET_MEDIA: UInt32 = 1013
DISPID_IHTMLSTYLESHEET_CSSTEXT: UInt32 = 1014
DISPID_IHTMLSTYLESHEET_RULES: UInt32 = 1015
DISPID_IHTMLSTYLESHEET2_PAGES: UInt32 = 1016
DISPID_IHTMLSTYLESHEET2_ADDPAGERULE: UInt32 = 1017
DISPID_IHTMLSTYLESHEET3_IE8_HREF: UInt32 = 1150
DISPID_IHTMLSTYLESHEET3_ISALTERNATE: UInt32 = 1151
DISPID_IHTMLSTYLESHEET3_ISPREFALTERNATE: UInt32 = 1152
DISPID_IHTMLSTYLESHEET4_IE9_TYPE: UInt32 = 1153
DISPID_IHTMLSTYLESHEET4_IE9_HREF: UInt32 = 1154
DISPID_IHTMLSTYLESHEET4_IE9_TITLE: UInt32 = 1155
DISPID_IHTMLSTYLESHEET4_OWNERNODE: UInt32 = 1156
DISPID_IHTMLSTYLESHEET4_OWNERRULE: UInt32 = 1157
DISPID_IHTMLSTYLESHEET4_CSSRULES: UInt32 = 1158
DISPID_IHTMLSTYLESHEET4_IE9_MEDIA: UInt32 = 1159
DISPID_IHTMLSTYLESHEET4_INSERTRULE: UInt32 = 1160
DISPID_IHTMLSTYLESHEET4_DELETERULE: UInt32 = 1161
DISPID_IHTMLSTYLESHEETSCOLLECTION_LENGTH: UInt32 = 1001
DISPID_IHTMLSTYLESHEETSCOLLECTION__NEWENUM: Int32 = -4
DISPID_IHTMLSTYLESHEETSCOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLSTYLESHEETSCOLLECTION2_IE9_ITEM: UInt32 = 1002
DISPID_IHTMLLINKELEMENT_HREF: UInt32 = 1005
DISPID_IHTMLLINKELEMENT_REL: UInt32 = 1006
DISPID_IHTMLLINKELEMENT_REV: UInt32 = 1007
DISPID_IHTMLLINKELEMENT_TYPE: UInt32 = 1008
DISPID_IHTMLLINKELEMENT_READYSTATE: UInt32 = 70652
DISPID_IHTMLLINKELEMENT_ONREADYSTATECHANGE: UInt32 = 71561
DISPID_IHTMLLINKELEMENT_ONLOAD: UInt32 = 71568
DISPID_IHTMLLINKELEMENT_ONERROR: UInt32 = 71565
DISPID_IHTMLLINKELEMENT_STYLESHEET: UInt32 = 1014
DISPID_IHTMLLINKELEMENT_DISABLED: UInt32 = 65612
DISPID_IHTMLLINKELEMENT_MEDIA: UInt32 = 1016
DISPID_IHTMLLINKELEMENT2_TARGET: UInt32 = 1017
DISPID_IHTMLLINKELEMENT3_CHARSET: UInt32 = 1018
DISPID_IHTMLLINKELEMENT3_HREFLANG: UInt32 = 1019
DISPID_IHTMLLINKELEMENT4_IE8_HREF: UInt32 = 1150
DISPID_IHTMLLINKELEMENT5_SHEET: UInt32 = 1020
DISPID_HTMLLINKELEMENTEVENTS2_ONLOAD: UInt32 = 1003
DISPID_HTMLLINKELEMENTEVENTS2_ONERROR: UInt32 = 1002
DISPID_HTMLLINKELEMENTEVENTS_ONLOAD: UInt32 = 1003
DISPID_HTMLLINKELEMENTEVENTS_ONERROR: UInt32 = 1002
DISPID_IHTMLTXTRANGE_HTMLTEXT: UInt32 = 1003
DISPID_IHTMLTXTRANGE_TEXT: UInt32 = 1004
DISPID_IHTMLTXTRANGE_PARENTELEMENT: UInt32 = 1006
DISPID_IHTMLTXTRANGE_DUPLICATE: UInt32 = 1008
DISPID_IHTMLTXTRANGE_INRANGE: UInt32 = 1010
DISPID_IHTMLTXTRANGE_ISEQUAL: UInt32 = 1011
DISPID_IHTMLTXTRANGE_SCROLLINTOVIEW: UInt32 = 1012
DISPID_IHTMLTXTRANGE_COLLAPSE: UInt32 = 1013
DISPID_IHTMLTXTRANGE_EXPAND: UInt32 = 1014
DISPID_IHTMLTXTRANGE_MOVE: UInt32 = 1015
DISPID_IHTMLTXTRANGE_MOVESTART: UInt32 = 1016
DISPID_IHTMLTXTRANGE_MOVEEND: UInt32 = 1017
DISPID_IHTMLTXTRANGE_SELECT: UInt32 = 1024
DISPID_IHTMLTXTRANGE_PASTEHTML: UInt32 = 1026
DISPID_IHTMLTXTRANGE_MOVETOELEMENTTEXT: UInt32 = 1001
DISPID_IHTMLTXTRANGE_SETENDPOINT: UInt32 = 1025
DISPID_IHTMLTXTRANGE_COMPAREENDPOINTS: UInt32 = 1018
DISPID_IHTMLTXTRANGE_FINDTEXT: UInt32 = 1019
DISPID_IHTMLTXTRANGE_MOVETOPOINT: UInt32 = 1020
DISPID_IHTMLTXTRANGE_GETBOOKMARK: UInt32 = 1021
DISPID_IHTMLTXTRANGE_MOVETOBOOKMARK: UInt32 = 1009
DISPID_IHTMLTXTRANGE_QUERYCOMMANDSUPPORTED: UInt32 = 1027
DISPID_IHTMLTXTRANGE_QUERYCOMMANDENABLED: UInt32 = 1028
DISPID_IHTMLTXTRANGE_QUERYCOMMANDSTATE: UInt32 = 1029
DISPID_IHTMLTXTRANGE_QUERYCOMMANDINDETERM: UInt32 = 1030
DISPID_IHTMLTXTRANGE_QUERYCOMMANDTEXT: UInt32 = 1031
DISPID_IHTMLTXTRANGE_QUERYCOMMANDVALUE: UInt32 = 1032
DISPID_IHTMLTXTRANGE_EXECCOMMAND: UInt32 = 1033
DISPID_IHTMLTXTRANGE_EXECCOMMANDSHOWHELP: UInt32 = 1034
DISPID_IHTMLTEXTRANGEMETRICS_OFFSETTOP: UInt32 = 1035
DISPID_IHTMLTEXTRANGEMETRICS_OFFSETLEFT: UInt32 = 1036
DISPID_IHTMLTEXTRANGEMETRICS_BOUNDINGTOP: UInt32 = 1037
DISPID_IHTMLTEXTRANGEMETRICS_BOUNDINGLEFT: UInt32 = 1038
DISPID_IHTMLTEXTRANGEMETRICS_BOUNDINGWIDTH: UInt32 = 1039
DISPID_IHTMLTEXTRANGEMETRICS_BOUNDINGHEIGHT: UInt32 = 1040
DISPID_IHTMLTEXTRANGEMETRICS2_GETCLIENTRECTS: UInt32 = 1041
DISPID_IHTMLTEXTRANGEMETRICS2_GETBOUNDINGCLIENTRECT: UInt32 = 1042
DISPID_IHTMLTXTRANGECOLLECTION_LENGTH: UInt32 = 1500
DISPID_IHTMLTXTRANGECOLLECTION__NEWENUM: Int32 = -4
DISPID_IHTMLTXTRANGECOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLDOMRANGE_STARTCONTAINER: UInt32 = 1001
DISPID_IHTMLDOMRANGE_STARTOFFSET: UInt32 = 1002
DISPID_IHTMLDOMRANGE_ENDCONTAINER: UInt32 = 1003
DISPID_IHTMLDOMRANGE_ENDOFFSET: UInt32 = 1004
DISPID_IHTMLDOMRANGE_COLLAPSED: UInt32 = 1005
DISPID_IHTMLDOMRANGE_COMMONANCESTORCONTAINER: UInt32 = 1006
DISPID_IHTMLDOMRANGE_SETSTART: UInt32 = 1007
DISPID_IHTMLDOMRANGE_SETEND: UInt32 = 1008
DISPID_IHTMLDOMRANGE_SETSTARTBEFORE: UInt32 = 1009
DISPID_IHTMLDOMRANGE_SETSTARTAFTER: UInt32 = 1010
DISPID_IHTMLDOMRANGE_SETENDBEFORE: UInt32 = 1011
DISPID_IHTMLDOMRANGE_SETENDAFTER: UInt32 = 1012
DISPID_IHTMLDOMRANGE_COLLAPSE: UInt32 = 1013
DISPID_IHTMLDOMRANGE_SELECTNODE: UInt32 = 1014
DISPID_IHTMLDOMRANGE_SELECTNODECONTENTS: UInt32 = 1015
DISPID_IHTMLDOMRANGE_COMPAREBOUNDARYPOINTS: UInt32 = 1016
DISPID_IHTMLDOMRANGE_DELETECONTENTS: UInt32 = 1017
DISPID_IHTMLDOMRANGE_EXTRACTCONTENTS: UInt32 = 1018
DISPID_IHTMLDOMRANGE_CLONECONTENTS: UInt32 = 1019
DISPID_IHTMLDOMRANGE_INSERTNODE: UInt32 = 1020
DISPID_IHTMLDOMRANGE_SURROUNDCONTENTS: UInt32 = 1021
DISPID_IHTMLDOMRANGE_CLONERANGE: UInt32 = 1022
DISPID_IHTMLDOMRANGE_TOSTRING: UInt32 = 1023
DISPID_IHTMLDOMRANGE_DETACH: UInt32 = 1024
DISPID_IHTMLDOMRANGE_GETCLIENTRECTS: UInt32 = 1025
DISPID_IHTMLDOMRANGE_GETBOUNDINGCLIENTRECT: UInt32 = 1026
DISPID_IHTMLFORMELEMENT_ACTION: UInt32 = 1001
DISPID_IHTMLFORMELEMENT_DIR: UInt32 = 70653
DISPID_IHTMLFORMELEMENT_ENCODING: UInt32 = 1003
DISPID_IHTMLFORMELEMENT_METHOD: UInt32 = 1004
DISPID_IHTMLFORMELEMENT_ELEMENTS: UInt32 = 1005
DISPID_IHTMLFORMELEMENT_TARGET: UInt32 = 1006
DISPID_IHTMLFORMELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLFORMELEMENT_ONSUBMIT: UInt32 = 71547
DISPID_IHTMLFORMELEMENT_ONRESET: UInt32 = 71548
DISPID_IHTMLFORMELEMENT_SUBMIT: UInt32 = 1009
DISPID_IHTMLFORMELEMENT_RESET: UInt32 = 1010
DISPID_IHTMLFORMELEMENT_LENGTH: UInt32 = 1500
DISPID_IHTMLFORMELEMENT__NEWENUM: Int32 = -4
DISPID_IHTMLFORMELEMENT_ITEM: UInt32 = 0
DISPID_IHTMLFORMELEMENT_TAGS: UInt32 = 1502
DISPID_IHTMLFORMELEMENT2_ACCEPTCHARSET: UInt32 = 1011
DISPID_IHTMLFORMELEMENT2_URNS: UInt32 = 1505
DISPID_IHTMLFORMELEMENT3_NAMEDITEM: UInt32 = 1506
DISPID_IHTMLSUBMITDATA_APPENDNAMEVALUEPAIR: UInt32 = 1012
DISPID_IHTMLSUBMITDATA_APPENDNAMEFILEPAIR: UInt32 = 1013
DISPID_IHTMLSUBMITDATA_APPENDITEMSEPARATOR: UInt32 = 1014
DISPID_IHTMLFORMELEMENT4_IE8_ACTION: UInt32 = 1150
DISPID_HTMLFORMELEMENTEVENTS2_ONSUBMIT: UInt32 = 1007
DISPID_HTMLFORMELEMENTEVENTS2_ONRESET: UInt32 = 1015
DISPID_HTMLFORMELEMENTEVENTS_ONSUBMIT: UInt32 = 1007
DISPID_HTMLFORMELEMENTEVENTS_ONRESET: UInt32 = 1015
DISPID_IHTMLCONTROLELEMENT_TABINDEX: UInt32 = 65551
DISPID_IHTMLCONTROLELEMENT_FOCUS: UInt32 = 67536
DISPID_IHTMLCONTROLELEMENT_ACCESSKEY: UInt32 = 67541
DISPID_IHTMLCONTROLELEMENT_ONBLUR: UInt32 = 71551
DISPID_IHTMLCONTROLELEMENT_ONFOCUS: UInt32 = 71550
DISPID_IHTMLCONTROLELEMENT_ONRESIZE: UInt32 = 71572
DISPID_IHTMLCONTROLELEMENT_BLUR: UInt32 = 67538
DISPID_IHTMLCONTROLELEMENT_ADDFILTER: UInt32 = 67553
DISPID_IHTMLCONTROLELEMENT_REMOVEFILTER: UInt32 = 67554
DISPID_IHTMLCONTROLELEMENT_CLIENTHEIGHT: UInt32 = 67555
DISPID_IHTMLCONTROLELEMENT_CLIENTWIDTH: UInt32 = 67556
DISPID_IHTMLCONTROLELEMENT_CLIENTTOP: UInt32 = 67557
DISPID_IHTMLCONTROLELEMENT_CLIENTLEFT: UInt32 = 67558
DISPID_IHTMLTEXTCONTAINER_CREATECONTROLRANGE: UInt32 = 1001
DISPID_IHTMLTEXTCONTAINER_SCROLLHEIGHT: UInt32 = 1002
DISPID_IHTMLTEXTCONTAINER_SCROLLWIDTH: UInt32 = 1003
DISPID_IHTMLTEXTCONTAINER_SCROLLTOP: UInt32 = 1004
DISPID_IHTMLTEXTCONTAINER_SCROLLLEFT: UInt32 = 1005
DISPID_IHTMLTEXTCONTAINER_ONSCROLL: UInt32 = 71567
DISPID_HTMLTEXTCONTAINEREVENTS2_ONCHANGE: UInt32 = 1001
DISPID_HTMLTEXTCONTAINEREVENTS2_ONSELECT: UInt32 = 1006
DISPID_HTMLTEXTCONTAINEREVENTS_ONCHANGE: UInt32 = 1001
DISPID_HTMLTEXTCONTAINEREVENTS_ONSELECT: UInt32 = 1006
DISPID_IHTMLCONTROLRANGE_SELECT: UInt32 = 1002
DISPID_IHTMLCONTROLRANGE_ADD: UInt32 = 1003
DISPID_IHTMLCONTROLRANGE_REMOVE: UInt32 = 1004
DISPID_IHTMLCONTROLRANGE_ITEM: UInt32 = 0
DISPID_IHTMLCONTROLRANGE_SCROLLINTOVIEW: UInt32 = 1006
DISPID_IHTMLCONTROLRANGE_QUERYCOMMANDSUPPORTED: UInt32 = 1007
DISPID_IHTMLCONTROLRANGE_QUERYCOMMANDENABLED: UInt32 = 1008
DISPID_IHTMLCONTROLRANGE_QUERYCOMMANDSTATE: UInt32 = 1009
DISPID_IHTMLCONTROLRANGE_QUERYCOMMANDINDETERM: UInt32 = 1010
DISPID_IHTMLCONTROLRANGE_QUERYCOMMANDTEXT: UInt32 = 1011
DISPID_IHTMLCONTROLRANGE_QUERYCOMMANDVALUE: UInt32 = 1012
DISPID_IHTMLCONTROLRANGE_EXECCOMMAND: UInt32 = 1013
DISPID_IHTMLCONTROLRANGE_EXECCOMMANDSHOWHELP: UInt32 = 1014
DISPID_IHTMLCONTROLRANGE_COMMONPARENTELEMENT: UInt32 = 1015
DISPID_IHTMLCONTROLRANGE_LENGTH: UInt32 = 1005
DISPID_IHTMLCONTROLRANGE2_ADDELEMENT: UInt32 = 1016
DISPID_IHTMLIMGELEMENT_ISMAP: UInt32 = 2002
DISPID_IHTMLIMGELEMENT_USEMAP: UInt32 = 2008
DISPID_IHTMLIMGELEMENT_MIMETYPE: UInt32 = 2010
DISPID_IHTMLIMGELEMENT_FILESIZE: UInt32 = 2011
DISPID_IHTMLIMGELEMENT_FILECREATEDDATE: UInt32 = 2012
DISPID_IHTMLIMGELEMENT_FILEMODIFIEDDATE: UInt32 = 2013
DISPID_IHTMLIMGELEMENT_FILEUPDATEDDATE: UInt32 = 2014
DISPID_IHTMLIMGELEMENT_PROTOCOL: UInt32 = 2015
DISPID_IHTMLIMGELEMENT_HREF: UInt32 = 2016
DISPID_IHTMLIMGELEMENT_NAMEPROP: UInt32 = 2017
DISPID_IHTMLIMGELEMENT_BORDER: UInt32 = 1004
DISPID_IHTMLIMGELEMENT_VSPACE: UInt32 = 1005
DISPID_IHTMLIMGELEMENT_HSPACE: UInt32 = 1006
DISPID_IHTMLIMGELEMENT_ALT: UInt32 = 1002
DISPID_IHTMLIMGELEMENT_SRC: UInt32 = 1003
DISPID_IHTMLIMGELEMENT_LOWSRC: UInt32 = 1007
DISPID_IHTMLIMGELEMENT_VRML: UInt32 = 1008
DISPID_IHTMLIMGELEMENT_DYNSRC: UInt32 = 1009
DISPID_IHTMLIMGELEMENT_READYSTATE: UInt32 = 70652
DISPID_IHTMLIMGELEMENT_COMPLETE: UInt32 = 1010
DISPID_IHTMLIMGELEMENT_LOOP: UInt32 = 1011
DISPID_IHTMLIMGELEMENT_ALIGN: UInt32 = 65609
DISPID_IHTMLIMGELEMENT_ONLOAD: UInt32 = 71568
DISPID_IHTMLIMGELEMENT_ONERROR: UInt32 = 71565
DISPID_IHTMLIMGELEMENT_ONABORT: UInt32 = 71564
DISPID_IHTMLIMGELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLIMGELEMENT_WIDTH: UInt32 = 65541
DISPID_IHTMLIMGELEMENT_HEIGHT: UInt32 = 65542
DISPID_IHTMLIMGELEMENT_START: UInt32 = 1013
DISPID_IHTMLIMGELEMENT2_LONGDESC: UInt32 = 2019
DISPID_IHTMLIMGELEMENT3_IE8_LONGDESC: UInt32 = 1151
DISPID_IHTMLIMGELEMENT3_IE8_VRML: UInt32 = 1152
DISPID_IHTMLIMGELEMENT3_IE8_LOWSRC: UInt32 = 1153
DISPID_IHTMLIMGELEMENT3_IE8_DYNSRC: UInt32 = 1154
DISPID_IHTMLIMGELEMENT4_NATURALWIDTH: UInt32 = 1155
DISPID_IHTMLIMGELEMENT4_NATURALHEIGHT: UInt32 = 1156
DISPID_IHTMLMSIMGELEMENT_MSPLAYTODISABLED: UInt32 = 1157
DISPID_IHTMLMSIMGELEMENT_MSPLAYTOPRIMARY: UInt32 = 1158
DISPID_IHTMLIMAGEELEMENTFACTORY_CREATE: UInt32 = 0
DISPID_HTMLIMGEVENTS2_ONLOAD: UInt32 = 1003
DISPID_HTMLIMGEVENTS2_ONERROR: UInt32 = 1002
DISPID_HTMLIMGEVENTS2_ONABORT: UInt32 = 1000
DISPID_HTMLIMGEVENTS_ONLOAD: UInt32 = 1003
DISPID_HTMLIMGEVENTS_ONERROR: UInt32 = 1002
DISPID_HTMLIMGEVENTS_ONABORT: UInt32 = 1000
DISPID_IHTMLBODYELEMENT_BACKGROUND: UInt32 = 70537
DISPID_IHTMLBODYELEMENT_BGPROPERTIES: UInt32 = 70581
DISPID_IHTMLBODYELEMENT_LEFTMARGIN: UInt32 = 70576
DISPID_IHTMLBODYELEMENT_TOPMARGIN: UInt32 = 70573
DISPID_IHTMLBODYELEMENT_RIGHTMARGIN: UInt32 = 70574
DISPID_IHTMLBODYELEMENT_BOTTOMMARGIN: UInt32 = 70575
DISPID_IHTMLBODYELEMENT_NOWRAP: UInt32 = 70541
DISPID_IHTMLBODYELEMENT_BGCOLOR: Int32 = -501
DISPID_IHTMLBODYELEMENT_TEXT: UInt32 = 70538
DISPID_IHTMLBODYELEMENT_LINK: UInt32 = 2010
DISPID_IHTMLBODYELEMENT_VLINK: UInt32 = 2012
DISPID_IHTMLBODYELEMENT_ALINK: UInt32 = 2011
DISPID_IHTMLBODYELEMENT_ONLOAD: UInt32 = 71568
DISPID_IHTMLBODYELEMENT_ONUNLOAD: UInt32 = 71569
DISPID_IHTMLBODYELEMENT_SCROLL: UInt32 = 70615
DISPID_IHTMLBODYELEMENT_ONSELECT: UInt32 = 71546
DISPID_IHTMLBODYELEMENT_ONBEFOREUNLOAD: UInt32 = 71575
DISPID_IHTMLBODYELEMENT_CREATETEXTRANGE: UInt32 = 2013
DISPID_IHTMLBODYELEMENT2_ONBEFOREPRINT: UInt32 = 71602
DISPID_IHTMLBODYELEMENT2_ONAFTERPRINT: UInt32 = 71603
DISPID_IHTMLBODYELEMENT3_IE8_BACKGROUND: UInt32 = 1150
DISPID_IHTMLBODYELEMENT3_ONONLINE: UInt32 = 71643
DISPID_IHTMLBODYELEMENT3_ONOFFLINE: UInt32 = 71644
DISPID_IHTMLBODYELEMENT3_ONHASHCHANGE: UInt32 = 71645
DISPID_IHTMLBODYELEMENT4_ONMESSAGE: UInt32 = 71646
DISPID_IHTMLBODYELEMENT4_ONSTORAGE: UInt32 = 71636
DISPID_IHTMLBODYELEMENT5_ONPOPSTATE: UInt32 = 71728
DISPID_IHTMLFONTELEMENT_COLOR: UInt32 = 70538
DISPID_IHTMLFONTELEMENT_FACE: UInt32 = 70554
DISPID_IHTMLFONTELEMENT_SIZE: UInt32 = 70555
DISPID_IHTMLANCHORELEMENT_HREF: UInt32 = 0
DISPID_IHTMLANCHORELEMENT_TARGET: UInt32 = 1003
DISPID_IHTMLANCHORELEMENT_REL: UInt32 = 1005
DISPID_IHTMLANCHORELEMENT_REV: UInt32 = 1006
DISPID_IHTMLANCHORELEMENT_URN: UInt32 = 1007
DISPID_IHTMLANCHORELEMENT_METHODS: UInt32 = 1008
DISPID_IHTMLANCHORELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLANCHORELEMENT_HOST: UInt32 = 1012
DISPID_IHTMLANCHORELEMENT_HOSTNAME: UInt32 = 1013
DISPID_IHTMLANCHORELEMENT_PATHNAME: UInt32 = 1014
DISPID_IHTMLANCHORELEMENT_PORT: UInt32 = 1015
DISPID_IHTMLANCHORELEMENT_PROTOCOL: UInt32 = 1016
DISPID_IHTMLANCHORELEMENT_SEARCH: UInt32 = 1017
DISPID_IHTMLANCHORELEMENT_HASH: UInt32 = 1018
DISPID_IHTMLANCHORELEMENT_ONBLUR: UInt32 = 71551
DISPID_IHTMLANCHORELEMENT_ONFOCUS: UInt32 = 71550
DISPID_IHTMLANCHORELEMENT_ACCESSKEY: UInt32 = 67541
DISPID_IHTMLANCHORELEMENT_PROTOCOLLONG: UInt32 = 1031
DISPID_IHTMLANCHORELEMENT_MIMETYPE: UInt32 = 1030
DISPID_IHTMLANCHORELEMENT_NAMEPROP: UInt32 = 1032
DISPID_IHTMLANCHORELEMENT_TABINDEX: UInt32 = 65551
DISPID_IHTMLANCHORELEMENT_FOCUS: UInt32 = 67536
DISPID_IHTMLANCHORELEMENT_BLUR: UInt32 = 67538
DISPID_IHTMLANCHORELEMENT2_CHARSET: UInt32 = 1023
DISPID_IHTMLANCHORELEMENT2_COORDS: UInt32 = 1024
DISPID_IHTMLANCHORELEMENT2_HREFLANG: UInt32 = 1025
DISPID_IHTMLANCHORELEMENT2_SHAPE: UInt32 = 1026
DISPID_IHTMLANCHORELEMENT2_TYPE: UInt32 = 1027
DISPID_IHTMLANCHORELEMENT3_IE8_SHAPE: UInt32 = 1151
DISPID_IHTMLANCHORELEMENT3_IE8_COORDS: UInt32 = 1152
DISPID_IHTMLANCHORELEMENT3_IE8_HREF: UInt32 = 1153
DISPID_IHTMLLABELELEMENT_HTMLFOR: UInt32 = 1000
DISPID_IHTMLLABELELEMENT_ACCESSKEY: UInt32 = 67541
DISPID_IHTMLLABELELEMENT2_FORM: UInt32 = 1002
DISPID_IHTMLLISTELEMENT2_COMPACT: UInt32 = 1001
DISPID_IHTMLULISTELEMENT_COMPACT: UInt32 = 1001
DISPID_IHTMLULISTELEMENT_TYPE: UInt32 = 70553
DISPID_IHTMLOLISTELEMENT_COMPACT: UInt32 = 1001
DISPID_IHTMLOLISTELEMENT_START: UInt32 = 1003
DISPID_IHTMLOLISTELEMENT_TYPE: UInt32 = 70553
DISPID_IHTMLLIELEMENT_TYPE: UInt32 = 70553
DISPID_IHTMLLIELEMENT_VALUE: UInt32 = 1001
DISPID_IHTMLBLOCKELEMENT_CLEAR: UInt32 = 70552
DISPID_IHTMLBLOCKELEMENT2_CITE: UInt32 = 1001
DISPID_IHTMLBLOCKELEMENT2_WIDTH: UInt32 = 1002
DISPID_IHTMLBLOCKELEMENT3_IE8_CITE: UInt32 = 1150
DISPID_IHTMLDIVELEMENT_ALIGN: UInt32 = 65608
DISPID_IHTMLDIVELEMENT_NOWRAP: UInt32 = 70541
DISPID_IHTMLDDELEMENT_NOWRAP: UInt32 = 70541
DISPID_IHTMLDTELEMENT_NOWRAP: UInt32 = 70541
DISPID_IHTMLBRELEMENT_CLEAR: UInt32 = 70552
DISPID_IHTMLDLISTELEMENT_COMPACT: UInt32 = 1001
DISPID_IHTMLHRELEMENT_ALIGN: UInt32 = 65608
DISPID_IHTMLHRELEMENT_COLOR: UInt32 = 70538
DISPID_IHTMLHRELEMENT_NOSHADE: UInt32 = 1001
DISPID_IHTMLHRELEMENT_WIDTH: UInt32 = 65541
DISPID_IHTMLHRELEMENT_SIZE: UInt32 = 65542
DISPID_IHTMLPARAELEMENT_ALIGN: UInt32 = 65608
DISPID_IHTMLELEMENTCOLLECTION_TOSTRING: UInt32 = 1501
DISPID_IHTMLELEMENTCOLLECTION_LENGTH: UInt32 = 1500
DISPID_IHTMLELEMENTCOLLECTION__NEWENUM: Int32 = -4
DISPID_IHTMLELEMENTCOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLELEMENTCOLLECTION_TAGS: UInt32 = 1502
DISPID_IHTMLELEMENTCOLLECTION2_URNS: UInt32 = 1505
DISPID_IHTMLELEMENTCOLLECTION3_NAMEDITEM: UInt32 = 1506
DISPID_IHTMLELEMENTCOLLECTION4_IE8_LENGTH: UInt32 = 1150
DISPID_IHTMLELEMENTCOLLECTION4_IE8_ITEM: UInt32 = 1152
DISPID_IHTMLELEMENTCOLLECTION4_IE8_NAMEDITEM: UInt32 = 1153
DISPID_IHTMLHEADERELEMENT_ALIGN: UInt32 = 65608
DISPID_IHTMLSELECTELEMENT_SIZE: UInt32 = 1002
DISPID_IHTMLSELECTELEMENT_MULTIPLE: UInt32 = 1003
DISPID_IHTMLSELECTELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLSELECTELEMENT_OPTIONS: UInt32 = 1005
DISPID_IHTMLSELECTELEMENT_ONCHANGE: UInt32 = 71566
DISPID_IHTMLSELECTELEMENT_SELECTEDINDEX: UInt32 = 1010
DISPID_IHTMLSELECTELEMENT_TYPE: UInt32 = 1012
DISPID_IHTMLSELECTELEMENT_VALUE: UInt32 = 1011
DISPID_IHTMLSELECTELEMENT_DISABLED: UInt32 = 65612
DISPID_IHTMLSELECTELEMENT_FORM: UInt32 = 67540
DISPID_IHTMLSELECTELEMENT_ADD: UInt32 = 1503
DISPID_IHTMLSELECTELEMENT_REMOVE: UInt32 = 1504
DISPID_IHTMLSELECTELEMENT_LENGTH: UInt32 = 1500
DISPID_IHTMLSELECTELEMENT__NEWENUM: Int32 = -4
DISPID_IHTMLSELECTELEMENT_ITEM: UInt32 = 0
DISPID_IHTMLSELECTELEMENT_TAGS: UInt32 = 1502
DISPID_IHTMLSELECTELEMENT2_URNS: UInt32 = 1505
DISPID_IHTMLSELECTELEMENT4_NAMEDITEM: UInt32 = 1506
DISPID_IHTMLSELECTELEMENT5_IE8_ADD: UInt32 = 1150
DISPID_IHTMLSELECTELEMENT6_IE9_ADD: UInt32 = 1151
DISPID_IHTMLSELECTELEMENT6_IE9_VALUE: UInt32 = 1152
DISPID_HTMLSELECTELEMENTEVENTS2_ONCHANGE: UInt32 = 1001
DISPID_HTMLSELECTELEMENTEVENTS_ONCHANGE: UInt32 = 1001
DISPID_IHTMLSELECTIONOBJECT_CREATERANGE: UInt32 = 1001
DISPID_IHTMLSELECTIONOBJECT_EMPTY: UInt32 = 1002
DISPID_IHTMLSELECTIONOBJECT_CLEAR: UInt32 = 1003
DISPID_IHTMLSELECTIONOBJECT_TYPE: UInt32 = 1004
DISPID_IHTMLSELECTIONOBJECT2_CREATERANGECOLLECTION: UInt32 = 1005
DISPID_IHTMLSELECTIONOBJECT2_TYPEDETAIL: UInt32 = 1006
DISPID_IHTMLSELECTION_ANCHORNODE: UInt32 = 1001
DISPID_IHTMLSELECTION_ANCHOROFFSET: UInt32 = 1002
DISPID_IHTMLSELECTION_FOCUSNODE: UInt32 = 1003
DISPID_IHTMLSELECTION_FOCUSOFFSET: UInt32 = 1004
DISPID_IHTMLSELECTION_ISCOLLAPSED: UInt32 = 1005
DISPID_IHTMLSELECTION_COLLAPSE: UInt32 = 1006
DISPID_IHTMLSELECTION_COLLAPSETOSTART: UInt32 = 1007
DISPID_IHTMLSELECTION_COLLAPSETOEND: UInt32 = 1008
DISPID_IHTMLSELECTION_SELECTALLCHILDREN: UInt32 = 1009
DISPID_IHTMLSELECTION_DELETEFROMDOCUMENT: UInt32 = 1010
DISPID_IHTMLSELECTION_RANGECOUNT: UInt32 = 1011
DISPID_IHTMLSELECTION_GETRANGEAT: UInt32 = 1012
DISPID_IHTMLSELECTION_ADDRANGE: UInt32 = 1013
DISPID_IHTMLSELECTION_REMOVERANGE: UInt32 = 1014
DISPID_IHTMLSELECTION_REMOVEALLRANGES: UInt32 = 1015
DISPID_IHTMLSELECTION_TOSTRING: UInt32 = 1016
DISPID_IHTMLOPTIONELEMENT_SELECTED: UInt32 = 1001
DISPID_IHTMLOPTIONELEMENT_VALUE: UInt32 = 1002
DISPID_IHTMLOPTIONELEMENT_DEFAULTSELECTED: UInt32 = 1003
DISPID_IHTMLOPTIONELEMENT_INDEX: UInt32 = 1005
DISPID_IHTMLOPTIONELEMENT_TEXT: UInt32 = 1004
DISPID_IHTMLOPTIONELEMENT_FORM: UInt32 = 1006
DISPID_IHTMLOPTIONELEMENT3_LABEL: UInt32 = 1007
DISPID_IHTMLOPTIONELEMENT4_IE9_VALUE: UInt32 = 1008
DISPID_IHTMLOPTIONELEMENTFACTORY_CREATE: UInt32 = 0
DISPID_IHTMLINPUTELEMENT_TYPE: UInt32 = 2000
DISPID_IHTMLINPUTELEMENT_VALUE: UInt32 = 70637
DISPID_IHTMLINPUTELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLINPUTELEMENT_STATUS: UInt32 = 2001
DISPID_IHTMLINPUTELEMENT_DISABLED: UInt32 = 65612
DISPID_IHTMLINPUTELEMENT_FORM: UInt32 = 67540
DISPID_IHTMLINPUTELEMENT_SIZE: UInt32 = 2002
DISPID_IHTMLINPUTELEMENT_MAXLENGTH: UInt32 = 2003
DISPID_IHTMLINPUTELEMENT_SELECT: UInt32 = 2004
DISPID_IHTMLINPUTELEMENT_ONCHANGE: UInt32 = 71566
DISPID_IHTMLINPUTELEMENT_ONSELECT: UInt32 = 71546
DISPID_IHTMLINPUTELEMENT_DEFAULTVALUE: UInt32 = 70619
DISPID_IHTMLINPUTELEMENT_READONLY: UInt32 = 2005
DISPID_IHTMLINPUTELEMENT_CREATETEXTRANGE: UInt32 = 2006
DISPID_IHTMLINPUTELEMENT_INDETERMINATE: UInt32 = 2007
DISPID_IHTMLINPUTELEMENT_DEFAULTCHECKED: UInt32 = 2008
DISPID_IHTMLINPUTELEMENT_CHECKED: UInt32 = 2009
DISPID_IHTMLINPUTELEMENT_BORDER: UInt32 = 2012
DISPID_IHTMLINPUTELEMENT_VSPACE: UInt32 = 2013
DISPID_IHTMLINPUTELEMENT_HSPACE: UInt32 = 2014
DISPID_IHTMLINPUTELEMENT_ALT: UInt32 = 2010
DISPID_IHTMLINPUTELEMENT_SRC: UInt32 = 2011
DISPID_IHTMLINPUTELEMENT_LOWSRC: UInt32 = 2015
DISPID_IHTMLINPUTELEMENT_VRML: UInt32 = 2016
DISPID_IHTMLINPUTELEMENT_DYNSRC: UInt32 = 2017
DISPID_IHTMLINPUTELEMENT_READYSTATE: UInt32 = 70652
DISPID_IHTMLINPUTELEMENT_COMPLETE: UInt32 = 2018
DISPID_IHTMLINPUTELEMENT_LOOP: UInt32 = 2019
DISPID_IHTMLINPUTELEMENT_ALIGN: UInt32 = 65609
DISPID_IHTMLINPUTELEMENT_ONLOAD: UInt32 = 71568
DISPID_IHTMLINPUTELEMENT_ONERROR: UInt32 = 71565
DISPID_IHTMLINPUTELEMENT_ONABORT: UInt32 = 71564
DISPID_IHTMLINPUTELEMENT_WIDTH: UInt32 = 65541
DISPID_IHTMLINPUTELEMENT_HEIGHT: UInt32 = 65542
DISPID_IHTMLINPUTELEMENT_START: UInt32 = 2020
DISPID_IHTMLINPUTELEMENT2_ACCEPT: UInt32 = 2022
DISPID_IHTMLINPUTELEMENT2_USEMAP: UInt32 = 2023
DISPID_IHTMLINPUTELEMENT3_IE8_SRC: UInt32 = 1150
DISPID_IHTMLINPUTELEMENT3_IE8_LOWSRC: UInt32 = 1151
DISPID_IHTMLINPUTELEMENT3_IE8_VRML: UInt32 = 1152
DISPID_IHTMLINPUTELEMENT3_IE8_DYNSRC: UInt32 = 1153
DISPID_IHTMLINPUTBUTTONELEMENT_TYPE: UInt32 = 2000
DISPID_IHTMLINPUTBUTTONELEMENT_VALUE: UInt32 = 70637
DISPID_IHTMLINPUTBUTTONELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLINPUTBUTTONELEMENT_STATUS: UInt32 = 2021
DISPID_IHTMLINPUTBUTTONELEMENT_DISABLED: UInt32 = 65612
DISPID_IHTMLINPUTBUTTONELEMENT_FORM: UInt32 = 67540
DISPID_IHTMLINPUTBUTTONELEMENT_CREATETEXTRANGE: UInt32 = 2006
DISPID_IHTMLINPUTHIDDENELEMENT_TYPE: UInt32 = 2000
DISPID_IHTMLINPUTHIDDENELEMENT_VALUE: UInt32 = 70637
DISPID_IHTMLINPUTHIDDENELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLINPUTHIDDENELEMENT_STATUS: UInt32 = 2021
DISPID_IHTMLINPUTHIDDENELEMENT_DISABLED: UInt32 = 65612
DISPID_IHTMLINPUTHIDDENELEMENT_FORM: UInt32 = 67540
DISPID_IHTMLINPUTHIDDENELEMENT_CREATETEXTRANGE: UInt32 = 2006
DISPID_IHTMLINPUTTEXTELEMENT_TYPE: UInt32 = 2000
DISPID_IHTMLINPUTTEXTELEMENT_VALUE: UInt32 = 70637
DISPID_IHTMLINPUTTEXTELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLINPUTTEXTELEMENT_STATUS: UInt32 = 2021
DISPID_IHTMLINPUTTEXTELEMENT_DISABLED: UInt32 = 65612
DISPID_IHTMLINPUTTEXTELEMENT_FORM: UInt32 = 67540
DISPID_IHTMLINPUTTEXTELEMENT_DEFAULTVALUE: UInt32 = 70619
DISPID_IHTMLINPUTTEXTELEMENT_SIZE: UInt32 = 2002
DISPID_IHTMLINPUTTEXTELEMENT_MAXLENGTH: UInt32 = 2003
DISPID_IHTMLINPUTTEXTELEMENT_SELECT: UInt32 = 2004
DISPID_IHTMLINPUTTEXTELEMENT_ONCHANGE: UInt32 = 71566
DISPID_IHTMLINPUTTEXTELEMENT_ONSELECT: UInt32 = 71546
DISPID_IHTMLINPUTTEXTELEMENT_READONLY: UInt32 = 2005
DISPID_IHTMLINPUTTEXTELEMENT_CREATETEXTRANGE: UInt32 = 2006
DISPID_IHTMLINPUTTEXTELEMENT2_SELECTIONSTART: UInt32 = 2025
DISPID_IHTMLINPUTTEXTELEMENT2_SELECTIONEND: UInt32 = 2026
DISPID_IHTMLINPUTTEXTELEMENT2_SETSELECTIONRANGE: UInt32 = 2027
DISPID_IHTMLINPUTFILEELEMENT_TYPE: UInt32 = 2000
DISPID_IHTMLINPUTFILEELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLINPUTFILEELEMENT_STATUS: UInt32 = 2021
DISPID_IHTMLINPUTFILEELEMENT_DISABLED: UInt32 = 65612
DISPID_IHTMLINPUTFILEELEMENT_FORM: UInt32 = 67540
DISPID_IHTMLINPUTFILEELEMENT_SIZE: UInt32 = 2002
DISPID_IHTMLINPUTFILEELEMENT_MAXLENGTH: UInt32 = 2003
DISPID_IHTMLINPUTFILEELEMENT_SELECT: UInt32 = 2004
DISPID_IHTMLINPUTFILEELEMENT_ONCHANGE: UInt32 = 71566
DISPID_IHTMLINPUTFILEELEMENT_ONSELECT: UInt32 = 71546
DISPID_IHTMLINPUTFILEELEMENT_VALUE: UInt32 = 70637
DISPID_IHTMLOPTIONBUTTONELEMENT_VALUE: UInt32 = 70637
DISPID_IHTMLOPTIONBUTTONELEMENT_TYPE: UInt32 = 2000
DISPID_IHTMLOPTIONBUTTONELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLOPTIONBUTTONELEMENT_CHECKED: UInt32 = 2009
DISPID_IHTMLOPTIONBUTTONELEMENT_DEFAULTCHECKED: UInt32 = 2008
DISPID_IHTMLOPTIONBUTTONELEMENT_ONCHANGE: UInt32 = 71566
DISPID_IHTMLOPTIONBUTTONELEMENT_DISABLED: UInt32 = 65612
DISPID_IHTMLOPTIONBUTTONELEMENT_STATUS: UInt32 = 2001
DISPID_IHTMLOPTIONBUTTONELEMENT_INDETERMINATE: UInt32 = 2007
DISPID_IHTMLOPTIONBUTTONELEMENT_FORM: UInt32 = 67540
DISPID_IHTMLINPUTIMAGE_TYPE: UInt32 = 2000
DISPID_IHTMLINPUTIMAGE_DISABLED: UInt32 = 65612
DISPID_IHTMLINPUTIMAGE_BORDER: UInt32 = 2012
DISPID_IHTMLINPUTIMAGE_VSPACE: UInt32 = 2013
DISPID_IHTMLINPUTIMAGE_HSPACE: UInt32 = 2014
DISPID_IHTMLINPUTIMAGE_ALT: UInt32 = 2010
DISPID_IHTMLINPUTIMAGE_SRC: UInt32 = 2011
DISPID_IHTMLINPUTIMAGE_LOWSRC: UInt32 = 2015
DISPID_IHTMLINPUTIMAGE_VRML: UInt32 = 2016
DISPID_IHTMLINPUTIMAGE_DYNSRC: UInt32 = 2017
DISPID_IHTMLINPUTIMAGE_READYSTATE: UInt32 = 70652
DISPID_IHTMLINPUTIMAGE_COMPLETE: UInt32 = 2018
DISPID_IHTMLINPUTIMAGE_LOOP: UInt32 = 2019
DISPID_IHTMLINPUTIMAGE_ALIGN: UInt32 = 65609
DISPID_IHTMLINPUTIMAGE_ONLOAD: UInt32 = 71568
DISPID_IHTMLINPUTIMAGE_ONERROR: UInt32 = 71565
DISPID_IHTMLINPUTIMAGE_ONABORT: UInt32 = 71564
DISPID_IHTMLINPUTIMAGE_NAME: UInt32 = 65536
DISPID_IHTMLINPUTIMAGE_WIDTH: UInt32 = 65541
DISPID_IHTMLINPUTIMAGE_HEIGHT: UInt32 = 65542
DISPID_IHTMLINPUTIMAGE_START: UInt32 = 2020
DISPID_IHTMLINPUTRANGEELEMENT_DISABLED: UInt32 = 65612
DISPID_IHTMLINPUTRANGEELEMENT_TYPE: UInt32 = 2000
DISPID_IHTMLINPUTRANGEELEMENT_ALT: UInt32 = 2010
DISPID_IHTMLINPUTRANGEELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLINPUTRANGEELEMENT_VALUE: UInt32 = 70637
DISPID_IHTMLINPUTRANGEELEMENT_MIN: UInt32 = 2028
DISPID_IHTMLINPUTRANGEELEMENT_MAX: UInt32 = 2029
DISPID_IHTMLINPUTRANGEELEMENT_STEP: UInt32 = 2030
DISPID_IHTMLINPUTRANGEELEMENT_VALUEASNUMBER: UInt32 = 2031
DISPID_IHTMLINPUTRANGEELEMENT_STEPUP: UInt32 = 2033
DISPID_IHTMLINPUTRANGEELEMENT_STEPDOWN: UInt32 = 2032
DISPID_HTMLINPUTTEXTELEMENTEVENTS2_ONCHANGE: UInt32 = 1001
DISPID_HTMLINPUTTEXTELEMENTEVENTS2_ONSELECT: UInt32 = 1006
DISPID_HTMLINPUTTEXTELEMENTEVENTS2_ONLOAD: UInt32 = 1003
DISPID_HTMLINPUTTEXTELEMENTEVENTS2_ONERROR: UInt32 = 1002
DISPID_HTMLINPUTTEXTELEMENTEVENTS2_ONABORT: UInt32 = 1000
DISPID_HTMLINPUTIMAGEEVENTS2_ONLOAD: UInt32 = 1003
DISPID_HTMLINPUTIMAGEEVENTS2_ONERROR: UInt32 = 1002
DISPID_HTMLINPUTIMAGEEVENTS2_ONABORT: UInt32 = 1000
DISPID_HTMLINPUTTEXTELEMENTEVENTS_ONCHANGE: UInt32 = 1001
DISPID_HTMLINPUTTEXTELEMENTEVENTS_ONSELECT: UInt32 = 1006
DISPID_HTMLINPUTTEXTELEMENTEVENTS_ONLOAD: UInt32 = 1003
DISPID_HTMLINPUTTEXTELEMENTEVENTS_ONERROR: UInt32 = 1002
DISPID_HTMLINPUTTEXTELEMENTEVENTS_ONABORT: UInt32 = 1000
DISPID_HTMLINPUTIMAGEEVENTS_ONLOAD: UInt32 = 1003
DISPID_HTMLINPUTIMAGEEVENTS_ONERROR: UInt32 = 1002
DISPID_HTMLINPUTIMAGEEVENTS_ONABORT: UInt32 = 1000
DISPID_IHTMLTEXTAREAELEMENT_TYPE: UInt32 = 2000
DISPID_IHTMLTEXTAREAELEMENT_VALUE: UInt32 = 70637
DISPID_IHTMLTEXTAREAELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLTEXTAREAELEMENT_STATUS: UInt32 = 2001
DISPID_IHTMLTEXTAREAELEMENT_DISABLED: UInt32 = 65612
DISPID_IHTMLTEXTAREAELEMENT_FORM: UInt32 = 67540
DISPID_IHTMLTEXTAREAELEMENT_DEFAULTVALUE: UInt32 = 70619
DISPID_IHTMLTEXTAREAELEMENT_SELECT: UInt32 = 7005
DISPID_IHTMLTEXTAREAELEMENT_ONCHANGE: UInt32 = 71566
DISPID_IHTMLTEXTAREAELEMENT_ONSELECT: UInt32 = 71546
DISPID_IHTMLTEXTAREAELEMENT_READONLY: UInt32 = 7004
DISPID_IHTMLTEXTAREAELEMENT_ROWS: UInt32 = 7001
DISPID_IHTMLTEXTAREAELEMENT_COLS: UInt32 = 7002
DISPID_IHTMLTEXTAREAELEMENT_WRAP: UInt32 = 7003
DISPID_IHTMLTEXTAREAELEMENT_CREATETEXTRANGE: UInt32 = 7006
DISPID_IHTMLTEXTAREAELEMENT2_SELECTIONSTART: UInt32 = 7007
DISPID_IHTMLTEXTAREAELEMENT2_SELECTIONEND: UInt32 = 7008
DISPID_IHTMLTEXTAREAELEMENT2_SETSELECTIONRANGE: UInt32 = 7009
DISPID_IHTMLBUTTONELEMENT_TYPE: UInt32 = 2000
DISPID_IHTMLBUTTONELEMENT_VALUE: UInt32 = 70637
DISPID_IHTMLBUTTONELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLBUTTONELEMENT_STATUS: UInt32 = 8001
DISPID_IHTMLBUTTONELEMENT_DISABLED: UInt32 = 65612
DISPID_IHTMLBUTTONELEMENT_FORM: UInt32 = 67540
DISPID_IHTMLBUTTONELEMENT_CREATETEXTRANGE: UInt32 = 8002
DISPID_IHTMLBUTTONELEMENT2_IE9_TYPE: UInt32 = 8003
DISPID_IHTMLMARQUEEELEMENT_BGCOLOR: Int32 = -501
DISPID_IHTMLMARQUEEELEMENT_SCROLLDELAY: UInt32 = 6000
DISPID_IHTMLMARQUEEELEMENT_DIRECTION: UInt32 = 6001
DISPID_IHTMLMARQUEEELEMENT_BEHAVIOR: UInt32 = 6002
DISPID_IHTMLMARQUEEELEMENT_SCROLLAMOUNT: UInt32 = 6003
DISPID_IHTMLMARQUEEELEMENT_LOOP: UInt32 = 6004
DISPID_IHTMLMARQUEEELEMENT_VSPACE: UInt32 = 6005
DISPID_IHTMLMARQUEEELEMENT_HSPACE: UInt32 = 6006
DISPID_IHTMLMARQUEEELEMENT_ONFINISH: UInt32 = 71562
DISPID_IHTMLMARQUEEELEMENT_ONSTART: UInt32 = 71563
DISPID_IHTMLMARQUEEELEMENT_ONBOUNCE: UInt32 = 71556
DISPID_IHTMLMARQUEEELEMENT_WIDTH: UInt32 = 65541
DISPID_IHTMLMARQUEEELEMENT_HEIGHT: UInt32 = 65542
DISPID_IHTMLMARQUEEELEMENT_TRUESPEED: UInt32 = 6007
DISPID_IHTMLMARQUEEELEMENT_START: UInt32 = 6010
DISPID_IHTMLMARQUEEELEMENT_STOP: UInt32 = 6011
DISPID_HTMLMARQUEEELEMENTEVENTS2_ONBOUNCE: UInt32 = 1009
DISPID_HTMLMARQUEEELEMENTEVENTS2_ONFINISH: UInt32 = 1010
DISPID_HTMLMARQUEEELEMENTEVENTS2_ONSTART: UInt32 = 1011
DISPID_HTMLMARQUEEELEMENTEVENTS_ONBOUNCE: UInt32 = 1009
DISPID_HTMLMARQUEEELEMENTEVENTS_ONFINISH: UInt32 = 1010
DISPID_HTMLMARQUEEELEMENTEVENTS_ONSTART: UInt32 = 1011
DISPID_IHTMLHTMLELEMENT_VERSION: UInt32 = 1001
DISPID_IHTMLHEADELEMENT_PROFILE: UInt32 = 1001
DISPID_IHTMLHEADELEMENT2_IE8_PROFILE: UInt32 = 1150
DISPID_IHTMLTITLEELEMENT_TEXT: UInt32 = 70637
DISPID_IHTMLMETAELEMENT_HTTPEQUIV: UInt32 = 1001
DISPID_IHTMLMETAELEMENT_CONTENT: UInt32 = 1002
DISPID_IHTMLMETAELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLMETAELEMENT_URL: UInt32 = 1003
DISPID_IHTMLMETAELEMENT_CHARSET: UInt32 = 1013
DISPID_IHTMLMETAELEMENT2_SCHEME: UInt32 = 1020
DISPID_IHTMLMETAELEMENT3_IE8_URL: UInt32 = 1150
DISPID_IHTMLBASEELEMENT_HREF: UInt32 = 1003
DISPID_IHTMLBASEELEMENT_TARGET: UInt32 = 1004
DISPID_IHTMLBASEELEMENT2_IE8_HREF: UInt32 = 1150
DISPID_IHTMLISINDEXELEMENT_PROMPT: UInt32 = 1010
DISPID_IHTMLISINDEXELEMENT_ACTION: UInt32 = 1011
DISPID_IHTMLISINDEXELEMENT2_FORM: UInt32 = 1012
DISPID_IHTMLNEXTIDELEMENT_N: UInt32 = 1012
DISPID_IHTMLBASEFONTELEMENT_COLOR: UInt32 = 70538
DISPID_IHTMLBASEFONTELEMENT_FACE: UInt32 = 70554
DISPID_IHTMLBASEFONTELEMENT_SIZE: UInt32 = 70562
DISPID_IOMHISTORY_LENGTH: UInt32 = 1
DISPID_IOMHISTORY_BACK: UInt32 = 2
DISPID_IOMHISTORY_FORWARD: UInt32 = 3
DISPID_IOMHISTORY_GO: UInt32 = 4
DISPID_IHTMLOPSPROFILE_ADDREQUEST: UInt32 = 1
DISPID_IHTMLOPSPROFILE_CLEARREQUEST: UInt32 = 2
DISPID_IHTMLOPSPROFILE_DOREQUEST: UInt32 = 3
DISPID_IHTMLOPSPROFILE_GETATTRIBUTE: UInt32 = 4
DISPID_IHTMLOPSPROFILE_SETATTRIBUTE: UInt32 = 5
DISPID_IHTMLOPSPROFILE_COMMITCHANGES: UInt32 = 6
DISPID_IHTMLOPSPROFILE_ADDREADREQUEST: UInt32 = 7
DISPID_IHTMLOPSPROFILE_DOREADREQUEST: UInt32 = 8
DISPID_IHTMLOPSPROFILE_DOWRITEREQUEST: UInt32 = 9
DISPID_IOMNAVIGATOR_APPCODENAME: UInt32 = 1
DISPID_IOMNAVIGATOR_APPNAME: UInt32 = 2
DISPID_IOMNAVIGATOR_APPVERSION: UInt32 = 3
DISPID_IOMNAVIGATOR_USERAGENT: UInt32 = 4
DISPID_IOMNAVIGATOR_JAVAENABLED: UInt32 = 5
DISPID_IOMNAVIGATOR_TAINTENABLED: UInt32 = 6
DISPID_IOMNAVIGATOR_MIMETYPES: UInt32 = 7
DISPID_IOMNAVIGATOR_PLUGINS: UInt32 = 8
DISPID_IOMNAVIGATOR_COOKIEENABLED: UInt32 = 9
DISPID_IOMNAVIGATOR_OPSPROFILE: UInt32 = 10
DISPID_IOMNAVIGATOR_TOSTRING: UInt32 = 11
DISPID_IOMNAVIGATOR_CPUCLASS: UInt32 = 12
DISPID_IOMNAVIGATOR_SYSTEMLANGUAGE: UInt32 = 13
DISPID_IOMNAVIGATOR_BROWSERLANGUAGE: UInt32 = 14
DISPID_IOMNAVIGATOR_USERLANGUAGE: UInt32 = 15
DISPID_IOMNAVIGATOR_PLATFORM: UInt32 = 16
DISPID_IOMNAVIGATOR_APPMINORVERSION: UInt32 = 17
DISPID_IOMNAVIGATOR_CONNECTIONSPEED: UInt32 = 18
DISPID_IOMNAVIGATOR_ONLINE: UInt32 = 19
DISPID_IOMNAVIGATOR_USERPROFILE: UInt32 = 20
DISPID_INAVIGATORGEOLOCATION_GEOLOCATION: UInt32 = 21
DISPID_INAVIGATORDONOTTRACK_MSDONOTTRACK: UInt32 = 22
DISPID_IHTMLLOCATION_HREF: UInt32 = 0
DISPID_IHTMLLOCATION_PROTOCOL: UInt32 = 1
DISPID_IHTMLLOCATION_HOST: UInt32 = 2
DISPID_IHTMLLOCATION_HOSTNAME: UInt32 = 3
DISPID_IHTMLLOCATION_PORT: UInt32 = 4
DISPID_IHTMLLOCATION_PATHNAME: UInt32 = 5
DISPID_IHTMLLOCATION_SEARCH: UInt32 = 6
DISPID_IHTMLLOCATION_HASH: UInt32 = 7
DISPID_IHTMLLOCATION_RELOAD: UInt32 = 8
DISPID_IHTMLLOCATION_REPLACE: UInt32 = 9
DISPID_IHTMLLOCATION_ASSIGN: UInt32 = 10
DISPID_IHTMLLOCATION_TOSTRING: UInt32 = 11
DISPID_IHTMLMIMETYPESCOLLECTION_LENGTH: UInt32 = 1
DISPID_IHTMLPLUGINSCOLLECTION_LENGTH: UInt32 = 1
DISPID_IHTMLPLUGINSCOLLECTION_REFRESH: UInt32 = 2
DISPID_IHTMLBOOKMARKCOLLECTION_LENGTH: UInt32 = 1501
DISPID_IHTMLBOOKMARKCOLLECTION__NEWENUM: Int32 = -4
DISPID_IHTMLBOOKMARKCOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLDATATRANSFER_SETDATA: UInt32 = 1001
DISPID_IHTMLDATATRANSFER_GETDATA: UInt32 = 1002
DISPID_IHTMLDATATRANSFER_CLEARDATA: UInt32 = 1003
DISPID_IHTMLDATATRANSFER_DROPEFFECT: UInt32 = 1004
DISPID_IHTMLDATATRANSFER_EFFECTALLOWED: UInt32 = 1005
DISPID_IHTMLEVENTOBJ_SRCELEMENT: UInt32 = 1001
DISPID_IHTMLEVENTOBJ_ALTKEY: UInt32 = 1002
DISPID_IHTMLEVENTOBJ_CTRLKEY: UInt32 = 1003
DISPID_IHTMLEVENTOBJ_SHIFTKEY: UInt32 = 1004
DISPID_IHTMLEVENTOBJ_RETURNVALUE: UInt32 = 1007
DISPID_IHTMLEVENTOBJ_CANCELBUBBLE: UInt32 = 1008
DISPID_IHTMLEVENTOBJ_FROMELEMENT: UInt32 = 1009
DISPID_IHTMLEVENTOBJ_TOELEMENT: UInt32 = 1010
DISPID_IHTMLEVENTOBJ_KEYCODE: UInt32 = 1011
DISPID_IHTMLEVENTOBJ_BUTTON: UInt32 = 1012
DISPID_IHTMLEVENTOBJ_TYPE: UInt32 = 1013
DISPID_IHTMLEVENTOBJ_QUALIFIER: UInt32 = 1014
DISPID_IHTMLEVENTOBJ_REASON: UInt32 = 1015
DISPID_IHTMLEVENTOBJ_X: UInt32 = 1005
DISPID_IHTMLEVENTOBJ_Y: UInt32 = 1006
DISPID_IHTMLEVENTOBJ_CLIENTX: UInt32 = 1020
DISPID_IHTMLEVENTOBJ_CLIENTY: UInt32 = 1021
DISPID_IHTMLEVENTOBJ_OFFSETX: UInt32 = 1022
DISPID_IHTMLEVENTOBJ_OFFSETY: UInt32 = 1023
DISPID_IHTMLEVENTOBJ_SCREENX: UInt32 = 1024
DISPID_IHTMLEVENTOBJ_SCREENY: UInt32 = 1025
DISPID_IHTMLEVENTOBJ_SRCFILTER: UInt32 = 1026
DISPID_IHTMLEVENTOBJ2_SETATTRIBUTE: UInt32 = 66037
DISPID_IHTMLEVENTOBJ2_GETATTRIBUTE: UInt32 = 66038
DISPID_IHTMLEVENTOBJ2_REMOVEATTRIBUTE: UInt32 = 66039
DISPID_IHTMLEVENTOBJ2_PROPERTYNAME: UInt32 = 1027
DISPID_IHTMLEVENTOBJ2_BOOKMARKS: UInt32 = 1031
DISPID_IHTMLEVENTOBJ2_RECORDSET: UInt32 = 1032
DISPID_IHTMLEVENTOBJ2_DATAFLD: UInt32 = 1033
DISPID_IHTMLEVENTOBJ2_BOUNDELEMENTS: UInt32 = 1034
DISPID_IHTMLEVENTOBJ2_REPEAT: UInt32 = 1035
DISPID_IHTMLEVENTOBJ2_SRCURN: UInt32 = 1036
DISPID_IHTMLEVENTOBJ2_SRCELEMENT: UInt32 = 1001
DISPID_IHTMLEVENTOBJ2_ALTKEY: UInt32 = 1002
DISPID_IHTMLEVENTOBJ2_CTRLKEY: UInt32 = 1003
DISPID_IHTMLEVENTOBJ2_SHIFTKEY: UInt32 = 1004
DISPID_IHTMLEVENTOBJ2_FROMELEMENT: UInt32 = 1009
DISPID_IHTMLEVENTOBJ2_TOELEMENT: UInt32 = 1010
DISPID_IHTMLEVENTOBJ2_BUTTON: UInt32 = 1012
DISPID_IHTMLEVENTOBJ2_TYPE: UInt32 = 1013
DISPID_IHTMLEVENTOBJ2_QUALIFIER: UInt32 = 1014
DISPID_IHTMLEVENTOBJ2_REASON: UInt32 = 1015
DISPID_IHTMLEVENTOBJ2_X: UInt32 = 1005
DISPID_IHTMLEVENTOBJ2_Y: UInt32 = 1006
DISPID_IHTMLEVENTOBJ2_CLIENTX: UInt32 = 1020
DISPID_IHTMLEVENTOBJ2_CLIENTY: UInt32 = 1021
DISPID_IHTMLEVENTOBJ2_OFFSETX: UInt32 = 1022
DISPID_IHTMLEVENTOBJ2_OFFSETY: UInt32 = 1023
DISPID_IHTMLEVENTOBJ2_SCREENX: UInt32 = 1024
DISPID_IHTMLEVENTOBJ2_SCREENY: UInt32 = 1025
DISPID_IHTMLEVENTOBJ2_SRCFILTER: UInt32 = 1026
DISPID_IHTMLEVENTOBJ2_DATATRANSFER: UInt32 = 1037
DISPID_IHTMLEVENTOBJ3_CONTENTOVERFLOW: UInt32 = 1038
DISPID_IHTMLEVENTOBJ3_SHIFTLEFT: UInt32 = 1039
DISPID_IHTMLEVENTOBJ3_ALTLEFT: UInt32 = 1040
DISPID_IHTMLEVENTOBJ3_CTRLLEFT: UInt32 = 1041
DISPID_IHTMLEVENTOBJ3_IMECOMPOSITIONCHANGE: UInt32 = 1042
DISPID_IHTMLEVENTOBJ3_IMENOTIFYCOMMAND: UInt32 = 1043
DISPID_IHTMLEVENTOBJ3_IMENOTIFYDATA: UInt32 = 1044
DISPID_IHTMLEVENTOBJ3_IMEREQUEST: UInt32 = 1046
DISPID_IHTMLEVENTOBJ3_IMEREQUESTDATA: UInt32 = 1047
DISPID_IHTMLEVENTOBJ3_KEYBOARDLAYOUT: UInt32 = 1045
DISPID_IHTMLEVENTOBJ3_BEHAVIORCOOKIE: UInt32 = 1048
DISPID_IHTMLEVENTOBJ3_BEHAVIORPART: UInt32 = 1049
DISPID_IHTMLEVENTOBJ3_NEXTPAGE: UInt32 = 1050
DISPID_IHTMLEVENTOBJ4_WHEELDELTA: UInt32 = 1051
DISPID_IHTMLEVENTOBJ5_URL: UInt32 = 1052
DISPID_IHTMLEVENTOBJ5_DATA: UInt32 = 1054
DISPID_IHTMLEVENTOBJ5_SOURCE: UInt32 = 1055
DISPID_IHTMLEVENTOBJ5_ORIGIN: UInt32 = 1053
DISPID_IHTMLEVENTOBJ5_ISSESSION: UInt32 = 1056
DISPID_IHTMLEVENTOBJ6_ACTIONURL: UInt32 = 1058
DISPID_IHTMLEVENTOBJ6_BUTTONID: UInt32 = 1057
DISPID_IHTMLSTYLEMEDIA_TYPE: UInt32 = 1001
DISPID_IHTMLSTYLEMEDIA_MATCHMEDIUM: UInt32 = 1002
DISPID_IHTMLFRAMESCOLLECTION2_ITEM: UInt32 = 0
DISPID_IHTMLFRAMESCOLLECTION2_LENGTH: UInt32 = 1001
DISPID_IHTMLSCREEN_COLORDEPTH: UInt32 = 1001
DISPID_IHTMLSCREEN_BUFFERDEPTH: UInt32 = 1002
DISPID_IHTMLSCREEN_WIDTH: UInt32 = 1003
DISPID_IHTMLSCREEN_HEIGHT: UInt32 = 1004
DISPID_IHTMLSCREEN_UPDATEINTERVAL: UInt32 = 1005
DISPID_IHTMLSCREEN_AVAILHEIGHT: UInt32 = 1006
DISPID_IHTMLSCREEN_AVAILWIDTH: UInt32 = 1007
DISPID_IHTMLSCREEN_FONTSMOOTHINGENABLED: UInt32 = 1008
DISPID_IHTMLSCREEN2_LOGICALXDPI: UInt32 = 1009
DISPID_IHTMLSCREEN2_LOGICALYDPI: UInt32 = 1010
DISPID_IHTMLSCREEN2_DEVICEXDPI: UInt32 = 1011
DISPID_IHTMLSCREEN2_DEVICEYDPI: UInt32 = 1012
DISPID_IHTMLSCREEN3_SYSTEMXDPI: UInt32 = 1013
DISPID_IHTMLSCREEN3_SYSTEMYDPI: UInt32 = 1014
DISPID_IHTMLSCREEN4_PIXELDEPTH: UInt32 = 1015
DISPID_IHTMLWINDOW2_FRAMES: UInt32 = 1100
DISPID_IHTMLWINDOW2_DEFAULTSTATUS: UInt32 = 1101
DISPID_IHTMLWINDOW2_STATUS: UInt32 = 1102
DISPID_IHTMLWINDOW2_SETTIMEOUT: UInt32 = 1172
DISPID_IHTMLWINDOW2_CLEARTIMEOUT: UInt32 = 1104
DISPID_IHTMLWINDOW2_ALERT: UInt32 = 1105
DISPID_IHTMLWINDOW2_CONFIRM: UInt32 = 1110
DISPID_IHTMLWINDOW2_PROMPT: UInt32 = 1111
DISPID_IHTMLWINDOW2_IMAGE: UInt32 = 1125
DISPID_IHTMLWINDOW2_LOCATION: UInt32 = 14
DISPID_IHTMLWINDOW2_HISTORY: UInt32 = 2
DISPID_IHTMLWINDOW2_CLOSE: UInt32 = 3
DISPID_IHTMLWINDOW2_OPENER: UInt32 = 4
DISPID_IHTMLWINDOW2_NAVIGATOR: UInt32 = 5
DISPID_IHTMLWINDOW2_NAME: UInt32 = 11
DISPID_IHTMLWINDOW2_PARENT: UInt32 = 12
DISPID_IHTMLWINDOW2_OPEN: UInt32 = 13
DISPID_IHTMLWINDOW2_SELF: UInt32 = 20
DISPID_IHTMLWINDOW2_TOP: UInt32 = 21
DISPID_IHTMLWINDOW2_WINDOW: UInt32 = 22
DISPID_IHTMLWINDOW2_NAVIGATE: UInt32 = 25
DISPID_IHTMLWINDOW2_ONFOCUS: UInt32 = 71550
DISPID_IHTMLWINDOW2_ONBLUR: UInt32 = 71551
DISPID_IHTMLWINDOW2_ONLOAD: UInt32 = 71568
DISPID_IHTMLWINDOW2_ONBEFOREUNLOAD: UInt32 = 71575
DISPID_IHTMLWINDOW2_ONUNLOAD: UInt32 = 71569
DISPID_IHTMLWINDOW2_ONHELP: UInt32 = 71549
DISPID_IHTMLWINDOW2_ONERROR: UInt32 = 71565
DISPID_IHTMLWINDOW2_ONRESIZE: UInt32 = 71572
DISPID_IHTMLWINDOW2_ONSCROLL: UInt32 = 71567
DISPID_IHTMLWINDOW2_DOCUMENT: UInt32 = 1151
DISPID_IHTMLWINDOW2_EVENT: UInt32 = 1152
DISPID_IHTMLWINDOW2__NEWENUM: UInt32 = 1153
DISPID_IHTMLWINDOW2_SHOWMODALDIALOG: UInt32 = 1154
DISPID_IHTMLWINDOW2_SHOWHELP: UInt32 = 1155
DISPID_IHTMLWINDOW2_SCREEN: UInt32 = 1156
DISPID_IHTMLWINDOW2_OPTION: UInt32 = 1157
DISPID_IHTMLWINDOW2_FOCUS: UInt32 = 1158
DISPID_IHTMLWINDOW2_CLOSED: UInt32 = 23
DISPID_IHTMLWINDOW2_BLUR: UInt32 = 1159
DISPID_IHTMLWINDOW2_SCROLL: UInt32 = 1160
DISPID_IHTMLWINDOW2_CLIENTINFORMATION: UInt32 = 1161
DISPID_IHTMLWINDOW2_SETINTERVAL: UInt32 = 1173
DISPID_IHTMLWINDOW2_CLEARINTERVAL: UInt32 = 1163
DISPID_IHTMLWINDOW2_OFFSCREENBUFFERING: UInt32 = 1164
DISPID_IHTMLWINDOW2_EXECSCRIPT: UInt32 = 1165
DISPID_IHTMLWINDOW2_TOSTRING: UInt32 = 1166
DISPID_IHTMLWINDOW2_SCROLLBY: UInt32 = 1167
DISPID_IHTMLWINDOW2_SCROLLTO: UInt32 = 1168
DISPID_IHTMLWINDOW2_MOVETO: UInt32 = 6
DISPID_IHTMLWINDOW2_MOVEBY: UInt32 = 7
DISPID_IHTMLWINDOW2_RESIZETO: UInt32 = 9
DISPID_IHTMLWINDOW2_RESIZEBY: UInt32 = 8
DISPID_IHTMLWINDOW2_EXTERNAL: UInt32 = 1169
DISPID_IHTMLWINDOW3_SCREENLEFT: UInt32 = 1170
DISPID_IHTMLWINDOW3_SCREENTOP: UInt32 = 1171
DISPID_IHTMLWINDOW3_ATTACHEVENT: UInt32 = 66043
DISPID_IHTMLWINDOW3_DETACHEVENT: UInt32 = 66044
DISPID_IHTMLWINDOW3_SETTIMEOUT: UInt32 = 1103
DISPID_IHTMLWINDOW3_SETINTERVAL: UInt32 = 1162
DISPID_IHTMLWINDOW3_PRINT: UInt32 = 1174
DISPID_IHTMLWINDOW3_ONBEFOREPRINT: UInt32 = 71602
DISPID_IHTMLWINDOW3_ONAFTERPRINT: UInt32 = 71603
DISPID_IHTMLWINDOW3_CLIPBOARDDATA: UInt32 = 1175
DISPID_IHTMLWINDOW3_SHOWMODELESSDIALOG: UInt32 = 1176
DISPID_IHTMLWINDOW4_CREATEPOPUP: UInt32 = 1180
DISPID_IHTMLWINDOW4_FRAMEELEMENT: UInt32 = 1181
DISPID_IHTMLWINDOW5_XMLHTTPREQUEST: UInt32 = 1190
DISPID_IHTMLWINDOW6_XDOMAINREQUEST: UInt32 = 1191
DISPID_IHTMLWINDOW6_SESSIONSTORAGE: UInt32 = 1192
DISPID_IHTMLWINDOW6_LOCALSTORAGE: UInt32 = 1193
DISPID_IHTMLWINDOW6_ONHASHCHANGE: UInt32 = 71645
DISPID_IHTMLWINDOW6_MAXCONNECTIONSPERSERVER: UInt32 = 1194
DISPID_IHTMLWINDOW6_POSTMESSAGE: UInt32 = 1196
DISPID_IHTMLWINDOW6_TOSTATICHTML: UInt32 = 1197
DISPID_IHTMLWINDOW6_ONMESSAGE: UInt32 = 71646
DISPID_IHTMLWINDOW6_MSWRITEPROFILERMARK: UInt32 = 1198
DISPID_IHTMLWINDOW7_GETSELECTION: UInt32 = 1199
DISPID_IHTMLWINDOW7_GETCOMPUTEDSTYLE: UInt32 = 1200
DISPID_IHTMLWINDOW7_STYLEMEDIA: UInt32 = 1202
DISPID_IHTMLWINDOW7_PERFORMANCE: UInt32 = 1203
DISPID_IHTMLWINDOW7_INNERWIDTH: UInt32 = 1204
DISPID_IHTMLWINDOW7_INNERHEIGHT: UInt32 = 1205
DISPID_IHTMLWINDOW7_PAGEXOFFSET: UInt32 = 1206
DISPID_IHTMLWINDOW7_PAGEYOFFSET: UInt32 = 1207
DISPID_IHTMLWINDOW7_SCREENX: UInt32 = 1208
DISPID_IHTMLWINDOW7_SCREENY: UInt32 = 1209
DISPID_IHTMLWINDOW7_OUTERWIDTH: UInt32 = 1210
DISPID_IHTMLWINDOW7_OUTERHEIGHT: UInt32 = 1211
DISPID_IHTMLWINDOW7_ONABORT: UInt32 = 71564
DISPID_IHTMLWINDOW7_ONCANPLAY: UInt32 = 71670
DISPID_IHTMLWINDOW7_ONCANPLAYTHROUGH: UInt32 = 71671
DISPID_IHTMLWINDOW7_ONCHANGE: UInt32 = 71566
DISPID_IHTMLWINDOW7_ONCLICK: UInt32 = 71544
DISPID_IHTMLWINDOW7_ONCONTEXTMENU: UInt32 = 71601
DISPID_IHTMLWINDOW7_ONDBLCLICK: UInt32 = 71545
DISPID_IHTMLWINDOW7_ONDRAG: UInt32 = 71585
DISPID_IHTMLWINDOW7_ONDRAGEND: UInt32 = 71586
DISPID_IHTMLWINDOW7_ONDRAGENTER: UInt32 = 71587
DISPID_IHTMLWINDOW7_ONDRAGLEAVE: UInt32 = 71589
DISPID_IHTMLWINDOW7_ONDRAGOVER: UInt32 = 71588
DISPID_IHTMLWINDOW7_ONDRAGSTART: UInt32 = 71571
DISPID_IHTMLWINDOW7_ONDROP: UInt32 = 71590
DISPID_IHTMLWINDOW7_ONDURATIONCHANGE: UInt32 = 71672
DISPID_IHTMLWINDOW7_ONFOCUSIN: UInt32 = 71627
DISPID_IHTMLWINDOW7_ONFOCUSOUT: UInt32 = 71628
DISPID_IHTMLWINDOW7_ONINPUT: UInt32 = 71663
DISPID_IHTMLWINDOW7_ONEMPTIED: UInt32 = 71673
DISPID_IHTMLWINDOW7_ONENDED: UInt32 = 71674
DISPID_IHTMLWINDOW7_ONKEYDOWN: UInt32 = 71541
DISPID_IHTMLWINDOW7_ONKEYPRESS: UInt32 = 71543
DISPID_IHTMLWINDOW7_ONKEYUP: UInt32 = 71542
DISPID_IHTMLWINDOW7_ONLOADEDDATA: UInt32 = 71675
DISPID_IHTMLWINDOW7_ONLOADEDMETADATA: UInt32 = 71676
DISPID_IHTMLWINDOW7_ONLOADSTART: UInt32 = 71677
DISPID_IHTMLWINDOW7_ONMOUSEDOWN: UInt32 = 71538
DISPID_IHTMLWINDOW7_ONMOUSEENTER: UInt32 = 71621
DISPID_IHTMLWINDOW7_ONMOUSELEAVE: UInt32 = 71622
DISPID_IHTMLWINDOW7_ONMOUSEMOVE: UInt32 = 71540
DISPID_IHTMLWINDOW7_ONMOUSEOUT: UInt32 = 71537
DISPID_IHTMLWINDOW7_ONMOUSEOVER: UInt32 = 71536
DISPID_IHTMLWINDOW7_ONMOUSEUP: UInt32 = 71539
DISPID_IHTMLWINDOW7_ONMOUSEWHEEL: UInt32 = 71612
DISPID_IHTMLWINDOW7_ONOFFLINE: UInt32 = 71644
DISPID_IHTMLWINDOW7_ONONLINE: UInt32 = 71643
DISPID_IHTMLWINDOW7_ONPROGRESS: UInt32 = 71681
DISPID_IHTMLWINDOW7_ONRATECHANGE: UInt32 = 71682
DISPID_IHTMLWINDOW7_ONREADYSTATECHANGE: UInt32 = 71561
DISPID_IHTMLWINDOW7_ONRESET: UInt32 = 71548
DISPID_IHTMLWINDOW7_ONSEEKED: UInt32 = 71683
DISPID_IHTMLWINDOW7_ONSEEKING: UInt32 = 71684
DISPID_IHTMLWINDOW7_ONSELECT: UInt32 = 71546
DISPID_IHTMLWINDOW7_ONSTALLED: UInt32 = 71685
DISPID_IHTMLWINDOW7_ONSTORAGE: UInt32 = 71636
DISPID_IHTMLWINDOW7_ONSUBMIT: UInt32 = 71547
DISPID_IHTMLWINDOW7_ONSUSPEND: UInt32 = 71686
DISPID_IHTMLWINDOW7_ONTIMEUPDATE: UInt32 = 71687
DISPID_IHTMLWINDOW7_ONPAUSE: UInt32 = 71678
DISPID_IHTMLWINDOW7_ONPLAY: UInt32 = 71679
DISPID_IHTMLWINDOW7_ONPLAYING: UInt32 = 71680
DISPID_IHTMLWINDOW7_ONVOLUMECHANGE: UInt32 = 71688
DISPID_IHTMLWINDOW7_ONWAITING: UInt32 = 71689
DISPID_IHTMLWINDOW8_ONMSPOINTERDOWN: UInt32 = 71690
DISPID_IHTMLWINDOW8_ONMSPOINTERMOVE: UInt32 = 71691
DISPID_IHTMLWINDOW8_ONMSPOINTERUP: UInt32 = 71692
DISPID_IHTMLWINDOW8_ONMSPOINTEROVER: UInt32 = 71693
DISPID_IHTMLWINDOW8_ONMSPOINTEROUT: UInt32 = 71694
DISPID_IHTMLWINDOW8_ONMSPOINTERCANCEL: UInt32 = 71695
DISPID_IHTMLWINDOW8_ONMSPOINTERHOVER: UInt32 = 71696
DISPID_IHTMLWINDOW8_ONMSGESTURESTART: UInt32 = 71699
DISPID_IHTMLWINDOW8_ONMSGESTURECHANGE: UInt32 = 71700
DISPID_IHTMLWINDOW8_ONMSGESTUREEND: UInt32 = 71701
DISPID_IHTMLWINDOW8_ONMSGESTUREHOLD: UInt32 = 71702
DISPID_IHTMLWINDOW8_ONMSGESTURETAP: UInt32 = 71703
DISPID_IHTMLWINDOW8_ONMSGESTUREDOUBLETAP: UInt32 = 71704
DISPID_IHTMLWINDOW8_ONMSINERTIASTART: UInt32 = 71705
DISPID_IHTMLWINDOW8_APPLICATIONCACHE: UInt32 = 1213
DISPID_IHTMLWINDOW8_ONPOPSTATE: UInt32 = 71728
DISPID_HTMLWINDOWEVENTS3_ONHASHCHANGE: UInt32 = 1066
DISPID_HTMLWINDOWEVENTS3_ONMESSAGE: UInt32 = 1067
DISPID_HTMLWINDOWEVENTS2_ONLOAD: UInt32 = 1003
DISPID_HTMLWINDOWEVENTS2_ONUNLOAD: UInt32 = 1008
DISPID_HTMLWINDOWEVENTS2_ONHELP: UInt32 = 65546
DISPID_HTMLWINDOWEVENTS2_ONFOCUS: UInt32 = 65537
DISPID_HTMLWINDOWEVENTS2_ONERROR: UInt32 = 1002
DISPID_HTMLWINDOWEVENTS2_ONRESIZE: UInt32 = 1016
DISPID_HTMLWINDOWEVENTS2_ONSCROLL: UInt32 = 1014
DISPID_HTMLWINDOWEVENTS2_ONBEFOREUNLOAD: UInt32 = 1017
DISPID_HTMLWINDOWEVENTS2_ONBEFOREPRINT: UInt32 = 1024
DISPID_HTMLWINDOWEVENTS2_ONAFTERPRINT: UInt32 = 1025
DISPID_HTMLWINDOWEVENTS_ONLOAD: UInt32 = 1003
DISPID_HTMLWINDOWEVENTS_ONUNLOAD: UInt32 = 1008
DISPID_HTMLWINDOWEVENTS_ONHELP: UInt32 = 65546
DISPID_HTMLWINDOWEVENTS_ONFOCUS: UInt32 = 65537
DISPID_HTMLWINDOWEVENTS_ONERROR: UInt32 = 1002
DISPID_HTMLWINDOWEVENTS_ONRESIZE: UInt32 = 1016
DISPID_HTMLWINDOWEVENTS_ONSCROLL: UInt32 = 1014
DISPID_HTMLWINDOWEVENTS_ONBEFOREUNLOAD: UInt32 = 1017
DISPID_HTMLWINDOWEVENTS_ONBEFOREPRINT: UInt32 = 1024
DISPID_HTMLWINDOWEVENTS_ONAFTERPRINT: UInt32 = 1025
DISPID_IHTMLDOCUMENTCOMPATIBLEINFO_USERAGENT: UInt32 = 1001
DISPID_IHTMLDOCUMENTCOMPATIBLEINFO_VERSION: UInt32 = 1002
DISPID_IHTMLDOCUMENTCOMPATIBLEINFOCOLLECTION_LENGTH: UInt32 = 1001
DISPID_IHTMLDOCUMENTCOMPATIBLEINFOCOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLDOCUMENT_SCRIPT: UInt32 = 1001
DISPID_IHTMLDOCUMENT2_ALL: UInt32 = 1003
DISPID_IHTMLDOCUMENT2_BODY: UInt32 = 1004
DISPID_IHTMLDOCUMENT2_ACTIVEELEMENT: UInt32 = 1005
DISPID_IHTMLDOCUMENT2_IMAGES: UInt32 = 1011
DISPID_IHTMLDOCUMENT2_APPLETS: UInt32 = 1008
DISPID_IHTMLDOCUMENT2_LINKS: UInt32 = 1009
DISPID_IHTMLDOCUMENT2_FORMS: UInt32 = 1010
DISPID_IHTMLDOCUMENT2_ANCHORS: UInt32 = 1007
DISPID_IHTMLDOCUMENT2_TITLE: UInt32 = 1012
DISPID_IHTMLDOCUMENT2_SCRIPTS: UInt32 = 1013
DISPID_IHTMLDOCUMENT2_DESIGNMODE: UInt32 = 1014
DISPID_IHTMLDOCUMENT2_SELECTION: UInt32 = 1017
DISPID_IHTMLDOCUMENT2_READYSTATE: UInt32 = 1018
DISPID_IHTMLDOCUMENT2_FRAMES: UInt32 = 1019
DISPID_IHTMLDOCUMENT2_EMBEDS: UInt32 = 1015
DISPID_IHTMLDOCUMENT2_PLUGINS: UInt32 = 1021
DISPID_IHTMLDOCUMENT2_ALINKCOLOR: UInt32 = 1022
DISPID_IHTMLDOCUMENT2_BGCOLOR: Int32 = -501
DISPID_IHTMLDOCUMENT2_FGCOLOR: UInt32 = 70538
DISPID_IHTMLDOCUMENT2_LINKCOLOR: UInt32 = 1024
DISPID_IHTMLDOCUMENT2_VLINKCOLOR: UInt32 = 1023
DISPID_IHTMLDOCUMENT2_REFERRER: UInt32 = 1027
DISPID_IHTMLDOCUMENT2_LOCATION: UInt32 = 1026
DISPID_IHTMLDOCUMENT2_LASTMODIFIED: UInt32 = 1028
DISPID_IHTMLDOCUMENT2_URL: UInt32 = 1025
DISPID_IHTMLDOCUMENT2_DOMAIN: UInt32 = 1029
DISPID_IHTMLDOCUMENT2_COOKIE: UInt32 = 1030
DISPID_IHTMLDOCUMENT2_EXPANDO: UInt32 = 1031
DISPID_IHTMLDOCUMENT2_CHARSET: UInt32 = 1032
DISPID_IHTMLDOCUMENT2_DEFAULTCHARSET: UInt32 = 1033
DISPID_IHTMLDOCUMENT2_MIMETYPE: UInt32 = 1041
DISPID_IHTMLDOCUMENT2_FILESIZE: UInt32 = 1042
DISPID_IHTMLDOCUMENT2_FILECREATEDDATE: UInt32 = 1043
DISPID_IHTMLDOCUMENT2_FILEMODIFIEDDATE: UInt32 = 1044
DISPID_IHTMLDOCUMENT2_FILEUPDATEDDATE: UInt32 = 1045
DISPID_IHTMLDOCUMENT2_SECURITY: UInt32 = 1046
DISPID_IHTMLDOCUMENT2_PROTOCOL: UInt32 = 1047
DISPID_IHTMLDOCUMENT2_NAMEPROP: UInt32 = 1048
DISPID_IHTMLDOCUMENT2_WRITE: UInt32 = 1054
DISPID_IHTMLDOCUMENT2_WRITELN: UInt32 = 1055
DISPID_IHTMLDOCUMENT2_OPEN: UInt32 = 1056
DISPID_IHTMLDOCUMENT2_CLOSE: UInt32 = 1057
DISPID_IHTMLDOCUMENT2_CLEAR: UInt32 = 1058
DISPID_IHTMLDOCUMENT2_QUERYCOMMANDSUPPORTED: UInt32 = 1059
DISPID_IHTMLDOCUMENT2_QUERYCOMMANDENABLED: UInt32 = 1060
DISPID_IHTMLDOCUMENT2_QUERYCOMMANDSTATE: UInt32 = 1061
DISPID_IHTMLDOCUMENT2_QUERYCOMMANDINDETERM: UInt32 = 1062
DISPID_IHTMLDOCUMENT2_QUERYCOMMANDTEXT: UInt32 = 1063
DISPID_IHTMLDOCUMENT2_QUERYCOMMANDVALUE: UInt32 = 1064
DISPID_IHTMLDOCUMENT2_EXECCOMMAND: UInt32 = 1065
DISPID_IHTMLDOCUMENT2_EXECCOMMANDSHOWHELP: UInt32 = 1066
DISPID_IHTMLDOCUMENT2_CREATEELEMENT: UInt32 = 1067
DISPID_IHTMLDOCUMENT2_ONHELP: UInt32 = 71549
DISPID_IHTMLDOCUMENT2_ONCLICK: UInt32 = 71544
DISPID_IHTMLDOCUMENT2_ONDBLCLICK: UInt32 = 71545
DISPID_IHTMLDOCUMENT2_ONKEYUP: UInt32 = 71542
DISPID_IHTMLDOCUMENT2_ONKEYDOWN: UInt32 = 71541
DISPID_IHTMLDOCUMENT2_ONKEYPRESS: UInt32 = 71543
DISPID_IHTMLDOCUMENT2_ONMOUSEUP: UInt32 = 71539
DISPID_IHTMLDOCUMENT2_ONMOUSEDOWN: UInt32 = 71538
DISPID_IHTMLDOCUMENT2_ONMOUSEMOVE: UInt32 = 71540
DISPID_IHTMLDOCUMENT2_ONMOUSEOUT: UInt32 = 71537
DISPID_IHTMLDOCUMENT2_ONMOUSEOVER: UInt32 = 71536
DISPID_IHTMLDOCUMENT2_ONREADYSTATECHANGE: UInt32 = 71561
DISPID_IHTMLDOCUMENT2_ONAFTERUPDATE: UInt32 = 71558
DISPID_IHTMLDOCUMENT2_ONROWEXIT: UInt32 = 71554
DISPID_IHTMLDOCUMENT2_ONROWENTER: UInt32 = 71555
DISPID_IHTMLDOCUMENT2_ONDRAGSTART: UInt32 = 71571
DISPID_IHTMLDOCUMENT2_ONSELECTSTART: UInt32 = 71573
DISPID_IHTMLDOCUMENT2_ELEMENTFROMPOINT: UInt32 = 1068
DISPID_IHTMLDOCUMENT2_PARENTWINDOW: UInt32 = 1034
DISPID_IHTMLDOCUMENT2_STYLESHEETS: UInt32 = 1069
DISPID_IHTMLDOCUMENT2_ONBEFOREUPDATE: UInt32 = 71557
DISPID_IHTMLDOCUMENT2_ONERRORUPDATE: UInt32 = 71574
DISPID_IHTMLDOCUMENT2_TOSTRING: UInt32 = 1070
DISPID_IHTMLDOCUMENT2_CREATESTYLESHEET: UInt32 = 1071
DISPID_IHTMLDOCUMENT3_RELEASECAPTURE: UInt32 = 1072
DISPID_IHTMLDOCUMENT3_RECALC: UInt32 = 1073
DISPID_IHTMLDOCUMENT3_CREATETEXTNODE: UInt32 = 1074
DISPID_IHTMLDOCUMENT3_DOCUMENTELEMENT: UInt32 = 1075
DISPID_IHTMLDOCUMENT3_UNIQUEID: UInt32 = 1077
DISPID_IHTMLDOCUMENT3_ATTACHEVENT: UInt32 = 66043
DISPID_IHTMLDOCUMENT3_DETACHEVENT: UInt32 = 66044
DISPID_IHTMLDOCUMENT3_ONROWSDELETE: UInt32 = 71598
DISPID_IHTMLDOCUMENT3_ONROWSINSERTED: UInt32 = 71599
DISPID_IHTMLDOCUMENT3_ONCELLCHANGE: UInt32 = 71600
DISPID_IHTMLDOCUMENT3_ONDATASETCHANGED: UInt32 = 71576
DISPID_IHTMLDOCUMENT3_ONDATAAVAILABLE: UInt32 = 71577
DISPID_IHTMLDOCUMENT3_ONDATASETCOMPLETE: UInt32 = 71578
DISPID_IHTMLDOCUMENT3_ONPROPERTYCHANGE: UInt32 = 71583
DISPID_IHTMLDOCUMENT3_DIR: UInt32 = 70653
DISPID_IHTMLDOCUMENT3_ONCONTEXTMENU: UInt32 = 71601
DISPID_IHTMLDOCUMENT3_ONSTOP: UInt32 = 71604
DISPID_IHTMLDOCUMENT3_CREATEDOCUMENTFRAGMENT: UInt32 = 1076
DISPID_IHTMLDOCUMENT3_PARENTDOCUMENT: UInt32 = 1078
DISPID_IHTMLDOCUMENT3_ENABLEDOWNLOAD: UInt32 = 1079
DISPID_IHTMLDOCUMENT3_BASEURL: UInt32 = 1080
DISPID_IHTMLDOCUMENT3_CHILDNODES: UInt32 = 66585
DISPID_IHTMLDOCUMENT3_INHERITSTYLESHEETS: UInt32 = 1082
DISPID_IHTMLDOCUMENT3_ONBEFOREEDITFOCUS: UInt32 = 71605
DISPID_IHTMLDOCUMENT3_GETELEMENTSBYNAME: UInt32 = 1086
DISPID_IHTMLDOCUMENT3_GETELEMENTBYID: UInt32 = 1088
DISPID_IHTMLDOCUMENT3_GETELEMENTSBYTAGNAME: UInt32 = 1087
DISPID_IHTMLDOCUMENT4_FOCUS: UInt32 = 1089
DISPID_IHTMLDOCUMENT4_HASFOCUS: UInt32 = 1090
DISPID_IHTMLDOCUMENT4_ONSELECTIONCHANGE: UInt32 = 71616
DISPID_IHTMLDOCUMENT4_NAMESPACES: UInt32 = 1091
DISPID_IHTMLDOCUMENT4_CREATEDOCUMENTFROMURL: UInt32 = 1092
DISPID_IHTMLDOCUMENT4_MEDIA: UInt32 = 1093
DISPID_IHTMLDOCUMENT4_CREATEEVENTOBJECT: UInt32 = 1094
DISPID_IHTMLDOCUMENT4_FIREEVENT: UInt32 = 1095
DISPID_IHTMLDOCUMENT4_CREATERENDERSTYLE: UInt32 = 1096
DISPID_IHTMLDOCUMENT4_ONCONTROLSELECT: UInt32 = 71615
DISPID_IHTMLDOCUMENT4_URLUNENCODED: UInt32 = 1097
DISPID_IHTMLDOCUMENT5_ONMOUSEWHEEL: UInt32 = 71612
DISPID_IHTMLDOCUMENT5_DOCTYPE: UInt32 = 1098
DISPID_IHTMLDOCUMENT5_IMPLEMENTATION: UInt32 = 1099
DISPID_IHTMLDOCUMENT5_CREATEATTRIBUTE: UInt32 = 1100
DISPID_IHTMLDOCUMENT5_CREATECOMMENT: UInt32 = 1101
DISPID_IHTMLDOCUMENT5_ONFOCUSIN: UInt32 = 71627
DISPID_IHTMLDOCUMENT5_ONFOCUSOUT: UInt32 = 71628
DISPID_IHTMLDOCUMENT5_ONACTIVATE: UInt32 = 71623
DISPID_IHTMLDOCUMENT5_ONDEACTIVATE: UInt32 = 71624
DISPID_IHTMLDOCUMENT5_ONBEFOREACTIVATE: UInt32 = 71626
DISPID_IHTMLDOCUMENT5_ONBEFOREDEACTIVATE: UInt32 = 71613
DISPID_IHTMLDOCUMENT5_COMPATMODE: UInt32 = 1102
DISPID_IHTMLDOCUMENT6_COMPATIBLE: UInt32 = 1103
DISPID_IHTMLDOCUMENT6_DOCUMENTMODE: UInt32 = 1104
DISPID_IHTMLDOCUMENT6_ONSTORAGE: UInt32 = 71636
DISPID_IHTMLDOCUMENT6_ONSTORAGECOMMIT: UInt32 = 71637
DISPID_IHTMLDOCUMENT6_IE8_GETELEMENTBYID: UInt32 = 1107
DISPID_IHTMLDOCUMENT6_UPDATESETTINGS: UInt32 = 1109
DISPID_IHTMLDOCUMENT7_DEFAULTVIEW: UInt32 = 1110
DISPID_IHTMLDOCUMENT7_CREATECDATASECTION: UInt32 = 1123
DISPID_IHTMLDOCUMENT7_GETSELECTION: UInt32 = 1112
DISPID_IHTMLDOCUMENT7_GETELEMENTSBYTAGNAMENS: UInt32 = 1113
DISPID_IHTMLDOCUMENT7_CREATEELEMENTNS: UInt32 = 1114
DISPID_IHTMLDOCUMENT7_CREATEATTRIBUTENS: UInt32 = 1115
DISPID_IHTMLDOCUMENT7_ONMSTHUMBNAILCLICK: UInt32 = 71657
DISPID_IHTMLDOCUMENT7_CHARACTERSET: UInt32 = 1117
DISPID_IHTMLDOCUMENT7_IE9_CREATEELEMENT: UInt32 = 1118
DISPID_IHTMLDOCUMENT7_IE9_CREATEATTRIBUTE: UInt32 = 1119
DISPID_IHTMLDOCUMENT7_GETELEMENTSBYCLASSNAME: UInt32 = 1120
DISPID_IHTMLDOCUMENT7_CREATEPROCESSINGINSTRUCTION: UInt32 = 1124
DISPID_IHTMLDOCUMENT7_ADOPTNODE: UInt32 = 1125
DISPID_IHTMLDOCUMENT7_ONMSSITEMODEJUMPLISTITEMREMOVED: UInt32 = 71666
DISPID_IHTMLDOCUMENT7_IE9_ALL: UInt32 = 1126
DISPID_IHTMLDOCUMENT7_INPUTENCODING: UInt32 = 1127
DISPID_IHTMLDOCUMENT7_XMLENCODING: UInt32 = 1128
DISPID_IHTMLDOCUMENT7_XMLSTANDALONE: UInt32 = 1129
DISPID_IHTMLDOCUMENT7_XMLVERSION: UInt32 = 1130
DISPID_IHTMLDOCUMENT7_HASATTRIBUTES: UInt32 = 1132
DISPID_IHTMLDOCUMENT7_ONABORT: UInt32 = 71564
DISPID_IHTMLDOCUMENT7_ONBLUR: UInt32 = 71551
DISPID_IHTMLDOCUMENT7_ONCANPLAY: UInt32 = 71670
DISPID_IHTMLDOCUMENT7_ONCANPLAYTHROUGH: UInt32 = 71671
DISPID_IHTMLDOCUMENT7_ONCHANGE: UInt32 = 71566
DISPID_IHTMLDOCUMENT7_ONDRAG: UInt32 = 71585
DISPID_IHTMLDOCUMENT7_ONDRAGEND: UInt32 = 71586
DISPID_IHTMLDOCUMENT7_ONDRAGENTER: UInt32 = 71587
DISPID_IHTMLDOCUMENT7_ONDRAGLEAVE: UInt32 = 71589
DISPID_IHTMLDOCUMENT7_ONDRAGOVER: UInt32 = 71588
DISPID_IHTMLDOCUMENT7_ONDROP: UInt32 = 71590
DISPID_IHTMLDOCUMENT7_ONDURATIONCHANGE: UInt32 = 71672
DISPID_IHTMLDOCUMENT7_ONEMPTIED: UInt32 = 71673
DISPID_IHTMLDOCUMENT7_ONENDED: UInt32 = 71674
DISPID_IHTMLDOCUMENT7_ONERROR: UInt32 = 71565
DISPID_IHTMLDOCUMENT7_ONFOCUS: UInt32 = 71550
DISPID_IHTMLDOCUMENT7_ONINPUT: UInt32 = 71663
DISPID_IHTMLDOCUMENT7_ONLOAD: UInt32 = 71568
DISPID_IHTMLDOCUMENT7_ONLOADEDDATA: UInt32 = 71675
DISPID_IHTMLDOCUMENT7_ONLOADEDMETADATA: UInt32 = 71676
DISPID_IHTMLDOCUMENT7_ONLOADSTART: UInt32 = 71677
DISPID_IHTMLDOCUMENT7_ONPAUSE: UInt32 = 71678
DISPID_IHTMLDOCUMENT7_ONPLAY: UInt32 = 71679
DISPID_IHTMLDOCUMENT7_ONPLAYING: UInt32 = 71680
DISPID_IHTMLDOCUMENT7_ONPROGRESS: UInt32 = 71681
DISPID_IHTMLDOCUMENT7_ONRATECHANGE: UInt32 = 71682
DISPID_IHTMLDOCUMENT7_ONRESET: UInt32 = 71548
DISPID_IHTMLDOCUMENT7_ONSCROLL: UInt32 = 71567
DISPID_IHTMLDOCUMENT7_ONSEEKED: UInt32 = 71683
DISPID_IHTMLDOCUMENT7_ONSEEKING: UInt32 = 71684
DISPID_IHTMLDOCUMENT7_ONSELECT: UInt32 = 71546
DISPID_IHTMLDOCUMENT7_ONSTALLED: UInt32 = 71685
DISPID_IHTMLDOCUMENT7_ONSUBMIT: UInt32 = 71547
DISPID_IHTMLDOCUMENT7_ONSUSPEND: UInt32 = 71686
DISPID_IHTMLDOCUMENT7_ONTIMEUPDATE: UInt32 = 71687
DISPID_IHTMLDOCUMENT7_ONVOLUMECHANGE: UInt32 = 71688
DISPID_IHTMLDOCUMENT7_ONWAITING: UInt32 = 71689
DISPID_IHTMLDOCUMENT7_NORMALIZE: UInt32 = 1134
DISPID_IHTMLDOCUMENT7_IMPORTNODE: UInt32 = 1135
DISPID_IHTMLDOCUMENT7_IE9_PARENTWINDOW: UInt32 = 1136
DISPID_IHTMLDOCUMENT7_IE9_BODY: UInt32 = 1137
DISPID_IHTMLDOCUMENT7_HEAD: UInt32 = 1138
DISPID_IHTMLDOCUMENT8_ONMSCONTENTZOOM: UInt32 = 71708
DISPID_IHTMLDOCUMENT8_ONMSPOINTERDOWN: UInt32 = 71690
DISPID_IHTMLDOCUMENT8_ONMSPOINTERMOVE: UInt32 = 71691
DISPID_IHTMLDOCUMENT8_ONMSPOINTERUP: UInt32 = 71692
DISPID_IHTMLDOCUMENT8_ONMSPOINTEROVER: UInt32 = 71693
DISPID_IHTMLDOCUMENT8_ONMSPOINTEROUT: UInt32 = 71694
DISPID_IHTMLDOCUMENT8_ONMSPOINTERCANCEL: UInt32 = 71695
DISPID_IHTMLDOCUMENT8_ONMSPOINTERHOVER: UInt32 = 71696
DISPID_IHTMLDOCUMENT8_ONMSGESTURESTART: UInt32 = 71699
DISPID_IHTMLDOCUMENT8_ONMSGESTURECHANGE: UInt32 = 71700
DISPID_IHTMLDOCUMENT8_ONMSGESTUREEND: UInt32 = 71701
DISPID_IHTMLDOCUMENT8_ONMSGESTUREHOLD: UInt32 = 71702
DISPID_IHTMLDOCUMENT8_ONMSGESTURETAP: UInt32 = 71703
DISPID_IHTMLDOCUMENT8_ONMSGESTUREDOUBLETAP: UInt32 = 71704
DISPID_IHTMLDOCUMENT8_ONMSINERTIASTART: UInt32 = 71705
DISPID_IHTMLDOCUMENT8_ELEMENTSFROMPOINT: UInt32 = 1139
DISPID_IHTMLDOCUMENT8_ELEMENTSFROMRECT: UInt32 = 1140
DISPID_IHTMLDOCUMENT8_ONMSMANIPULATIONSTATECHANGED: UInt32 = 71714
DISPID_IHTMLDOCUMENT8_MSCAPSLOCKWARNINGOFF: UInt32 = 1141
DISPID_IDOCUMENTEVENT_CREATEEVENT: UInt32 = 1108
DISPID_IDOCUMENTRANGE_CREATERANGE: UInt32 = 1111
DISPID_IDOCUMENTSELECTOR_QUERYSELECTOR: UInt32 = 1105
DISPID_IDOCUMENTSELECTOR_QUERYSELECTORALL: UInt32 = 1106
DISPID_IDOCUMENTTRAVERSAL_CREATENODEITERATOR: UInt32 = 1121
DISPID_IDOCUMENTTRAVERSAL_CREATETREEWALKER: UInt32 = 1122
DISPID_HTMLDOCUMENTEVENTS4_ONMSTHUMBNAILCLICK: UInt32 = 71657
DISPID_HTMLDOCUMENTEVENTS4_ONMSSITEMODEJUMPLISTITEMREMOVED: UInt32 = 71666
DISPID_HTMLDOCUMENTEVENTS3_ONSTORAGE: UInt32 = 1057
DISPID_HTMLDOCUMENTEVENTS3_ONSTORAGECOMMIT: UInt32 = 1058
DISPID_HTMLDOCUMENTEVENTS2_ONHELP: UInt32 = 65546
DISPID_HTMLDOCUMENTEVENTS2_ONCLICK: Int32 = -600
DISPID_HTMLDOCUMENTEVENTS2_ONDBLCLICK: Int32 = -601
DISPID_HTMLDOCUMENTEVENTS2_ONKEYDOWN: Int32 = -602
DISPID_HTMLDOCUMENTEVENTS2_ONKEYUP: Int32 = -604
DISPID_HTMLDOCUMENTEVENTS2_ONKEYPRESS: Int32 = -603
DISPID_HTMLDOCUMENTEVENTS2_ONMOUSEDOWN: Int32 = -605
DISPID_HTMLDOCUMENTEVENTS2_ONMOUSEMOVE: Int32 = -606
DISPID_HTMLDOCUMENTEVENTS2_ONMOUSEUP: Int32 = -607
DISPID_HTMLDOCUMENTEVENTS2_ONMOUSEOUT: UInt32 = 65545
DISPID_HTMLDOCUMENTEVENTS2_ONMOUSEOVER: UInt32 = 65544
DISPID_HTMLDOCUMENTEVENTS2_ONREADYSTATECHANGE: Int32 = -609
DISPID_HTMLDOCUMENTEVENTS2_ONBEFOREUPDATE: UInt32 = 65540
DISPID_HTMLDOCUMENTEVENTS2_ONAFTERUPDATE: UInt32 = 65541
DISPID_HTMLDOCUMENTEVENTS2_ONROWEXIT: UInt32 = 65542
DISPID_HTMLDOCUMENTEVENTS2_ONROWENTER: UInt32 = 65543
DISPID_HTMLDOCUMENTEVENTS2_ONDRAGSTART: UInt32 = 65547
DISPID_HTMLDOCUMENTEVENTS2_ONSELECTSTART: UInt32 = 65548
DISPID_HTMLDOCUMENTEVENTS2_ONERRORUPDATE: UInt32 = 65549
DISPID_HTMLDOCUMENTEVENTS2_ONCONTEXTMENU: UInt32 = 1023
DISPID_HTMLDOCUMENTEVENTS2_ONSTOP: UInt32 = 1026
DISPID_HTMLDOCUMENTEVENTS2_ONROWSDELETE: UInt32 = 65568
DISPID_HTMLDOCUMENTEVENTS2_ONROWSINSERTED: UInt32 = 65569
DISPID_HTMLDOCUMENTEVENTS2_ONCELLCHANGE: UInt32 = 65570
DISPID_HTMLDOCUMENTEVENTS2_ONPROPERTYCHANGE: UInt32 = 65555
DISPID_HTMLDOCUMENTEVENTS2_ONDATASETCHANGED: UInt32 = 65550
DISPID_HTMLDOCUMENTEVENTS2_ONDATAAVAILABLE: UInt32 = 65551
DISPID_HTMLDOCUMENTEVENTS2_ONDATASETCOMPLETE: UInt32 = 65552
DISPID_HTMLDOCUMENTEVENTS2_ONBEFOREEDITFOCUS: UInt32 = 1027
DISPID_HTMLDOCUMENTEVENTS2_ONSELECTIONCHANGE: UInt32 = 1037
DISPID_HTMLDOCUMENTEVENTS2_ONCONTROLSELECT: UInt32 = 1036
DISPID_HTMLDOCUMENTEVENTS2_ONMOUSEWHEEL: UInt32 = 1033
DISPID_HTMLDOCUMENTEVENTS2_ONFOCUSIN: UInt32 = 1048
DISPID_HTMLDOCUMENTEVENTS2_ONFOCUSOUT: UInt32 = 1049
DISPID_HTMLDOCUMENTEVENTS2_ONACTIVATE: UInt32 = 1044
DISPID_HTMLDOCUMENTEVENTS2_ONDEACTIVATE: UInt32 = 1045
DISPID_HTMLDOCUMENTEVENTS2_ONBEFOREACTIVATE: UInt32 = 1047
DISPID_HTMLDOCUMENTEVENTS2_ONBEFOREDEACTIVATE: UInt32 = 1034
DISPID_HTMLDOCUMENTEVENTS_ONHELP: UInt32 = 65546
DISPID_HTMLDOCUMENTEVENTS_ONCLICK: Int32 = -600
DISPID_HTMLDOCUMENTEVENTS_ONDBLCLICK: Int32 = -601
DISPID_HTMLDOCUMENTEVENTS_ONKEYDOWN: Int32 = -602
DISPID_HTMLDOCUMENTEVENTS_ONKEYUP: Int32 = -604
DISPID_HTMLDOCUMENTEVENTS_ONKEYPRESS: Int32 = -603
DISPID_HTMLDOCUMENTEVENTS_ONMOUSEDOWN: Int32 = -605
DISPID_HTMLDOCUMENTEVENTS_ONMOUSEMOVE: Int32 = -606
DISPID_HTMLDOCUMENTEVENTS_ONMOUSEUP: Int32 = -607
DISPID_HTMLDOCUMENTEVENTS_ONMOUSEOUT: UInt32 = 65545
DISPID_HTMLDOCUMENTEVENTS_ONMOUSEOVER: UInt32 = 65544
DISPID_HTMLDOCUMENTEVENTS_ONREADYSTATECHANGE: Int32 = -609
DISPID_HTMLDOCUMENTEVENTS_ONBEFOREUPDATE: UInt32 = 65540
DISPID_HTMLDOCUMENTEVENTS_ONAFTERUPDATE: UInt32 = 65541
DISPID_HTMLDOCUMENTEVENTS_ONROWEXIT: UInt32 = 65542
DISPID_HTMLDOCUMENTEVENTS_ONROWENTER: UInt32 = 65543
DISPID_HTMLDOCUMENTEVENTS_ONDRAGSTART: UInt32 = 65547
DISPID_HTMLDOCUMENTEVENTS_ONSELECTSTART: UInt32 = 65548
DISPID_HTMLDOCUMENTEVENTS_ONERRORUPDATE: UInt32 = 65549
DISPID_HTMLDOCUMENTEVENTS_ONCONTEXTMENU: UInt32 = 1023
DISPID_HTMLDOCUMENTEVENTS_ONSTOP: UInt32 = 1026
DISPID_HTMLDOCUMENTEVENTS_ONROWSDELETE: UInt32 = 65568
DISPID_HTMLDOCUMENTEVENTS_ONROWSINSERTED: UInt32 = 65569
DISPID_HTMLDOCUMENTEVENTS_ONCELLCHANGE: UInt32 = 65570
DISPID_HTMLDOCUMENTEVENTS_ONPROPERTYCHANGE: UInt32 = 65555
DISPID_HTMLDOCUMENTEVENTS_ONDATASETCHANGED: UInt32 = 65550
DISPID_HTMLDOCUMENTEVENTS_ONDATAAVAILABLE: UInt32 = 65551
DISPID_HTMLDOCUMENTEVENTS_ONDATASETCOMPLETE: UInt32 = 65552
DISPID_HTMLDOCUMENTEVENTS_ONBEFOREEDITFOCUS: UInt32 = 1027
DISPID_HTMLDOCUMENTEVENTS_ONSELECTIONCHANGE: UInt32 = 1037
DISPID_HTMLDOCUMENTEVENTS_ONCONTROLSELECT: UInt32 = 1036
DISPID_HTMLDOCUMENTEVENTS_ONMOUSEWHEEL: UInt32 = 1033
DISPID_HTMLDOCUMENTEVENTS_ONFOCUSIN: UInt32 = 1048
DISPID_HTMLDOCUMENTEVENTS_ONFOCUSOUT: UInt32 = 1049
DISPID_HTMLDOCUMENTEVENTS_ONACTIVATE: UInt32 = 1044
DISPID_HTMLDOCUMENTEVENTS_ONDEACTIVATE: UInt32 = 1045
DISPID_HTMLDOCUMENTEVENTS_ONBEFOREACTIVATE: UInt32 = 1047
DISPID_HTMLDOCUMENTEVENTS_ONBEFOREDEACTIVATE: UInt32 = 1034
DISPID_IWEBBRIDGE_URL: UInt32 = 1
DISPID_IWEBBRIDGE_SCROLLBAR: UInt32 = 2
DISPID_IWEBBRIDGE_EMBED: UInt32 = 3
DISPID_IWEBBRIDGE_EVENT: UInt32 = 1152
DISPID_IWEBBRIDGE_READYSTATE: Int32 = -525
DISPID_IWEBBRIDGE_ABOUTBOX: Int32 = -552
DISPID_IWBSCRIPTCONTROL_RAISEEVENT: UInt32 = 1
DISPID_IWBSCRIPTCONTROL_BUBBLEEVENT: UInt32 = 2
DISPID_IWBSCRIPTCONTROL_SETCONTEXTMENU: UInt32 = 3
DISPID_IWBSCRIPTCONTROL_SELECTABLECONTENT: UInt32 = 4
DISPID_IWBSCRIPTCONTROL_FROZEN: UInt32 = 5
DISPID_IWBSCRIPTCONTROL_SCROLLBAR: UInt32 = 7
DISPID_IWBSCRIPTCONTROL_VERSION: UInt32 = 8
DISPID_IWBSCRIPTCONTROL_VISIBILITY: UInt32 = 9
DISPID_IWBSCRIPTCONTROL_ONVISIBILITYCHANGE: UInt32 = 10
DISPID_DWEBBRIDGEEVENTS_ONSCRIPTLETEVENT: UInt32 = 1
DISPID_DWEBBRIDGEEVENTS_ONREADYSTATECHANGE: Int32 = -609
DISPID_DWEBBRIDGEEVENTS_ONCLICK: Int32 = -600
DISPID_DWEBBRIDGEEVENTS_ONDBLCLICK: Int32 = -601
DISPID_DWEBBRIDGEEVENTS_ONKEYDOWN: Int32 = -602
DISPID_DWEBBRIDGEEVENTS_ONKEYUP: Int32 = -604
DISPID_DWEBBRIDGEEVENTS_ONKEYPRESS: Int32 = -603
DISPID_DWEBBRIDGEEVENTS_ONMOUSEDOWN: Int32 = -605
DISPID_DWEBBRIDGEEVENTS_ONMOUSEMOVE: Int32 = -606
DISPID_DWEBBRIDGEEVENTS_ONMOUSEUP: Int32 = -607
DISPID_IHTMLEMBEDELEMENT_HIDDEN: UInt32 = 68546
DISPID_IHTMLEMBEDELEMENT_PALETTE: UInt32 = 68540
DISPID_IHTMLEMBEDELEMENT_PLUGINSPAGE: UInt32 = 68541
DISPID_IHTMLEMBEDELEMENT_SRC: UInt32 = 68542
DISPID_IHTMLEMBEDELEMENT_UNITS: UInt32 = 68544
DISPID_IHTMLEMBEDELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLEMBEDELEMENT_WIDTH: UInt32 = 65541
DISPID_IHTMLEMBEDELEMENT_HEIGHT: UInt32 = 65542
DISPID_IHTMLEMBEDELEMENT2_IE8_SRC: UInt32 = 1150
DISPID_IHTMLEMBEDELEMENT2_IE8_PLUGINSPAGE: UInt32 = 1151
DISPID_IHTMLAREASCOLLECTION_LENGTH: UInt32 = 1500
DISPID_IHTMLAREASCOLLECTION__NEWENUM: Int32 = -4
DISPID_IHTMLAREASCOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLAREASCOLLECTION_TAGS: UInt32 = 1502
DISPID_IHTMLAREASCOLLECTION_ADD: UInt32 = 1503
DISPID_IHTMLAREASCOLLECTION_REMOVE: UInt32 = 1504
DISPID_IHTMLAREASCOLLECTION2_URNS: UInt32 = 1505
DISPID_IHTMLAREASCOLLECTION3_NAMEDITEM: UInt32 = 1506
DISPID_IHTMLAREASCOLLECTION4_IE8_LENGTH: UInt32 = 1150
DISPID_IHTMLAREASCOLLECTION4_IE8_ITEM: UInt32 = 1152
DISPID_IHTMLAREASCOLLECTION4_IE8_NAMEDITEM: UInt32 = 1153
DISPID_IHTMLMAPELEMENT_AREAS: UInt32 = 1002
DISPID_IHTMLMAPELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLAREAELEMENT_SHAPE: UInt32 = 1001
DISPID_IHTMLAREAELEMENT_COORDS: UInt32 = 1002
DISPID_IHTMLAREAELEMENT_HREF: UInt32 = 0
DISPID_IHTMLAREAELEMENT_TARGET: UInt32 = 1004
DISPID_IHTMLAREAELEMENT_ALT: UInt32 = 1005
DISPID_IHTMLAREAELEMENT_NOHREF: UInt32 = 1006
DISPID_IHTMLAREAELEMENT_HOST: UInt32 = 1007
DISPID_IHTMLAREAELEMENT_HOSTNAME: UInt32 = 1008
DISPID_IHTMLAREAELEMENT_PATHNAME: UInt32 = 1009
DISPID_IHTMLAREAELEMENT_PORT: UInt32 = 1010
DISPID_IHTMLAREAELEMENT_PROTOCOL: UInt32 = 1011
DISPID_IHTMLAREAELEMENT_SEARCH: UInt32 = 1012
DISPID_IHTMLAREAELEMENT_HASH: UInt32 = 1013
DISPID_IHTMLAREAELEMENT_ONBLUR: UInt32 = 71551
DISPID_IHTMLAREAELEMENT_ONFOCUS: UInt32 = 71550
DISPID_IHTMLAREAELEMENT_TABINDEX: UInt32 = 65551
DISPID_IHTMLAREAELEMENT_FOCUS: UInt32 = 67536
DISPID_IHTMLAREAELEMENT_BLUR: UInt32 = 67538
DISPID_IHTMLAREAELEMENT2_IE8_SHAPE: UInt32 = 1151
DISPID_IHTMLAREAELEMENT2_IE8_COORDS: UInt32 = 1152
DISPID_IHTMLAREAELEMENT2_IE8_HREF: UInt32 = 1153
DISPID_IHTMLTABLECAPTION_ALIGN: UInt32 = 65608
DISPID_IHTMLTABLECAPTION_VALIGN: UInt32 = 70567
DISPID_IHTMLCOMMENTELEMENT_TEXT: UInt32 = 1001
DISPID_IHTMLCOMMENTELEMENT_ATOMIC: UInt32 = 1002
DISPID_IHTMLCOMMENTELEMENT2_DATA: UInt32 = 1003
DISPID_IHTMLCOMMENTELEMENT2_LENGTH: UInt32 = 1004
DISPID_IHTMLCOMMENTELEMENT2_SUBSTRINGDATA: UInt32 = 1005
DISPID_IHTMLCOMMENTELEMENT2_APPENDDATA: UInt32 = 1006
DISPID_IHTMLCOMMENTELEMENT2_INSERTDATA: UInt32 = 1007
DISPID_IHTMLCOMMENTELEMENT2_DELETEDATA: UInt32 = 1008
DISPID_IHTMLCOMMENTELEMENT2_REPLACEDATA: UInt32 = 1009
DISPID_IHTMLCOMMENTELEMENT3_IE9_SUBSTRINGDATA: UInt32 = 1010
DISPID_IHTMLCOMMENTELEMENT3_IE9_INSERTDATA: UInt32 = 1011
DISPID_IHTMLCOMMENTELEMENT3_IE9_DELETEDATA: UInt32 = 1012
DISPID_IHTMLCOMMENTELEMENT3_IE9_REPLACEDATA: UInt32 = 1013
DISPID_IHTMLPHRASEELEMENT2_CITE: UInt32 = 1001
DISPID_IHTMLPHRASEELEMENT2_DATETIME: UInt32 = 1002
DISPID_IHTMLPHRASEELEMENT3_IE8_CITE: UInt32 = 1150
DISPID_IHTMLTABLE_COLS: UInt32 = 1001
DISPID_IHTMLTABLE_BORDER: UInt32 = 1002
DISPID_IHTMLTABLE_FRAME: UInt32 = 1004
DISPID_IHTMLTABLE_RULES: UInt32 = 1003
DISPID_IHTMLTABLE_CELLSPACING: UInt32 = 1005
DISPID_IHTMLTABLE_CELLPADDING: UInt32 = 1006
DISPID_IHTMLTABLE_BACKGROUND: UInt32 = 70537
DISPID_IHTMLTABLE_BGCOLOR: Int32 = -501
DISPID_IHTMLTABLE_BORDERCOLOR: UInt32 = 70564
DISPID_IHTMLTABLE_BORDERCOLORLIGHT: UInt32 = 70565
DISPID_IHTMLTABLE_BORDERCOLORDARK: UInt32 = 70566
DISPID_IHTMLTABLE_ALIGN: UInt32 = 65609
DISPID_IHTMLTABLE_REFRESH: UInt32 = 1015
DISPID_IHTMLTABLE_ROWS: UInt32 = 1016
DISPID_IHTMLTABLE_WIDTH: UInt32 = 65541
DISPID_IHTMLTABLE_HEIGHT: UInt32 = 65542
DISPID_IHTMLTABLE_DATAPAGESIZE: UInt32 = 1017
DISPID_IHTMLTABLE_NEXTPAGE: UInt32 = 1018
DISPID_IHTMLTABLE_PREVIOUSPAGE: UInt32 = 1019
DISPID_IHTMLTABLE_THEAD: UInt32 = 1020
DISPID_IHTMLTABLE_TFOOT: UInt32 = 1021
DISPID_IHTMLTABLE_TBODIES: UInt32 = 1024
DISPID_IHTMLTABLE_CAPTION: UInt32 = 1025
DISPID_IHTMLTABLE_CREATETHEAD: UInt32 = 1026
DISPID_IHTMLTABLE_DELETETHEAD: UInt32 = 1027
DISPID_IHTMLTABLE_CREATETFOOT: UInt32 = 1028
DISPID_IHTMLTABLE_DELETETFOOT: UInt32 = 1029
DISPID_IHTMLTABLE_CREATECAPTION: UInt32 = 1030
DISPID_IHTMLTABLE_DELETECAPTION: UInt32 = 1031
DISPID_IHTMLTABLE_INSERTROW: UInt32 = 1032
DISPID_IHTMLTABLE_DELETEROW: UInt32 = 1033
DISPID_IHTMLTABLE_READYSTATE: UInt32 = 70652
DISPID_IHTMLTABLE_ONREADYSTATECHANGE: UInt32 = 71561
DISPID_IHTMLTABLE2_FIRSTPAGE: UInt32 = 1035
DISPID_IHTMLTABLE2_LASTPAGE: UInt32 = 1036
DISPID_IHTMLTABLE2_CELLS: UInt32 = 1037
DISPID_IHTMLTABLE2_MOVEROW: UInt32 = 1038
DISPID_IHTMLTABLE3_SUMMARY: UInt32 = 1039
DISPID_IHTMLTABLE4_IE9_THEAD: UInt32 = 1040
DISPID_IHTMLTABLE4_IE9_TFOOT: UInt32 = 1041
DISPID_IHTMLTABLE4_IE9_CAPTION: UInt32 = 1042
DISPID_IHTMLTABLE4_IE9_INSERTROW: UInt32 = 1043
DISPID_IHTMLTABLE4_IE9_DELETEROW: UInt32 = 1044
DISPID_IHTMLTABLE4_CREATETBODY: UInt32 = 1045
DISPID_IHTMLTABLECOL_SPAN: UInt32 = 1001
DISPID_IHTMLTABLECOL_WIDTH: UInt32 = 65541
DISPID_IHTMLTABLECOL_ALIGN: UInt32 = 65608
DISPID_IHTMLTABLECOL_VALIGN: UInt32 = 70567
DISPID_IHTMLTABLECOL2_CH: UInt32 = 1002
DISPID_IHTMLTABLECOL2_CHOFF: UInt32 = 1003
DISPID_IHTMLTABLECOL3_IE9_CH: UInt32 = 1004
DISPID_IHTMLTABLECOL3_IE9_CHOFF: UInt32 = 1005
DISPID_IHTMLTABLESECTION_ALIGN: UInt32 = 65608
DISPID_IHTMLTABLESECTION_VALIGN: UInt32 = 70567
DISPID_IHTMLTABLESECTION_BGCOLOR: Int32 = -501
DISPID_IHTMLTABLESECTION_ROWS: UInt32 = 1000
DISPID_IHTMLTABLESECTION_INSERTROW: UInt32 = 1001
DISPID_IHTMLTABLESECTION_DELETEROW: UInt32 = 1002
DISPID_IHTMLTABLESECTION2_MOVEROW: UInt32 = 1003
DISPID_IHTMLTABLESECTION3_CH: UInt32 = 1004
DISPID_IHTMLTABLESECTION3_CHOFF: UInt32 = 1005
DISPID_IHTMLTABLESECTION4_IE9_CH: UInt32 = 1006
DISPID_IHTMLTABLESECTION4_IE9_CHOFF: UInt32 = 1007
DISPID_IHTMLTABLESECTION4_IE9_INSERTROW: UInt32 = 1008
DISPID_IHTMLTABLESECTION4_IE9_DELETEROW: UInt32 = 1009
DISPID_IHTMLTABLEROW_ALIGN: UInt32 = 65608
DISPID_IHTMLTABLEROW_VALIGN: UInt32 = 70567
DISPID_IHTMLTABLEROW_BGCOLOR: Int32 = -501
DISPID_IHTMLTABLEROW_BORDERCOLOR: UInt32 = 70564
DISPID_IHTMLTABLEROW_BORDERCOLORLIGHT: UInt32 = 70565
DISPID_IHTMLTABLEROW_BORDERCOLORDARK: UInt32 = 70566
DISPID_IHTMLTABLEROW_ROWINDEX: UInt32 = 1000
DISPID_IHTMLTABLEROW_SECTIONROWINDEX: UInt32 = 1001
DISPID_IHTMLTABLEROW_CELLS: UInt32 = 1002
DISPID_IHTMLTABLEROW_INSERTCELL: UInt32 = 1003
DISPID_IHTMLTABLEROW_DELETECELL: UInt32 = 1004
DISPID_IHTMLTABLEROW2_HEIGHT: UInt32 = 65542
DISPID_IHTMLTABLEROW3_CH: UInt32 = 1009
DISPID_IHTMLTABLEROW3_CHOFF: UInt32 = 1010
DISPID_IHTMLTABLEROW4_IE9_CH: UInt32 = 1011
DISPID_IHTMLTABLEROW4_IE9_CHOFF: UInt32 = 1012
DISPID_IHTMLTABLEROW4_IE9_INSERTCELL: UInt32 = 1013
DISPID_IHTMLTABLEROW4_IE9_DELETECELL: UInt32 = 1014
DISPID_IHTMLTABLEROWMETRICS_CLIENTHEIGHT: UInt32 = 67555
DISPID_IHTMLTABLEROWMETRICS_CLIENTWIDTH: UInt32 = 67556
DISPID_IHTMLTABLEROWMETRICS_CLIENTTOP: UInt32 = 67557
DISPID_IHTMLTABLEROWMETRICS_CLIENTLEFT: UInt32 = 67558
DISPID_IHTMLTABLECELL_ROWSPAN: UInt32 = 2001
DISPID_IHTMLTABLECELL_COLSPAN: UInt32 = 2002
DISPID_IHTMLTABLECELL_ALIGN: UInt32 = 65608
DISPID_IHTMLTABLECELL_VALIGN: UInt32 = 70567
DISPID_IHTMLTABLECELL_BGCOLOR: Int32 = -501
DISPID_IHTMLTABLECELL_NOWRAP: UInt32 = 70541
DISPID_IHTMLTABLECELL_BACKGROUND: UInt32 = 70537
DISPID_IHTMLTABLECELL_BORDERCOLOR: UInt32 = 70564
DISPID_IHTMLTABLECELL_BORDERCOLORLIGHT: UInt32 = 70565
DISPID_IHTMLTABLECELL_BORDERCOLORDARK: UInt32 = 70566
DISPID_IHTMLTABLECELL_WIDTH: UInt32 = 65541
DISPID_IHTMLTABLECELL_HEIGHT: UInt32 = 65542
DISPID_IHTMLTABLECELL_CELLINDEX: UInt32 = 2003
DISPID_IHTMLTABLECELL2_ABBR: UInt32 = 2004
DISPID_IHTMLTABLECELL2_AXIS: UInt32 = 2005
DISPID_IHTMLTABLECELL2_CH: UInt32 = 2006
DISPID_IHTMLTABLECELL2_CHOFF: UInt32 = 2007
DISPID_IHTMLTABLECELL2_HEADERS: UInt32 = 2008
DISPID_IHTMLTABLECELL2_SCOPE: UInt32 = 2009
DISPID_IHTMLTABLECELL3_IE9_CH: UInt32 = 2010
DISPID_IHTMLTABLECELL3_IE9_CHOFF: UInt32 = 2011
DISPID_IHTMLSCRIPTELEMENT_SRC: UInt32 = 1001
DISPID_IHTMLSCRIPTELEMENT_HTMLFOR: UInt32 = 1004
DISPID_IHTMLSCRIPTELEMENT_EVENT: UInt32 = 1005
DISPID_IHTMLSCRIPTELEMENT_TEXT: UInt32 = 1006
DISPID_IHTMLSCRIPTELEMENT_DEFER: UInt32 = 1007
DISPID_IHTMLSCRIPTELEMENT_READYSTATE: UInt32 = 70652
DISPID_IHTMLSCRIPTELEMENT_ONERROR: UInt32 = 71565
DISPID_IHTMLSCRIPTELEMENT_TYPE: UInt32 = 1009
DISPID_IHTMLSCRIPTELEMENT2_CHARSET: UInt32 = 1010
DISPID_IHTMLSCRIPTELEMENT3_IE8_SRC: UInt32 = 1150
DISPID_IHTMLSCRIPTELEMENT4_USEDCHARSET: UInt32 = 1011
DISPID_HTMLSCRIPTEVENTS2_ONERROR: UInt32 = 1002
DISPID_HTMLSCRIPTEVENTS_ONERROR: UInt32 = 1002
DISPID_IHTMLOBJECTELEMENT_OBJECT: UInt32 = 68537
DISPID_IHTMLOBJECTELEMENT_CLASSID: UInt32 = 68538
DISPID_IHTMLOBJECTELEMENT_DATA: UInt32 = 68539
DISPID_IHTMLOBJECTELEMENT_RECORDSET: UInt32 = 68541
DISPID_IHTMLOBJECTELEMENT_ALIGN: UInt32 = 65609
DISPID_IHTMLOBJECTELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLOBJECTELEMENT_CODEBASE: UInt32 = 68542
DISPID_IHTMLOBJECTELEMENT_CODETYPE: UInt32 = 68543
DISPID_IHTMLOBJECTELEMENT_CODE: UInt32 = 68544
DISPID_IHTMLOBJECTELEMENT_BASEHREF: UInt32 = 65538
DISPID_IHTMLOBJECTELEMENT_TYPE: UInt32 = 68545
DISPID_IHTMLOBJECTELEMENT_FORM: UInt32 = 67540
DISPID_IHTMLOBJECTELEMENT_WIDTH: UInt32 = 65541
DISPID_IHTMLOBJECTELEMENT_HEIGHT: UInt32 = 65542
DISPID_IHTMLOBJECTELEMENT_READYSTATE: UInt32 = 68546
DISPID_IHTMLOBJECTELEMENT_ONREADYSTATECHANGE: UInt32 = 71561
DISPID_IHTMLOBJECTELEMENT_ONERROR: UInt32 = 71565
DISPID_IHTMLOBJECTELEMENT_ALTHTML: UInt32 = 68547
DISPID_IHTMLOBJECTELEMENT_VSPACE: UInt32 = 68548
DISPID_IHTMLOBJECTELEMENT_HSPACE: UInt32 = 68549
DISPID_IHTMLOBJECTELEMENT2_NAMEDRECORDSET: UInt32 = 68550
DISPID_IHTMLOBJECTELEMENT2_CLASSID: UInt32 = 68538
DISPID_IHTMLOBJECTELEMENT2_DATA: UInt32 = 68539
DISPID_IHTMLOBJECTELEMENT3_ARCHIVE: UInt32 = 68551
DISPID_IHTMLOBJECTELEMENT3_ALT: UInt32 = 68552
DISPID_IHTMLOBJECTELEMENT3_DECLARE: UInt32 = 68553
DISPID_IHTMLOBJECTELEMENT3_STANDBY: UInt32 = 68554
DISPID_IHTMLOBJECTELEMENT3_BORDER: UInt32 = 68555
DISPID_IHTMLOBJECTELEMENT3_USEMAP: UInt32 = 68556
DISPID_IHTMLOBJECTELEMENT4_CONTENTDOCUMENT: UInt32 = 68566
DISPID_IHTMLOBJECTELEMENT4_IE8_CODEBASE: UInt32 = 68567
DISPID_IHTMLOBJECTELEMENT4_IE8_DATA: UInt32 = 68568
DISPID_IHTMLOBJECTELEMENT5_IE9_OBJECT: UInt32 = 68569
DISPID_IHTMLPARAMELEMENT_NAME: UInt32 = 1001
DISPID_IHTMLPARAMELEMENT_VALUE: UInt32 = 1002
DISPID_IHTMLPARAMELEMENT_TYPE: UInt32 = 1003
DISPID_IHTMLPARAMELEMENT_VALUETYPE: UInt32 = 1004
DISPID_IHTMLPARAMELEMENT2_NAME: UInt32 = 1001
DISPID_IHTMLPARAMELEMENT2_TYPE: UInt32 = 1003
DISPID_IHTMLPARAMELEMENT2_VALUE: UInt32 = 1002
DISPID_IHTMLPARAMELEMENT2_IE8_VALUETYPE: UInt32 = 1150
DISPID_HTMLOBJECTELEMENTEVENTS2_ONBEFOREUPDATE: UInt32 = 65540
DISPID_HTMLOBJECTELEMENTEVENTS2_ONAFTERUPDATE: UInt32 = 65541
DISPID_HTMLOBJECTELEMENTEVENTS2_ONERRORUPDATE: UInt32 = 65549
DISPID_HTMLOBJECTELEMENTEVENTS2_ONROWEXIT: UInt32 = 65542
DISPID_HTMLOBJECTELEMENTEVENTS2_ONROWENTER: UInt32 = 65543
DISPID_HTMLOBJECTELEMENTEVENTS2_ONDATASETCHANGED: UInt32 = 65550
DISPID_HTMLOBJECTELEMENTEVENTS2_ONDATAAVAILABLE: UInt32 = 65551
DISPID_HTMLOBJECTELEMENTEVENTS2_ONDATASETCOMPLETE: UInt32 = 65552
DISPID_HTMLOBJECTELEMENTEVENTS2_ONERROR: UInt32 = 65555
DISPID_HTMLOBJECTELEMENTEVENTS2_ONROWSDELETE: UInt32 = 65568
DISPID_HTMLOBJECTELEMENTEVENTS2_ONROWSINSERTED: UInt32 = 65569
DISPID_HTMLOBJECTELEMENTEVENTS2_ONCELLCHANGE: UInt32 = 65570
DISPID_HTMLOBJECTELEMENTEVENTS2_ONREADYSTATECHANGE: UInt32 = 65556
DISPID_HTMLOBJECTELEMENTEVENTS_ONBEFOREUPDATE: UInt32 = 65540
DISPID_HTMLOBJECTELEMENTEVENTS_ONAFTERUPDATE: UInt32 = 65541
DISPID_HTMLOBJECTELEMENTEVENTS_ONERRORUPDATE: UInt32 = 65549
DISPID_HTMLOBJECTELEMENTEVENTS_ONROWEXIT: UInt32 = 65542
DISPID_HTMLOBJECTELEMENTEVENTS_ONROWENTER: UInt32 = 65543
DISPID_HTMLOBJECTELEMENTEVENTS_ONDATASETCHANGED: UInt32 = 65550
DISPID_HTMLOBJECTELEMENTEVENTS_ONDATAAVAILABLE: UInt32 = 65551
DISPID_HTMLOBJECTELEMENTEVENTS_ONDATASETCOMPLETE: UInt32 = 65552
DISPID_HTMLOBJECTELEMENTEVENTS_ONERROR: UInt32 = 65555
DISPID_HTMLOBJECTELEMENTEVENTS_ONROWSDELETE: UInt32 = 65568
DISPID_HTMLOBJECTELEMENTEVENTS_ONROWSINSERTED: UInt32 = 65569
DISPID_HTMLOBJECTELEMENTEVENTS_ONCELLCHANGE: UInt32 = 65570
DISPID_HTMLOBJECTELEMENTEVENTS_ONREADYSTATECHANGE: UInt32 = 65556
DISPID_IHTMLFRAMEBASE_SRC: UInt32 = 68536
DISPID_IHTMLFRAMEBASE_NAME: UInt32 = 65536
DISPID_IHTMLFRAMEBASE_BORDER: UInt32 = 68538
DISPID_IHTMLFRAMEBASE_FRAMEBORDER: UInt32 = 68539
DISPID_IHTMLFRAMEBASE_FRAMESPACING: UInt32 = 68540
DISPID_IHTMLFRAMEBASE_MARGINWIDTH: UInt32 = 68541
DISPID_IHTMLFRAMEBASE_MARGINHEIGHT: UInt32 = 68542
DISPID_IHTMLFRAMEBASE_NORESIZE: UInt32 = 68543
DISPID_IHTMLFRAMEBASE_SCROLLING: UInt32 = 68544
DISPID_IHTMLFRAMEBASE2_CONTENTWINDOW: UInt32 = 68545
DISPID_IHTMLFRAMEBASE2_ONLOAD: UInt32 = 71568
DISPID_IHTMLFRAMEBASE2_ONREADYSTATECHANGE: UInt32 = 71561
DISPID_IHTMLFRAMEBASE2_READYSTATE: UInt32 = 70652
DISPID_IHTMLFRAMEBASE2_ALLOWTRANSPARENCY: UInt32 = 70742
DISPID_IHTMLFRAMEBASE3_LONGDESC: UInt32 = 68546
DISPID_HTMLFRAMESITEEVENTS2_ONLOAD: UInt32 = 1003
DISPID_HTMLFRAMESITEEVENTS_ONLOAD: UInt32 = 1003
DISPID_IHTMLFRAMEELEMENT_BORDERCOLOR: UInt32 = 69537
DISPID_IHTMLFRAMEELEMENT2_HEIGHT: UInt32 = 65542
DISPID_IHTMLFRAMEELEMENT2_WIDTH: UInt32 = 65541
DISPID_IHTMLFRAMEELEMENT3_CONTENTDOCUMENT: UInt32 = 69656
DISPID_IHTMLFRAMEELEMENT3_IE8_SRC: UInt32 = 69657
DISPID_IHTMLFRAMEELEMENT3_IE8_LONGDESC: UInt32 = 69658
DISPID_IHTMLFRAMEELEMENT3_IE8_FRAMEBORDER: UInt32 = 69659
DISPID_IHTMLIFRAMEELEMENT_VSPACE: UInt32 = 69537
DISPID_IHTMLIFRAMEELEMENT_HSPACE: UInt32 = 69538
DISPID_IHTMLIFRAMEELEMENT_ALIGN: UInt32 = 65609
DISPID_IHTMLIFRAMEELEMENT2_HEIGHT: UInt32 = 65542
DISPID_IHTMLIFRAMEELEMENT2_WIDTH: UInt32 = 65541
DISPID_IHTMLIFRAMEELEMENT3_CONTENTDOCUMENT: UInt32 = 69656
DISPID_IHTMLIFRAMEELEMENT3_IE8_SRC: UInt32 = 69657
DISPID_IHTMLIFRAMEELEMENT3_IE8_LONGDESC: UInt32 = 69658
DISPID_IHTMLIFRAMEELEMENT3_IE8_FRAMEBORDER: UInt32 = 69659
DISPID_IHTMLDIVPOSITION_ALIGN: UInt32 = 65609
DISPID_IHTMLFIELDSETELEMENT_ALIGN: UInt32 = 65609
DISPID_IHTMLFIELDSETELEMENT2_FORM: UInt32 = 67540
DISPID_IHTMLLEGENDELEMENT_ALIGN: UInt32 = 65609
DISPID_IHTMLLEGENDELEMENT2_FORM: UInt32 = 67540
DISPID_IHTMLSPANFLOW_ALIGN: UInt32 = 65609
DISPID_IHTMLFRAMESETELEMENT_ROWS: UInt32 = 1000
DISPID_IHTMLFRAMESETELEMENT_COLS: UInt32 = 1001
DISPID_IHTMLFRAMESETELEMENT_BORDER: UInt32 = 1002
DISPID_IHTMLFRAMESETELEMENT_BORDERCOLOR: UInt32 = 1003
DISPID_IHTMLFRAMESETELEMENT_FRAMEBORDER: UInt32 = 1004
DISPID_IHTMLFRAMESETELEMENT_FRAMESPACING: UInt32 = 1005
DISPID_IHTMLFRAMESETELEMENT_NAME: UInt32 = 65536
DISPID_IHTMLFRAMESETELEMENT_ONLOAD: UInt32 = 71568
DISPID_IHTMLFRAMESETELEMENT_ONUNLOAD: UInt32 = 71569
DISPID_IHTMLFRAMESETELEMENT_ONBEFOREUNLOAD: UInt32 = 71575
DISPID_IHTMLFRAMESETELEMENT2_ONBEFOREPRINT: UInt32 = 71602
DISPID_IHTMLFRAMESETELEMENT2_ONAFTERPRINT: UInt32 = 71603
DISPID_IHTMLFRAMESETELEMENT3_ONHASHCHANGE: UInt32 = 71645
DISPID_IHTMLFRAMESETELEMENT3_ONMESSAGE: UInt32 = 71646
DISPID_IHTMLFRAMESETELEMENT3_ONOFFLINE: UInt32 = 71644
DISPID_IHTMLFRAMESETELEMENT3_ONONLINE: UInt32 = 71643
DISPID_IHTMLFRAMESETELEMENT3_ONSTORAGE: UInt32 = 71636
DISPID_IHTMLBGSOUND_SRC: UInt32 = 1001
DISPID_IHTMLBGSOUND_LOOP: UInt32 = 1002
DISPID_IHTMLBGSOUND_VOLUME: UInt32 = 1003
DISPID_IHTMLBGSOUND_BALANCE: UInt32 = 1004
DISPID_IHTMLFONTNAMESCOLLECTION_LENGTH: UInt32 = 1501
DISPID_IHTMLFONTNAMESCOLLECTION__NEWENUM: Int32 = -4
DISPID_IHTMLFONTNAMESCOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLFONTSIZESCOLLECTION_LENGTH: UInt32 = 1502
DISPID_IHTMLFONTSIZESCOLLECTION__NEWENUM: Int32 = -4
DISPID_IHTMLFONTSIZESCOLLECTION_FORFONT: UInt32 = 1503
DISPID_IHTMLFONTSIZESCOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLOPTIONSHOLDER_DOCUMENT: UInt32 = 1503
DISPID_IHTMLOPTIONSHOLDER_FONTS: UInt32 = 1504
DISPID_IHTMLOPTIONSHOLDER_EXECARG: UInt32 = 1505
DISPID_IHTMLOPTIONSHOLDER_ERRORLINE: UInt32 = 1506
DISPID_IHTMLOPTIONSHOLDER_ERRORCHARACTER: UInt32 = 1507
DISPID_IHTMLOPTIONSHOLDER_ERRORCODE: UInt32 = 1508
DISPID_IHTMLOPTIONSHOLDER_ERRORMESSAGE: UInt32 = 1509
DISPID_IHTMLOPTIONSHOLDER_ERRORDEBUG: UInt32 = 1510
DISPID_IHTMLOPTIONSHOLDER_UNSECUREDWINDOWOFDOCUMENT: UInt32 = 1511
DISPID_IHTMLOPTIONSHOLDER_FINDTEXT: UInt32 = 1512
DISPID_IHTMLOPTIONSHOLDER_ANYTHINGAFTERFRAMESET: UInt32 = 1513
DISPID_IHTMLOPTIONSHOLDER_SIZES: UInt32 = 1514
DISPID_IHTMLOPTIONSHOLDER_OPENFILEDLG: UInt32 = 1515
DISPID_IHTMLOPTIONSHOLDER_SAVEFILEDLG: UInt32 = 1516
DISPID_IHTMLOPTIONSHOLDER_CHOOSECOLORDLG: UInt32 = 1517
DISPID_IHTMLOPTIONSHOLDER_SHOWSECURITYINFO: UInt32 = 1518
DISPID_IHTMLOPTIONSHOLDER_ISAPARTMENTMODEL: UInt32 = 1519
DISPID_IHTMLOPTIONSHOLDER_GETCHARSET: UInt32 = 1520
DISPID_IHTMLOPTIONSHOLDER_SECURECONNECTIONINFO: UInt32 = 1521
DISPID_IHTMLSTYLEELEMENT_TYPE: UInt32 = 1002
DISPID_IHTMLSTYLEELEMENT_READYSTATE: UInt32 = 70652
DISPID_IHTMLSTYLEELEMENT_ONREADYSTATECHANGE: UInt32 = 71561
DISPID_IHTMLSTYLEELEMENT_ONLOAD: UInt32 = 71568
DISPID_IHTMLSTYLEELEMENT_ONERROR: UInt32 = 71565
DISPID_IHTMLSTYLEELEMENT_STYLESHEET: UInt32 = 1004
DISPID_IHTMLSTYLEELEMENT_DISABLED: UInt32 = 65612
DISPID_IHTMLSTYLEELEMENT_MEDIA: UInt32 = 1006
DISPID_IHTMLSTYLEELEMENT2_SHEET: UInt32 = 1007
DISPID_HTMLSTYLEELEMENTEVENTS2_ONLOAD: UInt32 = 1003
DISPID_HTMLSTYLEELEMENTEVENTS2_ONERROR: UInt32 = 1002
DISPID_HTMLSTYLEELEMENTEVENTS_ONLOAD: UInt32 = 1003
DISPID_HTMLSTYLEELEMENTEVENTS_ONERROR: UInt32 = 1002
DISPID_IHTMLSTYLEFONTFACE_FONTSRC: UInt32 = 70633
DISPID_IHTMLSTYLEFONTFACE2_STYLE: UInt32 = 65610
DISPID_IHTMLXDOMAINREQUEST_RESPONSETEXT: UInt32 = 1003
DISPID_IHTMLXDOMAINREQUEST_TIMEOUT: UInt32 = 1004
DISPID_IHTMLXDOMAINREQUEST_CONTENTTYPE: UInt32 = 1005
DISPID_IHTMLXDOMAINREQUEST_ONPROGRESS: UInt32 = 1006
DISPID_IHTMLXDOMAINREQUEST_ONERROR: UInt32 = 71565
DISPID_IHTMLXDOMAINREQUEST_ONTIMEOUT: UInt32 = 71648
DISPID_IHTMLXDOMAINREQUEST_ONLOAD: UInt32 = 71568
DISPID_IHTMLXDOMAINREQUEST_ABORT: UInt32 = 1010
DISPID_IHTMLXDOMAINREQUEST_OPEN: UInt32 = 1011
DISPID_IHTMLXDOMAINREQUEST_SEND: UInt32 = 1012
DISPID_IHTMLXDOMAINREQUESTFACTORY_CREATE: UInt32 = 0
DISPID_IHTMLSTORAGE_LENGTH: UInt32 = 1001
DISPID_IHTMLSTORAGE_REMAININGSPACE: UInt32 = 1002
DISPID_IHTMLSTORAGE_KEY: UInt32 = 1006
DISPID_IHTMLSTORAGE_GETITEM: UInt32 = 1003
DISPID_IHTMLSTORAGE_SETITEM: UInt32 = 1004
DISPID_IHTMLSTORAGE_REMOVEITEM: UInt32 = 1005
DISPID_IHTMLSTORAGE_CLEAR: UInt32 = 1007
DISPID_IHTMLSTORAGE2_IE9_SETITEM: UInt32 = 1008
DISPID_IEVENTTARGET_ADDEVENTLISTENER: UInt32 = 66046
DISPID_IEVENTTARGET_REMOVEEVENTLISTENER: UInt32 = 66047
DISPID_IEVENTTARGET_DISPATCHEVENT: UInt32 = 66048
DISPID_IDOMEVENT_BUBBLES: UInt32 = 1001
DISPID_IDOMEVENT_CANCELABLE: UInt32 = 1002
DISPID_IDOMEVENT_CURRENTTARGET: UInt32 = 1003
DISPID_IDOMEVENT_DEFAULTPREVENTED: UInt32 = 1004
DISPID_IDOMEVENT_EVENTPHASE: UInt32 = 1005
DISPID_IDOMEVENT_TARGET: UInt32 = 1006
DISPID_IDOMEVENT_TIMESTAMP: UInt32 = 1007
DISPID_IDOMEVENT_TYPE: UInt32 = 1008
DISPID_IDOMEVENT_INITEVENT: UInt32 = 1009
DISPID_IDOMEVENT_PREVENTDEFAULT: UInt32 = 1010
DISPID_IDOMEVENT_STOPPROPAGATION: UInt32 = 1011
DISPID_IDOMEVENT_STOPIMMEDIATEPROPAGATION: UInt32 = 1012
DISPID_IDOMEVENT_ISTRUSTED: UInt32 = 1013
DISPID_IDOMEVENT_CANCELBUBBLE: UInt32 = 1014
DISPID_IDOMEVENT_SRCELEMENT: UInt32 = 1015
DISPID_IDOMUIEVENT_VIEW: UInt32 = 1026
DISPID_IDOMUIEVENT_DETAIL: UInt32 = 1027
DISPID_IDOMUIEVENT_INITUIEVENT: UInt32 = 1028
DISPID_IDOMMOUSEEVENT_SCREENX: UInt32 = 1051
DISPID_IDOMMOUSEEVENT_SCREENY: UInt32 = 1052
DISPID_IDOMMOUSEEVENT_CLIENTX: UInt32 = 1053
DISPID_IDOMMOUSEEVENT_CLIENTY: UInt32 = 1054
DISPID_IDOMMOUSEEVENT_CTRLKEY: UInt32 = 1055
DISPID_IDOMMOUSEEVENT_SHIFTKEY: UInt32 = 1056
DISPID_IDOMMOUSEEVENT_ALTKEY: UInt32 = 1057
DISPID_IDOMMOUSEEVENT_METAKEY: UInt32 = 1058
DISPID_IDOMMOUSEEVENT_BUTTON: UInt32 = 1059
DISPID_IDOMMOUSEEVENT_RELATEDTARGET: UInt32 = 1060
DISPID_IDOMMOUSEEVENT_INITMOUSEEVENT: UInt32 = 1061
DISPID_IDOMMOUSEEVENT_GETMODIFIERSTATE: UInt32 = 1062
DISPID_IDOMMOUSEEVENT_BUTTONS: UInt32 = 1063
DISPID_IDOMMOUSEEVENT_FROMELEMENT: UInt32 = 1064
DISPID_IDOMMOUSEEVENT_TOELEMENT: UInt32 = 1065
DISPID_IDOMMOUSEEVENT_X: UInt32 = 1066
DISPID_IDOMMOUSEEVENT_Y: UInt32 = 1067
DISPID_IDOMMOUSEEVENT_OFFSETX: UInt32 = 1068
DISPID_IDOMMOUSEEVENT_OFFSETY: UInt32 = 1069
DISPID_IDOMMOUSEEVENT_PAGEX: UInt32 = 1070
DISPID_IDOMMOUSEEVENT_PAGEY: UInt32 = 1071
DISPID_IDOMMOUSEEVENT_LAYERX: UInt32 = 1072
DISPID_IDOMMOUSEEVENT_LAYERY: UInt32 = 1073
DISPID_IDOMMOUSEEVENT_WHICH: UInt32 = 1074
DISPID_IDOMDRAGEVENT_DATATRANSFER: UInt32 = 1401
DISPID_IDOMDRAGEVENT_INITDRAGEVENT: UInt32 = 1402
DISPID_IDOMMOUSEWHEELEVENT_WHEELDELTA: UInt32 = 1076
DISPID_IDOMMOUSEWHEELEVENT_INITMOUSEWHEELEVENT: UInt32 = 1077
DISPID_IDOMWHEELEVENT_DELTAX: UInt32 = 1101
DISPID_IDOMWHEELEVENT_DELTAY: UInt32 = 1102
DISPID_IDOMWHEELEVENT_DELTAZ: UInt32 = 1103
DISPID_IDOMWHEELEVENT_DELTAMODE: UInt32 = 1104
DISPID_IDOMWHEELEVENT_INITWHEELEVENT: UInt32 = 1105
DISPID_IDOMTEXTEVENT_DATA: UInt32 = 1126
DISPID_IDOMTEXTEVENT_INPUTMETHOD: UInt32 = 1127
DISPID_IDOMTEXTEVENT_INITTEXTEVENT: UInt32 = 1128
DISPID_IDOMTEXTEVENT_LOCALE: UInt32 = 1129
DISPID_IDOMKEYBOARDEVENT_KEY: UInt32 = 1151
DISPID_IDOMKEYBOARDEVENT_LOCATION: UInt32 = 1152
DISPID_IDOMKEYBOARDEVENT_CTRLKEY: UInt32 = 1153
DISPID_IDOMKEYBOARDEVENT_SHIFTKEY: UInt32 = 1154
DISPID_IDOMKEYBOARDEVENT_ALTKEY: UInt32 = 1155
DISPID_IDOMKEYBOARDEVENT_METAKEY: UInt32 = 1156
DISPID_IDOMKEYBOARDEVENT_REPEAT: UInt32 = 1157
DISPID_IDOMKEYBOARDEVENT_GETMODIFIERSTATE: UInt32 = 1158
DISPID_IDOMKEYBOARDEVENT_INITKEYBOARDEVENT: UInt32 = 1159
DISPID_IDOMKEYBOARDEVENT_KEYCODE: UInt32 = 1160
DISPID_IDOMKEYBOARDEVENT_CHARCODE: UInt32 = 1161
DISPID_IDOMKEYBOARDEVENT_WHICH: UInt32 = 1162
DISPID_IDOMKEYBOARDEVENT_IE9_CHAR: UInt32 = 1163
DISPID_IDOMKEYBOARDEVENT_LOCALE: UInt32 = 1164
DISPID_IDOMCOMPOSITIONEVENT_DATA: UInt32 = 1176
DISPID_IDOMCOMPOSITIONEVENT_INITCOMPOSITIONEVENT: UInt32 = 1177
DISPID_IDOMCOMPOSITIONEVENT_LOCALE: UInt32 = 1178
DISPID_IDOMMUTATIONEVENT_RELATEDNODE: UInt32 = 1226
DISPID_IDOMMUTATIONEVENT_PREVVALUE: UInt32 = 1227
DISPID_IDOMMUTATIONEVENT_NEWVALUE: UInt32 = 1228
DISPID_IDOMMUTATIONEVENT_ATTRNAME: UInt32 = 1229
DISPID_IDOMMUTATIONEVENT_ATTRCHANGE: UInt32 = 1230
DISPID_IDOMMUTATIONEVENT_INITMUTATIONEVENT: UInt32 = 1231
DISPID_IDOMBEFOREUNLOADEVENT_RETURNVALUE: UInt32 = 1376
DISPID_IDOMFOCUSEVENT_RELATEDTARGET: UInt32 = 1251
DISPID_IDOMFOCUSEVENT_INITFOCUSEVENT: UInt32 = 1252
DISPID_IDOMCUSTOMEVENT_DETAIL: UInt32 = 1201
DISPID_IDOMCUSTOMEVENT_INITCUSTOMEVENT: UInt32 = 1202
DISPID_ICANVASGRADIENT_ADDCOLORSTOP: UInt32 = 1000
DISPID_ICANVASTEXTMETRICS_WIDTH: UInt32 = 1000
DISPID_ICANVASIMAGEDATA_WIDTH: UInt32 = 1000
DISPID_ICANVASIMAGEDATA_HEIGHT: UInt32 = 1001
DISPID_ICANVASIMAGEDATA_DATA: UInt32 = 1002
DISPID_ICANVASPIXELARRAY_LENGTH: UInt32 = 1000
DISPID_ICANVASRENDERINGCONTEXT2D_CANVAS: UInt32 = 1000
DISPID_ICANVASRENDERINGCONTEXT2D_RESTORE: UInt32 = 1001
DISPID_ICANVASRENDERINGCONTEXT2D_SAVE: UInt32 = 1002
DISPID_ICANVASRENDERINGCONTEXT2D_ROTATE: UInt32 = 1003
DISPID_ICANVASRENDERINGCONTEXT2D_SCALE: UInt32 = 1004
DISPID_ICANVASRENDERINGCONTEXT2D_SETTRANSFORM: UInt32 = 1005
DISPID_ICANVASRENDERINGCONTEXT2D_TRANSFORM: UInt32 = 1006
DISPID_ICANVASRENDERINGCONTEXT2D_TRANSLATE: UInt32 = 1007
DISPID_ICANVASRENDERINGCONTEXT2D_GLOBALALPHA: UInt32 = 1008
DISPID_ICANVASRENDERINGCONTEXT2D_GLOBALCOMPOSITEOPERATION: UInt32 = 1009
DISPID_ICANVASRENDERINGCONTEXT2D_FILLSTYLE: UInt32 = 1010
DISPID_ICANVASRENDERINGCONTEXT2D_STROKESTYLE: UInt32 = 1011
DISPID_ICANVASRENDERINGCONTEXT2D_CREATELINEARGRADIENT: UInt32 = 1012
DISPID_ICANVASRENDERINGCONTEXT2D_CREATERADIALGRADIENT: UInt32 = 1013
DISPID_ICANVASRENDERINGCONTEXT2D_CREATEPATTERN: UInt32 = 1014
DISPID_ICANVASRENDERINGCONTEXT2D_LINECAP: UInt32 = 1015
DISPID_ICANVASRENDERINGCONTEXT2D_LINEJOIN: UInt32 = 1016
DISPID_ICANVASRENDERINGCONTEXT2D_LINEWIDTH: UInt32 = 1017
DISPID_ICANVASRENDERINGCONTEXT2D_MITERLIMIT: UInt32 = 1018
DISPID_ICANVASRENDERINGCONTEXT2D_SHADOWBLUR: UInt32 = 1019
DISPID_ICANVASRENDERINGCONTEXT2D_SHADOWCOLOR: UInt32 = 1020
DISPID_ICANVASRENDERINGCONTEXT2D_SHADOWOFFSETX: UInt32 = 1021
DISPID_ICANVASRENDERINGCONTEXT2D_SHADOWOFFSETY: UInt32 = 1022
DISPID_ICANVASRENDERINGCONTEXT2D_CLEARRECT: UInt32 = 1023
DISPID_ICANVASRENDERINGCONTEXT2D_FILLRECT: UInt32 = 1024
DISPID_ICANVASRENDERINGCONTEXT2D_STROKERECT: UInt32 = 1025
DISPID_ICANVASRENDERINGCONTEXT2D_ARC: UInt32 = 1026
DISPID_ICANVASRENDERINGCONTEXT2D_ARCTO: UInt32 = 1027
DISPID_ICANVASRENDERINGCONTEXT2D_BEGINPATH: UInt32 = 1028
DISPID_ICANVASRENDERINGCONTEXT2D_BEZIERCURVETO: UInt32 = 1029
DISPID_ICANVASRENDERINGCONTEXT2D_CLIP: UInt32 = 1030
DISPID_ICANVASRENDERINGCONTEXT2D_CLOSEPATH: UInt32 = 1031
DISPID_ICANVASRENDERINGCONTEXT2D_FILL: UInt32 = 1032
DISPID_ICANVASRENDERINGCONTEXT2D_LINETO: UInt32 = 1033
DISPID_ICANVASRENDERINGCONTEXT2D_MOVETO: UInt32 = 1034
DISPID_ICANVASRENDERINGCONTEXT2D_QUADRATICCURVETO: UInt32 = 1035
DISPID_ICANVASRENDERINGCONTEXT2D_RECT: UInt32 = 1036
DISPID_ICANVASRENDERINGCONTEXT2D_STROKE: UInt32 = 1037
DISPID_ICANVASRENDERINGCONTEXT2D_ISPOINTINPATH: UInt32 = 1038
DISPID_ICANVASRENDERINGCONTEXT2D_FONT: UInt32 = 1039
DISPID_ICANVASRENDERINGCONTEXT2D_TEXTALIGN: UInt32 = 1040
DISPID_ICANVASRENDERINGCONTEXT2D_TEXTBASELINE: UInt32 = 1041
DISPID_ICANVASRENDERINGCONTEXT2D_FILLTEXT: UInt32 = 1042
DISPID_ICANVASRENDERINGCONTEXT2D_MEASURETEXT: UInt32 = 1043
DISPID_ICANVASRENDERINGCONTEXT2D_STROKETEXT: UInt32 = 1044
DISPID_ICANVASRENDERINGCONTEXT2D_DRAWIMAGE: UInt32 = 1045
DISPID_ICANVASRENDERINGCONTEXT2D_CREATEIMAGEDATA: UInt32 = 1046
DISPID_ICANVASRENDERINGCONTEXT2D_GETIMAGEDATA: UInt32 = 1047
DISPID_ICANVASRENDERINGCONTEXT2D_PUTIMAGEDATA: UInt32 = 1048
DISPID_IHTMLCANVASELEMENT_WIDTH: UInt32 = 65541
DISPID_IHTMLCANVASELEMENT_HEIGHT: UInt32 = 65542
DISPID_IHTMLCANVASELEMENT_GETCONTEXT: UInt32 = 1001
DISPID_IHTMLCANVASELEMENT_TODATAURL: UInt32 = 1002
DISPID_IDOMPROGRESSEVENT_LENGTHCOMPUTABLE: UInt32 = 1551
DISPID_IDOMPROGRESSEVENT_LOADED: UInt32 = 1552
DISPID_IDOMPROGRESSEVENT_TOTAL: UInt32 = 1553
DISPID_IDOMPROGRESSEVENT_INITPROGRESSEVENT: UInt32 = 1554
DISPID_IDOMMESSAGEEVENT_DATA: UInt32 = 1326
DISPID_IDOMMESSAGEEVENT_ORIGIN: UInt32 = 1327
DISPID_IDOMMESSAGEEVENT_SOURCE: UInt32 = 1328
DISPID_IDOMMESSAGEEVENT_INITMESSAGEEVENT: UInt32 = 1329
DISPID_IDOMSITEMODEEVENT_BUTTONID: UInt32 = 1301
DISPID_IDOMSITEMODEEVENT_ACTIONURL: UInt32 = 1302
DISPID_IDOMSTORAGEEVENT_KEY: UInt32 = 1351
DISPID_IDOMSTORAGEEVENT_OLDVALUE: UInt32 = 1352
DISPID_IDOMSTORAGEEVENT_NEWVALUE: UInt32 = 1353
DISPID_IDOMSTORAGEEVENT_URL: UInt32 = 1354
DISPID_IDOMSTORAGEEVENT_STORAGEAREA: UInt32 = 1355
DISPID_IDOMSTORAGEEVENT_INITSTORAGEEVENT: UInt32 = 1356
DISPID_IHTMLXMLHTTPREQUEST_READYSTATE: UInt32 = 1002
DISPID_IHTMLXMLHTTPREQUEST_RESPONSEBODY: UInt32 = 1003
DISPID_IHTMLXMLHTTPREQUEST_RESPONSETEXT: UInt32 = 1004
DISPID_IHTMLXMLHTTPREQUEST_RESPONSEXML: UInt32 = 1005
DISPID_IHTMLXMLHTTPREQUEST_STATUS: UInt32 = 1006
DISPID_IHTMLXMLHTTPREQUEST_STATUSTEXT: UInt32 = 1007
DISPID_IHTMLXMLHTTPREQUEST_ONREADYSTATECHANGE: UInt32 = 71561
DISPID_IHTMLXMLHTTPREQUEST_ABORT: UInt32 = 1009
DISPID_IHTMLXMLHTTPREQUEST_OPEN: UInt32 = 1010
DISPID_IHTMLXMLHTTPREQUEST_SEND: UInt32 = 1011
DISPID_IHTMLXMLHTTPREQUEST_GETALLRESPONSEHEADERS: UInt32 = 1012
DISPID_IHTMLXMLHTTPREQUEST_GETRESPONSEHEADER: UInt32 = 1013
DISPID_IHTMLXMLHTTPREQUEST_SETREQUESTHEADER: UInt32 = 1014
DISPID_IHTMLXMLHTTPREQUEST2_TIMEOUT: UInt32 = 1015
DISPID_IHTMLXMLHTTPREQUEST2_ONTIMEOUT: UInt32 = 71648
DISPID_IHTMLXMLHTTPREQUESTFACTORY_CREATE: UInt32 = 0
DISPID_HTMLXMLHTTPREQUESTEVENTS_ONTIMEOUT: UInt32 = 1016
DISPID_HTMLXMLHTTPREQUESTEVENTS_ONREADYSTATECHANGE: UInt32 = 1008
DISPID_ISVGANGLE_UNITTYPE: UInt32 = 1000
DISPID_ISVGANGLE_VALUE: UInt32 = 1001
DISPID_ISVGANGLE_VALUEINSPECIFIEDUNITS: UInt32 = 1002
DISPID_ISVGANGLE_VALUEASSTRING: UInt32 = 1003
DISPID_ISVGANGLE_NEWVALUESPECIFIEDUNITS: UInt32 = 1004
DISPID_ISVGANGLE_CONVERTTOSPECIFIEDUNITS: UInt32 = 1005
DISPID_ISVGSTYLABLE_CLASSNAME: UInt32 = 1001
DISPID_ISVGLOCATABLE_NEARESTVIEWPORTELEMENT: UInt32 = 1002
DISPID_ISVGLOCATABLE_FARTHESTVIEWPORTELEMENT: UInt32 = 1003
DISPID_ISVGLOCATABLE_GETBBOX: UInt32 = 1004
DISPID_ISVGLOCATABLE_GETCTM: UInt32 = 1005
DISPID_ISVGLOCATABLE_GETSCREENCTM: UInt32 = 1006
DISPID_ISVGLOCATABLE_GETTRANSFORMTOELEMENT: UInt32 = 1007
DISPID_ISVGTRANSFORMABLE_TRANSFORM: UInt32 = 1009
DISPID_ISVGTESTS_REQUIREDFEATURES: UInt32 = 1011
DISPID_ISVGTESTS_REQUIREDEXTENSIONS: UInt32 = 1013
DISPID_ISVGTESTS_SYSTEMLANGUAGE: UInt32 = 1015
DISPID_ISVGTESTS_HASEXTENSION: UInt32 = 1016
DISPID_ISVGLANGSPACE_XMLLANG: UInt32 = 1017
DISPID_ISVGLANGSPACE_XMLSPACE: UInt32 = 1018
DISPID_ISVGEXTERNALRESOURCESREQUIRED_EXTERNALRESOURCESREQUIRED: UInt32 = 1020
DISPID_ISVGFITTOVIEWBOX_VIEWBOX: UInt32 = 1022
DISPID_ISVGFITTOVIEWBOX_PRESERVEASPECTRATIO: UInt32 = 1024
DISPID_ISVGZOOMANDPAN_ZOOMANDPAN: UInt32 = 1025
DISPID_ISVGURIREFERENCE_HREF: UInt32 = 1026
DISPID_ISVGANIMATEDANGLE_BASEVAL: UInt32 = 1000
DISPID_ISVGANIMATEDANGLE_ANIMVAL: UInt32 = 1001
DISPID_ISVGANIMATEDTRANSFORMLIST_BASEVAL: UInt32 = 1000
DISPID_ISVGANIMATEDTRANSFORMLIST_ANIMVAL: UInt32 = 1001
DISPID_ISVGANIMATEDBOOLEAN_BASEVAL: UInt32 = 1000
DISPID_ISVGANIMATEDBOOLEAN_ANIMVAL: UInt32 = 1001
DISPID_ISVGANIMATEDENUMERATION_BASEVAL: UInt32 = 1000
DISPID_ISVGANIMATEDENUMERATION_ANIMVAL: UInt32 = 1001
DISPID_ISVGANIMATEDINTEGER_BASEVAL: UInt32 = 1000
DISPID_ISVGANIMATEDINTEGER_ANIMVAL: UInt32 = 1001
DISPID_ISVGANIMATEDLENGTH_BASEVAL: UInt32 = 1000
DISPID_ISVGANIMATEDLENGTH_ANIMVAL: UInt32 = 1001
DISPID_ISVGANIMATEDLENGTHLIST_BASEVAL: UInt32 = 1000
DISPID_ISVGANIMATEDLENGTHLIST_ANIMVAL: UInt32 = 1001
DISPID_ISVGANIMATEDNUMBER_BASEVAL: UInt32 = 1000
DISPID_ISVGANIMATEDNUMBER_ANIMVAL: UInt32 = 1001
DISPID_ISVGANIMATEDNUMBERLIST_BASEVAL: UInt32 = 1000
DISPID_ISVGANIMATEDNUMBERLIST_ANIMVAL: UInt32 = 1001
DISPID_ISVGANIMATEDRECT_BASEVAL: UInt32 = 1000
DISPID_ISVGANIMATEDRECT_ANIMVAL: UInt32 = 1001
DISPID_ISVGANIMATEDSTRING_BASEVAL: UInt32 = 1000
DISPID_ISVGANIMATEDSTRING_ANIMVAL: UInt32 = 1001
DISPID_ISVGCLIPPATHELEMENT_CLIPPATHUNITS: UInt32 = 1051
DISPID_ISVGDOCUMENT_ROOTELEMENT: UInt32 = 1116
DISPID_IGETSVGDOCUMENT_GETSVGDOCUMENT: UInt32 = 65615
DISPID_ISVGELEMENT_XMLBASE: UInt32 = 1032
DISPID_ISVGELEMENT_OWNERSVGELEMENT: UInt32 = 1033
DISPID_ISVGELEMENT_VIEWPORTELEMENT: UInt32 = 1034
DISPID_ISVGELEMENT_FOCUSABLE: UInt32 = 1036
DISPID_ISVGLENGTH_UNITTYPE: UInt32 = 1000
DISPID_ISVGLENGTH_VALUE: UInt32 = 1001
DISPID_ISVGLENGTH_VALUEINSPECIFIEDUNITS: UInt32 = 1002
DISPID_ISVGLENGTH_VALUEASSTRING: UInt32 = 1003
DISPID_ISVGLENGTH_NEWVALUESPECIFIEDUNITS: UInt32 = 1004
DISPID_ISVGLENGTH_CONVERTTOSPECIFIEDUNITS: UInt32 = 1005
DISPID_ISVGLENGTHLIST_NUMBEROFITEMS: UInt32 = 1000
DISPID_ISVGLENGTHLIST_CLEAR: UInt32 = 1001
DISPID_ISVGLENGTHLIST_INITIALIZE: UInt32 = 1002
DISPID_ISVGLENGTHLIST_GETITEM: UInt32 = 1003
DISPID_ISVGLENGTHLIST_INSERTITEMBEFORE: UInt32 = 1004
DISPID_ISVGLENGTHLIST_REPLACEITEM: UInt32 = 1005
DISPID_ISVGLENGTHLIST_REMOVEITEM: UInt32 = 1006
DISPID_ISVGLENGTHLIST_APPENDITEM: UInt32 = 1007
DISPID_ISVGMATRIX_A: UInt32 = 1000
DISPID_ISVGMATRIX_B: UInt32 = 1001
DISPID_ISVGMATRIX_C: UInt32 = 1002
DISPID_ISVGMATRIX_D: UInt32 = 1003
DISPID_ISVGMATRIX_E: UInt32 = 1004
DISPID_ISVGMATRIX_F: UInt32 = 1005
DISPID_ISVGMATRIX_MULTIPLY: UInt32 = 1006
DISPID_ISVGMATRIX_INVERSE: UInt32 = 1007
DISPID_ISVGMATRIX_TRANSLATE: UInt32 = 1008
DISPID_ISVGMATRIX_SCALE: UInt32 = 1009
DISPID_ISVGMATRIX_SCALENONUNIFORM: UInt32 = 1010
DISPID_ISVGMATRIX_ROTATE: UInt32 = 1011
DISPID_ISVGMATRIX_ROTATEFROMVECTOR: UInt32 = 1012
DISPID_ISVGMATRIX_FLIPX: UInt32 = 1013
DISPID_ISVGMATRIX_FLIPY: UInt32 = 1014
DISPID_ISVGMATRIX_SKEWX: UInt32 = 1015
DISPID_ISVGMATRIX_SKEWY: UInt32 = 1016
DISPID_ISVGNUMBER_VALUE: UInt32 = 1000
DISPID_ISVGNUMBERLIST_NUMBEROFITEMS: UInt32 = 1000
DISPID_ISVGNUMBERLIST_CLEAR: UInt32 = 1001
DISPID_ISVGNUMBERLIST_INITIALIZE: UInt32 = 1002
DISPID_ISVGNUMBERLIST_GETITEM: UInt32 = 1003
DISPID_ISVGNUMBERLIST_INSERTITEMBEFORE: UInt32 = 1004
DISPID_ISVGNUMBERLIST_REPLACEITEM: UInt32 = 1005
DISPID_ISVGNUMBERLIST_REMOVEITEM: UInt32 = 1006
DISPID_ISVGNUMBERLIST_APPENDITEM: UInt32 = 1007
DISPID_ISVGPATTERNELEMENT_PATTERNUNITS: UInt32 = 1051
DISPID_ISVGPATTERNELEMENT_PATTERNCONTENTUNITS: UInt32 = 1053
DISPID_ISVGPATTERNELEMENT_PATTERNTRANSFORM: UInt32 = 1055
DISPID_ISVGPATTERNELEMENT_X: UInt32 = 1057
DISPID_ISVGPATTERNELEMENT_Y: UInt32 = 1059
DISPID_ISVGPATTERNELEMENT_WIDTH: UInt32 = 1061
DISPID_ISVGPATTERNELEMENT_HEIGHT: UInt32 = 1063
DISPID_ISVGPATHSEG_PATHSEGTYPE: UInt32 = 1000
DISPID_ISVGPATHSEG_PATHSEGTYPEASLETTER: UInt32 = 1001
DISPID_ISVGPATHSEGARCABS_X: UInt32 = 1020
DISPID_ISVGPATHSEGARCABS_Y: UInt32 = 1021
DISPID_ISVGPATHSEGARCABS_R1: UInt32 = 1022
DISPID_ISVGPATHSEGARCABS_R2: UInt32 = 1023
DISPID_ISVGPATHSEGARCABS_ANGLE: UInt32 = 1024
DISPID_ISVGPATHSEGARCABS_LARGEARCFLAG: UInt32 = 1025
DISPID_ISVGPATHSEGARCABS_SWEEPFLAG: UInt32 = 1026
DISPID_ISVGPATHSEGARCREL_X: UInt32 = 1020
DISPID_ISVGPATHSEGARCREL_Y: UInt32 = 1021
DISPID_ISVGPATHSEGARCREL_R1: UInt32 = 1022
DISPID_ISVGPATHSEGARCREL_R2: UInt32 = 1023
DISPID_ISVGPATHSEGARCREL_ANGLE: UInt32 = 1024
DISPID_ISVGPATHSEGARCREL_LARGEARCFLAG: UInt32 = 1025
DISPID_ISVGPATHSEGARCREL_SWEEPFLAG: UInt32 = 1026
DISPID_ISVGPATHSEGMOVETOABS_X: UInt32 = 1020
DISPID_ISVGPATHSEGMOVETOABS_Y: UInt32 = 1021
DISPID_ISVGPATHSEGMOVETOREL_X: UInt32 = 1020
DISPID_ISVGPATHSEGMOVETOREL_Y: UInt32 = 1021
DISPID_ISVGPATHSEGLINETOABS_X: UInt32 = 1020
DISPID_ISVGPATHSEGLINETOABS_Y: UInt32 = 1021
DISPID_ISVGPATHSEGLINETOREL_X: UInt32 = 1020
DISPID_ISVGPATHSEGLINETOREL_Y: UInt32 = 1021
DISPID_ISVGPATHSEGCURVETOCUBICABS_X: UInt32 = 1020
DISPID_ISVGPATHSEGCURVETOCUBICABS_Y: UInt32 = 1021
DISPID_ISVGPATHSEGCURVETOCUBICABS_X1: UInt32 = 1022
DISPID_ISVGPATHSEGCURVETOCUBICABS_Y1: UInt32 = 1023
DISPID_ISVGPATHSEGCURVETOCUBICABS_X2: UInt32 = 1024
DISPID_ISVGPATHSEGCURVETOCUBICABS_Y2: UInt32 = 1025
DISPID_ISVGPATHSEGCURVETOCUBICREL_X: UInt32 = 1020
DISPID_ISVGPATHSEGCURVETOCUBICREL_Y: UInt32 = 1021
DISPID_ISVGPATHSEGCURVETOCUBICREL_X1: UInt32 = 1022
DISPID_ISVGPATHSEGCURVETOCUBICREL_Y1: UInt32 = 1023
DISPID_ISVGPATHSEGCURVETOCUBICREL_X2: UInt32 = 1024
DISPID_ISVGPATHSEGCURVETOCUBICREL_Y2: UInt32 = 1025
DISPID_ISVGPATHSEGCURVETOCUBICSMOOTHABS_X: UInt32 = 1020
DISPID_ISVGPATHSEGCURVETOCUBICSMOOTHABS_Y: UInt32 = 1021
DISPID_ISVGPATHSEGCURVETOCUBICSMOOTHABS_X2: UInt32 = 1022
DISPID_ISVGPATHSEGCURVETOCUBICSMOOTHABS_Y2: UInt32 = 1023
DISPID_ISVGPATHSEGCURVETOCUBICSMOOTHREL_X: UInt32 = 1020
DISPID_ISVGPATHSEGCURVETOCUBICSMOOTHREL_Y: UInt32 = 1021
DISPID_ISVGPATHSEGCURVETOCUBICSMOOTHREL_X2: UInt32 = 1022
DISPID_ISVGPATHSEGCURVETOCUBICSMOOTHREL_Y2: UInt32 = 1023
DISPID_ISVGPATHSEGCURVETOQUADRATICABS_X: UInt32 = 1020
DISPID_ISVGPATHSEGCURVETOQUADRATICABS_Y: UInt32 = 1021
DISPID_ISVGPATHSEGCURVETOQUADRATICABS_X1: UInt32 = 1022
DISPID_ISVGPATHSEGCURVETOQUADRATICABS_Y1: UInt32 = 1023
DISPID_ISVGPATHSEGCURVETOQUADRATICREL_X: UInt32 = 1020
DISPID_ISVGPATHSEGCURVETOQUADRATICREL_Y: UInt32 = 1021
DISPID_ISVGPATHSEGCURVETOQUADRATICREL_X1: UInt32 = 1022
DISPID_ISVGPATHSEGCURVETOQUADRATICREL_Y1: UInt32 = 1023
DISPID_ISVGPATHSEGCURVETOQUADRATICSMOOTHABS_X: UInt32 = 1020
DISPID_ISVGPATHSEGCURVETOQUADRATICSMOOTHABS_Y: UInt32 = 1021
DISPID_ISVGPATHSEGCURVETOQUADRATICSMOOTHREL_X: UInt32 = 1020
DISPID_ISVGPATHSEGCURVETOQUADRATICSMOOTHREL_Y: UInt32 = 1021
DISPID_ISVGPATHSEGLINETOHORIZONTALABS_X: UInt32 = 1020
DISPID_ISVGPATHSEGLINETOHORIZONTALREL_X: UInt32 = 1020
DISPID_ISVGPATHSEGLINETOVERTICALABS_Y: UInt32 = 1020
DISPID_ISVGPATHSEGLINETOVERTICALREL_Y: UInt32 = 1020
DISPID_ISVGPATHSEGLIST_NUMBEROFITEMS: UInt32 = 1000
DISPID_ISVGPATHSEGLIST_CLEAR: UInt32 = 1001
DISPID_ISVGPATHSEGLIST_INITIALIZE: UInt32 = 1002
DISPID_ISVGPATHSEGLIST_GETITEM: UInt32 = 1003
DISPID_ISVGPATHSEGLIST_INSERTITEMBEFORE: UInt32 = 1004
DISPID_ISVGPATHSEGLIST_REPLACEITEM: UInt32 = 1005
DISPID_ISVGPATHSEGLIST_REMOVEITEM: UInt32 = 1006
DISPID_ISVGPATHSEGLIST_APPENDITEM: UInt32 = 1007
DISPID_ISVGPOINT_X: UInt32 = 1000
DISPID_ISVGPOINT_Y: UInt32 = 1001
DISPID_ISVGPOINT_MATRIXTRANSFORM: UInt32 = 1002
DISPID_ISVGPOINTLIST_NUMBEROFITEMS: UInt32 = 1000
DISPID_ISVGPOINTLIST_CLEAR: UInt32 = 1001
DISPID_ISVGPOINTLIST_INITIALIZE: UInt32 = 1002
DISPID_ISVGPOINTLIST_GETITEM: UInt32 = 1003
DISPID_ISVGPOINTLIST_INSERTITEMBEFORE: UInt32 = 1004
DISPID_ISVGPOINTLIST_REPLACEITEM: UInt32 = 1005
DISPID_ISVGPOINTLIST_REMOVEITEM: UInt32 = 1006
DISPID_ISVGPOINTLIST_APPENDITEM: UInt32 = 1007
DISPID_ISVGRECT_X: UInt32 = 1000
DISPID_ISVGRECT_Y: UInt32 = 1001
DISPID_ISVGRECT_WIDTH: UInt32 = 1002
DISPID_ISVGRECT_HEIGHT: UInt32 = 1003
DISPID_ISVGSTRINGLIST_NUMBEROFITEMS: UInt32 = 1000
DISPID_ISVGSTRINGLIST_CLEAR: UInt32 = 1001
DISPID_ISVGSTRINGLIST_INITIALIZE: UInt32 = 1002
DISPID_ISVGSTRINGLIST_GETITEM: UInt32 = 1003
DISPID_ISVGSTRINGLIST_INSERTITEMBEFORE: UInt32 = 1004
DISPID_ISVGSTRINGLIST_REPLACEITEM: UInt32 = 1005
DISPID_ISVGSTRINGLIST_REMOVEITEM: UInt32 = 1006
DISPID_ISVGSTRINGLIST_APPENDITEM: UInt32 = 1007
DISPID_ISVGTRANSFORM_TYPE: UInt32 = 1000
DISPID_ISVGTRANSFORM_MATRIX: UInt32 = 1001
DISPID_ISVGTRANSFORM_ANGLE: UInt32 = 1002
DISPID_ISVGTRANSFORM_SETMATRIX: UInt32 = 1003
DISPID_ISVGTRANSFORM_SETTRANSLATE: UInt32 = 1004
DISPID_ISVGTRANSFORM_SETSCALE: UInt32 = 1005
DISPID_ISVGTRANSFORM_SETROTATE: UInt32 = 1006
DISPID_ISVGTRANSFORM_SETSKEWX: UInt32 = 1007
DISPID_ISVGTRANSFORM_SETSKEWY: UInt32 = 1008
DISPID_ISVGSVGELEMENT_X: UInt32 = 1052
DISPID_ISVGSVGELEMENT_Y: UInt32 = 1054
DISPID_ISVGSVGELEMENT_WIDTH: UInt32 = 1056
DISPID_ISVGSVGELEMENT_HEIGHT: UInt32 = 1058
DISPID_ISVGSVGELEMENT_CONTENTSCRIPTTYPE: UInt32 = 1059
DISPID_ISVGSVGELEMENT_CONTENTSTYLETYPE: UInt32 = 1060
DISPID_ISVGSVGELEMENT_VIEWPORT: UInt32 = 1061
DISPID_ISVGSVGELEMENT_PIXELUNITTOMILLIMETERX: UInt32 = 1062
DISPID_ISVGSVGELEMENT_PIXELUNITTOMILLIMETERY: UInt32 = 1063
DISPID_ISVGSVGELEMENT_SCREENPIXELTOMILLIMETERX: UInt32 = 1064
DISPID_ISVGSVGELEMENT_SCREENPIXELTOMILLIMETERY: UInt32 = 1065
DISPID_ISVGSVGELEMENT_USECURRENTVIEW: UInt32 = 1066
DISPID_ISVGSVGELEMENT_CURRENTVIEW: UInt32 = 1067
DISPID_ISVGSVGELEMENT_CURRENTSCALE: UInt32 = 1068
DISPID_ISVGSVGELEMENT_CURRENTTRANSLATE: UInt32 = 1069
DISPID_ISVGSVGELEMENT_SUSPENDREDRAW: UInt32 = 1070
DISPID_ISVGSVGELEMENT_UNSUSPENDREDRAW: UInt32 = 1071
DISPID_ISVGSVGELEMENT_UNSUSPENDREDRAWALL: UInt32 = 1072
DISPID_ISVGSVGELEMENT_FORCEREDRAW: UInt32 = 1073
DISPID_ISVGSVGELEMENT_PAUSEANIMATIONS: UInt32 = 1074
DISPID_ISVGSVGELEMENT_UNPAUSEANIMATIONS: UInt32 = 1075
DISPID_ISVGSVGELEMENT_ANIMATIONSPAUSED: UInt32 = 1076
DISPID_ISVGSVGELEMENT_GETCURRENTTIME: UInt32 = 1077
DISPID_ISVGSVGELEMENT_SETCURRENTTIME: UInt32 = 1078
DISPID_ISVGSVGELEMENT_GETINTERSECTIONLIST: UInt32 = 1079
DISPID_ISVGSVGELEMENT_GETENCLOSURELIST: UInt32 = 1080
DISPID_ISVGSVGELEMENT_CHECKINTERSECTION: UInt32 = 1081
DISPID_ISVGSVGELEMENT_CHECKENCLOSURE: UInt32 = 1082
DISPID_ISVGSVGELEMENT_DESELECTALL: UInt32 = 1083
DISPID_ISVGSVGELEMENT_CREATESVGNUMBER: UInt32 = 1084
DISPID_ISVGSVGELEMENT_CREATESVGLENGTH: UInt32 = 1085
DISPID_ISVGSVGELEMENT_CREATESVGANGLE: UInt32 = 1086
DISPID_ISVGSVGELEMENT_CREATESVGPOINT: UInt32 = 1087
DISPID_ISVGSVGELEMENT_CREATESVGMATRIX: UInt32 = 1088
DISPID_ISVGSVGELEMENT_CREATESVGRECT: UInt32 = 1089
DISPID_ISVGSVGELEMENT_CREATESVGTRANSFORM: UInt32 = 1090
DISPID_ISVGSVGELEMENT_CREATESVGTRANSFORMFROMMATRIX: UInt32 = 1091
DISPID_ISVGSVGELEMENT_GETELEMENTBYID: UInt32 = 1092
DISPID_ISVGUSEELEMENT_X: UInt32 = 1052
DISPID_ISVGUSEELEMENT_Y: UInt32 = 1054
DISPID_ISVGUSEELEMENT_WIDTH: UInt32 = 1056
DISPID_ISVGUSEELEMENT_HEIGHT: UInt32 = 1058
DISPID_ISVGUSEELEMENT_INSTANCEROOT: UInt32 = 1059
DISPID_ISVGUSEELEMENT_ANIMATEDINSTANCEROOT: UInt32 = 1060
DISPID_IHTMLSTYLESHEETRULESAPPLIEDCOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLSTYLESHEETRULESAPPLIEDCOLLECTION_LENGTH: UInt32 = 1001
DISPID_IHTMLSTYLESHEETRULESAPPLIEDCOLLECTION_PROPERTYAPPLIEDBY: UInt32 = 1002
DISPID_IHTMLSTYLESHEETRULESAPPLIEDCOLLECTION_PROPERTYAPPLIEDTRACE: UInt32 = 1004
DISPID_IHTMLSTYLESHEETRULESAPPLIEDCOLLECTION_PROPERTYAPPLIEDTRACELENGTH: UInt32 = 1005
DISPID_IRULESAPPLIED_ELEMENT: UInt32 = 1001
DISPID_IRULESAPPLIED_INLINESTYLES: UInt32 = 1002
DISPID_IRULESAPPLIED_APPLIEDRULES: UInt32 = 1003
DISPID_IRULESAPPLIED_PROPERTYISINLINE: UInt32 = 1004
DISPID_IRULESAPPLIED_PROPERTYISINHERITABLE: UInt32 = 1005
DISPID_IRULESAPPLIED_HASINHERITABLEPROPERTY: UInt32 = 1006
DISPID_IRULESAPPLIEDCOLLECTION_ITEM: UInt32 = 0
DISPID_IRULESAPPLIEDCOLLECTION_LENGTH: UInt32 = 1001
DISPID_IRULESAPPLIEDCOLLECTION_ELEMENT: UInt32 = 1002
DISPID_IRULESAPPLIEDCOLLECTION_PROPERTYINHERITEDFROM: UInt32 = 1003
DISPID_IRULESAPPLIEDCOLLECTION_PROPERTYCOUNT: UInt32 = 1004
DISPID_IRULESAPPLIEDCOLLECTION_PROPERTY: UInt32 = 1005
DISPID_IRULESAPPLIEDCOLLECTION_PROPERTYINHERITEDTRACE: UInt32 = 1006
DISPID_IRULESAPPLIEDCOLLECTION_PROPERTYINHERITEDTRACELENGTH: UInt32 = 1007
DISPID_ISVGTRANSFORMLIST_NUMBEROFITEMS: UInt32 = 1000
DISPID_ISVGTRANSFORMLIST_CLEAR: UInt32 = 1001
DISPID_ISVGTRANSFORMLIST_INITIALIZE: UInt32 = 1002
DISPID_ISVGTRANSFORMLIST_GETITEM: UInt32 = 1003
DISPID_ISVGTRANSFORMLIST_INSERTITEMBEFORE: UInt32 = 1004
DISPID_ISVGTRANSFORMLIST_REPLACEITEM: UInt32 = 1005
DISPID_ISVGTRANSFORMLIST_REMOVEITEM: UInt32 = 1006
DISPID_ISVGTRANSFORMLIST_APPENDITEM: UInt32 = 1007
DISPID_ISVGTRANSFORMLIST_CREATESVGTRANSFORMFROMMATRIX: UInt32 = 1008
DISPID_ISVGTRANSFORMLIST_CONSOLIDATE: UInt32 = 1009
DISPID_ISVGANIMATEDPOINTS_POINTS: UInt32 = 1050
DISPID_ISVGANIMATEDPOINTS_ANIMATEDPOINTS: UInt32 = 1052
DISPID_ISVGCIRCLEELEMENT_CX: UInt32 = 1052
DISPID_ISVGCIRCLEELEMENT_CY: UInt32 = 1054
DISPID_ISVGCIRCLEELEMENT_R: UInt32 = 1056
DISPID_ISVGELLIPSEELEMENT_CX: UInt32 = 1052
DISPID_ISVGELLIPSEELEMENT_CY: UInt32 = 1054
DISPID_ISVGELLIPSEELEMENT_RX: UInt32 = 1056
DISPID_ISVGELLIPSEELEMENT_RY: UInt32 = 1058
DISPID_ISVGLINEELEMENT_X1: UInt32 = 1052
DISPID_ISVGLINEELEMENT_Y1: UInt32 = 1054
DISPID_ISVGLINEELEMENT_X2: UInt32 = 1056
DISPID_ISVGLINEELEMENT_Y2: UInt32 = 1058
DISPID_ISVGRECTELEMENT_X: UInt32 = 1052
DISPID_ISVGRECTELEMENT_Y: UInt32 = 1054
DISPID_ISVGRECTELEMENT_WIDTH: UInt32 = 1056
DISPID_ISVGRECTELEMENT_HEIGHT: UInt32 = 1058
DISPID_ISVGRECTELEMENT_RX: UInt32 = 1060
DISPID_ISVGRECTELEMENT_RY: UInt32 = 1062
DISPID_ISVGANIMATEDPATHDATA_PATHSEGLIST: UInt32 = 1052
DISPID_ISVGANIMATEDPATHDATA_NORMALIZEDPATHSEGLIST: UInt32 = 1076
DISPID_ISVGANIMATEDPATHDATA_ANIMATEDPATHSEGLIST: UInt32 = 1077
DISPID_ISVGANIMATEDPATHDATA_ANIMATEDNORMALIZEDPATHSEGLIST: UInt32 = 1078
DISPID_ISVGPATHELEMENT_PATHLENGTH: UInt32 = 1053
DISPID_ISVGPATHELEMENT_GETTOTALLENGTH: UInt32 = 1073
DISPID_ISVGPATHELEMENT_GETPOINTATLENGTH: UInt32 = 1074
DISPID_ISVGPATHELEMENT_GETPATHSEGATLENGTH: UInt32 = 1075
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGCLOSEPATH: UInt32 = 1054
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGMOVETOABS: UInt32 = 1055
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGMOVETOREL: UInt32 = 1056
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGLINETOABS: UInt32 = 1057
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGLINETOREL: UInt32 = 1058
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGCURVETOCUBICABS: UInt32 = 1059
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGCURVETOCUBICREL: UInt32 = 1060
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGCURVETOQUADRATICABS: UInt32 = 1061
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGCURVETOQUADRATICREL: UInt32 = 1062
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGARCABS: UInt32 = 1063
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGARCREL: UInt32 = 1064
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGLINETOHORIZONTALABS: UInt32 = 1065
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGLINETOHORIZONTALREL: UInt32 = 1066
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGLINETOVERTICALABS: UInt32 = 1067
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGLINETOVERTICALREL: UInt32 = 1068
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGCURVETOCUBICSMOOTHABS: UInt32 = 1069
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGCURVETOCUBICSMOOTHREL: UInt32 = 1070
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGCURVETOQUADRATICSMOOTHABS: UInt32 = 1071
DISPID_ISVGPATHELEMENT_CREATESVGPATHSEGCURVETOQUADRATICSMOOTHREL: UInt32 = 1072
DISPID_ISVGPRESERVEASPECTRATIO_ALIGN: UInt32 = 1000
DISPID_ISVGPRESERVEASPECTRATIO_MEETORSLICE: UInt32 = 1001
DISPID_ISVGANIMATEDPRESERVEASPECTRATIO_BASEVAL: UInt32 = 1000
DISPID_ISVGANIMATEDPRESERVEASPECTRATIO_ANIMVAL: UInt32 = 1001
DISPID_ISVGIMAGEELEMENT_X: UInt32 = 1051
DISPID_ISVGIMAGEELEMENT_Y: UInt32 = 1053
DISPID_ISVGIMAGEELEMENT_WIDTH: UInt32 = 1055
DISPID_ISVGIMAGEELEMENT_HEIGHT: UInt32 = 1057
DISPID_ISVGSTOPELEMENT_OFFSET: UInt32 = 1051
DISPID_ISVGGRADIENTELEMENT_GRADIENTUNITS: UInt32 = 1051
DISPID_ISVGGRADIENTELEMENT_GRADIENTTRANSFORM: UInt32 = 1053
DISPID_ISVGGRADIENTELEMENT_SPREADMETHOD: UInt32 = 1055
DISPID_ISVGLINEARGRADIENTELEMENT_X1: UInt32 = 1071
DISPID_ISVGLINEARGRADIENTELEMENT_Y1: UInt32 = 1073
DISPID_ISVGLINEARGRADIENTELEMENT_X2: UInt32 = 1075
DISPID_ISVGLINEARGRADIENTELEMENT_Y2: UInt32 = 1077
DISPID_ISVGRADIALGRADIENTELEMENT_CX: UInt32 = 1071
DISPID_ISVGRADIALGRADIENTELEMENT_CY: UInt32 = 1073
DISPID_ISVGRADIALGRADIENTELEMENT_R: UInt32 = 1075
DISPID_ISVGRADIALGRADIENTELEMENT_FX: UInt32 = 1077
DISPID_ISVGRADIALGRADIENTELEMENT_FY: UInt32 = 1079
DISPID_ISVGMASKELEMENT_MASKUNITS: UInt32 = 1051
DISPID_ISVGMASKELEMENT_MASKCONTENTUNITS: UInt32 = 1053
DISPID_ISVGMASKELEMENT_X: UInt32 = 1055
DISPID_ISVGMASKELEMENT_Y: UInt32 = 1057
DISPID_ISVGMASKELEMENT_WIDTH: UInt32 = 1059
DISPID_ISVGMASKELEMENT_HEIGHT: UInt32 = 1061
DISPID_ISVGMARKERELEMENT_REFX: UInt32 = 1051
DISPID_ISVGMARKERELEMENT_REFY: UInt32 = 1053
DISPID_ISVGMARKERELEMENT_MARKERUNITS: UInt32 = 1055
DISPID_ISVGMARKERELEMENT_MARKERWIDTH: UInt32 = 1057
DISPID_ISVGMARKERELEMENT_MARKERHEIGHT: UInt32 = 1059
DISPID_ISVGMARKERELEMENT_ORIENTTYPE: UInt32 = 1061
DISPID_ISVGMARKERELEMENT_ORIENTANGLE: UInt32 = 1062
DISPID_ISVGMARKERELEMENT_SETORIENTTOAUTO: UInt32 = 1063
DISPID_ISVGMARKERELEMENT_SETORIENTTOANGLE: UInt32 = 1064
DISPID_ISVGZOOMEVENT_ZOOMRECTSCREEN: UInt32 = 1276
DISPID_ISVGZOOMEVENT_PREVIOUSSCALE: UInt32 = 1277
DISPID_ISVGZOOMEVENT_PREVIOUSTRANSLATE: UInt32 = 1278
DISPID_ISVGZOOMEVENT_NEWSCALE: UInt32 = 1279
DISPID_ISVGZOOMEVENT_NEWTRANSLATE: UInt32 = 1280
DISPID_ISVGAELEMENT_TARGET: UInt32 = 1052
DISPID_ISVGVIEWELEMENT_VIEWTARGET: UInt32 = 1052
DISPID_IHTMLMEDIAERROR_CODE: UInt32 = 1000
DISPID_IHTMLTIMERANGES_LENGTH: UInt32 = 1000
DISPID_IHTMLTIMERANGES_START: UInt32 = 1001
DISPID_IHTMLTIMERANGES_END: UInt32 = 1002
DISPID_IHTMLTIMERANGES2_STARTDOUBLE: UInt32 = 1003
DISPID_IHTMLTIMERANGES2_ENDDOUBLE: UInt32 = 1004
DISPID_IHTMLMEDIAELEMENT_ERROR: UInt32 = 1000
DISPID_IHTMLMEDIAELEMENT_SRC: UInt32 = 1001
DISPID_IHTMLMEDIAELEMENT_CURRENTSRC: UInt32 = 1002
DISPID_IHTMLMEDIAELEMENT_NETWORKSTATE: UInt32 = 1003
DISPID_IHTMLMEDIAELEMENT_PRELOAD: UInt32 = 1004
DISPID_IHTMLMEDIAELEMENT_BUFFERED: UInt32 = 1005
DISPID_IHTMLMEDIAELEMENT_LOAD: UInt32 = 1006
DISPID_IHTMLMEDIAELEMENT_CANPLAYTYPE: UInt32 = 1007
DISPID_IHTMLMEDIAELEMENT_SEEKING: UInt32 = 1009
DISPID_IHTMLMEDIAELEMENT_CURRENTTIME: UInt32 = 1010
DISPID_IHTMLMEDIAELEMENT_INITIALTIME: UInt32 = 1011
DISPID_IHTMLMEDIAELEMENT_DURATION: UInt32 = 1012
DISPID_IHTMLMEDIAELEMENT_PAUSED: UInt32 = 1013
DISPID_IHTMLMEDIAELEMENT_DEFAULTPLAYBACKRATE: UInt32 = 1014
DISPID_IHTMLMEDIAELEMENT_PLAYBACKRATE: UInt32 = 1015
DISPID_IHTMLMEDIAELEMENT_PLAYED: UInt32 = 1016
DISPID_IHTMLMEDIAELEMENT_SEEKABLE: UInt32 = 1017
DISPID_IHTMLMEDIAELEMENT_ENDED: UInt32 = 1018
DISPID_IHTMLMEDIAELEMENT_AUTOPLAY: UInt32 = 1019
DISPID_IHTMLMEDIAELEMENT_LOOP: UInt32 = 1020
DISPID_IHTMLMEDIAELEMENT_PLAY: UInt32 = 1021
DISPID_IHTMLMEDIAELEMENT_PAUSE: UInt32 = 1022
DISPID_IHTMLMEDIAELEMENT_CONTROLS: UInt32 = 1023
DISPID_IHTMLMEDIAELEMENT_VOLUME: UInt32 = 1024
DISPID_IHTMLMEDIAELEMENT_MUTED: UInt32 = 1025
DISPID_IHTMLMEDIAELEMENT_AUTOBUFFER: UInt32 = 1026
DISPID_IHTMLMEDIAELEMENT2_CURRENTTIMEDOUBLE: UInt32 = 1027
DISPID_IHTMLMEDIAELEMENT2_INITIALTIMEDOUBLE: UInt32 = 1028
DISPID_IHTMLMEDIAELEMENT2_DURATIONDOUBLE: UInt32 = 1029
DISPID_IHTMLMEDIAELEMENT2_DEFAULTPLAYBACKRATEDOUBLE: UInt32 = 1030
DISPID_IHTMLMEDIAELEMENT2_PLAYBACKRATEDOUBLE: UInt32 = 1031
DISPID_IHTMLMEDIAELEMENT2_VOLUMEDOUBLE: UInt32 = 1032
DISPID_IHTMLMSMEDIAELEMENT_MSPLAYTODISABLED: UInt32 = 1033
DISPID_IHTMLMSMEDIAELEMENT_MSPLAYTOPRIMARY: UInt32 = 1034
DISPID_IHTMLSOURCEELEMENT_SRC: UInt32 = 1000
DISPID_IHTMLSOURCEELEMENT_TYPE: UInt32 = 1001
DISPID_IHTMLSOURCEELEMENT_MEDIA: UInt32 = 1002
DISPID_IHTMLVIDEOELEMENT_WIDTH: UInt32 = 65541
DISPID_IHTMLVIDEOELEMENT_HEIGHT: UInt32 = 65542
DISPID_IHTMLVIDEOELEMENT_VIDEOWIDTH: UInt32 = 1050
DISPID_IHTMLVIDEOELEMENT_VIDEOHEIGHT: UInt32 = 1051
DISPID_IHTMLVIDEOELEMENT_POSTER: UInt32 = 1052
DISPID_IHTMLAUDIOELEMENTFACTORY_CREATE: UInt32 = 0
DISPID_ISVGELEMENTINSTANCE_CORRESPONDINGELEMENT: UInt32 = 1000
DISPID_ISVGELEMENTINSTANCE_CORRESPONDINGUSEELEMENT: UInt32 = 1001
DISPID_ISVGELEMENTINSTANCE_PARENTNODE: UInt32 = 1002
DISPID_ISVGELEMENTINSTANCE_CHILDNODES: UInt32 = 1003
DISPID_ISVGELEMENTINSTANCE_FIRSTCHILD: UInt32 = 1004
DISPID_ISVGELEMENTINSTANCE_LASTCHILD: UInt32 = 1005
DISPID_ISVGELEMENTINSTANCE_PREVIOUSSIBLING: UInt32 = 1006
DISPID_ISVGELEMENTINSTANCE_NEXTSIBLING: UInt32 = 1007
DISPID_ISVGELEMENTINSTANCELIST_LENGTH: UInt32 = 1000
DISPID_ISVGELEMENTINSTANCELIST_ITEM: UInt32 = 1001
DISPID_IDOMEXCEPTION_CODE: UInt32 = 1000
DISPID_IDOMEXCEPTION_MESSAGE: UInt32 = 1001
DISPID_IRANGEEXCEPTION_CODE: UInt32 = 1000
DISPID_IRANGEEXCEPTION_MESSAGE: UInt32 = 1001
DISPID_ISVGEXCEPTION_CODE: UInt32 = 1000
DISPID_ISVGEXCEPTION_MESSAGE: UInt32 = 1001
DISPID_IEVENTEXCEPTION_CODE: UInt32 = 1000
DISPID_IEVENTEXCEPTION_MESSAGE: UInt32 = 1001
DISPID_ISVGSCRIPTELEMENT_TYPE: UInt32 = 1052
DISPID_ISVGSTYLEELEMENT_TYPE: UInt32 = 1051
DISPID_ISVGSTYLEELEMENT_MEDIA: UInt32 = 1052
DISPID_ISVGTEXTCONTENTELEMENT_TEXTLENGTH: UInt32 = 1053
DISPID_ISVGTEXTCONTENTELEMENT_LENGTHADJUST: UInt32 = 1051
DISPID_ISVGTEXTCONTENTELEMENT_GETNUMBEROFCHARS: UInt32 = 1054
DISPID_ISVGTEXTCONTENTELEMENT_GETCOMPUTEDTEXTLENGTH: UInt32 = 1055
DISPID_ISVGTEXTCONTENTELEMENT_GETSUBSTRINGLENGTH: UInt32 = 1056
DISPID_ISVGTEXTCONTENTELEMENT_GETSTARTPOSITIONOFCHAR: UInt32 = 1057
DISPID_ISVGTEXTCONTENTELEMENT_GETENDPOSITIONOFCHAR: UInt32 = 1058
DISPID_ISVGTEXTCONTENTELEMENT_GETEXTENTOFCHAR: UInt32 = 1059
DISPID_ISVGTEXTCONTENTELEMENT_GETROTATIONOFCHAR: UInt32 = 1060
DISPID_ISVGTEXTCONTENTELEMENT_GETCHARNUMATPOSITION: UInt32 = 1061
DISPID_ISVGTEXTCONTENTELEMENT_SELECTSUBSTRING: UInt32 = 1062
DISPID_ISVGTEXTPOSITIONINGELEMENT_X: UInt32 = 1071
DISPID_ISVGTEXTPOSITIONINGELEMENT_Y: UInt32 = 1073
DISPID_ISVGTEXTPOSITIONINGELEMENT_DX: UInt32 = 1075
DISPID_ISVGTEXTPOSITIONINGELEMENT_DY: UInt32 = 1077
DISPID_ISVGTEXTPOSITIONINGELEMENT_ROTATE: UInt32 = 1079
DISPID_IDOMDOCUMENTTYPE_NAME: UInt32 = 1000
DISPID_IDOMDOCUMENTTYPE_ENTITIES: UInt32 = 1001
DISPID_IDOMDOCUMENTTYPE_NOTATIONS: UInt32 = 1002
DISPID_IDOMDOCUMENTTYPE_PUBLICID: UInt32 = 1003
DISPID_IDOMDOCUMENTTYPE_SYSTEMID: UInt32 = 1004
DISPID_IDOMDOCUMENTTYPE_INTERNALSUBSET: UInt32 = 1005
DISPID_IDOMNODEITERATOR_ROOT: UInt32 = 1000
DISPID_IDOMNODEITERATOR_WHATTOSHOW: UInt32 = 1001
DISPID_IDOMNODEITERATOR_FILTER: UInt32 = 1002
DISPID_IDOMNODEITERATOR_EXPANDENTITYREFERENCES: UInt32 = 1003
DISPID_IDOMNODEITERATOR_NEXTNODE: UInt32 = 1010
DISPID_IDOMNODEITERATOR_PREVIOUSNODE: UInt32 = 1011
DISPID_IDOMNODEITERATOR_DETACH: UInt32 = 1012
DISPID_IDOMTREEWALKER_ROOT: UInt32 = 1000
DISPID_IDOMTREEWALKER_WHATTOSHOW: UInt32 = 1001
DISPID_IDOMTREEWALKER_FILTER: UInt32 = 1002
DISPID_IDOMTREEWALKER_EXPANDENTITYREFERENCES: UInt32 = 1003
DISPID_IDOMTREEWALKER_CURRENTNODE: UInt32 = 1020
DISPID_IDOMTREEWALKER_PARENTNODE: UInt32 = 1021
DISPID_IDOMTREEWALKER_FIRSTCHILD: UInt32 = 1022
DISPID_IDOMTREEWALKER_LASTCHILD: UInt32 = 1023
DISPID_IDOMTREEWALKER_PREVIOUSSIBLING: UInt32 = 1024
DISPID_IDOMTREEWALKER_NEXTSIBLING: UInt32 = 1025
DISPID_IDOMTREEWALKER_PREVIOUSNODE: UInt32 = 1026
DISPID_IDOMTREEWALKER_NEXTNODE: UInt32 = 1027
DISPID_IDOMPROCESSINGINSTRUCTION_TARGET: UInt32 = 1000
DISPID_IDOMPROCESSINGINSTRUCTION_DATA: UInt32 = 1001
DISPID_IHTMLPERFORMANCE_NAVIGATION: UInt32 = 1000
DISPID_IHTMLPERFORMANCE_TIMING: UInt32 = 1001
DISPID_IHTMLPERFORMANCE_TOSTRING: UInt32 = 1002
DISPID_IHTMLPERFORMANCE_TOJSON: UInt32 = 1003
DISPID_IHTMLPERFORMANCENAVIGATION_TYPE: UInt32 = 1000
DISPID_IHTMLPERFORMANCENAVIGATION_REDIRECTCOUNT: UInt32 = 1001
DISPID_IHTMLPERFORMANCENAVIGATION_TOSTRING: UInt32 = 1002
DISPID_IHTMLPERFORMANCENAVIGATION_TOJSON: UInt32 = 1003
DISPID_IHTMLPERFORMANCETIMING_NAVIGATIONSTART: UInt32 = 1000
DISPID_IHTMLPERFORMANCETIMING_UNLOADEVENTSTART: UInt32 = 1001
DISPID_IHTMLPERFORMANCETIMING_UNLOADEVENTEND: UInt32 = 1002
DISPID_IHTMLPERFORMANCETIMING_REDIRECTSTART: UInt32 = 1003
DISPID_IHTMLPERFORMANCETIMING_REDIRECTEND: UInt32 = 1004
DISPID_IHTMLPERFORMANCETIMING_FETCHSTART: UInt32 = 1005
DISPID_IHTMLPERFORMANCETIMING_DOMAINLOOKUPSTART: UInt32 = 1006
DISPID_IHTMLPERFORMANCETIMING_DOMAINLOOKUPEND: UInt32 = 1007
DISPID_IHTMLPERFORMANCETIMING_CONNECTSTART: UInt32 = 1008
DISPID_IHTMLPERFORMANCETIMING_CONNECTEND: UInt32 = 1009
DISPID_IHTMLPERFORMANCETIMING_REQUESTSTART: UInt32 = 1010
DISPID_IHTMLPERFORMANCETIMING_RESPONSESTART: UInt32 = 1011
DISPID_IHTMLPERFORMANCETIMING_RESPONSEEND: UInt32 = 1012
DISPID_IHTMLPERFORMANCETIMING_DOMLOADING: UInt32 = 1013
DISPID_IHTMLPERFORMANCETIMING_DOMINTERACTIVE: UInt32 = 1014
DISPID_IHTMLPERFORMANCETIMING_DOMCONTENTLOADEDEVENTSTART: UInt32 = 1015
DISPID_IHTMLPERFORMANCETIMING_DOMCONTENTLOADEDEVENTEND: UInt32 = 1016
DISPID_IHTMLPERFORMANCETIMING_DOMCOMPLETE: UInt32 = 1017
DISPID_IHTMLPERFORMANCETIMING_LOADEVENTSTART: UInt32 = 1018
DISPID_IHTMLPERFORMANCETIMING_LOADEVENTEND: UInt32 = 1019
DISPID_IHTMLPERFORMANCETIMING_MSFIRSTPAINT: UInt32 = 1020
DISPID_IHTMLPERFORMANCETIMING_TOSTRING: UInt32 = 1021
DISPID_IHTMLPERFORMANCETIMING_TOJSON: UInt32 = 1022
DISPID_ITEMPLATEPRINTER_STARTDOC: UInt32 = 1
DISPID_ITEMPLATEPRINTER_STOPDOC: UInt32 = 2
DISPID_ITEMPLATEPRINTER_PRINTBLANKPAGE: UInt32 = 3
DISPID_ITEMPLATEPRINTER_PRINTPAGE: UInt32 = 4
DISPID_ITEMPLATEPRINTER_ENSUREPRINTDIALOGDEFAULTS: UInt32 = 5
DISPID_ITEMPLATEPRINTER_SHOWPRINTDIALOG: UInt32 = 6
DISPID_ITEMPLATEPRINTER_SHOWPAGESETUPDIALOG: UInt32 = 7
DISPID_ITEMPLATEPRINTER_PRINTNONNATIVE: UInt32 = 8
DISPID_ITEMPLATEPRINTER_PRINTNONNATIVEFRAMES: UInt32 = 9
DISPID_ITEMPLATEPRINTER_FRAMESETDOCUMENT: UInt32 = 10
DISPID_ITEMPLATEPRINTER_FRAMEACTIVE: UInt32 = 11
DISPID_ITEMPLATEPRINTER_FRAMEASSHOWN: UInt32 = 12
DISPID_ITEMPLATEPRINTER_SELECTION: UInt32 = 13
DISPID_ITEMPLATEPRINTER_SELECTEDPAGES: UInt32 = 14
DISPID_ITEMPLATEPRINTER_CURRENTPAGE: UInt32 = 15
DISPID_ITEMPLATEPRINTER_CURRENTPAGEAVAIL: UInt32 = 16
DISPID_ITEMPLATEPRINTER_COLLATE: UInt32 = 17
DISPID_ITEMPLATEPRINTER_DUPLEX: UInt32 = 18
DISPID_ITEMPLATEPRINTER_COPIES: UInt32 = 19
DISPID_ITEMPLATEPRINTER_PAGEFROM: UInt32 = 20
DISPID_ITEMPLATEPRINTER_PAGETO: UInt32 = 21
DISPID_ITEMPLATEPRINTER_TABLEOFLINKS: UInt32 = 22
DISPID_ITEMPLATEPRINTER_ALLLINKEDDOCUMENTS: UInt32 = 23
DISPID_ITEMPLATEPRINTER_HEADER: UInt32 = 24
DISPID_ITEMPLATEPRINTER_FOOTER: UInt32 = 25
DISPID_ITEMPLATEPRINTER_MARGINLEFT: UInt32 = 26
DISPID_ITEMPLATEPRINTER_MARGINRIGHT: UInt32 = 27
DISPID_ITEMPLATEPRINTER_MARGINTOP: UInt32 = 28
DISPID_ITEMPLATEPRINTER_MARGINBOTTOM: UInt32 = 29
DISPID_ITEMPLATEPRINTER_PAGEWIDTH: UInt32 = 30
DISPID_ITEMPLATEPRINTER_PAGEHEIGHT: UInt32 = 31
DISPID_ITEMPLATEPRINTER_UNPRINTABLELEFT: UInt32 = 32
DISPID_ITEMPLATEPRINTER_UNPRINTABLETOP: UInt32 = 33
DISPID_ITEMPLATEPRINTER_UNPRINTABLERIGHT: UInt32 = 34
DISPID_ITEMPLATEPRINTER_UNPRINTABLEBOTTOM: UInt32 = 35
DISPID_ITEMPLATEPRINTER_UPDATEPAGESTATUS: UInt32 = 36
DISPID_ITEMPLATEPRINTER2_SELECTIONENABLED: UInt32 = 37
DISPID_ITEMPLATEPRINTER2_FRAMEACTIVEENABLED: UInt32 = 38
DISPID_ITEMPLATEPRINTER2_ORIENTATION: UInt32 = 39
DISPID_ITEMPLATEPRINTER2_USEPRINTERCOPYCOLLATE: UInt32 = 40
DISPID_ITEMPLATEPRINTER2_DEVICESUPPORTS: UInt32 = 41
DISPID_ITEMPLATEPRINTER3_HEADERFOOTERFONT: UInt32 = 42
DISPID_ITEMPLATEPRINTER3_GETPAGEMARGINTOP: UInt32 = 43
DISPID_ITEMPLATEPRINTER3_GETPAGEMARGINRIGHT: UInt32 = 44
DISPID_ITEMPLATEPRINTER3_GETPAGEMARGINBOTTOM: UInt32 = 45
DISPID_ITEMPLATEPRINTER3_GETPAGEMARGINLEFT: UInt32 = 46
DISPID_ITEMPLATEPRINTER3_GETPAGEMARGINTOPIMPORTANT: UInt32 = 47
DISPID_ITEMPLATEPRINTER3_GETPAGEMARGINRIGHTIMPORTANT: UInt32 = 48
DISPID_ITEMPLATEPRINTER3_GETPAGEMARGINBOTTOMIMPORTANT: UInt32 = 49
DISPID_ITEMPLATEPRINTER3_GETPAGEMARGINLEFTIMPORTANT: UInt32 = 50
DISPID_IPRINTMANAGERTEMPLATEPRINTER_STARTPRINT: UInt32 = 501
DISPID_IPRINTMANAGERTEMPLATEPRINTER_DRAWPREVIEWPAGE: UInt32 = 502
DISPID_IPRINTMANAGERTEMPLATEPRINTER_SETPAGECOUNT: UInt32 = 503
DISPID_IPRINTMANAGERTEMPLATEPRINTER_INVALIDATEPREVIEW: UInt32 = 504
DISPID_IPRINTMANAGERTEMPLATEPRINTER_GETPRINTTASKOPTIONVALUE: UInt32 = 505
DISPID_IPRINTMANAGERTEMPLATEPRINTER_ENDPRINT: UInt32 = 506
DISPID_IPRINTMANAGERTEMPLATEPRINTER2_SHOWHEADERFOOTER: UInt32 = 507
DISPID_IPRINTMANAGERTEMPLATEPRINTER2_SHRINKTOFIT: UInt32 = 508
DISPID_IPRINTMANAGERTEMPLATEPRINTER2_PERCENTSCALE: UInt32 = 509
DISPID_ISVGTEXTPATHELEMENT_STARTOFFSET: UInt32 = 1071
DISPID_ISVGTEXTPATHELEMENT_METHOD: UInt32 = 1073
DISPID_ISVGTEXTPATHELEMENT_SPACING: UInt32 = 1075
DISPID_IDOMXMLSERIALIZER_SERIALIZETOSTRING: UInt32 = 1000
DISPID_IDOMPARSER_PARSEFROMSTRING: UInt32 = 1000
DISPID_IDOMXMLSERIALIZERFACTORY_CREATE: UInt32 = 0
DISPID_IDOMPARSERFACTORY_CREATE: UInt32 = 0
DISPID_IHTMLPROGRESSELEMENT_VALUE: UInt32 = 0
DISPID_IHTMLPROGRESSELEMENT_MAX: UInt32 = 1000
DISPID_IHTMLPROGRESSELEMENT_POSITION: UInt32 = 1001
DISPID_IHTMLPROGRESSELEMENT_FORM: UInt32 = 67540
DISPID_IDOMMSTRANSITIONEVENT_PROPERTYNAME: UInt32 = 1476
DISPID_IDOMMSTRANSITIONEVENT_ELAPSEDTIME: UInt32 = 1477
DISPID_IDOMMSTRANSITIONEVENT_INITMSTRANSITIONEVENT: UInt32 = 1478
DISPID_IDOMMSANIMATIONEVENT_ANIMATIONNAME: UInt32 = 1501
DISPID_IDOMMSANIMATIONEVENT_ELAPSEDTIME: UInt32 = 1502
DISPID_IDOMMSANIMATIONEVENT_INITMSANIMATIONEVENT: UInt32 = 1503
DISPID_IWEBGEOLOCATION_GETCURRENTPOSITION: UInt32 = 1001
DISPID_IWEBGEOLOCATION_WATCHPOSITION: UInt32 = 1002
DISPID_IWEBGEOLOCATION_CLEARWATCH: UInt32 = 1003
DISPID_IWEBGEOCOORDINATES_LATITUDE: UInt32 = 1001
DISPID_IWEBGEOCOORDINATES_LONGITUDE: UInt32 = 1002
DISPID_IWEBGEOCOORDINATES_ALTITUDE: UInt32 = 1003
DISPID_IWEBGEOCOORDINATES_ACCURACY: UInt32 = 1004
DISPID_IWEBGEOCOORDINATES_ALTITUDEACCURACY: UInt32 = 1005
DISPID_IWEBGEOCOORDINATES_HEADING: UInt32 = 1006
DISPID_IWEBGEOCOORDINATES_SPEED: UInt32 = 1007
DISPID_IWEBGEOPOSITIONERROR_CODE: UInt32 = 1001
DISPID_IWEBGEOPOSITIONERROR_MESSAGE: UInt32 = 1002
DISPID_IWEBGEOPOSITION_COORDS: UInt32 = 1001
DISPID_IWEBGEOPOSITION_TIMESTAMP: UInt32 = 1002
DISPID_ICLIENTCAPS_JAVAENABLED: UInt32 = 1
DISPID_ICLIENTCAPS_COOKIEENABLED: UInt32 = 2
DISPID_ICLIENTCAPS_CPUCLASS: UInt32 = 3
DISPID_ICLIENTCAPS_SYSTEMLANGUAGE: UInt32 = 4
DISPID_ICLIENTCAPS_USERLANGUAGE: UInt32 = 5
DISPID_ICLIENTCAPS_PLATFORM: UInt32 = 6
DISPID_ICLIENTCAPS_CONNECTIONSPEED: UInt32 = 7
DISPID_ICLIENTCAPS_ONLINE: UInt32 = 8
DISPID_ICLIENTCAPS_COLORDEPTH: UInt32 = 9
DISPID_ICLIENTCAPS_BUFFERDEPTH: UInt32 = 10
DISPID_ICLIENTCAPS_WIDTH: UInt32 = 11
DISPID_ICLIENTCAPS_HEIGHT: UInt32 = 12
DISPID_ICLIENTCAPS_AVAILHEIGHT: UInt32 = 13
DISPID_ICLIENTCAPS_AVAILWIDTH: UInt32 = 14
DISPID_ICLIENTCAPS_CONNECTIONTYPE: UInt32 = 15
DISPID_ICLIENTCAPS_ISCOMPONENTINSTALLED: UInt32 = 16
DISPID_ICLIENTCAPS_GETCOMPONENTVERSION: UInt32 = 17
DISPID_ICLIENTCAPS_COMPAREVERSIONS: UInt32 = 18
DISPID_ICLIENTCAPS_ADDCOMPONENTREQUEST: UInt32 = 19
DISPID_ICLIENTCAPS_DOCOMPONENTREQUEST: UInt32 = 20
DISPID_ICLIENTCAPS_CLEARCOMPONENTREQUEST: UInt32 = 21
DISPID_IDOMMSMANIPULATIONEVENT_LASTSTATE: UInt32 = 1526
DISPID_IDOMMSMANIPULATIONEVENT_CURRENTSTATE: UInt32 = 1527
DISPID_IDOMMSMANIPULATIONEVENT_INITMSMANIPULATIONEVENT: UInt32 = 1528
DISPID_IDOMCLOSEEVENT_WASCLEAN: UInt32 = 1526
DISPID_IDOMCLOSEEVENT_INITCLOSEEVENT: UInt32 = 1529
DISPID_IHTMLAPPLICATIONCACHE_STATUS: UInt32 = 1001
DISPID_IHTMLAPPLICATIONCACHE_ONCHECKING: UInt32 = 71717
DISPID_IHTMLAPPLICATIONCACHE_ONERROR: UInt32 = 71565
DISPID_IHTMLAPPLICATIONCACHE_ONNOUPDATE: UInt32 = 71718
DISPID_IHTMLAPPLICATIONCACHE_ONDOWNLOADING: UInt32 = 71719
DISPID_IHTMLAPPLICATIONCACHE_ONPROGRESS: UInt32 = 71681
DISPID_IHTMLAPPLICATIONCACHE_ONUPDATEREADY: UInt32 = 71720
DISPID_IHTMLAPPLICATIONCACHE_ONCACHED: UInt32 = 71721
DISPID_IHTMLAPPLICATIONCACHE_ONOBSOLETE: UInt32 = 71722
DISPID_IHTMLAPPLICATIONCACHE_UPDATE: UInt32 = 1002
DISPID_IHTMLAPPLICATIONCACHE_SWAPCACHE: UInt32 = 1003
DISPID_IHTMLAPPLICATIONCACHE_ABORT: UInt32 = 1004
DISPID_ILINEINFO_X: UInt32 = 1001
DISPID_ILINEINFO_BASELINE: UInt32 = 1002
DISPID_ILINEINFO_TEXTDESCENT: UInt32 = 1003
DISPID_ILINEINFO_TEXTHEIGHT: UInt32 = 1004
DISPID_ILINEINFO_LINEDIRECTION: UInt32 = 1005
DISPID_IHTMLCOMPUTEDSTYLE_BOLD: UInt32 = 1001
DISPID_IHTMLCOMPUTEDSTYLE_ITALIC: UInt32 = 1002
DISPID_IHTMLCOMPUTEDSTYLE_UNDERLINE: UInt32 = 1003
DISPID_IHTMLCOMPUTEDSTYLE_OVERLINE: UInt32 = 1004
DISPID_IHTMLCOMPUTEDSTYLE_STRIKEOUT: UInt32 = 1005
DISPID_IHTMLCOMPUTEDSTYLE_SUBSCRIPT: UInt32 = 1006
DISPID_IHTMLCOMPUTEDSTYLE_SUPERSCRIPT: UInt32 = 1007
DISPID_IHTMLCOMPUTEDSTYLE_EXPLICITFACE: UInt32 = 1008
DISPID_IHTMLCOMPUTEDSTYLE_FONTWEIGHT: UInt32 = 1009
DISPID_IHTMLCOMPUTEDSTYLE_FONTSIZE: UInt32 = 1010
DISPID_IHTMLCOMPUTEDSTYLE_FONTNAME: UInt32 = 1011
DISPID_IHTMLCOMPUTEDSTYLE_HASBGCOLOR: UInt32 = 1012
DISPID_IHTMLCOMPUTEDSTYLE_TEXTCOLOR: UInt32 = 1013
DISPID_IHTMLCOMPUTEDSTYLE_BACKGROUNDCOLOR: UInt32 = 1014
DISPID_IHTMLCOMPUTEDSTYLE_PREFORMATTED: UInt32 = 1015
DISPID_IHTMLCOMPUTEDSTYLE_DIRECTION: UInt32 = 1016
DISPID_IHTMLCOMPUTEDSTYLE_BLOCKDIRECTION: UInt32 = 1017
DISPID_IHTMLCOMPUTEDSTYLE_OL: UInt32 = 1018
DISPID_IHTMLDLGSAFEHELPER_CHOOSECOLORDLG: UInt32 = 1
DISPID_IHTMLDLGSAFEHELPER_GETCHARSET: UInt32 = 2
DISPID_IHTMLDLGSAFEHELPER_FONTS: UInt32 = 3
DISPID_IHTMLDLGSAFEHELPER_BLOCKFORMATS: UInt32 = 4
DISPID_IBLOCKFORMATS__NEWENUM: Int32 = -4
DISPID_IBLOCKFORMATS_COUNT: UInt32 = 1
DISPID_IBLOCKFORMATS_ITEM: UInt32 = 0
DISPID_IFONTNAMES__NEWENUM: Int32 = -4
DISPID_IFONTNAMES_COUNT: UInt32 = 1
DISPID_IFONTNAMES_ITEM: UInt32 = 0
DISPID_IHTMLNAMESPACE_NAME: UInt32 = 1000
DISPID_IHTMLNAMESPACE_URN: UInt32 = 1001
DISPID_IHTMLNAMESPACE_TAGNAMES: UInt32 = 1002
DISPID_IHTMLNAMESPACE_READYSTATE: UInt32 = 70652
DISPID_IHTMLNAMESPACE_ONREADYSTATECHANGE: UInt32 = 71561
DISPID_IHTMLNAMESPACE_DOIMPORT: UInt32 = 1003
DISPID_IHTMLNAMESPACE_ATTACHEVENT: UInt32 = 66043
DISPID_IHTMLNAMESPACE_DETACHEVENT: UInt32 = 66044
DISPID_IHTMLNAMESPACECOLLECTION_LENGTH: UInt32 = 1000
DISPID_IHTMLNAMESPACECOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLNAMESPACECOLLECTION_ADD: UInt32 = 1001
DISPID_HTMLNAMESPACEEVENTS_ONREADYSTATECHANGE: Int32 = -609
DISPID_IHTMLIPRINTCOLLECTION_LENGTH: UInt32 = 1501
DISPID_IHTMLIPRINTCOLLECTION__NEWENUM: Int32 = -4
DISPID_IHTMLIPRINTCOLLECTION_ITEM: UInt32 = 0
DISPID_IHTMLDIALOG_DIALOGTOP: UInt32 = 65540
DISPID_IHTMLDIALOG_DIALOGLEFT: UInt32 = 65539
DISPID_IHTMLDIALOG_DIALOGWIDTH: UInt32 = 65541
DISPID_IHTMLDIALOG_DIALOGHEIGHT: UInt32 = 65542
DISPID_IHTMLDIALOG_DIALOGARGUMENTS: UInt32 = 25000
DISPID_IHTMLDIALOG_MENUARGUMENTS: UInt32 = 25013
DISPID_IHTMLDIALOG_RETURNVALUE: UInt32 = 25001
DISPID_IHTMLDIALOG_CLOSE: UInt32 = 25011
DISPID_IHTMLDIALOG_TOSTRING: UInt32 = 25012
DISPID_IHTMLDIALOG2_STATUS: UInt32 = 25014
DISPID_IHTMLDIALOG2_RESIZABLE: UInt32 = 25015
DISPID_IHTMLDIALOG3_UNADORNED: UInt32 = 25016
DISPID_IHTMLDIALOG3_DIALOGHIDE: UInt32 = 25007
DISPID_IHTMLMODELESSINIT_PARAMETERS: UInt32 = 25000
DISPID_IHTMLMODELESSINIT_OPTIONSTRING: UInt32 = 25001
DISPID_IHTMLMODELESSINIT_MONIKER: UInt32 = 25006
DISPID_IHTMLMODELESSINIT_DOCUMENT: UInt32 = 25007
DISPID_IHTMLPOPUP_SHOW: UInt32 = 27001
DISPID_IHTMLPOPUP_HIDE: UInt32 = 27002
DISPID_IHTMLPOPUP_DOCUMENT: UInt32 = 27003
DISPID_IHTMLPOPUP_ISOPEN: UInt32 = 27004
DISPID_IHTMLAPPBEHAVIOR_APPLICATIONNAME: UInt32 = 5000
DISPID_IHTMLAPPBEHAVIOR_VERSION: UInt32 = 5001
DISPID_IHTMLAPPBEHAVIOR_ICON: UInt32 = 5002
DISPID_IHTMLAPPBEHAVIOR_SINGLEINSTANCE: UInt32 = 5003
DISPID_IHTMLAPPBEHAVIOR_MINIMIZEBUTTON: UInt32 = 5005
DISPID_IHTMLAPPBEHAVIOR_MAXIMIZEBUTTON: UInt32 = 5006
DISPID_IHTMLAPPBEHAVIOR_BORDER: UInt32 = 5007
DISPID_IHTMLAPPBEHAVIOR_BORDERSTYLE: UInt32 = 5008
DISPID_IHTMLAPPBEHAVIOR_SYSMENU: UInt32 = 5009
DISPID_IHTMLAPPBEHAVIOR_CAPTION: UInt32 = 5010
DISPID_IHTMLAPPBEHAVIOR_WINDOWSTATE: UInt32 = 5011
DISPID_IHTMLAPPBEHAVIOR_SHOWINTASKBAR: UInt32 = 5012
DISPID_IHTMLAPPBEHAVIOR_COMMANDLINE: UInt32 = 5013
DISPID_IHTMLAPPBEHAVIOR2_CONTEXTMENU: UInt32 = 5014
DISPID_IHTMLAPPBEHAVIOR2_INNERBORDER: UInt32 = 5015
DISPID_IHTMLAPPBEHAVIOR2_SCROLL: UInt32 = 5016
DISPID_IHTMLAPPBEHAVIOR2_SCROLLFLAT: UInt32 = 5017
DISPID_IHTMLAPPBEHAVIOR2_SELECTION: UInt32 = 5018
DISPID_IHTMLAPPBEHAVIOR3_NAVIGABLE: UInt32 = 5019
DISPID_IHTMLTXTRANGEINTERNAL_GET_VISIBLETEXT: UInt32 = 1050
DISPID_IE9EVENTS_ABORT: UInt32 = 1000
DISPID_IE9EVENTS_ACTIVATE: UInt32 = 1044
DISPID_IE9EVENTS_AFTERPRINT: UInt32 = 1025
DISPID_IE9EVENTS_BEFOREACTIVATE: UInt32 = 1047
DISPID_IE9EVENTS_BEFOREDEACTIVATE: UInt32 = 1034
DISPID_IE9EVENTS_BEFOREUNLOAD: UInt32 = 1017
DISPID_IE9EVENTS_BEFOREPRINT: UInt32 = 1024
DISPID_IE9EVENTS_BOUNCE: UInt32 = 1009
DISPID_IE9EVENTS_CHANGE: UInt32 = 1001
DISPID_IE9EVENTS_CLICK: Int32 = -600
DISPID_IE9EVENTS_COMPLETE: UInt32 = 71727
DISPID_IE9EVENTS_CONTEXTMENU: UInt32 = 1023
DISPID_IE9EVENTS_DEACTIVATE: UInt32 = 1045
DISPID_IE9EVENTS_DOMCONTENTLOADED: UInt32 = 71662
DISPID_IE9EVENTS_SUCCESS: UInt32 = 71725
DISPID_IE9EVENTS_ERROR: UInt32 = 1002
DISPID_IE9EVENTS_FINISH: UInt32 = 1010
DISPID_IE9EVENTS_FOCUS: UInt32 = 65537
DISPID_IE9EVENTS_FOCUSIN: UInt32 = 1048
DISPID_IE9EVENTS_FOCUSOUT: UInt32 = 1049
DISPID_IE9EVENTS_HASHCHANGE: UInt32 = 1066
DISPID_IE9EVENTS_HELP: UInt32 = 65546
DISPID_IE9EVENTS_INPUT: UInt32 = 71663
DISPID_IE9EVENTS_LOAD: UInt32 = 1003
DISPID_IE9EVENTS_KEYDOWN: Int32 = -602
DISPID_IE9EVENTS_KEYPRESS: Int32 = -603
DISPID_IE9EVENTS_KEYUP: Int32 = -604
DISPID_IE9EVENTS_MESSAGE: UInt32 = 1067
DISPID_IE9EVENTS_ONLINE: UInt32 = 1064
DISPID_IE9EVENTS_OFFLINE: UInt32 = 1065
DISPID_IE9EVENTS_READYSTATECHANGE: Int32 = -609
DISPID_IE9EVENTS_RESET: UInt32 = 1015
DISPID_IE9EVENTS_RESIZE: UInt32 = 1016
DISPID_IE9EVENTS_SCROLL: UInt32 = 1014
DISPID_IE9EVENTS_SELECT: UInt32 = 1006
DISPID_IE9EVENTS_SELECTIONCHANGE: UInt32 = 1037
DISPID_IE9EVENTS_SELECTSTART: UInt32 = 65548
DISPID_IE9EVENTS_START: UInt32 = 1011
DISPID_IE9EVENTS_STOP: UInt32 = 1026
DISPID_IE9EVENTS_STORAGE: UInt32 = 1057
DISPID_IE9EVENTS_STORAGECOMMIT: UInt32 = 1058
DISPID_IE9EVENTS_SUBMIT: UInt32 = 1007
DISPID_IE9EVENTS_TEXTINPUT: UInt32 = 71665
DISPID_IE9EVENTS_TIMEOUT: UInt32 = 0
DISPID_IE9EVENTS_UNLOAD: UInt32 = 1008
DISPID_IE9EVENTS_WHEEL: UInt32 = 71649
DISPID_IE9EVENTS_DBLCLICK: Int32 = -601
DISPID_IE9EVENTS_MOUSEDOWN: Int32 = -605
DISPID_IE9EVENTS_MOUSEENTER: UInt32 = 1042
DISPID_IE9EVENTS_MOUSELEAVE: UInt32 = 1043
DISPID_IE9EVENTS_MOUSEMOVE: Int32 = -606
DISPID_IE9EVENTS_MOUSEOUT: UInt32 = 65545
DISPID_IE9EVENTS_MOUSEOVER: UInt32 = 65544
DISPID_IE9EVENTS_MOUSEUP: Int32 = -607
DISPID_IE9EVENTS_MOUSEWHEEL: UInt32 = 1033
DISPID_IE9EVENTS_BEFORECOPY: UInt32 = 65566
DISPID_IE9EVENTS_BEFORECUT: UInt32 = 65565
DISPID_IE9EVENTS_BEFOREPASTE: UInt32 = 65567
DISPID_IE9EVENTS_COPY: UInt32 = 65563
DISPID_IE9EVENTS_CUT: UInt32 = 65562
DISPID_IE9EVENTS_DRAG: UInt32 = 65556
DISPID_IE9EVENTS_DRAGEND: UInt32 = 65557
DISPID_IE9EVENTS_DRAGENTER: UInt32 = 65558
DISPID_IE9EVENTS_DRAGLEAVE: UInt32 = 65560
DISPID_IE9EVENTS_DRAGOVER: UInt32 = 65559
DISPID_IE9EVENTS_DRAGSTART: UInt32 = 65547
DISPID_IE9EVENTS_DROP: UInt32 = 65561
DISPID_IE9EVENTS_PASTE: UInt32 = 65564
DISPID_IE9EVENTS_MSBEFOREEDITFOCUS: UInt32 = 1027
DISPID_IE9EVENTS_MSCONTROLSELECT: UInt32 = 1036
DISPID_IE9EVENTS_MSCONTROLRESIZESTART: UInt32 = 1040
DISPID_IE9EVENTS_MSCONTROLRESIZEEND: UInt32 = 1041
DISPID_IE9EVENTS_COMPOSITIONSTART: UInt32 = 71658
DISPID_IE9EVENTS_COMPOSITIONUPDATE: UInt32 = 71659
DISPID_IE9EVENTS_COMPOSITIONEND: UInt32 = 71660
DISPID_IE9EVENTS_DOMATTRMODIFIED: UInt32 = 71661
DISPID_IE9EVENTS_DOMCHARACTERDATAMODIFIED: UInt32 = 71664
DISPID_IE9EVENTS_DOMNODEINSERTED: UInt32 = 71667
DISPID_IE9EVENTS_DOMNODEREMOVED: UInt32 = 71668
DISPID_IE9EVENTS_DOMSUBTREEMODIFIED: UInt32 = 71669
DISPID_IE9EVENTS_SVGLOAD: UInt32 = 71650
DISPID_IE9EVENTS_SVGUNLOAD: UInt32 = 71651
DISPID_IE9EVENTS_SVGABORT: UInt32 = 71652
DISPID_IE9EVENTS_SVGERROR: UInt32 = 71653
DISPID_IE9EVENTS_SVGRESIZE: UInt32 = 71654
DISPID_IE9EVENTS_SVGSCROLL: UInt32 = 71655
DISPID_IE9EVENTS_SVGZOOM: UInt32 = 71656
DISPID_IE9EVENTS_MSTHUMBNAILCLICK: UInt32 = 71657
DISPID_IE9EVENTS_MSSITEMODEJUMPLISTITEMREMOVED: UInt32 = 71666
DISPID_IE9EVENTS_CANPLAY: UInt32 = 71670
DISPID_IE9EVENTS_CANPLAYTHROUGH: UInt32 = 71671
DISPID_IE9EVENTS_DURATIONCHANGE: UInt32 = 71672
DISPID_IE9EVENTS_EMPTIED: UInt32 = 71673
DISPID_IE9EVENTS_ENDED: UInt32 = 71674
DISPID_IE9EVENTS_LOADEDDATA: UInt32 = 71675
DISPID_IE9EVENTS_LOADEDMETADATA: UInt32 = 71676
DISPID_IE9EVENTS_LOADSTART: UInt32 = 71677
DISPID_IE9EVENTS_PAUSE: UInt32 = 71678
DISPID_IE9EVENTS_PLAY: UInt32 = 71679
DISPID_IE9EVENTS_PLAYING: UInt32 = 71680
DISPID_IE9EVENTS_PROGRESS: UInt32 = 71681
DISPID_IE9EVENTS_RATECHANGE: UInt32 = 71682
DISPID_IE9EVENTS_SEEKED: UInt32 = 71683
DISPID_IE9EVENTS_SEEKING: UInt32 = 71684
DISPID_IE9EVENTS_STALLED: UInt32 = 71685
DISPID_IE9EVENTS_SUSPEND: UInt32 = 71686
DISPID_IE9EVENTS_TIMEUPDATE: UInt32 = 71687
DISPID_IE9EVENTS_VOLUMECHANGE: UInt32 = 71688
DISPID_IE9EVENTS_WAITING: UInt32 = 71689
DISPID_IE9EVENTS_BLOCKED: UInt32 = 71726
DISPID_IE9EVENTS_UPGRADENEEDED: UInt32 = 71734
DISPID_IE9EVENTS_CUECHANGE: UInt32 = 71729
DISPID_IE9EVENTS_ENTER: UInt32 = 71730
DISPID_IE9EVENTS_EXIT: UInt32 = 71731
DISPID_IE9EVENTS_ADDTRACK: UInt32 = 71736
DISPID_IE9EVENTS_REMOVETRACK: UInt32 = 71781
DISPID_IE9EVENTS_MSPOINTERDOWN: UInt32 = 71690
DISPID_IE9EVENTS_MSPOINTERMOVE: UInt32 = 71691
DISPID_IE9EVENTS_MSPOINTERUP: UInt32 = 71692
DISPID_IE9EVENTS_MSPOINTEROVER: UInt32 = 71693
DISPID_IE9EVENTS_MSPOINTEROUT: UInt32 = 71694
DISPID_IE9EVENTS_MSPOINTERCANCEL: UInt32 = 71695
DISPID_IE9EVENTS_MSPOINTERHOVER: UInt32 = 71696
DISPID_IE9EVENTS_MSLOSTPOINTERCAPTURE: UInt32 = 71706
DISPID_IE9EVENTS_MSGOTPOINTERCAPTURE: UInt32 = 71707
DISPID_IE9EVENTS_MSPOINTERENTER: UInt32 = 71769
DISPID_IE9EVENTS_MSPOINTERLEAVE: UInt32 = 71770
DISPID_IE9EVENTS_TOUCHSTART: UInt32 = 71784
DISPID_IE9EVENTS_TOUCHEND: UInt32 = 71785
DISPID_IE9EVENTS_TOUCHMOVE: UInt32 = 71786
DISPID_IE9EVENTS_TOUCHCANCEL: UInt32 = 71787
DISPID_IE9EVENTS_MSGESTURESTART: UInt32 = 71699
DISPID_IE9EVENTS_MSGESTURECHANGE: UInt32 = 71700
DISPID_IE9EVENTS_MSGESTUREEND: UInt32 = 71701
DISPID_IE9EVENTS_MSGESTUREHOLD: UInt32 = 71702
DISPID_IE9EVENTS_MSGESTURETAP: UInt32 = 71703
DISPID_IE9EVENTS_MSGESTUREDOUBLETAP: UInt32 = 71704
DISPID_IE9EVENTS_MSINERTIASTART: UInt32 = 71705
DISPID_IE9EVENTS_MSCONTENTZOOM: UInt32 = 71708
DISPID_IE9EVENTS_MSHOLDVISUAL: UInt32 = 71738
DISPID_IE9EVENTS_TRANSITIONSTART: UInt32 = 71709
DISPID_IE9EVENTS_TRANSITIONEND: UInt32 = 71710
DISPID_IE9EVENTS_ANIMATIONSTART: UInt32 = 71711
DISPID_IE9EVENTS_ANIMATIONEND: UInt32 = 71712
DISPID_IE9EVENTS_ANIMATIONITERATION: UInt32 = 71713
DISPID_IE9EVENTS_MSMANIPULATIONSTATECHANGED: UInt32 = 71714
DISPID_IE9EVENTS_CHECKING: UInt32 = 71717
DISPID_IE9EVENTS_NOUPDATE: UInt32 = 71718
DISPID_IE9EVENTS_DOWNLOADING: UInt32 = 71719
DISPID_IE9EVENTS_UPDATEREADY: UInt32 = 71720
DISPID_IE9EVENTS_CACHED: UInt32 = 71721
DISPID_IE9EVENTS_OBSOLETE: UInt32 = 71722
DISPID_IE9EVENTS_INVALID: UInt32 = 71724
DISPID_IE9EVENTS_OPEN: UInt32 = 71715
DISPID_IE9EVENTS_CLOSE: UInt32 = 71716
DISPID_IE9EVENTS_LOADEND: UInt32 = 71723
DISPID_IE9EVENTS_POPSTATE: UInt32 = 71728
DISPID_IE9EVENTS_VISIBILITYCHANGE: UInt32 = 71732
DISPID_IE9EVENTS_MSREGIONUPDATE: UInt32 = 71733
DISPID_IE9EVENTS_MSVIDEOFORMATCHANGED: UInt32 = 71735
DISPID_IE9EVENTS_MSVIDEOFRAMESTEPCOMPLETED: UInt32 = 71737
DISPID_IE9EVENTS_MSVIDEOOPTIMALLAYOUTCHANGED: UInt32 = 71739
DISPID_IE9EVENTS_MSFULLSCREENCHANGE: UInt32 = 71740
DISPID_IE9EVENTS_MSFULLSCREENERROR: UInt32 = 71741
DISPID_IE9EVENTS_MSELEMENTRESIZE: UInt32 = 71742
DISPID_IE9EVENTS_SOURCEOPEN: UInt32 = 71743
DISPID_IE9EVENTS_SOURCEENDED: UInt32 = 71745
DISPID_IE9EVENTS_SOURCECLOSE: UInt32 = 71744
DISPID_IE9EVENTS_ADDSOURCEBUFFER: UInt32 = 71746
DISPID_IE9EVENTS_REMOVESOURCEBUFFER: UInt32 = 71747
DISPID_IE9EVENTS_UPDATESTART: UInt32 = 71766
DISPID_IE9EVENTS_UPDATE: UInt32 = 71767
DISPID_IE9EVENTS_UPDATEEND: UInt32 = 71768
DISPID_IE9EVENTS_MSNEEDKEY: UInt32 = 71748
DISPID_IE9EVENTS_MSKEYMESSAGE: UInt32 = 71749
DISPID_IE9EVENTS_MSKEYERROR: UInt32 = 71750
DISPID_IE9EVENTS_MSKEYADDED: UInt32 = 71751
DISPID_IE9EVENTS_MSWEBVIEWDOMCONTENTLOADED: UInt32 = 71752
DISPID_IE9EVENTS_MSWEBVIEWCONTENTLOADING: UInt32 = 71753
DISPID_IE9EVENTS_MSWEBVIEWNAVIGATIONSTARTING: UInt32 = 71754
DISPID_IE9EVENTS_MSWEBVIEWNAVIGATIONCOMPLETED: UInt32 = 71755
DISPID_IE9EVENTS_MSWEBVIEWFRAMEDOMCONTENTLOADED: UInt32 = 71756
DISPID_IE9EVENTS_MSWEBVIEWFRAMECONTENTLOADING: UInt32 = 71757
DISPID_IE9EVENTS_MSWEBVIEWFRAMENAVIGATIONSTARTING: UInt32 = 71758
DISPID_IE9EVENTS_MSWEBVIEWFRAMENAVIGATIONCOMPLETED: UInt32 = 71759
DISPID_IE9EVENTS_MSWEBVIEWSCRIPTNOTIFY: UInt32 = 71760
DISPID_IE9EVENTS_MSWEBVIEWLONGRUNNINGSCRIPTDETECTED: UInt32 = 71763
DISPID_IE9EVENTS_MSWEBVIEWUNVIEWABLECONTENTIDENTIFIED: UInt32 = 71761
DISPID_IE9EVENTS_MSWEBVIEWUNSAFECONTENTWARNINGDISPLAYING: UInt32 = 71762
DISPID_IE9EVENTS_MSWEBVIEWCONTAINSFULLSCREENELEMENTCHANGED: UInt32 = 71783
DISPID_IE9EVENTS_WEBGLCONTEXTLOST: UInt32 = 71764
DISPID_IE9EVENTS_WEBGLCONTEXTRESTORED: UInt32 = 71765
DISPID_IE9EVENTS_WEBGLCONTEXTCREATIONERROR: UInt32 = 71792
DISPID_IE9EVENTS_MSSITEPINNED: UInt32 = 71771
DISPID_IE9EVENTS_MSORIENTATIONCHANGE: UInt32 = 71772
DISPID_IE9EVENTS_ORIENTATIONCHANGE: UInt32 = 71795
DISPID_IE9EVENTS_DEVICEORIENTATION: UInt32 = 71773
DISPID_IE9EVENTS_DEVICEMOTION: UInt32 = 71774
DISPID_IE9EVENTS_COMPASSNEEDSCALIBRATION: UInt32 = 71782
DISPID_IE9EVENTS_PAGESHOW: UInt32 = 71775
DISPID_IE9EVENTS_PAGEHIDE: UInt32 = 71776
DISPID_IE9EVENTS_MSCANDIDATEWINDOWSHOW: UInt32 = 71777
DISPID_IE9EVENTS_MSCANDIDATEWINDOWUPDATE: UInt32 = 71778
DISPID_IE9EVENTS_MSCANDIDATEWINDOWHIDE: UInt32 = 71779
CONTEXT_MENU_DEFAULT: UInt32 = 0
CONTEXT_MENU_IMAGE: UInt32 = 1
CONTEXT_MENU_CONTROL: UInt32 = 2
CONTEXT_MENU_TABLE: UInt32 = 3
CONTEXT_MENU_TEXTSELECT: UInt32 = 4
CONTEXT_MENU_ANCHOR: UInt32 = 5
CONTEXT_MENU_UNKNOWN: UInt32 = 6
CONTEXT_MENU_IMGDYNSRC: UInt32 = 7
CONTEXT_MENU_DEBUG: UInt32 = 8
CONTEXT_MENU_VSCROLL: UInt32 = 9
CONTEXT_MENU_HSCROLL: UInt32 = 10
CONTEXT_MENU_MEDIA: UInt32 = 11
CONTEXT_MENU_ENTITY: UInt32 = 12
CONTEXT_MENU_PDF: UInt32 = 13
CONTEXT_MENU_DISABLEDFLASH: UInt32 = 14
MENUEXT_SHOWDIALOG: UInt32 = 1
HTMLDLG_NOUI: UInt32 = 16
HTMLDLG_MODAL: UInt32 = 32
HTMLDLG_MODELESS: UInt32 = 64
HTMLDLG_PRINT_TEMPLATE: UInt32 = 128
HTMLDLG_VERIFY: UInt32 = 256
HTMLDLG_ALLOW_UNKNOWN_THREAD: UInt32 = 512
PRINT_DONTBOTHERUSER: UInt32 = 1
PRINT_WAITFORCOMPLETION: UInt32 = 2
CMDID_SCRIPTSITE_URL: UInt32 = 0
CMDID_SCRIPTSITE_HTMLDLGTRUST: UInt32 = 1
CMDID_SCRIPTSITE_SECSTATE: UInt32 = 2
CMDID_SCRIPTSITE_SID: UInt32 = 3
CMDID_SCRIPTSITE_TRUSTEDDOC: UInt32 = 4
CMDID_SCRIPTSITE_SECURITY_WINDOW: UInt32 = 5
CMDID_SCRIPTSITE_NAMESPACE: UInt32 = 6
CMDID_SCRIPTSITE_IURI: UInt32 = 7
CMDID_HOSTCONTEXT_URL: UInt32 = 8
CMDID_SCRIPTSITE_ALLOWRECOVERY: UInt32 = 9
CMDID_SCRIPTSITE_BASEIURI: UInt32 = 10
SZ_HTML_CLIENTSITE_OBJECTPARAM: String = '{d4db6850-5385-11d0-89e9-00a0c90a90ac}'
CGID_DocHostCommandHandler: Guid = Guid('{f38bc242-b950-11d1-8918-00c04fc2c836}')
SID_SEditCommandTarget: Guid = Guid('{3050f4b5-98b5-11cf-bb82-00aa00bdce0b}')
CGID_EditStateCommands: Guid = Guid('{3050f4b6-98b5-11cf-bb82-00aa00bdce0b}')
SID_SHTMLEditHost: Guid = Guid('{3050f6a0-98b5-11cf-bb82-00aa00bdce0b}')
SID_SHTMLEditServices: Guid = Guid('{3050f7f9-98b5-11cf-bb82-00aa00bdce0b}')
COOKIEACTION_NONE: UInt32 = 0
COOKIEACTION_ACCEPT: UInt32 = 1
COOKIEACTION_REJECT: UInt32 = 2
COOKIEACTION_DOWNGRADE: UInt32 = 4
COOKIEACTION_LEASH: UInt32 = 8
COOKIEACTION_SUPPRESS: UInt32 = 16
COOKIEACTION_READ: UInt32 = 32
PRIVACY_URLISTOPLEVEL: UInt32 = 65536
PRIVACY_URLHASCOMPACTPOLICY: UInt32 = 131072
PRIVACY_URLHASPOSTDATA: UInt32 = 524288
PRIVACY_URLHASPOLICYREFLINK: UInt32 = 1048576
PRIVACY_URLHASPOLICYREFHEADER: UInt32 = 2097152
PRIVACY_URLHASP3PHEADER: UInt32 = 4194304
DEBUGCALLBACKNOTIFICATION_TIMEOUT: UInt32 = 1
DEBUGCALLBACKNOTIFICATION_INTERVAL: UInt32 = 2
DEBUGCALLBACKNOTIFICATION_IMMEDIATE: UInt32 = 4
DEBUGCALLBACKNOTIFICATION_ANIMATIONFRAME: UInt32 = 8
DEBUGCALLBACKNOTIFICATION_DOMEVENT: UInt32 = 16
DEBUGDOMEVENTPROPAGATIONSTATUS_DEFAULTCANCELED: UInt32 = 1
DEBUGDOMEVENTPROPAGATIONSTATUS_STOPIMMEDIATEPROPAGATION: UInt32 = 2
DEBUGDOMEVENTPROPAGATIONSTATUS_STOPPROPAGATION: UInt32 = 4
@winfunctype('SHDOCVW.dll')
def DoPrivacyDlg(hwndOwner: win32more.Windows.Win32.Foundation.HWND, pszUrl: win32more.Windows.Win32.Foundation.PWSTR, pPrivacyEnum: win32more.Windows.Win32.Web.MsHtml.IEnumPrivacyRecords, fReportAllSites: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
ApplicationCache = Guid('{30510829-98b5-11cf-bb82-00aa00bdce0b}')
BEHAVIOR_EVENT = Int32
BEHAVIOREVENT_FIRST: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_EVENT = 0
BEHAVIOREVENT_CONTENTREADY: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_EVENT = 0
BEHAVIOREVENT_DOCUMENTREADY: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_EVENT = 1
BEHAVIOREVENT_APPLYSTYLE: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_EVENT = 2
BEHAVIOREVENT_DOCUMENTCONTEXTCHANGE: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_EVENT = 3
BEHAVIOREVENT_CONTENTSAVE: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_EVENT = 4
BEHAVIOREVENT_LAST: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_EVENT = 4
BEHAVIOR_EVENT_Max: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_EVENT = 2147483647
BEHAVIOR_EVENT_FLAGS = Int32
BEHAVIOREVENTFLAGS_BUBBLE: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_EVENT_FLAGS = 1
BEHAVIOREVENTFLAGS_STANDARDADDITIVE: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_EVENT_FLAGS = 2
BEHAVIOR_EVENT_FLAGS_Max: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_EVENT_FLAGS = 2147483647
BEHAVIOR_LAYOUT_INFO = Int32
BEHAVIORLAYOUTINFO_FULLDELEGATION: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_LAYOUT_INFO = 1
BEHAVIORLAYOUTINFO_MODIFYNATURAL: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_LAYOUT_INFO = 2
BEHAVIORLAYOUTINFO_MAPSIZE: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_LAYOUT_INFO = 4
BEHAVIOR_LAYOUT_INFO_Max: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_LAYOUT_INFO = 2147483647
BEHAVIOR_LAYOUT_MODE = Int32
BEHAVIORLAYOUTMODE_NATURAL: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_LAYOUT_MODE = 1
BEHAVIORLAYOUTMODE_MINWIDTH: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_LAYOUT_MODE = 2
BEHAVIORLAYOUTMODE_MAXWIDTH: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_LAYOUT_MODE = 4
BEHAVIORLAYOUTMODE_MEDIA_RESOLUTION: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_LAYOUT_MODE = 16384
BEHAVIORLAYOUTMODE_FINAL_PERCENT: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_LAYOUT_MODE = 32768
BEHAVIOR_LAYOUT_MODE_Max: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_LAYOUT_MODE = 2147483647
BEHAVIOR_RELATION = Int32
BEHAVIOR_FIRSTRELATION: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RELATION = 0
BEHAVIOR_SAMEELEMENT: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RELATION = 0
BEHAVIOR_PARENT: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RELATION = 1
BEHAVIOR_CHILD: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RELATION = 2
BEHAVIOR_SIBLING: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RELATION = 3
BEHAVIOR_LASTRELATION: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RELATION = 3
BEHAVIOR_RELATION_Max: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RELATION = 2147483647
BEHAVIOR_RENDER_INFO = Int32
BEHAVIORRENDERINFO_BEFOREBACKGROUND: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RENDER_INFO = 1
BEHAVIORRENDERINFO_AFTERBACKGROUND: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RENDER_INFO = 2
BEHAVIORRENDERINFO_BEFORECONTENT: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RENDER_INFO = 4
BEHAVIORRENDERINFO_AFTERCONTENT: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RENDER_INFO = 8
BEHAVIORRENDERINFO_AFTERFOREGROUND: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RENDER_INFO = 32
BEHAVIORRENDERINFO_ABOVECONTENT: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RENDER_INFO = 40
BEHAVIORRENDERINFO_ALLLAYERS: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RENDER_INFO = 255
BEHAVIORRENDERINFO_DISABLEBACKGROUND: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RENDER_INFO = 256
BEHAVIORRENDERINFO_DISABLENEGATIVEZ: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RENDER_INFO = 512
BEHAVIORRENDERINFO_DISABLECONTENT: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RENDER_INFO = 1024
BEHAVIORRENDERINFO_DISABLEPOSITIVEZ: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RENDER_INFO = 2048
BEHAVIORRENDERINFO_DISABLEALLLAYERS: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RENDER_INFO = 3840
BEHAVIORRENDERINFO_HITTESTING: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RENDER_INFO = 4096
BEHAVIORRENDERINFO_SURFACE: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RENDER_INFO = 1048576
BEHAVIORRENDERINFO_3DSURFACE: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RENDER_INFO = 2097152
BEHAVIOR_RENDER_INFO_Max: win32more.Windows.Win32.Web.MsHtml.BEHAVIOR_RENDER_INFO = 2147483647
BlockFormats = Guid('{3050f831-98b5-11cf-bb82-00aa00bdce0b}')
CARET_DIRECTION = Int32
CARET_DIRECTION_INDETERMINATE: win32more.Windows.Win32.Web.MsHtml.CARET_DIRECTION = 0
CARET_DIRECTION_SAME: win32more.Windows.Win32.Web.MsHtml.CARET_DIRECTION = 1
CARET_DIRECTION_BACKWARD: win32more.Windows.Win32.Web.MsHtml.CARET_DIRECTION = 2
CARET_DIRECTION_FORWARD: win32more.Windows.Win32.Web.MsHtml.CARET_DIRECTION = 3
CARET_DIRECTION_Max: win32more.Windows.Win32.Web.MsHtml.CARET_DIRECTION = 2147483647
CClientCaps = Guid('{7e8bc44e-aeff-11d1-89c2-00c04fb6bfc4}')
CEventObj = Guid('{3050f48a-98b5-11cf-bb82-00aa00bdce0b}')
CMimeTypes = Guid('{3050f3fe-98b5-11cf-bb82-00aa00bdce0b}')
COORD_SYSTEM = Int32
COORD_SYSTEM_GLOBAL: win32more.Windows.Win32.Web.MsHtml.COORD_SYSTEM = 0
COORD_SYSTEM_PARENT: win32more.Windows.Win32.Web.MsHtml.COORD_SYSTEM = 1
COORD_SYSTEM_CONTAINER: win32more.Windows.Win32.Web.MsHtml.COORD_SYSTEM = 2
COORD_SYSTEM_CONTENT: win32more.Windows.Win32.Web.MsHtml.COORD_SYSTEM = 3
COORD_SYSTEM_FRAME: win32more.Windows.Win32.Web.MsHtml.COORD_SYSTEM = 4
COORD_SYSTEM_CLIENT: win32more.Windows.Win32.Web.MsHtml.COORD_SYSTEM = 5
COORD_SYSTEM_Max: win32more.Windows.Win32.Web.MsHtml.COORD_SYSTEM = 2147483647
COpsProfile = Guid('{3050f402-98b5-11cf-bb82-00aa00bdce0b}')
CPlugins = Guid('{3050f3ff-98b5-11cf-bb82-00aa00bdce0b}')
CPrintManagerTemplatePrinter = Guid('{63619f54-9d71-4c23-a08d-50d7f18db2e9}')
CTemplatePrinter = Guid('{3050f6b3-98b5-11cf-bb82-00aa00bdce0b}')
CanvasGradient = Guid('{30510715-98b5-11cf-bb82-00aa00bdce0b}')
CanvasImageData = Guid('{3051071b-98b5-11cf-bb82-00aa00bdce0b}')
CanvasPattern = Guid('{30510717-98b5-11cf-bb82-00aa00bdce0b}')
CanvasRenderingContext2D = Guid('{30510700-98b5-11cf-bb82-00aa00bdce0b}')
CanvasTextMetrics = Guid('{30510719-98b5-11cf-bb82-00aa00bdce0b}')
DEV_CONSOLE_MESSAGE_LEVEL = Int32
DCML_INFORMATIONAL: win32more.Windows.Win32.Web.MsHtml.DEV_CONSOLE_MESSAGE_LEVEL = 0
DCML_WARNING: win32more.Windows.Win32.Web.MsHtml.DEV_CONSOLE_MESSAGE_LEVEL = 1
DCML_ERROR: win32more.Windows.Win32.Web.MsHtml.DEV_CONSOLE_MESSAGE_LEVEL = 2
DEV_CONSOLE_MESSAGE_LEVEL_Max: win32more.Windows.Win32.Web.MsHtml.DEV_CONSOLE_MESSAGE_LEVEL = 2147483647
DISPLAY_BREAK = Int32
DISPLAY_BREAK_None: win32more.Windows.Win32.Web.MsHtml.DISPLAY_BREAK = 0
DISPLAY_BREAK_Block: win32more.Windows.Win32.Web.MsHtml.DISPLAY_BREAK = 1
DISPLAY_BREAK_Break: win32more.Windows.Win32.Web.MsHtml.DISPLAY_BREAK = 2
DISPLAY_BREAK_Max: win32more.Windows.Win32.Web.MsHtml.DISPLAY_BREAK = 2147483647
DISPLAY_GRAVITY = Int32
DISPLAY_GRAVITY_PreviousLine: win32more.Windows.Win32.Web.MsHtml.DISPLAY_GRAVITY = 1
DISPLAY_GRAVITY_NextLine: win32more.Windows.Win32.Web.MsHtml.DISPLAY_GRAVITY = 2
DISPLAY_GRAVITY_Max: win32more.Windows.Win32.Web.MsHtml.DISPLAY_GRAVITY = 2147483647
DISPLAY_MOVEUNIT = Int32
DISPLAY_MOVEUNIT_PreviousLine: win32more.Windows.Win32.Web.MsHtml.DISPLAY_MOVEUNIT = 1
DISPLAY_MOVEUNIT_NextLine: win32more.Windows.Win32.Web.MsHtml.DISPLAY_MOVEUNIT = 2
DISPLAY_MOVEUNIT_CurrentLineStart: win32more.Windows.Win32.Web.MsHtml.DISPLAY_MOVEUNIT = 3
DISPLAY_MOVEUNIT_CurrentLineEnd: win32more.Windows.Win32.Web.MsHtml.DISPLAY_MOVEUNIT = 4
DISPLAY_MOVEUNIT_TopOfWindow: win32more.Windows.Win32.Web.MsHtml.DISPLAY_MOVEUNIT = 5
DISPLAY_MOVEUNIT_BottomOfWindow: win32more.Windows.Win32.Web.MsHtml.DISPLAY_MOVEUNIT = 6
DISPLAY_MOVEUNIT_Max: win32more.Windows.Win32.Web.MsHtml.DISPLAY_MOVEUNIT = 2147483647
DOCHOSTUIDBLCLK = Int32
DOCHOSTUIDBLCLK_DEFAULT: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIDBLCLK = 0
DOCHOSTUIDBLCLK_SHOWPROPERTIES: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIDBLCLK = 1
DOCHOSTUIDBLCLK_SHOWCODE: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIDBLCLK = 2
DOCHOSTUIFLAG = Int32
DOCHOSTUIFLAG_DIALOG: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 1
DOCHOSTUIFLAG_DISABLE_HELP_MENU: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 2
DOCHOSTUIFLAG_NO3DBORDER: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 4
DOCHOSTUIFLAG_SCROLL_NO: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 8
DOCHOSTUIFLAG_DISABLE_SCRIPT_INACTIVE: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 16
DOCHOSTUIFLAG_OPENNEWWIN: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 32
DOCHOSTUIFLAG_DISABLE_OFFSCREEN: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 64
DOCHOSTUIFLAG_FLAT_SCROLLBAR: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 128
DOCHOSTUIFLAG_DIV_BLOCKDEFAULT: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 256
DOCHOSTUIFLAG_ACTIVATE_CLIENTHIT_ONLY: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 512
DOCHOSTUIFLAG_OVERRIDEBEHAVIORFACTORY: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 1024
DOCHOSTUIFLAG_CODEPAGELINKEDFONTS: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 2048
DOCHOSTUIFLAG_URL_ENCODING_DISABLE_UTF8: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 4096
DOCHOSTUIFLAG_URL_ENCODING_ENABLE_UTF8: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 8192
DOCHOSTUIFLAG_ENABLE_FORMS_AUTOCOMPLETE: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 16384
DOCHOSTUIFLAG_ENABLE_INPLACE_NAVIGATION: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 65536
DOCHOSTUIFLAG_IME_ENABLE_RECONVERSION: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 131072
DOCHOSTUIFLAG_THEME: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 262144
DOCHOSTUIFLAG_NOTHEME: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 524288
DOCHOSTUIFLAG_NOPICS: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 1048576
DOCHOSTUIFLAG_NO3DOUTERBORDER: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 2097152
DOCHOSTUIFLAG_DISABLE_EDIT_NS_FIXUP: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 4194304
DOCHOSTUIFLAG_LOCAL_MACHINE_ACCESS_CHECK: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 8388608
DOCHOSTUIFLAG_DISABLE_UNTRUSTEDPROTOCOL: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 16777216
DOCHOSTUIFLAG_HOST_NAVIGATES: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 33554432
DOCHOSTUIFLAG_ENABLE_REDIRECT_NOTIFICATION: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 67108864
DOCHOSTUIFLAG_USE_WINDOWLESS_SELECTCONTROL: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 134217728
DOCHOSTUIFLAG_USE_WINDOWED_SELECTCONTROL: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 268435456
DOCHOSTUIFLAG_ENABLE_ACTIVEX_INACTIVATE_MODE: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 536870912
DOCHOSTUIFLAG_DPI_AWARE: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIFLAG = 1073741824
class DOCHOSTUIINFO(Structure):
    cbSize: UInt32
    dwFlags: UInt32
    dwDoubleClick: UInt32
    pchHostCss: win32more.Windows.Win32.Foundation.PWSTR
    pchHostNS: win32more.Windows.Win32.Foundation.PWSTR
DOCHOSTUITYPE = Int32
DOCHOSTUITYPE_BROWSE: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUITYPE = 0
DOCHOSTUITYPE_AUTHOR: win32more.Windows.Win32.Web.MsHtml.DOCHOSTUITYPE = 1
DOMBeforeUnloadEvent = Guid('{30510764-98b5-11cf-bb82-00aa00bdce0b}')
DOMChildrenCollection = Guid('{3050f5aa-98b5-11cf-bb82-00aa00bdce0b}')
DOMCloseEvent = Guid('{30510800-98b5-11cf-bb82-00aa00bdce0b}')
DOMCompositionEvent = Guid('{305106d9-98b5-11cf-bb82-00aa00bdce0b}')
DOMCustomEvent = Guid('{305106df-98b5-11cf-bb82-00aa00bdce0b}')
DOMDocumentType = Guid('{30510739-98b5-11cf-bb82-00aa00bdce0b}')
DOMDragEvent = Guid('{30510762-98b5-11cf-bb82-00aa00bdce0b}')
DOMEvent = Guid('{305104bb-98b5-11cf-bb82-00aa00bdce0b}')
DOMException = Guid('{3051072c-98b5-11cf-bb82-00aa00bdce0b}')
DOMFocusEvent = Guid('{305106cd-98b5-11cf-bb82-00aa00bdce0b}')
DOMKeyboardEvent = Guid('{305106d7-98b5-11cf-bb82-00aa00bdce0b}')
DOMMSAnimationEvent = Guid('{305107b8-98b5-11cf-bb82-00aa00bdce0b}')
DOMMSManipulationEvent = Guid('{30510817-98b5-11cf-bb82-00aa00bdce0b}')
DOMMSTransitionEvent = Guid('{305107b6-98b5-11cf-bb82-00aa00bdce0b}')
DOMMessageEvent = Guid('{30510721-98b5-11cf-bb82-00aa00bdce0b}')
DOMMouseEvent = Guid('{305106cf-98b5-11cf-bb82-00aa00bdce0b}')
DOMMouseWheelEvent = Guid('{305106d1-98b5-11cf-bb82-00aa00bdce0b}')
DOMMutationEvent = Guid('{305106db-98b5-11cf-bb82-00aa00bdce0b}')
DOMParser = Guid('{30510782-98b5-11cf-bb82-00aa00bdce0b}')
DOMParserFactory = Guid('{30510784-98b5-11cf-bb82-00aa00bdce0b}')
DOMProcessingInstruction = Guid('{30510743-98b5-11cf-bb82-00aa00bdce0b}')
DOMProgressEvent = Guid('{3051071f-98b5-11cf-bb82-00aa00bdce0b}')
DOMSiteModeEvent = Guid('{30510766-98b6-11cf-bb82-00aa00bdce0b}')
DOMStorageEvent = Guid('{30510723-98b5-11cf-bb82-00aa00bdce0b}')
DOMTextEvent = Guid('{305106d5-98b5-11cf-bb82-00aa00bdce0b}')
DOMUIEvent = Guid('{305106cb-98b5-11cf-bb82-00aa00bdce0b}')
DOMWheelEvent = Guid('{305106d3-98b5-11cf-bb82-00aa00bdce0b}')
DOM_EVENT_PHASE = Int32
DEP_CAPTURING_PHASE: win32more.Windows.Win32.Web.MsHtml.DOM_EVENT_PHASE = 1
DEP_AT_TARGET: win32more.Windows.Win32.Web.MsHtml.DOM_EVENT_PHASE = 2
DEP_BUBBLING_PHASE: win32more.Windows.Win32.Web.MsHtml.DOM_EVENT_PHASE = 3
DOM_EVENT_PHASE_Max: win32more.Windows.Win32.Web.MsHtml.DOM_EVENT_PHASE = 2147483647
class DWebBridgeEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{a6d897ff-0a95-11d1-b0ba-006008166e11}')
class DispApplicationCache(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900e4-98b5-11cf-bb82-00aa00bdce0b}')
class DispCEventObj(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f558-98b5-11cf-bb82-00aa00bdce0b}')
class DispCPlugins(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f54a-98b5-11cf-bb82-00aa00bdce0b}')
class DispCPrintManagerTemplatePrinter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900e9-98b5-11cf-bb82-00aa00bdce0b}')
class DispCanvasGradient(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059008c-98b5-11cf-bb82-00aa00bdce0b}')
class DispCanvasImageData(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059008f-98b5-11cf-bb82-00aa00bdce0b}')
class DispCanvasPattern(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059008d-98b5-11cf-bb82-00aa00bdce0b}')
class DispCanvasRenderingContext2D(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590082-98b5-11cf-bb82-00aa00bdce0b}')
class DispCanvasTextMetrics(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059008e-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMBeforeUnloadEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900a8-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMChildrenCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f577-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMCloseEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900dc-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMCompositionEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590078-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMCustomEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059007c-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMDocumentType(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590098-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMDragEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900a7-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5a2-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMException(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590094-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMFocusEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590071-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMKeyboardEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590077-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMMSAnimationEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900bc-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMMSManipulationEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900e1-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMMSTransitionEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900bb-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMMessageEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590092-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMMouseEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590073-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMMouseWheelEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590074-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMMutationEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590079-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMParser(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900ae-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMProcessingInstruction(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059009b-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMProgressEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590091-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMSiteModeEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900a9-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMStorageEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590093-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMTextEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590076-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMUIEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590072-98b5-11cf-bb82-00aa00bdce0b}')
class DispDOMWheelEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590075-98b5-11cf-bb82-00aa00bdce0b}')
class DispEventException(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590099-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTCAttachBehavior(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f583-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTCDefaultDispatch(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f573-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTCDescBehavior(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f57e-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTCEventBehavior(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f574-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTCMethodBehavior(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f587-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTCPropertyBehavior(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f57f-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLAnchorElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f502-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLAppBehavior(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f57c-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLAreaElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f503-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLAreasCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f56a-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLAttributeCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f56c-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLAudioElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059008a-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLBGsound(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f53c-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLBRElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f53a-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLBaseElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f518-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLBaseFontElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f504-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLBlockElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f506-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLBody(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f507-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLButtonElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f51f-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLCSSImportRule(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059007e-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLCSSMediaList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590097-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLCSSMediaRule(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059007f-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLCSSNamespaceRule(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590080-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLCSSRule(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059007d-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLCSSStyleDeclaration(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059009a-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLCanvasElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059007b-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLCommentElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f50a-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLCurrentStyle(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f557-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLDDElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f50b-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLDListElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f53b-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLDOMAttribute(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f564-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLDOMImplementation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f58f-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLDOMRange(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5a3-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLDOMTextNode(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f565-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLDTElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f50d-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLDefaults(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f58c-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLDivElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f50c-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLDivPosition(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f50f-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLDocument(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f55f-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLDocumentCompatibleInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f53e-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLDocumentCompatibleInfoCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f53f-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLElementCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f56b-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLEmbed(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f52e-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLFieldSetElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f545-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLFontElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f512-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLFormElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f510-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLFrameBase(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f541-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLFrameElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f513-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLFrameSetSite(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f514-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLGenericElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f563-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLHRElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f53d-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLHeadElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f561-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLHeaderElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f515-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLHistory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f549-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLHtmlElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f560-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLIFrame(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f51b-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLImg(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f51c-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLInputElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f57d-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLIsIndexElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f519-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLLIElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f523-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLLabelElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f522-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLLegendElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f546-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLLinkElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f524-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLListElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f525-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLLocation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f54e-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLMSCSSKeyframeRule(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900de-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLMSCSSKeyframesRule(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900df-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLMapElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f526-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLMarqueeElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f527-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLMediaElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590088-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLMediaError(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590086-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLMetaElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f517-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLNamespace(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f54f-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLNamespaceCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f550-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLNavigator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f54c-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLNextIdElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f51a-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLNoShowElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f528-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLOListElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f52a-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLObjectElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f529-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLOptionElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f52b-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLParaElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f52c-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLParamElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f590-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLPerformance(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059009f-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLPerformanceNavigation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900a0-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLPerformanceTiming(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900a1-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLPhraseElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f52d-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLPopup(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f589-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLProgressElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900af-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLRenderStyle(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f58b-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLRichtextElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f54d-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLRuleStyle(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f55c-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLScreen(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f591-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLScriptElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f530-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLSelectElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f531-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLSemanticElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900ba-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLSourceElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590089-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLSpanElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f548-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLSpanFlow(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f544-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLStorage(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f59d-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLStyle(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f55a-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLStyleElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f511-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLStyleFontFace(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590081-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLStyleMedia(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059009e-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLStyleSheet(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f58d-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLStyleSheetPage(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f540-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLStyleSheetPagesCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f543-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLStyleSheetRule(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f50e-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLStyleSheetRulesAppliedCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5a6-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLStyleSheetRulesCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f52f-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLStyleSheetsCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f547-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLTable(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f532-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLTableCaption(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f508-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLTableCell(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f536-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLTableCol(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f533-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLTableRow(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f535-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLTableSection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f534-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLTextAreaElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f521-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLTextElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f537-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLTimeRanges(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590087-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLTitleElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f516-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLUListElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f538-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLUnknownElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f539-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLUrnCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f551-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLVideoElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059008b-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLW3CComputedStyle(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590070-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLWindow2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f55d-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLWindowProxy(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f55e-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLWndOptionElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f598-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLWndSelectElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f597-98b5-11cf-bb82-00aa00bdce0b}')
class DispHTMLXMLHttpRequest(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f596-98b5-11cf-bb82-00aa00bdce0b}')
class DispIHTMLInputButtonElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f51e-98b5-11cf-bb82-00aa00bdce0b}')
class DispIHTMLInputFileElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f542-98b5-11cf-bb82-00aa00bdce0b}')
class DispIHTMLInputImage(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f51d-98b5-11cf-bb82-00aa00bdce0b}')
class DispIHTMLInputTextElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f520-98b5-11cf-bb82-00aa00bdce0b}')
class DispIHTMLOptionButtonElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f509-98b5-11cf-bb82-00aa00bdce0b}')
class DispNodeIterator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059009c-98b5-11cf-bb82-00aa00bdce0b}')
class DispRangeException(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590095-98b5-11cf-bb82-00aa00bdce0b}')
class DispRulesApplied(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5a5-98b5-11cf-bb82-00aa00bdce0b}')
class DispRulesAppliedCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5a4-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGAElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590033-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGCircleElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059000a-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGClipPathElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059003b-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGDefsElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590003-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGDescElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590005-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590000-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGElementInstance(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590007-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGElementInstanceList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590008-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGEllipseElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059000b-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGException(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590096-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGGElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590002-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGGradientElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059002e-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGImageElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590027-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGLineElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059000c-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGLinearGradientElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059002a-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGMarkerElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590036-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGMaskElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059003c-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGMetadataElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059002f-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590011-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegArcAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590013-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegArcRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590014-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegClosePath(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590015-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegCurvetoCubicAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590016-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegCurvetoCubicRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590017-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegCurvetoCubicSmoothAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590018-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegCurvetoCubicSmoothRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590019-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegCurvetoQuadraticAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059001a-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegCurvetoQuadraticRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059001b-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegCurvetoQuadraticSmoothAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059001c-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegCurvetoQuadraticSmoothRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059001d-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegLinetoAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059001e-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegLinetoHorizontalAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059001f-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegLinetoHorizontalRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590020-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegLinetoRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590021-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegLinetoVerticalAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590022-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegLinetoVerticalRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590023-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegMovetoAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590024-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPathSegMovetoRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590025-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPatternElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059002c-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPolygonElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059000d-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGPolylineElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059000e-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGRadialGradientElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059002b-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGRectElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590009-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGSVGElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590001-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGScriptElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590039-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGStopElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059002d-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGStyleElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590029-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGSwitchElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590030-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGSymbolElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590004-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGTSpanElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059003a-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGTextContentElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590035-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGTextElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590037-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGTextPathElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059003d-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGTextPositioningElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590038-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGTitleElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590006-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGUseElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590010-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGViewElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590034-98b5-11cf-bb82-00aa00bdce0b}')
class DispSVGZoomEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30590031-98b5-11cf-bb82-00aa00bdce0b}')
class DispStaticNodeList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f59b-98b5-11cf-bb82-00aa00bdce0b}')
class DispTreeWalker(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3059009d-98b5-11cf-bb82-00aa00bdce0b}')
class DispWebGeocoordinates(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900be-98b5-11cf-bb82-00aa00bdce0b}')
class DispWebGeolocation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900bd-98b5-11cf-bb82-00aa00bdce0b}')
class DispWebGeoposition(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900c1-98b5-11cf-bb82-00aa00bdce0b}')
class DispWebGeopositionError(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900bf-98b5-11cf-bb82-00aa00bdce0b}')
class DispXDomainRequest(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f599-98b5-11cf-bb82-00aa00bdce0b}')
class DispXMLHttpRequestEventTarget(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900e7-98b5-11cf-bb82-00aa00bdce0b}')
class DispXMLSerializer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305900ad-98b5-11cf-bb82-00aa00bdce0b}')
DomConstructor = Int32
DomConstructorObject: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 0
DomConstructorAttr: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 1
DomConstructorBehaviorUrnsCollection: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 2
DomConstructorBookmarkCollection: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 3
DomConstructorCompatibleInfo: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 4
DomConstructorCompatibleInfoCollection: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 5
DomConstructorControlRangeCollection: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 6
DomConstructorCSSCurrentStyleDeclaration: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 7
DomConstructorCSSRuleList: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 8
DomConstructorCSSRuleStyleDeclaration: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 9
DomConstructorCSSStyleDeclaration: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 10
DomConstructorCSSStyleRule: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 11
DomConstructorCSSStyleSheet: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 12
DomConstructorDataTransfer: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 13
DomConstructorDOMImplementation: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 14
DomConstructorElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 15
DomConstructorEvent: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 16
DomConstructorHistory: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 17
DomConstructorHTCElementBehaviorDefaults: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 18
DomConstructorHTMLAnchorElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 19
DomConstructorHTMLAreaElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 20
DomConstructorHTMLAreasCollection: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 21
DomConstructorHTMLBaseElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 22
DomConstructorHTMLBaseFontElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 23
DomConstructorHTMLBGSoundElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 24
DomConstructorHTMLBlockElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 25
DomConstructorHTMLBodyElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 26
DomConstructorHTMLBRElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 27
DomConstructorHTMLButtonElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 28
DomConstructorHTMLCollection: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 29
DomConstructorHTMLCommentElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 30
DomConstructorHTMLDDElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 31
DomConstructorHTMLDivElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 32
DomConstructorHTMLDocument: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 33
DomConstructorHTMLDListElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 34
DomConstructorHTMLDTElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 35
DomConstructorHTMLEmbedElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 36
DomConstructorHTMLFieldSetElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 37
DomConstructorHTMLFontElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 38
DomConstructorHTMLFormElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 39
DomConstructorHTMLFrameElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 40
DomConstructorHTMLFrameSetElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 41
DomConstructorHTMLGenericElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 42
DomConstructorHTMLHeadElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 43
DomConstructorHTMLHeadingElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 44
DomConstructorHTMLHRElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 45
DomConstructorHTMLHtmlElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 46
DomConstructorHTMLIFrameElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 47
DomConstructorHTMLImageElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 48
DomConstructorHTMLInputElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 49
DomConstructorHTMLIsIndexElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 50
DomConstructorHTMLLabelElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 51
DomConstructorHTMLLegendElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 52
DomConstructorHTMLLIElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 53
DomConstructorHTMLLinkElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 54
DomConstructorHTMLMapElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 55
DomConstructorHTMLMarqueeElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 56
DomConstructorHTMLMetaElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 57
DomConstructorHTMLModelessDialog: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 58
DomConstructorHTMLNamespaceInfo: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 59
DomConstructorHTMLNamespaceInfoCollection: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 60
DomConstructorHTMLNextIdElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 61
DomConstructorHTMLNoShowElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 62
DomConstructorHTMLObjectElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 63
DomConstructorHTMLOListElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 64
DomConstructorHTMLOptionElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 65
DomConstructorHTMLParagraphElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 66
DomConstructorHTMLParamElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 67
DomConstructorHTMLPhraseElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 68
DomConstructorHTMLPluginsCollection: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 69
DomConstructorHTMLPopup: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 70
DomConstructorHTMLScriptElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 71
DomConstructorHTMLSelectElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 72
DomConstructorHTMLSpanElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 73
DomConstructorHTMLStyleElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 74
DomConstructorHTMLTableCaptionElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 75
DomConstructorHTMLTableCellElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 76
DomConstructorHTMLTableColElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 77
DomConstructorHTMLTableElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 78
DomConstructorHTMLTableRowElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 79
DomConstructorHTMLTableSectionElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 80
DomConstructorHTMLTextAreaElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 81
DomConstructorHTMLTextElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 82
DomConstructorHTMLTitleElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 83
DomConstructorHTMLUListElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 84
DomConstructorHTMLUnknownElement: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 85
DomConstructorImage: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 86
DomConstructorLocation: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 87
DomConstructorNamedNodeMap: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 88
DomConstructorNavigator: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 89
DomConstructorNodeList: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 90
DomConstructorOption: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 91
DomConstructorScreen: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 92
DomConstructorSelection: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 93
DomConstructorStaticNodeList: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 94
DomConstructorStorage: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 95
DomConstructorStyleSheetList: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 96
DomConstructorStyleSheetPage: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 97
DomConstructorStyleSheetPageList: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 98
DomConstructorText: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 99
DomConstructorTextRange: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 100
DomConstructorTextRangeCollection: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 101
DomConstructorTextRectangle: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 102
DomConstructorTextRectangleList: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 103
DomConstructorWindow: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 104
DomConstructorXDomainRequest: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 105
DomConstructorXMLHttpRequest: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 106
DomConstructorMax: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 107
DomConstructor_Max: win32more.Windows.Win32.Web.MsHtml.DomConstructor = 2147483647
ELEMENTDESCRIPTOR_FLAGS = Int32
ELEMENTDESCRIPTORFLAGS_LITERAL: win32more.Windows.Win32.Web.MsHtml.ELEMENTDESCRIPTOR_FLAGS = 1
ELEMENTDESCRIPTORFLAGS_NESTED_LITERAL: win32more.Windows.Win32.Web.MsHtml.ELEMENTDESCRIPTOR_FLAGS = 2
ELEMENTDESCRIPTOR_FLAGS_Max: win32more.Windows.Win32.Web.MsHtml.ELEMENTDESCRIPTOR_FLAGS = 2147483647
ELEMENTNAMESPACE_FLAGS = Int32
ELEMENTNAMESPACEFLAGS_ALLOWANYTAG: win32more.Windows.Win32.Web.MsHtml.ELEMENTNAMESPACE_FLAGS = 1
ELEMENTNAMESPACEFLAGS_QUERYFORUNKNOWNTAGS: win32more.Windows.Win32.Web.MsHtml.ELEMENTNAMESPACE_FLAGS = 2
ELEMENTNAMESPACE_FLAGS_Max: win32more.Windows.Win32.Web.MsHtml.ELEMENTNAMESPACE_FLAGS = 2147483647
ELEMENT_ADJACENCY = Int32
ELEM_ADJ_BeforeBegin: win32more.Windows.Win32.Web.MsHtml.ELEMENT_ADJACENCY = 0
ELEM_ADJ_AfterBegin: win32more.Windows.Win32.Web.MsHtml.ELEMENT_ADJACENCY = 1
ELEM_ADJ_BeforeEnd: win32more.Windows.Win32.Web.MsHtml.ELEMENT_ADJACENCY = 2
ELEM_ADJ_AfterEnd: win32more.Windows.Win32.Web.MsHtml.ELEMENT_ADJACENCY = 3
ELEMENT_ADJACENCY_Max: win32more.Windows.Win32.Web.MsHtml.ELEMENT_ADJACENCY = 2147483647
ELEMENT_CORNER = Int32
ELEMENT_CORNER_NONE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_CORNER = 0
ELEMENT_CORNER_TOP: win32more.Windows.Win32.Web.MsHtml.ELEMENT_CORNER = 1
ELEMENT_CORNER_LEFT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_CORNER = 2
ELEMENT_CORNER_BOTTOM: win32more.Windows.Win32.Web.MsHtml.ELEMENT_CORNER = 3
ELEMENT_CORNER_RIGHT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_CORNER = 4
ELEMENT_CORNER_TOPLEFT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_CORNER = 5
ELEMENT_CORNER_TOPRIGHT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_CORNER = 6
ELEMENT_CORNER_BOTTOMLEFT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_CORNER = 7
ELEMENT_CORNER_BOTTOMRIGHT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_CORNER = 8
ELEMENT_CORNER_Max: win32more.Windows.Win32.Web.MsHtml.ELEMENT_CORNER = 2147483647
ELEMENT_TAG_ID = Int32
TAGID_NULL: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 0
TAGID_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 1
TAGID_A: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 2
TAGID_ACRONYM: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 3
TAGID_ADDRESS: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 4
TAGID_APPLET: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 5
TAGID_AREA: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 6
TAGID_B: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 7
TAGID_BASE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 8
TAGID_BASEFONT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 9
TAGID_BDO: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 10
TAGID_BGSOUND: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 11
TAGID_BIG: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 12
TAGID_BLINK: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 13
TAGID_BLOCKQUOTE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 14
TAGID_BODY: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 15
TAGID_BR: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 16
TAGID_BUTTON: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 17
TAGID_CAPTION: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 18
TAGID_CENTER: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 19
TAGID_CITE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 20
TAGID_CODE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 21
TAGID_COL: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 22
TAGID_COLGROUP: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 23
TAGID_COMMENT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 24
TAGID_COMMENT_RAW: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 25
TAGID_DD: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 26
TAGID_DEL: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 27
TAGID_DFN: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 28
TAGID_DIR: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 29
TAGID_DIV: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 30
TAGID_DL: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 31
TAGID_DT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 32
TAGID_EM: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 33
TAGID_EMBED: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 34
TAGID_FIELDSET: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 35
TAGID_FONT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 36
TAGID_FORM: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 37
TAGID_FRAME: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 38
TAGID_FRAMESET: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 39
TAGID_GENERIC: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 40
TAGID_H1: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 41
TAGID_H2: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 42
TAGID_H3: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 43
TAGID_H4: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 44
TAGID_H5: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 45
TAGID_H6: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 46
TAGID_HEAD: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 47
TAGID_HR: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 48
TAGID_HTML: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 49
TAGID_I: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 50
TAGID_IFRAME: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 51
TAGID_IMG: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 52
TAGID_INPUT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 53
TAGID_INS: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 54
TAGID_KBD: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 55
TAGID_LABEL: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 56
TAGID_LEGEND: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 57
TAGID_LI: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 58
TAGID_LINK: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 59
TAGID_LISTING: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 60
TAGID_MAP: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 61
TAGID_MARQUEE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 62
TAGID_MENU: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 63
TAGID_META: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 64
TAGID_NEXTID: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 65
TAGID_NOBR: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 66
TAGID_NOEMBED: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 67
TAGID_NOFRAMES: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 68
TAGID_NOSCRIPT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 69
TAGID_OBJECT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 70
TAGID_OL: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 71
TAGID_OPTION: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 72
TAGID_P: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 73
TAGID_PARAM: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 74
TAGID_PLAINTEXT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 75
TAGID_PRE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 76
TAGID_Q: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 77
TAGID_RP: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 78
TAGID_RT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 79
TAGID_RUBY: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 80
TAGID_S: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 81
TAGID_SAMP: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 82
TAGID_SCRIPT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 83
TAGID_SELECT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 84
TAGID_SMALL: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 85
TAGID_SPAN: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 86
TAGID_STRIKE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 87
TAGID_STRONG: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 88
TAGID_STYLE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 89
TAGID_SUB: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 90
TAGID_SUP: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 91
TAGID_TABLE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 92
TAGID_TBODY: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 93
TAGID_TC: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 94
TAGID_TD: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 95
TAGID_TEXTAREA: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 96
TAGID_TFOOT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 97
TAGID_TH: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 98
TAGID_THEAD: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 99
TAGID_TITLE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 100
TAGID_TR: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 101
TAGID_TT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 102
TAGID_U: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 103
TAGID_UL: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 104
TAGID_VAR: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 105
TAGID_WBR: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 106
TAGID_XMP: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 107
TAGID_ROOT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 108
TAGID_OPTGROUP: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 109
TAGID_ABBR: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 110
TAGID_SVG_A: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 111
TAGID_SVG_ALTGLYPH: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 112
TAGID_SVG_ALTGLYPHDEF: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 113
TAGID_SVG_ALTGLYPHITEM: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 114
TAGID_SVG_ANIMATE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 115
TAGID_SVG_ANIMATECOLOR: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 116
TAGID_SVG_ANIMATEMOTION: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 117
TAGID_SVG_ANIMATETRANSFORM: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 118
TAGID_SVG_CIRCLE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 119
TAGID_SVG_CLIPPATH: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 120
TAGID_SVG_COLOR_PROFILE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 121
TAGID_SVG_CURSOR: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 122
TAGID_SVG_DEFINITION_SRC: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 123
TAGID_SVG_DEFS: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 124
TAGID_SVG_DESC: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 125
TAGID_SVG_ELLIPSE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 126
TAGID_SVG_FEBLEND: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 127
TAGID_SVG_FECOLORMATRIX: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 128
TAGID_SVG_FECOMPONENTTRANSFER: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 129
TAGID_SVG_FECOMPOSITE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 130
TAGID_SVG_FECONVOLVEMATRIX: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 131
TAGID_SVG_FEDIFFUSELIGHTING: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 132
TAGID_SVG_FEDISPLACEMENTMAP: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 133
TAGID_SVG_FEDISTANTLIGHT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 134
TAGID_SVG_FEFLOOD: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 135
TAGID_SVG_FEFUNCA: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 136
TAGID_SVG_FEFUNCB: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 137
TAGID_SVG_FEFUNCG: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 138
TAGID_SVG_FEFUNCR: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 139
TAGID_SVG_FEGAUSSIANBLUR: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 140
TAGID_SVG_FEIMAGE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 141
TAGID_SVG_FEMERGE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 142
TAGID_SVG_FEMERGENODE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 143
TAGID_SVG_FEMORPHOLOGY: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 144
TAGID_SVG_FEOFFSET: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 145
TAGID_SVG_FEPOINTLIGHT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 146
TAGID_SVG_FESPECULARLIGHTING: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 147
TAGID_SVG_FESPOTLIGHT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 148
TAGID_SVG_FETILE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 149
TAGID_SVG_FETURBULENCE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 150
TAGID_SVG_FILTER: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 151
TAGID_SVG_FONT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 152
TAGID_SVG_FONT_FACE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 153
TAGID_SVG_FONT_FACE_FORMAT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 154
TAGID_SVG_FONT_FACE_NAME: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 155
TAGID_SVG_FONT_FACE_SRC: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 156
TAGID_SVG_FONT_FACE_URI: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 157
TAGID_SVG_FOREIGNOBJECT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 158
TAGID_SVG_G: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 159
TAGID_SVG_GLYPH: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 160
TAGID_SVG_GLYPHREF: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 161
TAGID_SVG_HKERN: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 162
TAGID_SVG_IMAGE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 163
TAGID_SVG_LINE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 164
TAGID_SVG_LINEARGRADIENT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 165
TAGID_SVG_MARKER: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 166
TAGID_SVG_MASK: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 167
TAGID_SVG_METADATA: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 168
TAGID_SVG_MISSING_GLYPH: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 169
TAGID_SVG_MPATH: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 170
TAGID_SVG_PATH: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 171
TAGID_SVG_PATTERN: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 172
TAGID_SVG_POLYGON: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 173
TAGID_SVG_POLYLINE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 174
TAGID_SVG_RADIALGRADIENT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 175
TAGID_SVG_RECT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 176
TAGID_SVG_SCRIPT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 177
TAGID_SVG_SET: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 178
TAGID_SVG_STOP: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 179
TAGID_SVG_STYLE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 180
TAGID_SVG_SVG: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 181
TAGID_SVG_SWITCH: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 182
TAGID_SVG_SYMBOL: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 183
TAGID_SVG_TEXT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 184
TAGID_SVG_TEXTPATH: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 185
TAGID_SVG_TITLE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 186
TAGID_SVG_TREF: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 187
TAGID_SVG_TSPAN: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 188
TAGID_SVG_USE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 189
TAGID_SVG_VIEW: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 190
TAGID_SVG_VKERN: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 191
TAGID_AUDIO: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 192
TAGID_SOURCE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 193
TAGID_VIDEO: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 194
TAGID_CANVAS: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 195
TAGID_DOCTYPE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 196
TAGID_KEYGEN: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 197
TAGID_PROCESSINGINSTRUCTION: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 198
TAGID_ARTICLE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 199
TAGID_ASIDE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 200
TAGID_FIGCAPTION: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 201
TAGID_FIGURE: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 202
TAGID_FOOTER: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 203
TAGID_HEADER: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 204
TAGID_HGROUP: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 205
TAGID_MARK: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 206
TAGID_NAV: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 207
TAGID_SECTION: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 208
TAGID_PROGRESS: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 209
TAGID_MATHML_ANNOTATION_XML: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 210
TAGID_MATHML_MATH: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 211
TAGID_MATHML_MI: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 212
TAGID_MATHML_MN: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 213
TAGID_MATHML_MO: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 214
TAGID_MATHML_MS: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 215
TAGID_MATHML_MTEXT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 216
TAGID_DATALIST: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 217
TAGID_TRACK: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 218
TAGID_ISINDEX: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 219
TAGID_COMMAND: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 220
TAGID_DETAILS: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 221
TAGID_SUMMARY: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 222
TAGID_X_MS_WEBVIEW: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 223
TAGID_COUNT: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 224
TAGID_LAST_PREDEFINED: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 10000
ELEMENT_TAG_ID_Max: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID = 2147483647
EventException = Guid('{3051073b-98b5-11cf-bb82-00aa00bdce0b}')
FINDTEXT_FLAGS = Int32
FINDTEXT_BACKWARDS: win32more.Windows.Win32.Web.MsHtml.FINDTEXT_FLAGS = 1
FINDTEXT_WHOLEWORD: win32more.Windows.Win32.Web.MsHtml.FINDTEXT_FLAGS = 2
FINDTEXT_MATCHCASE: win32more.Windows.Win32.Web.MsHtml.FINDTEXT_FLAGS = 4
FINDTEXT_RAW: win32more.Windows.Win32.Web.MsHtml.FINDTEXT_FLAGS = 131072
FINDTEXT_MATCHREPEATEDWHITESPACE: win32more.Windows.Win32.Web.MsHtml.FINDTEXT_FLAGS = 262144
FINDTEXT_MATCHDIAC: win32more.Windows.Win32.Web.MsHtml.FINDTEXT_FLAGS = 536870912
FINDTEXT_MATCHKASHIDA: win32more.Windows.Win32.Web.MsHtml.FINDTEXT_FLAGS = 1073741824
FINDTEXT_MATCHALEFHAMZA: win32more.Windows.Win32.Web.MsHtml.FINDTEXT_FLAGS = -2147483648
FINDTEXT_FLAGS_Max: win32more.Windows.Win32.Web.MsHtml.FINDTEXT_FLAGS = 2147483647
FontNames = Guid('{3050f83a-98b5-11cf-bb82-00aa00bdce0b}')
FramesCollection = Guid('{3050f7f6-98b5-11cf-bb82-00aa00bdce0b}')
HTCAttachBehavior = Guid('{3050f5f5-98b5-11cf-bb82-00aa00bdce0b}')
HTCDefaultDispatch = Guid('{3050f4fc-98b5-11cf-bb82-00aa00bdce0b}')
HTCDescBehavior = Guid('{3050f5dd-98b5-11cf-bb82-00aa00bdce0b}')
HTCEventBehavior = Guid('{3050f4fe-98b5-11cf-bb82-00aa00bdce0b}')
HTCMethodBehavior = Guid('{3050f630-98b5-11cf-bb82-00aa00bdce0b}')
HTCPropertyBehavior = Guid('{3050f5de-98b5-11cf-bb82-00aa00bdce0b}')
HTMLAnchorElement = Guid('{3050f248-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLAnchorEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f29d-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLAnchorEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f610-98b5-11cf-bb82-00aa00bdce0b}')
HTMLAppBehavior = Guid('{3050f5cb-98b5-11cf-bb82-00aa00bdce0b}')
HTMLAppFlag = Int32
HTMLAppFlagNo: win32more.Windows.Win32.Web.MsHtml.HTMLAppFlag = 0
HTMLAppFlagOff: win32more.Windows.Win32.Web.MsHtml.HTMLAppFlag = 0
HTMLAppFlag0: win32more.Windows.Win32.Web.MsHtml.HTMLAppFlag = 0
HTMLAppFlagYes: win32more.Windows.Win32.Web.MsHtml.HTMLAppFlag = 1
HTMLAppFlagOn: win32more.Windows.Win32.Web.MsHtml.HTMLAppFlag = 1
HTMLAppFlag1: win32more.Windows.Win32.Web.MsHtml.HTMLAppFlag = 1
HTMLAppFlag_Max: win32more.Windows.Win32.Web.MsHtml.HTMLAppFlag = 2147483647
HTMLAreaElement = Guid('{3050f283-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLAreaEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f366-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLAreaEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f611-98b5-11cf-bb82-00aa00bdce0b}')
HTMLAreasCollection = Guid('{3050f4ca-98b5-11cf-bb82-00aa00bdce0b}')
HTMLAttributeCollection = Guid('{3050f4cc-98b5-11cf-bb82-00aa00bdce0b}')
HTMLAudioElement = Guid('{3051070e-98b5-11cf-bb82-00aa00bdce0b}')
HTMLAudioElementFactory = Guid('{305107ec-98b5-11cf-bb82-00aa00bdce0b}')
HTMLBGsound = Guid('{3050f370-98b5-11cf-bb82-00aa00bdce0b}')
HTMLBRElement = Guid('{3050f280-98b5-11cf-bb82-00aa00bdce0b}')
HTMLBaseElement = Guid('{3050f276-98b5-11cf-bb82-00aa00bdce0b}')
HTMLBaseFontElement = Guid('{3050f282-98b5-11cf-bb82-00aa00bdce0b}')
HTMLBlockElement = Guid('{3050f281-98b5-11cf-bb82-00aa00bdce0b}')
HTMLBody = Guid('{3050f24a-98b5-11cf-bb82-00aa00bdce0b}')
HTMLBorder = Int32
HTMLBorderNone: win32more.Windows.Win32.Web.MsHtml.HTMLBorder = 0
HTMLBorderThick: win32more.Windows.Win32.Web.MsHtml.HTMLBorder = 262144
HTMLBorderDialog: win32more.Windows.Win32.Web.MsHtml.HTMLBorder = 4194304
HTMLBorderThin: win32more.Windows.Win32.Web.MsHtml.HTMLBorder = 8388608
HTMLBorder_Max: win32more.Windows.Win32.Web.MsHtml.HTMLBorder = 2147483647
HTMLBorderStyle = Int32
HTMLBorderStyleNormal: win32more.Windows.Win32.Web.MsHtml.HTMLBorderStyle = 0
HTMLBorderStyleRaised: win32more.Windows.Win32.Web.MsHtml.HTMLBorderStyle = 256
HTMLBorderStyleSunken: win32more.Windows.Win32.Web.MsHtml.HTMLBorderStyle = 512
HTMLBorderStylecombined: win32more.Windows.Win32.Web.MsHtml.HTMLBorderStyle = 768
HTMLBorderStyleStatic: win32more.Windows.Win32.Web.MsHtml.HTMLBorderStyle = 131072
HTMLBorderStyle_Max: win32more.Windows.Win32.Web.MsHtml.HTMLBorderStyle = 2147483647
HTMLButtonElement = Guid('{3050f2c6-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLButtonElementEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2b3-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLButtonElementEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f617-98b5-11cf-bb82-00aa00bdce0b}')
HTMLCSSImportRule = Guid('{305106f0-98b5-11cf-bb82-00aa00bdce0b}')
HTMLCSSMediaList = Guid('{30510732-98b5-11cf-bb82-00aa00bdce0b}')
HTMLCSSMediaRule = Guid('{305106f1-98b5-11cf-bb82-00aa00bdce0b}')
HTMLCSSNamespaceRule = Guid('{305106f2-98b5-11cf-bb82-00aa00bdce0b}')
HTMLCSSRule = Guid('{305106ef-98b5-11cf-bb82-00aa00bdce0b}')
HTMLCSSStyleDeclaration = Guid('{30510741-98b5-11cf-bb82-00aa00bdce0b}')
HTMLCanvasElement = Guid('{305106e5-98b5-11cf-bb82-00aa00bdce0b}')
HTMLCaptionFlag = Int32
HTMLCaptionFlagNo: win32more.Windows.Win32.Web.MsHtml.HTMLCaptionFlag = 0
HTMLCaptionFlagYes: win32more.Windows.Win32.Web.MsHtml.HTMLCaptionFlag = 12582912
HTMLCaptionFlag_Max: win32more.Windows.Win32.Web.MsHtml.HTMLCaptionFlag = 2147483647
HTMLCommentElement = Guid('{3050f317-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLControlElementEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4ea-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLControlElementEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f612-98b5-11cf-bb82-00aa00bdce0b}')
HTMLCurrentStyle = Guid('{3050f3dc-98b5-11cf-bb82-00aa00bdce0b}')
HTMLDDElement = Guid('{3050f27f-98b5-11cf-bb82-00aa00bdce0b}')
HTMLDListElement = Guid('{3050f27d-98b5-11cf-bb82-00aa00bdce0b}')
HTMLDOMAttribute = Guid('{3050f4b2-98b5-11cf-bb82-00aa00bdce0b}')
HTMLDOMImplementation = Guid('{3050f80e-98b5-11cf-bb82-00aa00bdce0b}')
HTMLDOMRange = Guid('{305106c3-98b5-11cf-bb82-00aa00bdce0b}')
HTMLDOMTextNode = Guid('{3050f4ba-98b5-11cf-bb82-00aa00bdce0b}')
HTMLDOMXmlSerializerFactory = Guid('{30510780-98b5-11cf-bb82-00aa00bdce0b}')
HTMLDTElement = Guid('{3050f27c-98b5-11cf-bb82-00aa00bdce0b}')
HTMLDefaults = Guid('{3050f6c8-98b5-11cf-bb82-00aa00bdce0b}')
HTMLDialog = Guid('{3050f28a-98b5-11cf-bb82-00aa00bdce0b}')
HTMLDivElement = Guid('{3050f27e-98b5-11cf-bb82-00aa00bdce0b}')
HTMLDivPosition = Guid('{3050f249-98b5-11cf-bb82-00aa00bdce0b}')
HTMLDlgBorder = Int32
HTMLDlgBorderThin: win32more.Windows.Win32.Web.MsHtml.HTMLDlgBorder = 0
HTMLDlgBorderThick: win32more.Windows.Win32.Web.MsHtml.HTMLDlgBorder = 262144
HTMLDlgBorder_Max: win32more.Windows.Win32.Web.MsHtml.HTMLDlgBorder = 2147483647
HTMLDlgCenter = Int32
HTMLDlgCenterNo: win32more.Windows.Win32.Web.MsHtml.HTMLDlgCenter = 0
HTMLDlgCenterOff: win32more.Windows.Win32.Web.MsHtml.HTMLDlgCenter = 0
HTMLDlgCenter0: win32more.Windows.Win32.Web.MsHtml.HTMLDlgCenter = 0
HTMLDlgCenterYes: win32more.Windows.Win32.Web.MsHtml.HTMLDlgCenter = 1
HTMLDlgCenterOn: win32more.Windows.Win32.Web.MsHtml.HTMLDlgCenter = 1
HTMLDlgCenter1: win32more.Windows.Win32.Web.MsHtml.HTMLDlgCenter = 1
HTMLDlgCenterParent: win32more.Windows.Win32.Web.MsHtml.HTMLDlgCenter = 1
HTMLDlgCenterDesktop: win32more.Windows.Win32.Web.MsHtml.HTMLDlgCenter = 2
HTMLDlgCenter_Max: win32more.Windows.Win32.Web.MsHtml.HTMLDlgCenter = 2147483647
HTMLDlgEdge = Int32
HTMLDlgEdgeSunken: win32more.Windows.Win32.Web.MsHtml.HTMLDlgEdge = 0
HTMLDlgEdgeRaised: win32more.Windows.Win32.Web.MsHtml.HTMLDlgEdge = 16
HTMLDlgEdge_Max: win32more.Windows.Win32.Web.MsHtml.HTMLDlgEdge = 2147483647
HTMLDlgFlag = Int32
HTMLDlgFlagNo: win32more.Windows.Win32.Web.MsHtml.HTMLDlgFlag = 0
HTMLDlgFlagOff: win32more.Windows.Win32.Web.MsHtml.HTMLDlgFlag = 0
HTMLDlgFlag0: win32more.Windows.Win32.Web.MsHtml.HTMLDlgFlag = 0
HTMLDlgFlagYes: win32more.Windows.Win32.Web.MsHtml.HTMLDlgFlag = 1
HTMLDlgFlagOn: win32more.Windows.Win32.Web.MsHtml.HTMLDlgFlag = 1
HTMLDlgFlag1: win32more.Windows.Win32.Web.MsHtml.HTMLDlgFlag = 1
HTMLDlgFlagNotSet: win32more.Windows.Win32.Web.MsHtml.HTMLDlgFlag = -1
HTMLDlgFlag_Max: win32more.Windows.Win32.Web.MsHtml.HTMLDlgFlag = 2147483647
HTMLDocument = Guid('{25336920-03f9-11cf-8fd0-00aa00686f13}')
HTMLDocumentCompatibleInfo = Guid('{3051041b-98b5-11cf-bb82-00aa00bdce0b}')
HTMLDocumentCompatibleInfoCollection = Guid('{30510419-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLDocumentEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f260-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLDocumentEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f613-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLDocumentEvents3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5a0-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLDocumentEvents4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510737-98b5-11cf-bb82-00aa00bdce0b}')
HTMLElementCollection = Guid('{3050f4cb-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLElementEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f33c-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLElementEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f60f-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLElementEvents3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f59f-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLElementEvents4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051075e-98b5-11cf-bb82-00aa00bdce0b}')
HTMLEmbed = Guid('{3050f25d-98b5-11cf-bb82-00aa00bdce0b}')
HTMLFieldSetElement = Guid('{3050f3e8-98b5-11cf-bb82-00aa00bdce0b}')
HTMLFontElement = Guid('{3050f27b-98b5-11cf-bb82-00aa00bdce0b}')
HTMLFormElement = Guid('{3050f251-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLFormElementEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f364-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLFormElementEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f614-98b5-11cf-bb82-00aa00bdce0b}')
HTMLFrameBase = Guid('{3050f312-98b5-11cf-bb82-00aa00bdce0b}')
HTMLFrameElement = Guid('{3050f314-98b5-11cf-bb82-00aa00bdce0b}')
HTMLFrameSetSite = Guid('{3050f31a-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLFrameSiteEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f800-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLFrameSiteEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f7ff-98b5-11cf-bb82-00aa00bdce0b}')
HTMLGenericElement = Guid('{3050f4b8-98b5-11cf-bb82-00aa00bdce0b}')
HTMLHRElement = Guid('{3050f252-98b5-11cf-bb82-00aa00bdce0b}')
HTMLHeadElement = Guid('{3050f493-98b5-11cf-bb82-00aa00bdce0b}')
HTMLHeaderElement = Guid('{3050f27a-98b5-11cf-bb82-00aa00bdce0b}')
HTMLHistory = Guid('{feceaaa3-8405-11cf-8ba1-00aa00476da6}')
HTMLHtmlElement = Guid('{3050f491-98b5-11cf-bb82-00aa00bdce0b}')
HTMLIFrame = Guid('{3050f316-98b5-11cf-bb82-00aa00bdce0b}')
HTMLImageElementFactory = Guid('{3050f38f-98b5-11cf-bb82-00aa00bdce0b}')
HTMLImg = Guid('{3050f241-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLImgEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f25b-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLImgEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f616-98b5-11cf-bb82-00aa00bdce0b}')
HTMLInputButtonElement = Guid('{3050f2b4-98b5-11cf-bb82-00aa00bdce0b}')
HTMLInputElement = Guid('{3050f5d8-98b5-11cf-bb82-00aa00bdce0b}')
HTMLInputFileElement = Guid('{3050f2ae-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLInputFileElementEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2af-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLInputFileElementEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f61a-98b5-11cf-bb82-00aa00bdce0b}')
HTMLInputImage = Guid('{3050f2c4-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLInputImageEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2c3-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLInputImageEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f61b-98b5-11cf-bb82-00aa00bdce0b}')
HTMLInputTextElement = Guid('{3050f2ab-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLInputTextElementEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2a7-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLInputTextElementEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f618-98b5-11cf-bb82-00aa00bdce0b}')
HTMLIsIndexElement = Guid('{3050f278-98b5-11cf-bb82-00aa00bdce0b}')
HTMLLIElement = Guid('{3050f273-98b5-11cf-bb82-00aa00bdce0b}')
HTMLLabelElement = Guid('{3050f32b-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLLabelEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f329-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLLabelEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f61c-98b5-11cf-bb82-00aa00bdce0b}')
HTMLLegendElement = Guid('{3050f3e9-98b5-11cf-bb82-00aa00bdce0b}')
HTMLLinkElement = Guid('{3050f277-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLLinkElementEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f3cc-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLLinkElementEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f61d-98b5-11cf-bb82-00aa00bdce0b}')
HTMLListElement = Guid('{3050f272-98b5-11cf-bb82-00aa00bdce0b}')
HTMLLocation = Guid('{163bb1e1-6e00-11cf-837a-48dc04c10000}')
HTMLMSCSSKeyframeRule = Guid('{3051080e-98b5-11cf-bb82-00aa00bdce0b}')
HTMLMSCSSKeyframesRule = Guid('{3051080f-98b5-11cf-bb82-00aa00bdce0b}')
HTMLMapElement = Guid('{3050f271-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLMapEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f3ba-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLMapEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f61e-98b5-11cf-bb82-00aa00bdce0b}')
HTMLMarqueeElement = Guid('{3050f2b9-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLMarqueeElementEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2b8-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLMarqueeElementEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f61f-98b5-11cf-bb82-00aa00bdce0b}')
HTMLMaximizeFlag = Int32
HTMLMaximizeFlagNo: win32more.Windows.Win32.Web.MsHtml.HTMLMaximizeFlag = 0
HTMLMaximizeFlagYes: win32more.Windows.Win32.Web.MsHtml.HTMLMaximizeFlag = 65536
HTMLMaximizeFlag_Max: win32more.Windows.Win32.Web.MsHtml.HTMLMaximizeFlag = 2147483647
HTMLMediaElement = Guid('{3051070c-98b5-11cf-bb82-00aa00bdce0b}')
HTMLMediaError = Guid('{3051070a-98b5-11cf-bb82-00aa00bdce0b}')
HTMLMetaElement = Guid('{3050f275-98b5-11cf-bb82-00aa00bdce0b}')
HTMLMinimizeFlag = Int32
HTMLMinimizeFlagNo: win32more.Windows.Win32.Web.MsHtml.HTMLMinimizeFlag = 0
HTMLMinimizeFlagYes: win32more.Windows.Win32.Web.MsHtml.HTMLMinimizeFlag = 131072
HTMLMinimizeFlag_Max: win32more.Windows.Win32.Web.MsHtml.HTMLMinimizeFlag = 2147483647
HTMLNamespace = Guid('{3050f6bc-98b5-11cf-bb82-00aa00bdce0b}')
HTMLNamespaceCollection = Guid('{3050f6b9-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLNamespaceEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f6bd-98b5-11cf-bb82-00aa00bdce0b}')
HTMLNavigator = Guid('{feceaaa6-8405-11cf-8ba1-00aa00476da6}')
HTMLNextIdElement = Guid('{3050f279-98b5-11cf-bb82-00aa00bdce0b}')
HTMLNoShowElement = Guid('{3050f38b-98b5-11cf-bb82-00aa00bdce0b}')
HTMLOListElement = Guid('{3050f270-98b5-11cf-bb82-00aa00bdce0b}')
HTMLObjectElement = Guid('{3050f24e-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLObjectElementEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f3c4-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLObjectElementEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f620-98b5-11cf-bb82-00aa00bdce0b}')
HTMLOptionButtonElement = Guid('{3050f2be-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLOptionButtonElementEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2bd-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLOptionButtonElementEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f619-98b5-11cf-bb82-00aa00bdce0b}')
HTMLOptionElement = Guid('{3050f24d-98b5-11cf-bb82-00aa00bdce0b}')
HTMLOptionElementFactory = Guid('{3050f38d-98b5-11cf-bb82-00aa00bdce0b}')
HTMLParaElement = Guid('{3050f26f-98b5-11cf-bb82-00aa00bdce0b}')
HTMLParamElement = Guid('{3050f83e-98b5-11cf-bb82-00aa00bdce0b}')
HTMLPerformance = Guid('{3051074f-98b5-11cf-bb82-00aa00bdce0b}')
HTMLPerformanceNavigation = Guid('{30510751-98b5-11cf-bb82-00aa00bdce0b}')
HTMLPerformanceTiming = Guid('{30510753-98b5-11cf-bb82-00aa00bdce0b}')
HTMLPhraseElement = Guid('{3050f26e-98b5-11cf-bb82-00aa00bdce0b}')
HTMLPopup = Guid('{3050f667-98b5-11cf-bb82-00aa00bdce0b}')
HTMLProgressElement = Guid('{3050f2d5-98b5-11cf-bb82-00aa00bdce0b}')
HTMLRenderStyle = Guid('{3050f6aa-98b5-11cf-bb82-00aa00bdce0b}')
HTMLRichtextElement = Guid('{3050f2df-98b5-11cf-bb82-00aa00bdce0b}')
HTMLRuleStyle = Guid('{3050f3d0-98b5-11cf-bb82-00aa00bdce0b}')
HTMLScreen = Guid('{3050f35d-98b5-11cf-bb82-00aa00bdce0b}')
HTMLScriptElement = Guid('{3050f28c-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLScriptEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f3e2-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLScriptEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f621-98b5-11cf-bb82-00aa00bdce0b}')
HTMLSelectElement = Guid('{3050f245-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLSelectElementEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f302-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLSelectElementEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f622-98b5-11cf-bb82-00aa00bdce0b}')
HTMLSemanticElement = Guid('{305107b0-98b5-11cf-bb82-00aa00bdce0b}')
HTMLSourceElement = Guid('{3051070d-98b5-11cf-bb82-00aa00bdce0b}')
HTMLSpanElement = Guid('{3050f3f5-98b4-11cf-bb82-00aa00bdce0b}')
HTMLSpanFlow = Guid('{3050f3e6-98b5-11cf-bb82-00aa00bdce0b}')
HTMLStorage = Guid('{30510475-98b5-11cf-bb82-00aa00bdce0b}')
HTMLStyle = Guid('{3050f285-98b5-11cf-bb82-00aa00bdce0b}')
HTMLStyleElement = Guid('{3050f37d-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLStyleElementEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f3cb-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLStyleElementEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f615-98b5-11cf-bb82-00aa00bdce0b}')
HTMLStyleFontFace = Guid('{3050f3d4-98b5-11cf-bb82-00aa00bdce0b}')
HTMLStyleMedia = Guid('{3051074c-98b5-11cf-bb82-00aa00bdce0b}')
HTMLStyleSheet = Guid('{3050f2e4-98b5-11cf-bb82-00aa00bdce0b}')
HTMLStyleSheetPage = Guid('{3050f7ef-98b5-11cf-bb82-00aa00bdce0b}')
HTMLStyleSheetPagesCollection = Guid('{3050f7f1-98b5-11cf-bb82-00aa00bdce0b}')
HTMLStyleSheetRule = Guid('{3050f3ce-98b5-11cf-bb82-00aa00bdce0b}')
HTMLStyleSheetRulesAppliedCollection = Guid('{eb36f845-2395-4719-b85c-d0d80e184bd9}')
HTMLStyleSheetRulesCollection = Guid('{3050f3cd-98b5-11cf-bb82-00aa00bdce0b}')
HTMLStyleSheetsCollection = Guid('{3050f37f-98b5-11cf-bb82-00aa00bdce0b}')
HTMLSysMenuFlag = Int32
HTMLSysMenuFlagNo: win32more.Windows.Win32.Web.MsHtml.HTMLSysMenuFlag = 0
HTMLSysMenuFlagYes: win32more.Windows.Win32.Web.MsHtml.HTMLSysMenuFlag = 524288
HTMLSysMenuFlag_Max: win32more.Windows.Win32.Web.MsHtml.HTMLSysMenuFlag = 2147483647
HTMLTable = Guid('{3050f26b-98b5-11cf-bb82-00aa00bdce0b}')
HTMLTableCaption = Guid('{3050f2ec-98b5-11cf-bb82-00aa00bdce0b}')
HTMLTableCell = Guid('{3050f246-98b5-11cf-bb82-00aa00bdce0b}')
HTMLTableCol = Guid('{3050f26c-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLTableEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f407-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLTableEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f623-98b5-11cf-bb82-00aa00bdce0b}')
HTMLTableRow = Guid('{3050f26d-98b5-11cf-bb82-00aa00bdce0b}')
HTMLTableSection = Guid('{3050f2e9-98b5-11cf-bb82-00aa00bdce0b}')
HTMLTextAreaElement = Guid('{3050f2ac-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLTextContainerEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{1ff6aa72-5842-11cf-a707-00aa00c0098d}')
class HTMLTextContainerEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f624-98b5-11cf-bb82-00aa00bdce0b}')
HTMLTextElement = Guid('{3050f26a-98b5-11cf-bb82-00aa00bdce0b}')
HTMLTimeRanges = Guid('{3051070b-98b5-11cf-bb82-00aa00bdce0b}')
HTMLTitleElement = Guid('{3050f284-98b5-11cf-bb82-00aa00bdce0b}')
HTMLUListElement = Guid('{3050f269-98b5-11cf-bb82-00aa00bdce0b}')
HTMLUnknownElement = Guid('{3050f268-98b5-11cf-bb82-00aa00bdce0b}')
HTMLUrnCollection = Guid('{3050f580-98b5-11cf-bb82-00aa00bdce0b}')
HTMLVideoElement = Guid('{3051070f-98b5-11cf-bb82-00aa00bdce0b}')
HTMLW3CComputedStyle = Guid('{305106c8-98b5-11cf-bb82-00aa00bdce0b}')
HTMLWindow2 = Guid('{d48a6ec6-6a4a-11cf-94a7-444553540000}')
class HTMLWindowEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{96a0a4e0-d062-11cf-94b6-00aa0060275c}')
class HTMLWindowEvents2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f625-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLWindowEvents3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5a1-98b5-11cf-bb82-00aa00bdce0b}')
HTMLWindowProxy = Guid('{3050f391-98b5-11cf-bb82-00aa00bdce0b}')
HTMLWindowState = Int32
HTMLWindowStateNormal: win32more.Windows.Win32.Web.MsHtml.HTMLWindowState = 1
HTMLWindowStateMaximize: win32more.Windows.Win32.Web.MsHtml.HTMLWindowState = 3
HTMLWindowStateMinimize: win32more.Windows.Win32.Web.MsHtml.HTMLWindowState = 6
HTMLWindowState_Max: win32more.Windows.Win32.Web.MsHtml.HTMLWindowState = 2147483647
HTMLWndOptionElement = Guid('{3050f2d0-98b5-11cf-bb82-00aa00bdce0b}')
HTMLWndSelectElement = Guid('{3050f2cf-98b5-11cf-bb82-00aa00bdce0b}')
HTMLXMLHttpRequest = Guid('{3051040b-98b5-11cf-bb82-00aa00bdce0b}')
class HTMLXMLHttpRequestEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510498-98b5-11cf-bb82-00aa00bdce0b}')
HTMLXMLHttpRequestFactory = Guid('{3051040d-98b5-11cf-bb82-00aa00bdce0b}')
HTML_PAINTER = Int32
HTMLPAINTER_OPAQUE: win32more.Windows.Win32.Web.MsHtml.HTML_PAINTER = 1
HTMLPAINTER_TRANSPARENT: win32more.Windows.Win32.Web.MsHtml.HTML_PAINTER = 2
HTMLPAINTER_ALPHA: win32more.Windows.Win32.Web.MsHtml.HTML_PAINTER = 4
HTMLPAINTER_COMPLEX: win32more.Windows.Win32.Web.MsHtml.HTML_PAINTER = 8
HTMLPAINTER_OVERLAY: win32more.Windows.Win32.Web.MsHtml.HTML_PAINTER = 16
HTMLPAINTER_HITTEST: win32more.Windows.Win32.Web.MsHtml.HTML_PAINTER = 32
HTMLPAINTER_SURFACE: win32more.Windows.Win32.Web.MsHtml.HTML_PAINTER = 256
HTMLPAINTER_3DSURFACE: win32more.Windows.Win32.Web.MsHtml.HTML_PAINTER = 512
HTMLPAINTER_NOBAND: win32more.Windows.Win32.Web.MsHtml.HTML_PAINTER = 1024
HTMLPAINTER_NODC: win32more.Windows.Win32.Web.MsHtml.HTML_PAINTER = 4096
HTMLPAINTER_NOPHYSICALCLIP: win32more.Windows.Win32.Web.MsHtml.HTML_PAINTER = 8192
HTMLPAINTER_NOSAVEDC: win32more.Windows.Win32.Web.MsHtml.HTML_PAINTER = 16384
HTMLPAINTER_SUPPORTS_XFORM: win32more.Windows.Win32.Web.MsHtml.HTML_PAINTER = 32768
HTMLPAINTER_EXPAND: win32more.Windows.Win32.Web.MsHtml.HTML_PAINTER = 65536
HTMLPAINTER_NOSCROLLBITS: win32more.Windows.Win32.Web.MsHtml.HTML_PAINTER = 131072
HTML_PAINTER_Max: win32more.Windows.Win32.Web.MsHtml.HTML_PAINTER = 2147483647
class HTML_PAINTER_INFO(Structure):
    lFlags: Int32
    lZOrder: Int32
    iidDrawObject: Guid
    rcExpand: win32more.Windows.Win32.Foundation.RECT
HTML_PAINT_DRAW_FLAGS = Int32
HTMLPAINT_DRAW_UPDATEREGION: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_DRAW_FLAGS = 1
HTMLPAINT_DRAW_USE_XFORM: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_DRAW_FLAGS = 2
HTML_PAINT_DRAW_FLAGS_Max: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_DRAW_FLAGS = 2147483647
class HTML_PAINT_DRAW_INFO(Structure):
    rcViewport: win32more.Windows.Win32.Foundation.RECT
    hrgnUpdate: win32more.Windows.Win32.Graphics.Gdi.HRGN
    xform: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_XFORM
HTML_PAINT_DRAW_INFO_FLAGS = Int32
HTMLPAINT_DRAWINFO_VIEWPORT: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_DRAW_INFO_FLAGS = 1
HTMLPAINT_DRAWINFO_UPDATEREGION: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_DRAW_INFO_FLAGS = 2
HTMLPAINT_DRAWINFO_XFORM: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_DRAW_INFO_FLAGS = 4
HTML_PAINT_DRAW_INFO_FLAGS_Max: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_DRAW_INFO_FLAGS = 2147483647
HTML_PAINT_EVENT_FLAGS = Int32
HTMLPAINT_EVENT_TARGET: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_EVENT_FLAGS = 1
HTMLPAINT_EVENT_SETCURSOR: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_EVENT_FLAGS = 2
HTML_PAINT_EVENT_FLAGS_Max: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_EVENT_FLAGS = 2147483647
class HTML_PAINT_XFORM(Structure):
    eM11: Single
    eM12: Single
    eM21: Single
    eM22: Single
    eDx: Single
    eDy: Single
HTML_PAINT_ZORDER = Int32
HTMLPAINT_ZORDER_NONE: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_ZORDER = 0
HTMLPAINT_ZORDER_REPLACE_ALL: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_ZORDER = 1
HTMLPAINT_ZORDER_REPLACE_CONTENT: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_ZORDER = 2
HTMLPAINT_ZORDER_REPLACE_BACKGROUND: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_ZORDER = 3
HTMLPAINT_ZORDER_BELOW_CONTENT: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_ZORDER = 4
HTMLPAINT_ZORDER_BELOW_FLOW: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_ZORDER = 5
HTMLPAINT_ZORDER_ABOVE_FLOW: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_ZORDER = 6
HTMLPAINT_ZORDER_ABOVE_CONTENT: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_ZORDER = 7
HTMLPAINT_ZORDER_WINDOW_TOP: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_ZORDER = 8
HTML_PAINT_ZORDER_Max: win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_ZORDER = 2147483647
HT_OPTIONS = Int32
HT_OPT_AllowAfterEOL: win32more.Windows.Win32.Web.MsHtml.HT_OPTIONS = 1
HT_OPTIONS_Max: win32more.Windows.Win32.Web.MsHtml.HT_OPTIONS = 2147483647
HT_RESULTS = Int32
HT_RESULTS_Glyph: win32more.Windows.Win32.Web.MsHtml.HT_RESULTS = 1
HT_RESULTS_Max: win32more.Windows.Win32.Web.MsHtml.HT_RESULTS = 2147483647
HostDialogHelper = IntPtr
HtmlDlgSafeHelper = Guid('{3050f819-98b5-11cf-bb82-00aa00bdce0b}')
class IBFCacheable(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{30510861-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def EnterBFCache(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ExitBFCache(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IBlockFormats(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f830-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get__NewEnum(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Count(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Item(self, pvarIndex: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pbstrBlockFormat: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICSSFilter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f3ec-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def SetSite(self, pSink: win32more.Windows.Win32.Web.MsHtml.ICSSFilterSite) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnAmbientPropertyChange(self, dispid: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICSSFilterSite(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f3ed-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetElement(self, Element: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def FireOnFilterChangeEvent(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICanvasGradient(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510714-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def addColorStop(self, offset: Single, color: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICanvasImageData(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051071a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_width(self, p: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_height(self, p: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_data(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICanvasPattern(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510716-98b5-11cf-bb82-00aa00bdce0b}')
class ICanvasPixelArray(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051071c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICanvasPixelArrayData(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{305107f9-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetBufferPointer(self, ppBuffer: POINTER(POINTER(Byte)), pBufferLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICanvasRenderingContext2D(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106ff-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_canvas(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLCanvasElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def restore(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def save(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def rotate(self, angle: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def scale(self, x: Single, y: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def setTransform(self, m11: Single, m12: Single, m21: Single, m22: Single, dx: Single, dy: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def transform(self, m11: Single, m12: Single, m21: Single, m22: Single, dx: Single, dy: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def translate(self, x: Single, y: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_globalAlpha(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_globalAlpha(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_globalCompositeOperation(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_globalCompositeOperation(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_fillStyle(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_fillStyle(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_strokeStyle(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_strokeStyle(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def createLinearGradient(self, x0: Single, y0: Single, x1: Single, y1: Single, ppCanvasGradient: POINTER(win32more.Windows.Win32.Web.MsHtml.ICanvasGradient)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def createRadialGradient(self, x0: Single, y0: Single, r0: Single, x1: Single, y1: Single, r1: Single, ppCanvasGradient: POINTER(win32more.Windows.Win32.Web.MsHtml.ICanvasGradient)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def createPattern(self, image: win32more.Windows.Win32.System.Com.IDispatch, repetition: win32more.Windows.Win32.System.Variant.VARIANT, ppCanvasPattern: POINTER(win32more.Windows.Win32.Web.MsHtml.ICanvasPattern)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_lineCap(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_lineCap(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_lineJoin(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_lineJoin(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def put_lineWidth(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_lineWidth(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def put_miterLimit(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_miterLimit(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def put_shadowBlur(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_shadowBlur(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def put_shadowColor(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_shadowColor(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def put_shadowOffsetX(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_shadowOffsetX(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def put_shadowOffsetY(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_shadowOffsetY(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def clearRect(self, x: Single, y: Single, w: Single, h: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def fillRect(self, x: Single, y: Single, w: Single, h: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def strokeRect(self, x: Single, y: Single, w: Single, h: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def arc(self, x: Single, y: Single, radius: Single, startAngle: Single, endAngle: Single, anticlockwise: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def arcTo(self, x1: Single, y1: Single, x2: Single, y2: Single, radius: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def beginPath(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def bezierCurveTo(self, cp1x: Single, cp1y: Single, cp2x: Single, cp2y: Single, x: Single, y: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def clip(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def closePath(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def fill(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def lineTo(self, x: Single, y: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def moveTo(self, x: Single, y: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def quadraticCurveTo(self, cpx: Single, cpy: Single, x: Single, y: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def rect(self, x: Single, y: Single, w: Single, h: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def stroke(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def isPointInPath(self, x: Single, y: Single, pResult: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def put_font(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def get_font(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def put_textAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def get_textAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def put_textBaseline(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def get_textBaseline(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def fillText(self, text: win32more.Windows.Win32.Foundation.BSTR, x: Single, y: Single, maxWidth: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def measureText(self, text: win32more.Windows.Win32.Foundation.BSTR, ppCanvasTextMetrics: POINTER(win32more.Windows.Win32.Web.MsHtml.ICanvasTextMetrics)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def strokeText(self, text: win32more.Windows.Win32.Foundation.BSTR, x: Single, y: Single, maxWidth: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def drawImage(self, pSrc: win32more.Windows.Win32.System.Com.IDispatch, a1: win32more.Windows.Win32.System.Variant.VARIANT, a2: win32more.Windows.Win32.System.Variant.VARIANT, a3: win32more.Windows.Win32.System.Variant.VARIANT, a4: win32more.Windows.Win32.System.Variant.VARIANT, a5: win32more.Windows.Win32.System.Variant.VARIANT, a6: win32more.Windows.Win32.System.Variant.VARIANT, a7: win32more.Windows.Win32.System.Variant.VARIANT, a8: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def createImageData(self, a1: win32more.Windows.Win32.System.Variant.VARIANT, a2: win32more.Windows.Win32.System.Variant.VARIANT, ppCanvasImageData: POINTER(win32more.Windows.Win32.Web.MsHtml.ICanvasImageData)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def getImageData(self, sx: Single, sy: Single, sw: Single, sh: Single, ppCanvasImageData: POINTER(win32more.Windows.Win32.Web.MsHtml.ICanvasImageData)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def putImageData(self, imagedata: win32more.Windows.Win32.Web.MsHtml.ICanvasImageData, dx: Single, dy: Single, dirtyX: win32more.Windows.Win32.System.Variant.VARIANT, dirtyY: win32more.Windows.Win32.System.Variant.VARIANT, dirtyWidth: win32more.Windows.Win32.System.Variant.VARIANT, dirtyHeight: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICanvasTextMetrics(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510718-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_width(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IClassFactoryEx(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IClassFactory
    _iid_ = Guid('{342d1ea0-ae25-11d1-89c5-006008c3fbfc}')
    @commethod(5)
    def CreateInstanceWithContext(self, punkContext: win32more.Windows.Win32.System.Com.IUnknown, punkOuter: win32more.Windows.Win32.System.Com.IUnknown, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IClientCaps(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{7e8bc44d-aeff-11d1-89c2-00c04fb6bfc4}')
    @commethod(7)
    def get_javaEnabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_cookieEnabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_cpuClass(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_systemLanguage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_userLanguage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_platform(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_connectionSpeed(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_onLine(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_colorDepth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_bufferDepth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_width(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_height(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_availHeight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_availWidth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_connectionType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def isComponentInstalled(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, bstrUrl: win32more.Windows.Win32.Foundation.BSTR, bStrVer: win32more.Windows.Win32.Foundation.BSTR, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def getComponentVersion(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, bstrUrl: win32more.Windows.Win32.Foundation.BSTR, pbstrVer: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def compareVersions(self, bstrVer1: win32more.Windows.Win32.Foundation.BSTR, bstrVer2: win32more.Windows.Win32.Foundation.BSTR, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def addComponentRequest(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, bstrUrl: win32more.Windows.Win32.Foundation.BSTR, bStrVer: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def doComponentRequest(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def clearComponentRequest(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICustomDoc(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f3f0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def SetUIHandler(self, pUIHandler: win32more.Windows.Win32.Web.MsHtml.IDocHostUIHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMBeforeUnloadEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510763-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_returnValue(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_returnValue(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMCloseEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305107ff-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_wasClean(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def initCloseEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, wasClean: win32more.Windows.Win32.Foundation.VARIANT_BOOL, code: Int32, reason: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMCompositionEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106d8-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_data(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def initCompositionEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, viewArg: win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2, data: win32more.Windows.Win32.Foundation.BSTR, locale: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_locale(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMCustomEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106de-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_detail(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def initCustomEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, detail: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMDocumentType(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510738-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_entities(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_notations(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_publicId(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_systemId(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_internalSubset(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMDragEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510761-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_dataTransfer(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDataTransfer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def initDragEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, viewArg: win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2, detailArg: Int32, screenXArg: Int32, screenYArg: Int32, clientXArg: Int32, clientYArg: Int32, ctrlKeyArg: win32more.Windows.Win32.Foundation.VARIANT_BOOL, altKeyArg: win32more.Windows.Win32.Foundation.VARIANT_BOOL, shiftKeyArg: win32more.Windows.Win32.Foundation.VARIANT_BOOL, metaKeyArg: win32more.Windows.Win32.Foundation.VARIANT_BOOL, buttonArg: UInt16, relatedTargetArg: win32more.Windows.Win32.Web.MsHtml.IEventTarget, dataTransferArg: win32more.Windows.Win32.Web.MsHtml.IHTMLDataTransfer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104ba-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_bubbles(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_cancelable(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_currentTarget(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IEventTarget)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_defaultPrevented(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_eventPhase(self, p: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_target(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IEventTarget)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_timeStamp(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def initEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def preventDefault(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def stopPropagation(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def stopImmediatePropagation(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_isTrusted(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_cancelBubble(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_cancelBubble(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_srcElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMEventRegistrationCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3051083b-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def OnDOMEventListenerAdded(self, pszEventType: win32more.Windows.Win32.Foundation.PWSTR, pHandler: win32more.Windows.Win32.Web.MsHtml.IScriptEventHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnDOMEventListenerRemoved(self, ullCookie: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMException(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051072b-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_code(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_code(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_message(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMFocusEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106cc-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_relatedTarget(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IEventTarget)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def initFocusEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, view: win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2, detail: Int32, relatedTargetArg: win32more.Windows.Win32.Web.MsHtml.IEventTarget) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMKeyboardEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106d6-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_key(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_location(self, p: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_ctrlKey(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_shiftKey(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_altKey(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_metaKey(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_repeat(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def getModifierState(self, keyArg: win32more.Windows.Win32.Foundation.BSTR, state: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def initKeyboardEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, viewArg: win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2, keyArg: win32more.Windows.Win32.Foundation.BSTR, locationArg: UInt32, modifiersListArg: win32more.Windows.Win32.Foundation.BSTR, repeat: win32more.Windows.Win32.Foundation.VARIANT_BOOL, locale: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_keyCode(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_charCode(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_which(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_ie9_char(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_locale(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMMSAnimationEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305107b7-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_animationName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_elapsedTime(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def initMSAnimationEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, animationName: win32more.Windows.Win32.Foundation.BSTR, elapsedTime: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMMSManipulationEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510816-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_lastState(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_currentState(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def initMSManipulationEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, viewArg: win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2, detailArg: Int32, lastState: Int32, currentState: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMMSTransitionEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305107b5-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_propertyName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_elapsedTime(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def initMSTransitionEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, propertyName: win32more.Windows.Win32.Foundation.BSTR, elapsedTime: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMMessageEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510720-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_data(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_origin(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_source(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def initMessageEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, data: win32more.Windows.Win32.Foundation.BSTR, origin: win32more.Windows.Win32.Foundation.BSTR, lastEventId: win32more.Windows.Win32.Foundation.BSTR, source: win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMMouseEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106ce-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_screenX(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_screenY(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_clientX(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_clientY(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_ctrlKey(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_shiftKey(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_altKey(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_metaKey(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_button(self, p: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_relatedTarget(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IEventTarget)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def initMouseEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, viewArg: win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2, detailArg: Int32, screenXArg: Int32, screenYArg: Int32, clientXArg: Int32, clientYArg: Int32, ctrlKeyArg: win32more.Windows.Win32.Foundation.VARIANT_BOOL, altKeyArg: win32more.Windows.Win32.Foundation.VARIANT_BOOL, shiftKeyArg: win32more.Windows.Win32.Foundation.VARIANT_BOOL, metaKeyArg: win32more.Windows.Win32.Foundation.VARIANT_BOOL, buttonArg: UInt16, relatedTargetArg: win32more.Windows.Win32.Web.MsHtml.IEventTarget) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def getModifierState(self, keyArg: win32more.Windows.Win32.Foundation.BSTR, activated: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_buttons(self, p: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_fromElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_toElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_x(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_y(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_offsetX(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_offsetY(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_pageX(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_pageY(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_layerX(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_layerY(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_which(self, p: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMMouseWheelEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106d0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_wheelDelta(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def initMouseWheelEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, viewArg: win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2, detailArg: Int32, screenXArg: Int32, screenYArg: Int32, clientXArg: Int32, clientYArg: Int32, buttonArg: UInt16, relatedTargetArg: win32more.Windows.Win32.Web.MsHtml.IEventTarget, modifiersListArg: win32more.Windows.Win32.Foundation.BSTR, wheelDeltaArg: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMMutationEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106da-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_relatedNode(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_prevValue(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_newValue(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_attrName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_attrChange(self, p: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def initMutationEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, relatedNodeArg: win32more.Windows.Win32.System.Com.IDispatch, prevValueArg: win32more.Windows.Win32.Foundation.BSTR, newValueArg: win32more.Windows.Win32.Foundation.BSTR, attrNameArg: win32more.Windows.Win32.Foundation.BSTR, attrChangeArg: UInt16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMNodeIterator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510746-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_root(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_whatToShow(self, p: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_filter(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_expandEntityReferences(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def nextNode(self, ppRetNode: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def previousNode(self, ppRetNode: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def detach(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMParser(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510781-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def parseFromString(self, xmlSource: win32more.Windows.Win32.Foundation.BSTR, mimeType: win32more.Windows.Win32.Foundation.BSTR, ppNode: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDocument2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMParserFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510783-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def create(self, __MIDL__IDOMParserFactory0000: POINTER(win32more.Windows.Win32.Web.MsHtml.IDOMParser)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMProcessingInstruction(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510742-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_target(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_data(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_data(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMProgressEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051071e-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_lengthComputable(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_loaded(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_total(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def initProgressEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, lengthComputableArg: win32more.Windows.Win32.Foundation.VARIANT_BOOL, loadedArg: UInt64, totalArg: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMSiteModeEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510765-98b6-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_buttonID(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_actionURL(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMStorageEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510722-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_key(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_oldValue(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_newValue(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_url(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_storageArea(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStorage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def initStorageEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, keyArg: win32more.Windows.Win32.Foundation.BSTR, oldValueArg: win32more.Windows.Win32.Foundation.BSTR, newValueArg: win32more.Windows.Win32.Foundation.BSTR, urlArg: win32more.Windows.Win32.Foundation.BSTR, storageAreaArg: win32more.Windows.Win32.Web.MsHtml.IHTMLStorage) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMTextEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106d4-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_data(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_inputMethod(self, p: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def initTextEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, viewArg: win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2, dataArg: win32more.Windows.Win32.Foundation.BSTR, inputMethod: UInt32, locale: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_locale(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMTreeWalker(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510748-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_root(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_whatToShow(self, p: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_filter(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_expandEntityReferences(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_currentNode(self, v: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_currentNode(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def parentNode(self, ppRetNode: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def firstChild(self, ppRetNode: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def lastChild(self, ppRetNode: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def previousSibling(self, ppRetNode: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def nextSibling(self, ppRetNode: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def previousNode(self, ppRetNode: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def nextNode(self, ppRetNode: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMUIEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106ca-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_view(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_detail(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def initUIEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, view: win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2, detail: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMWheelEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106d2-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_deltaX(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_deltaY(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_deltaZ(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_deltaMode(self, p: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def initWheelEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, canBubble: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cancelable: win32more.Windows.Win32.Foundation.VARIANT_BOOL, viewArg: win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2, detailArg: Int32, screenXArg: Int32, screenYArg: Int32, clientXArg: Int32, clientYArg: Int32, buttonArg: UInt16, relatedTargetArg: win32more.Windows.Win32.Web.MsHtml.IEventTarget, modifiersListArg: win32more.Windows.Win32.Foundation.BSTR, deltaX: Int32, deltaY: Int32, deltaZ: Int32, deltaMode: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMXmlSerializer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051077d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def serializeToString(self, pNode: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, pString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDOMXmlSerializerFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051077f-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def create(self, __MIDL__IDOMXmlSerializerFactory0000: POINTER(win32more.Windows.Win32.Web.MsHtml.IDOMXmlSerializer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDebugCallbackNotificationHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{30510842-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def RequestedCallbackTypes(self, pCallbackMask: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def BeforeDispatchEvent(self, pEvent: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def DispatchEventComplete(self, pEvent: win32more.Windows.Win32.System.Com.IUnknown, propagationStatus: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def BeforeInvokeDomCallback(self, pEvent: win32more.Windows.Win32.System.Com.IUnknown, pCallback: win32more.Windows.Win32.Web.MsHtml.IScriptEventHandler, eStage: win32more.Windows.Win32.Web.MsHtml.DOM_EVENT_PHASE, propagationStatus: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def InvokeDomCallbackComplete(self, pEvent: win32more.Windows.Win32.System.Com.IUnknown, pCallback: win32more.Windows.Win32.Web.MsHtml.IScriptEventHandler, eStage: win32more.Windows.Win32.Web.MsHtml.DOM_EVENT_PHASE, propagationStatus: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def BeforeInvokeCallback(self, eCallbackType: win32more.Windows.Win32.Web.MsHtml.SCRIPT_TIMER_TYPE, callbackCookie: UInt32, pDispHandler: win32more.Windows.Win32.System.Com.IDispatch, ullHandlerCookie: UInt64, functionName: win32more.Windows.Win32.Foundation.BSTR, line: UInt32, column: UInt32, cchLength: UInt32, pDebugDocumentContext: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def InvokeCallbackComplete(self, eCallbackType: win32more.Windows.Win32.Web.MsHtml.SCRIPT_TIMER_TYPE, callbackCookie: UInt32, pDispHandler: win32more.Windows.Win32.System.Com.IDispatch, ullHandlerCookie: UInt64, functionName: win32more.Windows.Win32.Foundation.BSTR, line: UInt32, column: UInt32, cchLength: UInt32, pDebugDocumentContext: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDeveloperConsoleMessageReceiver(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{30510808-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def Write(self, source: win32more.Windows.Win32.Foundation.PWSTR, level: win32more.Windows.Win32.Web.MsHtml.DEV_CONSOLE_MESSAGE_LEVEL, messageId: Int32, messageText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def WriteWithUrl(self, source: win32more.Windows.Win32.Foundation.PWSTR, level: win32more.Windows.Win32.Web.MsHtml.DEV_CONSOLE_MESSAGE_LEVEL, messageId: Int32, messageText: win32more.Windows.Win32.Foundation.PWSTR, fileUrl: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def WriteWithUrlAndLine(self, source: win32more.Windows.Win32.Foundation.PWSTR, level: win32more.Windows.Win32.Web.MsHtml.DEV_CONSOLE_MESSAGE_LEVEL, messageId: Int32, messageText: win32more.Windows.Win32.Foundation.PWSTR, fileUrl: win32more.Windows.Win32.Foundation.PWSTR, line: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def WriteWithUrlLineAndColumn(self, source: win32more.Windows.Win32.Foundation.PWSTR, level: win32more.Windows.Win32.Web.MsHtml.DEV_CONSOLE_MESSAGE_LEVEL, messageId: Int32, messageText: win32more.Windows.Win32.Foundation.PWSTR, fileUrl: win32more.Windows.Win32.Foundation.PWSTR, line: UInt32, column: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDiagnosticsScriptEngine(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{30510859-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def EvaluateScript(self, pszScript: win32more.Windows.Win32.Foundation.PWSTR, pszScriptName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def FireScriptMessageEvent(self, pszNames: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pszValues: POINTER(win32more.Windows.Win32.Foundation.PWSTR), ulPropertyCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Detach(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDiagnosticsScriptEngineProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3051085a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def CreateDiagnosticsScriptEngine(self, pScriptSite: win32more.Windows.Win32.Web.MsHtml.IDiagnosticsScriptEngineSite, fDebuggingEnabled: win32more.Windows.Win32.Foundation.BOOL, ulProcessId: UInt32, ppEngine: POINTER(win32more.Windows.Win32.Web.MsHtml.IDiagnosticsScriptEngine)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDiagnosticsScriptEngineSite(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{30510858-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def OnMessage(self, pszData: POINTER(win32more.Windows.Win32.Foundation.PWSTR), ulDataCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnScriptError(self, pScriptError: win32more.Windows.Win32.System.Diagnostics.Debug.ActiveScript.IActiveScriptError) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDisplayPointer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f69e-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def MoveToPoint(self, ptPoint: win32more.Windows.Win32.Foundation.POINT, eCoordSystem: win32more.Windows.Win32.Web.MsHtml.COORD_SYSTEM, pElementContext: win32more.Windows.Win32.Web.MsHtml.IHTMLElement, dwHitTestOptions: UInt32, pdwHitTestResults: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MoveUnit(self, eMoveUnit: win32more.Windows.Win32.Web.MsHtml.DISPLAY_MOVEUNIT, lXPos: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def PositionMarkupPointer(self, pMarkupPointer: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def MoveToPointer(self, pDispPointer: win32more.Windows.Win32.Web.MsHtml.IDisplayPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetPointerGravity(self, eGravity: win32more.Windows.Win32.Web.MsHtml.POINTER_GRAVITY) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetPointerGravity(self, peGravity: POINTER(win32more.Windows.Win32.Web.MsHtml.POINTER_GRAVITY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetDisplayGravity(self, eGravity: win32more.Windows.Win32.Web.MsHtml.DISPLAY_GRAVITY) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetDisplayGravity(self, peGravity: POINTER(win32more.Windows.Win32.Web.MsHtml.DISPLAY_GRAVITY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def IsPositioned(self, pfPositioned: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Unposition(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def IsEqualTo(self, pDispPointer: win32more.Windows.Win32.Web.MsHtml.IDisplayPointer, pfIsEqual: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def IsLeftOf(self, pDispPointer: win32more.Windows.Win32.Web.MsHtml.IDisplayPointer, pfIsLeftOf: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def IsRightOf(self, pDispPointer: win32more.Windows.Win32.Web.MsHtml.IDisplayPointer, pfIsRightOf: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def IsAtBOL(self, pfBOL: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def MoveToMarkupPointer(self, pPointer: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pDispLineContext: win32more.Windows.Win32.Web.MsHtml.IDisplayPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def ScrollIntoView(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetLineInfo(self, ppLineInfo: POINTER(win32more.Windows.Win32.Web.MsHtml.ILineInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetFlowElement(self, ppLayoutElement: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def QueryBreaks(self, pdwBreaks: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDisplayServices(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f69d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def CreateDisplayPointer(self, ppDispPointer: POINTER(win32more.Windows.Win32.Web.MsHtml.IDisplayPointer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def TransformRect(self, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT), eSource: win32more.Windows.Win32.Web.MsHtml.COORD_SYSTEM, eDestination: win32more.Windows.Win32.Web.MsHtml.COORD_SYSTEM, pIElement: win32more.Windows.Win32.Web.MsHtml.IHTMLElement) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def TransformPoint(self, pPoint: POINTER(win32more.Windows.Win32.Foundation.POINT), eSource: win32more.Windows.Win32.Web.MsHtml.COORD_SYSTEM, eDestination: win32more.Windows.Win32.Web.MsHtml.COORD_SYSTEM, pIElement: win32more.Windows.Win32.Web.MsHtml.IHTMLElement) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetCaret(self, ppCaret: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLCaret)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetComputedStyle(self, pPointer: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, ppComputedStyle: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLComputedStyle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def ScrollRectIntoView(self, pIElement: win32more.Windows.Win32.Web.MsHtml.IHTMLElement, rect: win32more.Windows.Win32.Foundation.RECT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def HasFlowLayout(self, pIElement: win32more.Windows.Win32.Web.MsHtml.IHTMLElement, pfHasFlowLayout: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDocHostShowUI(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c4d244b0-d43e-11cf-893b-00aa00bdce1a}')
    @commethod(3)
    def ShowMessage(self, hwnd: win32more.Windows.Win32.Foundation.HWND, lpstrText: win32more.Windows.Win32.Foundation.PWSTR, lpstrCaption: win32more.Windows.Win32.Foundation.PWSTR, dwType: UInt32, lpstrHelpFile: win32more.Windows.Win32.Foundation.PWSTR, dwHelpContext: UInt32, plResult: POINTER(win32more.Windows.Win32.Foundation.LRESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ShowHelp(self, hwnd: win32more.Windows.Win32.Foundation.HWND, pszHelpFile: win32more.Windows.Win32.Foundation.PWSTR, uCommand: UInt32, dwData: UInt32, ptMouse: win32more.Windows.Win32.Foundation.POINT, pDispatchObjectHit: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDocHostUIHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bd3f23c0-d43e-11cf-893b-00aa00bdce1a}')
    @commethod(3)
    def ShowContextMenu(self, dwID: UInt32, ppt: POINTER(win32more.Windows.Win32.Foundation.POINT), pcmdtReserved: win32more.Windows.Win32.System.Com.IUnknown, pdispReserved: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetHostInfo(self, pInfo: POINTER(win32more.Windows.Win32.Web.MsHtml.DOCHOSTUIINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def ShowUI(self, dwID: UInt32, pActiveObject: win32more.Windows.Win32.System.Ole.IOleInPlaceActiveObject, pCommandTarget: win32more.Windows.Win32.System.Ole.IOleCommandTarget, pFrame: win32more.Windows.Win32.System.Ole.IOleInPlaceFrame, pDoc: win32more.Windows.Win32.System.Ole.IOleInPlaceUIWindow) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def HideUI(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def UpdateUI(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def EnableModeless(self, fEnable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def OnDocWindowActivate(self, fActivate: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def OnFrameWindowActivate(self, fActivate: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def ResizeBorder(self, prcBorder: POINTER(win32more.Windows.Win32.Foundation.RECT), pUIWindow: win32more.Windows.Win32.System.Ole.IOleInPlaceUIWindow, fRameWindow: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def TranslateAccelerator(self, lpMsg: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.MSG), pguidCmdGroup: POINTER(Guid), nCmdID: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetOptionKeyPath(self, pchKey: POINTER(win32more.Windows.Win32.Foundation.PWSTR), dw: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetDropTarget(self, pDropTarget: win32more.Windows.Win32.System.Ole.IDropTarget, ppDropTarget: POINTER(win32more.Windows.Win32.System.Ole.IDropTarget)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetExternal(self, ppDispatch: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def TranslateUrl(self, dwTranslate: UInt32, pchURLIn: win32more.Windows.Win32.Foundation.PWSTR, ppchURLOut: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def FilterDataObject(self, pDO: win32more.Windows.Win32.System.Com.IDataObject, ppDORet: POINTER(win32more.Windows.Win32.System.Com.IDataObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDocHostUIHandler2(ComPtr):
    extends: win32more.Windows.Win32.Web.MsHtml.IDocHostUIHandler
    _iid_ = Guid('{3050f6d0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(18)
    def GetOverrideKeyPath(self, pchKey: POINTER(win32more.Windows.Win32.Foundation.PWSTR), dw: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDocumentEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104bc-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def createEvent(self, eventType: win32more.Windows.Win32.Foundation.BSTR, ppEvent: POINTER(win32more.Windows.Win32.Web.MsHtml.IDOMEvent)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDocumentRange(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104af-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def createRange(self, ppIHTMLDOMRange: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMRange)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDocumentSelector(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510462-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def querySelector(self, v: win32more.Windows.Win32.Foundation.BSTR, pel: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def querySelectorAll(self, v: win32more.Windows.Win32.Foundation.BSTR, pel: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMChildrenCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDocumentTraversal(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510744-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def createNodeIterator(self, pRootNode: win32more.Windows.Win32.System.Com.IDispatch, ulWhatToShow: Int32, pFilter: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), fEntityReferenceExpansion: win32more.Windows.Win32.Foundation.VARIANT_BOOL, ppNodeIterator: POINTER(win32more.Windows.Win32.Web.MsHtml.IDOMNodeIterator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def createTreeWalker(self, pRootNode: win32more.Windows.Win32.System.Com.IDispatch, ulWhatToShow: Int32, pFilter: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), fEntityReferenceExpansion: win32more.Windows.Win32.Foundation.VARIANT_BOOL, ppTreeWalker: POINTER(win32more.Windows.Win32.Web.MsHtml.IDOMTreeWalker)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def IEISXMLNSREGISTEREDFN(lpszURI: win32more.Windows.Win32.Foundation.PWSTR, pCLSID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def IEREGISTERXMLNSFN(lpszURI: win32more.Windows.Win32.Foundation.PWSTR, clsid: Guid, fMachine: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementBehavior(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f425-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def Init(self, pBehaviorSite: win32more.Windows.Win32.Web.MsHtml.IElementBehaviorSite) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Notify(self, lEvent: Int32, pVar: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Detach(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementBehaviorCategory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f4ed-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetCategory(self, ppchCategory: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementBehaviorFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f429-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def FindBehavior(self, bstrBehavior: win32more.Windows.Win32.Foundation.BSTR, bstrBehaviorUrl: win32more.Windows.Win32.Foundation.BSTR, pSite: win32more.Windows.Win32.Web.MsHtml.IElementBehaviorSite, ppBehavior: POINTER(win32more.Windows.Win32.Web.MsHtml.IElementBehavior)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementBehaviorFocus(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f6b6-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetFocusRect(self, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementBehaviorLayout(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f6ba-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetSize(self, dwFlags: Int32, sizeContent: win32more.Windows.Win32.Foundation.SIZE, pptTranslateBy: POINTER(win32more.Windows.Win32.Foundation.POINT), pptTopLeft: POINTER(win32more.Windows.Win32.Foundation.POINT), psizeProposed: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetLayoutInfo(self, plLayoutInfo: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetPosition(self, lFlags: Int32, pptTopLeft: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def MapSize(self, psizeIn: POINTER(win32more.Windows.Win32.Foundation.SIZE), prcOut: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementBehaviorLayout2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f846-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetTextDescent(self, plDescent: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementBehaviorRender(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f4aa-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def Draw(self, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lLayer: Int32, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT), pReserved: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetRenderInfo(self, plRenderInfo: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def HitTestPoint(self, pPoint: POINTER(win32more.Windows.Win32.Foundation.POINT), pReserved: win32more.Windows.Win32.System.Com.IUnknown, pbHit: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementBehaviorSite(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f427-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetElement(self, ppElement: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def RegisterNotification(self, lEvent: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementBehaviorSiteCategory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f4ee-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetRelatedBehaviors(self, lDirection: Int32, pchCategory: win32more.Windows.Win32.Foundation.PWSTR, ppEnumerator: POINTER(win32more.Windows.Win32.System.Com.IEnumUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementBehaviorSiteLayout(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f6b7-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def InvalidateLayoutInfo(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def InvalidateSize(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetMediaResolution(self, psizeResolution: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementBehaviorSiteLayout2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f847-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetFontInfo(self, plf: POINTER(win32more.Windows.Win32.Graphics.Gdi.LOGFONTW)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementBehaviorSiteOM(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f489-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def RegisterEvent(self, pchEvent: win32more.Windows.Win32.Foundation.PWSTR, lFlags: Int32, plCookie: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetEventCookie(self, pchEvent: win32more.Windows.Win32.Foundation.PWSTR, plCookie: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def FireEvent(self, lCookie: Int32, pEventObject: win32more.Windows.Win32.Web.MsHtml.IHTMLEventObj) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateEventObject(self, ppEventObject: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLEventObj)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def RegisterName(self, pchName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def RegisterUrn(self, pchUrn: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementBehaviorSiteOM2(ComPtr):
    extends: win32more.Windows.Win32.Web.MsHtml.IElementBehaviorSiteOM
    _iid_ = Guid('{3050f659-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(9)
    def GetDefaults(self, ppDefaults: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementDefaults)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementBehaviorSiteRender(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f4a7-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def Invalidate(self, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def InvalidateRenderInfo(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def InvalidateStyle(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementBehaviorSubmit(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f646-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetSubmitInfo(self, pSubmitData: win32more.Windows.Win32.Web.MsHtml.IHTMLSubmitData) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementNamespace(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f671-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def AddTag(self, bstrTagName: win32more.Windows.Win32.Foundation.BSTR, lFlags: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementNamespaceFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f672-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def Create(self, pNamespace: win32more.Windows.Win32.Web.MsHtml.IElementNamespace) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementNamespaceFactory2(ComPtr):
    extends: win32more.Windows.Win32.Web.MsHtml.IElementNamespaceFactory
    _iid_ = Guid('{3050f805-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(4)
    def CreateWithImplementation(self, pNamespace: win32more.Windows.Win32.Web.MsHtml.IElementNamespace, bstrImplementation: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementNamespaceFactoryCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f7fd-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def Resolve(self, bstrNamespace: win32more.Windows.Win32.Foundation.BSTR, bstrTagName: win32more.Windows.Win32.Foundation.BSTR, bstrAttrs: win32more.Windows.Win32.Foundation.BSTR, pNamespace: win32more.Windows.Win32.Web.MsHtml.IElementNamespace) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementNamespaceTable(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f670-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def AddNamespace(self, bstrNamespace: win32more.Windows.Win32.Foundation.BSTR, bstrUrn: win32more.Windows.Win32.Foundation.BSTR, lFlags: Int32, pvarFactory: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementSegment(ComPtr):
    extends: win32more.Windows.Win32.Web.MsHtml.ISegment
    _iid_ = Guid('{3050f68f-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(4)
    def GetElement(self, ppIElement: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetPrimary(self, fPrimary: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def IsPrimary(self, pfPrimary: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementSelector(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510463-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def querySelector(self, v: win32more.Windows.Win32.Foundation.BSTR, pel: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def querySelectorAll(self, v: win32more.Windows.Win32.Foundation.BSTR, pel: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMChildrenCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IElementTraversal(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510736-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_firstElementChild(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_lastElementChild(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_previousElementSibling(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_nextElementSibling(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_childElementCount(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumPrivacyRecords(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f844-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetSize(self, pSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetPrivacyImpacted(self, pState: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Next(self, pbstrUrl: POINTER(win32more.Windows.Win32.Foundation.BSTR), pbstrPolicyRef: POINTER(win32more.Windows.Win32.Foundation.BSTR), pdwReserved: POINTER(Int32), pdwPrivacyFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEventException(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051073a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_code(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_code(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_message(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEventTarget(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104b9-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def addEventListener(self, type: win32more.Windows.Win32.Foundation.BSTR, listener: win32more.Windows.Win32.System.Com.IDispatch, useCapture: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def removeEventListener(self, type: win32more.Windows.Win32.Foundation.BSTR, listener: win32more.Windows.Win32.System.Com.IDispatch, useCapture: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def dispatchEvent(self, evt: win32more.Windows.Win32.Web.MsHtml.IDOMEvent, pfResult: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEventTarget2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{30510839-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetRegisteredEventTypes(self, ppEventTypeArray: POINTER(POINTER(win32more.Windows.Win32.System.Com.SAFEARRAY))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetListenersForType(self, pszEventType: win32more.Windows.Win32.Foundation.PWSTR, ppEventHandlerArray: POINTER(POINTER(win32more.Windows.Win32.System.Com.SAFEARRAY))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RegisterForDOMEventListeners(self, pCallback: win32more.Windows.Win32.Web.MsHtml.IDOMEventRegistrationCallback) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def UnregisterForDOMEventListeners(self, pCallback: win32more.Windows.Win32.Web.MsHtml.IDOMEventRegistrationCallback) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IFontNames(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f839-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get__NewEnum(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Count(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Item(self, pvarIndex: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pbstrFontName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IGetSVGDocument(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305105ab-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def getSVGDocument(self, ppSVGDocument: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTCAttachBehavior(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5f4-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def fireEvent(self, evt: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def detachEvent(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTCAttachBehavior2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f7eb-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def fireEvent(self, evt: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTCDefaultDispatch(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4fd-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_element(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def createEventObject(self, eventObj: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLEventObj)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_defaults(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_document(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTCDescBehavior(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5dc-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_urn(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTCEventBehavior(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4ff-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def fire(self, pvar: win32more.Windows.Win32.Web.MsHtml.IHTMLEventObj) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTCMethodBehavior(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f631-98b5-11cf-bb82-00aa00bdce0b}')
class IHTCPropertyBehavior(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5df-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def fireChange(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_value(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_value(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLAnchorElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f1da-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_href(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_href(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_target(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_target(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_rel(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_rel(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_rev(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_rev(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_urn(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_urn(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_Methods(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_Methods(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_host(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_host(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_hostname(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_hostname(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_pathname(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_pathname(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_port(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_port(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_protocol(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_protocol(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_search(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_search(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_hash(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_hash(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_onblur(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_onblur(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_onfocus(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_onfocus(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_accessKey(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_accessKey(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_protocolLong(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_mimeType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def get_nameProp(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def put_tabIndex(self, v: Int16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_tabIndex(self, p: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def focus(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def blur(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLAnchorElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f825-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_charset(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_charset(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_coords(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_coords(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_hreflang(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_hreflang(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_shape(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_shape(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_type(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLAnchorElement3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051041d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_shape(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_shape(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_coords(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_coords(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_href(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_href(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLAppBehavior(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5ca-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_applicationName(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_applicationName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_version(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_version(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_icon(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_icon(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_singleInstance(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_singleInstance(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_minimizeButton(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_minimizeButton(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_maximizeButton(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_maximizeButton(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_border(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_border(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_borderStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_borderStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_sysMenu(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_sysMenu(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_caption(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_caption(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_windowState(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_windowState(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_showInTaskBar(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_showInTaskBar(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_commandLine(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLAppBehavior2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5c9-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_contextMenu(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_contextMenu(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_innerBorder(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_innerBorder(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_scroll(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_scroll(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_scrollFlat(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_scrollFlat(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_selection(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_selection(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLAppBehavior3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5cd-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_navigable(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_navigable(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLApplicationCache(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510828-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_status(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_onchecking(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_onchecking(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_onerror(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_onerror(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_onnoupdate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_onnoupdate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_ondownloading(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_ondownloading(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_onprogress(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_onprogress(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_onupdateready(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_onupdateready(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_oncached(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_oncached(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_onobsolete(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_onobsolete(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def update(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def swapCache(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def abort(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLAreaElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f265-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_shape(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_shape(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_coords(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_coords(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_href(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_href(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_target(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_target(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_alt(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_alt(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_noHref(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_noHref(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_host(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_host(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_hostname(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_hostname(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_pathname(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_pathname(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_port(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_port(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_protocol(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_protocol(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_search(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_search(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_hash(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_hash(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_onblur(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_onblur(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_onfocus(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_onfocus(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_tabIndex(self, v: Int16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_tabIndex(self, p: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def focus(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def blur(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLAreaElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051041f-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_shape(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_shape(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_coords(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_coords(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_href(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_href(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLAreasCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f383-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_length(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get__newEnum(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def item(self, name: win32more.Windows.Win32.System.Variant.VARIANT, index: win32more.Windows.Win32.System.Variant.VARIANT, pdisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def tags(self, tagName: win32more.Windows.Win32.System.Variant.VARIANT, pdisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def add(self, element: win32more.Windows.Win32.Web.MsHtml.IHTMLElement, before: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def remove(self, index: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLAreasCollection2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5ec-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def urns(self, urn: win32more.Windows.Win32.System.Variant.VARIANT, pdisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLAreasCollection3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f837-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def namedItem(self, name: win32more.Windows.Win32.Foundation.BSTR, pdisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLAreasCollection4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510492-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def item(self, index: Int32, pNode: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def namedItem(self, name: win32more.Windows.Win32.Foundation.BSTR, pNode: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLAttributeCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4c3-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__newEnum(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def item(self, name: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pdisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLAttributeCollection2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f80a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def getNamedItem(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, newretNode: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def setNamedItem(self, ppNode: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute, newretNode: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def removeNamedItem(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, newretNode: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLAttributeCollection3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510469-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def getNamedItem(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, ppNodeOut: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def setNamedItem(self, pNodeIn: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute, ppNodeOut: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def removeNamedItem(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, ppNodeOut: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def item(self, index: Int32, ppNodeOut: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLAttributeCollection4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106fa-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def getNamedItemNS(self, pvarNS: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), bstrName: win32more.Windows.Win32.Foundation.BSTR, ppNodeOut: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def setNamedItemNS(self, pNodeIn: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2, ppNodeOut: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def removeNamedItemNS(self, pvarNS: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), bstrName: win32more.Windows.Win32.Foundation.BSTR, ppNodeOut: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def getNamedItem(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, ppNodeOut: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def setNamedItem(self, pNodeIn: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2, ppNodeOut: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def removeNamedItem(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, ppNodeOut: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def item(self, index: Int32, ppNodeOut: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLAudioElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510708-98b5-11cf-bb82-00aa00bdce0b}')
class IHTMLAudioElementFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305107eb-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def create(self, src: win32more.Windows.Win32.System.Variant.VARIANT, __MIDL__IHTMLAudioElementFactory0000: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLAudioElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLBGsound(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f369-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_src(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_src(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_loop(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_loop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_volume(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_volume(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_balance(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_balance(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLBRElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f1f0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_clear(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_clear(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLBaseElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f204-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_href(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_href(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_target(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_target(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLBaseElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510420-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_href(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_href(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLBaseFontElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f202-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_color(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_color(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_face(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_face(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_size(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_size(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLBlockElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f208-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_clear(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_clear(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLBlockElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f823-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_cite(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_cite(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_width(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_width(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLBlockElement3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510494-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_cite(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_cite(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLBodyElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f1d8-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_background(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_background(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_bgProperties(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_bgProperties(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_leftMargin(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_leftMargin(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_topMargin(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_topMargin(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_rightMargin(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_rightMargin(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_bottomMargin(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_bottomMargin(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_noWrap(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_noWrap(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_bgColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_bgColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_text(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_text(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_link(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_link(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_vLink(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_vLink(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_aLink(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_aLink(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_onload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_onload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_onunload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_onunload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_scroll(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_scroll(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_onselect(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_onselect(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_onbeforeunload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_onbeforeunload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def createTextRange(self, range: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTxtRange)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLBodyElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5c5-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_onbeforeprint(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_onbeforeprint(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_onafterprint(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_onafterprint(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLBodyElement3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510422-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_background(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_background(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_ononline(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_ononline(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_onoffline(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_onoffline(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_onhashchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_onhashchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLBodyElement4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510795-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_onmessage(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_onmessage(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_onstorage(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_onstorage(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLBodyElement5(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510822-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_onpopstate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_onpopstate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLBookmarkCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4ce-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__newEnum(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def item(self, index: Int32, pVarBookmark: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLButtonElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2bb-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_status(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_status(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_disabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_disabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_form(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFormElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def createTextRange(self, range: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTxtRange)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLButtonElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106f3-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_type(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCSSImportRule(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106ea-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_href(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_media(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_media(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_styleSheet(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheet)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCSSMediaList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510731-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_mediaText(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_mediaText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def item(self, index: Int32, pbstrMedium: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def appendMedium(self, bstrMedium: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def deleteMedium(self, bstrMedium: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCSSMediaRule(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106eb-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_media(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_media(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_cssRules(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheetRulesCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def insertRule(self, bstrRule: win32more.Windows.Win32.Foundation.BSTR, lIndex: Int32, plNewIndex: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def deleteRule(self, lIndex: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCSSNamespaceRule(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106ee-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_namespaceURI(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_prefix(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCSSRule(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106e9-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_type(self, p: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_cssText(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_cssText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_parentRule(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLCSSRule)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_parentStyleSheet(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheet)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCSSStyleDeclaration(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510740-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_parentRule(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def getPropertyValue(self, bstrPropertyName: win32more.Windows.Win32.Foundation.BSTR, pbstrPropertyValue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def getPropertyPriority(self, bstrPropertyName: win32more.Windows.Win32.Foundation.BSTR, pbstrPropertyPriority: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def removeProperty(self, bstrPropertyName: win32more.Windows.Win32.Foundation.BSTR, pbstrPropertyValue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def setProperty(self, bstrPropertyName: win32more.Windows.Win32.Foundation.BSTR, pvarPropertyValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pvarPropertyPriority: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def item(self, index: Int32, pbstrPropertyName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_fontFamily(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_fontFamily(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_fontStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_fontStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_fontVariant(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_fontVariant(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_fontWeight(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_fontWeight(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_fontSize(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_fontSize(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_font(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_font(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_color(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_color(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_background(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_background(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def put_backgroundColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_backgroundColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def put_backgroundImage(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_backgroundImage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def put_backgroundRepeat(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_backgroundRepeat(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def put_backgroundAttachment(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_backgroundAttachment(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def put_backgroundPosition(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_backgroundPosition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def put_backgroundPositionX(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_backgroundPositionX(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def put_backgroundPositionY(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def get_backgroundPositionY(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def put_wordSpacing(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_wordSpacing(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def put_letterSpacing(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def get_letterSpacing(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def put_textDecoration(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def get_textDecoration(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def put_verticalAlign(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def get_verticalAlign(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def put_textTransform(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def get_textTransform(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def put_textAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def get_textAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def put_textIndent(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def get_textIndent(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def put_lineHeight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def get_lineHeight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def put_marginTop(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def get_marginTop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def put_marginRight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def get_marginRight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def put_marginBottom(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def get_marginBottom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def put_marginLeft(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def get_marginLeft(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def put_margin(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def get_margin(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def put_paddingTop(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def get_paddingTop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def put_paddingRight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def get_paddingRight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def put_paddingBottom(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def get_paddingBottom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def put_paddingLeft(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def get_paddingLeft(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def put_padding(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def get_padding(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def put_border(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def get_border(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def put_borderTop(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def get_borderTop(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def put_borderRight(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def get_borderRight(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def put_borderBottom(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def get_borderBottom(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def put_borderLeft(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def get_borderLeft(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def put_borderColor(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def get_borderColor(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def put_borderTopColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def get_borderTopColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def put_borderRightColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def get_borderRightColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def put_borderBottomColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def get_borderBottomColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def put_borderLeftColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def get_borderLeftColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def put_borderWidth(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def get_borderWidth(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def put_borderTopWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def get_borderTopWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def put_borderRightWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(105)
    def get_borderRightWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(106)
    def put_borderBottomWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(107)
    def get_borderBottomWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(108)
    def put_borderLeftWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(109)
    def get_borderLeftWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(110)
    def put_borderStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(111)
    def get_borderStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(112)
    def put_borderTopStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(113)
    def get_borderTopStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(114)
    def put_borderRightStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(115)
    def get_borderRightStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(116)
    def put_borderBottomStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(117)
    def get_borderBottomStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(118)
    def put_borderLeftStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(119)
    def get_borderLeftStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(120)
    def put_width(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(121)
    def get_width(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(122)
    def put_height(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(123)
    def get_height(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(124)
    def put_styleFloat(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(125)
    def get_styleFloat(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(126)
    def put_clear(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(127)
    def get_clear(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(128)
    def put_display(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(129)
    def get_display(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(130)
    def put_visibility(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(131)
    def get_visibility(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(132)
    def put_listStyleType(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(133)
    def get_listStyleType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(134)
    def put_listStylePosition(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(135)
    def get_listStylePosition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(136)
    def put_listStyleImage(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(137)
    def get_listStyleImage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(138)
    def put_listStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(139)
    def get_listStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(140)
    def put_whiteSpace(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(141)
    def get_whiteSpace(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(142)
    def put_top(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(143)
    def get_top(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(144)
    def put_left(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(145)
    def get_left(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(146)
    def put_zIndex(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(147)
    def get_zIndex(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(148)
    def put_overflow(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(149)
    def get_overflow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(150)
    def put_pageBreakBefore(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(151)
    def get_pageBreakBefore(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(152)
    def put_pageBreakAfter(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(153)
    def get_pageBreakAfter(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(154)
    def put_cssText(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(155)
    def get_cssText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(156)
    def put_cursor(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(157)
    def get_cursor(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(158)
    def put_clip(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(159)
    def get_clip(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(160)
    def put_filter(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(161)
    def get_filter(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(162)
    def put_tableLayout(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(163)
    def get_tableLayout(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(164)
    def put_borderCollapse(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(165)
    def get_borderCollapse(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(166)
    def put_direction(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(167)
    def get_direction(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(168)
    def put_behavior(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(169)
    def get_behavior(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(170)
    def put_position(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(171)
    def get_position(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(172)
    def put_unicodeBidi(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(173)
    def get_unicodeBidi(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(174)
    def put_bottom(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(175)
    def get_bottom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(176)
    def put_right(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(177)
    def get_right(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(178)
    def put_imeMode(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(179)
    def get_imeMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(180)
    def put_rubyAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(181)
    def get_rubyAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(182)
    def put_rubyPosition(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(183)
    def get_rubyPosition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(184)
    def put_rubyOverhang(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(185)
    def get_rubyOverhang(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(186)
    def put_layoutGridChar(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(187)
    def get_layoutGridChar(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(188)
    def put_layoutGridLine(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(189)
    def get_layoutGridLine(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(190)
    def put_layoutGridMode(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(191)
    def get_layoutGridMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(192)
    def put_layoutGridType(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(193)
    def get_layoutGridType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(194)
    def put_layoutGrid(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(195)
    def get_layoutGrid(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(196)
    def put_textAutospace(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(197)
    def get_textAutospace(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(198)
    def put_wordBreak(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(199)
    def get_wordBreak(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(200)
    def put_lineBreak(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(201)
    def get_lineBreak(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(202)
    def put_textJustify(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(203)
    def get_textJustify(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(204)
    def put_textJustifyTrim(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(205)
    def get_textJustifyTrim(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(206)
    def put_textKashida(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(207)
    def get_textKashida(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(208)
    def put_overflowX(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(209)
    def get_overflowX(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(210)
    def put_overflowY(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(211)
    def get_overflowY(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(212)
    def put_accelerator(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(213)
    def get_accelerator(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(214)
    def put_layoutFlow(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(215)
    def get_layoutFlow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(216)
    def put_zoom(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(217)
    def get_zoom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(218)
    def put_wordWrap(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(219)
    def get_wordWrap(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(220)
    def put_textUnderlinePosition(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(221)
    def get_textUnderlinePosition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(222)
    def put_scrollbarBaseColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(223)
    def get_scrollbarBaseColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(224)
    def put_scrollbarFaceColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(225)
    def get_scrollbarFaceColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(226)
    def put_scrollbar3dLightColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(227)
    def get_scrollbar3dLightColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(228)
    def put_scrollbarShadowColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(229)
    def get_scrollbarShadowColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(230)
    def put_scrollbarHighlightColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(231)
    def get_scrollbarHighlightColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(232)
    def put_scrollbarDarkShadowColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(233)
    def get_scrollbarDarkShadowColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(234)
    def put_scrollbarArrowColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(235)
    def get_scrollbarArrowColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(236)
    def put_scrollbarTrackColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(237)
    def get_scrollbarTrackColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(238)
    def put_writingMode(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(239)
    def get_writingMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(240)
    def put_textAlignLast(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(241)
    def get_textAlignLast(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(242)
    def put_textKashidaSpace(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(243)
    def get_textKashidaSpace(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(244)
    def put_textOverflow(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(245)
    def get_textOverflow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(246)
    def put_minHeight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(247)
    def get_minHeight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(248)
    def put_msInterpolationMode(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(249)
    def get_msInterpolationMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(250)
    def put_maxHeight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(251)
    def get_maxHeight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(252)
    def put_minWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(253)
    def get_minWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(254)
    def put_maxWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(255)
    def get_maxWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(256)
    def put_content(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(257)
    def get_content(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(258)
    def put_captionSide(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(259)
    def get_captionSide(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(260)
    def put_counterIncrement(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(261)
    def get_counterIncrement(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(262)
    def put_counterReset(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(263)
    def get_counterReset(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(264)
    def put_outline(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(265)
    def get_outline(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(266)
    def put_outlineWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(267)
    def get_outlineWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(268)
    def put_outlineStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(269)
    def get_outlineStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(270)
    def put_outlineColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(271)
    def get_outlineColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(272)
    def put_boxSizing(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(273)
    def get_boxSizing(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(274)
    def put_borderSpacing(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(275)
    def get_borderSpacing(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(276)
    def put_orphans(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(277)
    def get_orphans(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(278)
    def put_widows(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(279)
    def get_widows(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(280)
    def put_pageBreakInside(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(281)
    def get_pageBreakInside(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(282)
    def put_emptyCells(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(283)
    def get_emptyCells(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(284)
    def put_msBlockProgression(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(285)
    def get_msBlockProgression(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(286)
    def put_quotes(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(287)
    def get_quotes(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(288)
    def put_alignmentBaseline(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(289)
    def get_alignmentBaseline(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(290)
    def put_baselineShift(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(291)
    def get_baselineShift(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(292)
    def put_dominantBaseline(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(293)
    def get_dominantBaseline(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(294)
    def put_fontSizeAdjust(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(295)
    def get_fontSizeAdjust(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(296)
    def put_fontStretch(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(297)
    def get_fontStretch(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(298)
    def put_opacity(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(299)
    def get_opacity(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(300)
    def put_clipPath(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(301)
    def get_clipPath(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(302)
    def put_clipRule(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(303)
    def get_clipRule(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(304)
    def put_fill(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(305)
    def get_fill(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(306)
    def put_fillOpacity(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(307)
    def get_fillOpacity(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(308)
    def put_fillRule(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(309)
    def get_fillRule(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(310)
    def put_kerning(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(311)
    def get_kerning(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(312)
    def put_marker(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(313)
    def get_marker(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(314)
    def put_markerEnd(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(315)
    def get_markerEnd(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(316)
    def put_markerMid(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(317)
    def get_markerMid(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(318)
    def put_markerStart(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(319)
    def get_markerStart(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(320)
    def put_mask(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(321)
    def get_mask(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(322)
    def put_pointerEvents(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(323)
    def get_pointerEvents(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(324)
    def put_stopColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(325)
    def get_stopColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(326)
    def put_stopOpacity(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(327)
    def get_stopOpacity(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(328)
    def put_stroke(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(329)
    def get_stroke(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(330)
    def put_strokeDasharray(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(331)
    def get_strokeDasharray(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(332)
    def put_strokeDashoffset(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(333)
    def get_strokeDashoffset(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(334)
    def put_strokeLinecap(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(335)
    def get_strokeLinecap(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(336)
    def put_strokeLinejoin(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(337)
    def get_strokeLinejoin(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(338)
    def put_strokeMiterlimit(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(339)
    def get_strokeMiterlimit(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(340)
    def put_strokeOpacity(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(341)
    def get_strokeOpacity(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(342)
    def put_strokeWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(343)
    def get_strokeWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(344)
    def put_textAnchor(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(345)
    def get_textAnchor(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(346)
    def put_glyphOrientationHorizontal(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(347)
    def get_glyphOrientationHorizontal(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(348)
    def put_glyphOrientationVertical(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(349)
    def get_glyphOrientationVertical(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(350)
    def put_borderRadius(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(351)
    def get_borderRadius(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(352)
    def put_borderTopLeftRadius(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(353)
    def get_borderTopLeftRadius(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(354)
    def put_borderTopRightRadius(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(355)
    def get_borderTopRightRadius(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(356)
    def put_borderBottomRightRadius(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(357)
    def get_borderBottomRightRadius(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(358)
    def put_borderBottomLeftRadius(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(359)
    def get_borderBottomLeftRadius(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(360)
    def put_clipTop(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(361)
    def get_clipTop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(362)
    def put_clipRight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(363)
    def get_clipRight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(364)
    def get_clipBottom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(365)
    def put_clipLeft(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(366)
    def get_clipLeft(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(367)
    def put_cssFloat(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(368)
    def get_cssFloat(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(369)
    def put_backgroundClip(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(370)
    def get_backgroundClip(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(371)
    def put_backgroundOrigin(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(372)
    def get_backgroundOrigin(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(373)
    def put_backgroundSize(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(374)
    def get_backgroundSize(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(375)
    def put_boxShadow(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(376)
    def get_boxShadow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(377)
    def put_msTransform(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(378)
    def get_msTransform(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(379)
    def put_msTransformOrigin(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(380)
    def get_msTransformOrigin(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCSSStyleDeclaration2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305107d1-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_msScrollChaining(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_msScrollChaining(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_msContentZooming(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_msContentZooming(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_msContentZoomSnapType(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_msContentZoomSnapType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_msScrollRails(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_msScrollRails(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_msContentZoomChaining(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_msContentZoomChaining(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_msScrollSnapType(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_msScrollSnapType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_msContentZoomLimit(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_msContentZoomLimit(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_msContentZoomSnap(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_msContentZoomSnap(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_msContentZoomSnapPoints(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_msContentZoomSnapPoints(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_msContentZoomLimitMin(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_msContentZoomLimitMin(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_msContentZoomLimitMax(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_msContentZoomLimitMax(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_msScrollSnapX(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_msScrollSnapX(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_msScrollSnapY(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_msScrollSnapY(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_msScrollSnapPointsX(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_msScrollSnapPointsX(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_msScrollSnapPointsY(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_msScrollSnapPointsY(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_msGridColumn(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_msGridColumn(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_msGridColumnAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_msGridColumnAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_msGridColumns(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_msGridColumns(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_msGridColumnSpan(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_msGridColumnSpan(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_msGridRow(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_msGridRow(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def put_msGridRowAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_msGridRowAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def put_msGridRows(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def get_msGridRows(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def put_msGridRowSpan(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_msGridRowSpan(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def put_msWrapThrough(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_msWrapThrough(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def put_msWrapMargin(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_msWrapMargin(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def put_msWrapFlow(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def get_msWrapFlow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def put_msAnimationName(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def get_msAnimationName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def put_msAnimationDuration(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_msAnimationDuration(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def put_msAnimationTimingFunction(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def get_msAnimationTimingFunction(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def put_msAnimationDelay(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def get_msAnimationDelay(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def put_msAnimationDirection(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def get_msAnimationDirection(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def put_msAnimationPlayState(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def get_msAnimationPlayState(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def put_msAnimationIterationCount(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def get_msAnimationIterationCount(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def put_msAnimation(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def get_msAnimation(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def put_msAnimationFillMode(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def get_msAnimationFillMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def put_colorInterpolationFilters(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def get_colorInterpolationFilters(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def put_columnCount(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def get_columnCount(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def put_columnWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def get_columnWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def put_columnGap(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def get_columnGap(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def put_columnFill(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def get_columnFill(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def put_columnSpan(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def get_columnSpan(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def put_columns(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def get_columns(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def put_columnRule(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def get_columnRule(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def put_columnRuleColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def get_columnRuleColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def put_columnRuleStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def get_columnRuleStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def put_columnRuleWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def get_columnRuleWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def put_breakBefore(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def get_breakBefore(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def put_breakAfter(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def get_breakAfter(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def put_breakInside(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def get_breakInside(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(105)
    def put_floodColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(106)
    def get_floodColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(107)
    def put_floodOpacity(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(108)
    def get_floodOpacity(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(109)
    def put_lightingColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(110)
    def get_lightingColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(111)
    def put_msScrollLimitXMin(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(112)
    def get_msScrollLimitXMin(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(113)
    def put_msScrollLimitYMin(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(114)
    def get_msScrollLimitYMin(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(115)
    def put_msScrollLimitXMax(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(116)
    def get_msScrollLimitXMax(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(117)
    def put_msScrollLimitYMax(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(118)
    def get_msScrollLimitYMax(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(119)
    def put_msScrollLimit(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(120)
    def get_msScrollLimit(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(121)
    def put_textShadow(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(122)
    def get_textShadow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(123)
    def put_msFlowFrom(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(124)
    def get_msFlowFrom(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(125)
    def put_msFlowInto(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(126)
    def get_msFlowInto(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(127)
    def put_msHyphens(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(128)
    def get_msHyphens(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(129)
    def put_msHyphenateLimitZone(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(130)
    def get_msHyphenateLimitZone(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(131)
    def put_msHyphenateLimitChars(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(132)
    def get_msHyphenateLimitChars(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(133)
    def put_msHyphenateLimitLines(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(134)
    def get_msHyphenateLimitLines(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(135)
    def put_msHighContrastAdjust(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(136)
    def get_msHighContrastAdjust(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(137)
    def put_enableBackground(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(138)
    def get_enableBackground(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(139)
    def put_msFontFeatureSettings(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(140)
    def get_msFontFeatureSettings(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(141)
    def put_msUserSelect(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(142)
    def get_msUserSelect(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(143)
    def put_msOverflowStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(144)
    def get_msOverflowStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(145)
    def put_msTransformStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(146)
    def get_msTransformStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(147)
    def put_msBackfaceVisibility(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(148)
    def get_msBackfaceVisibility(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(149)
    def put_msPerspective(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(150)
    def get_msPerspective(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(151)
    def put_msPerspectiveOrigin(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(152)
    def get_msPerspectiveOrigin(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(153)
    def put_msTransitionProperty(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(154)
    def get_msTransitionProperty(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(155)
    def put_msTransitionDuration(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(156)
    def get_msTransitionDuration(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(157)
    def put_msTransitionTimingFunction(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(158)
    def get_msTransitionTimingFunction(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(159)
    def put_msTransitionDelay(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(160)
    def get_msTransitionDelay(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(161)
    def put_msTransition(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(162)
    def get_msTransition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(163)
    def put_msTouchAction(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(164)
    def get_msTouchAction(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(165)
    def put_msScrollTranslation(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(166)
    def get_msScrollTranslation(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(167)
    def put_msFlex(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(168)
    def get_msFlex(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(169)
    def put_msFlexPositive(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(170)
    def get_msFlexPositive(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(171)
    def put_msFlexNegative(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(172)
    def get_msFlexNegative(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(173)
    def put_msFlexPreferredSize(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(174)
    def get_msFlexPreferredSize(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(175)
    def put_msFlexFlow(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(176)
    def get_msFlexFlow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(177)
    def put_msFlexDirection(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(178)
    def get_msFlexDirection(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(179)
    def put_msFlexWrap(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(180)
    def get_msFlexWrap(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(181)
    def put_msFlexAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(182)
    def get_msFlexAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(183)
    def put_msFlexItemAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(184)
    def get_msFlexItemAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(185)
    def put_msFlexPack(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(186)
    def get_msFlexPack(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(187)
    def put_msFlexLinePack(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(188)
    def get_msFlexLinePack(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(189)
    def put_msFlexOrder(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(190)
    def get_msFlexOrder(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(191)
    def put_msTouchSelect(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(192)
    def get_msTouchSelect(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(193)
    def put_transform(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(194)
    def get_transform(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(195)
    def put_transformOrigin(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(196)
    def get_transformOrigin(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(197)
    def put_transformStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(198)
    def get_transformStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(199)
    def put_backfaceVisibility(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(200)
    def get_backfaceVisibility(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(201)
    def put_perspective(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(202)
    def get_perspective(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(203)
    def put_perspectiveOrigin(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(204)
    def get_perspectiveOrigin(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(205)
    def put_transitionProperty(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(206)
    def get_transitionProperty(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(207)
    def put_transitionDuration(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(208)
    def get_transitionDuration(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(209)
    def put_transitionTimingFunction(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(210)
    def get_transitionTimingFunction(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(211)
    def put_transitionDelay(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(212)
    def get_transitionDelay(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(213)
    def put_transition(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(214)
    def get_transition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(215)
    def put_fontFeatureSettings(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(216)
    def get_fontFeatureSettings(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(217)
    def put_animationName(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(218)
    def get_animationName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(219)
    def put_animationDuration(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(220)
    def get_animationDuration(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(221)
    def put_animationTimingFunction(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(222)
    def get_animationTimingFunction(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(223)
    def put_animationDelay(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(224)
    def get_animationDelay(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(225)
    def put_animationDirection(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(226)
    def get_animationDirection(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(227)
    def put_animationPlayState(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(228)
    def get_animationPlayState(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(229)
    def put_animationIterationCount(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(230)
    def get_animationIterationCount(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(231)
    def put_animation(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(232)
    def get_animation(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(233)
    def put_animationFillMode(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(234)
    def get_animationFillMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCSSStyleDeclaration3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051085c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_flex(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_flex(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_flexDirection(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_flexDirection(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_flexWrap(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_flexWrap(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_flexFlow(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_flexFlow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_flexGrow(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_flexGrow(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_flexShrink(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_flexShrink(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_flexBasis(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_flexBasis(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_justifyContent(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_justifyContent(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_alignItems(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_alignItems(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_alignSelf(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_alignSelf(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_alignContent(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_alignContent(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_borderImage(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_borderImage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_borderImageSource(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_borderImageSource(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_borderImageSlice(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_borderImageSlice(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_borderImageWidth(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_borderImageWidth(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_borderImageOutset(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_borderImageOutset(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_borderImageRepeat(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_borderImageRepeat(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_msImeAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_msImeAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_msTextCombineHorizontal(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_msTextCombineHorizontal(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_touchAction(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_touchAction(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCSSStyleDeclaration4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d6100f3b-27c8-4132-afea-f0e4b1e00060}')
    @commethod(7)
    def put_webkitAppearance(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_webkitAppearance(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_webkitUserSelect(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_webkitUserSelect(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_webkitBoxAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_webkitBoxAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_webkitBoxOrdinalGroup(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_webkitBoxOrdinalGroup(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_webkitBoxPack(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_webkitBoxPack(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_webkitBoxFlex(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_webkitBoxFlex(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_webkitBoxOrient(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_webkitBoxOrient(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_webkitBoxDirection(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_webkitBoxDirection(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_webkitTransform(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_webkitTransform(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_webkitBackgroundSize(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_webkitBackgroundSize(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_webkitBackfaceVisibility(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_webkitBackfaceVisibility(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_webkitAnimation(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_webkitAnimation(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_webkitTransition(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_webkitTransition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_webkitAnimationName(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_webkitAnimationName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_webkitAnimationDuration(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_webkitAnimationDuration(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_webkitAnimationTimingFunction(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_webkitAnimationTimingFunction(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_webkitAnimationDelay(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_webkitAnimationDelay(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_webkitAnimationIterationCount(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_webkitAnimationIterationCount(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_webkitAnimationDirection(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_webkitAnimationDirection(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_webkitAnimationPlayState(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_webkitAnimationPlayState(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def put_webkitTransitionProperty(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_webkitTransitionProperty(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def put_webkitTransitionDuration(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def get_webkitTransitionDuration(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def put_webkitTransitionTimingFunction(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_webkitTransitionTimingFunction(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def put_webkitTransitionDelay(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_webkitTransitionDelay(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def put_webkitBackgroundAttachment(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_webkitBackgroundAttachment(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def put_webkitBackgroundColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def get_webkitBackgroundColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def put_webkitBackgroundClip(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def get_webkitBackgroundClip(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def put_webkitBackgroundImage(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_webkitBackgroundImage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def put_webkitBackgroundRepeat(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def get_webkitBackgroundRepeat(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def put_webkitBackgroundOrigin(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def get_webkitBackgroundOrigin(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def put_webkitBackgroundPosition(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def get_webkitBackgroundPosition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def put_webkitBackgroundPositionX(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def get_webkitBackgroundPositionX(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def put_webkitBackgroundPositionY(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def get_webkitBackgroundPositionY(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def put_webkitBackground(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def get_webkitBackground(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def put_webkitTransformOrigin(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def get_webkitTransformOrigin(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def put_msTextSizeAdjust(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def get_msTextSizeAdjust(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def put_webkitTextSizeAdjust(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def get_webkitTextSizeAdjust(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def put_webkitBorderImage(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def get_webkitBorderImage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def put_webkitBorderImageSource(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def get_webkitBorderImageSource(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def put_webkitBorderImageSlice(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def get_webkitBorderImageSlice(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def put_webkitBorderImageWidth(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def get_webkitBorderImageWidth(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def put_webkitBorderImageOutset(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def get_webkitBorderImageOutset(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def put_webkitBorderImageRepeat(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def get_webkitBorderImageRepeat(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def put_webkitBoxSizing(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def get_webkitBoxSizing(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def put_webkitAnimationFillMode(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def get_webkitAnimationFillMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCanvasElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106e4-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_width(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_width(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_height(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_height(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def getContext(self, contextId: win32more.Windows.Win32.Foundation.BSTR, ppContext: POINTER(win32more.Windows.Win32.Web.MsHtml.ICanvasRenderingContext2D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def toDataURL(self, type: win32more.Windows.Win32.Foundation.BSTR, jpegquality: win32more.Windows.Win32.System.Variant.VARIANT, pUrl: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCaret(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f604-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def MoveCaretToPointer(self, pDispPointer: win32more.Windows.Win32.Web.MsHtml.IDisplayPointer, fScrollIntoView: win32more.Windows.Win32.Foundation.BOOL, eDir: win32more.Windows.Win32.Web.MsHtml.CARET_DIRECTION) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MoveCaretToPointerEx(self, pDispPointer: win32more.Windows.Win32.Web.MsHtml.IDisplayPointer, fVisible: win32more.Windows.Win32.Foundation.BOOL, fScrollIntoView: win32more.Windows.Win32.Foundation.BOOL, eDir: win32more.Windows.Win32.Web.MsHtml.CARET_DIRECTION) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def MoveMarkupPointerToCaret(self, pIMarkupPointer: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def MoveDisplayPointerToCaret(self, pDispPointer: win32more.Windows.Win32.Web.MsHtml.IDisplayPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def IsVisible(self, pIsVisible: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Show(self, fScrollIntoView: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Hide(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def InsertText(self, pText: win32more.Windows.Win32.Foundation.PWSTR, lLen: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def ScrollIntoView(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetLocation(self, pPoint: POINTER(win32more.Windows.Win32.Foundation.POINT), fTranslate: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetCaretDirection(self, peDir: POINTER(win32more.Windows.Win32.Web.MsHtml.CARET_DIRECTION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SetCaretDirection(self, eDir: win32more.Windows.Win32.Web.MsHtml.CARET_DIRECTION) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLChangeLog(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f649-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetNextChange(self, pbBuffer: POINTER(Byte), nBufferSize: Int32, pnRecordLength: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLChangePlayback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f6e0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def ExecChange(self, pbRecord: POINTER(Byte), fForward: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLChangeSink(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f64a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def Notify(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCommentElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f20c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_text(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_text(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_atomic(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_atomic(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCommentElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f813-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_data(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_data(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def substringData(self, offset: Int32, Count: Int32, pbstrsubString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def appendData(self, bstrstring: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def insertData(self, offset: Int32, bstrstring: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def deleteData(self, offset: Int32, Count: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def replaceData(self, offset: Int32, Count: Int32, bstrstring: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCommentElement3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051073f-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def substringData(self, offset: Int32, Count: Int32, pbstrsubString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def insertData(self, offset: Int32, bstrstring: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def deleteData(self, offset: Int32, Count: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def replaceData(self, offset: Int32, Count: Int32, bstrstring: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLComputedStyle(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f6c3-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def get_bold(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_italic(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_underline(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def get_overline(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def get_strikeOut(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_subScript(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_superScript(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_explicitFace(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_fontWeight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_fontSize(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_fontName(self, p: POINTER(SByte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_hasBgColor(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_textColor(self, p: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_backgroundColor(self, p: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_preFormatted(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_direction(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_blockDirection(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_OL(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def IsEqual(self, pComputedStyle: win32more.Windows.Win32.Web.MsHtml.IHTMLComputedStyle, pfEqual: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLControlElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4e9-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_tabIndex(self, v: Int16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_tabIndex(self, p: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def focus(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_accessKey(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_accessKey(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_onblur(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_onblur(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_onfocus(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_onfocus(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_onresize(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_onresize(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def blur(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def addFilter(self, pUnk: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def removeFilter(self, pUnk: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_clientHeight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_clientWidth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_clientTop(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_clientLeft(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLControlRange(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f29c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def select(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def add(self, item: win32more.Windows.Win32.Web.MsHtml.IHTMLControlElement) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def remove(self, index: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def item(self, index: Int32, pdisp: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def scrollIntoView(self, varargStart: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def queryCommandSupported(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def queryCommandEnabled(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def queryCommandState(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def queryCommandIndeterm(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def queryCommandText(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pcmdText: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def queryCommandValue(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pcmdValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def execCommand(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, showUI: win32more.Windows.Win32.Foundation.VARIANT_BOOL, value: win32more.Windows.Win32.System.Variant.VARIANT, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def execCommandShowHelp(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def commonParentElement(self, parent: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLControlRange2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f65e-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def addElement(self, item: win32more.Windows.Win32.Web.MsHtml.IHTMLElement) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCurrentStyle(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f3db-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_position(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_styleFloat(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_color(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_backgroundColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_fontFamily(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_fontStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_fontVariant(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_fontWeight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_fontSize(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_backgroundImage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_backgroundPositionX(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_backgroundPositionY(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_backgroundRepeat(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_borderLeftColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_borderTopColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_borderRightColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_borderBottomColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_borderTopStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_borderRightStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_borderBottomStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_borderLeftStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_borderTopWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_borderRightWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_borderBottomWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_borderLeftWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_left(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_top(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_width(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_height(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_paddingLeft(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_paddingTop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_paddingRight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_paddingBottom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_textAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_textDecoration(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_display(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def get_visibility(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_zIndex(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_letterSpacing(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_lineHeight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def get_textIndent(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_verticalAlign(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def get_backgroundAttachment(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def get_marginTop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def get_marginRight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_marginBottom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def get_marginLeft(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_clear(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def get_listStyleType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_listStylePosition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def get_listStyleImage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def get_clipTop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def get_clipRight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def get_clipBottom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def get_clipLeft(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_overflow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def get_pageBreakBefore(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def get_pageBreakAfter(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def get_cursor(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def get_tableLayout(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def get_borderCollapse(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def get_direction(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def get_behavior(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def getAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, lFlags: Int32, AttributeValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def get_unicodeBidi(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def get_right(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def get_bottom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def get_imeMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def get_rubyAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def get_rubyPosition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def get_rubyOverhang(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def get_textAutospace(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def get_lineBreak(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def get_wordBreak(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def get_textJustify(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def get_textJustifyTrim(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def get_textKashida(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def get_blockDirection(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def get_layoutGridChar(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def get_layoutGridLine(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def get_layoutGridMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def get_layoutGridType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def get_borderStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def get_borderColor(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def get_borderWidth(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def get_padding(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def get_margin(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def get_accelerator(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def get_overflowX(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def get_overflowY(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def get_textTransform(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCurrentStyle2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f658-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_layoutFlow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_wordWrap(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_textUnderlinePosition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_hasLayout(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_scrollbarBaseColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_scrollbarFaceColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_scrollbar3dLightColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_scrollbarShadowColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_scrollbarHighlightColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_scrollbarDarkShadowColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_scrollbarArrowColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_scrollbarTrackColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_writingMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_zoom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_filter(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_textAlignLast(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_textKashidaSpace(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_isBlock(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCurrentStyle3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f818-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_textOverflow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_minHeight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_wordSpacing(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_whiteSpace(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCurrentStyle4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f33b-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_msInterpolationMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_maxHeight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_minWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_maxWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLCurrentStyle5(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510481-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_captionSide(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_outline(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_outlineWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_outlineStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_outlineColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_boxSizing(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_borderSpacing(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_orphans(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_widows(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_pageBreakInside(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_emptyCells(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_msBlockProgression(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_quotes(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDDElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f1f2-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_noWrap(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_noWrap(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDListElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f1f1-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_compact(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_compact(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDOMAttribute(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4b0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_nodeName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_nodeValue(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_nodeValue(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_specified(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDOMAttribute2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f810-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_expando(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_nodeType(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_parentNode(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_childNodes(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_firstChild(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_lastChild(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_previousSibling(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_nextSibling(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_attributes(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_ownerDocument(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def insertBefore(self, newChild: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, refChild: win32more.Windows.Win32.System.Variant.VARIANT, node: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def replaceChild(self, newChild: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, oldChild: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, node: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def removeChild(self, oldChild: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, node: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def appendChild(self, newChild: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, node: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def hasChildNodes(self, fChildren: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def cloneNode(self, fDeep: win32more.Windows.Win32.Foundation.VARIANT_BOOL, clonedNode: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDOMAttribute3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510468-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_nodeValue(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_nodeValue(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_specified(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_ownerElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDOMAttribute4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106f9-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_nodeValue(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_nodeValue(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_nodeName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_firstChild(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_lastChild(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_childNodes(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def hasAttributes(self, pfHasAttributes: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def hasChildNodes(self, fChildren: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def normalize(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_specified(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDOMChildrenCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5ab-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__newEnum(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def item(self, index: Int32, ppItem: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDOMChildrenCollection2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510791-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def item(self, index: Int32, ppItem: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDOMConstructor(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051049b-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_constructor(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def LookupGetter(self, propname: win32more.Windows.Win32.Foundation.BSTR, ppDispHandler: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def LookupSetter(self, propname: win32more.Windows.Win32.Foundation.BSTR, ppDispHandler: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def DefineGetter(self, propname: win32more.Windows.Win32.Foundation.BSTR, pdispHandler: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def DefineSetter(self, propname: win32more.Windows.Win32.Foundation.BSTR, pdispHandler: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDOMConstructorCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051049c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_Attr(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_BehaviorUrnsCollection(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_BookmarkCollection(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_CompatibleInfo(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_CompatibleInfoCollection(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_ControlRangeCollection(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_CSSCurrentStyleDeclaration(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_CSSRuleList(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_CSSRuleStyleDeclaration(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_CSSStyleDeclaration(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_CSSStyleRule(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_CSSStyleSheet(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_DataTransfer(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_DOMImplementation(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_Element(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_Event(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_History(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_HTCElementBehaviorDefaults(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_HTMLAnchorElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_HTMLAreaElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_HTMLAreasCollection(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_HTMLBaseElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_HTMLBaseFontElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_HTMLBGSoundElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_HTMLBlockElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_HTMLBodyElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_HTMLBRElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_HTMLButtonElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_HTMLCollection(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_HTMLCommentElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_HTMLDDElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_HTMLDivElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_HTMLDocument(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_HTMLDListElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_HTMLDTElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_HTMLEmbedElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def get_HTMLFieldSetElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_HTMLFontElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_HTMLFormElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_HTMLFrameElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def get_HTMLFrameSetElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_HTMLGenericElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def get_HTMLHeadElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def get_HTMLHeadingElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def get_HTMLHRElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_HTMLHtmlElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def get_HTMLIFrameElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_HTMLImageElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def get_HTMLInputElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_HTMLIsIndexElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def get_HTMLLabelElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def get_HTMLLegendElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def get_HTMLLIElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def get_HTMLLinkElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def get_HTMLMapElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_HTMLMarqueeElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def get_HTMLMetaElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def get_HTMLModelessDialog(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def get_HTMLNamespaceInfo(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def get_HTMLNamespaceInfoCollection(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def get_HTMLNextIdElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def get_HTMLNoShowElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def get_HTMLObjectElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def get_HTMLOListElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def get_HTMLOptionElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def get_HTMLParagraphElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def get_HTMLParamElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def get_HTMLPhraseElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def get_HTMLPluginsCollection(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def get_HTMLPopup(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def get_HTMLScriptElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def get_HTMLSelectElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def get_HTMLSpanElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def get_HTMLStyleElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def get_HTMLTableCaptionElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def get_HTMLTableCellElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def get_HTMLTableColElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def get_HTMLTableElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def get_HTMLTableRowElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def get_HTMLTableSectionElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def get_HTMLTextAreaElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def get_HTMLTextElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def get_HTMLTitleElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def get_HTMLUListElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def get_HTMLUnknownElement(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def get_Image(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def get_Location(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def get_NamedNodeMap(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def get_Navigator(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def get_NodeList(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def get_Option(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def get_Screen(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def get_Selection(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def get_StaticNodeList(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def get_Storage(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def get_StyleSheetList(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def get_StyleSheetPage(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def get_StyleSheetPageList(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(105)
    def get_Text(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(106)
    def get_TextRange(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(107)
    def get_TextRangeCollection(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(108)
    def get_TextRectangle(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(109)
    def get_TextRectangleList(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(110)
    def get_Window(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(111)
    def get_XDomainRequest(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(112)
    def get_XMLHttpRequest(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDOMImplementation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f80d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def hasFeature(self, bstrfeature: win32more.Windows.Win32.Foundation.BSTR, version: win32more.Windows.Win32.System.Variant.VARIANT, pfHasFeature: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDOMImplementation2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051073c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def createDocumentType(self, bstrQualifiedName: win32more.Windows.Win32.Foundation.BSTR, pvarPublicId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pvarSystemId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), newDocumentType: POINTER(win32more.Windows.Win32.Web.MsHtml.IDOMDocumentType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def createDocument(self, pvarNS: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pvarTagName: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pDocumentType: win32more.Windows.Win32.Web.MsHtml.IDOMDocumentType, ppnewDocument: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDocument7)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def createHTMLDocument(self, bstrTitle: win32more.Windows.Win32.Foundation.BSTR, ppnewDocument: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDocument7)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def hasFeature(self, bstrfeature: win32more.Windows.Win32.Foundation.BSTR, version: win32more.Windows.Win32.System.Variant.VARIANT, pfHasFeature: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDOMNode(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5da-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_nodeType(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_parentNode(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def hasChildNodes(self, fChildren: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_childNodes(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_attributes(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def insertBefore(self, newChild: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, refChild: win32more.Windows.Win32.System.Variant.VARIANT, node: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def removeChild(self, oldChild: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, node: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def replaceChild(self, newChild: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, oldChild: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, node: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def cloneNode(self, fDeep: win32more.Windows.Win32.Foundation.VARIANT_BOOL, clonedNode: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def removeNode(self, fDeep: win32more.Windows.Win32.Foundation.VARIANT_BOOL, removed: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def swapNode(self, otherNode: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, swappedNode: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def replaceNode(self, replacement: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, replaced: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def appendChild(self, newChild: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, node: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_nodeName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_nodeValue(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_nodeValue(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_firstChild(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_lastChild(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_previousSibling(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_nextSibling(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDOMNode2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f80b-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_ownerDocument(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDOMNode3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106e0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_prefix(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_prefix(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_localName(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_namespaceURI(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_textContent(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_textContent(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def isEqualNode(self, otherNode: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode3, isEqual: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def lookupNamespaceURI(self, pvarPrefix: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pvarNamespaceURI: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def lookupPrefix(self, pvarNamespaceURI: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pvarPrefix: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def isDefaultNamespace(self, pvarNamespace: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pfDefaultNamespace: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def appendChild(self, newChild: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, node: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def insertBefore(self, newChild: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, refChild: win32more.Windows.Win32.System.Variant.VARIANT, node: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def removeChild(self, oldChild: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, node: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def replaceChild(self, newChild: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, oldChild: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, node: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def isSameNode(self, otherNode: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode3, isSame: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def compareDocumentPosition(self, otherNode: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, flags: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def isSupported(self, feature: win32more.Windows.Win32.Foundation.BSTR, version: win32more.Windows.Win32.System.Variant.VARIANT, pfisSupported: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDOMRange(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104ae-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_startContainer(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_startOffset(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_endContainer(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_endOffset(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_collapsed(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_commonAncestorContainer(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def setStart(self, refNode: win32more.Windows.Win32.System.Com.IDispatch, offset: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def setEnd(self, refNode: win32more.Windows.Win32.System.Com.IDispatch, offset: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def setStartBefore(self, refNode: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def setStartAfter(self, refNode: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def setEndBefore(self, refNode: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def setEndAfter(self, refNode: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def collapse(self, toStart: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def selectNode(self, refNode: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def selectNodeContents(self, refNode: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def compareBoundaryPoints(self, how: Int16, sourceRange: win32more.Windows.Win32.System.Com.IDispatch, compareResult: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def deleteContents(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def extractContents(self, ppDocumentFragment: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def cloneContents(self, ppDocumentFragment: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def insertNode(self, newNode: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def surroundContents(self, newParent: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def cloneRange(self, ppClonedRange: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMRange)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def toString(self, pRangeString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def detach(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def getClientRects(self, ppRectCol: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLRectCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def getBoundingClientRect(self, ppRect: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLRect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDOMTextNode(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4b1-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_data(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_data(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def toString(self, String: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def splitText(self, offset: Int32, pRetNode: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDOMTextNode2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f809-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def substringData(self, offset: Int32, Count: Int32, pbstrsubString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def appendData(self, bstrstring: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def insertData(self, offset: Int32, bstrstring: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def deleteData(self, offset: Int32, Count: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def replaceData(self, offset: Int32, Count: Int32, bstrstring: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDOMTextNode3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051073e-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def substringData(self, offset: Int32, Count: Int32, pbstrsubString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def insertData(self, offset: Int32, bstrstring: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def deleteData(self, offset: Int32, Count: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def replaceData(self, offset: Int32, Count: Int32, bstrstring: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def splitText(self, offset: Int32, pRetNode: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_wholeText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def replaceWholeText(self, bstrText: win32more.Windows.Win32.Foundation.BSTR, ppRetNode: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def hasAttributes(self, pfHasAttributes: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def normalize(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDTElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f1f3-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_noWrap(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_noWrap(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDataTransfer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4b3-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def setData(self, format: win32more.Windows.Win32.Foundation.BSTR, data: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pret: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def getData(self, format: win32more.Windows.Win32.Foundation.BSTR, pvarRet: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def clearData(self, format: win32more.Windows.Win32.Foundation.BSTR, pret: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_dropEffect(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_dropEffect(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_effectAllowed(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_effectAllowed(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDatabinding(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f3f2-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_dataFld(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_dataFld(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_dataSrc(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_dataSrc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_dataFormatAs(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_dataFormatAs(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDialog(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f216-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_dialogTop(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_dialogTop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_dialogLeft(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_dialogLeft(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_dialogWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_dialogWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_dialogHeight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_dialogHeight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_dialogArguments(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_menuArguments(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_returnValue(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_returnValue(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def close(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def toString(self, String: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDialog2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5e0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_status(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_status(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_resizable(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_resizable(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDialog3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f388-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_unadorned(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_unadorned(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_dialogHide(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_dialogHide(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDivElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f200-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_noWrap(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_noWrap(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDivPosition(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f212-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDocument(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{626fc520-a41e-11cf-a731-00a0c9082637}')
    @commethod(7)
    def get_Script(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDocument2(ComPtr):
    extends: win32more.Windows.Win32.Web.MsHtml.IHTMLDocument
    _iid_ = Guid('{332c4425-26cb-11d0-b483-00c04fd90119}')
    @commethod(8)
    def get_all(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_body(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_activeElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_images(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_applets(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_links(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_forms(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_anchors(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_title(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_title(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_scripts(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_designMode(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_designMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_selection(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLSelectionObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_readyState(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_frames(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFramesCollection2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_embeds(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_plugins(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_alinkColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_alinkColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_bgColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_bgColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def put_fgColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_fgColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def put_linkColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_linkColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def put_vlinkColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_vlinkColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_referrer(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_location(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLLocation)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_lastModified(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_URL(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_URL(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_domain(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_domain(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_cookie(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_cookie(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_expando(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_expando(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def put_charset(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_charset(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def put_defaultCharset(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def get_defaultCharset(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def get_mimeType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_fileSize(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def get_fileCreatedDate(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_fileModifiedDate(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def get_fileUpdatedDate(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_security(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def get_protocol(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def get_nameProp(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def write(self, psarray: POINTER(win32more.Windows.Win32.System.Com.SAFEARRAY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def writeln(self, psarray: POINTER(win32more.Windows.Win32.System.Com.SAFEARRAY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def open(self, url: win32more.Windows.Win32.Foundation.BSTR, name: win32more.Windows.Win32.System.Variant.VARIANT, features: win32more.Windows.Win32.System.Variant.VARIANT, replace: win32more.Windows.Win32.System.Variant.VARIANT, pomWindowResult: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def close(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def queryCommandSupported(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def queryCommandEnabled(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def queryCommandState(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def queryCommandIndeterm(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def queryCommandText(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pcmdText: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def queryCommandValue(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pcmdValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def execCommand(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, showUI: win32more.Windows.Win32.Foundation.VARIANT_BOOL, value: win32more.Windows.Win32.System.Variant.VARIANT, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def execCommandShowHelp(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def createElement(self, eTag: win32more.Windows.Win32.Foundation.BSTR, newElem: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def put_onhelp(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def get_onhelp(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def put_onclick(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def get_onclick(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def put_ondblclick(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def get_ondblclick(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def put_onkeyup(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def get_onkeyup(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def put_onkeydown(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def get_onkeydown(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def put_onkeypress(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def get_onkeypress(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def put_onmouseup(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def get_onmouseup(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def put_onmousedown(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def get_onmousedown(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def put_onmousemove(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def get_onmousemove(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def put_onmouseout(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def get_onmouseout(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def put_onmouseover(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def get_onmouseover(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def put_onreadystatechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def get_onreadystatechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def put_onafterupdate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def get_onafterupdate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def put_onrowexit(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def get_onrowexit(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def put_onrowenter(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def get_onrowenter(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def put_ondragstart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def get_ondragstart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(105)
    def put_onselectstart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(106)
    def get_onselectstart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(107)
    def elementFromPoint(self, x: Int32, y: Int32, elementHit: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(108)
    def get_parentWindow(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(109)
    def get_styleSheets(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheetsCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(110)
    def put_onbeforeupdate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(111)
    def get_onbeforeupdate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(112)
    def put_onerrorupdate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(113)
    def get_onerrorupdate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(114)
    def toString(self, String: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(115)
    def createStyleSheet(self, bstrHref: win32more.Windows.Win32.Foundation.BSTR, lIndex: Int32, ppnewStyleSheet: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheet)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDocument3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f485-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def releaseCapture(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def recalc(self, fForce: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def createTextNode(self, text: win32more.Windows.Win32.Foundation.BSTR, newTextNode: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_documentElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_uniqueID(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def attachEvent(self, event: win32more.Windows.Win32.Foundation.BSTR, pDisp: win32more.Windows.Win32.System.Com.IDispatch, pfResult: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def detachEvent(self, event: win32more.Windows.Win32.Foundation.BSTR, pDisp: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_onrowsdelete(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_onrowsdelete(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_onrowsinserted(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_onrowsinserted(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_oncellchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_oncellchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_ondatasetchanged(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_ondatasetchanged(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_ondataavailable(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_ondataavailable(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_ondatasetcomplete(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_ondatasetcomplete(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_onpropertychange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_onpropertychange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_dir(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_dir(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def put_oncontextmenu(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_oncontextmenu(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def put_onstop(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_onstop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def createDocumentFragment(self, pNewDoc: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDocument2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_parentDocument(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDocument2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def put_enableDownload(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_enableDownload(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def put_baseUrl(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_baseUrl(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_childNodes(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_inheritStyleSheets(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_inheritStyleSheets(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_onbeforeeditfocus(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_onbeforeeditfocus(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def getElementsByName(self, v: win32more.Windows.Win32.Foundation.BSTR, pelColl: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def getElementById(self, v: win32more.Windows.Win32.Foundation.BSTR, pel: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def getElementsByTagName(self, v: win32more.Windows.Win32.Foundation.BSTR, pelColl: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDocument4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f69a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def focus(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def hasFocus(self, pfFocus: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_onselectionchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_onselectionchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_namespaces(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def createDocumentFromUrl(self, bstrUrl: win32more.Windows.Win32.Foundation.BSTR, bstrOptions: win32more.Windows.Win32.Foundation.BSTR, newDoc: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDocument2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_media(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_media(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def createEventObject(self, pvarEventObject: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppEventObj: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLEventObj)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def fireEvent(self, bstrEventName: win32more.Windows.Win32.Foundation.BSTR, pvarEventObject: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pfCancelled: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def createRenderStyle(self, v: win32more.Windows.Win32.Foundation.BSTR, ppIHTMLRenderStyle: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLRenderStyle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_oncontrolselect(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_oncontrolselect(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_URLUnencoded(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDocument5(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f80c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_onmousewheel(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_onmousewheel(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_doctype(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_implementation(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMImplementation)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def createAttribute(self, bstrattrName: win32more.Windows.Win32.Foundation.BSTR, ppattribute: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def createComment(self, bstrdata: win32more.Windows.Win32.Foundation.BSTR, ppRetNode: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_onfocusin(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_onfocusin(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_onfocusout(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_onfocusout(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_onactivate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_onactivate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_ondeactivate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_ondeactivate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_onbeforeactivate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_onbeforeactivate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_onbeforedeactivate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_onbeforedeactivate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_compatMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDocument6(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510417-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_compatible(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDocumentCompatibleInfoCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_documentMode(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_onstorage(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_onstorage(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_onstoragecommit(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_onstoragecommit(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def getElementById(self, bstrId: win32more.Windows.Win32.Foundation.BSTR, ppRetElement: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def updateSettings(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDocument7(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104b8-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_defaultView(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def createCDATASection(self, text: win32more.Windows.Win32.Foundation.BSTR, newCDATASectionNode: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def getSelection(self, ppIHTMLSelection: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLSelection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def getElementsByTagNameNS(self, pvarNS: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), bstrLocalName: win32more.Windows.Win32.Foundation.BSTR, pelColl: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def createElementNS(self, pvarNS: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), bstrTag: win32more.Windows.Win32.Foundation.BSTR, newElem: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def createAttributeNS(self, pvarNS: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), bstrAttrName: win32more.Windows.Win32.Foundation.BSTR, ppAttribute: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_onmsthumbnailclick(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_onmsthumbnailclick(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_characterSet(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def createElement(self, bstrTag: win32more.Windows.Win32.Foundation.BSTR, newElem: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def createAttribute(self, bstrAttrName: win32more.Windows.Win32.Foundation.BSTR, ppAttribute: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def getElementsByClassName(self, v: win32more.Windows.Win32.Foundation.BSTR, pel: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def createProcessingInstruction(self, bstrTarget: win32more.Windows.Win32.Foundation.BSTR, bstrData: win32more.Windows.Win32.Foundation.BSTR, newProcessingInstruction: POINTER(win32more.Windows.Win32.Web.MsHtml.IDOMProcessingInstruction)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def adoptNode(self, pNodeSource: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, ppNodeDest: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_onmssitemodejumplistitemremoved(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_onmssitemodejumplistitemremoved(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_all(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_inputEncoding(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_xmlEncoding(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_xmlStandalone(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_xmlStandalone(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_xmlVersion(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_xmlVersion(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def hasAttributes(self, pfHasAttributes: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_onabort(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_onabort(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_onblur(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_onblur(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_oncanplay(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_oncanplay(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_oncanplaythrough(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_oncanplaythrough(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_onchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_onchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_ondrag(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_ondrag(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_ondragend(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_ondragend(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_ondragenter(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_ondragenter(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def put_ondragleave(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_ondragleave(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def put_ondragover(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def get_ondragover(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def put_ondrop(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_ondrop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def put_ondurationchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_ondurationchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def put_onemptied(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_onemptied(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def put_onended(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def get_onended(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def put_onerror(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def get_onerror(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def put_onfocus(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_onfocus(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def put_oninput(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def get_oninput(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def put_onload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def get_onload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def put_onloadeddata(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def get_onloadeddata(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def put_onloadedmetadata(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def get_onloadedmetadata(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def put_onloadstart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def get_onloadstart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def put_onpause(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def get_onpause(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def put_onplay(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def get_onplay(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def put_onplaying(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def get_onplaying(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def put_onprogress(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def get_onprogress(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def put_onratechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def get_onratechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def put_onreset(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def get_onreset(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def put_onscroll(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def get_onscroll(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def put_onseeked(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def get_onseeked(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def put_onseeking(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def get_onseeking(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def put_onselect(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def get_onselect(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def put_onstalled(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def get_onstalled(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def put_onsubmit(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def get_onsubmit(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def put_onsuspend(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def get_onsuspend(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def put_ontimeupdate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def get_ontimeupdate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def put_onvolumechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def get_onvolumechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def put_onwaiting(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def get_onwaiting(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(105)
    def normalize(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(106)
    def importNode(self, pNodeSource: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, fDeep: win32more.Windows.Win32.Foundation.VARIANT_BOOL, ppNodeDest: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(107)
    def get_parentWindow(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(108)
    def putref_body(self, v: win32more.Windows.Win32.Web.MsHtml.IHTMLElement) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(109)
    def get_body(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(110)
    def get_head(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDocument8(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305107d0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_onmscontentzoom(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_onmscontentzoom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_onmspointerdown(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_onmspointerdown(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_onmspointermove(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_onmspointermove(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_onmspointerup(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_onmspointerup(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_onmspointerover(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_onmspointerover(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_onmspointerout(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_onmspointerout(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_onmspointercancel(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_onmspointercancel(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_onmspointerhover(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_onmspointerhover(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_onmsgesturestart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_onmsgesturestart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_onmsgesturechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_onmsgesturechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_onmsgestureend(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_onmsgestureend(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_onmsgesturehold(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_onmsgesturehold(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_onmsgesturetap(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_onmsgesturetap(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_onmsgesturedoubletap(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_onmsgesturedoubletap(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_onmsinertiastart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_onmsinertiastart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def elementsFromPoint(self, x: Single, y: Single, elementsHit: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMChildrenCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def elementsFromRect(self, left: Single, top: Single, width: Single, height: Single, elementsHit: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMChildrenCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_onmsmanipulationstatechanged(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_onmsmanipulationstatechanged(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_msCapsLockWarningOff(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_msCapsLockWarningOff(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDocumentCompatibleInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051041a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_userAgent(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_version(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLDocumentCompatibleInfoCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510418-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def item(self, index: Int32, compatibleInfo: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDocumentCompatibleInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLEditDesigner(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f662-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def PreHandleEvent(self, inEvtDispId: Int32, pIEventObj: win32more.Windows.Win32.Web.MsHtml.IHTMLEventObj) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def PostHandleEvent(self, inEvtDispId: Int32, pIEventObj: win32more.Windows.Win32.Web.MsHtml.IHTMLEventObj) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def TranslateAccelerator(self, inEvtDispId: Int32, pIEventObj: win32more.Windows.Win32.Web.MsHtml.IHTMLEventObj) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def PostEditorEventNotify(self, inEvtDispId: Int32, pIEventObj: win32more.Windows.Win32.Web.MsHtml.IHTMLEventObj) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLEditHost(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f6a0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def SnapRect(self, pIElement: win32more.Windows.Win32.Web.MsHtml.IHTMLElement, prcNew: POINTER(win32more.Windows.Win32.Foundation.RECT), eHandle: win32more.Windows.Win32.Web.MsHtml.ELEMENT_CORNER) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLEditHost2(ComPtr):
    extends: win32more.Windows.Win32.Web.MsHtml.IHTMLEditHost
    _iid_ = Guid('{3050f848-98b5-11cf-bb82-00aa00bdce0d}')
    @commethod(4)
    def PreDrag(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLEditServices(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f663-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def AddDesigner(self, pIDesigner: win32more.Windows.Win32.Web.MsHtml.IHTMLEditDesigner) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def RemoveDesigner(self, pIDesigner: win32more.Windows.Win32.Web.MsHtml.IHTMLEditDesigner) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetSelectionServices(self, pIContainer: win32more.Windows.Win32.Web.MsHtml.IMarkupContainer, ppSelSvc: POINTER(win32more.Windows.Win32.Web.MsHtml.ISelectionServices)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def MoveToSelectionAnchor(self, pIStartAnchor: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def MoveToSelectionEnd(self, pIEndAnchor: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SelectRange(self, pStart: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pEnd: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, eType: win32more.Windows.Win32.Web.MsHtml.SELECTION_TYPE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLEditServices2(ComPtr):
    extends: win32more.Windows.Win32.Web.MsHtml.IHTMLEditServices
    _iid_ = Guid('{3050f812-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(9)
    def MoveToSelectionAnchorEx(self, pIStartAnchor: win32more.Windows.Win32.Web.MsHtml.IDisplayPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def MoveToSelectionEndEx(self, pIEndAnchor: win32more.Windows.Win32.Web.MsHtml.IDisplayPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def FreezeVirtualCaretPos(self, fReCompute: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def UnFreezeVirtualCaretPos(self, fReset: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f1ff-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def setAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, AttributeValue: win32more.Windows.Win32.System.Variant.VARIANT, lFlags: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def getAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, lFlags: Int32, AttributeValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def removeAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, lFlags: Int32, pfSuccess: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_className(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_className(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_id(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_id(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_tagName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_parentElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_style(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_onhelp(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_onhelp(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_onclick(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_onclick(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_ondblclick(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_ondblclick(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_onkeydown(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_onkeydown(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_onkeyup(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_onkeyup(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_onkeypress(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_onkeypress(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_onmouseout(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_onmouseout(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_onmouseover(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_onmouseover(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_onmousemove(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_onmousemove(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_onmousedown(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_onmousedown(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_onmouseup(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_onmouseup(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_document(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def put_title(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_title(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def put_language(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def get_language(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def put_onselectstart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_onselectstart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def scrollIntoView(self, varargStart: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def contains(self, pChild: win32more.Windows.Win32.Web.MsHtml.IHTMLElement, pfResult: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_sourceIndex(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def get_recordNumber(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def put_lang(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def get_lang(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_offsetLeft(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def get_offsetTop(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_offsetWidth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def get_offsetHeight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_offsetParent(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def put_innerHTML(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def get_innerHTML(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def put_innerText(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def get_innerText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def put_outerHTML(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_outerHTML(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def put_outerText(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def get_outerText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def insertAdjacentHTML(self, where: win32more.Windows.Win32.Foundation.BSTR, html: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def insertAdjacentText(self, where: win32more.Windows.Win32.Foundation.BSTR, text: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def get_parentTextEdit(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def get_isTextEdit(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def click(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def get_filters(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFiltersCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def put_ondragstart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def get_ondragstart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def toString(self, String: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def put_onbeforeupdate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def get_onbeforeupdate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def put_onafterupdate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def get_onafterupdate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def put_onerrorupdate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def get_onerrorupdate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def put_onrowexit(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def get_onrowexit(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def put_onrowenter(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def get_onrowenter(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def put_ondatasetchanged(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def get_ondatasetchanged(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def put_ondataavailable(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def get_ondataavailable(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def put_ondatasetcomplete(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def get_ondatasetcomplete(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def put_onfilterchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def get_onfilterchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def get_children(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def get_all(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f434-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_scopeName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def setCapture(self, containerCapture: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def releaseCapture(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_onlosecapture(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_onlosecapture(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def componentFromPoint(self, x: Int32, y: Int32, component: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def doScroll(self, component: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_onscroll(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_onscroll(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_ondrag(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_ondrag(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_ondragend(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_ondragend(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_ondragenter(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_ondragenter(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_ondragover(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_ondragover(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_ondragleave(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_ondragleave(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_ondrop(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_ondrop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_onbeforecut(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_onbeforecut(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def put_oncut(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_oncut(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def put_onbeforecopy(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_onbeforecopy(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def put_oncopy(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_oncopy(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def put_onbeforepaste(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_onbeforepaste(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def put_onpaste(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_onpaste(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_currentStyle(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLCurrentStyle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_onpropertychange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_onpropertychange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def getClientRects(self, pRectCol: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLRectCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def getBoundingClientRect(self, pRect: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLRect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def setExpression(self, propname: win32more.Windows.Win32.Foundation.BSTR, expression: win32more.Windows.Win32.Foundation.BSTR, language: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def getExpression(self, propname: win32more.Windows.Win32.Foundation.BSTR, expression: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def removeExpression(self, propname: win32more.Windows.Win32.Foundation.BSTR, pfSuccess: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def put_tabIndex(self, v: Int16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def get_tabIndex(self, p: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def focus(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def put_accessKey(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_accessKey(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def put_onblur(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_onblur(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def put_onfocus(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_onfocus(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def put_onresize(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def get_onresize(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def blur(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def addFilter(self, pUnk: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def removeFilter(self, pUnk: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_clientHeight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def get_clientWidth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def get_clientTop(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def get_clientLeft(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def attachEvent(self, event: win32more.Windows.Win32.Foundation.BSTR, pDisp: win32more.Windows.Win32.System.Com.IDispatch, pfResult: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def detachEvent(self, event: win32more.Windows.Win32.Foundation.BSTR, pDisp: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def get_readyState(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def put_onreadystatechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def get_onreadystatechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def put_onrowsdelete(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def get_onrowsdelete(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def put_onrowsinserted(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def get_onrowsinserted(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def put_oncellchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def get_oncellchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def put_dir(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def get_dir(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def createControlRange(self, range: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def get_scrollHeight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def get_scrollWidth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def put_scrollTop(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def get_scrollTop(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def put_scrollLeft(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def get_scrollLeft(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def clearAttributes(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def mergeAttributes(self, mergeThis: win32more.Windows.Win32.Web.MsHtml.IHTMLElement) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def put_oncontextmenu(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def get_oncontextmenu(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def insertAdjacentElement(self, where: win32more.Windows.Win32.Foundation.BSTR, insertedElement: win32more.Windows.Win32.Web.MsHtml.IHTMLElement, inserted: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def applyElement(self, apply: win32more.Windows.Win32.Web.MsHtml.IHTMLElement, where: win32more.Windows.Win32.Foundation.BSTR, applied: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def getAdjacentText(self, where: win32more.Windows.Win32.Foundation.BSTR, text: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def replaceAdjacentText(self, where: win32more.Windows.Win32.Foundation.BSTR, newText: win32more.Windows.Win32.Foundation.BSTR, oldText: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def get_canHaveChildren(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def addBehavior(self, bstrUrl: win32more.Windows.Win32.Foundation.BSTR, pvarFactory: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pCookie: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def removeBehavior(self, cookie: Int32, pfResult: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def get_runtimeStyle(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def get_behaviorUrns(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def put_tagUrn(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def get_tagUrn(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def put_onbeforeeditfocus(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def get_onbeforeeditfocus(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def get_readyStateValue(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def getElementsByTagName(self, v: win32more.Windows.Win32.Foundation.BSTR, pelColl: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLElement3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f673-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def mergeAttributes(self, mergeThis: win32more.Windows.Win32.Web.MsHtml.IHTMLElement, pvarFlags: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_isMultiLine(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_canHaveHTML(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_onlayoutcomplete(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_onlayoutcomplete(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_onpage(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_onpage(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_inflateBlock(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_inflateBlock(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_onbeforedeactivate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_onbeforedeactivate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def setActive(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_contentEditable(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_contentEditable(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_isContentEditable(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_hideFocus(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_hideFocus(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_disabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_disabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_isDisabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_onmove(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_onmove(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_oncontrolselect(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_oncontrolselect(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def fireEvent(self, bstrEventName: win32more.Windows.Win32.Foundation.BSTR, pvarEventObject: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pfCancelled: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def put_onresizestart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_onresizestart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def put_onresizeend(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_onresizeend(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def put_onmovestart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_onmovestart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def put_onmoveend(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_onmoveend(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def put_onmouseenter(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_onmouseenter(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def put_onmouseleave(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def get_onmouseleave(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def put_onactivate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_onactivate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def put_ondeactivate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def get_ondeactivate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def dragDrop(self, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def get_glyphMode(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLElement4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f80f-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_onmousewheel(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_onmousewheel(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def normalize(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def getAttributeNode(self, bstrname: win32more.Windows.Win32.Foundation.BSTR, ppAttribute: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def setAttributeNode(self, pattr: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute, ppretAttribute: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def removeAttributeNode(self, pattr: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute, ppretAttribute: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_onbeforeactivate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_onbeforeactivate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_onfocusin(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_onfocusin(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_onfocusout(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_onfocusout(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLElement5(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051045d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def getAttributeNode(self, bstrname: win32more.Windows.Win32.Foundation.BSTR, ppretAttribute: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def setAttributeNode(self, pattr: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2, ppretAttribute: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def removeAttributeNode(self, pattr: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2, ppretAttribute: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def hasAttribute(self, name: win32more.Windows.Win32.Foundation.BSTR, pfHasAttribute: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_role(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_role(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_ariaBusy(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_ariaBusy(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_ariaChecked(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_ariaChecked(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_ariaDisabled(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_ariaDisabled(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_ariaExpanded(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_ariaExpanded(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_ariaHaspopup(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_ariaHaspopup(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_ariaHidden(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_ariaHidden(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_ariaInvalid(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_ariaInvalid(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_ariaMultiselectable(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_ariaMultiselectable(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_ariaPressed(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_ariaPressed(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_ariaReadonly(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_ariaReadonly(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_ariaRequired(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_ariaRequired(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_ariaSecret(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_ariaSecret(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_ariaSelected(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_ariaSelected(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def getAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, AttributeValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def setAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, AttributeValue: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def removeAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, pfSuccess: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_attributes(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLAttributeCollection3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_ariaValuenow(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_ariaValuenow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_ariaPosinset(self, v: Int16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_ariaPosinset(self, p: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def put_ariaSetsize(self, v: Int16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_ariaSetsize(self, p: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def put_ariaLevel(self, v: Int16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def get_ariaLevel(self, p: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def put_ariaValuemin(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_ariaValuemin(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def put_ariaValuemax(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_ariaValuemax(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def put_ariaControls(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_ariaControls(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def put_ariaDescribedby(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def get_ariaDescribedby(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def put_ariaFlowto(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def get_ariaFlowto(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def put_ariaLabelledby(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_ariaLabelledby(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def put_ariaActivedescendant(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def get_ariaActivedescendant(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def put_ariaOwns(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def get_ariaOwns(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def hasAttributes(self, pfHasAttributes: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def put_ariaLive(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def get_ariaLive(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def put_ariaRelevant(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def get_ariaRelevant(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLElement6(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106f8-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def getAttributeNS(self, pvarNS: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), strAttributeName: win32more.Windows.Win32.Foundation.BSTR, AttributeValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def setAttributeNS(self, pvarNS: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), strAttributeName: win32more.Windows.Win32.Foundation.BSTR, pvarAttributeValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def removeAttributeNS(self, pvarNS: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), strAttributeName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def getAttributeNodeNS(self, pvarNS: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), bstrname: win32more.Windows.Win32.Foundation.BSTR, ppretAttribute: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def setAttributeNodeNS(self, pattr: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2, ppretAttribute: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def hasAttributeNS(self, pvarNS: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), name: win32more.Windows.Win32.Foundation.BSTR, pfHasAttribute: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def getAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, AttributeValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def setAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, pvarAttributeValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def removeAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def getAttributeNode(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, ppretAttribute: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def setAttributeNode(self, pattr: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2, ppretAttribute: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def removeAttributeNode(self, pattr: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2, ppretAttribute: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMAttribute2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def hasAttribute(self, name: win32more.Windows.Win32.Foundation.BSTR, pfHasAttribute: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def getElementsByTagNameNS(self, varNS: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), bstrLocalName: win32more.Windows.Win32.Foundation.BSTR, pelColl: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_tagName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_nodeName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def getElementsByClassName(self, v: win32more.Windows.Win32.Foundation.BSTR, pel: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def msMatchesSelector(self, v: win32more.Windows.Win32.Foundation.BSTR, pfMatches: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_onabort(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_onabort(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_oncanplay(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_oncanplay(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_oncanplaythrough(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_oncanplaythrough(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_onchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_onchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_ondurationchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_ondurationchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_onemptied(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_onemptied(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_onended(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_onended(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_onerror(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_onerror(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_oninput(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_oninput(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_onload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_onload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_onloadeddata(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_onloadeddata(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def put_onloadedmetadata(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_onloadedmetadata(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def put_onloadstart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def get_onloadstart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def put_onpause(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_onpause(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def put_onplay(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_onplay(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def put_onplaying(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_onplaying(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def put_onprogress(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def get_onprogress(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def put_onratechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def get_onratechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def put_onreset(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_onreset(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def put_onseeked(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def get_onseeked(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def put_onseeking(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def get_onseeking(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def put_onselect(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def get_onselect(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def put_onstalled(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def get_onstalled(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def put_onsubmit(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def get_onsubmit(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def put_onsuspend(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def get_onsuspend(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def put_ontimeupdate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def get_ontimeupdate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def put_onvolumechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def get_onvolumechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def put_onwaiting(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def get_onwaiting(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def hasAttributes(self, pfHasAttributes: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLElement7(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305107aa-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_onmspointerdown(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_onmspointerdown(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_onmspointermove(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_onmspointermove(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_onmspointerup(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_onmspointerup(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_onmspointerover(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_onmspointerover(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_onmspointerout(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_onmspointerout(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_onmspointercancel(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_onmspointercancel(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_onmspointerhover(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_onmspointerhover(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_onmslostpointercapture(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_onmslostpointercapture(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_onmsgotpointercapture(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_onmsgotpointercapture(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_onmsgesturestart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_onmsgesturestart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_onmsgesturechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_onmsgesturechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_onmsgestureend(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_onmsgestureend(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_onmsgesturehold(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_onmsgesturehold(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_onmsgesturetap(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_onmsgesturetap(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_onmsgesturedoubletap(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_onmsgesturedoubletap(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_onmsinertiastart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_onmsinertiastart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def msSetPointerCapture(self, pointerId: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def msReleasePointerCapture(self, pointerId: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_onmstransitionstart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_onmstransitionstart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_onmstransitionend(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_onmstransitionend(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_onmsanimationstart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_onmsanimationstart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def put_onmsanimationend(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_onmsanimationend(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def put_onmsanimationiteration(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def get_onmsanimationiteration(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def put_oninvalid(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_oninvalid(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def put_xmsAcceleratorKey(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_xmsAcceleratorKey(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def put_spellcheck(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_spellcheck(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def put_onmsmanipulationstatechanged(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def get_onmsmanipulationstatechanged(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def put_oncuechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def get_oncuechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLElementAppliedStyles(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104bd-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def msGetRulesApplied(self, ppRulesAppliedCollection: POINTER(win32more.Windows.Win32.Web.MsHtml.IRulesAppliedCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def msGetRulesAppliedWithAncestor(self, varContext: win32more.Windows.Win32.System.Variant.VARIANT, ppRulesAppliedCollection: POINTER(win32more.Windows.Win32.Web.MsHtml.IRulesAppliedCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLElementCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f21f-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def toString(self, String: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_length(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get__newEnum(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def item(self, name: win32more.Windows.Win32.System.Variant.VARIANT, index: win32more.Windows.Win32.System.Variant.VARIANT, pdisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def tags(self, tagName: win32more.Windows.Win32.System.Variant.VARIANT, pdisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLElementCollection2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5ee-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def urns(self, urn: win32more.Windows.Win32.System.Variant.VARIANT, pdisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLElementCollection3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f835-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def namedItem(self, name: win32more.Windows.Win32.Foundation.BSTR, pdisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLElementCollection4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510425-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def item(self, index: Int32, pNode: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def namedItem(self, name: win32more.Windows.Win32.Foundation.BSTR, pNode: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLElementDefaults(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f6c9-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_style(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_tabStop(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_tabStop(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_viewInheritStyle(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_viewInheritStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_viewMasterTab(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_viewMasterTab(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_scrollSegmentX(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_scrollSegmentX(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_scrollSegmentY(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_scrollSegmentY(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_isMultiLine(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_isMultiLine(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_contentEditable(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_contentEditable(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_canHaveHTML(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_canHaveHTML(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def putref_viewLink(self, v: win32more.Windows.Win32.Web.MsHtml.IHTMLDocument) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_viewLink(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDocument)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_frozen(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_frozen(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLElementRender(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f669-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def DrawToDC(self, hDC: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetDocumentPrinter(self, bstrPrinterName: win32more.Windows.Win32.Foundation.BSTR, hDC: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLEmbedElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f25f-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_hidden(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_hidden(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_palette(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_pluginspage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_src(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_src(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_units(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_units(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_width(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_width(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_height(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_height(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLEmbedElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510493-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_src(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_src(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_pluginspage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLEventObj(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f32d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_srcElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_altKey(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_ctrlKey(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_shiftKey(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_returnValue(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_returnValue(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_cancelBubble(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_cancelBubble(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_fromElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_toElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_keyCode(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_keyCode(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_button(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_qualifier(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_reason(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_x(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_y(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_clientX(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_clientY(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_offsetX(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_offsetY(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_screenX(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_screenY(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_srcFilter(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLEventObj2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f48b-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def setAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, AttributeValue: win32more.Windows.Win32.System.Variant.VARIANT, lFlags: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def getAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, lFlags: Int32, AttributeValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def removeAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, lFlags: Int32, pfSuccess: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_propertyName(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_propertyName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def putref_bookmarks(self, v: win32more.Windows.Win32.Web.MsHtml.IHTMLBookmarkCollection) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_bookmarks(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLBookmarkCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def putref_recordset(self, v: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_recordset(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_dataFld(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_dataFld(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def putref_boundElements(self, v: win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_boundElements(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_repeat(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_repeat(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_srcUrn(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_srcUrn(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def putref_srcElement(self, v: win32more.Windows.Win32.Web.MsHtml.IHTMLElement) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_srcElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_altKey(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_altKey(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_ctrlKey(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_ctrlKey(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def put_shiftKey(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_shiftKey(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def putref_fromElement(self, v: win32more.Windows.Win32.Web.MsHtml.IHTMLElement) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_fromElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def putref_toElement(self, v: win32more.Windows.Win32.Web.MsHtml.IHTMLElement) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_toElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def put_button(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_button(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def put_type(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def put_qualifier(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_qualifier(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def put_reason(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def get_reason(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def put_x(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_x(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def put_y(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def get_y(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def put_clientX(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def get_clientX(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def put_clientY(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def get_clientY(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def put_offsetX(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def get_offsetX(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def put_offsetY(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def get_offsetY(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def put_screenX(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def get_screenX(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def put_screenY(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def get_screenY(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def putref_srcFilter(self, v: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def get_srcFilter(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_dataTransfer(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDataTransfer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLEventObj3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f680-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_contentOverflow(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_shiftLeft(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_shiftLeft(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_altLeft(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_altLeft(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_ctrlLeft(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_ctrlLeft(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_imeCompositionChange(self, p: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_imeNotifyCommand(self, p: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_imeNotifyData(self, p: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_imeRequest(self, p: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_imeRequestData(self, p: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_keyboardLayout(self, p: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_behaviorCookie(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_behaviorPart(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_nextPage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLEventObj4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f814-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_wheelDelta(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLEventObj5(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510478-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_url(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_url(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_data(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_data(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_source(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_origin(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_origin(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_issession(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_issession(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLEventObj6(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510734-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_actionURL(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_buttonID(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFieldSetElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f3e7-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFieldSetElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f833-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_form(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFormElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFiltersCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f3ee-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__newEnum(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def item(self, pvarIndex: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pvarResult: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFontElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f1d9-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_color(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_color(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_face(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_face(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_size(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_size(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFontNamesCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f376-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__newEnum(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def item(self, index: Int32, pBstr: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFontSizesCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f377-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__newEnum(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_forFont(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def item(self, index: Int32, plSize: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFormElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f1f7-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_action(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_action(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_dir(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_dir(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_encoding(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_encoding(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_method(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_method(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_elements(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_target(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_target(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_onsubmit(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_onsubmit(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_onreset(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_onreset(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def submit(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_length(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get__newEnum(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def item(self, name: win32more.Windows.Win32.System.Variant.VARIANT, index: win32more.Windows.Win32.System.Variant.VARIANT, pdisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def tags(self, tagName: win32more.Windows.Win32.System.Variant.VARIANT, pdisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFormElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4f6-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_acceptCharset(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_acceptCharset(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def urns(self, urn: win32more.Windows.Win32.System.Variant.VARIANT, pdisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFormElement3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f836-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def namedItem(self, name: win32more.Windows.Win32.Foundation.BSTR, pdisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFormElement4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051042c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_action(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_action(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFrameBase(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f311-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_src(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_src(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_border(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_border(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_frameBorder(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_frameBorder(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_frameSpacing(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_frameSpacing(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_marginWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_marginWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_marginHeight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_marginHeight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_noResize(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_noResize(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_scrolling(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_scrolling(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFrameBase2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f6db-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_contentWindow(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_onload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_onload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_onreadystatechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_onreadystatechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_readyState(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_allowTransparency(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_allowTransparency(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFrameBase3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f82e-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_longDesc(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_longDesc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFrameElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f313-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_borderColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_borderColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFrameElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f7f5-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_height(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_height(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_width(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_width(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFrameElement3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051042d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_contentDocument(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_src(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_src(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_longDesc(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_longDesc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_frameBorder(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_frameBorder(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFrameSetElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f319-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_rows(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_rows(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_cols(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_cols(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_border(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_border(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_borderColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_borderColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_frameBorder(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_frameBorder(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_frameSpacing(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_frameSpacing(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_onload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_onload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_onunload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_onunload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_onbeforeunload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_onbeforeunload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFrameSetElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5c6-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_onbeforeprint(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_onbeforeprint(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_onafterprint(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_onafterprint(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFrameSetElement3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510796-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_onhashchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_onhashchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_onmessage(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_onmessage(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_onoffline(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_onoffline(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_ononline(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_ononline(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_onstorage(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_onstorage(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLFramesCollection2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{332c4426-26cb-11d0-b483-00c04fd90119}')
    @commethod(7)
    def item(self, pvarIndex: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pvarResult: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLGenericElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4b7-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_recordset(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def namedRecordset(self, dataMember: win32more.Windows.Win32.Foundation.BSTR, hierarchy: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppRecordset: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLHRElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f1f4-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_color(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_color(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_noShade(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_noShade(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_width(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_width(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_size(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_size(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLHeadElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f81d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_profile(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_profile(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLHeadElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051042f-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_profile(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_profile(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLHeaderElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f1f6-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLHtmlElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f81c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_version(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_version(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLIFrameElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f315-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_vspace(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_vspace(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_hspace(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_hspace(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLIFrameElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4e6-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_height(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_height(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_width(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_width(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLIFrameElement3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510433-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_contentDocument(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_src(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_src(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_longDesc(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_longDesc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_frameBorder(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_frameBorder(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLIPrintCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f6b5-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__newEnum(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def item(self, index: Int32, ppIPrint: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLImageElementFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f38e-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def create(self, width: win32more.Windows.Win32.System.Variant.VARIANT, height: win32more.Windows.Win32.System.Variant.VARIANT, __MIDL__IHTMLImageElementFactory0000: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLImgElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLImgElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f240-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_isMap(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_isMap(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_useMap(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_useMap(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_mimeType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_fileSize(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_fileCreatedDate(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_fileModifiedDate(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_fileUpdatedDate(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_protocol(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_href(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_nameProp(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_border(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_border(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_vspace(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_vspace(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_hspace(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_hspace(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_alt(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_alt(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_src(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_src(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_lowsrc(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_lowsrc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_vrml(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_vrml(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_dynsrc(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_dynsrc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_readyState(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_complete(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_loop(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_loop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_onload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_onload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_onerror(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_onerror(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_onabort(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_onabort(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def put_width(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def get_width(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def put_height(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_height(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def put_start(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_start(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLImgElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f826-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_longDesc(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_longDesc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLImgElement3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510434-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_longDesc(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_longDesc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_vrml(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_vrml(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_lowsrc(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_lowsrc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_dynsrc(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_dynsrc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLImgElement4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305107f6-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_naturalWidth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_naturalHeight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLInputButtonElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2b2-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_status(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_status(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_disabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_disabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_form(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFormElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def createTextRange(self, range: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTxtRange)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLInputElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5d2-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_type(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_status(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_status(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_disabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_disabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_form(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFormElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_size(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_size(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_maxLength(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_maxLength(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def select(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_onchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_onchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_onselect(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_onselect(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_defaultValue(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_defaultValue(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_readOnly(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_readOnly(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def createTextRange(self, range: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTxtRange)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def put_indeterminate(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_indeterminate(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def put_defaultChecked(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_defaultChecked(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def put_checked(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_checked(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def put_border(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_border(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def put_vspace(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_vspace(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def put_hspace(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def get_hspace(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def put_alt(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_alt(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def put_src(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def get_src(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def put_lowsrc(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def get_lowsrc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def put_vrml(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def get_vrml(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def put_dynsrc(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def get_dynsrc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_readyState(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def get_complete(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def put_loop(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def get_loop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def put_onload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def get_onload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def put_onerror(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def get_onerror(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def put_onabort(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def get_onabort(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def put_width(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def get_width(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def put_height(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def get_height(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def put_start(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def get_start(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLInputElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f821-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_accept(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_accept(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_useMap(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_useMap(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLInputElement3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510435-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_src(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_src(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_lowsrc(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_lowsrc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_vrml(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_vrml(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_dynsrc(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_dynsrc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLInputFileElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2ad-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_status(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_status(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_disabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_disabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_form(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFormElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_size(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_size(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_maxLength(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_maxLength(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def select(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_onchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_onchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_onselect(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_onselect(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLInputHiddenElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2a4-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_status(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_status(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_disabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_disabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_form(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFormElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def createTextRange(self, range: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTxtRange)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLInputImage(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2c2-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_disabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_disabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_border(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_border(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_vspace(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_vspace(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_hspace(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_hspace(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_alt(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_alt(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_src(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_src(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_lowsrc(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_lowsrc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_vrml(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_vrml(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_dynsrc(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_dynsrc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_readyState(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_complete(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_loop(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_loop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def put_onload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_onload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def put_onerror(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_onerror(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def put_onabort(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_onabort(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def put_width(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_width(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def put_height(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def get_height(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def put_start(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_start(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLInputRangeElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2d4-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_disabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_disabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_alt(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_alt(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_min(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_min(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_max(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_max(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_step(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_step(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_valueAsNumber(self, v: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_valueAsNumber(self, p: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def stepUp(self, n: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def stepDown(self, n: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLInputTextElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2a6-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_status(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_status(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_disabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_disabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_form(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFormElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_defaultValue(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_defaultValue(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_size(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_size(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_maxLength(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_maxLength(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def select(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_onchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_onchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_onselect(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_onselect(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_readOnly(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_readOnly(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def createTextRange(self, range: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTxtRange)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLInputTextElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2d2-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_selectionStart(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_selectionStart(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_selectionEnd(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_selectionEnd(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def setSelectionRange(self, start: Int32, end: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLIsIndexElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f206-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_prompt(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_prompt(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_action(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_action(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLIsIndexElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f82f-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_form(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFormElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLLIElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f1e0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_type(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_value(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_value(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLLabelElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f32a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_htmlFor(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_htmlFor(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_accessKey(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_accessKey(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLLabelElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f832-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_form(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFormElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLLegendElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f3ea-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLLegendElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f834-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_form(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFormElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLLinkElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f205-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_href(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_href(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_rel(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_rel(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_rev(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_rev(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_type(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_readyState(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_onreadystatechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_onreadystatechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_onload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_onload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_onerror(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_onerror(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_styleSheet(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheet)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_disabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_disabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_media(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_media(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLLinkElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4e5-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_target(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_target(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLLinkElement3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f81e-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_charset(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_charset(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_hreflang(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_hreflang(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLLinkElement4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051043a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_href(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_href(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLLinkElement5(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510726-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_sheet(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheet)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLListElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f20e-98b5-11cf-bb82-00aa00bdce0b}')
class IHTMLListElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f822-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_compact(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_compact(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLLocation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{163bb1e0-6e00-11cf-837a-48dc04c10000}')
    @commethod(7)
    def put_href(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_href(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_protocol(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_protocol(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_host(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_host(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_hostname(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_hostname(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_port(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_port(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_pathname(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_pathname(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_search(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_search(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_hash(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_hash(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def reload(self, flag: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def replace(self, bstr: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def assign(self, bstr: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def toString(self, string: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLMSCSSKeyframeRule(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051080c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_keyText(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_keyText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_style(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLRuleStyle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLMSCSSKeyframesRule(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051080d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_cssRules(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheetRulesCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def appendRule(self, bstrRule: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def deleteRule(self, bstrKey: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def findRule(self, bstrKey: win32more.Windows.Win32.Foundation.BSTR, ppMSKeyframeRule: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLMSCSSKeyframeRule)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLMSImgElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510793-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_msPlayToDisabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_msPlayToDisabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_msPlayToPrimary(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_msPlayToPrimary(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLMSMediaElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510792-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_msPlayToDisabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_msPlayToDisabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_msPlayToPrimary(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_msPlayToPrimary(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLMapElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f266-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_areas(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLAreasCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLMarqueeElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2b5-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_bgColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_bgColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_scrollDelay(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_scrollDelay(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_direction(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_direction(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_behavior(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_behavior(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_scrollAmount(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_scrollAmount(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_loop(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_loop(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_vspace(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_vspace(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_hspace(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_hspace(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_onfinish(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_onfinish(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_onstart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_onstart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_onbounce(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_onbounce(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_width(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_width(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_height(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_height(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_trueSpeed(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_trueSpeed(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def start(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def stop(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLMediaElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510706-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_error(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLMediaError)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_src(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_src(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_currentSrc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_networkState(self, p: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_preload(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_preload(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_buffered(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTimeRanges)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def load(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def canPlayType(self, type: win32more.Windows.Win32.Foundation.BSTR, canPlay: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_seeking(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_currentTime(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_currentTime(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_initialTime(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_duration(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_paused(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_defaultPlaybackRate(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_defaultPlaybackRate(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_playbackRate(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_playbackRate(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_played(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTimeRanges)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_seekable(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTimeRanges)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_ended(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def put_autoplay(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_autoplay(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def put_loop(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_loop(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def play(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def pause(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def put_controls(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_controls(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def put_volume(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_volume(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def put_muted(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_muted(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def put_autobuffer(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def get_autobuffer(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLMediaElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510809-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_currentTimeDouble(self, v: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_currentTimeDouble(self, p: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_initialTimeDouble(self, p: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_durationDouble(self, p: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_defaultPlaybackRateDouble(self, v: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_defaultPlaybackRateDouble(self, p: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_playbackRateDouble(self, v: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_playbackRateDouble(self, p: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_volumeDouble(self, v: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_volumeDouble(self, p: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLMediaError(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510704-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_code(self, p: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLMetaElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f203-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_httpEquiv(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_httpEquiv(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_content(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_content(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_url(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_url(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_charset(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_charset(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLMetaElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f81f-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_scheme(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_scheme(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLMetaElement3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510495-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_url(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_url(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLMimeTypesCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f3fc-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLModelessInit(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5e4-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_parameters(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_optionString(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_moniker(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_document(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLNamespace(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f6bb-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_urn(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_tagNames(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_readyState(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_onreadystatechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_onreadystatechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def doImport(self, bstrImplementationUrl: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def attachEvent(self, event: win32more.Windows.Win32.Foundation.BSTR, pDisp: win32more.Windows.Win32.System.Com.IDispatch, pfResult: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def detachEvent(self, event: win32more.Windows.Win32.Foundation.BSTR, pDisp: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLNamespaceCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f6b8-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def item(self, index: win32more.Windows.Win32.System.Variant.VARIANT, ppNamespace: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def add(self, bstrNamespace: win32more.Windows.Win32.Foundation.BSTR, bstrUrn: win32more.Windows.Win32.Foundation.BSTR, implementationUrl: win32more.Windows.Win32.System.Variant.VARIANT, ppNamespace: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLNextIdElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f207-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_n(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_n(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLNoShowElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f38a-98b5-11cf-bb82-00aa00bdce0b}')
class IHTMLOListElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f1de-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_compact(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_compact(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_start(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_start(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_type(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLOMWindowServices(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f5fc-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def moveTo(self, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def moveBy(self, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def resizeTo(self, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def resizeBy(self, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLObjectElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f24f-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_object(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_classid(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_data(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def putref_recordset(self, v: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_recordset(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_codeBase(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_codeBase(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_codeType(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_codeType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_code(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_code(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_BaseHref(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_type(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_form(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFormElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_width(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_width(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_height(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_height(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_readyState(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_onreadystatechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_onreadystatechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_onerror(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_onerror(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_altHtml(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_altHtml(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_vspace(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_vspace(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_hspace(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_hspace(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLObjectElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4cd-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def namedRecordset(self, dataMember: win32more.Windows.Win32.Foundation.BSTR, hierarchy: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppRecordset: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_classid(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_classid(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_data(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_data(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLObjectElement3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f827-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_archive(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_archive(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_alt(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_alt(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_declare(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_declare(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_standby(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_standby(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_border(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_border(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_useMap(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_useMap(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLObjectElement4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051043e-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_contentDocument(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_codeBase(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_codeBase(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_data(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_data(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLObjectElement5(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104b5-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_object(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_object(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLOpsProfile(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f401-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def addRequest(self, name: win32more.Windows.Win32.Foundation.BSTR, reserved: win32more.Windows.Win32.System.Variant.VARIANT, success: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def clearRequest(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def doRequest(self, usage: win32more.Windows.Win32.System.Variant.VARIANT, fname: win32more.Windows.Win32.System.Variant.VARIANT, domain: win32more.Windows.Win32.System.Variant.VARIANT, path: win32more.Windows.Win32.System.Variant.VARIANT, expire: win32more.Windows.Win32.System.Variant.VARIANT, reserved: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def getAttribute(self, name: win32more.Windows.Win32.Foundation.BSTR, value: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def setAttribute(self, name: win32more.Windows.Win32.Foundation.BSTR, value: win32more.Windows.Win32.Foundation.BSTR, prefs: win32more.Windows.Win32.System.Variant.VARIANT, success: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def commitChanges(self, success: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def addReadRequest(self, name: win32more.Windows.Win32.Foundation.BSTR, reserved: win32more.Windows.Win32.System.Variant.VARIANT, success: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def doReadRequest(self, usage: win32more.Windows.Win32.System.Variant.VARIANT, fname: win32more.Windows.Win32.System.Variant.VARIANT, domain: win32more.Windows.Win32.System.Variant.VARIANT, path: win32more.Windows.Win32.System.Variant.VARIANT, expire: win32more.Windows.Win32.System.Variant.VARIANT, reserved: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def doWriteRequest(self, success: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLOptionButtonElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2bc-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_checked(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_checked(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_defaultChecked(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_defaultChecked(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_onchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_onchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_disabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_disabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_status(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_status(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_indeterminate(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_indeterminate(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_form(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFormElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLOptionElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f211-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_selected(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_selected(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_defaultSelected(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_defaultSelected(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_index(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_index(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_text(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_text(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_form(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFormElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLOptionElement3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f820-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_label(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_label(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLOptionElement4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305107b4-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLOptionElementFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f38c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def create(self, text: win32more.Windows.Win32.System.Variant.VARIANT, value: win32more.Windows.Win32.System.Variant.VARIANT, defaultselected: win32more.Windows.Win32.System.Variant.VARIANT, selected: win32more.Windows.Win32.System.Variant.VARIANT, __MIDL__IHTMLOptionElementFactory0000: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLOptionElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLOptionsHolder(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f378-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_document(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDocument2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_fonts(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFontNamesCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_execArg(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_execArg(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_errorLine(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_errorLine(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_errorCharacter(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_errorCharacter(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_errorCode(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_errorCode(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_errorMessage(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_errorMessage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_errorDebug(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_errorDebug(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_unsecuredWindowOfDocument(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_findText(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_findText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_anythingAfterFrameset(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_anythingAfterFrameset(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def sizes(self, fontName: win32more.Windows.Win32.Foundation.BSTR, pSizesCollection: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFontSizesCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def openfiledlg(self, initFile: win32more.Windows.Win32.System.Variant.VARIANT, initDir: win32more.Windows.Win32.System.Variant.VARIANT, filter: win32more.Windows.Win32.System.Variant.VARIANT, title: win32more.Windows.Win32.System.Variant.VARIANT, pathName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def savefiledlg(self, initFile: win32more.Windows.Win32.System.Variant.VARIANT, initDir: win32more.Windows.Win32.System.Variant.VARIANT, filter: win32more.Windows.Win32.System.Variant.VARIANT, title: win32more.Windows.Win32.System.Variant.VARIANT, pathName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def choosecolordlg(self, initColor: win32more.Windows.Win32.System.Variant.VARIANT, rgbColor: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def showSecurityInfo(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def isApartmentModel(self, object: win32more.Windows.Win32.Web.MsHtml.IHTMLObjectElement, fApartment: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def getCharset(self, fontName: win32more.Windows.Win32.Foundation.BSTR, charset: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_secureConnectionInfo(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLPaintSite(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f6a7-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def InvalidatePainterInfo(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def InvalidateRect(self, prcInvalid: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def InvalidateRegion(self, rgnInvalid: win32more.Windows.Win32.Graphics.Gdi.HRGN) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetDrawInfo(self, lFlags: Int32, pDrawInfo: POINTER(win32more.Windows.Win32.Web.MsHtml.HTML_PAINT_DRAW_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def TransformGlobalToLocal(self, ptGlobal: win32more.Windows.Win32.Foundation.POINT, pptLocal: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def TransformLocalToGlobal(self, ptLocal: win32more.Windows.Win32.Foundation.POINT, pptGlobal: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetHitTestCookie(self, plCookie: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLPainter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f6a6-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def Draw(self, rcBounds: win32more.Windows.Win32.Foundation.RECT, rcUpdate: win32more.Windows.Win32.Foundation.RECT, lDrawFlags: Int32, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, pvDrawObject: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnResize(self, size: win32more.Windows.Win32.Foundation.SIZE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetPainterInfo(self, pInfo: POINTER(win32more.Windows.Win32.Web.MsHtml.HTML_PAINTER_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def HitTestPoint(self, pt: win32more.Windows.Win32.Foundation.POINT, pbHit: POINTER(win32more.Windows.Win32.Foundation.BOOL), plPartID: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLPainterEventInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f6df-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetEventInfoFlags(self, plEventInfoFlags: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetEventTarget(self, ppElement: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetCursor(self, lPartID: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def StringFromPartID(self, lPartID: Int32, pbstrPart: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLPainterOverlay(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f7e3-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def OnMove(self, rcDevice: win32more.Windows.Win32.Foundation.RECT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLParaElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f1f5-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLParamElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f83d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_type(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_valueType(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_valueType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLParamElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510444-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_type(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_valueType(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_valueType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLPerformance(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051074e-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_navigation(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLPerformanceNavigation)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_timing(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLPerformanceTiming)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def toString(self, string: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def toJSON(self, pVar: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLPerformanceNavigation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510750-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_type(self, p: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_redirectCount(self, p: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def toString(self, string: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def toJSON(self, pVar: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLPerformanceTiming(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510752-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_navigationStart(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_unloadEventStart(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_unloadEventEnd(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_redirectStart(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_redirectEnd(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_fetchStart(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_domainLookupStart(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_domainLookupEnd(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_connectStart(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_connectEnd(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_requestStart(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_responseStart(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_responseEnd(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_domLoading(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_domInteractive(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_domContentLoadedEventStart(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_domContentLoadedEventEnd(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_domComplete(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_loadEventStart(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_loadEventEnd(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_msFirstPaint(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def toString(self, string: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def toJSON(self, pVar: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLPhraseElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f20a-98b5-11cf-bb82-00aa00bdce0b}')
class IHTMLPhraseElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f824-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_cite(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_cite(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_dateTime(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_dateTime(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLPhraseElement3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051043d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_cite(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_cite(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLPluginsCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f3fd-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def refresh(self, reload: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLPopup(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f666-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def show(self, x: Int32, y: Int32, w: Int32, h: Int32, pElement: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def hide(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_document(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDocument)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_isOpen(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLProgressElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2d6-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_value(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_value(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_max(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_max(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_position(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_form(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFormElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLRect(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4a3-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_left(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_left(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_top(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_top(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_right(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_right(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_bottom(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_bottom(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLRect2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051076c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_width(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_height(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLRectCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4a4-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__newEnum(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def item(self, pvarIndex: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pvarResult: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLRenderStyle(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f6ae-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_textLineThroughStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_textLineThroughStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_textUnderlineStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_textUnderlineStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_textEffect(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_textEffect(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_textColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_textColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_textBackgroundColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_textBackgroundColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_textDecorationColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_textDecorationColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_renderingPriority(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_renderingPriority(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_defaultTextSelection(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_defaultTextSelection(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_textDecoration(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_textDecoration(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLRuleStyle(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f3cf-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_fontFamily(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_fontFamily(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_fontStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_fontStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_fontVariant(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_fontVariant(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_fontWeight(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_fontWeight(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_fontSize(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_fontSize(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_font(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_font(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_color(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_color(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_background(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_background(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_backgroundColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_backgroundColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_backgroundImage(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_backgroundImage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_backgroundRepeat(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_backgroundRepeat(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_backgroundAttachment(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_backgroundAttachment(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_backgroundPosition(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_backgroundPosition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_backgroundPositionX(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_backgroundPositionX(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_backgroundPositionY(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_backgroundPositionY(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_wordSpacing(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_wordSpacing(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_letterSpacing(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_letterSpacing(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_textDecoration(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_textDecoration(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_textDecorationNone(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_textDecorationNone(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_textDecorationUnderline(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_textDecorationUnderline(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def put_textDecorationOverline(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_textDecorationOverline(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def put_textDecorationLineThrough(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def get_textDecorationLineThrough(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def put_textDecorationBlink(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_textDecorationBlink(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def put_verticalAlign(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_verticalAlign(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def put_textTransform(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_textTransform(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def put_textAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def get_textAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def put_textIndent(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def get_textIndent(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def put_lineHeight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_lineHeight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def put_marginTop(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def get_marginTop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def put_marginRight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def get_marginRight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def put_marginBottom(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def get_marginBottom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def put_marginLeft(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def get_marginLeft(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def put_margin(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def get_margin(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def put_paddingTop(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def get_paddingTop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def put_paddingRight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def get_paddingRight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def put_paddingBottom(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def get_paddingBottom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def put_paddingLeft(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def get_paddingLeft(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def put_padding(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def get_padding(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def put_border(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def get_border(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def put_borderTop(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def get_borderTop(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def put_borderRight(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def get_borderRight(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def put_borderBottom(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def get_borderBottom(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def put_borderLeft(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def get_borderLeft(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def put_borderColor(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def get_borderColor(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def put_borderTopColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def get_borderTopColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def put_borderRightColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def get_borderRightColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def put_borderBottomColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def get_borderBottomColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def put_borderLeftColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def get_borderLeftColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def put_borderWidth(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def get_borderWidth(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(105)
    def put_borderTopWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(106)
    def get_borderTopWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(107)
    def put_borderRightWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(108)
    def get_borderRightWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(109)
    def put_borderBottomWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(110)
    def get_borderBottomWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(111)
    def put_borderLeftWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(112)
    def get_borderLeftWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(113)
    def put_borderStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(114)
    def get_borderStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(115)
    def put_borderTopStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(116)
    def get_borderTopStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(117)
    def put_borderRightStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(118)
    def get_borderRightStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(119)
    def put_borderBottomStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(120)
    def get_borderBottomStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(121)
    def put_borderLeftStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(122)
    def get_borderLeftStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(123)
    def put_width(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(124)
    def get_width(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(125)
    def put_height(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(126)
    def get_height(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(127)
    def put_styleFloat(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(128)
    def get_styleFloat(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(129)
    def put_clear(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(130)
    def get_clear(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(131)
    def put_display(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(132)
    def get_display(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(133)
    def put_visibility(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(134)
    def get_visibility(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(135)
    def put_listStyleType(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(136)
    def get_listStyleType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(137)
    def put_listStylePosition(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(138)
    def get_listStylePosition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(139)
    def put_listStyleImage(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(140)
    def get_listStyleImage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(141)
    def put_listStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(142)
    def get_listStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(143)
    def put_whiteSpace(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(144)
    def get_whiteSpace(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(145)
    def put_top(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(146)
    def get_top(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(147)
    def put_left(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(148)
    def get_left(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(149)
    def get_position(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(150)
    def put_zIndex(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(151)
    def get_zIndex(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(152)
    def put_overflow(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(153)
    def get_overflow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(154)
    def put_pageBreakBefore(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(155)
    def get_pageBreakBefore(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(156)
    def put_pageBreakAfter(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(157)
    def get_pageBreakAfter(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(158)
    def put_cssText(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(159)
    def get_cssText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(160)
    def put_cursor(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(161)
    def get_cursor(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(162)
    def put_clip(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(163)
    def get_clip(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(164)
    def put_filter(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(165)
    def get_filter(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(166)
    def setAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, AttributeValue: win32more.Windows.Win32.System.Variant.VARIANT, lFlags: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(167)
    def getAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, lFlags: Int32, AttributeValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(168)
    def removeAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, lFlags: Int32, pfSuccess: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLRuleStyle2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4ac-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_tableLayout(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_tableLayout(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_borderCollapse(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_borderCollapse(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_direction(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_direction(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_behavior(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_behavior(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_position(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_position(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_unicodeBidi(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_unicodeBidi(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_bottom(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_bottom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_right(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_right(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_pixelBottom(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_pixelBottom(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_pixelRight(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_pixelRight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_posBottom(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_posBottom(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_posRight(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_posRight(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_imeMode(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_imeMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_rubyAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_rubyAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_rubyPosition(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_rubyPosition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_rubyOverhang(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_rubyOverhang(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_layoutGridChar(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_layoutGridChar(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_layoutGridLine(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_layoutGridLine(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_layoutGridMode(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_layoutGridMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_layoutGridType(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_layoutGridType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def put_layoutGrid(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_layoutGrid(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def put_textAutospace(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def get_textAutospace(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def put_wordBreak(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_wordBreak(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def put_lineBreak(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_lineBreak(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def put_textJustify(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_textJustify(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def put_textJustifyTrim(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def get_textJustifyTrim(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def put_textKashida(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def get_textKashida(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def put_overflowX(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_overflowX(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def put_overflowY(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def get_overflowY(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def put_accelerator(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def get_accelerator(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLRuleStyle3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f657-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_layoutFlow(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_layoutFlow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_zoom(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_zoom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_wordWrap(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_wordWrap(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_textUnderlinePosition(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_textUnderlinePosition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_scrollbarBaseColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_scrollbarBaseColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_scrollbarFaceColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_scrollbarFaceColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_scrollbar3dLightColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_scrollbar3dLightColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_scrollbarShadowColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_scrollbarShadowColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_scrollbarHighlightColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_scrollbarHighlightColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_scrollbarDarkShadowColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_scrollbarDarkShadowColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_scrollbarArrowColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_scrollbarArrowColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_scrollbarTrackColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_scrollbarTrackColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_writingMode(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_writingMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_textAlignLast(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_textAlignLast(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_textKashidaSpace(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_textKashidaSpace(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLRuleStyle4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f817-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_textOverflow(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_textOverflow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_minHeight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_minHeight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLRuleStyle5(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f335-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_msInterpolationMode(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_msInterpolationMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_maxHeight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_maxHeight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_minWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_minWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_maxWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_maxWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLRuleStyle6(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510471-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_content(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_content(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_captionSide(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_captionSide(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_counterIncrement(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_counterIncrement(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_counterReset(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_counterReset(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_outline(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_outline(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_outlineWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_outlineWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_outlineStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_outlineStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_outlineColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_outlineColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_boxSizing(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_boxSizing(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_borderSpacing(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_borderSpacing(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_orphans(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_orphans(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_widows(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_widows(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_pageBreakInside(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_pageBreakInside(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_emptyCells(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_emptyCells(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_msBlockProgression(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_msBlockProgression(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_quotes(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_quotes(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLScreen(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f35c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_colorDepth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_bufferDepth(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_bufferDepth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_width(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_height(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_updateInterval(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_updateInterval(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_availHeight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_availWidth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_fontSmoothingEnabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLScreen2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f84a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_logicalXDPI(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_logicalYDPI(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_deviceXDPI(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_deviceYDPI(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLScreen3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104a1-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_systemXDPI(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_systemYDPI(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLScreen4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051076b-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_pixelDepth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLScriptElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f28b-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_src(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_src(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_htmlFor(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_htmlFor(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_event(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_event(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_text(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_text(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_defer(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_defer(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_readyState(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_onerror(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_onerror(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_type(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLScriptElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f828-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_charset(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_charset(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLScriptElement3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510447-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_src(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_src(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLScriptElement4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510801-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_usedCharset(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLSelectElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f244-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_size(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_size(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_multiple(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_multiple(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_options(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_onchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_onchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_selectedIndex(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_selectedIndex(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_disabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_disabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_form(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFormElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def add(self, element: win32more.Windows.Win32.Web.MsHtml.IHTMLElement, before: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def remove(self, index: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_length(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get__newEnum(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def item(self, name: win32more.Windows.Win32.System.Variant.VARIANT, index: win32more.Windows.Win32.System.Variant.VARIANT, pdisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def tags(self, tagName: win32more.Windows.Win32.System.Variant.VARIANT, pdisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLSelectElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5ed-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def urns(self, urn: win32more.Windows.Win32.System.Variant.VARIANT, pdisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLSelectElement4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f838-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def namedItem(self, name: win32more.Windows.Win32.Foundation.BSTR, pdisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLSelectElement5(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051049d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def add(self, pElem: win32more.Windows.Win32.Web.MsHtml.IHTMLOptionElement, pvarBefore: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLSelectElement6(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510760-98b6-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def add(self, pElem: win32more.Windows.Win32.Web.MsHtml.IHTMLOptionElement, pvarBefore: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLSelectElementEx(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f2d1-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def ShowDropdown(self, fShow: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetSelectExFlags(self, lFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetSelectExFlags(self, pFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetDropdownOpen(self, pfOpen: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLSelection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104b6-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_anchorNode(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_anchorOffset(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_focusNode(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_focusOffset(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_isCollapsed(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def collapse(self, parentNode: win32more.Windows.Win32.System.Com.IDispatch, offfset: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def collapseToStart(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def collapseToEnd(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def selectAllChildren(self, parentNode: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def deleteFromDocument(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_rangeCount(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def getRangeAt(self, index: Int32, ppRange: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDOMRange)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def addRange(self, range: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def removeRange(self, range: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def removeAllRanges(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def toString(self, pSelectionString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLSelectionObject(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f25a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def createRange(self, range: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def empty(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLSelectionObject2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f7ec-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def createRangeCollection(self, rangeCollection: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_typeDetail(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLSourceElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510707-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_src(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_src(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_type(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_media(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_media(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLSpanElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f3f3-98b5-11cf-bb82-00aa00bdce0b}')
class IHTMLSpanFlow(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f3e5-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStorage(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510474-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_remainingSpace(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def key(self, lIndex: Int32, __MIDL__IHTMLStorage0000: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def getItem(self, bstrKey: win32more.Windows.Win32.Foundation.BSTR, __MIDL__IHTMLStorage0001: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def setItem(self, bstrKey: win32more.Windows.Win32.Foundation.BSTR, bstrValue: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def removeItem(self, bstrKey: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStorage2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510799-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def setItem(self, bstrKey: win32more.Windows.Win32.Foundation.BSTR, bstrValue: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyle(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f25e-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_fontFamily(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_fontFamily(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_fontStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_fontStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_fontVariant(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_fontVariant(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_fontWeight(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_fontWeight(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_fontSize(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_fontSize(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_font(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_font(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_color(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_color(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_background(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_background(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_backgroundColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_backgroundColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_backgroundImage(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_backgroundImage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_backgroundRepeat(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_backgroundRepeat(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_backgroundAttachment(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_backgroundAttachment(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_backgroundPosition(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_backgroundPosition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_backgroundPositionX(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_backgroundPositionX(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_backgroundPositionY(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_backgroundPositionY(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_wordSpacing(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_wordSpacing(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_letterSpacing(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_letterSpacing(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_textDecoration(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_textDecoration(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_textDecorationNone(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_textDecorationNone(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_textDecorationUnderline(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_textDecorationUnderline(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def put_textDecorationOverline(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_textDecorationOverline(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def put_textDecorationLineThrough(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def get_textDecorationLineThrough(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def put_textDecorationBlink(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_textDecorationBlink(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def put_verticalAlign(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_verticalAlign(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def put_textTransform(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_textTransform(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def put_textAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def get_textAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def put_textIndent(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def get_textIndent(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def put_lineHeight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_lineHeight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def put_marginTop(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def get_marginTop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def put_marginRight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def get_marginRight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def put_marginBottom(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def get_marginBottom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def put_marginLeft(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def get_marginLeft(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def put_margin(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def get_margin(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def put_paddingTop(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def get_paddingTop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def put_paddingRight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def get_paddingRight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def put_paddingBottom(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def get_paddingBottom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def put_paddingLeft(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def get_paddingLeft(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def put_padding(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def get_padding(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def put_border(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def get_border(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def put_borderTop(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def get_borderTop(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def put_borderRight(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def get_borderRight(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def put_borderBottom(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def get_borderBottom(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def put_borderLeft(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def get_borderLeft(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def put_borderColor(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def get_borderColor(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def put_borderTopColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def get_borderTopColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def put_borderRightColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def get_borderRightColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def put_borderBottomColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def get_borderBottomColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def put_borderLeftColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def get_borderLeftColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def put_borderWidth(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def get_borderWidth(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(105)
    def put_borderTopWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(106)
    def get_borderTopWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(107)
    def put_borderRightWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(108)
    def get_borderRightWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(109)
    def put_borderBottomWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(110)
    def get_borderBottomWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(111)
    def put_borderLeftWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(112)
    def get_borderLeftWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(113)
    def put_borderStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(114)
    def get_borderStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(115)
    def put_borderTopStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(116)
    def get_borderTopStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(117)
    def put_borderRightStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(118)
    def get_borderRightStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(119)
    def put_borderBottomStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(120)
    def get_borderBottomStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(121)
    def put_borderLeftStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(122)
    def get_borderLeftStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(123)
    def put_width(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(124)
    def get_width(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(125)
    def put_height(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(126)
    def get_height(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(127)
    def put_styleFloat(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(128)
    def get_styleFloat(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(129)
    def put_clear(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(130)
    def get_clear(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(131)
    def put_display(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(132)
    def get_display(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(133)
    def put_visibility(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(134)
    def get_visibility(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(135)
    def put_listStyleType(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(136)
    def get_listStyleType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(137)
    def put_listStylePosition(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(138)
    def get_listStylePosition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(139)
    def put_listStyleImage(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(140)
    def get_listStyleImage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(141)
    def put_listStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(142)
    def get_listStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(143)
    def put_whiteSpace(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(144)
    def get_whiteSpace(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(145)
    def put_top(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(146)
    def get_top(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(147)
    def put_left(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(148)
    def get_left(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(149)
    def get_position(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(150)
    def put_zIndex(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(151)
    def get_zIndex(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(152)
    def put_overflow(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(153)
    def get_overflow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(154)
    def put_pageBreakBefore(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(155)
    def get_pageBreakBefore(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(156)
    def put_pageBreakAfter(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(157)
    def get_pageBreakAfter(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(158)
    def put_cssText(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(159)
    def get_cssText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(160)
    def put_pixelTop(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(161)
    def get_pixelTop(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(162)
    def put_pixelLeft(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(163)
    def get_pixelLeft(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(164)
    def put_pixelWidth(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(165)
    def get_pixelWidth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(166)
    def put_pixelHeight(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(167)
    def get_pixelHeight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(168)
    def put_posTop(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(169)
    def get_posTop(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(170)
    def put_posLeft(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(171)
    def get_posLeft(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(172)
    def put_posWidth(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(173)
    def get_posWidth(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(174)
    def put_posHeight(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(175)
    def get_posHeight(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(176)
    def put_cursor(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(177)
    def get_cursor(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(178)
    def put_clip(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(179)
    def get_clip(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(180)
    def put_filter(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(181)
    def get_filter(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(182)
    def setAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, AttributeValue: win32more.Windows.Win32.System.Variant.VARIANT, lFlags: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(183)
    def getAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, lFlags: Int32, AttributeValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(184)
    def removeAttribute(self, strAttributeName: win32more.Windows.Win32.Foundation.BSTR, lFlags: Int32, pfSuccess: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(185)
    def toString(self, String: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyle2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4a2-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_tableLayout(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_tableLayout(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_borderCollapse(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_borderCollapse(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_direction(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_direction(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_behavior(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_behavior(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def setExpression(self, propname: win32more.Windows.Win32.Foundation.BSTR, expression: win32more.Windows.Win32.Foundation.BSTR, language: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def getExpression(self, propname: win32more.Windows.Win32.Foundation.BSTR, expression: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def removeExpression(self, propname: win32more.Windows.Win32.Foundation.BSTR, pfSuccess: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_position(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_position(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_unicodeBidi(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_unicodeBidi(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_bottom(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_bottom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_right(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_right(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_pixelBottom(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_pixelBottom(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_pixelRight(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_pixelRight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def put_posBottom(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_posBottom(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def put_posRight(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_posRight(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def put_imeMode(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_imeMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def put_rubyAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_rubyAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def put_rubyPosition(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_rubyPosition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def put_rubyOverhang(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_rubyOverhang(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def put_layoutGridChar(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def get_layoutGridChar(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def put_layoutGridLine(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_layoutGridLine(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def put_layoutGridMode(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def get_layoutGridMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def put_layoutGridType(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def get_layoutGridType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def put_layoutGrid(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def get_layoutGrid(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def put_wordBreak(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def get_wordBreak(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def put_lineBreak(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def get_lineBreak(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def put_textJustify(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def get_textJustify(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def put_textJustifyTrim(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def get_textJustifyTrim(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def put_textKashida(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def get_textKashida(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def put_textAutospace(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def get_textAutospace(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def put_overflowX(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def get_overflowX(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def put_overflowY(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def get_overflowY(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def put_accelerator(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def get_accelerator(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyle3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f656-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_layoutFlow(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_layoutFlow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_zoom(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_zoom(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_wordWrap(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_wordWrap(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_textUnderlinePosition(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_textUnderlinePosition(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_scrollbarBaseColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_scrollbarBaseColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_scrollbarFaceColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_scrollbarFaceColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_scrollbar3dLightColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_scrollbar3dLightColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_scrollbarShadowColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_scrollbarShadowColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_scrollbarHighlightColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_scrollbarHighlightColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_scrollbarDarkShadowColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_scrollbarDarkShadowColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_scrollbarArrowColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_scrollbarArrowColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_scrollbarTrackColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_scrollbarTrackColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_writingMode(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_writingMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_textAlignLast(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_textAlignLast(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_textKashidaSpace(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_textKashidaSpace(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyle4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f816-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_textOverflow(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_textOverflow(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_minHeight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_minHeight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyle5(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f33a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_msInterpolationMode(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_msInterpolationMode(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_maxHeight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_maxHeight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_minWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_minWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_maxWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_maxWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyle6(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510480-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_content(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_content(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_captionSide(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_captionSide(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_counterIncrement(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_counterIncrement(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_counterReset(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_counterReset(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_outline(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_outline(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_outlineWidth(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_outlineWidth(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_outlineStyle(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_outlineStyle(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_outlineColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_outlineColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_boxSizing(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_boxSizing(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_borderSpacing(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_borderSpacing(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_orphans(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_orphans(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_widows(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_widows(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_pageBreakInside(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_pageBreakInside(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_emptyCells(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_emptyCells(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_msBlockProgression(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_msBlockProgression(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_quotes(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_quotes(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f375-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_type(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_readyState(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_onreadystatechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_onreadystatechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_onload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_onload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_onerror(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_onerror(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_styleSheet(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheet)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_disabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_disabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_media(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_media(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051072a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_sheet(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheet)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleEnabled(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104c2-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def msGetPropertyEnabled(self, name: win32more.Windows.Win32.Foundation.BSTR, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def msPutPropertyEnabled(self, name: win32more.Windows.Win32.Foundation.BSTR, b: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleFontFace(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f3d5-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_fontsrc(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_fontsrc(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleFontFace2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106ec-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_style(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLRuleStyle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleMedia(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051074b-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def matchMedium(self, mediaQuery: win32more.Windows.Win32.Foundation.BSTR, matches: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleSheet(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2e3-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_title(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_title(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_parentStyleSheet(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheet)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_owningElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_disabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_disabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_readOnly(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_imports(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheetsCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_href(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_href(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_id(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def addImport(self, bstrURL: win32more.Windows.Win32.Foundation.BSTR, lIndex: Int32, plIndex: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def addRule(self, bstrSelector: win32more.Windows.Win32.Foundation.BSTR, bstrStyle: win32more.Windows.Win32.Foundation.BSTR, lIndex: Int32, plNewIndex: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def removeImport(self, lIndex: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def removeRule(self, lIndex: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_media(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_media(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_cssText(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_cssText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_rules(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheetRulesCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleSheet2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f3d1-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_pages(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheetPagesCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def addPageRule(self, bstrSelector: win32more.Windows.Win32.Foundation.BSTR, bstrStyle: win32more.Windows.Win32.Foundation.BSTR, lIndex: Int32, plNewIndex: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleSheet3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510496-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_href(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_href(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_isAlternate(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_isPrefAlternate(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleSheet4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106f4-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_href(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_title(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_ownerNode(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_ownerRule(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLCSSRule)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_cssRules(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheetRulesCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_media(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def insertRule(self, bstrRule: win32more.Windows.Win32.Foundation.BSTR, lIndex: Int32, plNewIndex: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def deleteRule(self, lIndex: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleSheetPage(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f7ee-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_selector(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_pseudoClass(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleSheetPage2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106ed-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_selectorText(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_selectorText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_style(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLRuleStyle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleSheetPagesCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f7f0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def item(self, index: Int32, ppHTMLStyleSheetPage: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheetPage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleSheetRule(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f357-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_selectorText(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_selectorText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_style(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLRuleStyle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_readOnly(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleSheetRule2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106fd-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_selectorText(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_selectorText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleSheetRuleApplied(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104c1-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_msSpecificity(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def msGetSpecificity(self, index: Int32, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleSheetRulesAppliedCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104c0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def item(self, index: Int32, ppHTMLStyleSheetRule: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheetRule)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def propertyAppliedBy(self, name: win32more.Windows.Win32.Foundation.BSTR, ppRule: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheetRule)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def propertyAppliedTrace(self, name: win32more.Windows.Win32.Foundation.BSTR, index: Int32, ppRule: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheetRule)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def propertyAppliedTraceLength(self, name: win32more.Windows.Win32.Foundation.BSTR, pLength: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleSheetRulesCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2e5-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def item(self, index: Int32, ppHTMLStyleSheetRule: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheetRule)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleSheetRulesCollection2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106e8-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def item(self, index: Int32, ppHTMLCSSRule: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLCSSRule)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleSheetsCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f37e-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__newEnum(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def item(self, pvarIndex: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pvarResult: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLStyleSheetsCollection2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106e7-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def item(self, index: Int32, pvarResult: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLSubmitData(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f645-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def appendNameValuePair(self, name: win32more.Windows.Win32.Foundation.BSTR, value: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def appendNameFilePair(self, name: win32more.Windows.Win32.Foundation.BSTR, filename: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def appendItemSeparator(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTable(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f21e-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_cols(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_cols(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_border(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_border(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_frame(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_frame(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_rules(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_rules(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_cellSpacing(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_cellSpacing(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_cellPadding(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_cellPadding(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_background(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_background(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_bgColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_bgColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_borderColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_borderColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_borderColorLight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_borderColorLight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_borderColorDark(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_borderColorDark(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_rows(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_width(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_width(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_height(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_height(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_dataPageSize(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_dataPageSize(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def nextPage(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def previousPage(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_tHead(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTableSection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_tFoot(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTableSection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def get_tBodies(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_caption(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTableCaption)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def createTHead(self, head: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def deleteTHead(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def createTFoot(self, foot: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def deleteTFoot(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def createCaption(self, caption: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTableCaption)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def deleteCaption(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def insertRow(self, index: Int32, row: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def deleteRow(self, index: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def get_readyState(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def put_onreadystatechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def get_onreadystatechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTable2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4ad-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def firstPage(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def lastPage(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_cells(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def moveRow(self, indexFrom: Int32, indexTo: Int32, row: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTable3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f829-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_summary(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_summary(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTable4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106c2-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_tHead(self, v: win32more.Windows.Win32.Web.MsHtml.IHTMLTableSection) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_tHead(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTableSection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_tFoot(self, v: win32more.Windows.Win32.Web.MsHtml.IHTMLTableSection) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_tFoot(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTableSection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_caption(self, v: win32more.Windows.Win32.Web.MsHtml.IHTMLTableCaption) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_caption(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTableCaption)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def insertRow(self, index: Int32, row: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def deleteRow(self, index: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def createTBody(self, tbody: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTableSection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTableCaption(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2eb-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_vAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_vAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTableCell(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f23d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_rowSpan(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_rowSpan(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_colSpan(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_colSpan(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_vAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_vAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_bgColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_bgColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_noWrap(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_noWrap(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_background(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_background(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_borderColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_borderColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_borderColorLight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_borderColorLight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_borderColorDark(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_borderColorDark(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_width(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_width(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_height(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_height(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_cellIndex(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTableCell2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f82d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_abbr(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_abbr(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_axis(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_axis(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_ch(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_ch(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_chOff(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_chOff(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_headers(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_headers(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_scope(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_scope(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTableCell3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106c7-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_ch(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ch(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_chOff(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_chOff(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTableCol(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f23a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_span(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_span(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_width(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_width(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_vAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_vAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTableCol2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f82a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_ch(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ch(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_chOff(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_chOff(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTableCol3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106c4-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_ch(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ch(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_chOff(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_chOff(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTableRow(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f23c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_vAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_vAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_bgColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_bgColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_borderColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_borderColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_borderColorLight(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_borderColorLight(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_borderColorDark(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_borderColorDark(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_rowIndex(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_sectionRowIndex(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_cells(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def insertCell(self, index: Int32, row: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def deleteCell(self, index: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTableRow2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4a1-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_height(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_height(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTableRow3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f82c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_ch(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ch(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_chOff(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_chOff(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTableRow4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106c6-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_ch(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ch(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_chOff(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_chOff(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def insertCell(self, index: Int32, row: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def deleteCell(self, index: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTableRowMetrics(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f413-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_clientHeight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_clientWidth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_clientTop(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_clientLeft(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTableSection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f23b-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_align(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_align(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_vAlign(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_vAlign(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_bgColor(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_bgColor(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_rows(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def insertRow(self, index: Int32, row: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def deleteRow(self, index: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTableSection2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5c7-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def moveRow(self, indexFrom: Int32, indexTo: Int32, row: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTableSection3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f82b-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_ch(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ch(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_chOff(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_chOff(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTableSection4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305106c5-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_ch(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ch(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_chOff(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_chOff(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def insertRow(self, index: Int32, row: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def deleteRow(self, index: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTextAreaElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2aa-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_value(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_value(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_status(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_status(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_disabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_disabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_form(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFormElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_defaultValue(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_defaultValue(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def select(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_onchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_onchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_onselect(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_onselect(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_readOnly(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_readOnly(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_rows(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_rows(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_cols(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_cols(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def put_wrap(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_wrap(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def createTextRange(self, range: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTxtRange)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTextAreaElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f2d3-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_selectionStart(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_selectionStart(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_selectionEnd(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_selectionEnd(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def setSelectionRange(self, start: Int32, end: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTextContainer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f230-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def createControlRange(self, range: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_scrollHeight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_scrollWidth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_scrollTop(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_scrollTop(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_scrollLeft(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_scrollLeft(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_onscroll(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_onscroll(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTextElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f218-98b5-11cf-bb82-00aa00bdce0b}')
class IHTMLTextRangeMetrics(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f40b-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_offsetTop(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_offsetLeft(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_boundingTop(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_boundingLeft(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_boundingWidth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_boundingHeight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTextRangeMetrics2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4a6-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def getClientRects(self, pRectCol: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLRectCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def getBoundingClientRect(self, pRect: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLRect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTimeRanges(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510705-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def start(self, index: Int32, startTime: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def end(self, index: Int32, endTime: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTimeRanges2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051080b-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def startDouble(self, index: Int32, startTime: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def endDouble(self, index: Int32, endTime: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTitleElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f322-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_text(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_text(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTxtRange(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f220-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_htmlText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_text(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_text(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def parentElement(self, parent: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def duplicate(self, Duplicate: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLTxtRange)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def inRange(self, Range: win32more.Windows.Win32.Web.MsHtml.IHTMLTxtRange, InRange: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def isEqual(self, Range: win32more.Windows.Win32.Web.MsHtml.IHTMLTxtRange, IsEqual: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def scrollIntoView(self, fStart: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def collapse(self, Start: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def expand(self, Unit: win32more.Windows.Win32.Foundation.BSTR, Success: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def move(self, Unit: win32more.Windows.Win32.Foundation.BSTR, Count: Int32, ActualCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def moveStart(self, Unit: win32more.Windows.Win32.Foundation.BSTR, Count: Int32, ActualCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def moveEnd(self, Unit: win32more.Windows.Win32.Foundation.BSTR, Count: Int32, ActualCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def select(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def pasteHTML(self, html: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def moveToElementText(self, element: win32more.Windows.Win32.Web.MsHtml.IHTMLElement) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def setEndPoint(self, how: win32more.Windows.Win32.Foundation.BSTR, SourceRange: win32more.Windows.Win32.Web.MsHtml.IHTMLTxtRange) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def compareEndPoints(self, how: win32more.Windows.Win32.Foundation.BSTR, SourceRange: win32more.Windows.Win32.Web.MsHtml.IHTMLTxtRange, ret: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def findText(self, String: win32more.Windows.Win32.Foundation.BSTR, count: Int32, Flags: Int32, Success: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def moveToPoint(self, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def getBookmark(self, Boolmark: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def moveToBookmark(self, Bookmark: win32more.Windows.Win32.Foundation.BSTR, Success: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def queryCommandSupported(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def queryCommandEnabled(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def queryCommandState(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def queryCommandIndeterm(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def queryCommandText(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pcmdText: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def queryCommandValue(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pcmdValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def execCommand(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, showUI: win32more.Windows.Win32.Foundation.VARIANT_BOOL, value: win32more.Windows.Win32.System.Variant.VARIANT, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def execCommandShowHelp(self, cmdID: win32more.Windows.Win32.Foundation.BSTR, pfRet: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLTxtRangeCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f7ed-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__newEnum(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def item(self, pvarIndex: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pvarResult: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLUListElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f1dd-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_compact(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_compact(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_type(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLUniqueName(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4d0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_uniqueNumber(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_uniqueID(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLUnknownElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f209-98b5-11cf-bb82-00aa00bdce0b}')
class IHTMLUrnCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f5e2-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def item(self, index: Int32, ppUrn: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLVideoElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510709-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_width(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_width(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_height(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_height(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_videoWidth(self, p: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_videoHeight(self, p: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_poster(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_poster(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLWindow2(ComPtr):
    extends: win32more.Windows.Win32.Web.MsHtml.IHTMLFramesCollection2
    _iid_ = Guid('{332c4427-26cb-11d0-b483-00c04fd90119}')
    @commethod(9)
    def get_frames(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFramesCollection2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_defaultStatus(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_defaultStatus(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_status(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_status(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def setTimeout(self, expression: win32more.Windows.Win32.Foundation.BSTR, msec: Int32, language: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), timerID: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def clearTimeout(self, timerID: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def alert(self, message: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def confirm(self, message: win32more.Windows.Win32.Foundation.BSTR, confirmed: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def prompt(self, message: win32more.Windows.Win32.Foundation.BSTR, defstr: win32more.Windows.Win32.Foundation.BSTR, textdata: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_Image(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLImageElementFactory)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_location(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLLocation)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_history(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IOmHistory)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def close(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_opener(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_opener(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_navigator(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IOmNavigator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_name(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_name(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_parent(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def open(self, url: win32more.Windows.Win32.Foundation.BSTR, name: win32more.Windows.Win32.Foundation.BSTR, features: win32more.Windows.Win32.Foundation.BSTR, replace: win32more.Windows.Win32.Foundation.VARIANT_BOOL, pomWindowResult: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_self(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_top(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_window(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def navigate(self, url: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def put_onfocus(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_onfocus(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def put_onblur(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_onblur(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def put_onload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_onload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def put_onbeforeunload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_onbeforeunload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def put_onunload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def get_onunload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def put_onhelp(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_onhelp(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def put_onerror(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def get_onerror(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def put_onresize(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def get_onresize(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def put_onscroll(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def get_onscroll(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_document(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDocument2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def get_event(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLEventObj)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get__newEnum(self, p: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def showModalDialog(self, dialog: win32more.Windows.Win32.Foundation.BSTR, varArgIn: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), varOptions: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), varArgOut: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def showHelp(self, helpURL: win32more.Windows.Win32.Foundation.BSTR, helpArg: win32more.Windows.Win32.System.Variant.VARIANT, features: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def get_screen(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLScreen)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def get_Option(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLOptionElementFactory)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def focus(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def get_closed(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def blur(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def scroll(self, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def get_clientInformation(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IOmNavigator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def setInterval(self, expression: win32more.Windows.Win32.Foundation.BSTR, msec: Int32, language: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), timerID: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def clearInterval(self, timerID: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def put_offscreenBuffering(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def get_offscreenBuffering(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def execScript(self, code: win32more.Windows.Win32.Foundation.BSTR, language: win32more.Windows.Win32.Foundation.BSTR, pvarRet: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def toString(self, String: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def scrollBy(self, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def scrollTo(self, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def moveTo(self, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def moveBy(self, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def resizeTo(self, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def resizeBy(self, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def get_external(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLWindow3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f4ae-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_screenLeft(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_screenTop(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def attachEvent(self, event: win32more.Windows.Win32.Foundation.BSTR, pDisp: win32more.Windows.Win32.System.Com.IDispatch, pfResult: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def detachEvent(self, event: win32more.Windows.Win32.Foundation.BSTR, pDisp: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def setTimeout(self, expression: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), msec: Int32, language: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), timerID: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def setInterval(self, expression: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), msec: Int32, language: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), timerID: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def print(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_onbeforeprint(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_onbeforeprint(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_onafterprint(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_onafterprint(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_clipboardData(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDataTransfer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def showModelessDialog(self, url: win32more.Windows.Win32.Foundation.BSTR, varArgIn: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), options: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pDialog: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLWindow4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f6cf-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def createPopup(self, varArgIn: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppPopup: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_frameElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLFrameBase)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLWindow5(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051040e-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_XMLHttpRequest(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_XMLHttpRequest(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLWindow6(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510453-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_XDomainRequest(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_XDomainRequest(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_sessionStorage(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStorage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_localStorage(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStorage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_onhashchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_onhashchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_maxConnectionsPerServer(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def postMessage(self, msg: win32more.Windows.Win32.Foundation.BSTR, targetOrigin: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def toStaticHTML(self, bstrHTML: win32more.Windows.Win32.Foundation.BSTR, pbstrStaticHTML: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_onmessage(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_onmessage(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def msWriteProfilerMark(self, bstrProfilerMarkName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLWindow7(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104b7-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def getSelection(self, ppIHTMLSelection: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLSelection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def getComputedStyle(self, varArgIn: win32more.Windows.Win32.Web.MsHtml.IHTMLDOMNode, bstrPseudoElt: win32more.Windows.Win32.Foundation.BSTR, ppComputedStyle: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLCSSStyleDeclaration)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_styleMedia(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleMedia)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_performance(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_performance(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_innerWidth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_innerHeight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_pageXOffset(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_pageYOffset(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_screenX(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_screenY(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_outerWidth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_outerHeight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_onabort(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_onabort(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_oncanplay(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_oncanplay(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_oncanplaythrough(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_oncanplaythrough(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_onchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_onchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_onclick(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_onclick(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def put_oncontextmenu(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_oncontextmenu(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def put_ondblclick(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_ondblclick(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def put_ondrag(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_ondrag(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def put_ondragend(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_ondragend(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def put_ondragenter(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_ondragenter(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def put_ondragleave(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_ondragleave(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def put_ondragover(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def get_ondragover(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def put_ondragstart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_ondragstart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def put_ondrop(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def get_ondrop(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def put_ondurationchange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def get_ondurationchange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def put_onfocusin(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def get_onfocusin(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def put_onfocusout(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def get_onfocusout(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def put_oninput(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def get_oninput(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def put_onemptied(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def get_onemptied(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def put_onended(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def get_onended(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def put_onkeydown(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def get_onkeydown(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def put_onkeypress(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def get_onkeypress(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def put_onkeyup(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def get_onkeyup(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def put_onloadeddata(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def get_onloadeddata(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def put_onloadedmetadata(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def get_onloadedmetadata(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def put_onloadstart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def get_onloadstart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def put_onmousedown(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def get_onmousedown(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def put_onmouseenter(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def get_onmouseenter(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def put_onmouseleave(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def get_onmouseleave(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def put_onmousemove(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def get_onmousemove(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def put_onmouseout(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def get_onmouseout(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def put_onmouseover(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def get_onmouseover(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def put_onmouseup(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def get_onmouseup(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def put_onmousewheel(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def get_onmousewheel(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def put_onoffline(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def get_onoffline(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def put_ononline(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def get_ononline(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def put_onprogress(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def get_onprogress(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def put_onratechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def get_onratechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def put_onreadystatechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def get_onreadystatechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def put_onreset(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def get_onreset(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def put_onseeked(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def get_onseeked(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def put_onseeking(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def get_onseeking(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def put_onselect(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(105)
    def get_onselect(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(106)
    def put_onstalled(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(107)
    def get_onstalled(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(108)
    def put_onstorage(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(109)
    def get_onstorage(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(110)
    def put_onsubmit(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(111)
    def get_onsubmit(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(112)
    def put_onsuspend(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(113)
    def get_onsuspend(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(114)
    def put_ontimeupdate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(115)
    def get_ontimeupdate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(116)
    def put_onpause(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(117)
    def get_onpause(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(118)
    def put_onplay(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(119)
    def get_onplay(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(120)
    def put_onplaying(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(121)
    def get_onplaying(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(122)
    def put_onvolumechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(123)
    def get_onvolumechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(124)
    def put_onwaiting(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(125)
    def get_onwaiting(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLWindow8(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305107ab-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_onmspointerdown(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_onmspointerdown(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_onmspointermove(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_onmspointermove(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_onmspointerup(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_onmspointerup(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_onmspointerover(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_onmspointerover(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_onmspointerout(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_onmspointerout(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_onmspointercancel(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_onmspointercancel(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_onmspointerhover(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_onmspointerhover(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_onmsgesturestart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_onmsgesturestart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_onmsgesturechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_onmsgesturechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_onmsgestureend(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_onmsgestureend(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_onmsgesturehold(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_onmsgesturehold(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_onmsgesturetap(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_onmsgesturetap(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_onmsgesturedoubletap(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_onmsgesturedoubletap(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_onmsinertiastart(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_onmsinertiastart(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_applicationCache(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLApplicationCache)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def put_onpopstate(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_onpopstate(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLXDomainRequest(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510454-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_responseText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_timeout(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_timeout(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_contentType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_onprogress(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_onprogress(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_onerror(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_onerror(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_ontimeout(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_ontimeout(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_onload(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_onload(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def abort(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def open(self, bstrMethod: win32more.Windows.Win32.Foundation.BSTR, bstrUrl: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def send(self, varBody: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLXDomainRequestFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510456-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def create(self, __MIDL__IHTMLXDomainRequestFactory0000: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLXDomainRequest)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLXMLHttpRequest(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051040a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_readyState(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_responseBody(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_responseText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_responseXML(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_status(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_statusText(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_onreadystatechange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_onreadystatechange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def abort(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def open(self, bstrMethod: win32more.Windows.Win32.Foundation.BSTR, bstrUrl: win32more.Windows.Win32.Foundation.BSTR, varAsync: win32more.Windows.Win32.System.Variant.VARIANT, varUser: win32more.Windows.Win32.System.Variant.VARIANT, varPassword: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def send(self, varBody: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def getAllResponseHeaders(self, __MIDL__IHTMLXMLHttpRequest0000: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def getResponseHeader(self, bstrHeader: win32more.Windows.Win32.Foundation.BSTR, __MIDL__IHTMLXMLHttpRequest0001: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def setRequestHeader(self, bstrHeader: win32more.Windows.Win32.Foundation.BSTR, bstrValue: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLXMLHttpRequest2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510482-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_timeout(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_timeout(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_ontimeout(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_ontimeout(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHTMLXMLHttpRequestFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051040c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def create(self, __MIDL__IHTMLXMLHttpRequestFactory0000: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLXMLHttpRequest)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHighlightRenderingServices(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f606-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def AddSegment(self, pDispPointerStart: win32more.Windows.Win32.Web.MsHtml.IDisplayPointer, pDispPointerEnd: win32more.Windows.Win32.Web.MsHtml.IDisplayPointer, pIRenderStyle: win32more.Windows.Win32.Web.MsHtml.IHTMLRenderStyle, ppISegment: POINTER(win32more.Windows.Win32.Web.MsHtml.IHighlightSegment)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MoveSegmentToPointers(self, pISegment: win32more.Windows.Win32.Web.MsHtml.IHighlightSegment, pDispPointerStart: win32more.Windows.Win32.Web.MsHtml.IDisplayPointer, pDispPointerEnd: win32more.Windows.Win32.Web.MsHtml.IDisplayPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RemoveSegment(self, pISegment: win32more.Windows.Win32.Web.MsHtml.IHighlightSegment) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHighlightSegment(ComPtr):
    extends: win32more.Windows.Win32.Web.MsHtml.ISegment
    _iid_ = Guid('{3050f690-98b5-11cf-bb82-00aa00bdce0b}')
class IHostBehaviorInit(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f842-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def PopulateNamespaceTable(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHostDialogHelper(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{53dec138-a51e-11d2-861e-00c04fa35c89}')
    @commethod(3)
    def ShowHTMLDialog(self, hwndParent: win32more.Windows.Win32.Foundation.HWND, pMk: win32more.Windows.Win32.System.Com.IMoniker, pvarArgIn: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pchOptions: win32more.Windows.Win32.Foundation.PWSTR, pvarArgOut: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), punkHost: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IHtmlDlgSafeHelper(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f81a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def choosecolordlg(self, initColor: win32more.Windows.Win32.System.Variant.VARIANT, rgbColor: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def getCharset(self, fontName: win32more.Windows.Win32.Foundation.BSTR, charset: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Fonts(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_BlockFormats(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IICCSVGColor(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104d6-98b5-11cf-bb82-00aa00bdce0b}')
class IIE70DispatchEx(ComPtr):
    extends: win32more.Windows.Win32.System.Ole.IDispatchEx
    _iid_ = Guid('{3051046b-98b5-11cf-bb82-00aa00bdce0b}')
class IIE80DispatchEx(ComPtr):
    extends: win32more.Windows.Win32.System.Ole.IDispatchEx
    _iid_ = Guid('{3051046c-98b5-11cf-bb82-00aa00bdce0b}')
class IIMEServices(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f6ca-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetActiveIMM(self, ppActiveIMM: POINTER(win32more.Windows.Win32.UI.Input.Ime.IActiveIMMApp)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ILineInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f7e2-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def get_x(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_baseLine(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_textDescent(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def get_textHeight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def get_lineDirection(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMarkupContainer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f5f9-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def OwningDoc(self, ppDoc: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDocument2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMarkupContainer2(ComPtr):
    extends: win32more.Windows.Win32.Web.MsHtml.IMarkupContainer
    _iid_ = Guid('{3050f648-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(4)
    def CreateChangeLog(self, pChangeSink: win32more.Windows.Win32.Web.MsHtml.IHTMLChangeSink, ppChangeLog: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLChangeLog), fForward: win32more.Windows.Win32.Foundation.BOOL, fBackward: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RegisterForDirtyRange(self, pChangeSink: win32more.Windows.Win32.Web.MsHtml.IHTMLChangeSink, pdwCookie: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def UnRegisterForDirtyRange(self, dwCookie: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetAndClearDirtyRange(self, dwCookie: UInt32, pIPointerBegin: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pIPointerEnd: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetVersionNumber(self) -> Int32: ...
    @commethod(9)
    def GetMasterElement(self, ppElementMaster: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMarkupPointer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f49f-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def OwningDoc(self, ppDoc: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDocument2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Gravity(self, pGravity: POINTER(win32more.Windows.Win32.Web.MsHtml.POINTER_GRAVITY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetGravity(self, Gravity: win32more.Windows.Win32.Web.MsHtml.POINTER_GRAVITY) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Cling(self, pfCling: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetCling(self, fCLing: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Unposition(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def IsPositioned(self, pfPositioned: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetContainer(self, ppContainer: POINTER(win32more.Windows.Win32.Web.MsHtml.IMarkupContainer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def MoveAdjacentToElement(self, pElement: win32more.Windows.Win32.Web.MsHtml.IHTMLElement, eAdj: win32more.Windows.Win32.Web.MsHtml.ELEMENT_ADJACENCY) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def MoveToPointer(self, pPointer: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def MoveToContainer(self, pContainer: win32more.Windows.Win32.Web.MsHtml.IMarkupContainer, fAtStart: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Left(self, fMove: win32more.Windows.Win32.Foundation.BOOL, pContext: POINTER(win32more.Windows.Win32.Web.MsHtml.MARKUP_CONTEXT_TYPE), ppElement: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement), pcch: POINTER(Int32), pchText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def Right(self, fMove: win32more.Windows.Win32.Foundation.BOOL, pContext: POINTER(win32more.Windows.Win32.Web.MsHtml.MARKUP_CONTEXT_TYPE), ppElement: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement), pcch: POINTER(Int32), pchText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def CurrentScope(self, ppElemCurrent: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def IsLeftOf(self, pPointerThat: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pfResult: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def IsLeftOfOrEqualTo(self, pPointerThat: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pfResult: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def IsRightOf(self, pPointerThat: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pfResult: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def IsRightOfOrEqualTo(self, pPointerThat: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pfResult: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def IsEqualTo(self, pPointerThat: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pfAreEqual: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def MoveUnit(self, muAction: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def FindText(self, pchFindText: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, pIEndMatch: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pIEndSearch: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMarkupPointer2(ComPtr):
    extends: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer
    _iid_ = Guid('{3050f675-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(24)
    def IsAtWordBreak(self, pfAtBreak: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def GetMarkupPosition(self, plMP: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def MoveToMarkupPosition(self, pContainer: win32more.Windows.Win32.Web.MsHtml.IMarkupContainer, lMP: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def MoveUnitBounded(self, muAction: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION, pIBoundary: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def IsInsideURL(self, pRight: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pfResult: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def MoveToContent(self, pIElement: win32more.Windows.Win32.Web.MsHtml.IHTMLElement, fAtStart: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMarkupServices(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f4a0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def CreateMarkupPointer(self, ppPointer: POINTER(win32more.Windows.Win32.Web.MsHtml.IMarkupPointer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateMarkupContainer(self, ppMarkupContainer: POINTER(win32more.Windows.Win32.Web.MsHtml.IMarkupContainer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateElement(self, tagID: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID, pchAttributes: win32more.Windows.Win32.Foundation.PWSTR, ppElement: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CloneElement(self, pElemCloneThis: win32more.Windows.Win32.Web.MsHtml.IHTMLElement, ppElementTheClone: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def InsertElement(self, pElementInsert: win32more.Windows.Win32.Web.MsHtml.IHTMLElement, pPointerStart: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pPointerFinish: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def RemoveElement(self, pElementRemove: win32more.Windows.Win32.Web.MsHtml.IHTMLElement) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Remove(self, pPointerStart: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pPointerFinish: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def Copy(self, pPointerSourceStart: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pPointerSourceFinish: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pPointerTarget: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Move(self, pPointerSourceStart: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pPointerSourceFinish: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pPointerTarget: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def InsertText(self, pchText: win32more.Windows.Win32.Foundation.PWSTR, cch: Int32, pPointerTarget: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def ParseString(self, pchHTML: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, ppContainerResult: POINTER(win32more.Windows.Win32.Web.MsHtml.IMarkupContainer), ppPointerStart: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, ppPointerFinish: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def ParseGlobal(self, hglobalHTML: win32more.Windows.Win32.Foundation.HGLOBAL, dwFlags: UInt32, ppContainerResult: POINTER(win32more.Windows.Win32.Web.MsHtml.IMarkupContainer), pPointerStart: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pPointerFinish: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def IsScopedElement(self, pElement: win32more.Windows.Win32.Web.MsHtml.IHTMLElement, pfScoped: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetElementTagId(self, pElement: win32more.Windows.Win32.Web.MsHtml.IHTMLElement, ptagId: POINTER(win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetTagIDForName(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, ptagId: POINTER(win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetNameForTagID(self, tagId: win32more.Windows.Win32.Web.MsHtml.ELEMENT_TAG_ID, pbstrName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def MovePointersToRange(self, pIRange: win32more.Windows.Win32.Web.MsHtml.IHTMLTxtRange, pPointerStart: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pPointerFinish: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def MoveRangeToPointers(self, pPointerStart: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pPointerFinish: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pIRange: win32more.Windows.Win32.Web.MsHtml.IHTMLTxtRange) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def BeginUndoUnit(self, pchTitle: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def EndUndoUnit(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMarkupServices2(ComPtr):
    extends: win32more.Windows.Win32.Web.MsHtml.IMarkupServices
    _iid_ = Guid('{3050f682-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(23)
    def ParseGlobalEx(self, hglobalHTML: win32more.Windows.Win32.Foundation.HGLOBAL, dwFlags: UInt32, pContext: win32more.Windows.Win32.Web.MsHtml.IMarkupContainer, ppContainerResult: POINTER(win32more.Windows.Win32.Web.MsHtml.IMarkupContainer), pPointerStart: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pPointerFinish: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def ValidateElements(self, pPointerStart: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pPointerFinish: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pPointerTarget: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pPointerStatus: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, ppElemFailBottom: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement), ppElemFailTop: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def SaveSegmentsToClipboard(self, pSegmentList: win32more.Windows.Win32.Web.MsHtml.ISegmentList, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMarkupTextFrags(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f5fa-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetTextFragCount(self, pcFrags: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetTextFrag(self, iFrag: Int32, pbstrFrag: POINTER(win32more.Windows.Win32.Foundation.BSTR), pPointerFrag: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RemoveTextFrag(self, iFrag: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def InsertTextFrag(self, iFrag: Int32, bstrInsert: win32more.Windows.Win32.Foundation.BSTR, pPointerInsert: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def FindTextFragFromMarkupPointer(self, pPointerFind: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, piFrag: POINTER(Int32), pfFragFound: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INavigatorDoNotTrack(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510804-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_msDoNotTrack(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INavigatorGeolocation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305107cf-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_geolocation(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IWebGeolocation)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOmHistory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{feceaaa2-8405-11cf-8ba1-00aa00476da6}')
    @commethod(7)
    def get_length(self, p: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def back(self, pvargdistance: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def forward(self, pvargdistance: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def go(self, pvargdistance: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOmNavigator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{feceaaa5-8405-11cf-8ba1-00aa00476da6}')
    @commethod(7)
    def get_appCodeName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_appName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_appVersion(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_userAgent(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def javaEnabled(self, enabled: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def taintEnabled(self, enabled: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_mimeTypes(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLMimeTypesCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_plugins(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLPluginsCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_cookieEnabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_opsProfile(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLOpsProfile)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def toString(self, string: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_cpuClass(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_systemLanguage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_browserLanguage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_userLanguage(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_platform(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_appMinorVersion(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_connectionSpeed(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_onLine(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_userProfile(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLOpsProfile)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintManagerTemplatePrinter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f633be14-9eff-4c4d-929e-05717b21b3e6}')
    @commethod(7)
    def startPrint(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def drawPreviewPage(self, pElemDisp: win32more.Windows.Win32.System.Com.IDispatch, nPage: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def setPageCount(self, nPage: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def invalidatePreview(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def getPrintTaskOptionValue(self, bstrKey: win32more.Windows.Win32.Foundation.BSTR, pvarin: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def endPrint(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintManagerTemplatePrinter2(ComPtr):
    extends: win32more.Windows.Win32.Web.MsHtml.IPrintManagerTemplatePrinter
    _iid_ = Guid('{c6403497-7493-4f09-8016-54b03e9bda69}')
    @commethod(13)
    def get_showHeaderFooter(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_shrinkToFit(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_percentScale(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRangeException(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051072d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_code(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_code(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_message(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRulesApplied(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104bf-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_element(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_inlineStyles(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_appliedRules(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLStyleSheetRulesAppliedCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def propertyIsInline(self, name: win32more.Windows.Win32.Foundation.BSTR, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def propertyIsInheritable(self, name: win32more.Windows.Win32.Foundation.BSTR, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def hasInheritableProperty(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRulesAppliedCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104be-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def item(self, index: Int32, ppRulesApplied: POINTER(win32more.Windows.Win32.Web.MsHtml.IRulesApplied)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_element(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def propertyInheritedFrom(self, name: win32more.Windows.Win32.Foundation.BSTR, ppRulesApplied: POINTER(win32more.Windows.Win32.Web.MsHtml.IRulesApplied)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_propertyCount(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def property(self, index: Int32, pbstrProperty: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def propertyInheritedTrace(self, name: win32more.Windows.Win32.Foundation.BSTR, index: Int32, ppRulesApplied: POINTER(win32more.Windows.Win32.Web.MsHtml.IRulesApplied)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def propertyInheritedTraceLength(self, name: win32more.Windows.Win32.Foundation.BSTR, pLength: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGAElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051054b-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_target(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedString) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_target(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedString)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGAngle(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104d3-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_unitType(self, v: Int16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_unitType(self, p: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_value(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_value(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_valueInSpecifiedUnits(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_valueInSpecifiedUnits(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_valueAsString(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_valueAsString(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def newValueSpecifiedUnits(self, unitType: Int16, valueInSpecifiedUnits: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def convertToSpecifiedUnits(self, unitType: Int16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGAnimatedAngle(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104d4-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_baseVal(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAngle) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_baseVal(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAngle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_animVal(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAngle) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_animVal(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAngle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGAnimatedBoolean(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104c6-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_baseVal(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_baseVal(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_animVal(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_animVal(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGAnimatedEnumeration(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104c9-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_baseVal(self, v: UInt16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_baseVal(self, p: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_animVal(self, v: UInt16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_animVal(self, p: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGAnimatedInteger(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104ca-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_baseVal(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_baseVal(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_animVal(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_animVal(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGAnimatedLength(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104d0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_baseVal(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_baseVal(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_animVal(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_animVal(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGAnimatedLengthList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104d2-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_baseVal(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGLengthList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_baseVal(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGLengthList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_animVal(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGLengthList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_animVal(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGLengthList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGAnimatedNumber(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104cc-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_baseVal(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_baseVal(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_animVal(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_animVal(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGAnimatedNumberList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104ce-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_baseVal(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGNumberList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_baseVal(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGNumberList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_animVal(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGNumberList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_animVal(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGNumberList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGAnimatedPathData(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510511-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_pathSegList(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGPathSegList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_pathSegList(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_normalizedPathSegList(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGPathSegList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_normalizedPathSegList(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_animatedPathSegList(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGPathSegList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_animatedPathSegList(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def putref_animatedNormalizedPathSegList(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGPathSegList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_animatedNormalizedPathSegList(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGAnimatedPoints(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510517-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_points(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGPointList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_points(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPointList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_animatedPoints(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGPointList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_animatedPoints(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPointList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGAnimatedPreserveAspectRatio(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104fb-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_baseVal(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGPreserveAspectRatio) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_baseVal(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPreserveAspectRatio)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_animVal(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGPreserveAspectRatio) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_animVal(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPreserveAspectRatio)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGAnimatedRect(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104d8-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_baseVal(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGRect) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_baseVal(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGRect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_animVal(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGRect) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_animVal(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGRect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGAnimatedString(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104c7-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_baseVal(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_baseVal(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_animVal(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGAnimatedTransformList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104f9-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_baseVal(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGTransformList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_baseVal(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGTransformList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_animVal(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGTransformList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_animVal(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGTransformList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGCircleElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510514-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_cx(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_cx(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_cy(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_cy(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_r(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_r(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGClipPathElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051052d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_clipPathUnits(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_clipPathUnits(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGDefsElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104e9-98b5-11cf-bb82-00aa00bdce0b}')
class ISVGDescElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104ea-98b5-11cf-bb82-00aa00bdce0b}')
class ISVGDocument(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104e6-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_rootElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGSVGElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104c5-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_xmlbase(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_xmlbase(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_ownerSVGElement(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGSVGElement) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_ownerSVGElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGSVGElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_viewportElement(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGElement) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_viewportElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def putref_focusable(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_focusable(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGElementInstance(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104ee-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_correspondingElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_correspondingUseElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGUseElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_parentNode(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGElementInstance)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_childNodes(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGElementInstanceList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_firstChild(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGElementInstance)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_lastChild(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGElementInstance)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_previousSibling(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGElementInstance)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_nextSibling(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGElementInstance)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGElementInstanceList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104ef-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def item(self, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGElementInstance)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGEllipseElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510515-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_cx(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_cx(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_cy(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_cy(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_rx(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_rx(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def putref_ry(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_ry(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGException(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051072f-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_code(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_code(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_message(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGExternalResourcesRequired(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104df-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_externalResourcesRequired(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedBoolean)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGFitToViewBox(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104e0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_viewBox(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedRect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def putref_preserveAspectRatio(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedPreserveAspectRatio) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_preserveAspectRatio(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedPreserveAspectRatio)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGGElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104e8-98b5-11cf-bb82-00aa00bdce0b}')
class ISVGGradientElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510528-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_gradientUnits(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_gradientUnits(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_gradientTransform(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedTransformList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_gradientTransform(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedTransformList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_spreadMethod(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_spreadMethod(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGImageElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104f0-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_x(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_y(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_width(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_width(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def putref_height(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_height(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGLangSpace(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104de-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_xmllang(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_xmllang(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_xmlspace(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_xmlspace(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGLength(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104cf-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_unitType(self, v: Int16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_unitType(self, p: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_value(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_value(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_valueInSpecifiedUnits(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_valueInSpecifiedUnits(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_valueAsString(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_valueAsString(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def newValueSpecifiedUnits(self, unitType: Int16, valueInSpecifiedUnits: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def convertToSpecifiedUnits(self, unitType: Int16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGLengthList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104d1-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_numberOfItems(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_numberOfItems(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def initialize(self, newItem: win32more.Windows.Win32.Web.MsHtml.ISVGLength, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def getItem(self, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def insertItemBefore(self, newItem: win32more.Windows.Win32.Web.MsHtml.ISVGLength, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def replaceItem(self, newItem: win32more.Windows.Win32.Web.MsHtml.ISVGLength, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def removeItem(self, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def appendItem(self, newItem: win32more.Windows.Win32.Web.MsHtml.ISVGLength, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGLineElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510516-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_x1(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x1(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_y1(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y1(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_x2(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_x2(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def putref_y2(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_y2(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGLinearGradientElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510529-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_x1(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x1(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_y1(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y1(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_x2(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_x2(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def putref_y2(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_y2(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGLocatable(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104db-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_nearestViewportElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_farthestViewportElement(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def getBBox(self, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGRect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def getCTM(self, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGMatrix)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def getScreenCTM(self, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGMatrix)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def getTransformToElement(self, pElement: win32more.Windows.Win32.Web.MsHtml.ISVGElement, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGMatrix)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGMarkerElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510525-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_refX(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_refX(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_refY(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_refY(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_markerUnits(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_markerUnits(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def putref_markerWidth(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_markerWidth(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def putref_markerHeight(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_markerHeight(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def putref_orientType(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_orientType(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def putref_orientAngle(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedAngle) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_orientAngle(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedAngle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def setOrientToAuto(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def setOrientToAngle(self, pSVGAngle: win32more.Windows.Win32.Web.MsHtml.ISVGAngle) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGMaskElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051052e-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_maskUnits(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_maskUnits(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_maskContentUnits(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_maskContentUnits(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_x(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_x(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def putref_y(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_y(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def putref_width(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_width(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def putref_height(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_height(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGMatrix(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104f6-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_a(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_a(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_b(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_b(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_c(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_c(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_d(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_d(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_e(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_e(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_f(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_f(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def multiply(self, secondMatrix: win32more.Windows.Win32.Web.MsHtml.ISVGMatrix, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGMatrix)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def inverse(self, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGMatrix)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def translate(self, x: Single, y: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGMatrix)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def scale(self, scaleFactor: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGMatrix)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def scaleNonUniform(self, scaleFactorX: Single, scaleFactorY: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGMatrix)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def rotate(self, angle: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGMatrix)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def rotateFromVector(self, x: Single, y: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGMatrix)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def flipX(self, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGMatrix)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def flipY(self, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGMatrix)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def skewX(self, angle: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGMatrix)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def skewY(self, angle: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGMatrix)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGMetadataElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510560-98b5-11cf-bb82-00aa00bdce0b}')
class ISVGNumber(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104cb-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_value(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_value(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGNumberList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104cd-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_numberOfItems(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_numberOfItems(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def initialize(self, newItem: win32more.Windows.Win32.Web.MsHtml.ISVGNumber, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGNumber)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def getItem(self, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGNumber)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def insertItemBefore(self, newItem: win32more.Windows.Win32.Web.MsHtml.ISVGNumber, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGNumber)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def replaceItem(self, newItem: win32more.Windows.Win32.Web.MsHtml.ISVGNumber, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGNumber)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def removeItem(self, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGNumber)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def appendItem(self, newItem: win32more.Windows.Win32.Web.MsHtml.ISVGNumber, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGNumber)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPaint(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510524-98b5-11cf-bb82-00aa00bdce0b}')
class ISVGPathElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510512-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_pathLength(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedNumber) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_pathLength(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedNumber)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def getTotalLength(self, pfltResult: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def getPointAtLength(self, fltdistance: Single, ppPointResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def getPathSegAtLength(self, fltdistance: Single, plResult: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def createSVGPathSegClosePath(self, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegClosePath)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def createSVGPathSegMovetoAbs(self, x: Single, y: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegMovetoAbs)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def createSVGPathSegMovetoRel(self, x: Single, y: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegMovetoRel)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def createSVGPathSegLinetoAbs(self, x: Single, y: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegLinetoAbs)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def createSVGPathSegLinetoRel(self, x: Single, y: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegLinetoRel)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def createSVGPathSegCurvetoCubicAbs(self, x: Single, y: Single, x1: Single, y1: Single, x2: Single, y2: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegCurvetoCubicAbs)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def createSVGPathSegCurvetoCubicRel(self, x: Single, y: Single, x1: Single, y1: Single, x2: Single, y2: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegCurvetoCubicRel)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def createSVGPathSegCurvetoQuadraticAbs(self, x: Single, y: Single, x1: Single, y1: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegCurvetoQuadraticAbs)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def createSVGPathSegCurvetoQuadraticRel(self, x: Single, y: Single, x1: Single, y1: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegCurvetoQuadraticRel)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def createSVGPathSegArcAbs(self, x: Single, y: Single, r1: Single, r2: Single, angle: Single, largeArcFlag: win32more.Windows.Win32.Foundation.VARIANT_BOOL, sweepFlag: win32more.Windows.Win32.Foundation.VARIANT_BOOL, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegArcAbs)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def createSVGPathSegArcRel(self, x: Single, y: Single, r1: Single, r2: Single, angle: Single, largeArcFlag: win32more.Windows.Win32.Foundation.VARIANT_BOOL, sweepFlag: win32more.Windows.Win32.Foundation.VARIANT_BOOL, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegArcRel)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def createSVGPathSegLinetoHorizontalAbs(self, x: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegLinetoHorizontalAbs)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def createSVGPathSegLinetoHorizontalRel(self, x: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegLinetoHorizontalRel)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def createSVGPathSegLinetoVerticalAbs(self, y: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegLinetoVerticalAbs)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def createSVGPathSegLinetoVerticalRel(self, y: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegLinetoVerticalRel)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def createSVGPathSegCurvetoCubicSmoothAbs(self, x: Single, y: Single, x2: Single, y2: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegCurvetoCubicSmoothAbs)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def createSVGPathSegCurvetoCubicSmoothRel(self, x: Single, y: Single, x2: Single, y2: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegCurvetoCubicSmoothRel)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def createSVGPathSegCurvetoQuadraticSmoothAbs(self, x: Single, y: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegCurvetoQuadraticSmoothAbs)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def createSVGPathSegCurvetoQuadraticSmoothRel(self, x: Single, y: Single, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSegCurvetoQuadraticSmoothRel)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSeg(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104fc-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_pathSegType(self, v: Int16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_pathSegType(self, p: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_pathSegTypeAsLetter(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegArcAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510506-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_r1(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_r1(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_r2(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_r2(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_angle(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_angle(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_largeArcFlag(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_largeArcFlag(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_sweepFlag(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_sweepFlag(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegArcRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510507-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_r1(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_r1(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_r2(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_r2(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_angle(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_angle(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_largeArcFlag(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_largeArcFlag(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_sweepFlag(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_sweepFlag(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegClosePath(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104fd-98b5-11cf-bb82-00aa00bdce0b}')
class ISVGPathSegCurvetoCubicAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510502-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_x1(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_x1(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_y1(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_y1(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_x2(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_x2(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_y2(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_y2(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegCurvetoCubicRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510503-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_x1(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_x1(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_y1(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_y1(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_x2(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_x2(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_y2(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_y2(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegCurvetoCubicSmoothAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051050c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_x2(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_x2(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_y2(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_y2(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegCurvetoCubicSmoothRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051050d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_x2(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_x2(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_y2(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_y2(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegCurvetoQuadraticAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510504-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_x1(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_x1(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_y1(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_y1(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegCurvetoQuadraticRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510505-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_x1(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_x1(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_y1(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_y1(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegCurvetoQuadraticSmoothAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051050e-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegCurvetoQuadraticSmoothRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051050f-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegLinetoAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510500-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegLinetoHorizontalAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510508-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegLinetoHorizontalRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510509-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegLinetoRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510501-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegLinetoVerticalAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051050a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegLinetoVerticalRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051050b-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510510-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_numberOfItems(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_numberOfItems(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def initialize(self, newItem: win32more.Windows.Win32.Web.MsHtml.ISVGPathSeg, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSeg)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def getItem(self, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSeg)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def insertItemBefore(self, newItem: win32more.Windows.Win32.Web.MsHtml.ISVGPathSeg, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSeg)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def replaceItem(self, newItem: win32more.Windows.Win32.Web.MsHtml.ISVGPathSeg, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSeg)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def removeItem(self, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSeg)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def appendItem(self, newItem: win32more.Windows.Win32.Web.MsHtml.ISVGPathSeg, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPathSeg)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegMovetoAbs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104fe-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPathSegMovetoRel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104ff-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPatternElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051052c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_patternUnits(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_patternUnits(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_patternContentUnits(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_patternContentUnits(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_patternTransform(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedTransformList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_patternTransform(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedTransformList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def putref_x(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_x(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def putref_y(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_y(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def putref_width(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_width(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def putref_height(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_height(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPoint(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104f4-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def matrixTransform(self, pMatrix: win32more.Windows.Win32.Web.MsHtml.ISVGMatrix, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPointList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104f5-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_numberOfItems(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_numberOfItems(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def initialize(self, pNewItem: win32more.Windows.Win32.Web.MsHtml.ISVGPoint, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def getItem(self, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def insertItemBefore(self, pNewItem: win32more.Windows.Win32.Web.MsHtml.ISVGPoint, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def replaceItem(self, pNewItem: win32more.Windows.Win32.Web.MsHtml.ISVGPoint, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def removeItem(self, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def appendItem(self, pNewItem: win32more.Windows.Win32.Web.MsHtml.ISVGPoint, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGPolygonElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510519-98b5-11cf-bb82-00aa00bdce0b}')
class ISVGPolylineElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510518-98b5-11cf-bb82-00aa00bdce0b}')
class ISVGPreserveAspectRatio(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104fa-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_align(self, v: Int16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_align(self, p: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_meetOrSlice(self, v: Int16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_meetOrSlice(self, p: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGRadialGradientElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051052a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_cx(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_cx(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_cy(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_cy(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_r(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_r(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def putref_fx(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_fx(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def putref_fy(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_fy(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGRect(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104d7-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_x(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_y(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_width(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_width(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_height(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_height(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGRectElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510513-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_x(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_y(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_width(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_width(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def putref_height(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_height(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def putref_rx(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_rx(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def putref_ry(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_ry(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGSVGElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104e7-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_x(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_y(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_width(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_width(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def putref_height(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_height(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_contentScriptType(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_contentScriptType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_contentStyleType(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_contentStyleType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def putref_viewport(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGRect) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_viewport(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGRect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_pixelUnitToMillimeterX(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_pixelUnitToMillimeterX(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_pixelUnitToMillimeterY(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_pixelUnitToMillimeterY(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_screenPixelToMillimeterX(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_screenPixelToMillimeterX(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_screenPixelToMillimeterY(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_screenPixelToMillimeterY(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_useCurrentView(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_useCurrentView(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def putref_currentView(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGViewSpec) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_currentView(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGViewSpec)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_currentScale(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_currentScale(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def putref_currentTranslate(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGPoint) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_currentTranslate(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def suspendRedraw(self, maxWaitMilliseconds: UInt32, pResult: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def unsuspendRedraw(self, suspendHandeID: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def unsuspendRedrawAll(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def forceRedraw(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def pauseAnimations(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def unpauseAnimations(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def animationsPaused(self, pResult: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def getCurrentTime(self, pResult: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def setCurrentTime(self, seconds: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def getIntersectionList(self, rect: win32more.Windows.Win32.Web.MsHtml.ISVGRect, referenceElement: win32more.Windows.Win32.Web.MsHtml.ISVGElement, pResult: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def getEnclosureList(self, rect: win32more.Windows.Win32.Web.MsHtml.ISVGRect, referenceElement: win32more.Windows.Win32.Web.MsHtml.ISVGElement, pResult: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def checkIntersection(self, element: win32more.Windows.Win32.Web.MsHtml.ISVGElement, rect: win32more.Windows.Win32.Web.MsHtml.ISVGRect, pResult: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def checkEnclosure(self, element: win32more.Windows.Win32.Web.MsHtml.ISVGElement, rect: win32more.Windows.Win32.Web.MsHtml.ISVGRect, pResult: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def deselectAll(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def createSVGNumber(self, pResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGNumber)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def createSVGLength(self, pResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def createSVGAngle(self, pResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAngle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def createSVGPoint(self, pResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def createSVGMatrix(self, pResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGMatrix)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def createSVGRect(self, pResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGRect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def createSVGTransform(self, pResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def createSVGTransformFromMatrix(self, matrix: win32more.Windows.Win32.Web.MsHtml.ISVGMatrix, pResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def getElementById(self, elementId: win32more.Windows.Win32.Foundation.BSTR, pResult: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGScriptElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051054d-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_type(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGStopElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051052b-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_offset(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedNumber) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_offset(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedNumber)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGStringList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104c8-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_numberOfItems(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_numberOfItems(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def initialize(self, newItem: win32more.Windows.Win32.Foundation.BSTR, ppResult: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def getItem(self, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def insertItemBefore(self, newItem: win32more.Windows.Win32.Foundation.BSTR, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def replaceItem(self, newItem: win32more.Windows.Win32.Foundation.BSTR, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def removeItem(self, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def appendItem(self, newItem: win32more.Windows.Win32.Foundation.BSTR, ppResult: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGStylable(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104da-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_className(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedString)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGStyleElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104f3-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_type(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_type(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_media(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_media(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGSwitchElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104f1-98b5-11cf-bb82-00aa00bdce0b}')
class ISVGSymbolElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104ec-98b5-11cf-bb82-00aa00bdce0b}')
class ISVGTSpanElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051051d-98b5-11cf-bb82-00aa00bdce0b}')
class ISVGTests(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104dd-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_requiredFeatures(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGStringList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_requiredExtensions(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGStringList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_systemLanguage(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGStringList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def hasExtension(self, extension: win32more.Windows.Win32.Foundation.BSTR, pResult: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGTextContentElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051051a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_textLength(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_textLength(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_lengthAdjust(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_lengthAdjust(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def getNumberOfChars(self, pResult: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def getComputedTextLength(self, pResult: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def getSubStringLength(self, charnum: Int32, nchars: Int32, pResult: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def getStartPositionOfChar(self, charnum: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def getEndPositionOfChar(self, charnum: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def getExtentOfChar(self, charnum: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGRect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def getRotationOfChar(self, charnum: Int32, pResult: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def getCharNumAtPosition(self, point: win32more.Windows.Win32.Web.MsHtml.ISVGPoint, pResult: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def selectSubString(self, charnum: Int32, nchars: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGTextElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051051c-98b5-11cf-bb82-00aa00bdce0b}')
class ISVGTextPathElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051051f-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_startOffset(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_startOffset(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_method(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_method(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_spacing(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_spacing(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedEnumeration)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGTextPositioningElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051051b-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_x(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLengthList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLengthList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_y(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLengthList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLengthList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_dx(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLengthList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_dx(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLengthList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def putref_dy(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLengthList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_dy(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLengthList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def putref_rotate(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedNumberList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_rotate(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedNumberList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGTitleElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104eb-98b5-11cf-bb82-00aa00bdce0b}')
class ISVGTransform(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104f7-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_type(self, v: Int16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_type(self, p: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_matrix(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGMatrix) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_matrix(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGMatrix)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_angle(self, v: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_angle(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def setMatrix(self, matrix: win32more.Windows.Win32.Web.MsHtml.ISVGMatrix) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def setTranslate(self, tx: Single, ty: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def setScale(self, sx: Single, sy: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def setRotate(self, angle: Single, cx: Single, cy: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def setSkewX(self, angle: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def setSkewY(self, angle: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGTransformList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104f8-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def put_numberOfItems(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_numberOfItems(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def initialize(self, newItem: win32more.Windows.Win32.Web.MsHtml.ISVGTransform, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def getItem(self, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def insertItemBefore(self, newItem: win32more.Windows.Win32.Web.MsHtml.ISVGTransform, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def replaceItem(self, newItem: win32more.Windows.Win32.Web.MsHtml.ISVGTransform, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def removeItem(self, index: Int32, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def appendItem(self, newItem: win32more.Windows.Win32.Web.MsHtml.ISVGTransform, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def createSVGTransformFromMatrix(self, newItem: win32more.Windows.Win32.Web.MsHtml.ISVGMatrix, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def consolidate(self, ppResult: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGTransformable(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104dc-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_transform(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedTransformList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGURIReference(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104e3-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_href(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedString)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGUseElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104ed-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_x(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_x(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def putref_y(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_y(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_width(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_width(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def putref_height(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_height(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGAnimatedLength)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def putref_instanceRoot(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGElementInstance) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_instanceRoot(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGElementInstance)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def putref_animatedInstanceRoot(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGElementInstance) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_animatedInstanceRoot(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGElementInstance)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGViewElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051054c-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def putref_viewTarget(self, v: win32more.Windows.Win32.Web.MsHtml.ISVGStringList) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_viewTarget(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGStringList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGViewSpec(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104e2-98b5-11cf-bb82-00aa00bdce0b}')
class ISVGZoomAndPan(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305104e1-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_zoomAndPan(self, p: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISVGZoomEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3051054e-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_zoomRectScreen(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGRect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_previousScale(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_previousTranslate(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_newScale(self, p: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_newTranslate(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.ISVGPoint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IScriptEventHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3051083a-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def FunctionName(self, pbstrFunctionName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DebugDocumentContext(self, ppDebugDocumentContext: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def EventHandlerDispatch(self, ppDispHandler: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def UsesCapture(self, pfUsesCapture: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Cookie(self, pullCookie: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IScriptEventHandlerSourceInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{30510841-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetSourceInfo(self, pbstrFunctionName: POINTER(win32more.Windows.Win32.Foundation.BSTR), line: POINTER(UInt32), column: POINTER(UInt32), cchLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISecureUrlHost(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c81984c4-74c8-11d2-baa9-00c04fc2040e}')
    @commethod(3)
    def ValidateSecureUrl(self, pfAllow: POINTER(win32more.Windows.Win32.Foundation.BOOL), pchUrlInQuestion: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISegment(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f683-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetPointers(self, pIStart: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pIEnd: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISegmentList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f605-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def CreateIterator(self, ppIIter: POINTER(win32more.Windows.Win32.Web.MsHtml.ISegmentListIterator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetType(self, peType: POINTER(win32more.Windows.Win32.Web.MsHtml.SELECTION_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def IsEmpty(self, pfEmpty: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISegmentListIterator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f692-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def Current(self, ppISegment: POINTER(win32more.Windows.Win32.Web.MsHtml.ISegment)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def First(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def IsDone(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Advance(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISelectionServices(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f684-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def SetSelectionType(self, eType: win32more.Windows.Win32.Web.MsHtml.SELECTION_TYPE, pIListener: win32more.Windows.Win32.Web.MsHtml.ISelectionServicesListener) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetMarkupContainer(self, ppIContainer: POINTER(win32more.Windows.Win32.Web.MsHtml.IMarkupContainer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def AddSegment(self, pIStart: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pIEnd: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, ppISegmentAdded: POINTER(win32more.Windows.Win32.Web.MsHtml.ISegment)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def AddElementSegment(self, pIElement: win32more.Windows.Win32.Web.MsHtml.IHTMLElement, ppISegmentAdded: POINTER(win32more.Windows.Win32.Web.MsHtml.IElementSegment)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def RemoveSegment(self, pISegment: win32more.Windows.Win32.Web.MsHtml.ISegment) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetSelectionServicesListener(self, ppISelectionServicesListener: POINTER(win32more.Windows.Win32.Web.MsHtml.ISelectionServicesListener)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISelectionServicesListener(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f699-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def BeginSelectionUndo(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EndSelectionUndo(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def OnSelectedElementExit(self, pIElementStart: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pIElementEnd: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pIElementContentStart: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer, pIElementContentEnd: win32more.Windows.Win32.Web.MsHtml.IMarkupPointer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def OnChangeType(self, eType: win32more.Windows.Win32.Web.MsHtml.SELECTION_TYPE, pIListener: win32more.Windows.Win32.Web.MsHtml.ISelectionServicesListener) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetTypeDetail(self, pTypeDetail: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISequenceNumber(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3050f6c1-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetSequenceNumber(self, nCurrent: Int32, pnNew: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISurfacePresenter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{305106e2-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def Present(self, uBuffer: UInt32, pDirty: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetBuffer(self, backBufferIndex: UInt32, riid: POINTER(Guid), ppBuffer: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def IsCurrent(self, pIsCurrent: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITemplatePrinter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3050f6b4-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def startDoc(self, bstrTitle: win32more.Windows.Win32.Foundation.BSTR, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def stopDoc(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def printBlankPage(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def printPage(self, pElemDisp: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def ensurePrintDialogDefaults(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def showPrintDialog(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def showPageSetupDialog(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def printNonNative(self, pMarkup: win32more.Windows.Win32.System.Com.IUnknown, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def printNonNativeFrames(self, pMarkup: win32more.Windows.Win32.System.Com.IUnknown, fActiveFrame: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_framesetDocument(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_framesetDocument(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_frameActive(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_frameActive(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_frameAsShown(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_frameAsShown(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_selection(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_selection(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_selectedPages(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_selectedPages(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_currentPage(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_currentPage(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_currentPageAvail(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_currentPageAvail(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def put_collate(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_collate(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_duplex(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_copies(self, v: UInt16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_copies(self, p: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_pageFrom(self, v: UInt16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_pageFrom(self, p: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_pageTo(self, v: UInt16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_pageTo(self, p: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_tableOfLinks(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_tableOfLinks(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_allLinkedDocuments(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_allLinkedDocuments(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_header(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_header(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_footer(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_footer(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def put_marginLeft(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_marginLeft(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def put_marginRight(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def get_marginRight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def put_marginTop(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_marginTop(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def put_marginBottom(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_marginBottom(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def get_pageWidth(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_pageHeight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def get_unprintableLeft(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def get_unprintableTop(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def get_unprintableRight(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def get_unprintableBottom(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def updatePageStatus(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITemplatePrinter2(ComPtr):
    extends: win32more.Windows.Win32.Web.MsHtml.ITemplatePrinter
    _iid_ = Guid('{3050f83f-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(62)
    def put_selectionEnabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def get_selectionEnabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def put_frameActiveEnabled(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def get_frameActiveEnabled(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def put_orientation(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def get_orientation(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def put_usePrinterCopyCollate(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def get_usePrinterCopyCollate(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def deviceSupports(self, bstrProperty: win32more.Windows.Win32.Foundation.BSTR, pvar: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITemplatePrinter3(ComPtr):
    extends: win32more.Windows.Win32.Web.MsHtml.ITemplatePrinter2
    _iid_ = Guid('{305104a3-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(71)
    def put_headerFooterFont(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def get_headerFooterFont(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def getPageMarginTop(self, pageRule: win32more.Windows.Win32.System.Com.IDispatch, pageWidth: Int32, pageHeight: Int32, pMargin: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def getPageMarginRight(self, pageRule: win32more.Windows.Win32.System.Com.IDispatch, pageWidth: Int32, pageHeight: Int32, pMargin: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def getPageMarginBottom(self, pageRule: win32more.Windows.Win32.System.Com.IDispatch, pageWidth: Int32, pageHeight: Int32, pMargin: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def getPageMarginLeft(self, pageRule: win32more.Windows.Win32.System.Com.IDispatch, pageWidth: Int32, pageHeight: Int32, pMargin: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def getPageMarginTopImportant(self, pageRule: win32more.Windows.Win32.System.Com.IDispatch, pbImportant: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def getPageMarginRightImportant(self, pageRule: win32more.Windows.Win32.System.Com.IDispatch, pbImportant: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def getPageMarginBottomImportant(self, pageRule: win32more.Windows.Win32.System.Com.IDispatch, pbImportant: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def getPageMarginLeftImportant(self, pageRule: win32more.Windows.Win32.System.Com.IDispatch, pbImportant: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITrackingProtection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{30510803-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def EvaluateUrl(self, bstrUrl: win32more.Windows.Win32.Foundation.BSTR, pfAllowed: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetEnabled(self, pfEnabled: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IViewObjectPresentNotify(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{305107f8-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def OnPreRender(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IViewObjectPresentNotifySite(ComPtr):
    extends: win32more.Windows.Win32.Web.MsHtml.IViewObjectPresentSite
    _iid_ = Guid('{305107fa-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(6)
    def RequestFrame(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IViewObjectPresentSite(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{305106e1-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def CreateSurfacePresenter(self, pDevice: win32more.Windows.Win32.System.Com.IUnknown, width: UInt32, height: UInt32, backBufferCount: UInt32, format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, mode: win32more.Windows.Win32.Web.MsHtml.VIEW_OBJECT_ALPHA_MODE, ppQueue: POINTER(win32more.Windows.Win32.Web.MsHtml.ISurfacePresenter)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def IsHardwareComposition(self, pIsHardwareComposition: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetCompositionMode(self, mode: win32more.Windows.Win32.Web.MsHtml.VIEW_OBJECT_COMPOSITION_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IViewObjectPrint(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{305106e3-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetPrintBitmap(self, ppPrintBitmap: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWBScriptControl(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{a5170870-0cf8-11d1-8b91-0080c744f389}')
    @commethod(7)
    def raiseEvent(self, name: win32more.Windows.Win32.Foundation.BSTR, eventData: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def bubbleEvent(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def setContextMenu(self, menuItemPairs: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_selectableContent(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_selectableContent(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_frozen(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_scrollbar(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_scrollbar(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_version(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_visibility(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_onvisibilitychange(self, v: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_onvisibilitychange(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWPCBlockedUrls(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{30510413-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(3)
    def GetCount(self, pdwCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetUrl(self, dwIdx: UInt32, pbstrUrl: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWebBridge(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{ae24fdad-03c6-11d1-8b76-0080c744f389}')
    @commethod(7)
    def put_URL(self, v: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_URL(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_Scrollbar(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Scrollbar(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_embed(self, v: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_embed(self, p: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_event(self, p: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_readyState(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def AboutBox(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWebGeocoordinates(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305107c7-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_latitude(self, p: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_longitude(self, p: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_altitude(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_accuracy(self, p: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_altitudeAccuracy(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_heading(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_speed(self, p: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWebGeolocation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305107c5-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def getCurrentPosition(self, successCallback: win32more.Windows.Win32.System.Com.IDispatch, errorCallback: win32more.Windows.Win32.System.Com.IDispatch, options: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def watchPosition(self, successCallback: win32more.Windows.Win32.System.Com.IDispatch, errorCallback: win32more.Windows.Win32.System.Com.IDispatch, options: win32more.Windows.Win32.System.Com.IDispatch, watchId: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def clearWatch(self, watchId: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWebGeoposition(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305107cd-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_coords(self, p: POINTER(win32more.Windows.Win32.Web.MsHtml.IWebGeocoordinates)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_timestamp(self, p: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWebGeopositionError(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{305107c9-98b5-11cf-bb82-00aa00bdce0b}')
    @commethod(7)
    def get_code(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_message(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLGenericParse(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e4e23071-4d07-11d2-ae76-0080c73bc199}')
    @commethod(3)
    def SetGenericParse(self, fDoGeneric: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLHttpRequestEventTarget(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{30510830-98b5-11cf-bb82-00aa00bdce0b}')
LINE_DIRECTION = Int32
LINE_DIRECTION_RightToLeft: win32more.Windows.Win32.Web.MsHtml.LINE_DIRECTION = 1
LINE_DIRECTION_LeftToRight: win32more.Windows.Win32.Web.MsHtml.LINE_DIRECTION = 2
LINE_DIRECTION_Max: win32more.Windows.Win32.Web.MsHtml.LINE_DIRECTION = 2147483647
MARKUP_CONTEXT_TYPE = Int32
CONTEXT_TYPE_None: win32more.Windows.Win32.Web.MsHtml.MARKUP_CONTEXT_TYPE = 0
CONTEXT_TYPE_Text: win32more.Windows.Win32.Web.MsHtml.MARKUP_CONTEXT_TYPE = 1
CONTEXT_TYPE_EnterScope: win32more.Windows.Win32.Web.MsHtml.MARKUP_CONTEXT_TYPE = 2
CONTEXT_TYPE_ExitScope: win32more.Windows.Win32.Web.MsHtml.MARKUP_CONTEXT_TYPE = 3
CONTEXT_TYPE_NoScope: win32more.Windows.Win32.Web.MsHtml.MARKUP_CONTEXT_TYPE = 4
MARKUP_CONTEXT_TYPE_Max: win32more.Windows.Win32.Web.MsHtml.MARKUP_CONTEXT_TYPE = 2147483647
MOVEUNIT_ACTION = Int32
MOVEUNIT_PREVCHAR: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 0
MOVEUNIT_NEXTCHAR: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 1
MOVEUNIT_PREVCLUSTERBEGIN: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 2
MOVEUNIT_NEXTCLUSTERBEGIN: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 3
MOVEUNIT_PREVCLUSTEREND: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 4
MOVEUNIT_NEXTCLUSTEREND: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 5
MOVEUNIT_PREVWORDBEGIN: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 6
MOVEUNIT_NEXTWORDBEGIN: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 7
MOVEUNIT_PREVWORDEND: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 8
MOVEUNIT_NEXTWORDEND: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 9
MOVEUNIT_PREVPROOFWORD: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 10
MOVEUNIT_NEXTPROOFWORD: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 11
MOVEUNIT_NEXTURLBEGIN: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 12
MOVEUNIT_PREVURLBEGIN: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 13
MOVEUNIT_NEXTURLEND: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 14
MOVEUNIT_PREVURLEND: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 15
MOVEUNIT_PREVSENTENCE: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 16
MOVEUNIT_NEXTSENTENCE: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 17
MOVEUNIT_PREVBLOCK: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 18
MOVEUNIT_NEXTBLOCK: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 19
MOVEUNIT_ACTION_Max: win32more.Windows.Win32.Web.MsHtml.MOVEUNIT_ACTION = 2147483647
NodeIterator = Guid('{30510745-98b5-11cf-bb82-00aa00bdce0b}')
OldHTMLDocument = Guid('{d48a6ec9-6a4a-11cf-94a7-444553540000}')
OldHTMLFormElement = Guid('{0d04d285-6bec-11cf-8b97-00aa00476da6}')
PARSE_FLAGS = Int32
PARSE_ABSOLUTIFYIE40URLS: win32more.Windows.Win32.Web.MsHtml.PARSE_FLAGS = 1
PARSE_DISABLEVML: win32more.Windows.Win32.Web.MsHtml.PARSE_FLAGS = 2
PARSE_FLAGS_Max: win32more.Windows.Win32.Web.MsHtml.PARSE_FLAGS = 2147483647
POINTER_GRAVITY = Int32
POINTER_GRAVITY_Left: win32more.Windows.Win32.Web.MsHtml.POINTER_GRAVITY = 0
POINTER_GRAVITY_Right: win32more.Windows.Win32.Web.MsHtml.POINTER_GRAVITY = 1
POINTER_GRAVITY_Max: win32more.Windows.Win32.Web.MsHtml.POINTER_GRAVITY = 2147483647
RangeException = Guid('{3051072e-98b5-11cf-bb82-00aa00bdce0b}')
RulesApplied = Guid('{7c803920-7a53-4d26-98ac-fdd23e6b9e01}')
RulesAppliedCollection = Guid('{671926ee-c3cf-40af-be8f-1cbaee6486e8}')
SAVE_SEGMENTS_FLAGS = Int32
SAVE_SEGMENTS_NoIE4SelectionCompat: win32more.Windows.Win32.Web.MsHtml.SAVE_SEGMENTS_FLAGS = 1
SAVE_SEGMENTS_FLAGS_Max: win32more.Windows.Win32.Web.MsHtml.SAVE_SEGMENTS_FLAGS = 2147483647
SCRIPT_TIMER_TYPE = Int32
STT_TIMEOUT: win32more.Windows.Win32.Web.MsHtml.SCRIPT_TIMER_TYPE = 0
STT_INTERVAL: win32more.Windows.Win32.Web.MsHtml.SCRIPT_TIMER_TYPE = 1
STT_IMMEDIATE: win32more.Windows.Win32.Web.MsHtml.SCRIPT_TIMER_TYPE = 2
STT_ANIMATION_FRAME: win32more.Windows.Win32.Web.MsHtml.SCRIPT_TIMER_TYPE = 3
SCRIPT_TIMER_TYPE_Max: win32more.Windows.Win32.Web.MsHtml.SCRIPT_TIMER_TYPE = 2147483647
SECUREURLHOSTVALIDATE_FLAGS = Int32
SUHV_PROMPTBEFORENO: win32more.Windows.Win32.Web.MsHtml.SECUREURLHOSTVALIDATE_FLAGS = 1
SUHV_SILENTYES: win32more.Windows.Win32.Web.MsHtml.SECUREURLHOSTVALIDATE_FLAGS = 2
SUHV_UNSECURESOURCE: win32more.Windows.Win32.Web.MsHtml.SECUREURLHOSTVALIDATE_FLAGS = 4
SECUREURLHOSTVALIDATE_FLAGS_Max: win32more.Windows.Win32.Web.MsHtml.SECUREURLHOSTVALIDATE_FLAGS = 2147483647
SELECTION_TYPE = Int32
SELECTION_TYPE_None: win32more.Windows.Win32.Web.MsHtml.SELECTION_TYPE = 0
SELECTION_TYPE_Caret: win32more.Windows.Win32.Web.MsHtml.SELECTION_TYPE = 1
SELECTION_TYPE_Text: win32more.Windows.Win32.Web.MsHtml.SELECTION_TYPE = 2
SELECTION_TYPE_Control: win32more.Windows.Win32.Web.MsHtml.SELECTION_TYPE = 3
SELECTION_TYPE_Max: win32more.Windows.Win32.Web.MsHtml.SELECTION_TYPE = 2147483647
@winfunctype_pointer
def SHOWHTMLDIALOGEXFN(hwndParent: win32more.Windows.Win32.Foundation.HWND, pmk: win32more.Windows.Win32.System.Com.IMoniker, dwDialogFlags: UInt32, pvarArgIn: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pchOptions: win32more.Windows.Win32.Foundation.PWSTR, pvArgOut: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def SHOWHTMLDIALOGFN(hwndParent: win32more.Windows.Win32.Foundation.HWND, pmk: win32more.Windows.Win32.System.Com.IMoniker, pvarArgIn: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pchOptions: win32more.Windows.Win32.Foundation.PWSTR, pvArgOut: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def SHOWMODELESSHTMLDIALOGFN(hwndParent: win32more.Windows.Win32.Foundation.HWND, pmk: win32more.Windows.Win32.System.Com.IMoniker, pvarArgIn: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pvarOptions: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppWindow: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
SVGAElement = Guid('{305105db-98b5-11cf-bb82-00aa00bdce0b}')
SVGAngle = Guid('{30510584-98b5-11cf-bb82-00aa00bdce0b}')
SVGAnimatedAngle = Guid('{305105e4-98b5-11cf-bb82-00aa00bdce0b}')
SVGAnimatedBoolean = Guid('{3051058b-98b5-11cf-bb82-00aa00bdce0b}')
SVGAnimatedEnumeration = Guid('{3051058e-98b5-11cf-bb82-00aa00bdce0b}')
SVGAnimatedInteger = Guid('{3051058f-98b5-11cf-bb82-00aa00bdce0b}')
SVGAnimatedLength = Guid('{30510581-98b5-11cf-bb82-00aa00bdce0b}')
SVGAnimatedLengthList = Guid('{30510582-98b5-11cf-bb82-00aa00bdce0b}')
SVGAnimatedNumber = Guid('{30510588-98b5-11cf-bb82-00aa00bdce0b}')
SVGAnimatedNumberList = Guid('{3051058a-98b5-11cf-bb82-00aa00bdce0b}')
SVGAnimatedPreserveAspectRatio = Guid('{305105ce-98b5-11cf-bb82-00aa00bdce0b}')
SVGAnimatedRect = Guid('{30510586-98b5-11cf-bb82-00aa00bdce0b}')
SVGAnimatedString = Guid('{3051058c-98b5-11cf-bb82-00aa00bdce0b}')
SVGAnimatedTransformList = Guid('{305105b1-98b5-11cf-bb82-00aa00bdce0b}')
SVGCircleElement = Guid('{30510578-98b5-11cf-bb82-00aa00bdce0b}')
SVGClipPathElement = Guid('{305105e6-98b5-11cf-bb82-00aa00bdce0b}')
SVGDefsElement = Guid('{30510570-98b5-11cf-bb82-00aa00bdce0b}')
SVGDescElement = Guid('{30510572-98b5-11cf-bb82-00aa00bdce0b}')
SVGElement = Guid('{30510564-98b5-11cf-bb82-00aa00bdce0b}')
SVGElementInstance = Guid('{30510575-98b5-11cf-bb82-00aa00bdce0b}')
SVGElementInstanceList = Guid('{30510576-98b5-11cf-bb82-00aa00bdce0b}')
SVGEllipseElement = Guid('{30510579-98b5-11cf-bb82-00aa00bdce0b}')
SVGException = Guid('{30510730-98b5-11cf-bb82-00aa00bdce0b}')
SVGGElement = Guid('{3051056f-98b5-11cf-bb82-00aa00bdce0b}')
SVGGradientElement = Guid('{305105d6-98b5-11cf-bb82-00aa00bdce0b}')
SVGImageElement = Guid('{305105cf-98b5-11cf-bb82-00aa00bdce0b}')
SVGLength = Guid('{3051057e-98b5-11cf-bb82-00aa00bdce0b}')
SVGLengthList = Guid('{30510580-98b5-11cf-bb82-00aa00bdce0b}')
SVGLineElement = Guid('{3051057a-98b5-11cf-bb82-00aa00bdce0b}')
SVGLinearGradientElement = Guid('{305105d2-98b5-11cf-bb82-00aa00bdce0b}')
SVGMarkerElement = Guid('{305105de-98b5-11cf-bb82-00aa00bdce0b}')
SVGMaskElement = Guid('{305105e7-98b5-11cf-bb82-00aa00bdce0b}')
SVGMatrix = Guid('{305105ae-98b5-11cf-bb82-00aa00bdce0b}')
SVGMetadataElement = Guid('{305105d7-98b5-11cf-bb82-00aa00bdce0b}')
SVGNumber = Guid('{30510587-98b5-11cf-bb82-00aa00bdce0b}')
SVGNumberList = Guid('{30510589-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathElement = Guid('{305105b2-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSeg = Guid('{305105b3-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegArcAbs = Guid('{305105bb-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegArcRel = Guid('{305105bc-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegClosePath = Guid('{305105bd-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegCurvetoCubicAbs = Guid('{305105be-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegCurvetoCubicRel = Guid('{305105bf-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegCurvetoCubicSmoothAbs = Guid('{305105c0-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegCurvetoCubicSmoothRel = Guid('{305105c1-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegCurvetoQuadraticAbs = Guid('{305105c2-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegCurvetoQuadraticRel = Guid('{305105c3-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegCurvetoQuadraticSmoothAbs = Guid('{305105c4-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegCurvetoQuadraticSmoothRel = Guid('{305105c5-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegLinetoAbs = Guid('{305105c6-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegLinetoHorizontalAbs = Guid('{305105c7-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegLinetoHorizontalRel = Guid('{305105c8-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegLinetoRel = Guid('{305105c9-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegLinetoVerticalAbs = Guid('{305105ca-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegLinetoVerticalRel = Guid('{305105cb-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegList = Guid('{305105b4-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegMovetoAbs = Guid('{305105cc-98b5-11cf-bb82-00aa00bdce0b}')
SVGPathSegMovetoRel = Guid('{305105cd-98b5-11cf-bb82-00aa00bdce0b}')
SVGPatternElement = Guid('{305105d4-98b5-11cf-bb82-00aa00bdce0b}')
SVGPoint = Guid('{305105ba-98b5-11cf-bb82-00aa00bdce0b}')
SVGPointList = Guid('{305105b9-98b5-11cf-bb82-00aa00bdce0b}')
SVGPolygonElement = Guid('{3051057b-98b5-11cf-bb82-00aa00bdce0b}')
SVGPolylineElement = Guid('{3051057c-98b5-11cf-bb82-00aa00bdce0b}')
SVGPreserveAspectRatio = Guid('{305105d0-98b5-11cf-bb82-00aa00bdce0b}')
SVGRadialGradientElement = Guid('{305105d3-98b5-11cf-bb82-00aa00bdce0b}')
SVGRect = Guid('{30510583-98b5-11cf-bb82-00aa00bdce0b}')
SVGRectElement = Guid('{30510577-98b5-11cf-bb82-00aa00bdce0b}')
SVGSVGElement = Guid('{30510574-98b5-11cf-bb82-00aa00bdce0b}')
SVGScriptElement = Guid('{305105e1-98b5-11cf-bb82-00aa00bdce0b}')
SVGStopElement = Guid('{305105d5-98b5-11cf-bb82-00aa00bdce0b}')
SVGStringList = Guid('{3051058d-98b5-11cf-bb82-00aa00bdce0b}')
SVGStyleElement = Guid('{305105d1-98b5-11cf-bb82-00aa00bdce0b}')
SVGSwitchElement = Guid('{305105d8-98b5-11cf-bb82-00aa00bdce0b}')
SVGSymbolElement = Guid('{30510571-98b5-11cf-bb82-00aa00bdce0b}')
SVGTSpanElement = Guid('{305105e2-98b5-11cf-bb82-00aa00bdce0b}')
SVGTextContentElement = Guid('{305105dd-98b5-11cf-bb82-00aa00bdce0b}')
SVGTextElement = Guid('{305105df-98b5-11cf-bb82-00aa00bdce0b}')
SVGTextPathElement = Guid('{305105eb-98b5-11cf-bb82-00aa00bdce0b}')
SVGTextPositioningElement = Guid('{305105e0-98b5-11cf-bb82-00aa00bdce0b}')
SVGTitleElement = Guid('{30510573-98b5-11cf-bb82-00aa00bdce0b}')
SVGTransform = Guid('{305105af-98b5-11cf-bb82-00aa00bdce0b}')
SVGTransformList = Guid('{305105b0-98b5-11cf-bb82-00aa00bdce0b}')
SVGUseElement = Guid('{30510590-98b5-11cf-bb82-00aa00bdce0b}')
SVGViewElement = Guid('{305105dc-98b5-11cf-bb82-00aa00bdce0b}')
SVGZoomEvent = Guid('{305105d9-98b5-11cf-bb82-00aa00bdce0b}')
Scriptlet = Guid('{ae24fdae-03c6-11d1-8b76-0080c744f389}')
StaticNodeList = Guid('{30510467-98b5-11cf-bb82-00aa00bdce0b}')
ThreadDialogProcParam = Guid('{3050f5eb-98b5-11cf-bb82-00aa00bdce0b}')
TreeWalker = Guid('{30510747-98b5-11cf-bb82-00aa00bdce0b}')
VIEW_OBJECT_ALPHA_MODE = Int32
VIEW_OBJECT_ALPHA_MODE_IGNORE: win32more.Windows.Win32.Web.MsHtml.VIEW_OBJECT_ALPHA_MODE = 0
VIEW_OBJECT_ALPHA_MODE_PREMULTIPLIED: win32more.Windows.Win32.Web.MsHtml.VIEW_OBJECT_ALPHA_MODE = 1
VIEW_OBJECT_ALPHA_MODE_Max: win32more.Windows.Win32.Web.MsHtml.VIEW_OBJECT_ALPHA_MODE = 2147483647
VIEW_OBJECT_COMPOSITION_MODE = Int32
VIEW_OBJECT_COMPOSITION_MODE_LEGACY: win32more.Windows.Win32.Web.MsHtml.VIEW_OBJECT_COMPOSITION_MODE = 0
VIEW_OBJECT_COMPOSITION_MODE_SURFACEPRESENTER: win32more.Windows.Win32.Web.MsHtml.VIEW_OBJECT_COMPOSITION_MODE = 1
VIEW_OBJECT_COMPOSITION_MODE_Max: win32more.Windows.Win32.Web.MsHtml.VIEW_OBJECT_COMPOSITION_MODE = 2147483647
WebGeocoordinates = Guid('{305107c8-98b5-11cf-bb82-00aa00bdce0b}')
WebGeolocation = Guid('{305107c6-98b5-11cf-bb82-00aa00bdce0b}')
WebGeoposition = Guid('{305107ce-98b5-11cf-bb82-00aa00bdce0b}')
WebGeopositionError = Guid('{305107ca-98b5-11cf-bb82-00aa00bdce0b}')
XDomainRequest = Guid('{30510455-98b5-11cf-bb82-00aa00bdce0b}')
XDomainRequestFactory = Guid('{30510457-98b5-11cf-bb82-00aa00bdce0b}')
XMLHttpRequestEventTarget = Guid('{30510831-98b5-11cf-bb82-00aa00bdce0b}')
XMLSerializer = Guid('{3051077e-98b5-11cf-bb82-00aa00bdce0b}')
bodyScroll = Int32
bodyScrollyes: win32more.Windows.Win32.Web.MsHtml.bodyScroll = 1
bodyScrollno: win32more.Windows.Win32.Web.MsHtml.bodyScroll = 2
bodyScrollauto: win32more.Windows.Win32.Web.MsHtml.bodyScroll = 4
bodyScrolldefault: win32more.Windows.Win32.Web.MsHtml.bodyScroll = 3
bodyScroll_Max: win32more.Windows.Win32.Web.MsHtml.bodyScroll = 2147483647
frameScrolling = Int32
frameScrollingyes: win32more.Windows.Win32.Web.MsHtml.frameScrolling = 1
frameScrollingno: win32more.Windows.Win32.Web.MsHtml.frameScrolling = 2
frameScrollingauto: win32more.Windows.Win32.Web.MsHtml.frameScrolling = 4
frameScrolling_Max: win32more.Windows.Win32.Web.MsHtml.frameScrolling = 2147483647
htmlAdjacency = Int32
htmlAdjacencyBeforeBegin: win32more.Windows.Win32.Web.MsHtml.htmlAdjacency = 1
htmlAdjacencyAfterBegin: win32more.Windows.Win32.Web.MsHtml.htmlAdjacency = 2
htmlAdjacencyBeforeEnd: win32more.Windows.Win32.Web.MsHtml.htmlAdjacency = 3
htmlAdjacencyAfterEnd: win32more.Windows.Win32.Web.MsHtml.htmlAdjacency = 4
htmlAdjacency_Max: win32more.Windows.Win32.Web.MsHtml.htmlAdjacency = 2147483647
htmlApplyLocation = Int32
htmlApplyLocationInside: win32more.Windows.Win32.Web.MsHtml.htmlApplyLocation = 0
htmlApplyLocationOutside: win32more.Windows.Win32.Web.MsHtml.htmlApplyLocation = 1
htmlApplyLocation_Max: win32more.Windows.Win32.Web.MsHtml.htmlApplyLocation = 2147483647
htmlBlockAlign = Int32
htmlBlockAlignNotSet: win32more.Windows.Win32.Web.MsHtml.htmlBlockAlign = 0
htmlBlockAlignLeft: win32more.Windows.Win32.Web.MsHtml.htmlBlockAlign = 1
htmlBlockAlignCenter: win32more.Windows.Win32.Web.MsHtml.htmlBlockAlign = 2
htmlBlockAlignRight: win32more.Windows.Win32.Web.MsHtml.htmlBlockAlign = 3
htmlBlockAlignJustify: win32more.Windows.Win32.Web.MsHtml.htmlBlockAlign = 4
htmlBlockAlign_Max: win32more.Windows.Win32.Web.MsHtml.htmlBlockAlign = 2147483647
htmlCaptionAlign = Int32
htmlCaptionAlignNotSet: win32more.Windows.Win32.Web.MsHtml.htmlCaptionAlign = 0
htmlCaptionAlignLeft: win32more.Windows.Win32.Web.MsHtml.htmlCaptionAlign = 1
htmlCaptionAlignCenter: win32more.Windows.Win32.Web.MsHtml.htmlCaptionAlign = 2
htmlCaptionAlignRight: win32more.Windows.Win32.Web.MsHtml.htmlCaptionAlign = 3
htmlCaptionAlignJustify: win32more.Windows.Win32.Web.MsHtml.htmlCaptionAlign = 4
htmlCaptionAlignTop: win32more.Windows.Win32.Web.MsHtml.htmlCaptionAlign = 5
htmlCaptionAlignBottom: win32more.Windows.Win32.Web.MsHtml.htmlCaptionAlign = 6
htmlCaptionAlign_Max: win32more.Windows.Win32.Web.MsHtml.htmlCaptionAlign = 2147483647
htmlCaptionVAlign = Int32
htmlCaptionVAlignNotSet: win32more.Windows.Win32.Web.MsHtml.htmlCaptionVAlign = 0
htmlCaptionVAlignTop: win32more.Windows.Win32.Web.MsHtml.htmlCaptionVAlign = 1
htmlCaptionVAlignBottom: win32more.Windows.Win32.Web.MsHtml.htmlCaptionVAlign = 2
htmlCaptionVAlign_Max: win32more.Windows.Win32.Web.MsHtml.htmlCaptionVAlign = 2147483647
htmlCellAlign = Int32
htmlCellAlignNotSet: win32more.Windows.Win32.Web.MsHtml.htmlCellAlign = 0
htmlCellAlignLeft: win32more.Windows.Win32.Web.MsHtml.htmlCellAlign = 1
htmlCellAlignCenter: win32more.Windows.Win32.Web.MsHtml.htmlCellAlign = 2
htmlCellAlignRight: win32more.Windows.Win32.Web.MsHtml.htmlCellAlign = 3
htmlCellAlignMiddle: win32more.Windows.Win32.Web.MsHtml.htmlCellAlign = 2
htmlCellAlign_Max: win32more.Windows.Win32.Web.MsHtml.htmlCellAlign = 2147483647
htmlCellVAlign = Int32
htmlCellVAlignNotSet: win32more.Windows.Win32.Web.MsHtml.htmlCellVAlign = 0
htmlCellVAlignTop: win32more.Windows.Win32.Web.MsHtml.htmlCellVAlign = 1
htmlCellVAlignMiddle: win32more.Windows.Win32.Web.MsHtml.htmlCellVAlign = 2
htmlCellVAlignBottom: win32more.Windows.Win32.Web.MsHtml.htmlCellVAlign = 3
htmlCellVAlignBaseline: win32more.Windows.Win32.Web.MsHtml.htmlCellVAlign = 4
htmlCellVAlignCenter: win32more.Windows.Win32.Web.MsHtml.htmlCellVAlign = 2
htmlCellVAlign_Max: win32more.Windows.Win32.Web.MsHtml.htmlCellVAlign = 2147483647
htmlClear = Int32
htmlClearNotSet: win32more.Windows.Win32.Web.MsHtml.htmlClear = 0
htmlClearAll: win32more.Windows.Win32.Web.MsHtml.htmlClear = 1
htmlClearLeft: win32more.Windows.Win32.Web.MsHtml.htmlClear = 2
htmlClearRight: win32more.Windows.Win32.Web.MsHtml.htmlClear = 3
htmlClearBoth: win32more.Windows.Win32.Web.MsHtml.htmlClear = 4
htmlClearNone: win32more.Windows.Win32.Web.MsHtml.htmlClear = 5
htmlClear_Max: win32more.Windows.Win32.Web.MsHtml.htmlClear = 2147483647
htmlCompatMode = Int32
htmlCompatModeBackCompat: win32more.Windows.Win32.Web.MsHtml.htmlCompatMode = 0
htmlCompatModeCSS1Compat: win32more.Windows.Win32.Web.MsHtml.htmlCompatMode = 1
htmlCompatMode_Max: win32more.Windows.Win32.Web.MsHtml.htmlCompatMode = 2147483647
htmlComponent = Int32
htmlComponentClient: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 0
htmlComponentSbLeft: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 1
htmlComponentSbPageLeft: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 2
htmlComponentSbHThumb: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 3
htmlComponentSbPageRight: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 4
htmlComponentSbRight: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 5
htmlComponentSbUp: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 6
htmlComponentSbPageUp: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 7
htmlComponentSbVThumb: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 8
htmlComponentSbPageDown: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 9
htmlComponentSbDown: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 10
htmlComponentSbLeft2: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 11
htmlComponentSbPageLeft2: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 12
htmlComponentSbRight2: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 13
htmlComponentSbPageRight2: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 14
htmlComponentSbUp2: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 15
htmlComponentSbPageUp2: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 16
htmlComponentSbDown2: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 17
htmlComponentSbPageDown2: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 18
htmlComponentSbTop: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 19
htmlComponentSbBottom: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 20
htmlComponentOutside: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 21
htmlComponentGHTopLeft: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 22
htmlComponentGHLeft: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 23
htmlComponentGHTop: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 24
htmlComponentGHBottomLeft: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 25
htmlComponentGHTopRight: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 26
htmlComponentGHBottom: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 27
htmlComponentGHRight: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 28
htmlComponentGHBottomRight: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 29
htmlComponent_Max: win32more.Windows.Win32.Web.MsHtml.htmlComponent = 2147483647
htmlControlAlign = Int32
htmlControlAlignNotSet: win32more.Windows.Win32.Web.MsHtml.htmlControlAlign = 0
htmlControlAlignLeft: win32more.Windows.Win32.Web.MsHtml.htmlControlAlign = 1
htmlControlAlignCenter: win32more.Windows.Win32.Web.MsHtml.htmlControlAlign = 2
htmlControlAlignRight: win32more.Windows.Win32.Web.MsHtml.htmlControlAlign = 3
htmlControlAlignTextTop: win32more.Windows.Win32.Web.MsHtml.htmlControlAlign = 4
htmlControlAlignAbsMiddle: win32more.Windows.Win32.Web.MsHtml.htmlControlAlign = 5
htmlControlAlignBaseline: win32more.Windows.Win32.Web.MsHtml.htmlControlAlign = 6
htmlControlAlignAbsBottom: win32more.Windows.Win32.Web.MsHtml.htmlControlAlign = 7
htmlControlAlignBottom: win32more.Windows.Win32.Web.MsHtml.htmlControlAlign = 8
htmlControlAlignMiddle: win32more.Windows.Win32.Web.MsHtml.htmlControlAlign = 9
htmlControlAlignTop: win32more.Windows.Win32.Web.MsHtml.htmlControlAlign = 10
htmlControlAlign_Max: win32more.Windows.Win32.Web.MsHtml.htmlControlAlign = 2147483647
htmlDesignMode = Int32
htmlDesignModeInherit: win32more.Windows.Win32.Web.MsHtml.htmlDesignMode = -2
htmlDesignModeOn: win32more.Windows.Win32.Web.MsHtml.htmlDesignMode = -1
htmlDesignModeOff: win32more.Windows.Win32.Web.MsHtml.htmlDesignMode = 0
htmlDesignMode_Max: win32more.Windows.Win32.Web.MsHtml.htmlDesignMode = 2147483647
htmlDir = Int32
htmlDirNotSet: win32more.Windows.Win32.Web.MsHtml.htmlDir = 0
htmlDirLeftToRight: win32more.Windows.Win32.Web.MsHtml.htmlDir = 1
htmlDirRightToLeft: win32more.Windows.Win32.Web.MsHtml.htmlDir = 2
htmlDir_Max: win32more.Windows.Win32.Web.MsHtml.htmlDir = 2147483647
htmlDirection = Int32
htmlDirectionForward: win32more.Windows.Win32.Web.MsHtml.htmlDirection = 99999
htmlDirectionBackward: win32more.Windows.Win32.Web.MsHtml.htmlDirection = -99999
htmlDirection_Max: win32more.Windows.Win32.Web.MsHtml.htmlDirection = 2147483647
htmlDraggable = Int32
htmlDraggableAuto: win32more.Windows.Win32.Web.MsHtml.htmlDraggable = 0
htmlDraggableTrue: win32more.Windows.Win32.Web.MsHtml.htmlDraggable = 1
htmlDraggableFalse: win32more.Windows.Win32.Web.MsHtml.htmlDraggable = 2
htmlDraggable_Max: win32more.Windows.Win32.Web.MsHtml.htmlDraggable = 2147483647
htmlDropEffect = Int32
htmlDropEffectCopy: win32more.Windows.Win32.Web.MsHtml.htmlDropEffect = 0
htmlDropEffectLink: win32more.Windows.Win32.Web.MsHtml.htmlDropEffect = 1
htmlDropEffectMove: win32more.Windows.Win32.Web.MsHtml.htmlDropEffect = 2
htmlDropEffectNone: win32more.Windows.Win32.Web.MsHtml.htmlDropEffect = 3
htmlDropEffect_Max: win32more.Windows.Win32.Web.MsHtml.htmlDropEffect = 2147483647
htmlEditable = Int32
htmlEditableInherit: win32more.Windows.Win32.Web.MsHtml.htmlEditable = 0
htmlEditableTrue: win32more.Windows.Win32.Web.MsHtml.htmlEditable = 1
htmlEditableFalse: win32more.Windows.Win32.Web.MsHtml.htmlEditable = 2
htmlEditable_Max: win32more.Windows.Win32.Web.MsHtml.htmlEditable = 2147483647
htmlEffectAllowed = Int32
htmlEffectAllowedCopy: win32more.Windows.Win32.Web.MsHtml.htmlEffectAllowed = 0
htmlEffectAllowedLink: win32more.Windows.Win32.Web.MsHtml.htmlEffectAllowed = 1
htmlEffectAllowedMove: win32more.Windows.Win32.Web.MsHtml.htmlEffectAllowed = 2
htmlEffectAllowedCopyLink: win32more.Windows.Win32.Web.MsHtml.htmlEffectAllowed = 3
htmlEffectAllowedCopyMove: win32more.Windows.Win32.Web.MsHtml.htmlEffectAllowed = 4
htmlEffectAllowedLinkMove: win32more.Windows.Win32.Web.MsHtml.htmlEffectAllowed = 5
htmlEffectAllowedAll: win32more.Windows.Win32.Web.MsHtml.htmlEffectAllowed = 6
htmlEffectAllowedNone: win32more.Windows.Win32.Web.MsHtml.htmlEffectAllowed = 7
htmlEffectAllowedUninitialized: win32more.Windows.Win32.Web.MsHtml.htmlEffectAllowed = 8
htmlEffectAllowed_Max: win32more.Windows.Win32.Web.MsHtml.htmlEffectAllowed = 2147483647
htmlEncoding = Int32
htmlEncodingURL: win32more.Windows.Win32.Web.MsHtml.htmlEncoding = 0
htmlEncodingMultipart: win32more.Windows.Win32.Web.MsHtml.htmlEncoding = 1
htmlEncodingText: win32more.Windows.Win32.Web.MsHtml.htmlEncoding = 2
htmlEncoding_Max: win32more.Windows.Win32.Web.MsHtml.htmlEncoding = 2147483647
htmlEndPoints = Int32
htmlEndPointsStartToStart: win32more.Windows.Win32.Web.MsHtml.htmlEndPoints = 1
htmlEndPointsStartToEnd: win32more.Windows.Win32.Web.MsHtml.htmlEndPoints = 2
htmlEndPointsEndToStart: win32more.Windows.Win32.Web.MsHtml.htmlEndPoints = 3
htmlEndPointsEndToEnd: win32more.Windows.Win32.Web.MsHtml.htmlEndPoints = 4
htmlEndPoints_Max: win32more.Windows.Win32.Web.MsHtml.htmlEndPoints = 2147483647
htmlFrame = Int32
htmlFrameNotSet: win32more.Windows.Win32.Web.MsHtml.htmlFrame = 0
htmlFramevoid: win32more.Windows.Win32.Web.MsHtml.htmlFrame = 1
htmlFrameabove: win32more.Windows.Win32.Web.MsHtml.htmlFrame = 2
htmlFramebelow: win32more.Windows.Win32.Web.MsHtml.htmlFrame = 3
htmlFramehsides: win32more.Windows.Win32.Web.MsHtml.htmlFrame = 4
htmlFramelhs: win32more.Windows.Win32.Web.MsHtml.htmlFrame = 5
htmlFramerhs: win32more.Windows.Win32.Web.MsHtml.htmlFrame = 6
htmlFramevsides: win32more.Windows.Win32.Web.MsHtml.htmlFrame = 7
htmlFramebox: win32more.Windows.Win32.Web.MsHtml.htmlFrame = 8
htmlFrameborder: win32more.Windows.Win32.Web.MsHtml.htmlFrame = 9
htmlFrame_Max: win32more.Windows.Win32.Web.MsHtml.htmlFrame = 2147483647
htmlGlyphMode = Int32
htmlGlyphModeNone: win32more.Windows.Win32.Web.MsHtml.htmlGlyphMode = 0
htmlGlyphModeBegin: win32more.Windows.Win32.Web.MsHtml.htmlGlyphMode = 1
htmlGlyphModeEnd: win32more.Windows.Win32.Web.MsHtml.htmlGlyphMode = 2
htmlGlyphModeBoth: win32more.Windows.Win32.Web.MsHtml.htmlGlyphMode = 3
htmlGlyphMode_Max: win32more.Windows.Win32.Web.MsHtml.htmlGlyphMode = 2147483647
htmlInput = Int32
htmlInputNotSet: win32more.Windows.Win32.Web.MsHtml.htmlInput = 0
htmlInputButton: win32more.Windows.Win32.Web.MsHtml.htmlInput = 1
htmlInputCheckbox: win32more.Windows.Win32.Web.MsHtml.htmlInput = 2
htmlInputFile: win32more.Windows.Win32.Web.MsHtml.htmlInput = 3
htmlInputHidden: win32more.Windows.Win32.Web.MsHtml.htmlInput = 4
htmlInputImage: win32more.Windows.Win32.Web.MsHtml.htmlInput = 5
htmlInputPassword: win32more.Windows.Win32.Web.MsHtml.htmlInput = 6
htmlInputRadio: win32more.Windows.Win32.Web.MsHtml.htmlInput = 7
htmlInputReset: win32more.Windows.Win32.Web.MsHtml.htmlInput = 8
htmlInputSelectOne: win32more.Windows.Win32.Web.MsHtml.htmlInput = 9
htmlInputSelectMultiple: win32more.Windows.Win32.Web.MsHtml.htmlInput = 10
htmlInputSubmit: win32more.Windows.Win32.Web.MsHtml.htmlInput = 11
htmlInputText: win32more.Windows.Win32.Web.MsHtml.htmlInput = 12
htmlInputTextarea: win32more.Windows.Win32.Web.MsHtml.htmlInput = 13
htmlInputRichtext: win32more.Windows.Win32.Web.MsHtml.htmlInput = 14
htmlInputRange: win32more.Windows.Win32.Web.MsHtml.htmlInput = 15
htmlInputUrl: win32more.Windows.Win32.Web.MsHtml.htmlInput = 16
htmlInputEmail: win32more.Windows.Win32.Web.MsHtml.htmlInput = 17
htmlInputNumber: win32more.Windows.Win32.Web.MsHtml.htmlInput = 18
htmlInputTel: win32more.Windows.Win32.Web.MsHtml.htmlInput = 19
htmlInputSearch: win32more.Windows.Win32.Web.MsHtml.htmlInput = 20
htmlInput_Max: win32more.Windows.Win32.Web.MsHtml.htmlInput = 2147483647
htmlListType = Int32
htmlListTypeNotSet: win32more.Windows.Win32.Web.MsHtml.htmlListType = 0
htmlListTypeLargeAlpha: win32more.Windows.Win32.Web.MsHtml.htmlListType = 1
htmlListTypeSmallAlpha: win32more.Windows.Win32.Web.MsHtml.htmlListType = 2
htmlListTypeLargeRoman: win32more.Windows.Win32.Web.MsHtml.htmlListType = 3
htmlListTypeSmallRoman: win32more.Windows.Win32.Web.MsHtml.htmlListType = 4
htmlListTypeNumbers: win32more.Windows.Win32.Web.MsHtml.htmlListType = 5
htmlListTypeDisc: win32more.Windows.Win32.Web.MsHtml.htmlListType = 6
htmlListTypeCircle: win32more.Windows.Win32.Web.MsHtml.htmlListType = 7
htmlListTypeSquare: win32more.Windows.Win32.Web.MsHtml.htmlListType = 8
htmlListType_Max: win32more.Windows.Win32.Web.MsHtml.htmlListType = 2147483647
htmlLoop = Int32
htmlLoopLoopInfinite: win32more.Windows.Win32.Web.MsHtml.htmlLoop = -1
htmlLoop_Max: win32more.Windows.Win32.Web.MsHtml.htmlLoop = 2147483647
htmlMarqueeBehavior = Int32
htmlMarqueeBehaviorscroll: win32more.Windows.Win32.Web.MsHtml.htmlMarqueeBehavior = 1
htmlMarqueeBehaviorslide: win32more.Windows.Win32.Web.MsHtml.htmlMarqueeBehavior = 2
htmlMarqueeBehavioralternate: win32more.Windows.Win32.Web.MsHtml.htmlMarqueeBehavior = 3
htmlMarqueeBehavior_Max: win32more.Windows.Win32.Web.MsHtml.htmlMarqueeBehavior = 2147483647
htmlMarqueeDirection = Int32
htmlMarqueeDirectionleft: win32more.Windows.Win32.Web.MsHtml.htmlMarqueeDirection = 1
htmlMarqueeDirectionright: win32more.Windows.Win32.Web.MsHtml.htmlMarqueeDirection = 3
htmlMarqueeDirectionup: win32more.Windows.Win32.Web.MsHtml.htmlMarqueeDirection = 5
htmlMarqueeDirectiondown: win32more.Windows.Win32.Web.MsHtml.htmlMarqueeDirection = 7
htmlMarqueeDirection_Max: win32more.Windows.Win32.Web.MsHtml.htmlMarqueeDirection = 2147483647
htmlMediaErr = Int32
htmlMediaErrAborted: win32more.Windows.Win32.Web.MsHtml.htmlMediaErr = 0
htmlMediaErrNetwork: win32more.Windows.Win32.Web.MsHtml.htmlMediaErr = 1
htmlMediaErrDecode: win32more.Windows.Win32.Web.MsHtml.htmlMediaErr = 2
htmlMediaErrSrcNotSupported: win32more.Windows.Win32.Web.MsHtml.htmlMediaErr = 3
htmlMediaErr_Max: win32more.Windows.Win32.Web.MsHtml.htmlMediaErr = 2147483647
htmlMediaNetworkState = Int32
htmlMediaNetworkStateEmpty: win32more.Windows.Win32.Web.MsHtml.htmlMediaNetworkState = 0
htmlMediaNetworkStateIdle: win32more.Windows.Win32.Web.MsHtml.htmlMediaNetworkState = 1
htmlMediaNetworkStateLoading: win32more.Windows.Win32.Web.MsHtml.htmlMediaNetworkState = 2
htmlMediaNetworkStateNoSource: win32more.Windows.Win32.Web.MsHtml.htmlMediaNetworkState = 3
htmlMediaNetworkState_Max: win32more.Windows.Win32.Web.MsHtml.htmlMediaNetworkState = 2147483647
htmlMediaReadyState = Int32
htmlMediaReadyStateHaveNothing: win32more.Windows.Win32.Web.MsHtml.htmlMediaReadyState = 0
htmlMediaReadyStateHaveMetadata: win32more.Windows.Win32.Web.MsHtml.htmlMediaReadyState = 1
htmlMediaReadyStateHaveCurrentData: win32more.Windows.Win32.Web.MsHtml.htmlMediaReadyState = 2
htmlMediaReadyStateHaveFutureData: win32more.Windows.Win32.Web.MsHtml.htmlMediaReadyState = 3
htmlMediaReadyStateHaveEnoughData: win32more.Windows.Win32.Web.MsHtml.htmlMediaReadyState = 4
htmlMediaReadyState_Max: win32more.Windows.Win32.Web.MsHtml.htmlMediaReadyState = 2147483647
htmlMethod = Int32
htmlMethodNotSet: win32more.Windows.Win32.Web.MsHtml.htmlMethod = 0
htmlMethodGet: win32more.Windows.Win32.Web.MsHtml.htmlMethod = 1
htmlMethodPost: win32more.Windows.Win32.Web.MsHtml.htmlMethod = 2
htmlMethod_Max: win32more.Windows.Win32.Web.MsHtml.htmlMethod = 2147483647
htmlPersistState = Int32
htmlPersistStateNormal: win32more.Windows.Win32.Web.MsHtml.htmlPersistState = 0
htmlPersistStateFavorite: win32more.Windows.Win32.Web.MsHtml.htmlPersistState = 1
htmlPersistStateHistory: win32more.Windows.Win32.Web.MsHtml.htmlPersistState = 2
htmlPersistStateSnapshot: win32more.Windows.Win32.Web.MsHtml.htmlPersistState = 3
htmlPersistStateUserData: win32more.Windows.Win32.Web.MsHtml.htmlPersistState = 4
htmlPersistState_Max: win32more.Windows.Win32.Web.MsHtml.htmlPersistState = 2147483647
htmlReadyState = Int32
htmlReadyStateuninitialized: win32more.Windows.Win32.Web.MsHtml.htmlReadyState = 0
htmlReadyStateloading: win32more.Windows.Win32.Web.MsHtml.htmlReadyState = 1
htmlReadyStateloaded: win32more.Windows.Win32.Web.MsHtml.htmlReadyState = 2
htmlReadyStateinteractive: win32more.Windows.Win32.Web.MsHtml.htmlReadyState = 3
htmlReadyStatecomplete: win32more.Windows.Win32.Web.MsHtml.htmlReadyState = 4
htmlReadyState_Max: win32more.Windows.Win32.Web.MsHtml.htmlReadyState = 2147483647
htmlRules = Int32
htmlRulesNotSet: win32more.Windows.Win32.Web.MsHtml.htmlRules = 0
htmlRulesnone: win32more.Windows.Win32.Web.MsHtml.htmlRules = 1
htmlRulesgroups: win32more.Windows.Win32.Web.MsHtml.htmlRules = 2
htmlRulesrows: win32more.Windows.Win32.Web.MsHtml.htmlRules = 3
htmlRulescols: win32more.Windows.Win32.Web.MsHtml.htmlRules = 4
htmlRulesall: win32more.Windows.Win32.Web.MsHtml.htmlRules = 5
htmlRules_Max: win32more.Windows.Win32.Web.MsHtml.htmlRules = 2147483647
htmlSelectExFlag = Int32
htmlSelectExFlagNone: win32more.Windows.Win32.Web.MsHtml.htmlSelectExFlag = 0
htmlSelectExFlagHideSelectionInDesign: win32more.Windows.Win32.Web.MsHtml.htmlSelectExFlag = 1
htmlSelectExFlag_Max: win32more.Windows.Win32.Web.MsHtml.htmlSelectExFlag = 2147483647
htmlSelectType = Int32
htmlSelectTypeSelectOne: win32more.Windows.Win32.Web.MsHtml.htmlSelectType = 1
htmlSelectTypeSelectMultiple: win32more.Windows.Win32.Web.MsHtml.htmlSelectType = 2
htmlSelectType_Max: win32more.Windows.Win32.Web.MsHtml.htmlSelectType = 2147483647
htmlSelection = Int32
htmlSelectionNone: win32more.Windows.Win32.Web.MsHtml.htmlSelection = 0
htmlSelectionText: win32more.Windows.Win32.Web.MsHtml.htmlSelection = 1
htmlSelectionControl: win32more.Windows.Win32.Web.MsHtml.htmlSelection = 2
htmlSelectionTable: win32more.Windows.Win32.Web.MsHtml.htmlSelection = 3
htmlSelection_Max: win32more.Windows.Win32.Web.MsHtml.htmlSelection = 2147483647
htmlSpellCheck = Int32
htmlSpellCheckNotSet: win32more.Windows.Win32.Web.MsHtml.htmlSpellCheck = 0
htmlSpellCheckTrue: win32more.Windows.Win32.Web.MsHtml.htmlSpellCheck = 1
htmlSpellCheckFalse: win32more.Windows.Win32.Web.MsHtml.htmlSpellCheck = 2
htmlSpellCheckDefault: win32more.Windows.Win32.Web.MsHtml.htmlSpellCheck = 3
htmlSpellCheck_Max: win32more.Windows.Win32.Web.MsHtml.htmlSpellCheck = 2147483647
htmlStart = Int32
htmlStartfileopen: win32more.Windows.Win32.Web.MsHtml.htmlStart = 0
htmlStartmouseover: win32more.Windows.Win32.Web.MsHtml.htmlStart = 1
htmlStart_Max: win32more.Windows.Win32.Web.MsHtml.htmlStart = 2147483647
htmlTabIndex = Int32
htmlTabIndexNotSet: win32more.Windows.Win32.Web.MsHtml.htmlTabIndex = -32768
htmlTabIndex_Max: win32more.Windows.Win32.Web.MsHtml.htmlTabIndex = 2147483647
htmlUnit = Int32
htmlUnitCharacter: win32more.Windows.Win32.Web.MsHtml.htmlUnit = 1
htmlUnitWord: win32more.Windows.Win32.Web.MsHtml.htmlUnit = 2
htmlUnitSentence: win32more.Windows.Win32.Web.MsHtml.htmlUnit = 3
htmlUnitTextEdit: win32more.Windows.Win32.Web.MsHtml.htmlUnit = 6
htmlUnit_Max: win32more.Windows.Win32.Web.MsHtml.htmlUnit = 2147483647
htmlWrap = Int32
htmlWrapOff: win32more.Windows.Win32.Web.MsHtml.htmlWrap = 1
htmlWrapSoft: win32more.Windows.Win32.Web.MsHtml.htmlWrap = 2
htmlWrapHard: win32more.Windows.Win32.Web.MsHtml.htmlWrap = 3
htmlWrap_Max: win32more.Windows.Win32.Web.MsHtml.htmlWrap = 2147483647
htmlZOrder = Int32
htmlZOrderFront: win32more.Windows.Win32.Web.MsHtml.htmlZOrder = 0
htmlZOrderBack: win32more.Windows.Win32.Web.MsHtml.htmlZOrder = 1
htmlZOrder_Max: win32more.Windows.Win32.Web.MsHtml.htmlZOrder = 2147483647
lengthAdjust = Int32
LENGTHADJUST_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.lengthAdjust = 0
LENGTHADJUST_SPACING: win32more.Windows.Win32.Web.MsHtml.lengthAdjust = 1
LENGTHADJUST_SPACINGANDGLYPHS: win32more.Windows.Win32.Web.MsHtml.lengthAdjust = 2
lengthAdjust_Max: win32more.Windows.Win32.Web.MsHtml.lengthAdjust = 2147483647
mediaType = Int32
mediaTypeNotSet: win32more.Windows.Win32.Web.MsHtml.mediaType = 0
mediaTypeAll: win32more.Windows.Win32.Web.MsHtml.mediaType = 511
mediaTypeAural: win32more.Windows.Win32.Web.MsHtml.mediaType = 1
mediaTypeBraille: win32more.Windows.Win32.Web.MsHtml.mediaType = 2
mediaTypeEmbossed: win32more.Windows.Win32.Web.MsHtml.mediaType = 4
mediaTypeHandheld: win32more.Windows.Win32.Web.MsHtml.mediaType = 8
mediaTypePrint: win32more.Windows.Win32.Web.MsHtml.mediaType = 16
mediaTypeProjection: win32more.Windows.Win32.Web.MsHtml.mediaType = 32
mediaTypeScreen: win32more.Windows.Win32.Web.MsHtml.mediaType = 64
mediaTypeTty: win32more.Windows.Win32.Web.MsHtml.mediaType = 128
mediaTypeTv: win32more.Windows.Win32.Web.MsHtml.mediaType = 256
mediaType_Max: win32more.Windows.Win32.Web.MsHtml.mediaType = 2147483647
sandboxAllow = Int32
sandboxAllowScripts: win32more.Windows.Win32.Web.MsHtml.sandboxAllow = 0
sandboxAllowSameOrigin: win32more.Windows.Win32.Web.MsHtml.sandboxAllow = 1
sandboxAllowTopNavigation: win32more.Windows.Win32.Web.MsHtml.sandboxAllow = 2
sandboxAllowForms: win32more.Windows.Win32.Web.MsHtml.sandboxAllow = 3
sandboxAllowPopups: win32more.Windows.Win32.Web.MsHtml.sandboxAllow = 4
sandboxAllow_Max: win32more.Windows.Win32.Web.MsHtml.sandboxAllow = 2147483647
styleAccelerator = Int32
styleAcceleratorFalse: win32more.Windows.Win32.Web.MsHtml.styleAccelerator = 0
styleAcceleratorTrue: win32more.Windows.Win32.Web.MsHtml.styleAccelerator = 1
styleAccelerator_Max: win32more.Windows.Win32.Web.MsHtml.styleAccelerator = 2147483647
styleAlignContent = Int32
styleAlignContentFlexStart: win32more.Windows.Win32.Web.MsHtml.styleAlignContent = 0
styleAlignContentFlexEnd: win32more.Windows.Win32.Web.MsHtml.styleAlignContent = 1
styleAlignContentCenter: win32more.Windows.Win32.Web.MsHtml.styleAlignContent = 2
styleAlignContentSpaceBetween: win32more.Windows.Win32.Web.MsHtml.styleAlignContent = 3
styleAlignContentSpaceAround: win32more.Windows.Win32.Web.MsHtml.styleAlignContent = 4
styleAlignContentStretch: win32more.Windows.Win32.Web.MsHtml.styleAlignContent = 5
styleAlignContentNotSet: win32more.Windows.Win32.Web.MsHtml.styleAlignContent = 6
styleAlignContent_Max: win32more.Windows.Win32.Web.MsHtml.styleAlignContent = 2147483647
styleAlignItems = Int32
styleAlignItemsFlexStart: win32more.Windows.Win32.Web.MsHtml.styleAlignItems = 0
styleAlignItemsFlexEnd: win32more.Windows.Win32.Web.MsHtml.styleAlignItems = 1
styleAlignItemsCenter: win32more.Windows.Win32.Web.MsHtml.styleAlignItems = 2
styleAlignItemsBaseline: win32more.Windows.Win32.Web.MsHtml.styleAlignItems = 3
styleAlignItemsStretch: win32more.Windows.Win32.Web.MsHtml.styleAlignItems = 4
styleAlignItemsNotSet: win32more.Windows.Win32.Web.MsHtml.styleAlignItems = 5
styleAlignItems_Max: win32more.Windows.Win32.Web.MsHtml.styleAlignItems = 2147483647
styleAlignSelf = Int32
styleAlignSelfFlexStart: win32more.Windows.Win32.Web.MsHtml.styleAlignSelf = 0
styleAlignSelfFlexEnd: win32more.Windows.Win32.Web.MsHtml.styleAlignSelf = 1
styleAlignSelfCenter: win32more.Windows.Win32.Web.MsHtml.styleAlignSelf = 2
styleAlignSelfBaseline: win32more.Windows.Win32.Web.MsHtml.styleAlignSelf = 3
styleAlignSelfStretch: win32more.Windows.Win32.Web.MsHtml.styleAlignSelf = 4
styleAlignSelfAuto: win32more.Windows.Win32.Web.MsHtml.styleAlignSelf = 5
styleAlignSelfNotSet: win32more.Windows.Win32.Web.MsHtml.styleAlignSelf = 6
styleAlignSelf_Max: win32more.Windows.Win32.Web.MsHtml.styleAlignSelf = 2147483647
styleAlignmentBaseline = Int32
styleAlignmentBaselineNotSet: win32more.Windows.Win32.Web.MsHtml.styleAlignmentBaseline = 0
styleAlignmentBaselineAfterEdge: win32more.Windows.Win32.Web.MsHtml.styleAlignmentBaseline = 1
styleAlignmentBaselineAlphabetic: win32more.Windows.Win32.Web.MsHtml.styleAlignmentBaseline = 2
styleAlignmentBaselineAuto: win32more.Windows.Win32.Web.MsHtml.styleAlignmentBaseline = 3
styleAlignmentBaselineBaseline: win32more.Windows.Win32.Web.MsHtml.styleAlignmentBaseline = 4
styleAlignmentBaselineBeforeEdge: win32more.Windows.Win32.Web.MsHtml.styleAlignmentBaseline = 5
styleAlignmentBaselineCentral: win32more.Windows.Win32.Web.MsHtml.styleAlignmentBaseline = 6
styleAlignmentBaselineHanging: win32more.Windows.Win32.Web.MsHtml.styleAlignmentBaseline = 7
styleAlignmentBaselineMathematical: win32more.Windows.Win32.Web.MsHtml.styleAlignmentBaseline = 8
styleAlignmentBaselineMiddle: win32more.Windows.Win32.Web.MsHtml.styleAlignmentBaseline = 9
styleAlignmentBaselineTextAfterEdge: win32more.Windows.Win32.Web.MsHtml.styleAlignmentBaseline = 10
styleAlignmentBaselineTextBeforeEdge: win32more.Windows.Win32.Web.MsHtml.styleAlignmentBaseline = 11
styleAlignmentBaselineIdeographic: win32more.Windows.Win32.Web.MsHtml.styleAlignmentBaseline = 12
styleAlignmentBaseline_Max: win32more.Windows.Win32.Web.MsHtml.styleAlignmentBaseline = 2147483647
styleAttrType = Int32
styleAttrTypeString: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 0
styleAttrTypeColor: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 1
styleAttrTypeUrl: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 2
styleAttrTypeInteger: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 3
styleAttrTypeNumber: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 4
styleAttrTypeLength: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 5
styleAttrTypePx: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 6
styleAttrTypeEm: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 7
styleAttrTypeEx: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 8
styleAttrTypeIn: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 9
styleAttrTypeCm: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 10
styleAttrTypeMm: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 11
styleAttrTypePt: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 12
styleAttrTypePc: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 13
styleAttrTypeRem: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 14
styleAttrTypeCh: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 15
styleAttrTypeVh: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 16
styleAttrTypeVw: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 17
styleAttrTypeVmin: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 18
styleAttrTypePercentage: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 19
styleAttrTypeAngle: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 20
styleAttrTypeDeg: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 21
styleAttrTypeRad: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 22
styleAttrTypeGrad: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 23
styleAttrTypeTime: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 24
styleAttrTypeS: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 25
styleAttrTypeMs: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 26
styleAttrType_Max: win32more.Windows.Win32.Web.MsHtml.styleAttrType = 2147483647
styleAuto = Int32
styleAutoAuto: win32more.Windows.Win32.Web.MsHtml.styleAuto = 0
styleAuto_Max: win32more.Windows.Win32.Web.MsHtml.styleAuto = 2147483647
styleBackfaceVisibility = Int32
styleBackfaceVisibilityVisible: win32more.Windows.Win32.Web.MsHtml.styleBackfaceVisibility = 0
styleBackfaceVisibilityHidden: win32more.Windows.Win32.Web.MsHtml.styleBackfaceVisibility = 1
styleBackfaceVisibilityNotSet: win32more.Windows.Win32.Web.MsHtml.styleBackfaceVisibility = 2
styleBackfaceVisibility_Max: win32more.Windows.Win32.Web.MsHtml.styleBackfaceVisibility = 2147483647
styleBackgroundAttachment = Int32
styleBackgroundAttachmentFixed: win32more.Windows.Win32.Web.MsHtml.styleBackgroundAttachment = 0
styleBackgroundAttachmentScroll: win32more.Windows.Win32.Web.MsHtml.styleBackgroundAttachment = 1
styleBackgroundAttachmentNotSet: win32more.Windows.Win32.Web.MsHtml.styleBackgroundAttachment = 2
styleBackgroundAttachment_Max: win32more.Windows.Win32.Web.MsHtml.styleBackgroundAttachment = 2147483647
styleBackgroundAttachment3 = Int32
styleBackgroundAttachment3Fixed: win32more.Windows.Win32.Web.MsHtml.styleBackgroundAttachment3 = 0
styleBackgroundAttachment3Scroll: win32more.Windows.Win32.Web.MsHtml.styleBackgroundAttachment3 = 1
styleBackgroundAttachment3Local: win32more.Windows.Win32.Web.MsHtml.styleBackgroundAttachment3 = 2
styleBackgroundAttachment3NotSet: win32more.Windows.Win32.Web.MsHtml.styleBackgroundAttachment3 = 3
styleBackgroundAttachment3_Max: win32more.Windows.Win32.Web.MsHtml.styleBackgroundAttachment3 = 2147483647
styleBackgroundClip = Int32
styleBackgroundClipBorderBox: win32more.Windows.Win32.Web.MsHtml.styleBackgroundClip = 0
styleBackgroundClipPaddingBox: win32more.Windows.Win32.Web.MsHtml.styleBackgroundClip = 1
styleBackgroundClipContentBox: win32more.Windows.Win32.Web.MsHtml.styleBackgroundClip = 2
styleBackgroundClipNotSet: win32more.Windows.Win32.Web.MsHtml.styleBackgroundClip = 3
styleBackgroundClip_Max: win32more.Windows.Win32.Web.MsHtml.styleBackgroundClip = 2147483647
styleBackgroundOrigin = Int32
styleBackgroundOriginBorderBox: win32more.Windows.Win32.Web.MsHtml.styleBackgroundOrigin = 0
styleBackgroundOriginPaddingBox: win32more.Windows.Win32.Web.MsHtml.styleBackgroundOrigin = 1
styleBackgroundOriginContentBox: win32more.Windows.Win32.Web.MsHtml.styleBackgroundOrigin = 2
styleBackgroundOriginNotSet: win32more.Windows.Win32.Web.MsHtml.styleBackgroundOrigin = 3
styleBackgroundOrigin_Max: win32more.Windows.Win32.Web.MsHtml.styleBackgroundOrigin = 2147483647
styleBackgroundRepeat = Int32
styleBackgroundRepeatRepeat: win32more.Windows.Win32.Web.MsHtml.styleBackgroundRepeat = 0
styleBackgroundRepeatRepeatX: win32more.Windows.Win32.Web.MsHtml.styleBackgroundRepeat = 1
styleBackgroundRepeatRepeatY: win32more.Windows.Win32.Web.MsHtml.styleBackgroundRepeat = 2
styleBackgroundRepeatNoRepeat: win32more.Windows.Win32.Web.MsHtml.styleBackgroundRepeat = 3
styleBackgroundRepeatNotSet: win32more.Windows.Win32.Web.MsHtml.styleBackgroundRepeat = 4
styleBackgroundRepeat_Max: win32more.Windows.Win32.Web.MsHtml.styleBackgroundRepeat = 2147483647
styleBaselineShift = Int32
styleBaselineShiftBaseline: win32more.Windows.Win32.Web.MsHtml.styleBaselineShift = 0
styleBaselineShiftSub: win32more.Windows.Win32.Web.MsHtml.styleBaselineShift = 1
styleBaselineShiftSuper: win32more.Windows.Win32.Web.MsHtml.styleBaselineShift = 2
styleBaselineShift_Max: win32more.Windows.Win32.Web.MsHtml.styleBaselineShift = 2147483647
styleBidi = Int32
styleBidiNotSet: win32more.Windows.Win32.Web.MsHtml.styleBidi = 0
styleBidiNormal: win32more.Windows.Win32.Web.MsHtml.styleBidi = 1
styleBidiEmbed: win32more.Windows.Win32.Web.MsHtml.styleBidi = 2
styleBidiOverride: win32more.Windows.Win32.Web.MsHtml.styleBidi = 3
styleBidiInherit: win32more.Windows.Win32.Web.MsHtml.styleBidi = 4
styleBidi_Max: win32more.Windows.Win32.Web.MsHtml.styleBidi = 2147483647
styleBlockProgression = Int32
styleBlockProgressionTb: win32more.Windows.Win32.Web.MsHtml.styleBlockProgression = 0
styleBlockProgressionRl: win32more.Windows.Win32.Web.MsHtml.styleBlockProgression = 1
styleBlockProgressionBt: win32more.Windows.Win32.Web.MsHtml.styleBlockProgression = 2
styleBlockProgressionLr: win32more.Windows.Win32.Web.MsHtml.styleBlockProgression = 3
styleBlockProgressionNotSet: win32more.Windows.Win32.Web.MsHtml.styleBlockProgression = 4
styleBlockProgression_Max: win32more.Windows.Win32.Web.MsHtml.styleBlockProgression = 2147483647
styleBool = Int32
styleBoolFalse: win32more.Windows.Win32.Web.MsHtml.styleBool = 0
styleBoolTrue: win32more.Windows.Win32.Web.MsHtml.styleBool = 1
styleBool_Max: win32more.Windows.Win32.Web.MsHtml.styleBool = 2147483647
styleBorderCollapse = Int32
styleBorderCollapseNotSet: win32more.Windows.Win32.Web.MsHtml.styleBorderCollapse = 0
styleBorderCollapseSeparate: win32more.Windows.Win32.Web.MsHtml.styleBorderCollapse = 1
styleBorderCollapseCollapse: win32more.Windows.Win32.Web.MsHtml.styleBorderCollapse = 2
styleBorderCollapse_Max: win32more.Windows.Win32.Web.MsHtml.styleBorderCollapse = 2147483647
styleBorderImageRepeat = Int32
styleBorderImageRepeatStretch: win32more.Windows.Win32.Web.MsHtml.styleBorderImageRepeat = 0
styleBorderImageRepeatRepeat: win32more.Windows.Win32.Web.MsHtml.styleBorderImageRepeat = 1
styleBorderImageRepeatRound: win32more.Windows.Win32.Web.MsHtml.styleBorderImageRepeat = 2
styleBorderImageRepeatSpace: win32more.Windows.Win32.Web.MsHtml.styleBorderImageRepeat = 3
styleBorderImageRepeatNotSet: win32more.Windows.Win32.Web.MsHtml.styleBorderImageRepeat = 4
styleBorderImageRepeat_Max: win32more.Windows.Win32.Web.MsHtml.styleBorderImageRepeat = 2147483647
styleBorderImageSliceFill = Int32
styleBorderImageSliceFillNotSet: win32more.Windows.Win32.Web.MsHtml.styleBorderImageSliceFill = 0
styleBorderImageSliceFillFill: win32more.Windows.Win32.Web.MsHtml.styleBorderImageSliceFill = 1
styleBorderImageSliceFill_Max: win32more.Windows.Win32.Web.MsHtml.styleBorderImageSliceFill = 2147483647
styleBorderStyle = Int32
styleBorderStyleNotSet: win32more.Windows.Win32.Web.MsHtml.styleBorderStyle = 0
styleBorderStyleDotted: win32more.Windows.Win32.Web.MsHtml.styleBorderStyle = 1
styleBorderStyleDashed: win32more.Windows.Win32.Web.MsHtml.styleBorderStyle = 2
styleBorderStyleSolid: win32more.Windows.Win32.Web.MsHtml.styleBorderStyle = 3
styleBorderStyleDouble: win32more.Windows.Win32.Web.MsHtml.styleBorderStyle = 4
styleBorderStyleGroove: win32more.Windows.Win32.Web.MsHtml.styleBorderStyle = 5
styleBorderStyleRidge: win32more.Windows.Win32.Web.MsHtml.styleBorderStyle = 6
styleBorderStyleInset: win32more.Windows.Win32.Web.MsHtml.styleBorderStyle = 7
styleBorderStyleOutset: win32more.Windows.Win32.Web.MsHtml.styleBorderStyle = 8
styleBorderStyleWindowInset: win32more.Windows.Win32.Web.MsHtml.styleBorderStyle = 9
styleBorderStyleNone: win32more.Windows.Win32.Web.MsHtml.styleBorderStyle = 10
styleBorderStyleHidden: win32more.Windows.Win32.Web.MsHtml.styleBorderStyle = 11
styleBorderStyle_Max: win32more.Windows.Win32.Web.MsHtml.styleBorderStyle = 2147483647
styleBorderWidth = Int32
styleBorderWidthThin: win32more.Windows.Win32.Web.MsHtml.styleBorderWidth = 0
styleBorderWidthMedium: win32more.Windows.Win32.Web.MsHtml.styleBorderWidth = 1
styleBorderWidthThick: win32more.Windows.Win32.Web.MsHtml.styleBorderWidth = 2
styleBorderWidth_Max: win32more.Windows.Win32.Web.MsHtml.styleBorderWidth = 2147483647
styleBoxSizing = Int32
styleBoxSizingNotSet: win32more.Windows.Win32.Web.MsHtml.styleBoxSizing = 0
styleBoxSizingContentBox: win32more.Windows.Win32.Web.MsHtml.styleBoxSizing = 1
styleBoxSizingBorderBox: win32more.Windows.Win32.Web.MsHtml.styleBoxSizing = 2
styleBoxSizing_Max: win32more.Windows.Win32.Web.MsHtml.styleBoxSizing = 2147483647
styleBreak = Int32
styleBreakNotSet: win32more.Windows.Win32.Web.MsHtml.styleBreak = 0
styleBreakAuto: win32more.Windows.Win32.Web.MsHtml.styleBreak = 1
styleBreakAlways: win32more.Windows.Win32.Web.MsHtml.styleBreak = 2
styleBreakAvoid: win32more.Windows.Win32.Web.MsHtml.styleBreak = 3
styleBreakLeft: win32more.Windows.Win32.Web.MsHtml.styleBreak = 4
styleBreakRight: win32more.Windows.Win32.Web.MsHtml.styleBreak = 5
styleBreakPage: win32more.Windows.Win32.Web.MsHtml.styleBreak = 6
styleBreakColumn: win32more.Windows.Win32.Web.MsHtml.styleBreak = 7
styleBreakAvoidPage: win32more.Windows.Win32.Web.MsHtml.styleBreak = 8
styleBreakAvoidColumn: win32more.Windows.Win32.Web.MsHtml.styleBreak = 9
styleBreak_Max: win32more.Windows.Win32.Web.MsHtml.styleBreak = 2147483647
styleBreakInside = Int32
styleBreakInsideNotSet: win32more.Windows.Win32.Web.MsHtml.styleBreakInside = 0
styleBreakInsideAuto: win32more.Windows.Win32.Web.MsHtml.styleBreakInside = 1
styleBreakInsideAvoid: win32more.Windows.Win32.Web.MsHtml.styleBreakInside = 2
styleBreakInsideAvoidPage: win32more.Windows.Win32.Web.MsHtml.styleBreakInside = 3
styleBreakInsideAvoidColumn: win32more.Windows.Win32.Web.MsHtml.styleBreakInside = 4
styleBreakInside_Max: win32more.Windows.Win32.Web.MsHtml.styleBreakInside = 2147483647
styleCaptionSide = Int32
styleCaptionSideNotSet: win32more.Windows.Win32.Web.MsHtml.styleCaptionSide = 0
styleCaptionSideTop: win32more.Windows.Win32.Web.MsHtml.styleCaptionSide = 1
styleCaptionSideBottom: win32more.Windows.Win32.Web.MsHtml.styleCaptionSide = 2
styleCaptionSideLeft: win32more.Windows.Win32.Web.MsHtml.styleCaptionSide = 3
styleCaptionSideRight: win32more.Windows.Win32.Web.MsHtml.styleCaptionSide = 4
styleCaptionSide_Max: win32more.Windows.Win32.Web.MsHtml.styleCaptionSide = 2147483647
styleClipRule = Int32
styleClipRuleNotSet: win32more.Windows.Win32.Web.MsHtml.styleClipRule = 0
styleClipRuleNonZero: win32more.Windows.Win32.Web.MsHtml.styleClipRule = 1
styleClipRuleEvenOdd: win32more.Windows.Win32.Web.MsHtml.styleClipRule = 2
styleClipRule_Max: win32more.Windows.Win32.Web.MsHtml.styleClipRule = 2147483647
styleColorInterpolationFilters = Int32
styleColorInterpolationFiltersAuto: win32more.Windows.Win32.Web.MsHtml.styleColorInterpolationFilters = 0
styleColorInterpolationFiltersSRgb: win32more.Windows.Win32.Web.MsHtml.styleColorInterpolationFilters = 1
styleColorInterpolationFiltersLinearRgb: win32more.Windows.Win32.Web.MsHtml.styleColorInterpolationFilters = 2
styleColorInterpolationFiltersNotSet: win32more.Windows.Win32.Web.MsHtml.styleColorInterpolationFilters = 3
styleColorInterpolationFilters_Max: win32more.Windows.Win32.Web.MsHtml.styleColorInterpolationFilters = 2147483647
styleColumnFill = Int32
styleColumnFillAuto: win32more.Windows.Win32.Web.MsHtml.styleColumnFill = 0
styleColumnFillBalance: win32more.Windows.Win32.Web.MsHtml.styleColumnFill = 1
styleColumnFillNotSet: win32more.Windows.Win32.Web.MsHtml.styleColumnFill = 2
styleColumnFill_Max: win32more.Windows.Win32.Web.MsHtml.styleColumnFill = 2147483647
styleColumnSpan = Int32
styleColumnSpanNone: win32more.Windows.Win32.Web.MsHtml.styleColumnSpan = 0
styleColumnSpanAll: win32more.Windows.Win32.Web.MsHtml.styleColumnSpan = 1
styleColumnSpanOne: win32more.Windows.Win32.Web.MsHtml.styleColumnSpan = 2
styleColumnSpanNotSet: win32more.Windows.Win32.Web.MsHtml.styleColumnSpan = 3
styleColumnSpan_Max: win32more.Windows.Win32.Web.MsHtml.styleColumnSpan = 2147483647
styleCursor = Int32
styleCursorAuto: win32more.Windows.Win32.Web.MsHtml.styleCursor = 0
styleCursorCrosshair: win32more.Windows.Win32.Web.MsHtml.styleCursor = 1
styleCursorDefault: win32more.Windows.Win32.Web.MsHtml.styleCursor = 2
styleCursorHand: win32more.Windows.Win32.Web.MsHtml.styleCursor = 3
styleCursorMove: win32more.Windows.Win32.Web.MsHtml.styleCursor = 4
styleCursorE_resize: win32more.Windows.Win32.Web.MsHtml.styleCursor = 5
styleCursorNe_resize: win32more.Windows.Win32.Web.MsHtml.styleCursor = 6
styleCursorNw_resize: win32more.Windows.Win32.Web.MsHtml.styleCursor = 7
styleCursorN_resize: win32more.Windows.Win32.Web.MsHtml.styleCursor = 8
styleCursorSe_resize: win32more.Windows.Win32.Web.MsHtml.styleCursor = 9
styleCursorSw_resize: win32more.Windows.Win32.Web.MsHtml.styleCursor = 10
styleCursorS_resize: win32more.Windows.Win32.Web.MsHtml.styleCursor = 11
styleCursorW_resize: win32more.Windows.Win32.Web.MsHtml.styleCursor = 12
styleCursorText: win32more.Windows.Win32.Web.MsHtml.styleCursor = 13
styleCursorWait: win32more.Windows.Win32.Web.MsHtml.styleCursor = 14
styleCursorHelp: win32more.Windows.Win32.Web.MsHtml.styleCursor = 15
styleCursorPointer: win32more.Windows.Win32.Web.MsHtml.styleCursor = 16
styleCursorProgress: win32more.Windows.Win32.Web.MsHtml.styleCursor = 17
styleCursorNot_allowed: win32more.Windows.Win32.Web.MsHtml.styleCursor = 18
styleCursorNo_drop: win32more.Windows.Win32.Web.MsHtml.styleCursor = 19
styleCursorVertical_text: win32more.Windows.Win32.Web.MsHtml.styleCursor = 20
styleCursorall_scroll: win32more.Windows.Win32.Web.MsHtml.styleCursor = 21
styleCursorcol_resize: win32more.Windows.Win32.Web.MsHtml.styleCursor = 22
styleCursorrow_resize: win32more.Windows.Win32.Web.MsHtml.styleCursor = 23
styleCursorNone: win32more.Windows.Win32.Web.MsHtml.styleCursor = 24
styleCursorContext_menu: win32more.Windows.Win32.Web.MsHtml.styleCursor = 25
styleCursorEw_resize: win32more.Windows.Win32.Web.MsHtml.styleCursor = 26
styleCursorNs_resize: win32more.Windows.Win32.Web.MsHtml.styleCursor = 27
styleCursorNesw_resize: win32more.Windows.Win32.Web.MsHtml.styleCursor = 28
styleCursorNwse_resize: win32more.Windows.Win32.Web.MsHtml.styleCursor = 29
styleCursorCell: win32more.Windows.Win32.Web.MsHtml.styleCursor = 30
styleCursorCopy: win32more.Windows.Win32.Web.MsHtml.styleCursor = 31
styleCursorAlias: win32more.Windows.Win32.Web.MsHtml.styleCursor = 32
styleCursorcustom: win32more.Windows.Win32.Web.MsHtml.styleCursor = 33
styleCursorNotSet: win32more.Windows.Win32.Web.MsHtml.styleCursor = 34
styleCursor_Max: win32more.Windows.Win32.Web.MsHtml.styleCursor = 2147483647
styleDataRepeat = Int32
styleDataRepeatNone: win32more.Windows.Win32.Web.MsHtml.styleDataRepeat = 0
styleDataRepeatInner: win32more.Windows.Win32.Web.MsHtml.styleDataRepeat = 1
styleDataRepeat_Max: win32more.Windows.Win32.Web.MsHtml.styleDataRepeat = 2147483647
styleDefaultTextSelection = Int32
styleDefaultTextSelectionFalse: win32more.Windows.Win32.Web.MsHtml.styleDefaultTextSelection = 0
styleDefaultTextSelectionTrue: win32more.Windows.Win32.Web.MsHtml.styleDefaultTextSelection = 1
styleDefaultTextSelection_Max: win32more.Windows.Win32.Web.MsHtml.styleDefaultTextSelection = 2147483647
styleDir = Int32
styleDirNotSet: win32more.Windows.Win32.Web.MsHtml.styleDir = 0
styleDirLeftToRight: win32more.Windows.Win32.Web.MsHtml.styleDir = 1
styleDirRightToLeft: win32more.Windows.Win32.Web.MsHtml.styleDir = 2
styleDirInherit: win32more.Windows.Win32.Web.MsHtml.styleDir = 3
styleDir_Max: win32more.Windows.Win32.Web.MsHtml.styleDir = 2147483647
styleDisplay = Int32
styleDisplayNotSet: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 0
styleDisplayBlock: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 1
styleDisplayInline: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 2
styleDisplayListItem: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 3
styleDisplayNone: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 4
styleDisplayTableHeaderGroup: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 5
styleDisplayTableFooterGroup: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 6
styleDisplayInlineBlock: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 7
styleDisplayTable: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 8
styleDisplayInlineTable: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 9
styleDisplayTableRow: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 10
styleDisplayTableRowGroup: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 11
styleDisplayTableColumn: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 12
styleDisplayTableColumnGroup: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 13
styleDisplayTableCell: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 14
styleDisplayTableCaption: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 15
styleDisplayRunIn: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 16
styleDisplayRuby: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 17
styleDisplayRubyBase: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 18
styleDisplayRubyText: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 19
styleDisplayRubyBaseContainer: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 20
styleDisplayRubyTextContainer: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 21
styleDisplayMsFlexbox: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 22
styleDisplayMsInlineFlexbox: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 23
styleDisplayMsGrid: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 24
styleDisplayMsInlineGrid: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 25
styleDisplayFlex: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 26
styleDisplayInlineFlex: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 27
styleDisplayWebkitBox: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 28
styleDisplayWebkitInlineBox: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 29
styleDisplay_Max: win32more.Windows.Win32.Web.MsHtml.styleDisplay = 2147483647
styleDominantBaseline = Int32
styleDominantBaselineNotSet: win32more.Windows.Win32.Web.MsHtml.styleDominantBaseline = 0
styleDominantBaselineAlphabetic: win32more.Windows.Win32.Web.MsHtml.styleDominantBaseline = 1
styleDominantBaselineAuto: win32more.Windows.Win32.Web.MsHtml.styleDominantBaseline = 2
styleDominantBaselineCentral: win32more.Windows.Win32.Web.MsHtml.styleDominantBaseline = 3
styleDominantBaselineHanging: win32more.Windows.Win32.Web.MsHtml.styleDominantBaseline = 4
styleDominantBaselineIdeographic: win32more.Windows.Win32.Web.MsHtml.styleDominantBaseline = 5
styleDominantBaselineMathematical: win32more.Windows.Win32.Web.MsHtml.styleDominantBaseline = 6
styleDominantBaselineMiddle: win32more.Windows.Win32.Web.MsHtml.styleDominantBaseline = 7
styleDominantBaselineNoChange: win32more.Windows.Win32.Web.MsHtml.styleDominantBaseline = 8
styleDominantBaselineResetSize: win32more.Windows.Win32.Web.MsHtml.styleDominantBaseline = 9
styleDominantBaselineTextAfterEdge: win32more.Windows.Win32.Web.MsHtml.styleDominantBaseline = 10
styleDominantBaselineTextBeforeEdge: win32more.Windows.Win32.Web.MsHtml.styleDominantBaseline = 11
styleDominantBaselineUseScript: win32more.Windows.Win32.Web.MsHtml.styleDominantBaseline = 12
styleDominantBaseline_Max: win32more.Windows.Win32.Web.MsHtml.styleDominantBaseline = 2147483647
styleEmptyCells = Int32
styleEmptyCellsNotSet: win32more.Windows.Win32.Web.MsHtml.styleEmptyCells = 0
styleEmptyCellsShow: win32more.Windows.Win32.Web.MsHtml.styleEmptyCells = 1
styleEmptyCellsHide: win32more.Windows.Win32.Web.MsHtml.styleEmptyCells = 2
styleEmptyCells_Max: win32more.Windows.Win32.Web.MsHtml.styleEmptyCells = 2147483647
styleEnableBackground = Int32
styleEnableBackgroundNotSet: win32more.Windows.Win32.Web.MsHtml.styleEnableBackground = 0
styleEnableBackgroundAccumulate: win32more.Windows.Win32.Web.MsHtml.styleEnableBackground = 1
styleEnableBackgroundNew: win32more.Windows.Win32.Web.MsHtml.styleEnableBackground = 2
styleEnableBackgroundInherit: win32more.Windows.Win32.Web.MsHtml.styleEnableBackground = 3
styleEnableBackground_Max: win32more.Windows.Win32.Web.MsHtml.styleEnableBackground = 2147483647
styleFillRule = Int32
styleFillRuleNotSet: win32more.Windows.Win32.Web.MsHtml.styleFillRule = 0
styleFillRuleNonZero: win32more.Windows.Win32.Web.MsHtml.styleFillRule = 1
styleFillRuleEvenOdd: win32more.Windows.Win32.Web.MsHtml.styleFillRule = 2
styleFillRule_Max: win32more.Windows.Win32.Web.MsHtml.styleFillRule = 2147483647
styleFlex = Int32
styleFlexNone: win32more.Windows.Win32.Web.MsHtml.styleFlex = 0
styleFlexNotSet: win32more.Windows.Win32.Web.MsHtml.styleFlex = 1
styleFlex_Max: win32more.Windows.Win32.Web.MsHtml.styleFlex = 2147483647
styleFlexBasis = Int32
styleFlexBasisAuto: win32more.Windows.Win32.Web.MsHtml.styleFlexBasis = 0
styleFlexBasisNotSet: win32more.Windows.Win32.Web.MsHtml.styleFlexBasis = 1
styleFlexBasis_Max: win32more.Windows.Win32.Web.MsHtml.styleFlexBasis = 2147483647
styleFlexDirection = Int32
styleFlexDirectionRow: win32more.Windows.Win32.Web.MsHtml.styleFlexDirection = 0
styleFlexDirectionRowReverse: win32more.Windows.Win32.Web.MsHtml.styleFlexDirection = 1
styleFlexDirectionColumn: win32more.Windows.Win32.Web.MsHtml.styleFlexDirection = 2
styleFlexDirectionColumnReverse: win32more.Windows.Win32.Web.MsHtml.styleFlexDirection = 3
styleFlexDirectionNotSet: win32more.Windows.Win32.Web.MsHtml.styleFlexDirection = 4
styleFlexDirection_Max: win32more.Windows.Win32.Web.MsHtml.styleFlexDirection = 2147483647
styleFlexWrap = Int32
styleFlexWrapNowrap: win32more.Windows.Win32.Web.MsHtml.styleFlexWrap = 0
styleFlexWrapWrap: win32more.Windows.Win32.Web.MsHtml.styleFlexWrap = 1
styleFlexWrapWrapReverse: win32more.Windows.Win32.Web.MsHtml.styleFlexWrap = 2
styleFlexWrapNotSet: win32more.Windows.Win32.Web.MsHtml.styleFlexWrap = 3
styleFlexWrap_Max: win32more.Windows.Win32.Web.MsHtml.styleFlexWrap = 2147483647
styleFontSize = Int32
styleFontSizeXXSmall: win32more.Windows.Win32.Web.MsHtml.styleFontSize = 0
styleFontSizeXSmall: win32more.Windows.Win32.Web.MsHtml.styleFontSize = 1
styleFontSizeSmall: win32more.Windows.Win32.Web.MsHtml.styleFontSize = 2
styleFontSizeMedium: win32more.Windows.Win32.Web.MsHtml.styleFontSize = 3
styleFontSizeLarge: win32more.Windows.Win32.Web.MsHtml.styleFontSize = 4
styleFontSizeXLarge: win32more.Windows.Win32.Web.MsHtml.styleFontSize = 5
styleFontSizeXXLarge: win32more.Windows.Win32.Web.MsHtml.styleFontSize = 6
styleFontSizeSmaller: win32more.Windows.Win32.Web.MsHtml.styleFontSize = 7
styleFontSizeLarger: win32more.Windows.Win32.Web.MsHtml.styleFontSize = 8
styleFontSize_Max: win32more.Windows.Win32.Web.MsHtml.styleFontSize = 2147483647
styleFontStretch = Int32
styleFontStretchNotSet: win32more.Windows.Win32.Web.MsHtml.styleFontStretch = 0
styleFontStretchWider: win32more.Windows.Win32.Web.MsHtml.styleFontStretch = 1
styleFontStretchNarrower: win32more.Windows.Win32.Web.MsHtml.styleFontStretch = 2
styleFontStretchUltraCondensed: win32more.Windows.Win32.Web.MsHtml.styleFontStretch = 3
styleFontStretchExtraCondensed: win32more.Windows.Win32.Web.MsHtml.styleFontStretch = 4
styleFontStretchCondensed: win32more.Windows.Win32.Web.MsHtml.styleFontStretch = 5
styleFontStretchSemiCondensed: win32more.Windows.Win32.Web.MsHtml.styleFontStretch = 6
styleFontStretchNormal: win32more.Windows.Win32.Web.MsHtml.styleFontStretch = 7
styleFontStretchSemiExpanded: win32more.Windows.Win32.Web.MsHtml.styleFontStretch = 8
styleFontStretchExpanded: win32more.Windows.Win32.Web.MsHtml.styleFontStretch = 9
styleFontStretchExtraExpanded: win32more.Windows.Win32.Web.MsHtml.styleFontStretch = 10
styleFontStretchUltraExpanded: win32more.Windows.Win32.Web.MsHtml.styleFontStretch = 11
styleFontStretch_Max: win32more.Windows.Win32.Web.MsHtml.styleFontStretch = 2147483647
styleFontStyle = Int32
styleFontStyleNotSet: win32more.Windows.Win32.Web.MsHtml.styleFontStyle = 0
styleFontStyleItalic: win32more.Windows.Win32.Web.MsHtml.styleFontStyle = 1
styleFontStyleOblique: win32more.Windows.Win32.Web.MsHtml.styleFontStyle = 2
styleFontStyleNormal: win32more.Windows.Win32.Web.MsHtml.styleFontStyle = 3
styleFontStyle_Max: win32more.Windows.Win32.Web.MsHtml.styleFontStyle = 2147483647
styleFontVariant = Int32
styleFontVariantNotSet: win32more.Windows.Win32.Web.MsHtml.styleFontVariant = 0
styleFontVariantSmallCaps: win32more.Windows.Win32.Web.MsHtml.styleFontVariant = 1
styleFontVariantNormal: win32more.Windows.Win32.Web.MsHtml.styleFontVariant = 2
styleFontVariant_Max: win32more.Windows.Win32.Web.MsHtml.styleFontVariant = 2147483647
styleFontWeight = Int32
styleFontWeightNotSet: win32more.Windows.Win32.Web.MsHtml.styleFontWeight = 0
styleFontWeight100: win32more.Windows.Win32.Web.MsHtml.styleFontWeight = 1
styleFontWeight200: win32more.Windows.Win32.Web.MsHtml.styleFontWeight = 2
styleFontWeight300: win32more.Windows.Win32.Web.MsHtml.styleFontWeight = 3
styleFontWeight400: win32more.Windows.Win32.Web.MsHtml.styleFontWeight = 4
styleFontWeight500: win32more.Windows.Win32.Web.MsHtml.styleFontWeight = 5
styleFontWeight600: win32more.Windows.Win32.Web.MsHtml.styleFontWeight = 6
styleFontWeight700: win32more.Windows.Win32.Web.MsHtml.styleFontWeight = 7
styleFontWeight800: win32more.Windows.Win32.Web.MsHtml.styleFontWeight = 8
styleFontWeight900: win32more.Windows.Win32.Web.MsHtml.styleFontWeight = 9
styleFontWeightNormal: win32more.Windows.Win32.Web.MsHtml.styleFontWeight = 10
styleFontWeightBold: win32more.Windows.Win32.Web.MsHtml.styleFontWeight = 11
styleFontWeightBolder: win32more.Windows.Win32.Web.MsHtml.styleFontWeight = 12
styleFontWeightLighter: win32more.Windows.Win32.Web.MsHtml.styleFontWeight = 13
styleFontWeight_Max: win32more.Windows.Win32.Web.MsHtml.styleFontWeight = 2147483647
styleGridColumn = Int32
styleGridColumnNotSet: win32more.Windows.Win32.Web.MsHtml.styleGridColumn = 0
styleGridColumn_Max: win32more.Windows.Win32.Web.MsHtml.styleGridColumn = 2147483647
styleGridColumnAlign = Int32
styleGridColumnAlignCenter: win32more.Windows.Win32.Web.MsHtml.styleGridColumnAlign = 0
styleGridColumnAlignEnd: win32more.Windows.Win32.Web.MsHtml.styleGridColumnAlign = 1
styleGridColumnAlignStart: win32more.Windows.Win32.Web.MsHtml.styleGridColumnAlign = 2
styleGridColumnAlignStretch: win32more.Windows.Win32.Web.MsHtml.styleGridColumnAlign = 3
styleGridColumnAlignNotSet: win32more.Windows.Win32.Web.MsHtml.styleGridColumnAlign = 4
styleGridColumnAlign_Max: win32more.Windows.Win32.Web.MsHtml.styleGridColumnAlign = 2147483647
styleGridColumnSpan = Int32
styleGridColumnSpanNotSet: win32more.Windows.Win32.Web.MsHtml.styleGridColumnSpan = 0
styleGridColumnSpan_Max: win32more.Windows.Win32.Web.MsHtml.styleGridColumnSpan = 2147483647
styleGridRow = Int32
styleGridRowNotSet: win32more.Windows.Win32.Web.MsHtml.styleGridRow = 0
styleGridRow_Max: win32more.Windows.Win32.Web.MsHtml.styleGridRow = 2147483647
styleGridRowAlign = Int32
styleGridRowAlignCenter: win32more.Windows.Win32.Web.MsHtml.styleGridRowAlign = 0
styleGridRowAlignEnd: win32more.Windows.Win32.Web.MsHtml.styleGridRowAlign = 1
styleGridRowAlignStart: win32more.Windows.Win32.Web.MsHtml.styleGridRowAlign = 2
styleGridRowAlignStretch: win32more.Windows.Win32.Web.MsHtml.styleGridRowAlign = 3
styleGridRowAlignNotSet: win32more.Windows.Win32.Web.MsHtml.styleGridRowAlign = 4
styleGridRowAlign_Max: win32more.Windows.Win32.Web.MsHtml.styleGridRowAlign = 2147483647
styleGridRowSpan = Int32
styleGridRowSpanNotSet: win32more.Windows.Win32.Web.MsHtml.styleGridRowSpan = 0
styleGridRowSpan_Max: win32more.Windows.Win32.Web.MsHtml.styleGridRowSpan = 2147483647
styleHyphenateLimitLines = Int32
styleHyphenateLimitLinesNoLimit: win32more.Windows.Win32.Web.MsHtml.styleHyphenateLimitLines = 0
styleHyphenateLimitLines_Max: win32more.Windows.Win32.Web.MsHtml.styleHyphenateLimitLines = 2147483647
styleHyphens = Int32
styleHyphensNone: win32more.Windows.Win32.Web.MsHtml.styleHyphens = 0
styleHyphensManual: win32more.Windows.Win32.Web.MsHtml.styleHyphens = 1
styleHyphensAuto: win32more.Windows.Win32.Web.MsHtml.styleHyphens = 2
styleHyphensNotSet: win32more.Windows.Win32.Web.MsHtml.styleHyphens = 3
styleHyphens_Max: win32more.Windows.Win32.Web.MsHtml.styleHyphens = 2147483647
styleImeMode = Int32
styleImeModeAuto: win32more.Windows.Win32.Web.MsHtml.styleImeMode = 0
styleImeModeActive: win32more.Windows.Win32.Web.MsHtml.styleImeMode = 1
styleImeModeInactive: win32more.Windows.Win32.Web.MsHtml.styleImeMode = 2
styleImeModeDisabled: win32more.Windows.Win32.Web.MsHtml.styleImeMode = 3
styleImeModeNotSet: win32more.Windows.Win32.Web.MsHtml.styleImeMode = 4
styleImeMode_Max: win32more.Windows.Win32.Web.MsHtml.styleImeMode = 2147483647
styleInitialColor = Int32
styleInitialColorNoInitial: win32more.Windows.Win32.Web.MsHtml.styleInitialColor = 0
styleInitialColorColorProperty: win32more.Windows.Win32.Web.MsHtml.styleInitialColor = 1
styleInitialColorTransparent: win32more.Windows.Win32.Web.MsHtml.styleInitialColor = 2
styleInitialColorInvert: win32more.Windows.Win32.Web.MsHtml.styleInitialColor = 3
styleInitialColor_Max: win32more.Windows.Win32.Web.MsHtml.styleInitialColor = 2147483647
styleInitialString = Int32
styleInitialStringNoInitial: win32more.Windows.Win32.Web.MsHtml.styleInitialString = 0
styleInitialStringNone: win32more.Windows.Win32.Web.MsHtml.styleInitialString = 1
styleInitialStringAuto: win32more.Windows.Win32.Web.MsHtml.styleInitialString = 2
styleInitialStringNormal: win32more.Windows.Win32.Web.MsHtml.styleInitialString = 3
styleInitialString_Max: win32more.Windows.Win32.Web.MsHtml.styleInitialString = 2147483647
styleInterpolation = Int32
styleInterpolationNotSet: win32more.Windows.Win32.Web.MsHtml.styleInterpolation = 0
styleInterpolationNN: win32more.Windows.Win32.Web.MsHtml.styleInterpolation = 1
styleInterpolationBCH: win32more.Windows.Win32.Web.MsHtml.styleInterpolation = 2
styleInterpolation_Max: win32more.Windows.Win32.Web.MsHtml.styleInterpolation = 2147483647
styleJustifyContent = Int32
styleJustifyContentFlexStart: win32more.Windows.Win32.Web.MsHtml.styleJustifyContent = 0
styleJustifyContentFlexEnd: win32more.Windows.Win32.Web.MsHtml.styleJustifyContent = 1
styleJustifyContentCenter: win32more.Windows.Win32.Web.MsHtml.styleJustifyContent = 2
styleJustifyContentSpaceBetween: win32more.Windows.Win32.Web.MsHtml.styleJustifyContent = 3
styleJustifyContentSpaceAround: win32more.Windows.Win32.Web.MsHtml.styleJustifyContent = 4
styleJustifyContentNotSet: win32more.Windows.Win32.Web.MsHtml.styleJustifyContent = 5
styleJustifyContent_Max: win32more.Windows.Win32.Web.MsHtml.styleJustifyContent = 2147483647
styleLayoutFlow = Int32
styleLayoutFlowHorizontal: win32more.Windows.Win32.Web.MsHtml.styleLayoutFlow = 0
styleLayoutFlowVerticalIdeographic: win32more.Windows.Win32.Web.MsHtml.styleLayoutFlow = 1
styleLayoutFlowNotSet: win32more.Windows.Win32.Web.MsHtml.styleLayoutFlow = 2
styleLayoutFlow_Max: win32more.Windows.Win32.Web.MsHtml.styleLayoutFlow = 2147483647
styleLayoutGridChar = Int32
styleLayoutGridCharNotSet: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridChar = 0
styleLayoutGridCharAuto: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridChar = 1
styleLayoutGridCharNone: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridChar = 2
styleLayoutGridChar_Max: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridChar = 2147483647
styleLayoutGridLine = Int32
styleLayoutGridLineNotSet: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridLine = 0
styleLayoutGridLineAuto: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridLine = 1
styleLayoutGridLineNone: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridLine = 2
styleLayoutGridLine_Max: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridLine = 2147483647
styleLayoutGridMode = Int32
styleLayoutGridModeNotSet: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridMode = 0
styleLayoutGridModeChar: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridMode = 1
styleLayoutGridModeLine: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridMode = 2
styleLayoutGridModeBoth: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridMode = 3
styleLayoutGridModeNone: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridMode = 4
styleLayoutGridMode_Max: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridMode = 2147483647
styleLayoutGridType = Int32
styleLayoutGridTypeNotSet: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridType = 0
styleLayoutGridTypeLoose: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridType = 1
styleLayoutGridTypeStrict: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridType = 2
styleLayoutGridTypeFixed: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridType = 3
styleLayoutGridType_Max: win32more.Windows.Win32.Web.MsHtml.styleLayoutGridType = 2147483647
styleLineBreak = Int32
styleLineBreakNotSet: win32more.Windows.Win32.Web.MsHtml.styleLineBreak = 0
styleLineBreakNormal: win32more.Windows.Win32.Web.MsHtml.styleLineBreak = 1
styleLineBreakStrict: win32more.Windows.Win32.Web.MsHtml.styleLineBreak = 2
styleLineBreak_Max: win32more.Windows.Win32.Web.MsHtml.styleLineBreak = 2147483647
styleListStylePosition = Int32
styleListStylePositionNotSet: win32more.Windows.Win32.Web.MsHtml.styleListStylePosition = 0
styleListStylePositionInside: win32more.Windows.Win32.Web.MsHtml.styleListStylePosition = 1
styleListStylePositionOutSide: win32more.Windows.Win32.Web.MsHtml.styleListStylePosition = 2
styleListStylePosition_Max: win32more.Windows.Win32.Web.MsHtml.styleListStylePosition = 2147483647
styleListStyleType = Int32
styleListStyleTypeNotSet: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 0
styleListStyleTypeDisc: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 1
styleListStyleTypeCircle: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 2
styleListStyleTypeSquare: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 3
styleListStyleTypeDecimal: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 4
styleListStyleTypeLowerRoman: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 5
styleListStyleTypeUpperRoman: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 6
styleListStyleTypeLowerAlpha: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 7
styleListStyleTypeUpperAlpha: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 8
styleListStyleTypeNone: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 9
styleListStyleTypeDecimalLeadingZero: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 10
styleListStyleTypeGeorgian: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 11
styleListStyleTypeArmenian: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 12
styleListStyleTypeUpperLatin: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 13
styleListStyleTypeLowerLatin: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 14
styleListStyleTypeUpperGreek: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 15
styleListStyleTypeLowerGreek: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 16
styleListStyleType_Max: win32more.Windows.Win32.Web.MsHtml.styleListStyleType = 2147483647
styleMsAnimationDirection = Int32
styleMsAnimationDirectionNormal: win32more.Windows.Win32.Web.MsHtml.styleMsAnimationDirection = 0
styleMsAnimationDirectionAlternate: win32more.Windows.Win32.Web.MsHtml.styleMsAnimationDirection = 1
styleMsAnimationDirectionReverse: win32more.Windows.Win32.Web.MsHtml.styleMsAnimationDirection = 2
styleMsAnimationDirectionAlternateReverse: win32more.Windows.Win32.Web.MsHtml.styleMsAnimationDirection = 3
styleMsAnimationDirectionNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsAnimationDirection = 4
styleMsAnimationDirection_Max: win32more.Windows.Win32.Web.MsHtml.styleMsAnimationDirection = 2147483647
styleMsAnimationFillMode = Int32
styleMsAnimationFillModeNone: win32more.Windows.Win32.Web.MsHtml.styleMsAnimationFillMode = 0
styleMsAnimationFillModeForwards: win32more.Windows.Win32.Web.MsHtml.styleMsAnimationFillMode = 1
styleMsAnimationFillModeBackwards: win32more.Windows.Win32.Web.MsHtml.styleMsAnimationFillMode = 2
styleMsAnimationFillModeBoth: win32more.Windows.Win32.Web.MsHtml.styleMsAnimationFillMode = 3
styleMsAnimationFillModeNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsAnimationFillMode = 4
styleMsAnimationFillMode_Max: win32more.Windows.Win32.Web.MsHtml.styleMsAnimationFillMode = 2147483647
styleMsAnimationPlayState = Int32
styleMsAnimationPlayStateRunning: win32more.Windows.Win32.Web.MsHtml.styleMsAnimationPlayState = 0
styleMsAnimationPlayStatePaused: win32more.Windows.Win32.Web.MsHtml.styleMsAnimationPlayState = 1
styleMsAnimationPlayStateNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsAnimationPlayState = 2
styleMsAnimationPlayState_Max: win32more.Windows.Win32.Web.MsHtml.styleMsAnimationPlayState = 2147483647
styleMsContentZoomChaining = Int32
styleMsContentZoomChainingNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsContentZoomChaining = 0
styleMsContentZoomChainingNone: win32more.Windows.Win32.Web.MsHtml.styleMsContentZoomChaining = 1
styleMsContentZoomChainingChained: win32more.Windows.Win32.Web.MsHtml.styleMsContentZoomChaining = 2
styleMsContentZoomChaining_Max: win32more.Windows.Win32.Web.MsHtml.styleMsContentZoomChaining = 2147483647
styleMsContentZoomSnapType = Int32
styleMsContentZoomSnapTypeNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsContentZoomSnapType = 0
styleMsContentZoomSnapTypeNone: win32more.Windows.Win32.Web.MsHtml.styleMsContentZoomSnapType = 1
styleMsContentZoomSnapTypeMandatory: win32more.Windows.Win32.Web.MsHtml.styleMsContentZoomSnapType = 2
styleMsContentZoomSnapTypeProximity: win32more.Windows.Win32.Web.MsHtml.styleMsContentZoomSnapType = 3
styleMsContentZoomSnapType_Max: win32more.Windows.Win32.Web.MsHtml.styleMsContentZoomSnapType = 2147483647
styleMsContentZooming = Int32
styleMsContentZoomingNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsContentZooming = 0
styleMsContentZoomingNone: win32more.Windows.Win32.Web.MsHtml.styleMsContentZooming = 1
styleMsContentZoomingZoom: win32more.Windows.Win32.Web.MsHtml.styleMsContentZooming = 2
styleMsContentZooming_Max: win32more.Windows.Win32.Web.MsHtml.styleMsContentZooming = 2147483647
styleMsFlexAlign = Int32
styleMsFlexAlignStart: win32more.Windows.Win32.Web.MsHtml.styleMsFlexAlign = 0
styleMsFlexAlignEnd: win32more.Windows.Win32.Web.MsHtml.styleMsFlexAlign = 1
styleMsFlexAlignCenter: win32more.Windows.Win32.Web.MsHtml.styleMsFlexAlign = 2
styleMsFlexAlignBaseline: win32more.Windows.Win32.Web.MsHtml.styleMsFlexAlign = 3
styleMsFlexAlignStretch: win32more.Windows.Win32.Web.MsHtml.styleMsFlexAlign = 4
styleMsFlexAlignNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsFlexAlign = 5
styleMsFlexAlign_Max: win32more.Windows.Win32.Web.MsHtml.styleMsFlexAlign = 2147483647
styleMsFlexItemAlign = Int32
styleMsFlexItemAlignStart: win32more.Windows.Win32.Web.MsHtml.styleMsFlexItemAlign = 0
styleMsFlexItemAlignEnd: win32more.Windows.Win32.Web.MsHtml.styleMsFlexItemAlign = 1
styleMsFlexItemAlignCenter: win32more.Windows.Win32.Web.MsHtml.styleMsFlexItemAlign = 2
styleMsFlexItemAlignBaseline: win32more.Windows.Win32.Web.MsHtml.styleMsFlexItemAlign = 3
styleMsFlexItemAlignStretch: win32more.Windows.Win32.Web.MsHtml.styleMsFlexItemAlign = 4
styleMsFlexItemAlignAuto: win32more.Windows.Win32.Web.MsHtml.styleMsFlexItemAlign = 5
styleMsFlexItemAlignNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsFlexItemAlign = 6
styleMsFlexItemAlign_Max: win32more.Windows.Win32.Web.MsHtml.styleMsFlexItemAlign = 2147483647
styleMsFlexLinePack = Int32
styleMsFlexLinePackStart: win32more.Windows.Win32.Web.MsHtml.styleMsFlexLinePack = 0
styleMsFlexLinePackEnd: win32more.Windows.Win32.Web.MsHtml.styleMsFlexLinePack = 1
styleMsFlexLinePackCenter: win32more.Windows.Win32.Web.MsHtml.styleMsFlexLinePack = 2
styleMsFlexLinePackJustify: win32more.Windows.Win32.Web.MsHtml.styleMsFlexLinePack = 3
styleMsFlexLinePackDistribute: win32more.Windows.Win32.Web.MsHtml.styleMsFlexLinePack = 4
styleMsFlexLinePackStretch: win32more.Windows.Win32.Web.MsHtml.styleMsFlexLinePack = 5
styleMsFlexLinePackNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsFlexLinePack = 6
styleMsFlexLinePack_Max: win32more.Windows.Win32.Web.MsHtml.styleMsFlexLinePack = 2147483647
styleMsFlexPack = Int32
styleMsFlexPackStart: win32more.Windows.Win32.Web.MsHtml.styleMsFlexPack = 0
styleMsFlexPackEnd: win32more.Windows.Win32.Web.MsHtml.styleMsFlexPack = 1
styleMsFlexPackCenter: win32more.Windows.Win32.Web.MsHtml.styleMsFlexPack = 2
styleMsFlexPackJustify: win32more.Windows.Win32.Web.MsHtml.styleMsFlexPack = 3
styleMsFlexPackDistribute: win32more.Windows.Win32.Web.MsHtml.styleMsFlexPack = 4
styleMsFlexPackNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsFlexPack = 5
styleMsFlexPack_Max: win32more.Windows.Win32.Web.MsHtml.styleMsFlexPack = 2147483647
styleMsHighContrastAdjust = Int32
styleMsHighContrastAdjustNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsHighContrastAdjust = 0
styleMsHighContrastAdjustAuto: win32more.Windows.Win32.Web.MsHtml.styleMsHighContrastAdjust = 1
styleMsHighContrastAdjustNone: win32more.Windows.Win32.Web.MsHtml.styleMsHighContrastAdjust = 2
styleMsHighContrastAdjust_Max: win32more.Windows.Win32.Web.MsHtml.styleMsHighContrastAdjust = 2147483647
styleMsImeAlign = Int32
styleMsImeAlignAuto: win32more.Windows.Win32.Web.MsHtml.styleMsImeAlign = 0
styleMsImeAlignAfter: win32more.Windows.Win32.Web.MsHtml.styleMsImeAlign = 1
styleMsImeAlignNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsImeAlign = 2
styleMsImeAlign_Max: win32more.Windows.Win32.Web.MsHtml.styleMsImeAlign = 2147483647
styleMsOverflowStyle = Int32
styleMsOverflowStyleNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsOverflowStyle = 0
styleMsOverflowStyleAuto: win32more.Windows.Win32.Web.MsHtml.styleMsOverflowStyle = 1
styleMsOverflowStyleNone: win32more.Windows.Win32.Web.MsHtml.styleMsOverflowStyle = 2
styleMsOverflowStyleScrollbar: win32more.Windows.Win32.Web.MsHtml.styleMsOverflowStyle = 3
styleMsOverflowStyleMsAutoHidingScrollbar: win32more.Windows.Win32.Web.MsHtml.styleMsOverflowStyle = 4
styleMsOverflowStyle_Max: win32more.Windows.Win32.Web.MsHtml.styleMsOverflowStyle = 2147483647
styleMsScrollChaining = Int32
styleMsScrollChainingNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsScrollChaining = 0
styleMsScrollChainingNone: win32more.Windows.Win32.Web.MsHtml.styleMsScrollChaining = 1
styleMsScrollChainingChained: win32more.Windows.Win32.Web.MsHtml.styleMsScrollChaining = 2
styleMsScrollChaining_Max: win32more.Windows.Win32.Web.MsHtml.styleMsScrollChaining = 2147483647
styleMsScrollRails = Int32
styleMsScrollRailsNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsScrollRails = 0
styleMsScrollRailsNone: win32more.Windows.Win32.Web.MsHtml.styleMsScrollRails = 1
styleMsScrollRailsRailed: win32more.Windows.Win32.Web.MsHtml.styleMsScrollRails = 2
styleMsScrollRails_Max: win32more.Windows.Win32.Web.MsHtml.styleMsScrollRails = 2147483647
styleMsScrollSnapType = Int32
styleMsScrollSnapTypeNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsScrollSnapType = 0
styleMsScrollSnapTypeNone: win32more.Windows.Win32.Web.MsHtml.styleMsScrollSnapType = 1
styleMsScrollSnapTypeMandatory: win32more.Windows.Win32.Web.MsHtml.styleMsScrollSnapType = 2
styleMsScrollSnapTypeProximity: win32more.Windows.Win32.Web.MsHtml.styleMsScrollSnapType = 3
styleMsScrollSnapType_Max: win32more.Windows.Win32.Web.MsHtml.styleMsScrollSnapType = 2147483647
styleMsScrollTranslation = Int32
styleMsScrollTranslationNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsScrollTranslation = 0
styleMsScrollTranslationNone: win32more.Windows.Win32.Web.MsHtml.styleMsScrollTranslation = 1
styleMsScrollTranslationVtoH: win32more.Windows.Win32.Web.MsHtml.styleMsScrollTranslation = 2
styleMsScrollTranslation_Max: win32more.Windows.Win32.Web.MsHtml.styleMsScrollTranslation = 2147483647
styleMsTextCombineHorizontal = Int32
styleMsTextCombineHorizontalNone: win32more.Windows.Win32.Web.MsHtml.styleMsTextCombineHorizontal = 0
styleMsTextCombineHorizontalAll: win32more.Windows.Win32.Web.MsHtml.styleMsTextCombineHorizontal = 1
styleMsTextCombineHorizontalDigits: win32more.Windows.Win32.Web.MsHtml.styleMsTextCombineHorizontal = 2
styleMsTextCombineHorizontalNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsTextCombineHorizontal = 3
styleMsTextCombineHorizontal_Max: win32more.Windows.Win32.Web.MsHtml.styleMsTextCombineHorizontal = 2147483647
styleMsTouchAction = Int32
styleMsTouchActionNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsTouchAction = -1
styleMsTouchActionNone: win32more.Windows.Win32.Web.MsHtml.styleMsTouchAction = 0
styleMsTouchActionAuto: win32more.Windows.Win32.Web.MsHtml.styleMsTouchAction = 1
styleMsTouchActionManipulation: win32more.Windows.Win32.Web.MsHtml.styleMsTouchAction = 2
styleMsTouchActionDoubleTapZoom: win32more.Windows.Win32.Web.MsHtml.styleMsTouchAction = 4
styleMsTouchActionPanX: win32more.Windows.Win32.Web.MsHtml.styleMsTouchAction = 8
styleMsTouchActionPanY: win32more.Windows.Win32.Web.MsHtml.styleMsTouchAction = 16
styleMsTouchActionPinchZoom: win32more.Windows.Win32.Web.MsHtml.styleMsTouchAction = 32
styleMsTouchActionCrossSlideX: win32more.Windows.Win32.Web.MsHtml.styleMsTouchAction = 64
styleMsTouchActionCrossSlideY: win32more.Windows.Win32.Web.MsHtml.styleMsTouchAction = 128
styleMsTouchAction_Max: win32more.Windows.Win32.Web.MsHtml.styleMsTouchAction = 2147483647
styleMsTouchSelect = Int32
styleMsTouchSelectGrippers: win32more.Windows.Win32.Web.MsHtml.styleMsTouchSelect = 0
styleMsTouchSelectNone: win32more.Windows.Win32.Web.MsHtml.styleMsTouchSelect = 1
styleMsTouchSelectNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsTouchSelect = 2
styleMsTouchSelect_Max: win32more.Windows.Win32.Web.MsHtml.styleMsTouchSelect = 2147483647
styleMsUserSelect = Int32
styleMsUserSelectAuto: win32more.Windows.Win32.Web.MsHtml.styleMsUserSelect = 0
styleMsUserSelectText: win32more.Windows.Win32.Web.MsHtml.styleMsUserSelect = 1
styleMsUserSelectElement: win32more.Windows.Win32.Web.MsHtml.styleMsUserSelect = 2
styleMsUserSelectNone: win32more.Windows.Win32.Web.MsHtml.styleMsUserSelect = 3
styleMsUserSelectNotSet: win32more.Windows.Win32.Web.MsHtml.styleMsUserSelect = 4
styleMsUserSelect_Max: win32more.Windows.Win32.Web.MsHtml.styleMsUserSelect = 2147483647
styleNone = Int32
styleNoneNone: win32more.Windows.Win32.Web.MsHtml.styleNone = 0
styleNone_Max: win32more.Windows.Win32.Web.MsHtml.styleNone = 2147483647
styleNormal = Int32
styleNormalNormal: win32more.Windows.Win32.Web.MsHtml.styleNormal = 0
styleNormal_Max: win32more.Windows.Win32.Web.MsHtml.styleNormal = 2147483647
styleOutlineStyle = Int32
styleOutlineStyleNotSet: win32more.Windows.Win32.Web.MsHtml.styleOutlineStyle = 0
styleOutlineStyleDotted: win32more.Windows.Win32.Web.MsHtml.styleOutlineStyle = 1
styleOutlineStyleDashed: win32more.Windows.Win32.Web.MsHtml.styleOutlineStyle = 2
styleOutlineStyleSolid: win32more.Windows.Win32.Web.MsHtml.styleOutlineStyle = 3
styleOutlineStyleDouble: win32more.Windows.Win32.Web.MsHtml.styleOutlineStyle = 4
styleOutlineStyleGroove: win32more.Windows.Win32.Web.MsHtml.styleOutlineStyle = 5
styleOutlineStyleRidge: win32more.Windows.Win32.Web.MsHtml.styleOutlineStyle = 6
styleOutlineStyleInset: win32more.Windows.Win32.Web.MsHtml.styleOutlineStyle = 7
styleOutlineStyleOutset: win32more.Windows.Win32.Web.MsHtml.styleOutlineStyle = 8
styleOutlineStyleWindowInset: win32more.Windows.Win32.Web.MsHtml.styleOutlineStyle = 9
styleOutlineStyleNone: win32more.Windows.Win32.Web.MsHtml.styleOutlineStyle = 10
styleOutlineStyle_Max: win32more.Windows.Win32.Web.MsHtml.styleOutlineStyle = 2147483647
styleOverflow = Int32
styleOverflowNotSet: win32more.Windows.Win32.Web.MsHtml.styleOverflow = 0
styleOverflowAuto: win32more.Windows.Win32.Web.MsHtml.styleOverflow = 1
styleOverflowHidden: win32more.Windows.Win32.Web.MsHtml.styleOverflow = 2
styleOverflowVisible: win32more.Windows.Win32.Web.MsHtml.styleOverflow = 3
styleOverflowScroll: win32more.Windows.Win32.Web.MsHtml.styleOverflow = 4
styleOverflow_Max: win32more.Windows.Win32.Web.MsHtml.styleOverflow = 2147483647
stylePageBreak = Int32
stylePageBreakNotSet: win32more.Windows.Win32.Web.MsHtml.stylePageBreak = 0
stylePageBreakAuto: win32more.Windows.Win32.Web.MsHtml.stylePageBreak = 1
stylePageBreakAlways: win32more.Windows.Win32.Web.MsHtml.stylePageBreak = 2
stylePageBreakLeft: win32more.Windows.Win32.Web.MsHtml.stylePageBreak = 3
stylePageBreakRight: win32more.Windows.Win32.Web.MsHtml.stylePageBreak = 4
stylePageBreakAvoid: win32more.Windows.Win32.Web.MsHtml.stylePageBreak = 5
stylePageBreak_Max: win32more.Windows.Win32.Web.MsHtml.stylePageBreak = 2147483647
stylePageBreakInside = Int32
stylePageBreakInsideNotSet: win32more.Windows.Win32.Web.MsHtml.stylePageBreakInside = 0
stylePageBreakInsideAuto: win32more.Windows.Win32.Web.MsHtml.stylePageBreakInside = 1
stylePageBreakInsideAvoid: win32more.Windows.Win32.Web.MsHtml.stylePageBreakInside = 2
stylePageBreakInside_Max: win32more.Windows.Win32.Web.MsHtml.stylePageBreakInside = 2147483647
stylePerspectiveOriginX = Int32
stylePerspectiveOriginXNotSet: win32more.Windows.Win32.Web.MsHtml.stylePerspectiveOriginX = 0
stylePerspectiveOriginXLeft: win32more.Windows.Win32.Web.MsHtml.stylePerspectiveOriginX = 1
stylePerspectiveOriginXCenter: win32more.Windows.Win32.Web.MsHtml.stylePerspectiveOriginX = 2
stylePerspectiveOriginXRight: win32more.Windows.Win32.Web.MsHtml.stylePerspectiveOriginX = 3
stylePerspectiveOriginX_Max: win32more.Windows.Win32.Web.MsHtml.stylePerspectiveOriginX = 2147483647
stylePerspectiveOriginY = Int32
stylePerspectiveOriginYNotSet: win32more.Windows.Win32.Web.MsHtml.stylePerspectiveOriginY = 0
stylePerspectiveOriginYTop: win32more.Windows.Win32.Web.MsHtml.stylePerspectiveOriginY = 1
stylePerspectiveOriginYCenter: win32more.Windows.Win32.Web.MsHtml.stylePerspectiveOriginY = 2
stylePerspectiveOriginYBottom: win32more.Windows.Win32.Web.MsHtml.stylePerspectiveOriginY = 3
stylePerspectiveOriginY_Max: win32more.Windows.Win32.Web.MsHtml.stylePerspectiveOriginY = 2147483647
stylePointerEvents = Int32
stylePointerEventsNotSet: win32more.Windows.Win32.Web.MsHtml.stylePointerEvents = 0
stylePointerEventsVisiblePainted: win32more.Windows.Win32.Web.MsHtml.stylePointerEvents = 1
stylePointerEventsVisibleFill: win32more.Windows.Win32.Web.MsHtml.stylePointerEvents = 2
stylePointerEventsVisibleStroke: win32more.Windows.Win32.Web.MsHtml.stylePointerEvents = 3
stylePointerEventsVisible: win32more.Windows.Win32.Web.MsHtml.stylePointerEvents = 4
stylePointerEventsPainted: win32more.Windows.Win32.Web.MsHtml.stylePointerEvents = 5
stylePointerEventsFill: win32more.Windows.Win32.Web.MsHtml.stylePointerEvents = 6
stylePointerEventsStroke: win32more.Windows.Win32.Web.MsHtml.stylePointerEvents = 7
stylePointerEventsAll: win32more.Windows.Win32.Web.MsHtml.stylePointerEvents = 8
stylePointerEventsNone: win32more.Windows.Win32.Web.MsHtml.stylePointerEvents = 9
stylePointerEventsInitial: win32more.Windows.Win32.Web.MsHtml.stylePointerEvents = 10
stylePointerEventsAuto: win32more.Windows.Win32.Web.MsHtml.stylePointerEvents = 11
stylePointerEvents_Max: win32more.Windows.Win32.Web.MsHtml.stylePointerEvents = 2147483647
stylePosition = Int32
stylePositionNotSet: win32more.Windows.Win32.Web.MsHtml.stylePosition = 0
stylePositionstatic: win32more.Windows.Win32.Web.MsHtml.stylePosition = 1
stylePositionrelative: win32more.Windows.Win32.Web.MsHtml.stylePosition = 2
stylePositionabsolute: win32more.Windows.Win32.Web.MsHtml.stylePosition = 3
stylePositionfixed: win32more.Windows.Win32.Web.MsHtml.stylePosition = 4
stylePositionMsPage: win32more.Windows.Win32.Web.MsHtml.stylePosition = 5
stylePositionMsDeviceFixed: win32more.Windows.Win32.Web.MsHtml.stylePosition = 6
stylePosition_Max: win32more.Windows.Win32.Web.MsHtml.stylePosition = 2147483647
styleRubyAlign = Int32
styleRubyAlignNotSet: win32more.Windows.Win32.Web.MsHtml.styleRubyAlign = 0
styleRubyAlignAuto: win32more.Windows.Win32.Web.MsHtml.styleRubyAlign = 1
styleRubyAlignLeft: win32more.Windows.Win32.Web.MsHtml.styleRubyAlign = 2
styleRubyAlignCenter: win32more.Windows.Win32.Web.MsHtml.styleRubyAlign = 3
styleRubyAlignRight: win32more.Windows.Win32.Web.MsHtml.styleRubyAlign = 4
styleRubyAlignDistributeLetter: win32more.Windows.Win32.Web.MsHtml.styleRubyAlign = 5
styleRubyAlignDistributeSpace: win32more.Windows.Win32.Web.MsHtml.styleRubyAlign = 6
styleRubyAlignLineEdge: win32more.Windows.Win32.Web.MsHtml.styleRubyAlign = 7
styleRubyAlign_Max: win32more.Windows.Win32.Web.MsHtml.styleRubyAlign = 2147483647
styleRubyOverhang = Int32
styleRubyOverhangNotSet: win32more.Windows.Win32.Web.MsHtml.styleRubyOverhang = 0
styleRubyOverhangAuto: win32more.Windows.Win32.Web.MsHtml.styleRubyOverhang = 1
styleRubyOverhangWhitespace: win32more.Windows.Win32.Web.MsHtml.styleRubyOverhang = 2
styleRubyOverhangNone: win32more.Windows.Win32.Web.MsHtml.styleRubyOverhang = 3
styleRubyOverhang_Max: win32more.Windows.Win32.Web.MsHtml.styleRubyOverhang = 2147483647
styleRubyPosition = Int32
styleRubyPositionNotSet: win32more.Windows.Win32.Web.MsHtml.styleRubyPosition = 0
styleRubyPositionAbove: win32more.Windows.Win32.Web.MsHtml.styleRubyPosition = 1
styleRubyPositionInline: win32more.Windows.Win32.Web.MsHtml.styleRubyPosition = 2
styleRubyPosition_Max: win32more.Windows.Win32.Web.MsHtml.styleRubyPosition = 2147483647
styleStrokeLinecap = Int32
styleStrokeLinecapNotSet: win32more.Windows.Win32.Web.MsHtml.styleStrokeLinecap = 0
styleStrokeLinecapButt: win32more.Windows.Win32.Web.MsHtml.styleStrokeLinecap = 1
styleStrokeLinecapRound: win32more.Windows.Win32.Web.MsHtml.styleStrokeLinecap = 2
styleStrokeLinecapSquare: win32more.Windows.Win32.Web.MsHtml.styleStrokeLinecap = 3
styleStrokeLinecap_Max: win32more.Windows.Win32.Web.MsHtml.styleStrokeLinecap = 2147483647
styleStrokeLinejoin = Int32
styleStrokeLinejoinNotSet: win32more.Windows.Win32.Web.MsHtml.styleStrokeLinejoin = 0
styleStrokeLinejoinMiter: win32more.Windows.Win32.Web.MsHtml.styleStrokeLinejoin = 1
styleStrokeLinejoinRound: win32more.Windows.Win32.Web.MsHtml.styleStrokeLinejoin = 2
styleStrokeLinejoinBevel: win32more.Windows.Win32.Web.MsHtml.styleStrokeLinejoin = 3
styleStrokeLinejoin_Max: win32more.Windows.Win32.Web.MsHtml.styleStrokeLinejoin = 2147483647
styleStyleFloat = Int32
styleStyleFloatNotSet: win32more.Windows.Win32.Web.MsHtml.styleStyleFloat = 0
styleStyleFloatLeft: win32more.Windows.Win32.Web.MsHtml.styleStyleFloat = 1
styleStyleFloatRight: win32more.Windows.Win32.Web.MsHtml.styleStyleFloat = 2
styleStyleFloatNone: win32more.Windows.Win32.Web.MsHtml.styleStyleFloat = 3
styleStyleFloat_Max: win32more.Windows.Win32.Web.MsHtml.styleStyleFloat = 2147483647
styleTableLayout = Int32
styleTableLayoutNotSet: win32more.Windows.Win32.Web.MsHtml.styleTableLayout = 0
styleTableLayoutAuto: win32more.Windows.Win32.Web.MsHtml.styleTableLayout = 1
styleTableLayoutFixed: win32more.Windows.Win32.Web.MsHtml.styleTableLayout = 2
styleTableLayout_Max: win32more.Windows.Win32.Web.MsHtml.styleTableLayout = 2147483647
styleTextAlignLast = Int32
styleTextAlignLastNotSet: win32more.Windows.Win32.Web.MsHtml.styleTextAlignLast = 0
styleTextAlignLastLeft: win32more.Windows.Win32.Web.MsHtml.styleTextAlignLast = 1
styleTextAlignLastCenter: win32more.Windows.Win32.Web.MsHtml.styleTextAlignLast = 2
styleTextAlignLastRight: win32more.Windows.Win32.Web.MsHtml.styleTextAlignLast = 3
styleTextAlignLastJustify: win32more.Windows.Win32.Web.MsHtml.styleTextAlignLast = 4
styleTextAlignLastAuto: win32more.Windows.Win32.Web.MsHtml.styleTextAlignLast = 5
styleTextAlignLast_Max: win32more.Windows.Win32.Web.MsHtml.styleTextAlignLast = 2147483647
styleTextAnchor = Int32
styleTextAnchorNotSet: win32more.Windows.Win32.Web.MsHtml.styleTextAnchor = 0
styleTextAnchorStart: win32more.Windows.Win32.Web.MsHtml.styleTextAnchor = 1
styleTextAnchorMiddle: win32more.Windows.Win32.Web.MsHtml.styleTextAnchor = 2
styleTextAnchorEnd: win32more.Windows.Win32.Web.MsHtml.styleTextAnchor = 3
styleTextAnchor_Max: win32more.Windows.Win32.Web.MsHtml.styleTextAnchor = 2147483647
styleTextDecoration = Int32
styleTextDecorationNone: win32more.Windows.Win32.Web.MsHtml.styleTextDecoration = 0
styleTextDecorationUnderline: win32more.Windows.Win32.Web.MsHtml.styleTextDecoration = 1
styleTextDecorationOverline: win32more.Windows.Win32.Web.MsHtml.styleTextDecoration = 2
styleTextDecorationLineThrough: win32more.Windows.Win32.Web.MsHtml.styleTextDecoration = 3
styleTextDecorationBlink: win32more.Windows.Win32.Web.MsHtml.styleTextDecoration = 4
styleTextDecoration_Max: win32more.Windows.Win32.Web.MsHtml.styleTextDecoration = 2147483647
styleTextEffect = Int32
styleTextEffectNone: win32more.Windows.Win32.Web.MsHtml.styleTextEffect = 0
styleTextEffectEmboss: win32more.Windows.Win32.Web.MsHtml.styleTextEffect = 1
styleTextEffectEngrave: win32more.Windows.Win32.Web.MsHtml.styleTextEffect = 2
styleTextEffectOutline: win32more.Windows.Win32.Web.MsHtml.styleTextEffect = 3
styleTextEffect_Max: win32more.Windows.Win32.Web.MsHtml.styleTextEffect = 2147483647
styleTextJustify = Int32
styleTextJustifyNotSet: win32more.Windows.Win32.Web.MsHtml.styleTextJustify = 0
styleTextJustifyInterWord: win32more.Windows.Win32.Web.MsHtml.styleTextJustify = 1
styleTextJustifyNewspaper: win32more.Windows.Win32.Web.MsHtml.styleTextJustify = 2
styleTextJustifyDistribute: win32more.Windows.Win32.Web.MsHtml.styleTextJustify = 3
styleTextJustifyDistributeAllLines: win32more.Windows.Win32.Web.MsHtml.styleTextJustify = 4
styleTextJustifyInterIdeograph: win32more.Windows.Win32.Web.MsHtml.styleTextJustify = 5
styleTextJustifyInterCluster: win32more.Windows.Win32.Web.MsHtml.styleTextJustify = 6
styleTextJustifyKashida: win32more.Windows.Win32.Web.MsHtml.styleTextJustify = 7
styleTextJustifyAuto: win32more.Windows.Win32.Web.MsHtml.styleTextJustify = 8
styleTextJustify_Max: win32more.Windows.Win32.Web.MsHtml.styleTextJustify = 2147483647
styleTextJustifyTrim = Int32
styleTextJustifyTrimNotSet: win32more.Windows.Win32.Web.MsHtml.styleTextJustifyTrim = 0
styleTextJustifyTrimNone: win32more.Windows.Win32.Web.MsHtml.styleTextJustifyTrim = 1
styleTextJustifyTrimPunctuation: win32more.Windows.Win32.Web.MsHtml.styleTextJustifyTrim = 2
styleTextJustifyTrimPunctAndKana: win32more.Windows.Win32.Web.MsHtml.styleTextJustifyTrim = 3
styleTextJustifyTrim_Max: win32more.Windows.Win32.Web.MsHtml.styleTextJustifyTrim = 2147483647
styleTextLineThroughStyle = Int32
styleTextLineThroughStyleUndefined: win32more.Windows.Win32.Web.MsHtml.styleTextLineThroughStyle = 0
styleTextLineThroughStyleSingle: win32more.Windows.Win32.Web.MsHtml.styleTextLineThroughStyle = 1
styleTextLineThroughStyleDouble: win32more.Windows.Win32.Web.MsHtml.styleTextLineThroughStyle = 2
styleTextLineThroughStyle_Max: win32more.Windows.Win32.Web.MsHtml.styleTextLineThroughStyle = 2147483647
styleTextOverflow = Int32
styleTextOverflowClip: win32more.Windows.Win32.Web.MsHtml.styleTextOverflow = 0
styleTextOverflowEllipsis: win32more.Windows.Win32.Web.MsHtml.styleTextOverflow = 1
styleTextOverflowNotSet: win32more.Windows.Win32.Web.MsHtml.styleTextOverflow = 2
styleTextOverflow_Max: win32more.Windows.Win32.Web.MsHtml.styleTextOverflow = 2147483647
styleTextSizeAdjust = Int32
styleTextSizeAdjustNone: win32more.Windows.Win32.Web.MsHtml.styleTextSizeAdjust = 0
styleTextSizeAdjustAuto: win32more.Windows.Win32.Web.MsHtml.styleTextSizeAdjust = 1
styleTextSizeAdjust_Max: win32more.Windows.Win32.Web.MsHtml.styleTextSizeAdjust = 2147483647
styleTextTransform = Int32
styleTextTransformNotSet: win32more.Windows.Win32.Web.MsHtml.styleTextTransform = 0
styleTextTransformCapitalize: win32more.Windows.Win32.Web.MsHtml.styleTextTransform = 1
styleTextTransformLowercase: win32more.Windows.Win32.Web.MsHtml.styleTextTransform = 2
styleTextTransformUppercase: win32more.Windows.Win32.Web.MsHtml.styleTextTransform = 3
styleTextTransformNone: win32more.Windows.Win32.Web.MsHtml.styleTextTransform = 4
styleTextTransform_Max: win32more.Windows.Win32.Web.MsHtml.styleTextTransform = 2147483647
styleTextUnderlinePosition = Int32
styleTextUnderlinePositionBelow: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlinePosition = 0
styleTextUnderlinePositionAbove: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlinePosition = 1
styleTextUnderlinePositionAuto: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlinePosition = 2
styleTextUnderlinePositionNotSet: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlinePosition = 3
styleTextUnderlinePosition_Max: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlinePosition = 2147483647
styleTextUnderlineStyle = Int32
styleTextUnderlineStyleUndefined: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlineStyle = 0
styleTextUnderlineStyleSingle: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlineStyle = 1
styleTextUnderlineStyleDouble: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlineStyle = 2
styleTextUnderlineStyleWords: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlineStyle = 3
styleTextUnderlineStyleDotted: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlineStyle = 4
styleTextUnderlineStyleThick: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlineStyle = 5
styleTextUnderlineStyleDash: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlineStyle = 6
styleTextUnderlineStyleDotDash: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlineStyle = 7
styleTextUnderlineStyleDotDotDash: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlineStyle = 8
styleTextUnderlineStyleWave: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlineStyle = 9
styleTextUnderlineStyleSingleAccounting: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlineStyle = 10
styleTextUnderlineStyleDoubleAccounting: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlineStyle = 11
styleTextUnderlineStyleThickDash: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlineStyle = 12
styleTextUnderlineStyle_Max: win32more.Windows.Win32.Web.MsHtml.styleTextUnderlineStyle = 2147483647
styleTransformOriginX = Int32
styleTransformOriginXNotSet: win32more.Windows.Win32.Web.MsHtml.styleTransformOriginX = 0
styleTransformOriginXLeft: win32more.Windows.Win32.Web.MsHtml.styleTransformOriginX = 1
styleTransformOriginXCenter: win32more.Windows.Win32.Web.MsHtml.styleTransformOriginX = 2
styleTransformOriginXRight: win32more.Windows.Win32.Web.MsHtml.styleTransformOriginX = 3
styleTransformOriginX_Max: win32more.Windows.Win32.Web.MsHtml.styleTransformOriginX = 2147483647
styleTransformOriginY = Int32
styleTransformOriginYNotSet: win32more.Windows.Win32.Web.MsHtml.styleTransformOriginY = 0
styleTransformOriginYTop: win32more.Windows.Win32.Web.MsHtml.styleTransformOriginY = 1
styleTransformOriginYCenter: win32more.Windows.Win32.Web.MsHtml.styleTransformOriginY = 2
styleTransformOriginYBottom: win32more.Windows.Win32.Web.MsHtml.styleTransformOriginY = 3
styleTransformOriginY_Max: win32more.Windows.Win32.Web.MsHtml.styleTransformOriginY = 2147483647
styleTransformStyle = Int32
styleTransformStyleFlat: win32more.Windows.Win32.Web.MsHtml.styleTransformStyle = 0
styleTransformStylePreserve3D: win32more.Windows.Win32.Web.MsHtml.styleTransformStyle = 1
styleTransformStyleNotSet: win32more.Windows.Win32.Web.MsHtml.styleTransformStyle = 2
styleTransformStyle_Max: win32more.Windows.Win32.Web.MsHtml.styleTransformStyle = 2147483647
styleUserZoom = Int32
styleUserZoomNotSet: win32more.Windows.Win32.Web.MsHtml.styleUserZoom = 0
styleUserZoomZoom: win32more.Windows.Win32.Web.MsHtml.styleUserZoom = 1
styleUserZoomFixed: win32more.Windows.Win32.Web.MsHtml.styleUserZoom = 2
styleUserZoom_Max: win32more.Windows.Win32.Web.MsHtml.styleUserZoom = 2147483647
styleVerticalAlign = Int32
styleVerticalAlignAuto: win32more.Windows.Win32.Web.MsHtml.styleVerticalAlign = 0
styleVerticalAlignBaseline: win32more.Windows.Win32.Web.MsHtml.styleVerticalAlign = 1
styleVerticalAlignSub: win32more.Windows.Win32.Web.MsHtml.styleVerticalAlign = 2
styleVerticalAlignSuper: win32more.Windows.Win32.Web.MsHtml.styleVerticalAlign = 3
styleVerticalAlignTop: win32more.Windows.Win32.Web.MsHtml.styleVerticalAlign = 4
styleVerticalAlignTextTop: win32more.Windows.Win32.Web.MsHtml.styleVerticalAlign = 5
styleVerticalAlignMiddle: win32more.Windows.Win32.Web.MsHtml.styleVerticalAlign = 6
styleVerticalAlignBottom: win32more.Windows.Win32.Web.MsHtml.styleVerticalAlign = 7
styleVerticalAlignTextBottom: win32more.Windows.Win32.Web.MsHtml.styleVerticalAlign = 8
styleVerticalAlignInherit: win32more.Windows.Win32.Web.MsHtml.styleVerticalAlign = 9
styleVerticalAlignNotSet: win32more.Windows.Win32.Web.MsHtml.styleVerticalAlign = 10
styleVerticalAlign_Max: win32more.Windows.Win32.Web.MsHtml.styleVerticalAlign = 2147483647
styleViewportSize = Int32
styleViewportSizeAuto: win32more.Windows.Win32.Web.MsHtml.styleViewportSize = 0
styleViewportSizeDeviceWidth: win32more.Windows.Win32.Web.MsHtml.styleViewportSize = 1
styleViewportSizeDeviceHeight: win32more.Windows.Win32.Web.MsHtml.styleViewportSize = 2
styleViewportSize_Max: win32more.Windows.Win32.Web.MsHtml.styleViewportSize = 2147483647
styleVisibility = Int32
styleVisibilityNotSet: win32more.Windows.Win32.Web.MsHtml.styleVisibility = 0
styleVisibilityInherit: win32more.Windows.Win32.Web.MsHtml.styleVisibility = 1
styleVisibilityVisible: win32more.Windows.Win32.Web.MsHtml.styleVisibility = 2
styleVisibilityHidden: win32more.Windows.Win32.Web.MsHtml.styleVisibility = 3
styleVisibilityCollapse: win32more.Windows.Win32.Web.MsHtml.styleVisibility = 4
styleVisibility_Max: win32more.Windows.Win32.Web.MsHtml.styleVisibility = 2147483647
styleWebkitAppearance = Int32
styleWebkitAppearanceNone: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 0
styleWebkitAppearanceCapsLockIndicator: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 1
styleWebkitAppearanceButton: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 2
styleWebkitAppearanceButtonBevel: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 3
styleWebkitAppearanceCaret: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 4
styleWebkitAppearanceCheckbox: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 5
styleWebkitAppearanceDefaultButton: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 6
styleWebkitAppearanceListbox: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 7
styleWebkitAppearanceListitem: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 8
styleWebkitAppearanceMediaFullscreenButton: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 9
styleWebkitAppearanceMediaMuteButton: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 10
styleWebkitAppearanceMediaPlayButton: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 11
styleWebkitAppearanceMediaSeekBackButton: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 12
styleWebkitAppearanceMediaSeekForwardButton: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 13
styleWebkitAppearanceMediaSlider: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 14
styleWebkitAppearanceMediaSliderthumb: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 15
styleWebkitAppearanceMenulist: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 16
styleWebkitAppearanceMenulistButton: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 17
styleWebkitAppearanceMenulistText: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 18
styleWebkitAppearanceMenulistTextfield: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 19
styleWebkitAppearancePushButton: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 20
styleWebkitAppearanceRadio: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 21
styleWebkitAppearanceSearchfield: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 22
styleWebkitAppearanceSearchfieldCancelButton: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 23
styleWebkitAppearanceSearchfieldDecoration: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 24
styleWebkitAppearanceSearchfieldResultsButton: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 25
styleWebkitAppearanceSearchfieldResultsDecoration: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 26
styleWebkitAppearanceSliderHorizontal: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 27
styleWebkitAppearanceSliderVertical: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 28
styleWebkitAppearanceSliderthumbHorizontal: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 29
styleWebkitAppearanceSliderthumbVertical: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 30
styleWebkitAppearanceSquareButton: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 31
styleWebkitAppearanceTextarea: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 32
styleWebkitAppearanceTextfield: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 33
styleWebkitAppearanceNotSet: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 34
styleWebkitAppearance_Max: win32more.Windows.Win32.Web.MsHtml.styleWebkitAppearance = 2147483647
styleWebkitBoxDirection = Int32
styleWebkitBoxDirectionNormal: win32more.Windows.Win32.Web.MsHtml.styleWebkitBoxDirection = 0
styleWebkitBoxDirectionReverse: win32more.Windows.Win32.Web.MsHtml.styleWebkitBoxDirection = 1
styleWebkitBoxDirectionNotSet: win32more.Windows.Win32.Web.MsHtml.styleWebkitBoxDirection = 2
styleWebkitBoxDirection_Max: win32more.Windows.Win32.Web.MsHtml.styleWebkitBoxDirection = 2147483647
styleWebkitBoxOrient = Int32
styleWebkitBoxOrientHorizontal: win32more.Windows.Win32.Web.MsHtml.styleWebkitBoxOrient = 0
styleWebkitBoxOrientInlineAxis: win32more.Windows.Win32.Web.MsHtml.styleWebkitBoxOrient = 1
styleWebkitBoxOrientVertical: win32more.Windows.Win32.Web.MsHtml.styleWebkitBoxOrient = 2
styleWebkitBoxOrientBlockAxis: win32more.Windows.Win32.Web.MsHtml.styleWebkitBoxOrient = 3
styleWebkitBoxOrientNotSet: win32more.Windows.Win32.Web.MsHtml.styleWebkitBoxOrient = 4
styleWebkitBoxOrient_Max: win32more.Windows.Win32.Web.MsHtml.styleWebkitBoxOrient = 2147483647
styleWebkitBoxPack = Int32
styleWebkitBoxPackStart: win32more.Windows.Win32.Web.MsHtml.styleWebkitBoxPack = 0
styleWebkitBoxPackEnd: win32more.Windows.Win32.Web.MsHtml.styleWebkitBoxPack = 1
styleWebkitBoxPackCenter: win32more.Windows.Win32.Web.MsHtml.styleWebkitBoxPack = 2
styleWebkitBoxPackJustify: win32more.Windows.Win32.Web.MsHtml.styleWebkitBoxPack = 3
styleWebkitBoxPackNotSet: win32more.Windows.Win32.Web.MsHtml.styleWebkitBoxPack = 5
styleWebkitBoxPack_Max: win32more.Windows.Win32.Web.MsHtml.styleWebkitBoxPack = 2147483647
styleWhiteSpace = Int32
styleWhiteSpaceNotSet: win32more.Windows.Win32.Web.MsHtml.styleWhiteSpace = 0
styleWhiteSpaceNormal: win32more.Windows.Win32.Web.MsHtml.styleWhiteSpace = 1
styleWhiteSpacePre: win32more.Windows.Win32.Web.MsHtml.styleWhiteSpace = 2
styleWhiteSpaceNowrap: win32more.Windows.Win32.Web.MsHtml.styleWhiteSpace = 3
styleWhiteSpacePreline: win32more.Windows.Win32.Web.MsHtml.styleWhiteSpace = 4
styleWhiteSpacePrewrap: win32more.Windows.Win32.Web.MsHtml.styleWhiteSpace = 5
styleWhiteSpace_Max: win32more.Windows.Win32.Web.MsHtml.styleWhiteSpace = 2147483647
styleWidowsOrphans = Int32
styleWidowsOrphansNotSet: win32more.Windows.Win32.Web.MsHtml.styleWidowsOrphans = -2147483647
styleWidowsOrphans_Max: win32more.Windows.Win32.Web.MsHtml.styleWidowsOrphans = 2147483647
styleWordBreak = Int32
styleWordBreakNotSet: win32more.Windows.Win32.Web.MsHtml.styleWordBreak = 0
styleWordBreakNormal: win32more.Windows.Win32.Web.MsHtml.styleWordBreak = 1
styleWordBreakBreakAll: win32more.Windows.Win32.Web.MsHtml.styleWordBreak = 2
styleWordBreakKeepAll: win32more.Windows.Win32.Web.MsHtml.styleWordBreak = 3
styleWordBreak_Max: win32more.Windows.Win32.Web.MsHtml.styleWordBreak = 2147483647
styleWordWrap = Int32
styleWordWrapNotSet: win32more.Windows.Win32.Web.MsHtml.styleWordWrap = 0
styleWordWrapOff: win32more.Windows.Win32.Web.MsHtml.styleWordWrap = 1
styleWordWrapOn: win32more.Windows.Win32.Web.MsHtml.styleWordWrap = 2
styleWordWrap_Max: win32more.Windows.Win32.Web.MsHtml.styleWordWrap = 2147483647
styleWrapFlow = Int32
styleWrapFlowNotSet: win32more.Windows.Win32.Web.MsHtml.styleWrapFlow = 0
styleWrapFlowAuto: win32more.Windows.Win32.Web.MsHtml.styleWrapFlow = 1
styleWrapFlowBoth: win32more.Windows.Win32.Web.MsHtml.styleWrapFlow = 2
styleWrapFlowStart: win32more.Windows.Win32.Web.MsHtml.styleWrapFlow = 3
styleWrapFlowEnd: win32more.Windows.Win32.Web.MsHtml.styleWrapFlow = 4
styleWrapFlowClear: win32more.Windows.Win32.Web.MsHtml.styleWrapFlow = 5
styleWrapFlowMinimum: win32more.Windows.Win32.Web.MsHtml.styleWrapFlow = 6
styleWrapFlowMaximum: win32more.Windows.Win32.Web.MsHtml.styleWrapFlow = 7
styleWrapFlow_Max: win32more.Windows.Win32.Web.MsHtml.styleWrapFlow = 2147483647
styleWrapThrough = Int32
styleWrapThroughNotSet: win32more.Windows.Win32.Web.MsHtml.styleWrapThrough = 0
styleWrapThroughWrap: win32more.Windows.Win32.Web.MsHtml.styleWrapThrough = 1
styleWrapThroughNone: win32more.Windows.Win32.Web.MsHtml.styleWrapThrough = 2
styleWrapThrough_Max: win32more.Windows.Win32.Web.MsHtml.styleWrapThrough = 2147483647
styleWritingMode = Int32
styleWritingModeLrtb: win32more.Windows.Win32.Web.MsHtml.styleWritingMode = 0
styleWritingModeTbrl: win32more.Windows.Win32.Web.MsHtml.styleWritingMode = 1
styleWritingModeRltb: win32more.Windows.Win32.Web.MsHtml.styleWritingMode = 2
styleWritingModeBtrl: win32more.Windows.Win32.Web.MsHtml.styleWritingMode = 3
styleWritingModeNotSet: win32more.Windows.Win32.Web.MsHtml.styleWritingMode = 4
styleWritingModeTblr: win32more.Windows.Win32.Web.MsHtml.styleWritingMode = 5
styleWritingModeBtlr: win32more.Windows.Win32.Web.MsHtml.styleWritingMode = 6
styleWritingModeLrbt: win32more.Windows.Win32.Web.MsHtml.styleWritingMode = 7
styleWritingModeRlbt: win32more.Windows.Win32.Web.MsHtml.styleWritingMode = 8
styleWritingModeLr: win32more.Windows.Win32.Web.MsHtml.styleWritingMode = 9
styleWritingModeRl: win32more.Windows.Win32.Web.MsHtml.styleWritingMode = 10
styleWritingModeTb: win32more.Windows.Win32.Web.MsHtml.styleWritingMode = 11
styleWritingMode_Max: win32more.Windows.Win32.Web.MsHtml.styleWritingMode = 2147483647
styleZIndex = Int32
styleZIndexAuto: win32more.Windows.Win32.Web.MsHtml.styleZIndex = -2147483647
styleZIndex_Max: win32more.Windows.Win32.Web.MsHtml.styleZIndex = 2147483647
svgAngleType = Int32
SVG_ANGLETYPE_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgAngleType = 0
SVG_ANGLETYPE_UNSPECIFIED: win32more.Windows.Win32.Web.MsHtml.svgAngleType = 1
SVG_ANGLETYPE_DEG: win32more.Windows.Win32.Web.MsHtml.svgAngleType = 2
SVG_ANGLETYPE_RAD: win32more.Windows.Win32.Web.MsHtml.svgAngleType = 3
SVG_ANGLETYPE_GRAD: win32more.Windows.Win32.Web.MsHtml.svgAngleType = 4
svgAngleType_Max: win32more.Windows.Win32.Web.MsHtml.svgAngleType = 2147483647
svgChannel = Int32
SVG_CHANNEL_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgChannel = 0
SVG_CHANNEL_R: win32more.Windows.Win32.Web.MsHtml.svgChannel = 1
SVG_CHANNEL_G: win32more.Windows.Win32.Web.MsHtml.svgChannel = 2
SVG_CHANNEL_B: win32more.Windows.Win32.Web.MsHtml.svgChannel = 3
SVG_CHANNEL_A: win32more.Windows.Win32.Web.MsHtml.svgChannel = 4
svgChannel_Max: win32more.Windows.Win32.Web.MsHtml.svgChannel = 2147483647
svgEdgemode = Int32
SVG_EDGEMODE_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgEdgemode = 0
SVG_EDGEMODE_DUPLICATE: win32more.Windows.Win32.Web.MsHtml.svgEdgemode = 1
SVG_EDGEMODE_WRAP: win32more.Windows.Win32.Web.MsHtml.svgEdgemode = 2
SVG_EDGEMODE_NONE: win32more.Windows.Win32.Web.MsHtml.svgEdgemode = 3
svgEdgemode_Max: win32more.Windows.Win32.Web.MsHtml.svgEdgemode = 2147483647
svgExternalResourcesRequired = Int32
svgExternalResourcesRequiredFalse: win32more.Windows.Win32.Web.MsHtml.svgExternalResourcesRequired = 0
svgExternalResourcesRequiredTrue: win32more.Windows.Win32.Web.MsHtml.svgExternalResourcesRequired = 1
svgExternalResourcesRequired_Max: win32more.Windows.Win32.Web.MsHtml.svgExternalResourcesRequired = 2147483647
svgFeblendMode = Int32
SVG_FEBLEND_MODE_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgFeblendMode = 0
SVG_FEBLEND_MODE_NORMAL: win32more.Windows.Win32.Web.MsHtml.svgFeblendMode = 1
SVG_FEBLEND_MODE_MULTIPLY: win32more.Windows.Win32.Web.MsHtml.svgFeblendMode = 2
SVG_FEBLEND_MODE_SCREEN: win32more.Windows.Win32.Web.MsHtml.svgFeblendMode = 3
SVG_FEBLEND_MODE_DARKEN: win32more.Windows.Win32.Web.MsHtml.svgFeblendMode = 4
SVG_FEBLEND_MODE_LIGHTEN: win32more.Windows.Win32.Web.MsHtml.svgFeblendMode = 5
svgFeblendMode_Max: win32more.Windows.Win32.Web.MsHtml.svgFeblendMode = 2147483647
svgFecolormatrixType = Int32
SVG_FECOLORMATRIX_TYPE_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgFecolormatrixType = 0
SVG_FECOLORMATRIX_TYPE_MATRIX: win32more.Windows.Win32.Web.MsHtml.svgFecolormatrixType = 1
SVG_FECOLORMATRIX_TYPE_SATURATE: win32more.Windows.Win32.Web.MsHtml.svgFecolormatrixType = 2
SVG_FECOLORMATRIX_TYPE_HUEROTATE: win32more.Windows.Win32.Web.MsHtml.svgFecolormatrixType = 3
SVG_FECOLORMATRIX_TYPE_LUMINANCETOALPHA: win32more.Windows.Win32.Web.MsHtml.svgFecolormatrixType = 4
svgFecolormatrixType_Max: win32more.Windows.Win32.Web.MsHtml.svgFecolormatrixType = 2147483647
svgFecomponenttransferType = Int32
SVG_FECOMPONENTTRANSFER_TYPE_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgFecomponenttransferType = 0
SVG_FECOMPONENTTRANSFER_TYPE_IDENTITY: win32more.Windows.Win32.Web.MsHtml.svgFecomponenttransferType = 1
SVG_FECOMPONENTTRANSFER_TYPE_TABLE: win32more.Windows.Win32.Web.MsHtml.svgFecomponenttransferType = 2
SVG_FECOMPONENTTRANSFER_TYPE_DISCRETE: win32more.Windows.Win32.Web.MsHtml.svgFecomponenttransferType = 3
SVG_FECOMPONENTTRANSFER_TYPE_LINEAR: win32more.Windows.Win32.Web.MsHtml.svgFecomponenttransferType = 4
SVG_FECOMPONENTTRANSFER_TYPE_GAMMA: win32more.Windows.Win32.Web.MsHtml.svgFecomponenttransferType = 5
svgFecomponenttransferType_Max: win32more.Windows.Win32.Web.MsHtml.svgFecomponenttransferType = 2147483647
svgFecompositeOperator = Int32
SVG_FECOMPOSITE_OPERATOR_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgFecompositeOperator = 0
SVG_FECOMPOSITE_OPERATOR_OVER: win32more.Windows.Win32.Web.MsHtml.svgFecompositeOperator = 1
SVG_FECOMPOSITE_OPERATOR_IN: win32more.Windows.Win32.Web.MsHtml.svgFecompositeOperator = 2
SVG_FECOMPOSITE_OPERATOR_OUT: win32more.Windows.Win32.Web.MsHtml.svgFecompositeOperator = 3
SVG_FECOMPOSITE_OPERATOR_ATOP: win32more.Windows.Win32.Web.MsHtml.svgFecompositeOperator = 4
SVG_FECOMPOSITE_OPERATOR_XOR: win32more.Windows.Win32.Web.MsHtml.svgFecompositeOperator = 5
SVG_FECOMPOSITE_OPERATOR_ARITHMETIC: win32more.Windows.Win32.Web.MsHtml.svgFecompositeOperator = 6
svgFecompositeOperator_Max: win32more.Windows.Win32.Web.MsHtml.svgFecompositeOperator = 2147483647
svgFocusable = Int32
svgFocusableNotSet: win32more.Windows.Win32.Web.MsHtml.svgFocusable = 0
svgFocusableAuto: win32more.Windows.Win32.Web.MsHtml.svgFocusable = 1
svgFocusableTrue: win32more.Windows.Win32.Web.MsHtml.svgFocusable = 2
svgFocusableFalse: win32more.Windows.Win32.Web.MsHtml.svgFocusable = 3
svgFocusable_Max: win32more.Windows.Win32.Web.MsHtml.svgFocusable = 2147483647
svgLengthType = Int32
SVG_LENGTHTYPE_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgLengthType = 0
SVG_LENGTHTYPE_NUMBER: win32more.Windows.Win32.Web.MsHtml.svgLengthType = 1
SVG_LENGTHTYPE_PERCENTAGE: win32more.Windows.Win32.Web.MsHtml.svgLengthType = 2
SVG_LENGTHTYPE_EMS: win32more.Windows.Win32.Web.MsHtml.svgLengthType = 3
SVG_LENGTHTYPE_EXS: win32more.Windows.Win32.Web.MsHtml.svgLengthType = 4
SVG_LENGTHTYPE_PX: win32more.Windows.Win32.Web.MsHtml.svgLengthType = 5
SVG_LENGTHTYPE_CM: win32more.Windows.Win32.Web.MsHtml.svgLengthType = 6
SVG_LENGTHTYPE_MM: win32more.Windows.Win32.Web.MsHtml.svgLengthType = 7
SVG_LENGTHTYPE_IN: win32more.Windows.Win32.Web.MsHtml.svgLengthType = 8
SVG_LENGTHTYPE_PT: win32more.Windows.Win32.Web.MsHtml.svgLengthType = 9
SVG_LENGTHTYPE_PC: win32more.Windows.Win32.Web.MsHtml.svgLengthType = 10
svgLengthType_Max: win32more.Windows.Win32.Web.MsHtml.svgLengthType = 2147483647
svgMarkerOrient = Int32
SVG_MARKER_ORIENT_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgMarkerOrient = 0
SVG_MARKER_ORIENT_AUTO: win32more.Windows.Win32.Web.MsHtml.svgMarkerOrient = 1
SVG_MARKER_ORIENT_ANGLE: win32more.Windows.Win32.Web.MsHtml.svgMarkerOrient = 2
svgMarkerOrient_Max: win32more.Windows.Win32.Web.MsHtml.svgMarkerOrient = 2147483647
svgMarkerOrientAttribute = Int32
svgMarkerOrientAttributeAuto: win32more.Windows.Win32.Web.MsHtml.svgMarkerOrientAttribute = 0
svgMarkerOrientAttribute_Max: win32more.Windows.Win32.Web.MsHtml.svgMarkerOrientAttribute = 2147483647
svgMarkerUnits = Int32
SVG_MARKERUNITS_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgMarkerUnits = 0
SVG_MARKERUNITS_USERSPACEONUSE: win32more.Windows.Win32.Web.MsHtml.svgMarkerUnits = 1
SVG_MARKERUNITS_STROKEWIDTH: win32more.Windows.Win32.Web.MsHtml.svgMarkerUnits = 2
svgMarkerUnits_Max: win32more.Windows.Win32.Web.MsHtml.svgMarkerUnits = 2147483647
svgMorphologyOperator = Int32
SVG_MORPHOLOGY_OPERATOR_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgMorphologyOperator = 0
SVG_MORPHOLOGY_OPERATOR_ERODE: win32more.Windows.Win32.Web.MsHtml.svgMorphologyOperator = 1
SVG_MORPHOLOGY_OPERATOR_DILATE: win32more.Windows.Win32.Web.MsHtml.svgMorphologyOperator = 2
svgMorphologyOperator_Max: win32more.Windows.Win32.Web.MsHtml.svgMorphologyOperator = 2147483647
svgPathSegType = Int32
PATHSEG_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 0
PATHSEG_CLOSEPATH: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 1
PATHSEG_MOVETO_ABS: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 2
PATHSEG_MOVETO_REL: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 3
PATHSEG_LINETO_ABS: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 4
PATHSEG_LINETO_REL: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 5
PATHSEG_CURVETO_CUBIC_ABS: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 6
PATHSEG_CURVETO_CUBIC_REL: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 7
PATHSEG_CURVETO_QUADRATIC_ABS: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 8
PATHSEG_CURVETO_QUADRATIC_REL: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 9
PATHSEG_ARC_ABS: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 10
PATHSEG_ARC_REL: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 11
PATHSEG_LINETO_HORIZONTAL_ABS: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 12
PATHSEG_LINETO_HORIZONTAL_REL: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 13
PATHSEG_LINETO_VERTICAL_ABS: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 14
PATHSEG_LINETO_VERTICAL_REL: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 15
PATHSEG_CURVETO_CUBIC_SMOOTH_ABS: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 16
PATHSEG_CURVETO_CUBIC_SMOOTH_REL: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 17
PATHSEG_CURVETO_QUADRATIC_SMOOTH_ABS: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 18
PATHSEG_CURVETO_QUADRATIC_SMOOTH_REL: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 19
svgPathSegType_Max: win32more.Windows.Win32.Web.MsHtml.svgPathSegType = 2147483647
svgPreserveAlpha = Int32
SVG_PRESERVEALPHA_FALSE: win32more.Windows.Win32.Web.MsHtml.svgPreserveAlpha = 0
SVG_PRESERVEALPHA_TRUE: win32more.Windows.Win32.Web.MsHtml.svgPreserveAlpha = 1
svgPreserveAlpha_Max: win32more.Windows.Win32.Web.MsHtml.svgPreserveAlpha = 2147483647
svgPreserveAspectMeetOrSliceType = Int32
SVG_MEETORSLICE_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgPreserveAspectMeetOrSliceType = 0
SVG_MEETORSLICE_MEET: win32more.Windows.Win32.Web.MsHtml.svgPreserveAspectMeetOrSliceType = 1
SVG_MEETORSLICE_SLICE: win32more.Windows.Win32.Web.MsHtml.svgPreserveAspectMeetOrSliceType = 2
svgPreserveAspectMeetOrSliceType_Max: win32more.Windows.Win32.Web.MsHtml.svgPreserveAspectMeetOrSliceType = 2147483647
svgPreserveAspectRatioAlignType = Int32
SVG_PRESERVEASPECTRATIO_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgPreserveAspectRatioAlignType = 0
SVG_PRESERVEASPECTRATIO_NONE: win32more.Windows.Win32.Web.MsHtml.svgPreserveAspectRatioAlignType = 1
SVG_PRESERVEASPECTRATIO_XMINYMIN: win32more.Windows.Win32.Web.MsHtml.svgPreserveAspectRatioAlignType = 2
SVG_PRESERVEASPECTRATIO_XMIDYMIN: win32more.Windows.Win32.Web.MsHtml.svgPreserveAspectRatioAlignType = 3
SVG_PRESERVEASPECTRATIO_XMAXYMIN: win32more.Windows.Win32.Web.MsHtml.svgPreserveAspectRatioAlignType = 4
SVG_PRESERVEASPECTRATIO_XMINYMID: win32more.Windows.Win32.Web.MsHtml.svgPreserveAspectRatioAlignType = 5
SVG_PRESERVEASPECTRATIO_XMIDYMID: win32more.Windows.Win32.Web.MsHtml.svgPreserveAspectRatioAlignType = 6
SVG_PRESERVEASPECTRATIO_XMAXYMID: win32more.Windows.Win32.Web.MsHtml.svgPreserveAspectRatioAlignType = 7
SVG_PRESERVEASPECTRATIO_XMINYMAX: win32more.Windows.Win32.Web.MsHtml.svgPreserveAspectRatioAlignType = 8
SVG_PRESERVEASPECTRATIO_XMIDYMAX: win32more.Windows.Win32.Web.MsHtml.svgPreserveAspectRatioAlignType = 9
SVG_PRESERVEASPECTRATIO_XMAXYMAX: win32more.Windows.Win32.Web.MsHtml.svgPreserveAspectRatioAlignType = 10
svgPreserveAspectRatioAlignType_Max: win32more.Windows.Win32.Web.MsHtml.svgPreserveAspectRatioAlignType = 2147483647
svgSpreadMethod = Int32
SVG_SPREADMETHOD_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgSpreadMethod = 0
SVG_SPREADMETHOD_PAD: win32more.Windows.Win32.Web.MsHtml.svgSpreadMethod = 1
SVG_SPREADMETHOD_REFLECT: win32more.Windows.Win32.Web.MsHtml.svgSpreadMethod = 2
SVG_SPREADMETHOD_REPEAT: win32more.Windows.Win32.Web.MsHtml.svgSpreadMethod = 3
svgSpreadMethod_Max: win32more.Windows.Win32.Web.MsHtml.svgSpreadMethod = 2147483647
svgStitchtype = Int32
SVG_STITCHTYPE_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgStitchtype = 0
SVG_STITCHTYPE_STITCH: win32more.Windows.Win32.Web.MsHtml.svgStitchtype = 1
SVG_STITCHTYPE_NOSTITCH: win32more.Windows.Win32.Web.MsHtml.svgStitchtype = 2
svgStitchtype_Max: win32more.Windows.Win32.Web.MsHtml.svgStitchtype = 2147483647
svgTransformType = Int32
SVG_TRANSFORM_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgTransformType = 0
SVG_TRANSFORM_MATRIX: win32more.Windows.Win32.Web.MsHtml.svgTransformType = 1
SVG_TRANSFORM_TRANSLATE: win32more.Windows.Win32.Web.MsHtml.svgTransformType = 2
SVG_TRANSFORM_SCALE: win32more.Windows.Win32.Web.MsHtml.svgTransformType = 3
SVG_TRANSFORM_ROTATE: win32more.Windows.Win32.Web.MsHtml.svgTransformType = 4
SVG_TRANSFORM_SKEWX: win32more.Windows.Win32.Web.MsHtml.svgTransformType = 5
SVG_TRANSFORM_SKEWY: win32more.Windows.Win32.Web.MsHtml.svgTransformType = 6
svgTransformType_Max: win32more.Windows.Win32.Web.MsHtml.svgTransformType = 2147483647
svgTurbulenceType = Int32
SVG_TURBULENCE_TYPE_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgTurbulenceType = 0
SVG_TURBULENCE_TYPE_FACTALNOISE: win32more.Windows.Win32.Web.MsHtml.svgTurbulenceType = 1
SVG_TURBULENCE_TYPE_TURBULENCE: win32more.Windows.Win32.Web.MsHtml.svgTurbulenceType = 2
svgTurbulenceType_Max: win32more.Windows.Win32.Web.MsHtml.svgTurbulenceType = 2147483647
svgUnitTypes = Int32
SVG_UNITTYPE_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.svgUnitTypes = 0
SVG_UNITTYPE_USERSPACEONUSE: win32more.Windows.Win32.Web.MsHtml.svgUnitTypes = 1
SVG_UNITTYPE_OBJECTBOUNDINGBOX: win32more.Windows.Win32.Web.MsHtml.svgUnitTypes = 2
svgUnitTypes_Max: win32more.Windows.Win32.Web.MsHtml.svgUnitTypes = 2147483647
textDecoration = Int32
textDecorationNone: win32more.Windows.Win32.Web.MsHtml.textDecoration = 0
textDecorationUnderline: win32more.Windows.Win32.Web.MsHtml.textDecoration = 1
textDecorationOverline: win32more.Windows.Win32.Web.MsHtml.textDecoration = 2
textDecorationLineThrough: win32more.Windows.Win32.Web.MsHtml.textDecoration = 3
textDecorationBlink: win32more.Windows.Win32.Web.MsHtml.textDecoration = 4
textDecoration_Max: win32more.Windows.Win32.Web.MsHtml.textDecoration = 2147483647
textpathMethodtype = Int32
TEXTPATH_METHODTYPE_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.textpathMethodtype = 0
TEXTPATH_METHODTYPE_ALIGN: win32more.Windows.Win32.Web.MsHtml.textpathMethodtype = 1
TEXTPATH_METHODTYPE_STRETCH: win32more.Windows.Win32.Web.MsHtml.textpathMethodtype = 2
textpathMethodtype_Max: win32more.Windows.Win32.Web.MsHtml.textpathMethodtype = 2147483647
textpathSpacingtype = Int32
TEXTPATH_SPACINGTYPE_UNKNOWN: win32more.Windows.Win32.Web.MsHtml.textpathSpacingtype = 0
TEXTPATH_SPACINGTYPE_AUTO: win32more.Windows.Win32.Web.MsHtml.textpathSpacingtype = 1
TEXTPATH_SPACINGTYPE_EXACT: win32more.Windows.Win32.Web.MsHtml.textpathSpacingtype = 2
textpathSpacingtype_Max: win32more.Windows.Win32.Web.MsHtml.textpathSpacingtype = 2147483647


make_ready(__name__)
