from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
class APP_LOCAL_DEVICE_ID(Structure):
    value: Byte * 32
TRUE: win32more.Windows.Win32.Foundation.BOOL = 1
FALSE: win32more.Windows.Win32.Foundation.BOOL = 0
VARIANT_TRUE: win32more.Windows.Win32.Foundation.VARIANT_BOOL = -1
VARIANT_FALSE: win32more.Windows.Win32.Foundation.VARIANT_BOOL = 0
INVALID_HANDLE_VALUE: win32more.Windows.Win32.Foundation.HANDLE = -1
CO_E_NOTINITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2147221008
STILL_ACTIVE: win32more.Windows.Win32.Foundation.NTSTATUS = 259
EXCEPTION_ACCESS_VIOLATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741819
EXCEPTION_DATATYPE_MISALIGNMENT: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483646
EXCEPTION_BREAKPOINT: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483645
EXCEPTION_SINGLE_STEP: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483644
EXCEPTION_ARRAY_BOUNDS_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741684
EXCEPTION_FLT_DENORMAL_OPERAND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741683
EXCEPTION_FLT_DIVIDE_BY_ZERO: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741682
EXCEPTION_FLT_INEXACT_RESULT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741681
EXCEPTION_FLT_INVALID_OPERATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741680
EXCEPTION_FLT_OVERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741679
EXCEPTION_FLT_STACK_CHECK: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741678
EXCEPTION_FLT_UNDERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741677
EXCEPTION_INT_DIVIDE_BY_ZERO: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741676
EXCEPTION_INT_OVERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741675
EXCEPTION_PRIV_INSTRUCTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741674
EXCEPTION_IN_PAGE_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741818
EXCEPTION_ILLEGAL_INSTRUCTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741795
EXCEPTION_NONCONTINUABLE_EXCEPTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741787
EXCEPTION_STACK_OVERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741571
EXCEPTION_INVALID_DISPOSITION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741786
EXCEPTION_GUARD_PAGE: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483647
EXCEPTION_INVALID_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741816
EXCEPTION_POSSIBLE_DEADLOCK: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741420
EXCEPTION_SPAPI_UNRECOVERABLE_STACK_OVERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -536870144
CONTROL_C_EXIT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741510
STATUS_ACCESS_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741790
E_NOTIMPL: win32more.Windows.Win32.Foundation.HRESULT = -2147467263
E_OUTOFMEMORY: win32more.Windows.Win32.Foundation.HRESULT = -2147024882
E_INVALIDARG: win32more.Windows.Win32.Foundation.HRESULT = -2147024809
E_FAIL: win32more.Windows.Win32.Foundation.HRESULT = -2147467259
STRICT: UInt32 = 1
MAX_PATH: UInt32 = 260
IO_ERR_INSUFFICIENT_RESOURCES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479678
IO_ERR_DRIVER_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479676
IO_ERR_SEEK_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479674
IO_ERR_BAD_BLOCK: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479673
IO_ERR_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479671
IO_ERR_CONTROLLER_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479669
IO_ERR_NOT_READY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479665
IO_ERR_INVALID_REQUEST: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479664
IO_ERR_RESET: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479661
IO_ERR_BAD_FIRMWARE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479655
IO_WRN_BAD_FIRMWARE: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221478
IO_WRITE_CACHE_ENABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221472
IO_RECOVERED_VIA_ECC: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221471
IO_WRITE_CACHE_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221470
IO_WARNING_PAGING_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221453
IO_WRN_FAILURE_PREDICTED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221452
IO_WARNING_ALLOCATION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221448
IO_WARNING_DUPLICATE_SIGNATURE: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221446
IO_WARNING_DUPLICATE_PATH: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221445
IO_WARNING_WRITE_FUA_PROBLEM: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221372
IO_WARNING_VOLUME_LOST_DISK_EXTENT: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221362
IO_WARNING_DEVICE_HAS_INTERNAL_DUMP: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221361
IO_WARNING_SOFT_THRESHOLD_REACHED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221360
IO_WARNING_SOFT_THRESHOLD_REACHED_EX: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221359
IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_LUN: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221358
IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_POOL: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221357
IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_LUN: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221356
IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_POOL: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221355
IO_ERROR_DISK_RESOURCES_EXHAUSTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479530
IO_WARNING_DISK_CAPACITY_CHANGED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221353
IO_WARNING_DISK_PROVISIONING_TYPE_CHANGED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221352
IO_WARNING_IO_OPERATION_RETRIED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221351
IO_ERROR_IO_HARDWARE_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479526
IO_WARNING_COMPLETION_TIME: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221349
IO_WARNING_DISK_SURPRISE_REMOVED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221347
IO_WARNING_REPEATED_DISK_GUID: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221346
IO_WARNING_DISK_FIRMWARE_UPDATED: win32more.Windows.Win32.Foundation.NTSTATUS = 1074004127
IO_ERR_RETRY_SUCCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = 262145
IO_DUMP_CREATION_SUCCESS: win32more.Windows.Win32.Foundation.NTSTATUS = 262306
IO_FILE_QUOTA_THRESHOLD: win32more.Windows.Win32.Foundation.NTSTATUS = 1074004004
IO_FILE_QUOTA_LIMIT: win32more.Windows.Win32.Foundation.NTSTATUS = 1074004005
IO_FILE_QUOTA_STARTED: win32more.Windows.Win32.Foundation.NTSTATUS = 1074004006
IO_FILE_QUOTA_SUCCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = 1074004007
IO_INFO_THROTTLE_COMPLETE: win32more.Windows.Win32.Foundation.NTSTATUS = 1074004087
IO_CDROM_EXCLUSIVE_LOCK: win32more.Windows.Win32.Foundation.NTSTATUS = 1074004101
IO_WARNING_ADAPTER_FIRMWARE_UPDATED: win32more.Windows.Win32.Foundation.NTSTATUS = 1074004128
IO_FILE_QUOTA_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221464
IO_LOST_DELAYED_WRITE: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221454
IO_WARNING_INTERRUPT_STILL_PENDING: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221451
IO_DRIVER_CANCEL_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221450
IO_WARNING_LOG_FLUSH_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221447
IO_WARNING_BUS_RESET: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221386
IO_WARNING_RESET: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221375
IO_LOST_DELAYED_WRITE_NETWORK_DISCONNECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221365
IO_LOST_DELAYED_WRITE_NETWORK_SERVER_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221364
IO_LOST_DELAYED_WRITE_NETWORK_LOCAL_DISK_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221363
IO_WARNING_DUMP_DISABLED_DEVICE_GONE: win32more.Windows.Win32.Foundation.NTSTATUS = -2147221348
IO_ERR_CONFIGURATION_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479677
IO_ERR_PARITY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479675
IO_ERR_OVERRUN_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479672
IO_ERR_SEQUENCE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479670
IO_ERR_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479668
IO_ERR_INCORRECT_IRQL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479667
IO_ERR_INVALID_IOBASE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479666
IO_ERR_VERSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479663
IO_ERR_LAYERED_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479662
IO_ERR_PROTOCOL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479660
IO_ERR_MEMORY_CONFLICT_DETECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479659
IO_ERR_PORT_CONFLICT_DETECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479658
IO_ERR_DMA_CONFLICT_DETECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479657
IO_ERR_IRQ_CONFLICT_DETECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479656
IO_ERR_DMA_RESOURCE_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479653
IO_ERR_INTERRUPT_RESOURCE_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479652
IO_ERR_MEMORY_RESOURCE_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479651
IO_ERR_PORT_RESOURCE_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479650
IO_BAD_BLOCK_WITH_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479649
IO_FILE_SYSTEM_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479639
IO_FILE_QUOTA_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479638
IO_SYSTEM_SLEEP_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479637
IO_DUMP_POINTER_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479636
IO_DUMP_DRIVER_LOAD_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479635
IO_DUMP_INITIALIZATION_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479634
IO_DUMP_DUMPFILE_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479633
IO_DUMP_DIRECT_CONFIG_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479632
IO_DUMP_PAGE_CONFIG_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479631
IO_FILE_SYSTEM_CORRUPT_WITH_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479625
IO_ERR_THREAD_STUCK_IN_DEVICE_DRIVER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479572
IO_ERR_PORT_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479563
IO_ERROR_DUMP_CREATION_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479519
IO_DUMP_CALLBACK_EXCEPTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479517
IO_DUMP_INIT_DEDICATED_DUMP_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479516
MCA_INFO_CPU_THERMAL_THROTTLING_REMOVED: win32more.Windows.Win32.Foundation.NTSTATUS = 1074069616
MCA_INFO_NO_MORE_CORRECTED_ERROR_LOGS: win32more.Windows.Win32.Foundation.NTSTATUS = 1074069619
MCA_INFO_MEMORY_PAGE_MARKED_BAD: win32more.Windows.Win32.Foundation.NTSTATUS = 1074069620
MCA_WARNING_CACHE: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155908
MCA_WARNING_TLB: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155906
MCA_WARNING_CPU_BUS: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155904
MCA_WARNING_REGISTER_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155902
MCA_WARNING_MAS: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155900
MCA_WARNING_MEM_UNKNOWN: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155898
MCA_WARNING_MEM_1_2: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155896
MCA_WARNING_MEM_1_2_5: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155894
MCA_WARNING_MEM_1_2_5_4: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155892
MCA_WARNING_SYSTEM_EVENT: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155890
MCA_WARNING_PCI_BUS_PARITY: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155888
MCA_WARNING_PCI_BUS_PARITY_NO_INFO: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155886
MCA_WARNING_PCI_BUS_SERR: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155884
MCA_WARNING_PCI_BUS_SERR_NO_INFO: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155882
MCA_WARNING_PCI_BUS_MASTER_ABORT: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155880
MCA_WARNING_PCI_BUS_MASTER_ABORT_NO_INFO: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155878
MCA_WARNING_PCI_BUS_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155876
MCA_WARNING_PCI_BUS_TIMEOUT_NO_INFO: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155874
MCA_WARNING_PCI_BUS_UNKNOWN: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155872
MCA_WARNING_PCI_DEVICE: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155870
MCA_WARNING_SMBIOS: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155868
MCA_WARNING_PLATFORM_SPECIFIC: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155866
MCA_WARNING_UNKNOWN: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155864
MCA_WARNING_UNKNOWN_NO_CPU: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155862
MCA_WARNING_CMC_THRESHOLD_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155859
MCA_WARNING_CPE_THRESHOLD_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155858
MCA_WARNING_CPU_THERMAL_THROTTLED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155857
MCA_WARNING_CPU: win32more.Windows.Win32.Foundation.NTSTATUS = -2147155855
MCA_ERROR_CACHE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414083
MCA_ERROR_TLB: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414081
MCA_ERROR_CPU_BUS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414079
MCA_ERROR_REGISTER_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414077
MCA_ERROR_MAS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414075
MCA_ERROR_MEM_UNKNOWN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414073
MCA_ERROR_MEM_1_2: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414071
MCA_ERROR_MEM_1_2_5: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414069
MCA_ERROR_MEM_1_2_5_4: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414067
MCA_ERROR_SYSTEM_EVENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414065
MCA_ERROR_PCI_BUS_PARITY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414063
MCA_ERROR_PCI_BUS_PARITY_NO_INFO: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414061
MCA_ERROR_PCI_BUS_SERR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414059
MCA_ERROR_PCI_BUS_SERR_NO_INFO: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414057
MCA_ERROR_PCI_BUS_MASTER_ABORT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414055
MCA_ERROR_PCI_BUS_MASTER_ABORT_NO_INFO: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414053
MCA_ERROR_PCI_BUS_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414051
MCA_ERROR_PCI_BUS_TIMEOUT_NO_INFO: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414049
MCA_ERROR_PCI_BUS_UNKNOWN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414047
MCA_ERROR_PCI_DEVICE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414045
MCA_ERROR_SMBIOS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414043
MCA_ERROR_PLATFORM_SPECIFIC: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414041
MCA_ERROR_UNKNOWN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414039
MCA_ERROR_UNKNOWN_NO_CPU: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414037
MCA_ERROR_CPU: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414030
MCA_MEMORYHIERARCHY_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414024
MCA_TLB_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414023
MCA_BUS_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414022
MCA_BUS_TIMEOUT_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414021
MCA_INTERNALTIMER_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414020
MCA_MICROCODE_ROM_PARITY_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414018
MCA_EXTERNAL_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414017
MCA_FRC_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073414016
VOLMGR_KSR_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -2143813631
VOLMGR_KSR_READ_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -2143813630
VOLMGR_KSR_BYPASS: win32more.Windows.Win32.Foundation.NTSTATUS = -2143813629
STATUS_WAIT_0: win32more.Windows.Win32.Foundation.NTSTATUS = 0
FACILTIY_MUI_ERROR_CODE: UInt32 = 11
STATUS_SUCCESS: win32more.Windows.Win32.Foundation.NTSTATUS = 0
STATUS_WAIT_1: win32more.Windows.Win32.Foundation.NTSTATUS = 1
STATUS_WAIT_2: win32more.Windows.Win32.Foundation.NTSTATUS = 2
STATUS_WAIT_3: win32more.Windows.Win32.Foundation.NTSTATUS = 3
STATUS_WAIT_63: win32more.Windows.Win32.Foundation.NTSTATUS = 63
STATUS_ABANDONED: win32more.Windows.Win32.Foundation.NTSTATUS = 128
STATUS_ABANDONED_WAIT_0: win32more.Windows.Win32.Foundation.NTSTATUS = 128
STATUS_ABANDONED_WAIT_63: win32more.Windows.Win32.Foundation.NTSTATUS = 191
STATUS_USER_APC: win32more.Windows.Win32.Foundation.NTSTATUS = 192
STATUS_ALREADY_COMPLETE: win32more.Windows.Win32.Foundation.NTSTATUS = 255
STATUS_KERNEL_APC: win32more.Windows.Win32.Foundation.NTSTATUS = 256
STATUS_ALERTED: win32more.Windows.Win32.Foundation.NTSTATUS = 257
STATUS_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = 258
STATUS_PENDING: win32more.Windows.Win32.Foundation.NTSTATUS = 259
STATUS_REPARSE: win32more.Windows.Win32.Foundation.NTSTATUS = 260
STATUS_MORE_ENTRIES: win32more.Windows.Win32.Foundation.NTSTATUS = 261
STATUS_NOT_ALL_ASSIGNED: win32more.Windows.Win32.Foundation.NTSTATUS = 262
STATUS_SOME_NOT_MAPPED: win32more.Windows.Win32.Foundation.NTSTATUS = 263
STATUS_OPLOCK_BREAK_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = 264
STATUS_VOLUME_MOUNTED: win32more.Windows.Win32.Foundation.NTSTATUS = 265
STATUS_RXACT_COMMITTED: win32more.Windows.Win32.Foundation.NTSTATUS = 266
STATUS_NOTIFY_CLEANUP: win32more.Windows.Win32.Foundation.NTSTATUS = 267
STATUS_NOTIFY_ENUM_DIR: win32more.Windows.Win32.Foundation.NTSTATUS = 268
STATUS_NO_QUOTAS_FOR_ACCOUNT: win32more.Windows.Win32.Foundation.NTSTATUS = 269
STATUS_PRIMARY_TRANSPORT_CONNECT_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = 270
STATUS_PAGE_FAULT_TRANSITION: win32more.Windows.Win32.Foundation.NTSTATUS = 272
STATUS_PAGE_FAULT_DEMAND_ZERO: win32more.Windows.Win32.Foundation.NTSTATUS = 273
STATUS_PAGE_FAULT_COPY_ON_WRITE: win32more.Windows.Win32.Foundation.NTSTATUS = 274
STATUS_PAGE_FAULT_GUARD_PAGE: win32more.Windows.Win32.Foundation.NTSTATUS = 275
STATUS_PAGE_FAULT_PAGING_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = 276
STATUS_CACHE_PAGE_LOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = 277
STATUS_CRASH_DUMP: win32more.Windows.Win32.Foundation.NTSTATUS = 278
STATUS_BUFFER_ALL_ZEROS: win32more.Windows.Win32.Foundation.NTSTATUS = 279
STATUS_REPARSE_OBJECT: win32more.Windows.Win32.Foundation.NTSTATUS = 280
STATUS_RESOURCE_REQUIREMENTS_CHANGED: win32more.Windows.Win32.Foundation.NTSTATUS = 281
STATUS_TRANSLATION_COMPLETE: win32more.Windows.Win32.Foundation.NTSTATUS = 288
STATUS_DS_MEMBERSHIP_EVALUATED_LOCALLY: win32more.Windows.Win32.Foundation.NTSTATUS = 289
STATUS_NOTHING_TO_TERMINATE: win32more.Windows.Win32.Foundation.NTSTATUS = 290
STATUS_PROCESS_NOT_IN_JOB: win32more.Windows.Win32.Foundation.NTSTATUS = 291
STATUS_PROCESS_IN_JOB: win32more.Windows.Win32.Foundation.NTSTATUS = 292
STATUS_VOLSNAP_HIBERNATE_READY: win32more.Windows.Win32.Foundation.NTSTATUS = 293
STATUS_FSFILTER_OP_COMPLETED_SUCCESSFULLY: win32more.Windows.Win32.Foundation.NTSTATUS = 294
STATUS_INTERRUPT_VECTOR_ALREADY_CONNECTED: win32more.Windows.Win32.Foundation.NTSTATUS = 295
STATUS_INTERRUPT_STILL_CONNECTED: win32more.Windows.Win32.Foundation.NTSTATUS = 296
STATUS_PROCESS_CLONED: win32more.Windows.Win32.Foundation.NTSTATUS = 297
STATUS_FILE_LOCKED_WITH_ONLY_READERS: win32more.Windows.Win32.Foundation.NTSTATUS = 298
STATUS_FILE_LOCKED_WITH_WRITERS: win32more.Windows.Win32.Foundation.NTSTATUS = 299
STATUS_VALID_IMAGE_HASH: win32more.Windows.Win32.Foundation.NTSTATUS = 300
STATUS_VALID_CATALOG_HASH: win32more.Windows.Win32.Foundation.NTSTATUS = 301
STATUS_VALID_STRONG_CODE_HASH: win32more.Windows.Win32.Foundation.NTSTATUS = 302
STATUS_GHOSTED: win32more.Windows.Win32.Foundation.NTSTATUS = 303
STATUS_DATA_OVERWRITTEN: win32more.Windows.Win32.Foundation.NTSTATUS = 304
STATUS_RESOURCEMANAGER_READ_ONLY: win32more.Windows.Win32.Foundation.NTSTATUS = 514
STATUS_RING_PREVIOUSLY_EMPTY: win32more.Windows.Win32.Foundation.NTSTATUS = 528
STATUS_RING_PREVIOUSLY_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = 529
STATUS_RING_PREVIOUSLY_ABOVE_QUOTA: win32more.Windows.Win32.Foundation.NTSTATUS = 530
STATUS_RING_NEWLY_EMPTY: win32more.Windows.Win32.Foundation.NTSTATUS = 531
STATUS_RING_SIGNAL_OPPOSITE_ENDPOINT: win32more.Windows.Win32.Foundation.NTSTATUS = 532
STATUS_OPLOCK_SWITCHED_TO_NEW_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = 533
STATUS_OPLOCK_HANDLE_CLOSED: win32more.Windows.Win32.Foundation.NTSTATUS = 534
STATUS_WAIT_FOR_OPLOCK: win32more.Windows.Win32.Foundation.NTSTATUS = 871
STATUS_REPARSE_GLOBAL: win32more.Windows.Win32.Foundation.NTSTATUS = 872
STATUS_PAGE_FAULT_RETRY: win32more.Windows.Win32.Foundation.NTSTATUS = 873
DBG_EXCEPTION_HANDLED: win32more.Windows.Win32.Foundation.NTSTATUS = 65537
DBG_CONTINUE: win32more.Windows.Win32.Foundation.NTSTATUS = 65538
STATUS_FLT_IO_COMPLETE: win32more.Windows.Win32.Foundation.NTSTATUS = 1835009
STATUS_OBJECT_NAME_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741824
STATUS_THREAD_WAS_SUSPENDED: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741825
STATUS_WORKING_SET_LIMIT_RANGE: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741826
STATUS_IMAGE_NOT_AT_BASE: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741827
STATUS_RXACT_STATE_CREATED: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741828
STATUS_SEGMENT_NOTIFICATION: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741829
STATUS_LOCAL_USER_SESSION_KEY: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741830
STATUS_BAD_CURRENT_DIRECTORY: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741831
STATUS_SERIAL_MORE_WRITES: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741832
STATUS_REGISTRY_RECOVERED: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741833
STATUS_FT_READ_RECOVERY_FROM_BACKUP: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741834
STATUS_FT_WRITE_RECOVERY: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741835
STATUS_SERIAL_COUNTER_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741836
STATUS_NULL_LM_PASSWORD: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741837
STATUS_IMAGE_MACHINE_TYPE_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741838
STATUS_RECEIVE_PARTIAL: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741839
STATUS_RECEIVE_EXPEDITED: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741840
STATUS_RECEIVE_PARTIAL_EXPEDITED: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741841
STATUS_EVENT_DONE: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741842
STATUS_EVENT_PENDING: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741843
STATUS_CHECKING_FILE_SYSTEM: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741844
STATUS_FATAL_APP_EXIT: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741845
STATUS_PREDEFINED_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741846
STATUS_WAS_UNLOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741847
STATUS_SERVICE_NOTIFICATION: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741848
STATUS_WAS_LOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741849
STATUS_LOG_HARD_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741850
STATUS_ALREADY_WIN32: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741851
STATUS_WX86_UNSIMULATE: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741852
STATUS_WX86_CONTINUE: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741853
STATUS_WX86_SINGLE_STEP: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741854
STATUS_WX86_BREAKPOINT: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741855
STATUS_WX86_EXCEPTION_CONTINUE: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741856
STATUS_WX86_EXCEPTION_LASTCHANCE: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741857
STATUS_WX86_EXCEPTION_CHAIN: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741858
STATUS_IMAGE_MACHINE_TYPE_MISMATCH_EXE: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741859
STATUS_NO_YIELD_PERFORMED: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741860
STATUS_TIMER_RESUME_IGNORED: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741861
STATUS_ARBITRATION_UNHANDLED: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741862
STATUS_CARDBUS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741863
STATUS_WX86_CREATEWX86TIB: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741864
STATUS_MP_PROCESSOR_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741865
STATUS_HIBERNATED: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741866
STATUS_RESUME_HIBERNATION: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741867
STATUS_FIRMWARE_UPDATED: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741868
STATUS_DRIVERS_LEAKING_LOCKED_PAGES: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741869
STATUS_MESSAGE_RETRIEVED: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741870
STATUS_SYSTEM_POWERSTATE_TRANSITION: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741871
STATUS_ALPC_CHECK_COMPLETION_LIST: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741872
STATUS_SYSTEM_POWERSTATE_COMPLEX_TRANSITION: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741873
STATUS_ACCESS_AUDIT_BY_POLICY: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741874
STATUS_ABANDON_HIBERFILE: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741875
STATUS_BIZRULES_NOT_ENABLED: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741876
STATUS_FT_READ_FROM_COPY: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741877
STATUS_IMAGE_AT_DIFFERENT_BASE: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741878
STATUS_PATCH_DEFERRED: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741879
STATUS_EMULATION_BREAKPOINT: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741880
STATUS_EMULATION_SYSCALL: win32more.Windows.Win32.Foundation.NTSTATUS = 1073741881
DBG_REPLY_LATER: win32more.Windows.Win32.Foundation.NTSTATUS = 1073807361
DBG_UNABLE_TO_PROVIDE_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = 1073807362
DBG_TERMINATE_THREAD: win32more.Windows.Win32.Foundation.NTSTATUS = 1073807363
DBG_TERMINATE_PROCESS: win32more.Windows.Win32.Foundation.NTSTATUS = 1073807364
DBG_CONTROL_C: win32more.Windows.Win32.Foundation.NTSTATUS = 1073807365
DBG_PRINTEXCEPTION_C: win32more.Windows.Win32.Foundation.NTSTATUS = 1073807366
DBG_RIPEXCEPTION: win32more.Windows.Win32.Foundation.NTSTATUS = 1073807367
DBG_CONTROL_BREAK: win32more.Windows.Win32.Foundation.NTSTATUS = 1073807368
DBG_COMMAND_EXCEPTION: win32more.Windows.Win32.Foundation.NTSTATUS = 1073807369
DBG_PRINTEXCEPTION_WIDE_C: win32more.Windows.Win32.Foundation.NTSTATUS = 1073807370
STATUS_HEURISTIC_DAMAGE_POSSIBLE: win32more.Windows.Win32.Foundation.NTSTATUS = 1075380225
STATUS_GUARD_PAGE_VIOLATION: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483647
STATUS_DATATYPE_MISALIGNMENT: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483646
STATUS_BREAKPOINT: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483645
STATUS_SINGLE_STEP: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483644
STATUS_BUFFER_OVERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483643
STATUS_NO_MORE_FILES: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483642
STATUS_WAKE_SYSTEM_DEBUGGER: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483641
STATUS_HANDLES_CLOSED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483638
STATUS_NO_INHERITANCE: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483637
STATUS_GUID_SUBSTITUTION_MADE: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483636
STATUS_PARTIAL_COPY: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483635
STATUS_DEVICE_PAPER_EMPTY: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483634
STATUS_DEVICE_POWERED_OFF: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483633
STATUS_DEVICE_OFF_LINE: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483632
STATUS_DEVICE_BUSY: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483631
STATUS_NO_MORE_EAS: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483630
STATUS_INVALID_EA_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483629
STATUS_EA_LIST_INCONSISTENT: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483628
STATUS_INVALID_EA_FLAG: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483627
STATUS_VERIFY_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483626
STATUS_EXTRANEOUS_INFORMATION: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483625
STATUS_RXACT_COMMIT_NECESSARY: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483624
STATUS_NO_MORE_ENTRIES: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483622
STATUS_FILEMARK_DETECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483621
STATUS_MEDIA_CHANGED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483620
STATUS_BUS_RESET: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483619
STATUS_END_OF_MEDIA: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483618
STATUS_BEGINNING_OF_MEDIA: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483617
STATUS_MEDIA_CHECK: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483616
STATUS_SETMARK_DETECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483615
STATUS_NO_DATA_DETECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483614
STATUS_REDIRECTOR_HAS_OPEN_HANDLES: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483613
STATUS_SERVER_HAS_OPEN_HANDLES: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483612
STATUS_ALREADY_DISCONNECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483611
STATUS_LONGJUMP: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483610
STATUS_CLEANER_CARTRIDGE_INSTALLED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483609
STATUS_PLUGPLAY_QUERY_VETOED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483608
STATUS_UNWIND_CONSOLIDATE: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483607
STATUS_REGISTRY_HIVE_RECOVERED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483606
STATUS_DLL_MIGHT_BE_INSECURE: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483605
STATUS_DLL_MIGHT_BE_INCOMPATIBLE: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483604
STATUS_STOPPED_ON_SYMLINK: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483603
STATUS_CANNOT_GRANT_REQUESTED_OPLOCK: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483602
STATUS_NO_ACE_CONDITION: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483601
STATUS_DEVICE_SUPPORT_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483600
STATUS_DEVICE_POWER_CYCLE_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483599
STATUS_NO_WORK_DONE: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483598
STATUS_RETURN_ADDRESS_HIJACK_ATTEMPT: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483597
STATUS_RECOVERABLE_BUGCHECK: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483596
DBG_EXCEPTION_NOT_HANDLED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147418111
STATUS_CLUSTER_NODE_ALREADY_UP: win32more.Windows.Win32.Foundation.NTSTATUS = -2146238463
STATUS_CLUSTER_NODE_ALREADY_DOWN: win32more.Windows.Win32.Foundation.NTSTATUS = -2146238462
STATUS_CLUSTER_NETWORK_ALREADY_ONLINE: win32more.Windows.Win32.Foundation.NTSTATUS = -2146238461
STATUS_CLUSTER_NETWORK_ALREADY_OFFLINE: win32more.Windows.Win32.Foundation.NTSTATUS = -2146238460
STATUS_CLUSTER_NODE_ALREADY_MEMBER: win32more.Windows.Win32.Foundation.NTSTATUS = -2146238459
STATUS_FLT_BUFFER_TOO_SMALL: win32more.Windows.Win32.Foundation.NTSTATUS = -2145648639
STATUS_GRAPHICS_LINK_CONFIGURATION_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -2145517568
STATUS_FVE_PARTIAL_METADATA: win32more.Windows.Win32.Foundation.NTSTATUS = -2145320959
STATUS_FVE_TRANSIENT_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -2145320958
STATUS_CLOUD_FILE_PROPERTY_BLOB_CHECKSUM_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -2147430656
STATUS_UNSUCCESSFUL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741823
STATUS_NOT_IMPLEMENTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741822
STATUS_INVALID_INFO_CLASS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741821
STATUS_INFO_LENGTH_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741820
STATUS_ACCESS_VIOLATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741819
STATUS_IN_PAGE_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741818
STATUS_PAGEFILE_QUOTA: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741817
STATUS_INVALID_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741816
STATUS_BAD_INITIAL_STACK: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741815
STATUS_BAD_INITIAL_PC: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741814
STATUS_INVALID_CID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741813
STATUS_TIMER_NOT_CANCELED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741812
STATUS_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741811
STATUS_NO_SUCH_DEVICE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741810
STATUS_NO_SUCH_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741809
STATUS_INVALID_DEVICE_REQUEST: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741808
STATUS_END_OF_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741807
STATUS_WRONG_VOLUME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741806
STATUS_NO_MEDIA_IN_DEVICE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741805
STATUS_UNRECOGNIZED_MEDIA: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741804
STATUS_NONEXISTENT_SECTOR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741803
STATUS_MORE_PROCESSING_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741802
STATUS_NO_MEMORY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741801
STATUS_CONFLICTING_ADDRESSES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741800
STATUS_NOT_MAPPED_VIEW: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741799
STATUS_UNABLE_TO_FREE_VM: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741798
STATUS_UNABLE_TO_DELETE_SECTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741797
STATUS_INVALID_SYSTEM_SERVICE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741796
STATUS_ILLEGAL_INSTRUCTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741795
STATUS_INVALID_LOCK_SEQUENCE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741794
STATUS_INVALID_VIEW_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741793
STATUS_INVALID_FILE_FOR_SECTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741792
STATUS_ALREADY_COMMITTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741791
STATUS_BUFFER_TOO_SMALL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741789
STATUS_OBJECT_TYPE_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741788
STATUS_NONCONTINUABLE_EXCEPTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741787
STATUS_INVALID_DISPOSITION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741786
STATUS_UNWIND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741785
STATUS_BAD_STACK: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741784
STATUS_INVALID_UNWIND_TARGET: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741783
STATUS_NOT_LOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741782
STATUS_PARITY_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741781
STATUS_UNABLE_TO_DECOMMIT_VM: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741780
STATUS_NOT_COMMITTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741779
STATUS_INVALID_PORT_ATTRIBUTES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741778
STATUS_PORT_MESSAGE_TOO_LONG: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741777
STATUS_INVALID_PARAMETER_MIX: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741776
STATUS_INVALID_QUOTA_LOWER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741775
STATUS_DISK_CORRUPT_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741774
STATUS_OBJECT_NAME_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741773
STATUS_OBJECT_NAME_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741772
STATUS_OBJECT_NAME_COLLISION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741771
STATUS_PORT_DO_NOT_DISTURB: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741770
STATUS_PORT_DISCONNECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741769
STATUS_DEVICE_ALREADY_ATTACHED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741768
STATUS_OBJECT_PATH_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741767
STATUS_OBJECT_PATH_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741766
STATUS_OBJECT_PATH_SYNTAX_BAD: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741765
STATUS_DATA_OVERRUN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741764
STATUS_DATA_LATE_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741763
STATUS_DATA_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741762
STATUS_CRC_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741761
STATUS_SECTION_TOO_BIG: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741760
STATUS_PORT_CONNECTION_REFUSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741759
STATUS_INVALID_PORT_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741758
STATUS_SHARING_VIOLATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741757
STATUS_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741756
STATUS_INVALID_PAGE_PROTECTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741755
STATUS_MUTANT_NOT_OWNED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741754
STATUS_SEMAPHORE_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741753
STATUS_PORT_ALREADY_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741752
STATUS_SECTION_NOT_IMAGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741751
STATUS_SUSPEND_COUNT_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741750
STATUS_THREAD_IS_TERMINATING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741749
STATUS_BAD_WORKING_SET_LIMIT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741748
STATUS_INCOMPATIBLE_FILE_MAP: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741747
STATUS_SECTION_PROTECTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741746
STATUS_EAS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741745
STATUS_EA_TOO_LARGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741744
STATUS_NONEXISTENT_EA_ENTRY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741743
STATUS_NO_EAS_ON_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741742
STATUS_EA_CORRUPT_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741741
STATUS_FILE_LOCK_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741740
STATUS_LOCK_NOT_GRANTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741739
STATUS_DELETE_PENDING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741738
STATUS_CTL_FILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741737
STATUS_UNKNOWN_REVISION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741736
STATUS_REVISION_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741735
STATUS_INVALID_OWNER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741734
STATUS_INVALID_PRIMARY_GROUP: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741733
STATUS_NO_IMPERSONATION_TOKEN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741732
STATUS_CANT_DISABLE_MANDATORY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741731
STATUS_NO_LOGON_SERVERS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741730
STATUS_NO_SUCH_PRIVILEGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741728
STATUS_PRIVILEGE_NOT_HELD: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741727
STATUS_INVALID_ACCOUNT_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741726
STATUS_USER_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741725
STATUS_GROUP_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741723
STATUS_NO_SUCH_GROUP: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741722
STATUS_MEMBER_IN_GROUP: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741721
STATUS_MEMBER_NOT_IN_GROUP: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741720
STATUS_LAST_ADMIN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741719
STATUS_ILL_FORMED_PASSWORD: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741717
STATUS_PASSWORD_RESTRICTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741716
STATUS_INVALID_LOGON_HOURS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741713
STATUS_INVALID_WORKSTATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741712
STATUS_NONE_MAPPED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741709
STATUS_TOO_MANY_LUIDS_REQUESTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741708
STATUS_LUIDS_EXHAUSTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741707
STATUS_INVALID_SUB_AUTHORITY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741706
STATUS_INVALID_ACL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741705
STATUS_INVALID_SID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741704
STATUS_INVALID_SECURITY_DESCR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741703
STATUS_PROCEDURE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741702
STATUS_INVALID_IMAGE_FORMAT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741701
STATUS_NO_TOKEN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741700
STATUS_BAD_INHERITANCE_ACL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741699
STATUS_RANGE_NOT_LOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741698
STATUS_DISK_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741697
STATUS_SERVER_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741696
STATUS_SERVER_NOT_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741695
STATUS_TOO_MANY_GUIDS_REQUESTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741694
STATUS_GUIDS_EXHAUSTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741693
STATUS_INVALID_ID_AUTHORITY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741692
STATUS_AGENTS_EXHAUSTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741691
STATUS_INVALID_VOLUME_LABEL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741690
STATUS_SECTION_NOT_EXTENDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741689
STATUS_NOT_MAPPED_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741688
STATUS_RESOURCE_DATA_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741687
STATUS_RESOURCE_TYPE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741686
STATUS_RESOURCE_NAME_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741685
STATUS_ARRAY_BOUNDS_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741684
STATUS_FLOAT_DENORMAL_OPERAND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741683
STATUS_FLOAT_DIVIDE_BY_ZERO: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741682
STATUS_FLOAT_INEXACT_RESULT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741681
STATUS_FLOAT_INVALID_OPERATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741680
STATUS_FLOAT_OVERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741679
STATUS_FLOAT_STACK_CHECK: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741678
STATUS_FLOAT_UNDERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741677
STATUS_INTEGER_DIVIDE_BY_ZERO: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741676
STATUS_INTEGER_OVERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741675
STATUS_PRIVILEGED_INSTRUCTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741674
STATUS_TOO_MANY_PAGING_FILES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741673
STATUS_FILE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741672
STATUS_ALLOTTED_SPACE_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741671
STATUS_INSUFFICIENT_RESOURCES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741670
STATUS_DFS_EXIT_PATH_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741669
STATUS_DEVICE_DATA_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741668
STATUS_DEVICE_NOT_CONNECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741667
STATUS_DEVICE_POWER_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741666
STATUS_FREE_VM_NOT_AT_BASE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741665
STATUS_MEMORY_NOT_ALLOCATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741664
STATUS_WORKING_SET_QUOTA: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741663
STATUS_MEDIA_WRITE_PROTECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741662
STATUS_DEVICE_NOT_READY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741661
STATUS_INVALID_GROUP_ATTRIBUTES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741660
STATUS_BAD_IMPERSONATION_LEVEL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741659
STATUS_CANT_OPEN_ANONYMOUS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741658
STATUS_BAD_VALIDATION_CLASS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741657
STATUS_BAD_TOKEN_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741656
STATUS_BAD_MASTER_BOOT_RECORD: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741655
STATUS_INSTRUCTION_MISALIGNMENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741654
STATUS_INSTANCE_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741653
STATUS_PIPE_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741652
STATUS_INVALID_PIPE_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741651
STATUS_PIPE_BUSY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741650
STATUS_ILLEGAL_FUNCTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741649
STATUS_PIPE_DISCONNECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741648
STATUS_PIPE_CLOSING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741647
STATUS_PIPE_CONNECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741646
STATUS_PIPE_LISTENING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741645
STATUS_INVALID_READ_MODE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741644
STATUS_IO_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741643
STATUS_FILE_FORCED_CLOSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741642
STATUS_PROFILING_NOT_STARTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741641
STATUS_PROFILING_NOT_STOPPED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741640
STATUS_COULD_NOT_INTERPRET: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741639
STATUS_FILE_IS_A_DIRECTORY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741638
STATUS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741637
STATUS_REMOTE_NOT_LISTENING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741636
STATUS_DUPLICATE_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741635
STATUS_BAD_NETWORK_PATH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741634
STATUS_NETWORK_BUSY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741633
STATUS_DEVICE_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741632
STATUS_TOO_MANY_COMMANDS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741631
STATUS_ADAPTER_HARDWARE_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741630
STATUS_INVALID_NETWORK_RESPONSE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741629
STATUS_UNEXPECTED_NETWORK_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741628
STATUS_BAD_REMOTE_ADAPTER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741627
STATUS_PRINT_QUEUE_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741626
STATUS_NO_SPOOL_SPACE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741625
STATUS_PRINT_CANCELLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741624
STATUS_NETWORK_NAME_DELETED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741623
STATUS_NETWORK_ACCESS_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741622
STATUS_BAD_DEVICE_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741621
STATUS_BAD_NETWORK_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741620
STATUS_TOO_MANY_NAMES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741619
STATUS_TOO_MANY_SESSIONS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741618
STATUS_SHARING_PAUSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741617
STATUS_REQUEST_NOT_ACCEPTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741616
STATUS_REDIRECTOR_PAUSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741615
STATUS_NET_WRITE_FAULT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741614
STATUS_PROFILING_AT_LIMIT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741613
STATUS_NOT_SAME_DEVICE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741612
STATUS_FILE_RENAMED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741611
STATUS_VIRTUAL_CIRCUIT_CLOSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741610
STATUS_NO_SECURITY_ON_OBJECT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741609
STATUS_CANT_WAIT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741608
STATUS_PIPE_EMPTY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741607
STATUS_CANT_ACCESS_DOMAIN_INFO: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741606
STATUS_CANT_TERMINATE_SELF: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741605
STATUS_INVALID_SERVER_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741604
STATUS_INVALID_DOMAIN_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741603
STATUS_INVALID_DOMAIN_ROLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741602
STATUS_NO_SUCH_DOMAIN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741601
STATUS_DOMAIN_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741600
STATUS_DOMAIN_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741599
STATUS_OPLOCK_NOT_GRANTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741598
STATUS_INVALID_OPLOCK_PROTOCOL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741597
STATUS_INTERNAL_DB_CORRUPTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741596
STATUS_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741595
STATUS_GENERIC_NOT_MAPPED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741594
STATUS_BAD_DESCRIPTOR_FORMAT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741593
STATUS_INVALID_USER_BUFFER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741592
STATUS_UNEXPECTED_IO_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741591
STATUS_UNEXPECTED_MM_CREATE_ERR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741590
STATUS_UNEXPECTED_MM_MAP_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741589
STATUS_UNEXPECTED_MM_EXTEND_ERR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741588
STATUS_NOT_LOGON_PROCESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741587
STATUS_LOGON_SESSION_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741586
STATUS_INVALID_PARAMETER_1: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741585
STATUS_INVALID_PARAMETER_2: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741584
STATUS_INVALID_PARAMETER_3: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741583
STATUS_INVALID_PARAMETER_4: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741582
STATUS_INVALID_PARAMETER_5: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741581
STATUS_INVALID_PARAMETER_6: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741580
STATUS_INVALID_PARAMETER_7: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741579
STATUS_INVALID_PARAMETER_8: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741578
STATUS_INVALID_PARAMETER_9: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741577
STATUS_INVALID_PARAMETER_10: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741576
STATUS_INVALID_PARAMETER_11: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741575
STATUS_INVALID_PARAMETER_12: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741574
STATUS_REDIRECTOR_NOT_STARTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741573
STATUS_REDIRECTOR_STARTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741572
STATUS_STACK_OVERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741571
STATUS_NO_SUCH_PACKAGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741570
STATUS_BAD_FUNCTION_TABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741569
STATUS_VARIABLE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741568
STATUS_DIRECTORY_NOT_EMPTY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741567
STATUS_FILE_CORRUPT_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741566
STATUS_NOT_A_DIRECTORY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741565
STATUS_BAD_LOGON_SESSION_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741564
STATUS_LOGON_SESSION_COLLISION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741563
STATUS_NAME_TOO_LONG: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741562
STATUS_FILES_OPEN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741561
STATUS_CONNECTION_IN_USE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741560
STATUS_MESSAGE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741559
STATUS_PROCESS_IS_TERMINATING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741558
STATUS_INVALID_LOGON_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741557
STATUS_NO_GUID_TRANSLATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741556
STATUS_CANNOT_IMPERSONATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741555
STATUS_IMAGE_ALREADY_LOADED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741554
STATUS_ABIOS_NOT_PRESENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741553
STATUS_ABIOS_LID_NOT_EXIST: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741552
STATUS_ABIOS_LID_ALREADY_OWNED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741551
STATUS_ABIOS_NOT_LID_OWNER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741550
STATUS_ABIOS_INVALID_COMMAND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741549
STATUS_ABIOS_INVALID_LID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741548
STATUS_ABIOS_SELECTOR_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741547
STATUS_ABIOS_INVALID_SELECTOR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741546
STATUS_NO_LDT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741545
STATUS_INVALID_LDT_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741544
STATUS_INVALID_LDT_OFFSET: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741543
STATUS_INVALID_LDT_DESCRIPTOR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741542
STATUS_INVALID_IMAGE_NE_FORMAT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741541
STATUS_RXACT_INVALID_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741540
STATUS_RXACT_COMMIT_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741539
STATUS_MAPPED_FILE_SIZE_ZERO: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741538
STATUS_TOO_MANY_OPENED_FILES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741537
STATUS_CANCELLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741536
STATUS_CANNOT_DELETE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741535
STATUS_INVALID_COMPUTER_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741534
STATUS_FILE_DELETED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741533
STATUS_SPECIAL_ACCOUNT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741532
STATUS_SPECIAL_GROUP: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741531
STATUS_SPECIAL_USER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741530
STATUS_MEMBERS_PRIMARY_GROUP: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741529
STATUS_FILE_CLOSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741528
STATUS_TOO_MANY_THREADS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741527
STATUS_THREAD_NOT_IN_PROCESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741526
STATUS_TOKEN_ALREADY_IN_USE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741525
STATUS_PAGEFILE_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741524
STATUS_COMMITMENT_LIMIT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741523
STATUS_INVALID_IMAGE_LE_FORMAT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741522
STATUS_INVALID_IMAGE_NOT_MZ: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741521
STATUS_INVALID_IMAGE_PROTECT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741520
STATUS_INVALID_IMAGE_WIN_16: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741519
STATUS_LOGON_SERVER_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741518
STATUS_TIME_DIFFERENCE_AT_DC: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741517
STATUS_SYNCHRONIZATION_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741516
STATUS_DLL_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741515
STATUS_OPEN_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741514
STATUS_IO_PRIVILEGE_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741513
STATUS_ORDINAL_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741512
STATUS_ENTRYPOINT_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741511
STATUS_CONTROL_C_EXIT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741510
STATUS_LOCAL_DISCONNECT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741509
STATUS_REMOTE_DISCONNECT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741508
STATUS_REMOTE_RESOURCES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741507
STATUS_LINK_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741506
STATUS_LINK_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741505
STATUS_INVALID_CONNECTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741504
STATUS_INVALID_ADDRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741503
STATUS_DLL_INIT_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741502
STATUS_MISSING_SYSTEMFILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741501
STATUS_UNHANDLED_EXCEPTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741500
STATUS_APP_INIT_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741499
STATUS_PAGEFILE_CREATE_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741498
STATUS_NO_PAGEFILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741497
STATUS_INVALID_LEVEL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741496
STATUS_WRONG_PASSWORD_CORE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741495
STATUS_ILLEGAL_FLOAT_CONTEXT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741494
STATUS_PIPE_BROKEN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741493
STATUS_REGISTRY_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741492
STATUS_REGISTRY_IO_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741491
STATUS_NO_EVENT_PAIR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741490
STATUS_UNRECOGNIZED_VOLUME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741489
STATUS_SERIAL_NO_DEVICE_INITED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741488
STATUS_NO_SUCH_ALIAS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741487
STATUS_MEMBER_NOT_IN_ALIAS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741486
STATUS_MEMBER_IN_ALIAS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741485
STATUS_ALIAS_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741484
STATUS_LOGON_NOT_GRANTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741483
STATUS_TOO_MANY_SECRETS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741482
STATUS_SECRET_TOO_LONG: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741481
STATUS_INTERNAL_DB_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741480
STATUS_FULLSCREEN_MODE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741479
STATUS_TOO_MANY_CONTEXT_IDS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741478
STATUS_NOT_REGISTRY_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741476
STATUS_NT_CROSS_ENCRYPTION_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741475
STATUS_DOMAIN_CTRLR_CONFIG_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741474
STATUS_FT_MISSING_MEMBER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741473
STATUS_ILL_FORMED_SERVICE_ENTRY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741472
STATUS_ILLEGAL_CHARACTER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741471
STATUS_UNMAPPABLE_CHARACTER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741470
STATUS_UNDEFINED_CHARACTER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741469
STATUS_FLOPPY_VOLUME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741468
STATUS_FLOPPY_ID_MARK_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741467
STATUS_FLOPPY_WRONG_CYLINDER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741466
STATUS_FLOPPY_UNKNOWN_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741465
STATUS_FLOPPY_BAD_REGISTERS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741464
STATUS_DISK_RECALIBRATE_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741463
STATUS_DISK_OPERATION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741462
STATUS_DISK_RESET_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741461
STATUS_SHARED_IRQ_BUSY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741460
STATUS_FT_ORPHANING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741459
STATUS_BIOS_FAILED_TO_CONNECT_INTERRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741458
STATUS_PARTITION_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741454
STATUS_INVALID_BLOCK_LENGTH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741453
STATUS_DEVICE_NOT_PARTITIONED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741452
STATUS_UNABLE_TO_LOCK_MEDIA: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741451
STATUS_UNABLE_TO_UNLOAD_MEDIA: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741450
STATUS_EOM_OVERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741449
STATUS_NO_MEDIA: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741448
STATUS_NO_SUCH_MEMBER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741446
STATUS_INVALID_MEMBER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741445
STATUS_KEY_DELETED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741444
STATUS_NO_LOG_SPACE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741443
STATUS_TOO_MANY_SIDS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741442
STATUS_LM_CROSS_ENCRYPTION_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741441
STATUS_KEY_HAS_CHILDREN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741440
STATUS_CHILD_MUST_BE_VOLATILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741439
STATUS_DEVICE_CONFIGURATION_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741438
STATUS_DRIVER_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741437
STATUS_INVALID_DEVICE_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741436
STATUS_IO_DEVICE_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741435
STATUS_DEVICE_PROTOCOL_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741434
STATUS_BACKUP_CONTROLLER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741433
STATUS_LOG_FILE_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741432
STATUS_TOO_LATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741431
STATUS_NO_TRUST_LSA_SECRET: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741430
STATUS_NO_TRUST_SAM_ACCOUNT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741429
STATUS_TRUSTED_DOMAIN_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741428
STATUS_TRUSTED_RELATIONSHIP_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741427
STATUS_EVENTLOG_FILE_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741426
STATUS_EVENTLOG_CANT_START: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741425
STATUS_TRUST_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741424
STATUS_MUTANT_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741423
STATUS_NETLOGON_NOT_STARTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741422
STATUS_POSSIBLE_DEADLOCK: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741420
STATUS_NETWORK_CREDENTIAL_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741419
STATUS_REMOTE_SESSION_LIMIT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741418
STATUS_EVENTLOG_FILE_CHANGED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741417
STATUS_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741416
STATUS_NOLOGON_WORKSTATION_TRUST_ACCOUNT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741415
STATUS_NOLOGON_SERVER_TRUST_ACCOUNT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741414
STATUS_DOMAIN_TRUST_INCONSISTENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741413
STATUS_FS_DRIVER_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741412
STATUS_IMAGE_ALREADY_LOADED_AS_DLL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741411
STATUS_INCOMPATIBLE_WITH_GLOBAL_SHORT_NAME_REGISTRY_SETTING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741410
STATUS_SHORT_NAMES_NOT_ENABLED_ON_VOLUME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741409
STATUS_SECURITY_STREAM_IS_INCONSISTENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741408
STATUS_INVALID_LOCK_RANGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741407
STATUS_INVALID_ACE_CONDITION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741406
STATUS_IMAGE_SUBSYSTEM_NOT_PRESENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741405
STATUS_NOTIFICATION_GUID_ALREADY_DEFINED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741404
STATUS_INVALID_EXCEPTION_HANDLER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741403
STATUS_DUPLICATE_PRIVILEGES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741402
STATUS_NOT_ALLOWED_ON_SYSTEM_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741401
STATUS_REPAIR_NEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741400
STATUS_QUOTA_NOT_ENABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741399
STATUS_NO_APPLICATION_PACKAGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741398
STATUS_FILE_METADATA_OPTIMIZATION_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741397
STATUS_NOT_SAME_OBJECT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741396
STATUS_FATAL_MEMORY_EXHAUSTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741395
STATUS_ERROR_PROCESS_NOT_IN_JOB: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741394
STATUS_CPU_SET_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741393
STATUS_IO_DEVICE_INVALID_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741392
STATUS_IO_UNALIGNED_WRITE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741391
STATUS_CONTROL_STACK_VIOLATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741390
STATUS_WEAK_WHFBKEY_BLOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741389
STATUS_SERVER_TRANSPORT_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741388
STATUS_CERTIFICATE_VALIDATION_PREFERENCE_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741387
STATUS_DEVICE_RESET_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483210
STATUS_NETWORK_OPEN_RESTRICTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741311
STATUS_NO_USER_SESSION_KEY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741310
STATUS_USER_SESSION_DELETED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741309
STATUS_RESOURCE_LANG_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741308
STATUS_INSUFF_SERVER_RESOURCES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741307
STATUS_INVALID_BUFFER_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741306
STATUS_INVALID_ADDRESS_COMPONENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741305
STATUS_INVALID_ADDRESS_WILDCARD: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741304
STATUS_TOO_MANY_ADDRESSES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741303
STATUS_ADDRESS_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741302
STATUS_ADDRESS_CLOSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741301
STATUS_CONNECTION_DISCONNECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741300
STATUS_CONNECTION_RESET: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741299
STATUS_TOO_MANY_NODES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741298
STATUS_TRANSACTION_ABORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741297
STATUS_TRANSACTION_TIMED_OUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741296
STATUS_TRANSACTION_NO_RELEASE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741295
STATUS_TRANSACTION_NO_MATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741294
STATUS_TRANSACTION_RESPONDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741293
STATUS_TRANSACTION_INVALID_ID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741292
STATUS_TRANSACTION_INVALID_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741291
STATUS_NOT_SERVER_SESSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741290
STATUS_NOT_CLIENT_SESSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741289
STATUS_CANNOT_LOAD_REGISTRY_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741288
STATUS_DEBUG_ATTACH_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741287
STATUS_SYSTEM_PROCESS_TERMINATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741286
STATUS_DATA_NOT_ACCEPTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741285
STATUS_NO_BROWSER_SERVERS_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741284
STATUS_VDM_HARD_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741283
STATUS_DRIVER_CANCEL_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741282
STATUS_REPLY_MESSAGE_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741281
STATUS_MAPPED_ALIGNMENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741280
STATUS_IMAGE_CHECKSUM_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741279
STATUS_LOST_WRITEBEHIND_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741278
STATUS_CLIENT_SERVER_PARAMETERS_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741277
STATUS_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741275
STATUS_NOT_TINY_STREAM: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741274
STATUS_RECOVERY_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741273
STATUS_STACK_OVERFLOW_READ: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741272
STATUS_FAIL_CHECK: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741271
STATUS_DUPLICATE_OBJECTID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741270
STATUS_OBJECTID_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741269
STATUS_CONVERT_TO_LARGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741268
STATUS_RETRY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741267
STATUS_FOUND_OUT_OF_SCOPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741266
STATUS_ALLOCATE_BUCKET: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741265
STATUS_PROPSET_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741264
STATUS_MARSHALL_OVERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741263
STATUS_INVALID_VARIANT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741262
STATUS_DOMAIN_CONTROLLER_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741261
STATUS_HANDLE_NOT_CLOSABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741259
STATUS_CONNECTION_REFUSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741258
STATUS_GRACEFUL_DISCONNECT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741257
STATUS_ADDRESS_ALREADY_ASSOCIATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741256
STATUS_ADDRESS_NOT_ASSOCIATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741255
STATUS_CONNECTION_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741254
STATUS_CONNECTION_ACTIVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741253
STATUS_NETWORK_UNREACHABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741252
STATUS_HOST_UNREACHABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741251
STATUS_PROTOCOL_UNREACHABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741250
STATUS_PORT_UNREACHABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741249
STATUS_REQUEST_ABORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741248
STATUS_CONNECTION_ABORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741247
STATUS_BAD_COMPRESSION_BUFFER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741246
STATUS_USER_MAPPED_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741245
STATUS_AUDIT_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741244
STATUS_TIMER_RESOLUTION_NOT_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741243
STATUS_CONNECTION_COUNT_LIMIT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741242
STATUS_LOGIN_TIME_RESTRICTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741241
STATUS_LOGIN_WKSTA_RESTRICTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741240
STATUS_IMAGE_MP_UP_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741239
STATUS_INSUFFICIENT_LOGON_INFO: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741232
STATUS_BAD_DLL_ENTRYPOINT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741231
STATUS_BAD_SERVICE_ENTRYPOINT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741230
STATUS_LPC_REPLY_LOST: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741229
STATUS_IP_ADDRESS_CONFLICT1: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741228
STATUS_IP_ADDRESS_CONFLICT2: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741227
STATUS_REGISTRY_QUOTA_LIMIT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741226
STATUS_PATH_NOT_COVERED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741225
STATUS_NO_CALLBACK_ACTIVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741224
STATUS_LICENSE_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741223
STATUS_PWD_TOO_SHORT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741222
STATUS_PWD_TOO_RECENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741221
STATUS_PWD_HISTORY_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741220
STATUS_PLUGPLAY_NO_DEVICE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741218
STATUS_UNSUPPORTED_COMPRESSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741217
STATUS_INVALID_HW_PROFILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741216
STATUS_INVALID_PLUGPLAY_DEVICE_PATH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741215
STATUS_DRIVER_ORDINAL_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741214
STATUS_DRIVER_ENTRYPOINT_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741213
STATUS_RESOURCE_NOT_OWNED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741212
STATUS_TOO_MANY_LINKS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741211
STATUS_QUOTA_LIST_INCONSISTENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741210
STATUS_FILE_IS_OFFLINE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741209
STATUS_EVALUATION_EXPIRATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741208
STATUS_ILLEGAL_DLL_RELOCATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741207
STATUS_LICENSE_VIOLATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741206
STATUS_DLL_INIT_FAILED_LOGOFF: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741205
STATUS_DRIVER_UNABLE_TO_LOAD: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741204
STATUS_DFS_UNAVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741203
STATUS_VOLUME_DISMOUNTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741202
STATUS_WX86_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741201
STATUS_WX86_FLOAT_STACK_CHECK: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741200
STATUS_VALIDATE_CONTINUE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741199
STATUS_NO_MATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741198
STATUS_NO_MORE_MATCHES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741197
STATUS_NOT_A_REPARSE_POINT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741195
STATUS_IO_REPARSE_TAG_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741194
STATUS_IO_REPARSE_TAG_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741193
STATUS_IO_REPARSE_DATA_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741192
STATUS_IO_REPARSE_TAG_NOT_HANDLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741191
STATUS_PWD_TOO_LONG: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741190
STATUS_STOWED_EXCEPTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741189
STATUS_CONTEXT_STOWED_EXCEPTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741188
STATUS_REPARSE_POINT_NOT_RESOLVED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741184
STATUS_DIRECTORY_IS_A_REPARSE_POINT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741183
STATUS_RANGE_LIST_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741182
STATUS_SOURCE_ELEMENT_EMPTY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741181
STATUS_DESTINATION_ELEMENT_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741180
STATUS_ILLEGAL_ELEMENT_ADDRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741179
STATUS_MAGAZINE_NOT_PRESENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741178
STATUS_REINITIALIZATION_NEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741177
STATUS_DEVICE_REQUIRES_CLEANING: win32more.Windows.Win32.Foundation.NTSTATUS = -2147483000
STATUS_DEVICE_DOOR_OPEN: win32more.Windows.Win32.Foundation.NTSTATUS = -2147482999
STATUS_ENCRYPTION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741174
STATUS_DECRYPTION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741173
STATUS_RANGE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741172
STATUS_NO_RECOVERY_POLICY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741171
STATUS_NO_EFS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741170
STATUS_WRONG_EFS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741169
STATUS_NO_USER_KEYS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741168
STATUS_FILE_NOT_ENCRYPTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741167
STATUS_NOT_EXPORT_FORMAT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741166
STATUS_FILE_ENCRYPTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741165
STATUS_WAKE_SYSTEM: win32more.Windows.Win32.Foundation.NTSTATUS = 1073742484
STATUS_WMI_GUID_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741163
STATUS_WMI_INSTANCE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741162
STATUS_WMI_ITEMID_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741161
STATUS_WMI_TRY_AGAIN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741160
STATUS_SHARED_POLICY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741159
STATUS_POLICY_OBJECT_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741158
STATUS_POLICY_ONLY_IN_DS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741157
STATUS_VOLUME_NOT_UPGRADED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741156
STATUS_REMOTE_STORAGE_NOT_ACTIVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741155
STATUS_REMOTE_STORAGE_MEDIA_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741154
STATUS_NO_TRACKING_SERVICE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741153
STATUS_SERVER_SID_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741152
STATUS_DS_NO_ATTRIBUTE_OR_VALUE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741151
STATUS_DS_INVALID_ATTRIBUTE_SYNTAX: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741150
STATUS_DS_ATTRIBUTE_TYPE_UNDEFINED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741149
STATUS_DS_ATTRIBUTE_OR_VALUE_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741148
STATUS_DS_BUSY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741147
STATUS_DS_UNAVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741146
STATUS_DS_NO_RIDS_ALLOCATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741145
STATUS_DS_NO_MORE_RIDS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741144
STATUS_DS_INCORRECT_ROLE_OWNER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741143
STATUS_DS_RIDMGR_INIT_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741142
STATUS_DS_OBJ_CLASS_VIOLATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741141
STATUS_DS_CANT_ON_NON_LEAF: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741140
STATUS_DS_CANT_ON_RDN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741139
STATUS_DS_CANT_MOD_OBJ_CLASS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741138
STATUS_DS_CROSS_DOM_MOVE_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741137
STATUS_DS_GC_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741136
STATUS_DIRECTORY_SERVICE_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741135
STATUS_REPARSE_ATTRIBUTE_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741134
STATUS_CANT_ENABLE_DENY_ONLY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741133
STATUS_FLOAT_MULTIPLE_FAULTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741132
STATUS_FLOAT_MULTIPLE_TRAPS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741131
STATUS_DEVICE_REMOVED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741130
STATUS_JOURNAL_DELETE_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741129
STATUS_JOURNAL_NOT_ACTIVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741128
STATUS_NOINTERFACE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741127
STATUS_DS_RIDMGR_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741126
STATUS_DS_ADMIN_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741119
STATUS_DRIVER_FAILED_SLEEP: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741118
STATUS_MUTUAL_AUTHENTICATION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741117
STATUS_CORRUPT_SYSTEM_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741116
STATUS_DATATYPE_MISALIGNMENT_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741115
STATUS_WMI_READ_ONLY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741114
STATUS_WMI_SET_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741113
STATUS_COMMITMENT_MINIMUM: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741112
STATUS_REG_NAT_CONSUMPTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741111
STATUS_TRANSPORT_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741110
STATUS_DS_SAM_INIT_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741109
STATUS_ONLY_IF_CONNECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741108
STATUS_DS_SENSITIVE_GROUP_VIOLATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741107
STATUS_PNP_RESTART_ENUMERATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741106
STATUS_JOURNAL_ENTRY_DELETED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741105
STATUS_DS_CANT_MOD_PRIMARYGROUPID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741104
STATUS_SYSTEM_IMAGE_BAD_SIGNATURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741103
STATUS_PNP_REBOOT_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741102
STATUS_POWER_STATE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741101
STATUS_DS_INVALID_GROUP_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741100
STATUS_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741099
STATUS_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741098
STATUS_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741097
STATUS_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741096
STATUS_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741095
STATUS_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741094
STATUS_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741093
STATUS_DS_HAVE_PRIMARY_MEMBERS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741092
STATUS_WMI_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741091
STATUS_INSUFFICIENT_POWER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741090
STATUS_SAM_NEED_BOOTKEY_PASSWORD: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741089
STATUS_SAM_NEED_BOOTKEY_FLOPPY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741088
STATUS_DS_CANT_START: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741087
STATUS_DS_INIT_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741086
STATUS_SAM_INIT_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741085
STATUS_DS_GC_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741084
STATUS_DS_LOCAL_MEMBER_OF_LOCAL_ONLY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741083
STATUS_DS_NO_FPO_IN_UNIVERSAL_GROUPS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741082
STATUS_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741081
STATUS_MULTIPLE_FAULT_VIOLATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741080
STATUS_CURRENT_DOMAIN_NOT_ALLOWED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741079
STATUS_CANNOT_MAKE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741078
STATUS_SYSTEM_SHUTDOWN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741077
STATUS_DS_INIT_FAILURE_CONSOLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741076
STATUS_DS_SAM_INIT_FAILURE_CONSOLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741075
STATUS_UNFINISHED_CONTEXT_DELETED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741074
STATUS_NO_TGT_REPLY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741073
STATUS_OBJECTID_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741072
STATUS_NO_IP_ADDRESSES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741071
STATUS_WRONG_CREDENTIAL_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741070
STATUS_CRYPTO_SYSTEM_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741069
STATUS_MAX_REFERRALS_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741068
STATUS_MUST_BE_KDC: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741067
STATUS_STRONG_CRYPTO_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741066
STATUS_TOO_MANY_PRINCIPALS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741065
STATUS_NO_PA_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741064
STATUS_PKINIT_NAME_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741063
STATUS_SMARTCARD_LOGON_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741062
STATUS_KDC_INVALID_REQUEST: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741061
STATUS_KDC_UNABLE_TO_REFER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741060
STATUS_KDC_UNKNOWN_ETYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741059
STATUS_SHUTDOWN_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741058
STATUS_SERVER_SHUTDOWN_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741057
STATUS_NOT_SUPPORTED_ON_SBS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741056
STATUS_WMI_GUID_DISCONNECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741055
STATUS_WMI_ALREADY_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741054
STATUS_WMI_ALREADY_ENABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741053
STATUS_MFT_TOO_FRAGMENTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741052
STATUS_COPY_PROTECTION_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741051
STATUS_CSS_AUTHENTICATION_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741050
STATUS_CSS_KEY_NOT_PRESENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741049
STATUS_CSS_KEY_NOT_ESTABLISHED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741048
STATUS_CSS_SCRAMBLED_SECTOR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741047
STATUS_CSS_REGION_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741046
STATUS_CSS_RESETS_EXHAUSTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741045
STATUS_PASSWORD_CHANGE_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741044
STATUS_LOST_MODE_LOGON_RESTRICTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741043
STATUS_PKINIT_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741024
STATUS_SMARTCARD_SUBSYSTEM_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741023
STATUS_NO_KERB_KEY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073741022
STATUS_HOST_DOWN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740976
STATUS_UNSUPPORTED_PREAUTH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740975
STATUS_EFS_ALG_BLOB_TOO_BIG: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740974
STATUS_PORT_NOT_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740973
STATUS_DEBUGGER_INACTIVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740972
STATUS_DS_VERSION_CHECK_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740971
STATUS_AUDITING_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740970
STATUS_PRENT4_MACHINE_ACCOUNT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740969
STATUS_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740968
STATUS_INVALID_IMAGE_WIN_32: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740967
STATUS_INVALID_IMAGE_WIN_64: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740966
STATUS_BAD_BINDINGS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740965
STATUS_NETWORK_SESSION_EXPIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740964
STATUS_APPHELP_BLOCK: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740963
STATUS_ALL_SIDS_FILTERED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740962
STATUS_NOT_SAFE_MODE_DRIVER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740961
STATUS_ACCESS_DISABLED_BY_POLICY_DEFAULT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740959
STATUS_ACCESS_DISABLED_BY_POLICY_PATH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740958
STATUS_ACCESS_DISABLED_BY_POLICY_PUBLISHER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740957
STATUS_ACCESS_DISABLED_BY_POLICY_OTHER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740956
STATUS_FAILED_DRIVER_ENTRY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740955
STATUS_DEVICE_ENUMERATION_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740954
STATUS_MOUNT_POINT_NOT_RESOLVED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740952
STATUS_INVALID_DEVICE_OBJECT_PARAMETER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740951
STATUS_MCA_OCCURED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740950
STATUS_DRIVER_BLOCKED_CRITICAL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740949
STATUS_DRIVER_BLOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740948
STATUS_DRIVER_DATABASE_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740947
STATUS_SYSTEM_HIVE_TOO_LARGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740946
STATUS_INVALID_IMPORT_OF_NON_DLL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740945
STATUS_DS_SHUTTING_DOWN: win32more.Windows.Win32.Foundation.NTSTATUS = 1073742704
STATUS_NO_SECRETS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740943
STATUS_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740942
STATUS_FAILED_STACK_SWITCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740941
STATUS_HEAP_CORRUPTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740940
STATUS_SMARTCARD_WRONG_PIN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740928
STATUS_SMARTCARD_CARD_BLOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740927
STATUS_SMARTCARD_CARD_NOT_AUTHENTICATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740926
STATUS_SMARTCARD_NO_CARD: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740925
STATUS_SMARTCARD_NO_KEY_CONTAINER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740924
STATUS_SMARTCARD_NO_CERTIFICATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740923
STATUS_SMARTCARD_NO_KEYSET: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740922
STATUS_SMARTCARD_IO_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740921
STATUS_SMARTCARD_CERT_REVOKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740919
STATUS_ISSUING_CA_UNTRUSTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740918
STATUS_REVOCATION_OFFLINE_C: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740917
STATUS_PKINIT_CLIENT_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740916
STATUS_SMARTCARD_CERT_EXPIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740915
STATUS_DRIVER_FAILED_PRIOR_UNLOAD: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740914
STATUS_SMARTCARD_SILENT_CONTEXT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740913
STATUS_PER_USER_TRUST_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740799
STATUS_ALL_USER_TRUST_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740798
STATUS_USER_DELETE_TRUST_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740797
STATUS_DS_NAME_NOT_UNIQUE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740796
STATUS_DS_DUPLICATE_ID_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740795
STATUS_DS_GROUP_CONVERSION_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740794
STATUS_VOLSNAP_PREPARE_HIBERNATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740793
STATUS_USER2USER_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740792
STATUS_STACK_BUFFER_OVERRUN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740791
STATUS_NO_S4U_PROT_SUPPORT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740790
STATUS_CROSSREALM_DELEGATION_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740789
STATUS_REVOCATION_OFFLINE_KDC: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740788
STATUS_ISSUING_CA_UNTRUSTED_KDC: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740787
STATUS_KDC_CERT_EXPIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740786
STATUS_KDC_CERT_REVOKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740785
STATUS_PARAMETER_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740784
STATUS_HIBERNATION_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740783
STATUS_DELAY_LOAD_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740782
STATUS_VDM_DISALLOWED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740780
STATUS_HUNG_DISPLAY_DRIVER_THREAD: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740779
STATUS_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740778
STATUS_INVALID_CRUNTIME_PARAMETER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740777
STATUS_NTLM_BLOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740776
STATUS_DS_SRC_SID_EXISTS_IN_FOREST: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740775
STATUS_DS_DOMAIN_NAME_EXISTS_IN_FOREST: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740774
STATUS_DS_FLAT_NAME_EXISTS_IN_FOREST: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740773
STATUS_INVALID_USER_PRINCIPAL_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740772
STATUS_FATAL_USER_CALLBACK_EXCEPTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740771
STATUS_ASSERTION_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740768
STATUS_VERIFIER_STOP: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740767
STATUS_CALLBACK_POP_STACK: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740765
STATUS_INCOMPATIBLE_DRIVER_BLOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740764
STATUS_HIVE_UNLOADED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740763
STATUS_COMPRESSION_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740762
STATUS_FILE_SYSTEM_LIMITATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740761
STATUS_INVALID_IMAGE_HASH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740760
STATUS_NOT_CAPABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740759
STATUS_REQUEST_OUT_OF_SEQUENCE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740758
STATUS_IMPLEMENTATION_LIMIT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740757
STATUS_ELEVATION_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740756
STATUS_NO_SECURITY_CONTEXT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740755
STATUS_PKU2U_CERT_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740753
STATUS_BEYOND_VDL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740750
STATUS_ENCOUNTERED_WRITE_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740749
STATUS_PTE_CHANGED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740748
STATUS_PURGE_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740747
STATUS_CRED_REQUIRES_CONFIRMATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740736
STATUS_CS_ENCRYPTION_INVALID_SERVER_RESPONSE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740735
STATUS_CS_ENCRYPTION_UNSUPPORTED_SERVER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740734
STATUS_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740733
STATUS_CS_ENCRYPTION_NEW_ENCRYPTED_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740732
STATUS_CS_ENCRYPTION_FILE_NOT_CSE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740731
STATUS_INVALID_LABEL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740730
STATUS_DRIVER_PROCESS_TERMINATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740720
STATUS_AMBIGUOUS_SYSTEM_DEVICE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740719
STATUS_SYSTEM_DEVICE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740718
STATUS_RESTART_BOOT_APPLICATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740717
STATUS_INSUFFICIENT_NVRAM_RESOURCES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740716
STATUS_INVALID_SESSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740715
STATUS_THREAD_ALREADY_IN_SESSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740714
STATUS_THREAD_NOT_IN_SESSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740713
STATUS_INVALID_WEIGHT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740712
STATUS_REQUEST_PAUSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740711
STATUS_NO_RANGES_PROCESSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740704
STATUS_DISK_RESOURCES_EXHAUSTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740703
STATUS_NEEDS_REMEDIATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740702
STATUS_DEVICE_FEATURE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740701
STATUS_DEVICE_UNREACHABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740700
STATUS_INVALID_TOKEN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740699
STATUS_SERVER_UNAVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740698
STATUS_FILE_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740697
STATUS_DEVICE_INSUFFICIENT_RESOURCES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740696
STATUS_PACKAGE_UPDATING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740695
STATUS_NOT_READ_FROM_COPY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740694
STATUS_FT_WRITE_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740693
STATUS_FT_DI_SCAN_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740692
STATUS_OBJECT_NOT_EXTERNALLY_BACKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740691
STATUS_EXTERNAL_BACKING_PROVIDER_UNKNOWN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740690
STATUS_COMPRESSION_NOT_BENEFICIAL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740689
STATUS_DATA_CHECKSUM_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740688
STATUS_INTERMIXED_KERNEL_EA_OPERATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740687
STATUS_TRIM_READ_ZERO_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740686
STATUS_TOO_MANY_SEGMENT_DESCRIPTORS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740685
STATUS_INVALID_OFFSET_ALIGNMENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740684
STATUS_INVALID_FIELD_IN_PARAMETER_LIST: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740683
STATUS_OPERATION_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740682
STATUS_INVALID_INITIATOR_TARGET_PATH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740681
STATUS_SCRUB_DATA_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740680
STATUS_NOT_REDUNDANT_STORAGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740679
STATUS_RESIDENT_FILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740678
STATUS_COMPRESSED_FILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740677
STATUS_DIRECTORY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740676
STATUS_IO_OPERATION_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740675
STATUS_SYSTEM_NEEDS_REMEDIATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740674
STATUS_APPX_INTEGRITY_FAILURE_CLR_NGEN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740673
STATUS_SHARE_UNAVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740672
STATUS_APISET_NOT_HOSTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740671
STATUS_APISET_NOT_PRESENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740670
STATUS_DEVICE_HARDWARE_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740669
STATUS_FIRMWARE_SLOT_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740668
STATUS_FIRMWARE_IMAGE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740667
STATUS_STORAGE_TOPOLOGY_ID_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740666
STATUS_WIM_NOT_BOOTABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740665
STATUS_BLOCKED_BY_PARENTAL_CONTROLS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740664
STATUS_NEEDS_REGISTRATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740663
STATUS_QUOTA_ACTIVITY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740662
STATUS_CALLBACK_INVOKE_INLINE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740661
STATUS_BLOCK_TOO_MANY_REFERENCES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740660
STATUS_MARKED_TO_DISALLOW_WRITES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740659
STATUS_NETWORK_ACCESS_DENIED_EDP: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740658
STATUS_ENCLAVE_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740657
STATUS_PNP_NO_COMPAT_DRIVERS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740656
STATUS_PNP_DRIVER_PACKAGE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740655
STATUS_PNP_DRIVER_CONFIGURATION_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740654
STATUS_PNP_DRIVER_CONFIGURATION_INCOMPLETE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740653
STATUS_PNP_FUNCTION_DRIVER_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740652
STATUS_PNP_DEVICE_CONFIGURATION_PENDING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740651
STATUS_DEVICE_HINT_NAME_BUFFER_TOO_SMALL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740650
STATUS_PACKAGE_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740649
STATUS_DEVICE_IN_MAINTENANCE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740647
STATUS_NOT_SUPPORTED_ON_DAX: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740646
STATUS_FREE_SPACE_TOO_FRAGMENTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740645
STATUS_DAX_MAPPING_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740644
STATUS_CHILD_PROCESS_BLOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740643
STATUS_STORAGE_LOST_DATA_PERSISTENCE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740642
STATUS_PARTITION_TERMINATING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740640
STATUS_EXTERNAL_SYSKEY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740639
STATUS_ENCLAVE_VIOLATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740638
STATUS_FILE_PROTECTED_UNDER_DPL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740637
STATUS_VOLUME_NOT_CLUSTER_ALIGNED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740636
STATUS_NO_PHYSICALLY_ALIGNED_FREE_SPACE_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740635
STATUS_APPX_FILE_NOT_ENCRYPTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740634
STATUS_RWRAW_ENCRYPTED_FILE_NOT_ENCRYPTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740633
STATUS_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILEOFFSET: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740632
STATUS_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILERANGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740631
STATUS_RWRAW_ENCRYPTED_INVALID_EDATAINFO_PARAMETER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740630
STATUS_FT_READ_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740629
STATUS_PATCH_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740628
STATUS_STORAGE_RESERVE_ID_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740627
STATUS_STORAGE_RESERVE_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740626
STATUS_STORAGE_RESERVE_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740625
STATUS_STORAGE_RESERVE_NOT_EMPTY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740624
STATUS_NOT_A_DAX_VOLUME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740623
STATUS_NOT_DAX_MAPPABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740622
STATUS_CASE_DIFFERING_NAMES_IN_DIR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740621
STATUS_FILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740620
STATUS_NOT_SUPPORTED_WITH_BTT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740619
STATUS_ENCRYPTION_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740618
STATUS_ENCRYPTING_METADATA_DISALLOWED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740617
STATUS_CANT_CLEAR_ENCRYPTION_FLAG: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740616
STATUS_UNSATISFIED_DEPENDENCIES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740615
STATUS_CASE_SENSITIVE_PATH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740614
STATUS_UNSUPPORTED_PAGING_MODE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740613
STATUS_UNTRUSTED_MOUNT_POINT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740612
STATUS_HAS_SYSTEM_CRITICAL_FILES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740611
STATUS_OBJECT_IS_IMMUTABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740610
STATUS_FT_READ_FROM_COPY_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740609
STATUS_IMAGE_LOADED_AS_PATCH_IMAGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740608
STATUS_STORAGE_STACK_ACCESS_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740607
STATUS_INSUFFICIENT_VIRTUAL_ADDR_RESOURCES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740606
STATUS_ENCRYPTED_FILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740605
STATUS_SPARSE_FILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740604
STATUS_PAGEFILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740603
STATUS_VOLUME_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740602
STATUS_NOT_SUPPORTED_WITH_BYPASSIO: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740601
STATUS_NO_BYPASSIO_DRIVER_SUPPORT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740600
STATUS_NOT_SUPPORTED_WITH_ENCRYPTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740599
STATUS_NOT_SUPPORTED_WITH_COMPRESSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740598
STATUS_NOT_SUPPORTED_WITH_REPLICATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740597
STATUS_NOT_SUPPORTED_WITH_DEDUPLICATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740596
STATUS_NOT_SUPPORTED_WITH_AUDITING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740595
STATUS_NOT_SUPPORTED_WITH_MONITORING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740594
STATUS_NOT_SUPPORTED_WITH_SNAPSHOT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740593
STATUS_NOT_SUPPORTED_WITH_VIRTUALIZATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740592
STATUS_INDEX_OUT_OF_BOUNDS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740591
STATUS_BYPASSIO_FLT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740590
STATUS_VOLUME_WRITE_ACCESS_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740589
STATUS_PATCH_NOT_REGISTERED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740588
STATUS_NOT_SUPPORTED_WITH_CACHED_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740587
STATUS_VOLUME_UPGRADE_NOT_NEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740583
STATUS_VOLUME_UPGRADE_PENDING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740582
STATUS_VOLUME_UPGRADE_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740581
STATUS_VOLUME_UPGRADE_DISABLED_TILL_OS_DOWNGRADE_EXPIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740580
STATUS_NOT_A_DEV_VOLUME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740579
STATUS_FS_GUID_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740578
STATUS_CANT_ATTACH_TO_DEV_VOLUME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740577
STATUS_INVALID_CONFIG_VALUE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740576
STATUS_INVALID_TASK_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740544
STATUS_INVALID_TASK_INDEX: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740543
STATUS_THREAD_ALREADY_IN_TASK: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740542
STATUS_CALLBACK_BYPASS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740541
STATUS_UNDEFINED_SCOPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740540
STATUS_INVALID_CAP: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740539
STATUS_NOT_GUI_PROCESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740538
STATUS_DEVICE_HUNG: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740537
STATUS_CONTAINER_ASSIGNED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740536
STATUS_JOB_NO_CONTAINER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740535
STATUS_DEVICE_UNRESPONSIVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740534
STATUS_REPARSE_POINT_ENCOUNTERED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740533
STATUS_ATTRIBUTE_NOT_PRESENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740532
STATUS_NOT_A_TIERED_VOLUME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740531
STATUS_ALREADY_HAS_STREAM_ID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740530
STATUS_JOB_NOT_EMPTY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740529
STATUS_ALREADY_INITIALIZED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740528
STATUS_ENCLAVE_NOT_TERMINATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740527
STATUS_ENCLAVE_IS_TERMINATING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740526
STATUS_SMB1_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740525
STATUS_SMR_GARBAGE_COLLECTION_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740524
STATUS_INTERRUPTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740523
STATUS_THREAD_NOT_RUNNING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740522
STATUS_SESSION_KEY_TOO_SHORT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740521
STATUS_FS_METADATA_INCONSISTENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740520
STATUS_FAIL_FAST_EXCEPTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740286
STATUS_IMAGE_CERT_REVOKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740285
STATUS_DYNAMIC_CODE_BLOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740284
STATUS_IMAGE_CERT_EXPIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740283
STATUS_STRICT_CFG_VIOLATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740282
STATUS_SET_CONTEXT_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740278
STATUS_CROSS_PARTITION_VIOLATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740277
STATUS_PORT_CLOSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740032
STATUS_MESSAGE_LOST: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740031
STATUS_INVALID_MESSAGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740030
STATUS_REQUEST_CANCELED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740029
STATUS_RECURSIVE_DISPATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740028
STATUS_LPC_RECEIVE_BUFFER_EXPECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740027
STATUS_LPC_INVALID_CONNECTION_USAGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740026
STATUS_LPC_REQUESTS_NOT_ALLOWED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740025
STATUS_RESOURCE_IN_USE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740024
STATUS_HARDWARE_MEMORY_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740023
STATUS_THREADPOOL_HANDLE_EXCEPTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740022
STATUS_THREADPOOL_SET_EVENT_ON_COMPLETION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740021
STATUS_THREADPOOL_RELEASE_SEMAPHORE_ON_COMPLETION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740020
STATUS_THREADPOOL_RELEASE_MUTEX_ON_COMPLETION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740019
STATUS_THREADPOOL_FREE_LIBRARY_ON_COMPLETION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740018
STATUS_THREADPOOL_RELEASED_DURING_OPERATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740017
STATUS_CALLBACK_RETURNED_WHILE_IMPERSONATING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740016
STATUS_APC_RETURNED_WHILE_IMPERSONATING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740015
STATUS_PROCESS_IS_PROTECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740014
STATUS_MCA_EXCEPTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740013
STATUS_CERTIFICATE_MAPPING_NOT_UNIQUE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740012
STATUS_SYMLINK_CLASS_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740011
STATUS_INVALID_IDN_NORMALIZATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740010
STATUS_NO_UNICODE_TRANSLATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740009
STATUS_ALREADY_REGISTERED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740008
STATUS_CONTEXT_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740007
STATUS_PORT_ALREADY_HAS_COMPLETION_LIST: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740006
STATUS_CALLBACK_RETURNED_THREAD_PRIORITY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740005
STATUS_INVALID_THREAD: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740004
STATUS_CALLBACK_RETURNED_TRANSACTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740003
STATUS_CALLBACK_RETURNED_LDR_LOCK: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740002
STATUS_CALLBACK_RETURNED_LANG: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740001
STATUS_CALLBACK_RETURNED_PRI_BACK: win32more.Windows.Win32.Foundation.NTSTATUS = -1073740000
STATUS_CALLBACK_RETURNED_THREAD_AFFINITY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739999
STATUS_LPC_HANDLE_COUNT_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739998
STATUS_EXECUTABLE_MEMORY_WRITE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739997
STATUS_KERNEL_EXECUTABLE_MEMORY_WRITE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739996
STATUS_ATTACHED_EXECUTABLE_MEMORY_WRITE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739995
STATUS_TRIGGERED_EXECUTABLE_MEMORY_WRITE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739994
STATUS_DISK_REPAIR_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739776
STATUS_DS_DOMAIN_RENAME_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739775
STATUS_DISK_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739774
STATUS_DATA_LOST_REPAIR: win32more.Windows.Win32.Foundation.NTSTATUS = -2147481597
STATUS_CONTENT_BLOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739772
STATUS_BAD_CLUSTERS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739771
STATUS_VOLUME_DIRTY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739770
STATUS_DISK_REPAIR_REDIRECTED: win32more.Windows.Win32.Foundation.NTSTATUS = 1073743879
STATUS_DISK_REPAIR_UNSUCCESSFUL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739768
STATUS_CORRUPT_LOG_OVERFULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739767
STATUS_CORRUPT_LOG_CORRUPTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739766
STATUS_CORRUPT_LOG_UNAVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739765
STATUS_CORRUPT_LOG_DELETED_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739764
STATUS_CORRUPT_LOG_CLEARED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739763
STATUS_ORPHAN_NAME_EXHAUSTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739762
STATUS_PROACTIVE_SCAN_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739761
STATUS_ENCRYPTED_IO_NOT_POSSIBLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739760
STATUS_CORRUPT_LOG_UPLEVEL_RECORDS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739759
STATUS_FILE_CHECKED_OUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739519
STATUS_CHECKOUT_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739518
STATUS_BAD_FILE_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739517
STATUS_FILE_TOO_LARGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739516
STATUS_FORMS_AUTH_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739515
STATUS_VIRUS_INFECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739514
STATUS_VIRUS_DELETED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739513
STATUS_BAD_MCFG_TABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739512
STATUS_CANNOT_BREAK_OPLOCK: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739511
STATUS_BAD_KEY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739510
STATUS_BAD_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739509
STATUS_NO_KEY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739508
STATUS_FILE_HANDLE_REVOKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739504
STATUS_SECTION_DIRECT_MAP_ONLY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739503
STATUS_BLOCK_WEAK_REFERENCE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739502
STATUS_BLOCK_SOURCE_WEAK_REFERENCE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739501
STATUS_BLOCK_TARGET_WEAK_REFERENCE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739500
STATUS_BLOCK_SHARED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073739499
STATUS_VRF_VOLATILE_CFG_AND_IO_ENABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738744
STATUS_VRF_VOLATILE_NOT_STOPPABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738743
STATUS_VRF_VOLATILE_SAFE_MODE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738742
STATUS_VRF_VOLATILE_NOT_RUNNABLE_SYSTEM: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738741
STATUS_VRF_VOLATILE_NOT_SUPPORTED_RULECLASS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738740
STATUS_VRF_VOLATILE_PROTECTED_DRIVER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738739
STATUS_VRF_VOLATILE_NMI_REGISTERED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738738
STATUS_VRF_VOLATILE_SETTINGS_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738737
STATUS_DIF_IOCALLBACK_NOT_REPLACED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738634
STATUS_DIF_LIVEDUMP_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738633
STATUS_DIF_VOLATILE_SECTION_NOT_LOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738632
STATUS_DIF_VOLATILE_DRIVER_HOTPATCHED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738631
STATUS_DIF_VOLATILE_INVALID_INFO: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738630
STATUS_DIF_VOLATILE_DRIVER_IS_NOT_RUNNING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738629
STATUS_DIF_VOLATILE_PLUGIN_IS_NOT_RUNNING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738628
STATUS_DIF_VOLATILE_PLUGIN_CHANGE_NOT_ALLOWED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738627
STATUS_DIF_VOLATILE_NOT_ALLOWED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738626
STATUS_DIF_BINDING_API_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073738625
STATUS_WOW_ASSERTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073702760
STATUS_INVALID_SIGNATURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700864
STATUS_HMAC_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700863
STATUS_AUTH_TAG_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700862
STATUS_INVALID_STATE_TRANSITION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700861
STATUS_INVALID_KERNEL_INFO_VERSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700860
STATUS_INVALID_PEP_INFO_VERSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700859
STATUS_HANDLE_REVOKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700858
STATUS_EOF_ON_GHOSTED_RANGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700857
STATUS_CC_NEEDS_CALLBACK_SECTION_DRAIN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700856
STATUS_IPSEC_QUEUE_OVERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700848
STATUS_ND_QUEUE_OVERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700847
STATUS_HOPLIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700846
STATUS_PROTOCOL_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700845
STATUS_FASTPATH_REJECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700844
STATUS_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700736
STATUS_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700735
STATUS_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700734
STATUS_XML_PARSE_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700733
STATUS_XMLDSIG_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700732
STATUS_WRONG_COMPARTMENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700731
STATUS_AUTHIP_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700730
STATUS_DS_OID_MAPPED_GROUP_CANT_HAVE_MEMBERS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700729
STATUS_DS_OID_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700728
STATUS_INCORRECT_ACCOUNT_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700727
STATUS_LOCAL_POLICY_MODIFICATION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700726
STATUS_POLICY_CONTROLLED_ACCOUNT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700725
STATUS_LAPS_LEGACY_SCHEMA_MISSING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700724
STATUS_LAPS_SCHEMA_MISSING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700723
STATUS_LAPS_ENCRYPTION_REQUIRES_2016_DFL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700722
STATUS_HASH_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700608
STATUS_HASH_NOT_PRESENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700607
STATUS_SECONDARY_IC_PROVIDER_NOT_REGISTERED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700575
STATUS_GPIO_CLIENT_INFORMATION_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700574
STATUS_GPIO_VERSION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700573
STATUS_GPIO_INVALID_REGISTRATION_PACKET: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700572
STATUS_GPIO_OPERATION_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700571
STATUS_GPIO_INCOMPATIBLE_CONNECT_MODE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700570
STATUS_GPIO_INTERRUPT_ALREADY_UNMASKED: win32more.Windows.Win32.Foundation.NTSTATUS = -2147442393
STATUS_CANNOT_SWITCH_RUNLEVEL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700543
STATUS_INVALID_RUNLEVEL_SETTING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700542
STATUS_RUNLEVEL_SWITCH_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700541
STATUS_SERVICES_FAILED_AUTOSTART: win32more.Windows.Win32.Foundation.NTSTATUS = 1073783108
STATUS_RUNLEVEL_SWITCH_AGENT_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700539
STATUS_RUNLEVEL_SWITCH_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700538
STATUS_NOT_APPCONTAINER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700352
STATUS_NOT_SUPPORTED_IN_APPCONTAINER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700351
STATUS_INVALID_PACKAGE_SID_LENGTH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700350
STATUS_LPAC_ACCESS_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700349
STATUS_ADMINLESS_ACCESS_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700348
STATUS_APP_DATA_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700223
STATUS_APP_DATA_EXPIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700222
STATUS_APP_DATA_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700221
STATUS_APP_DATA_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700220
STATUS_APP_DATA_REBOOT_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700219
STATUS_OFFLOAD_READ_FLT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700191
STATUS_OFFLOAD_WRITE_FLT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700190
STATUS_OFFLOAD_READ_FILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700189
STATUS_OFFLOAD_WRITE_FILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700188
STATUS_WOF_WIM_HEADER_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700187
STATUS_WOF_WIM_RESOURCE_TABLE_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700186
STATUS_WOF_FILE_RESOURCE_TABLE_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073700185
STATUS_CIMFS_IMAGE_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073692671
STATUS_CIMFS_IMAGE_VERSION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073692670
STATUS_FILE_SYSTEM_VIRTUALIZATION_UNAVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073689087
STATUS_FILE_SYSTEM_VIRTUALIZATION_METADATA_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073689086
STATUS_FILE_SYSTEM_VIRTUALIZATION_BUSY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073689085
STATUS_FILE_SYSTEM_VIRTUALIZATION_PROVIDER_UNKNOWN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073689084
STATUS_FILE_SYSTEM_VIRTUALIZATION_INVALID_OPERATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073689083
STATUS_CLOUD_FILE_SYNC_ROOT_METADATA_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688832
STATUS_CLOUD_FILE_PROVIDER_NOT_RUNNING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688831
STATUS_CLOUD_FILE_METADATA_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688830
STATUS_CLOUD_FILE_METADATA_TOO_LARGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688829
STATUS_CLOUD_FILE_PROPERTY_BLOB_TOO_LARGE: win32more.Windows.Win32.Foundation.NTSTATUS = -2147430652
STATUS_CLOUD_FILE_TOO_MANY_PROPERTY_BLOBS: win32more.Windows.Win32.Foundation.NTSTATUS = -2147430651
STATUS_CLOUD_FILE_PROPERTY_VERSION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688826
STATUS_NOT_A_CLOUD_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688825
STATUS_CLOUD_FILE_NOT_IN_SYNC: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688824
STATUS_CLOUD_FILE_ALREADY_CONNECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688823
STATUS_CLOUD_FILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688822
STATUS_CLOUD_FILE_INVALID_REQUEST: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688821
STATUS_CLOUD_FILE_READ_ONLY_VOLUME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688820
STATUS_CLOUD_FILE_CONNECTED_PROVIDER_ONLY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688819
STATUS_CLOUD_FILE_VALIDATION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688818
STATUS_CLOUD_FILE_AUTHENTICATION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688817
STATUS_CLOUD_FILE_INSUFFICIENT_RESOURCES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688816
STATUS_CLOUD_FILE_NETWORK_UNAVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688815
STATUS_CLOUD_FILE_UNSUCCESSFUL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688814
STATUS_CLOUD_FILE_NOT_UNDER_SYNC_ROOT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688813
STATUS_CLOUD_FILE_IN_USE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688812
STATUS_CLOUD_FILE_PINNED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688811
STATUS_CLOUD_FILE_REQUEST_ABORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688810
STATUS_CLOUD_FILE_PROPERTY_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688809
STATUS_CLOUD_FILE_ACCESS_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688808
STATUS_CLOUD_FILE_INCOMPATIBLE_HARDLINKS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688807
STATUS_CLOUD_FILE_PROPERTY_LOCK_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688806
STATUS_CLOUD_FILE_REQUEST_CANCELED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688805
STATUS_CLOUD_FILE_PROVIDER_TERMINATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688803
STATUS_NOT_A_CLOUD_SYNC_ROOT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688802
STATUS_CLOUD_FILE_REQUEST_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688801
STATUS_CLOUD_FILE_DEHYDRATION_DISALLOWED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688800
STATUS_CLOUD_FILE_US_MESSAGE_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073688799
STATUS_FILE_SNAP_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073679104
STATUS_FILE_SNAP_USER_SECTION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073679103
STATUS_FILE_SNAP_MODIFY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073679102
STATUS_FILE_SNAP_IO_NOT_COORDINATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073679101
STATUS_FILE_SNAP_UNEXPECTED_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073679100
STATUS_FILE_SNAP_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073679099
DBG_NO_STATE_CHANGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073676287
DBG_APP_NOT_IDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073676286
RPC_NT_INVALID_STRING_BINDING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610751
RPC_NT_WRONG_KIND_OF_BINDING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610750
RPC_NT_INVALID_BINDING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610749
RPC_NT_PROTSEQ_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610748
RPC_NT_INVALID_RPC_PROTSEQ: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610747
RPC_NT_INVALID_STRING_UUID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610746
RPC_NT_INVALID_ENDPOINT_FORMAT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610745
RPC_NT_INVALID_NET_ADDR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610744
RPC_NT_NO_ENDPOINT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610743
RPC_NT_INVALID_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610742
RPC_NT_OBJECT_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610741
RPC_NT_ALREADY_REGISTERED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610740
RPC_NT_TYPE_ALREADY_REGISTERED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610739
RPC_NT_ALREADY_LISTENING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610738
RPC_NT_NO_PROTSEQS_REGISTERED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610737
RPC_NT_NOT_LISTENING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610736
RPC_NT_UNKNOWN_MGR_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610735
RPC_NT_UNKNOWN_IF: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610734
RPC_NT_NO_BINDINGS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610733
RPC_NT_NO_PROTSEQS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610732
RPC_NT_CANT_CREATE_ENDPOINT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610731
RPC_NT_OUT_OF_RESOURCES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610730
RPC_NT_SERVER_UNAVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610729
RPC_NT_SERVER_TOO_BUSY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610728
RPC_NT_INVALID_NETWORK_OPTIONS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610727
RPC_NT_NO_CALL_ACTIVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610726
RPC_NT_CALL_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610725
RPC_NT_CALL_FAILED_DNE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610724
RPC_NT_PROTOCOL_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610723
RPC_NT_UNSUPPORTED_TRANS_SYN: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610721
RPC_NT_UNSUPPORTED_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610719
RPC_NT_INVALID_TAG: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610718
RPC_NT_INVALID_BOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610717
RPC_NT_NO_ENTRY_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610716
RPC_NT_INVALID_NAME_SYNTAX: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610715
RPC_NT_UNSUPPORTED_NAME_SYNTAX: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610714
RPC_NT_UUID_NO_ADDRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610712
RPC_NT_DUPLICATE_ENDPOINT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610711
RPC_NT_UNKNOWN_AUTHN_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610710
RPC_NT_MAX_CALLS_TOO_SMALL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610709
RPC_NT_STRING_TOO_LONG: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610708
RPC_NT_PROTSEQ_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610707
RPC_NT_PROCNUM_OUT_OF_RANGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610706
RPC_NT_BINDING_HAS_NO_AUTH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610705
RPC_NT_UNKNOWN_AUTHN_SERVICE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610704
RPC_NT_UNKNOWN_AUTHN_LEVEL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610703
RPC_NT_INVALID_AUTH_IDENTITY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610702
RPC_NT_UNKNOWN_AUTHZ_SERVICE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610701
EPT_NT_INVALID_ENTRY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610700
EPT_NT_CANT_PERFORM_OP: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610699
EPT_NT_NOT_REGISTERED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610698
RPC_NT_NOTHING_TO_EXPORT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610697
RPC_NT_INCOMPLETE_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610696
RPC_NT_INVALID_VERS_OPTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610695
RPC_NT_NO_MORE_MEMBERS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610694
RPC_NT_NOT_ALL_OBJS_UNEXPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610693
RPC_NT_INTERFACE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610692
RPC_NT_ENTRY_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610691
RPC_NT_ENTRY_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610690
RPC_NT_NAME_SERVICE_UNAVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610689
RPC_NT_INVALID_NAF_ID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610688
RPC_NT_CANNOT_SUPPORT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610687
RPC_NT_NO_CONTEXT_AVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610686
RPC_NT_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610685
RPC_NT_ZERO_DIVIDE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610684
RPC_NT_ADDRESS_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610683
RPC_NT_FP_DIV_ZERO: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610682
RPC_NT_FP_UNDERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610681
RPC_NT_FP_OVERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610680
RPC_NT_NO_MORE_ENTRIES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545215
RPC_NT_SS_CHAR_TRANS_OPEN_FAIL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545214
RPC_NT_SS_CHAR_TRANS_SHORT_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545213
RPC_NT_SS_IN_NULL_CONTEXT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545212
RPC_NT_SS_CONTEXT_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545211
RPC_NT_SS_CONTEXT_DAMAGED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545210
RPC_NT_SS_HANDLES_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545209
RPC_NT_SS_CANNOT_GET_CALL_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545208
RPC_NT_NULL_REF_POINTER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545207
RPC_NT_ENUM_VALUE_OUT_OF_RANGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545206
RPC_NT_BYTE_COUNT_TOO_SMALL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545205
RPC_NT_BAD_STUB_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545204
RPC_NT_CALL_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610679
RPC_NT_NO_MORE_BINDINGS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610678
RPC_NT_GROUP_MEMBER_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610677
EPT_NT_CANT_CREATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610676
RPC_NT_INVALID_OBJECT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610675
RPC_NT_NO_INTERFACES: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610673
RPC_NT_CALL_CANCELLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610672
RPC_NT_BINDING_INCOMPLETE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610671
RPC_NT_COMM_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610670
RPC_NT_UNSUPPORTED_AUTHN_LEVEL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610669
RPC_NT_NO_PRINC_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610668
RPC_NT_NOT_RPC_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610667
RPC_NT_UUID_LOCAL_ONLY: win32more.Windows.Win32.Foundation.NTSTATUS = 1073872982
RPC_NT_SEC_PKG_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610665
RPC_NT_NOT_CANCELLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610664
RPC_NT_INVALID_ES_ACTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545127
RPC_NT_WRONG_ES_VERSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545126
RPC_NT_WRONG_STUB_VERSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545125
RPC_NT_INVALID_PIPE_OBJECT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545124
RPC_NT_INVALID_PIPE_OPERATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545123
RPC_NT_WRONG_PIPE_VERSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545122
RPC_NT_PIPE_CLOSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545121
RPC_NT_PIPE_DISCIPLINE_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545120
RPC_NT_PIPE_EMPTY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073545119
RPC_NT_INVALID_ASYNC_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610654
RPC_NT_INVALID_ASYNC_CALL: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610653
RPC_NT_PROXY_ACCESS_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610652
RPC_NT_COOKIE_AUTH_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073610651
RPC_NT_SEND_INCOMPLETE: win32more.Windows.Win32.Foundation.NTSTATUS = 1073873071
STATUS_ACPI_INVALID_OPCODE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431103
STATUS_ACPI_STACK_OVERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431102
STATUS_ACPI_ASSERT_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431101
STATUS_ACPI_INVALID_INDEX: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431100
STATUS_ACPI_INVALID_ARGUMENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431099
STATUS_ACPI_FATAL: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431098
STATUS_ACPI_INVALID_SUPERNAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431097
STATUS_ACPI_INVALID_ARGTYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431096
STATUS_ACPI_INVALID_OBJTYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431095
STATUS_ACPI_INVALID_TARGETTYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431094
STATUS_ACPI_INCORRECT_ARGUMENT_COUNT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431093
STATUS_ACPI_ADDRESS_NOT_MAPPED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431092
STATUS_ACPI_INVALID_EVENTTYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431091
STATUS_ACPI_HANDLER_COLLISION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431090
STATUS_ACPI_INVALID_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431089
STATUS_ACPI_INVALID_REGION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431088
STATUS_ACPI_INVALID_ACCESS_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431087
STATUS_ACPI_ACQUIRE_GLOBAL_LOCK: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431086
STATUS_ACPI_ALREADY_INITIALIZED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431085
STATUS_ACPI_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431084
STATUS_ACPI_INVALID_MUTEX_LEVEL: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431083
STATUS_ACPI_MUTEX_NOT_OWNED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431082
STATUS_ACPI_MUTEX_NOT_OWNER: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431081
STATUS_ACPI_RS_ACCESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431080
STATUS_ACPI_INVALID_TABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431079
STATUS_ACPI_REG_HANDLER_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431072
STATUS_ACPI_POWER_REQUEST_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072431071
STATUS_CTX_WINSTATION_NAME_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086463
STATUS_CTX_INVALID_PD: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086462
STATUS_CTX_PD_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086461
STATUS_CTX_CDM_CONNECT: win32more.Windows.Win32.Foundation.NTSTATUS = 1074397188
STATUS_CTX_CDM_DISCONNECT: win32more.Windows.Win32.Foundation.NTSTATUS = 1074397189
STATUS_CTX_CLOSE_PENDING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086458
STATUS_CTX_NO_OUTBUF: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086457
STATUS_CTX_MODEM_INF_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086456
STATUS_CTX_INVALID_MODEMNAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086455
STATUS_CTX_RESPONSE_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086454
STATUS_CTX_MODEM_RESPONSE_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086453
STATUS_CTX_MODEM_RESPONSE_NO_CARRIER: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086452
STATUS_CTX_MODEM_RESPONSE_NO_DIALTONE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086451
STATUS_CTX_MODEM_RESPONSE_BUSY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086450
STATUS_CTX_MODEM_RESPONSE_VOICE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086449
STATUS_CTX_TD_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086448
STATUS_CTX_LICENSE_CLIENT_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086446
STATUS_CTX_LICENSE_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086445
STATUS_CTX_LICENSE_EXPIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086444
STATUS_CTX_WINSTATION_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086443
STATUS_CTX_WINSTATION_NAME_COLLISION: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086442
STATUS_CTX_WINSTATION_BUSY: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086441
STATUS_CTX_BAD_VIDEO_MODE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086440
STATUS_CTX_GRAPHICS_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086430
STATUS_CTX_NOT_CONSOLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086428
STATUS_CTX_CLIENT_QUERY_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086426
STATUS_CTX_CONSOLE_DISCONNECT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086425
STATUS_CTX_CONSOLE_CONNECT: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086424
STATUS_CTX_SHADOW_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086422
STATUS_CTX_WINSTATION_ACCESS_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086421
STATUS_CTX_INVALID_WD: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086418
STATUS_CTX_WD_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086417
STATUS_CTX_SHADOW_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086416
STATUS_CTX_SHADOW_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086415
STATUS_RDP_PROTOCOL_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086414
STATUS_CTX_CLIENT_LICENSE_NOT_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086413
STATUS_CTX_CLIENT_LICENSE_IN_USE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086412
STATUS_CTX_SHADOW_ENDED_BY_MODE_CHANGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086411
STATUS_CTX_SHADOW_NOT_RUNNING: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086410
STATUS_CTX_LOGON_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086409
STATUS_CTX_SECURITY_LAYER_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086408
STATUS_TS_INCOMPATIBLE_SESSIONS: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086407
STATUS_TS_VIDEO_SUBSYSTEM_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1073086406
STATUS_PNP_BAD_MPS_TABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479627
STATUS_PNP_TRANSLATION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479626
STATUS_PNP_IRQ_TRANSLATION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479625
STATUS_PNP_INVALID_ID: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479624
STATUS_IO_REISSUE_AS_CACHED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073479623
STATUS_MUI_FILE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1073020927
STATUS_MUI_INVALID_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1073020926
STATUS_MUI_INVALID_RC_CONFIG: win32more.Windows.Win32.Foundation.NTSTATUS = -1073020925
STATUS_MUI_INVALID_LOCALE_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073020924
STATUS_MUI_INVALID_ULTIMATEFALLBACK_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1073020923
STATUS_MUI_FILE_NOT_LOADED: win32more.Windows.Win32.Foundation.NTSTATUS = -1073020922
STATUS_RESOURCE_ENUM_USER_STOP: win32more.Windows.Win32.Foundation.NTSTATUS = -1073020921
STATUS_FLT_NO_HANDLER_DEFINED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906815
STATUS_FLT_CONTEXT_ALREADY_DEFINED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906814
STATUS_FLT_INVALID_ASYNCHRONOUS_REQUEST: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906813
STATUS_FLT_DISALLOW_FAST_IO: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906812
STATUS_FLT_DISALLOW_FSFILTER_IO: Int32 = -1071906812
STATUS_FLT_INVALID_NAME_REQUEST: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906811
STATUS_FLT_NOT_SAFE_TO_POST_OPERATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906810
STATUS_FLT_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906809
STATUS_FLT_FILTER_NOT_READY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906808
STATUS_FLT_POST_OPERATION_CLEANUP: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906807
STATUS_FLT_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906806
STATUS_FLT_DELETING_OBJECT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906805
STATUS_FLT_MUST_BE_NONPAGED_POOL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906804
STATUS_FLT_DUPLICATE_ENTRY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906803
STATUS_FLT_CBDQ_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906802
STATUS_FLT_DO_NOT_ATTACH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906801
STATUS_FLT_DO_NOT_DETACH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906800
STATUS_FLT_INSTANCE_ALTITUDE_COLLISION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906799
STATUS_FLT_INSTANCE_NAME_COLLISION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906798
STATUS_FLT_FILTER_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906797
STATUS_FLT_VOLUME_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906796
STATUS_FLT_INSTANCE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906795
STATUS_FLT_CONTEXT_ALLOCATION_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906794
STATUS_FLT_INVALID_CONTEXT_REGISTRATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906793
STATUS_FLT_NAME_CACHE_MISS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906792
STATUS_FLT_NO_DEVICE_OBJECT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906791
STATUS_FLT_VOLUME_ALREADY_MOUNTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906790
STATUS_FLT_ALREADY_ENLISTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906789
STATUS_FLT_CONTEXT_ALREADY_LINKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906788
STATUS_FLT_NO_WAITER_FOR_REPLY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906784
STATUS_FLT_REGISTRATION_BUSY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906781
STATUS_FLT_WCOS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071906780
STATUS_SXS_SECTION_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365567
STATUS_SXS_CANT_GEN_ACTCTX: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365566
STATUS_SXS_INVALID_ACTCTXDATA_FORMAT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365565
STATUS_SXS_ASSEMBLY_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365564
STATUS_SXS_MANIFEST_FORMAT_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365563
STATUS_SXS_MANIFEST_PARSE_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365562
STATUS_SXS_ACTIVATION_CONTEXT_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365561
STATUS_SXS_KEY_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365560
STATUS_SXS_VERSION_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365559
STATUS_SXS_WRONG_SECTION_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365558
STATUS_SXS_THREAD_QUERIES_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365557
STATUS_SXS_ASSEMBLY_MISSING: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365556
STATUS_SXS_RELEASE_ACTIVATION_CONTEXT: win32more.Windows.Win32.Foundation.NTSTATUS = 1075118093
STATUS_SXS_PROCESS_DEFAULT_ALREADY_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365554
STATUS_SXS_EARLY_DEACTIVATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365553
STATUS_SXS_INVALID_DEACTIVATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365552
STATUS_SXS_MULTIPLE_DEACTIVATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365551
STATUS_SXS_SYSTEM_DEFAULT_ACTIVATION_CONTEXT_EMPTY: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365550
STATUS_SXS_PROCESS_TERMINATION_REQUESTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365549
STATUS_SXS_CORRUPT_ACTIVATION_STACK: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365548
STATUS_SXS_CORRUPTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365547
STATUS_SXS_INVALID_IDENTITY_ATTRIBUTE_VALUE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365546
STATUS_SXS_INVALID_IDENTITY_ATTRIBUTE_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365545
STATUS_SXS_IDENTITY_DUPLICATE_ATTRIBUTE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365544
STATUS_SXS_IDENTITY_PARSE_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365543
STATUS_SXS_COMPONENT_STORE_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365542
STATUS_SXS_FILE_HASH_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365541
STATUS_SXS_MANIFEST_IDENTITY_SAME_BUT_CONTENTS_DIFFERENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365540
STATUS_SXS_IDENTITIES_DIFFERENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365539
STATUS_SXS_ASSEMBLY_IS_NOT_A_DEPLOYMENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365538
STATUS_SXS_FILE_NOT_PART_OF_ASSEMBLY: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365537
STATUS_ADVANCED_INSTALLER_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365536
STATUS_XML_ENCODING_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365535
STATUS_SXS_MANIFEST_TOO_BIG: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365534
STATUS_SXS_SETTING_NOT_REGISTERED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365533
STATUS_SXS_TRANSACTION_CLOSURE_INCOMPLETE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365532
STATUS_SMI_PRIMITIVE_INSTALLER_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365531
STATUS_GENERIC_COMMAND_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365530
STATUS_SXS_FILE_HASH_MISSING: win32more.Windows.Win32.Foundation.NTSTATUS = -1072365529
STATUS_CLUSTER_INVALID_NODE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496639
STATUS_CLUSTER_NODE_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496638
STATUS_CLUSTER_JOIN_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496637
STATUS_CLUSTER_NODE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496636
STATUS_CLUSTER_LOCAL_NODE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496635
STATUS_CLUSTER_NETWORK_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496634
STATUS_CLUSTER_NETWORK_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496633
STATUS_CLUSTER_NETINTERFACE_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496632
STATUS_CLUSTER_NETINTERFACE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496631
STATUS_CLUSTER_INVALID_REQUEST: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496630
STATUS_CLUSTER_INVALID_NETWORK_PROVIDER: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496629
STATUS_CLUSTER_NODE_DOWN: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496628
STATUS_CLUSTER_NODE_UNREACHABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496627
STATUS_CLUSTER_NODE_NOT_MEMBER: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496626
STATUS_CLUSTER_JOIN_NOT_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496625
STATUS_CLUSTER_INVALID_NETWORK: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496624
STATUS_CLUSTER_NO_NET_ADAPTERS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496623
STATUS_CLUSTER_NODE_UP: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496622
STATUS_CLUSTER_NODE_PAUSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496621
STATUS_CLUSTER_NODE_NOT_PAUSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496620
STATUS_CLUSTER_NO_SECURITY_CONTEXT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496619
STATUS_CLUSTER_NETWORK_NOT_INTERNAL: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496618
STATUS_CLUSTER_POISONED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496617
STATUS_CLUSTER_NON_CSV_PATH: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496616
STATUS_CLUSTER_CSV_VOLUME_NOT_LOCAL: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496615
STATUS_CLUSTER_CSV_READ_OPLOCK_BREAK_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496608
STATUS_CLUSTER_CSV_AUTO_PAUSE_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496607
STATUS_CLUSTER_CSV_REDIRECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496606
STATUS_CLUSTER_CSV_NOT_REDIRECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496605
STATUS_CLUSTER_CSV_VOLUME_DRAINING: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496604
STATUS_CLUSTER_CSV_SNAPSHOT_CREATION_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496603
STATUS_CLUSTER_CSV_VOLUME_DRAINING_SUCCEEDED_DOWNLEVEL: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496602
STATUS_CLUSTER_CSV_NO_SNAPSHOTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496601
STATUS_CSV_IO_PAUSE_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496600
STATUS_CLUSTER_CSV_INVALID_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496599
STATUS_CLUSTER_CSV_SUPPORTED_ONLY_ON_COORDINATOR: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496592
STATUS_CLUSTER_CAM_TICKET_REPLAY_DETECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072496591
STATUS_TRANSACTIONAL_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103423
STATUS_INVALID_TRANSACTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103422
STATUS_TRANSACTION_NOT_ACTIVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103421
STATUS_TM_INITIALIZATION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103420
STATUS_RM_NOT_ACTIVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103419
STATUS_RM_METADATA_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103418
STATUS_TRANSACTION_NOT_JOINED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103417
STATUS_DIRECTORY_NOT_RM: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103416
STATUS_COULD_NOT_RESIZE_LOG: win32more.Windows.Win32.Foundation.NTSTATUS = -2145845239
STATUS_TRANSACTIONS_UNSUPPORTED_REMOTE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103414
STATUS_LOG_RESIZE_INVALID_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103413
STATUS_REMOTE_FILE_VERSION_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103412
STATUS_CRM_PROTOCOL_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103409
STATUS_TRANSACTION_PROPAGATION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103408
STATUS_CRM_PROTOCOL_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103407
STATUS_TRANSACTION_SUPERIOR_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103406
STATUS_TRANSACTION_REQUEST_NOT_VALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103405
STATUS_TRANSACTION_NOT_REQUESTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103404
STATUS_TRANSACTION_ALREADY_ABORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103403
STATUS_TRANSACTION_ALREADY_COMMITTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103402
STATUS_TRANSACTION_INVALID_MARSHALL_BUFFER: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103401
STATUS_CURRENT_TRANSACTION_NOT_VALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103400
STATUS_LOG_GROWTH_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103399
STATUS_OBJECT_NO_LONGER_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103391
STATUS_STREAM_MINIVERSION_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103390
STATUS_STREAM_MINIVERSION_NOT_VALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103389
STATUS_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103388
STATUS_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103387
STATUS_CANT_CREATE_MORE_STREAM_MINIVERSIONS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103386
STATUS_HANDLE_NO_LONGER_VALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103384
STATUS_NO_TXF_METADATA: win32more.Windows.Win32.Foundation.NTSTATUS = -2145845207
STATUS_LOG_CORRUPTION_DETECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103376
STATUS_CANT_RECOVER_WITH_HANDLE_OPEN: win32more.Windows.Win32.Foundation.NTSTATUS = -2145845199
STATUS_RM_DISCONNECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103374
STATUS_ENLISTMENT_NOT_SUPERIOR: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103373
STATUS_RECOVERY_NOT_NEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = 1075380276
STATUS_RM_ALREADY_STARTED: win32more.Windows.Win32.Foundation.NTSTATUS = 1075380277
STATUS_FILE_IDENTITY_NOT_PERSISTENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103370
STATUS_CANT_BREAK_TRANSACTIONAL_DEPENDENCY: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103369
STATUS_CANT_CROSS_RM_BOUNDARY: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103368
STATUS_TXF_DIR_NOT_EMPTY: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103367
STATUS_INDOUBT_TRANSACTIONS_EXIST: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103366
STATUS_TM_VOLATILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103365
STATUS_ROLLBACK_TIMER_EXPIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103364
STATUS_TXF_ATTRIBUTE_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103363
STATUS_EFS_NOT_ALLOWED_IN_TRANSACTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103362
STATUS_TRANSACTIONAL_OPEN_NOT_ALLOWED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103361
STATUS_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103360
STATUS_TXF_METADATA_ALREADY_PRESENT: win32more.Windows.Win32.Foundation.NTSTATUS = -2145845183
STATUS_TRANSACTION_SCOPE_CALLBACKS_NOT_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -2145845182
STATUS_TRANSACTION_REQUIRED_PROMOTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103357
STATUS_CANNOT_EXECUTE_FILE_IN_TRANSACTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103356
STATUS_TRANSACTIONS_NOT_FROZEN: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103355
STATUS_TRANSACTION_FREEZE_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103354
STATUS_NOT_SNAPSHOT_VOLUME: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103353
STATUS_NO_SAVEPOINT_WITH_OPEN_FILES: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103352
STATUS_SPARSE_NOT_ALLOWED_IN_TRANSACTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103351
STATUS_TM_IDENTITY_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103350
STATUS_FLOATED_SECTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103349
STATUS_CANNOT_ACCEPT_TRANSACTED_WORK: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103348
STATUS_CANNOT_ABORT_TRANSACTIONS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103347
STATUS_TRANSACTION_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103346
STATUS_RESOURCEMANAGER_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103345
STATUS_ENLISTMENT_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103344
STATUS_TRANSACTIONMANAGER_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103343
STATUS_TRANSACTIONMANAGER_NOT_ONLINE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103342
STATUS_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103341
STATUS_TRANSACTION_NOT_ROOT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103340
STATUS_TRANSACTION_OBJECT_EXPIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103339
STATUS_COMPRESSION_NOT_ALLOWED_IN_TRANSACTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103338
STATUS_TRANSACTION_RESPONSE_NOT_ENLISTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103337
STATUS_TRANSACTION_RECORD_TOO_LONG: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103336
STATUS_NO_LINK_TRACKING_IN_TRANSACTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103335
STATUS_OPERATION_NOT_SUPPORTED_IN_TRANSACTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103334
STATUS_TRANSACTION_INTEGRITY_VIOLATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103333
STATUS_TRANSACTIONMANAGER_IDENTITY_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103332
STATUS_RM_CANNOT_BE_FROZEN_FOR_SNAPSHOT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103331
STATUS_TRANSACTION_MUST_WRITETHROUGH: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103330
STATUS_TRANSACTION_NO_SUPERIOR: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103329
STATUS_EXPIRED_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103328
STATUS_TRANSACTION_NOT_ENLISTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072103327
STATUS_LOG_SECTOR_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037887
STATUS_LOG_SECTOR_PARITY_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037886
STATUS_LOG_SECTOR_REMAPPED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037885
STATUS_LOG_BLOCK_INCOMPLETE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037884
STATUS_LOG_INVALID_RANGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037883
STATUS_LOG_BLOCKS_EXHAUSTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037882
STATUS_LOG_READ_CONTEXT_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037881
STATUS_LOG_RESTART_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037880
STATUS_LOG_BLOCK_VERSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037879
STATUS_LOG_BLOCK_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037878
STATUS_LOG_READ_MODE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037877
STATUS_LOG_NO_RESTART: win32more.Windows.Win32.Foundation.NTSTATUS = 1075445772
STATUS_LOG_METADATA_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037875
STATUS_LOG_METADATA_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037874
STATUS_LOG_METADATA_INCONSISTENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037873
STATUS_LOG_RESERVATION_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037872
STATUS_LOG_CANT_DELETE: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037871
STATUS_LOG_CONTAINER_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037870
STATUS_LOG_START_OF_LOG: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037869
STATUS_LOG_POLICY_ALREADY_INSTALLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037868
STATUS_LOG_POLICY_NOT_INSTALLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037867
STATUS_LOG_POLICY_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037866
STATUS_LOG_POLICY_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037865
STATUS_LOG_PINNED_ARCHIVE_TAIL: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037864
STATUS_LOG_RECORD_NONEXISTENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037863
STATUS_LOG_RECORDS_RESERVED_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037862
STATUS_LOG_SPACE_RESERVED_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037861
STATUS_LOG_TAIL_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037860
STATUS_LOG_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037859
STATUS_LOG_MULTIPLEXED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037858
STATUS_LOG_DEDICATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037857
STATUS_LOG_ARCHIVE_NOT_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037856
STATUS_LOG_ARCHIVE_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037855
STATUS_LOG_EPHEMERAL: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037854
STATUS_LOG_NOT_ENOUGH_CONTAINERS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037853
STATUS_LOG_CLIENT_ALREADY_REGISTERED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037852
STATUS_LOG_CLIENT_NOT_REGISTERED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037851
STATUS_LOG_FULL_HANDLER_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037850
STATUS_LOG_CONTAINER_READ_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037849
STATUS_LOG_CONTAINER_WRITE_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037848
STATUS_LOG_CONTAINER_OPEN_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037847
STATUS_LOG_CONTAINER_STATE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037846
STATUS_LOG_STATE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037845
STATUS_LOG_PINNED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037844
STATUS_LOG_METADATA_FLUSH_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037843
STATUS_LOG_INCONSISTENT_SECURITY: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037842
STATUS_LOG_APPENDED_FLUSH_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037841
STATUS_LOG_PINNED_RESERVATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1072037840
STATUS_VIDEO_HUNG_DISPLAY_DRIVER_THREAD: win32more.Windows.Win32.Foundation.NTSTATUS = -1071972118
STATUS_VIDEO_HUNG_DISPLAY_DRIVER_THREAD_RECOVERED: win32more.Windows.Win32.Foundation.NTSTATUS = -2145713941
STATUS_VIDEO_DRIVER_DEBUG_REPORT_REQUEST: win32more.Windows.Win32.Foundation.NTSTATUS = 1075511532
STATUS_MONITOR_NO_DESCRIPTOR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071841279
STATUS_MONITOR_UNKNOWN_DESCRIPTOR_FORMAT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071841278
STATUS_MONITOR_INVALID_DESCRIPTOR_CHECKSUM: win32more.Windows.Win32.Foundation.NTSTATUS = -1071841277
STATUS_MONITOR_INVALID_STANDARD_TIMING_BLOCK: win32more.Windows.Win32.Foundation.NTSTATUS = -1071841276
STATUS_MONITOR_WMI_DATABLOCK_REGISTRATION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071841275
STATUS_MONITOR_INVALID_SERIAL_NUMBER_MONDSC_BLOCK: win32more.Windows.Win32.Foundation.NTSTATUS = -1071841274
STATUS_MONITOR_INVALID_USER_FRIENDLY_MONDSC_BLOCK: win32more.Windows.Win32.Foundation.NTSTATUS = -1071841273
STATUS_MONITOR_NO_MORE_DESCRIPTOR_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1071841272
STATUS_MONITOR_INVALID_DETAILED_TIMING_BLOCK: win32more.Windows.Win32.Foundation.NTSTATUS = -1071841271
STATUS_MONITOR_INVALID_MANUFACTURE_DATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071841270
STATUS_GRAPHICS_NOT_EXCLUSIVE_MODE_OWNER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775744
STATUS_GRAPHICS_INSUFFICIENT_DMA_BUFFER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775743
STATUS_GRAPHICS_INVALID_DISPLAY_ADAPTER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775742
STATUS_GRAPHICS_ADAPTER_WAS_RESET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775741
STATUS_GRAPHICS_INVALID_DRIVER_MODEL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775740
STATUS_GRAPHICS_PRESENT_MODE_CHANGED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775739
STATUS_GRAPHICS_PRESENT_OCCLUDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775738
STATUS_GRAPHICS_PRESENT_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775737
STATUS_GRAPHICS_CANNOTCOLORCONVERT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775736
STATUS_GRAPHICS_DRIVER_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775735
STATUS_GRAPHICS_PARTIAL_DATA_POPULATED: win32more.Windows.Win32.Foundation.NTSTATUS = 1075707914
STATUS_GRAPHICS_PRESENT_REDIRECTION_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775733
STATUS_GRAPHICS_PRESENT_UNOCCLUDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775732
STATUS_GRAPHICS_WINDOWDC_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775731
STATUS_GRAPHICS_WINDOWLESS_PRESENT_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775730
STATUS_GRAPHICS_PRESENT_INVALID_WINDOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775729
STATUS_GRAPHICS_PRESENT_BUFFER_NOT_BOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775728
STATUS_GRAPHICS_VAIL_STATE_CHANGED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775727
STATUS_GRAPHICS_INDIRECT_DISPLAY_ABANDON_SWAPCHAIN: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775726
STATUS_GRAPHICS_INDIRECT_DISPLAY_DEVICE_STOPPED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775725
STATUS_GRAPHICS_MPO_ALLOCATION_UNPINNED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775720
STATUS_GRAPHICS_NO_VIDEO_MEMORY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775488
STATUS_GRAPHICS_CANT_LOCK_MEMORY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775487
STATUS_GRAPHICS_ALLOCATION_BUSY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775486
STATUS_GRAPHICS_TOO_MANY_REFERENCES: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775485
STATUS_GRAPHICS_TRY_AGAIN_LATER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775484
STATUS_GRAPHICS_TRY_AGAIN_NOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775483
STATUS_GRAPHICS_ALLOCATION_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775482
STATUS_GRAPHICS_UNSWIZZLING_APERTURE_UNAVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775481
STATUS_GRAPHICS_UNSWIZZLING_APERTURE_UNSUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775480
STATUS_GRAPHICS_CANT_EVICT_PINNED_ALLOCATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775479
STATUS_GRAPHICS_INVALID_ALLOCATION_USAGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775472
STATUS_GRAPHICS_CANT_RENDER_LOCKED_ALLOCATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775471
STATUS_GRAPHICS_ALLOCATION_CLOSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775470
STATUS_GRAPHICS_INVALID_ALLOCATION_INSTANCE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775469
STATUS_GRAPHICS_INVALID_ALLOCATION_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775468
STATUS_GRAPHICS_WRONG_ALLOCATION_DEVICE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775467
STATUS_GRAPHICS_ALLOCATION_CONTENT_LOST: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775466
STATUS_GRAPHICS_GPU_EXCEPTION_ON_DEVICE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071775232
STATUS_GRAPHICS_SKIP_ALLOCATION_PREPARATION: win32more.Windows.Win32.Foundation.NTSTATUS = 1075708417
STATUS_GRAPHICS_INVALID_VIDPN_TOPOLOGY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774976
STATUS_GRAPHICS_VIDPN_TOPOLOGY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774975
STATUS_GRAPHICS_VIDPN_TOPOLOGY_CURRENTLY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774974
STATUS_GRAPHICS_INVALID_VIDPN: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774973
STATUS_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774972
STATUS_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774971
STATUS_GRAPHICS_VIDPN_MODALITY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774970
STATUS_GRAPHICS_MODE_NOT_PINNED: win32more.Windows.Win32.Foundation.NTSTATUS = 1075708679
STATUS_GRAPHICS_INVALID_VIDPN_SOURCEMODESET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774968
STATUS_GRAPHICS_INVALID_VIDPN_TARGETMODESET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774967
STATUS_GRAPHICS_INVALID_FREQUENCY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774966
STATUS_GRAPHICS_INVALID_ACTIVE_REGION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774965
STATUS_GRAPHICS_INVALID_TOTAL_REGION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774964
STATUS_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE_MODE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774960
STATUS_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET_MODE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774959
STATUS_GRAPHICS_PINNED_MODE_MUST_REMAIN_IN_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774958
STATUS_GRAPHICS_PATH_ALREADY_IN_TOPOLOGY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774957
STATUS_GRAPHICS_MODE_ALREADY_IN_MODESET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774956
STATUS_GRAPHICS_INVALID_VIDEOPRESENTSOURCESET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774955
STATUS_GRAPHICS_INVALID_VIDEOPRESENTTARGETSET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774954
STATUS_GRAPHICS_SOURCE_ALREADY_IN_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774953
STATUS_GRAPHICS_TARGET_ALREADY_IN_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774952
STATUS_GRAPHICS_INVALID_VIDPN_PRESENT_PATH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774951
STATUS_GRAPHICS_NO_RECOMMENDED_VIDPN_TOPOLOGY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774950
STATUS_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGESET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774949
STATUS_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774948
STATUS_GRAPHICS_FREQUENCYRANGE_NOT_IN_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774947
STATUS_GRAPHICS_NO_PREFERRED_MODE: win32more.Windows.Win32.Foundation.NTSTATUS = 1075708702
STATUS_GRAPHICS_FREQUENCYRANGE_ALREADY_IN_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774945
STATUS_GRAPHICS_STALE_MODESET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774944
STATUS_GRAPHICS_INVALID_MONITOR_SOURCEMODESET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774943
STATUS_GRAPHICS_INVALID_MONITOR_SOURCE_MODE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774942
STATUS_GRAPHICS_NO_RECOMMENDED_FUNCTIONAL_VIDPN: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774941
STATUS_GRAPHICS_MODE_ID_MUST_BE_UNIQUE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774940
STATUS_GRAPHICS_EMPTY_ADAPTER_MONITOR_MODE_SUPPORT_INTERSECTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774939
STATUS_GRAPHICS_VIDEO_PRESENT_TARGETS_LESS_THAN_SOURCES: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774938
STATUS_GRAPHICS_PATH_NOT_IN_TOPOLOGY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774937
STATUS_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_SOURCE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774936
STATUS_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_TARGET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774935
STATUS_GRAPHICS_INVALID_MONITORDESCRIPTORSET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774934
STATUS_GRAPHICS_INVALID_MONITORDESCRIPTOR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774933
STATUS_GRAPHICS_MONITORDESCRIPTOR_NOT_IN_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774932
STATUS_GRAPHICS_MONITORDESCRIPTOR_ALREADY_IN_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774931
STATUS_GRAPHICS_MONITORDESCRIPTOR_ID_MUST_BE_UNIQUE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774930
STATUS_GRAPHICS_INVALID_VIDPN_TARGET_SUBSET_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774929
STATUS_GRAPHICS_RESOURCES_NOT_RELATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774928
STATUS_GRAPHICS_SOURCE_ID_MUST_BE_UNIQUE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774927
STATUS_GRAPHICS_TARGET_ID_MUST_BE_UNIQUE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774926
STATUS_GRAPHICS_NO_AVAILABLE_VIDPN_TARGET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774925
STATUS_GRAPHICS_MONITOR_COULD_NOT_BE_ASSOCIATED_WITH_ADAPTER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774924
STATUS_GRAPHICS_NO_VIDPNMGR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774923
STATUS_GRAPHICS_NO_ACTIVE_VIDPN: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774922
STATUS_GRAPHICS_STALE_VIDPN_TOPOLOGY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774921
STATUS_GRAPHICS_MONITOR_NOT_CONNECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774920
STATUS_GRAPHICS_SOURCE_NOT_IN_TOPOLOGY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774919
STATUS_GRAPHICS_INVALID_PRIMARYSURFACE_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774918
STATUS_GRAPHICS_INVALID_VISIBLEREGION_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774917
STATUS_GRAPHICS_INVALID_STRIDE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774916
STATUS_GRAPHICS_INVALID_PIXELFORMAT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774915
STATUS_GRAPHICS_INVALID_COLORBASIS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774914
STATUS_GRAPHICS_INVALID_PIXELVALUEACCESSMODE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774913
STATUS_GRAPHICS_TARGET_NOT_IN_TOPOLOGY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774912
STATUS_GRAPHICS_NO_DISPLAY_MODE_MANAGEMENT_SUPPORT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774911
STATUS_GRAPHICS_VIDPN_SOURCE_IN_USE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774910
STATUS_GRAPHICS_CANT_ACCESS_ACTIVE_VIDPN: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774909
STATUS_GRAPHICS_INVALID_PATH_IMPORTANCE_ORDINAL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774908
STATUS_GRAPHICS_INVALID_PATH_CONTENT_GEOMETRY_TRANSFORMATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774907
STATUS_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774906
STATUS_GRAPHICS_INVALID_GAMMA_RAMP: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774905
STATUS_GRAPHICS_GAMMA_RAMP_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774904
STATUS_GRAPHICS_MULTISAMPLING_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774903
STATUS_GRAPHICS_MODE_NOT_IN_MODESET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774902
STATUS_GRAPHICS_DATASET_IS_EMPTY: win32more.Windows.Win32.Foundation.NTSTATUS = 1075708747
STATUS_GRAPHICS_NO_MORE_ELEMENTS_IN_DATASET: win32more.Windows.Win32.Foundation.NTSTATUS = 1075708748
STATUS_GRAPHICS_INVALID_VIDPN_TOPOLOGY_RECOMMENDATION_REASON: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774899
STATUS_GRAPHICS_INVALID_PATH_CONTENT_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774898
STATUS_GRAPHICS_INVALID_COPYPROTECTION_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774897
STATUS_GRAPHICS_UNASSIGNED_MODESET_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774896
STATUS_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_PINNED: win32more.Windows.Win32.Foundation.NTSTATUS = 1075708753
STATUS_GRAPHICS_INVALID_SCANLINE_ORDERING: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774894
STATUS_GRAPHICS_TOPOLOGY_CHANGES_NOT_ALLOWED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774893
STATUS_GRAPHICS_NO_AVAILABLE_IMPORTANCE_ORDINALS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774892
STATUS_GRAPHICS_INCOMPATIBLE_PRIVATE_FORMAT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774891
STATUS_GRAPHICS_INVALID_MODE_PRUNING_ALGORITHM: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774890
STATUS_GRAPHICS_INVALID_MONITOR_CAPABILITY_ORIGIN: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774889
STATUS_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE_CONSTRAINT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774888
STATUS_GRAPHICS_MAX_NUM_PATHS_REACHED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774887
STATUS_GRAPHICS_CANCEL_VIDPN_TOPOLOGY_AUGMENTATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774886
STATUS_GRAPHICS_INVALID_CLIENT_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774885
STATUS_GRAPHICS_CLIENTVIDPN_NOT_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774884
STATUS_GRAPHICS_SPECIFIED_CHILD_ALREADY_CONNECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774720
STATUS_GRAPHICS_CHILD_DESCRIPTOR_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774719
STATUS_GRAPHICS_UNKNOWN_CHILD_STATUS: win32more.Windows.Win32.Foundation.NTSTATUS = 1075708975
STATUS_GRAPHICS_NOT_A_LINKED_ADAPTER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774672
STATUS_GRAPHICS_LEADLINK_NOT_ENUMERATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774671
STATUS_GRAPHICS_CHAINLINKS_NOT_ENUMERATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774670
STATUS_GRAPHICS_ADAPTER_CHAIN_NOT_READY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774669
STATUS_GRAPHICS_CHAINLINKS_NOT_STARTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774668
STATUS_GRAPHICS_CHAINLINKS_NOT_POWERED_ON: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774667
STATUS_GRAPHICS_INCONSISTENT_DEVICE_LINK_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774666
STATUS_GRAPHICS_LEADLINK_START_DEFERRED: win32more.Windows.Win32.Foundation.NTSTATUS = 1075708983
STATUS_GRAPHICS_NOT_POST_DEVICE_DRIVER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774664
STATUS_GRAPHICS_POLLING_TOO_FREQUENTLY: win32more.Windows.Win32.Foundation.NTSTATUS = 1075708985
STATUS_GRAPHICS_START_DEFERRED: win32more.Windows.Win32.Foundation.NTSTATUS = 1075708986
STATUS_GRAPHICS_ADAPTER_ACCESS_NOT_EXCLUDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774661
STATUS_GRAPHICS_DEPENDABLE_CHILD_STATUS: win32more.Windows.Win32.Foundation.NTSTATUS = 1075708988
STATUS_GRAPHICS_OPM_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774464
STATUS_GRAPHICS_COPP_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774463
STATUS_GRAPHICS_UAB_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774462
STATUS_GRAPHICS_OPM_INVALID_ENCRYPTED_PARAMETERS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774461
STATUS_GRAPHICS_OPM_NO_PROTECTED_OUTPUTS_EXIST: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774459
STATUS_GRAPHICS_OPM_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774453
STATUS_GRAPHICS_OPM_INVALID_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774452
STATUS_GRAPHICS_PVP_INVALID_CERTIFICATE_LENGTH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774450
STATUS_GRAPHICS_OPM_SPANNING_MODE_ENABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774449
STATUS_GRAPHICS_OPM_THEATER_MODE_ENABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774448
STATUS_GRAPHICS_PVP_HFS_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774447
STATUS_GRAPHICS_OPM_INVALID_SRM: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774446
STATUS_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_HDCP: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774445
STATUS_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_ACP: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774444
STATUS_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_CGMSA: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774443
STATUS_GRAPHICS_OPM_HDCP_SRM_NEVER_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774442
STATUS_GRAPHICS_OPM_RESOLUTION_TOO_HIGH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774441
STATUS_GRAPHICS_OPM_ALL_HDCP_HARDWARE_ALREADY_IN_USE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774440
STATUS_GRAPHICS_OPM_PROTECTED_OUTPUT_NO_LONGER_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774438
STATUS_GRAPHICS_OPM_PROTECTED_OUTPUT_DOES_NOT_HAVE_COPP_SEMANTICS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774436
STATUS_GRAPHICS_OPM_INVALID_INFORMATION_REQUEST: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774435
STATUS_GRAPHICS_OPM_DRIVER_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774434
STATUS_GRAPHICS_OPM_PROTECTED_OUTPUT_DOES_NOT_HAVE_OPM_SEMANTICS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774433
STATUS_GRAPHICS_OPM_SIGNALING_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774432
STATUS_GRAPHICS_OPM_INVALID_CONFIGURATION_REQUEST: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774431
STATUS_GRAPHICS_I2C_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774336
STATUS_GRAPHICS_I2C_DEVICE_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774335
STATUS_GRAPHICS_I2C_ERROR_TRANSMITTING_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774334
STATUS_GRAPHICS_I2C_ERROR_RECEIVING_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774333
STATUS_GRAPHICS_DDCCI_VCP_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774332
STATUS_GRAPHICS_DDCCI_INVALID_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774331
STATUS_GRAPHICS_DDCCI_MONITOR_RETURNED_INVALID_TIMING_STATUS_BYTE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774330
STATUS_GRAPHICS_DDCCI_INVALID_CAPABILITIES_STRING: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774329
STATUS_GRAPHICS_MCA_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774328
STATUS_GRAPHICS_DDCCI_INVALID_MESSAGE_COMMAND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774327
STATUS_GRAPHICS_DDCCI_INVALID_MESSAGE_LENGTH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774326
STATUS_GRAPHICS_DDCCI_INVALID_MESSAGE_CHECKSUM: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774325
STATUS_GRAPHICS_INVALID_PHYSICAL_MONITOR_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774324
STATUS_GRAPHICS_MONITOR_NO_LONGER_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774323
STATUS_GRAPHICS_ONLY_CONSOLE_SESSION_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774240
STATUS_GRAPHICS_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774239
STATUS_GRAPHICS_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774238
STATUS_GRAPHICS_MIRRORING_DEVICES_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774237
STATUS_GRAPHICS_INVALID_POINTER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774236
STATUS_GRAPHICS_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774235
STATUS_GRAPHICS_PARAMETER_ARRAY_TOO_SMALL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774234
STATUS_GRAPHICS_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774233
STATUS_GRAPHICS_SESSION_TYPE_CHANGE_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071774232
STATUS_FVE_LOCKED_VOLUME: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579136
STATUS_FVE_NOT_ENCRYPTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579135
STATUS_FVE_BAD_INFORMATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579134
STATUS_FVE_TOO_SMALL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579133
STATUS_FVE_FAILED_WRONG_FS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579132
STATUS_FVE_BAD_PARTITION_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579131
STATUS_FVE_FS_NOT_EXTENDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579130
STATUS_FVE_FS_MOUNTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579129
STATUS_FVE_NO_LICENSE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579128
STATUS_FVE_ACTION_NOT_ALLOWED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579127
STATUS_FVE_BAD_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579126
STATUS_FVE_VOLUME_NOT_BOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579125
STATUS_FVE_NOT_DATA_VOLUME: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579124
STATUS_FVE_CONV_READ_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579123
STATUS_FVE_CONV_WRITE_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579122
STATUS_FVE_OVERLAPPED_UPDATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579121
STATUS_FVE_FAILED_SECTOR_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579120
STATUS_FVE_FAILED_AUTHENTICATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579119
STATUS_FVE_NOT_OS_VOLUME: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579118
STATUS_FVE_KEYFILE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579117
STATUS_FVE_KEYFILE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579116
STATUS_FVE_KEYFILE_NO_VMK: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579115
STATUS_FVE_TPM_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579114
STATUS_FVE_TPM_SRK_AUTH_NOT_ZERO: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579113
STATUS_FVE_TPM_INVALID_PCR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579112
STATUS_FVE_TPM_NO_VMK: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579111
STATUS_FVE_PIN_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579110
STATUS_FVE_AUTH_INVALID_APPLICATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579109
STATUS_FVE_AUTH_INVALID_CONFIG: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579108
STATUS_FVE_DEBUGGER_ENABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579107
STATUS_FVE_DRY_RUN_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579106
STATUS_FVE_BAD_METADATA_POINTER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579105
STATUS_FVE_OLD_METADATA_COPY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579104
STATUS_FVE_REBOOT_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579103
STATUS_FVE_RAW_ACCESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579102
STATUS_FVE_RAW_BLOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579101
STATUS_FVE_NO_AUTOUNLOCK_MASTER_KEY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579100
STATUS_FVE_MOR_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579099
STATUS_FVE_NO_FEATURE_LICENSE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579098
STATUS_FVE_POLICY_USER_DISABLE_RDV_NOT_ALLOWED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579097
STATUS_FVE_CONV_RECOVERY_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579096
STATUS_FVE_VIRTUALIZED_SPACE_TOO_BIG: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579095
STATUS_FVE_INVALID_DATUM_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579094
STATUS_FVE_VOLUME_TOO_SMALL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579088
STATUS_FVE_ENH_PIN_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579087
STATUS_FVE_FULL_ENCRYPTION_NOT_ALLOWED_ON_TP_STORAGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579086
STATUS_FVE_WIPE_NOT_ALLOWED_ON_TP_STORAGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579085
STATUS_FVE_NOT_ALLOWED_ON_CSV_STACK: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579084
STATUS_FVE_NOT_ALLOWED_ON_CLUSTER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579083
STATUS_FVE_NOT_ALLOWED_TO_UPGRADE_WHILE_CONVERTING: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579082
STATUS_FVE_WIPE_CANCEL_NOT_APPLICABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579081
STATUS_FVE_EDRIVE_DRY_RUN_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579080
STATUS_FVE_SECUREBOOT_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579079
STATUS_FVE_SECUREBOOT_CONFIG_CHANGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579078
STATUS_FVE_DEVICE_LOCKEDOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579077
STATUS_FVE_VOLUME_EXTEND_PREVENTS_EOW_DECRYPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579076
STATUS_FVE_NOT_DE_VOLUME: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579075
STATUS_FVE_PROTECTION_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579074
STATUS_FVE_PROTECTION_CANNOT_BE_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579073
STATUS_FVE_OSV_KSR_NOT_ALLOWED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579072
STATUS_FVE_EDRIVE_BAND_ENUMERATION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579071
STATUS_FVE_POLICY_ON_RDV_EXCLUSION_LIST: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579070
STATUS_FVE_DATASET_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579069
STATUS_FVE_METADATA_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071579068
STATUS_FWP_CALLOUT_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513599
STATUS_FWP_CONDITION_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513598
STATUS_FWP_FILTER_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513597
STATUS_FWP_LAYER_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513596
STATUS_FWP_PROVIDER_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513595
STATUS_FWP_PROVIDER_CONTEXT_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513594
STATUS_FWP_SUBLAYER_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513593
STATUS_FWP_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513592
STATUS_FWP_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513591
STATUS_FWP_IN_USE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513590
STATUS_FWP_DYNAMIC_SESSION_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513589
STATUS_FWP_WRONG_SESSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513588
STATUS_FWP_NO_TXN_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513587
STATUS_FWP_TXN_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513586
STATUS_FWP_TXN_ABORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513585
STATUS_FWP_SESSION_ABORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513584
STATUS_FWP_INCOMPATIBLE_TXN: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513583
STATUS_FWP_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513582
STATUS_FWP_NET_EVENTS_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513581
STATUS_FWP_INCOMPATIBLE_LAYER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513580
STATUS_FWP_KM_CLIENTS_ONLY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513579
STATUS_FWP_LIFETIME_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513578
STATUS_FWP_BUILTIN_OBJECT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513577
STATUS_FWP_TOO_MANY_CALLOUTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513576
STATUS_FWP_NOTIFICATION_DROPPED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513575
STATUS_FWP_TRAFFIC_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513574
STATUS_FWP_INCOMPATIBLE_SA_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513573
STATUS_FWP_NULL_POINTER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513572
STATUS_FWP_INVALID_ENUMERATOR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513571
STATUS_FWP_INVALID_FLAGS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513570
STATUS_FWP_INVALID_NET_MASK: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513569
STATUS_FWP_INVALID_RANGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513568
STATUS_FWP_INVALID_INTERVAL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513567
STATUS_FWP_ZERO_LENGTH_ARRAY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513566
STATUS_FWP_NULL_DISPLAY_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513565
STATUS_FWP_INVALID_ACTION_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513564
STATUS_FWP_INVALID_WEIGHT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513563
STATUS_FWP_MATCH_TYPE_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513562
STATUS_FWP_TYPE_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513561
STATUS_FWP_OUT_OF_BOUNDS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513560
STATUS_FWP_RESERVED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513559
STATUS_FWP_DUPLICATE_CONDITION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513558
STATUS_FWP_DUPLICATE_KEYMOD: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513557
STATUS_FWP_ACTION_INCOMPATIBLE_WITH_LAYER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513556
STATUS_FWP_ACTION_INCOMPATIBLE_WITH_SUBLAYER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513555
STATUS_FWP_CONTEXT_INCOMPATIBLE_WITH_LAYER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513554
STATUS_FWP_CONTEXT_INCOMPATIBLE_WITH_CALLOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513553
STATUS_FWP_INCOMPATIBLE_AUTH_METHOD: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513552
STATUS_FWP_INCOMPATIBLE_DH_GROUP: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513551
STATUS_FWP_EM_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513550
STATUS_FWP_NEVER_MATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513549
STATUS_FWP_PROVIDER_CONTEXT_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513548
STATUS_FWP_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513547
STATUS_FWP_TOO_MANY_SUBLAYERS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513546
STATUS_FWP_CALLOUT_NOTIFICATION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513545
STATUS_FWP_INVALID_AUTH_TRANSFORM: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513544
STATUS_FWP_INVALID_CIPHER_TRANSFORM: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513543
STATUS_FWP_INCOMPATIBLE_CIPHER_TRANSFORM: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513542
STATUS_FWP_INVALID_TRANSFORM_COMBINATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513541
STATUS_FWP_DUPLICATE_AUTH_METHOD: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513540
STATUS_FWP_INVALID_TUNNEL_ENDPOINT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513539
STATUS_FWP_L2_DRIVER_NOT_READY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513538
STATUS_FWP_KEY_DICTATOR_ALREADY_REGISTERED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513537
STATUS_FWP_KEY_DICTATION_INVALID_KEYING_MATERIAL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513536
STATUS_FWP_CONNECTIONS_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513535
STATUS_FWP_INVALID_DNS_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513534
STATUS_FWP_STILL_ON: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513533
STATUS_FWP_IKEEXT_NOT_RUNNING: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513532
STATUS_FWP_TCPIP_NOT_READY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513344
STATUS_FWP_INJECT_HANDLE_CLOSING: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513343
STATUS_FWP_INJECT_HANDLE_STALE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513342
STATUS_FWP_CANNOT_PEND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513341
STATUS_FWP_DROP_NOICMP: win32more.Windows.Win32.Foundation.NTSTATUS = -1071513340
STATUS_NDIS_CLOSING: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448062
STATUS_NDIS_BAD_VERSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448060
STATUS_NDIS_BAD_CHARACTERISTICS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448059
STATUS_NDIS_ADAPTER_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448058
STATUS_NDIS_OPEN_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448057
STATUS_NDIS_DEVICE_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448056
STATUS_NDIS_MULTICAST_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448055
STATUS_NDIS_MULTICAST_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448054
STATUS_NDIS_MULTICAST_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448053
STATUS_NDIS_REQUEST_ABORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448052
STATUS_NDIS_RESET_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448051
STATUS_NDIS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071447877
STATUS_NDIS_INVALID_PACKET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448049
STATUS_NDIS_ADAPTER_NOT_READY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448047
STATUS_NDIS_INVALID_LENGTH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448044
STATUS_NDIS_INVALID_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448043
STATUS_NDIS_BUFFER_TOO_SHORT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448042
STATUS_NDIS_INVALID_OID: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448041
STATUS_NDIS_ADAPTER_REMOVED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448040
STATUS_NDIS_UNSUPPORTED_MEDIA: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448039
STATUS_NDIS_GROUP_ADDRESS_IN_USE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448038
STATUS_NDIS_FILE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448037
STATUS_NDIS_ERROR_READING_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448036
STATUS_NDIS_ALREADY_MAPPED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448035
STATUS_NDIS_RESOURCE_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448034
STATUS_NDIS_MEDIA_DISCONNECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448033
STATUS_NDIS_INVALID_ADDRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448030
STATUS_NDIS_INVALID_DEVICE_REQUEST: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448048
STATUS_NDIS_PAUSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448022
STATUS_NDIS_INTERFACE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448021
STATUS_NDIS_UNSUPPORTED_REVISION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448020
STATUS_NDIS_INVALID_PORT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448019
STATUS_NDIS_INVALID_PORT_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448018
STATUS_NDIS_LOW_POWER_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448017
STATUS_NDIS_REINIT_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448016
STATUS_NDIS_NO_QUEUES: win32more.Windows.Win32.Foundation.NTSTATUS = -1071448015
STATUS_NDIS_DOT11_AUTO_CONFIG_ENABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071439872
STATUS_NDIS_DOT11_MEDIA_IN_USE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071439871
STATUS_NDIS_DOT11_POWER_STATE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1071439870
STATUS_NDIS_PM_WOL_PATTERN_LIST_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071439869
STATUS_NDIS_PM_PROTOCOL_OFFLOAD_LIST_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071439868
STATUS_NDIS_DOT11_AP_CHANNEL_CURRENTLY_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071439867
STATUS_NDIS_DOT11_AP_BAND_CURRENTLY_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071439866
STATUS_NDIS_DOT11_AP_CHANNEL_NOT_ALLOWED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071439865
STATUS_NDIS_DOT11_AP_BAND_NOT_ALLOWED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071439864
STATUS_NDIS_INDICATION_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = 1076035585
STATUS_NDIS_OFFLOAD_POLICY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071443953
STATUS_NDIS_OFFLOAD_CONNECTION_REJECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071443950
STATUS_NDIS_OFFLOAD_PATH_REJECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071443949
STATUS_TPM_ERROR_MASK: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054848
STATUS_TPM_AUTHFAIL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054847
STATUS_TPM_BADINDEX: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054846
STATUS_TPM_BAD_PARAMETER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054845
STATUS_TPM_AUDITFAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054844
STATUS_TPM_CLEAR_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054843
STATUS_TPM_DEACTIVATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054842
STATUS_TPM_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054841
STATUS_TPM_DISABLED_CMD: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054840
STATUS_TPM_FAIL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054839
STATUS_TPM_BAD_ORDINAL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054838
STATUS_TPM_INSTALL_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054837
STATUS_TPM_INVALID_KEYHANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054836
STATUS_TPM_KEYNOTFOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054835
STATUS_TPM_INAPPROPRIATE_ENC: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054834
STATUS_TPM_MIGRATEFAIL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054833
STATUS_TPM_INVALID_PCR_INFO: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054832
STATUS_TPM_NOSPACE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054831
STATUS_TPM_NOSRK: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054830
STATUS_TPM_NOTSEALED_BLOB: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054829
STATUS_TPM_OWNER_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054828
STATUS_TPM_RESOURCES: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054827
STATUS_TPM_SHORTRANDOM: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054826
STATUS_TPM_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054825
STATUS_TPM_WRONGPCRVAL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054824
STATUS_TPM_BAD_PARAM_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054823
STATUS_TPM_SHA_THREAD: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054822
STATUS_TPM_SHA_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054821
STATUS_TPM_FAILEDSELFTEST: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054820
STATUS_TPM_AUTH2FAIL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054819
STATUS_TPM_BADTAG: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054818
STATUS_TPM_IOERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054817
STATUS_TPM_ENCRYPT_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054816
STATUS_TPM_DECRYPT_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054815
STATUS_TPM_INVALID_AUTHHANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054814
STATUS_TPM_NO_ENDORSEMENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054813
STATUS_TPM_INVALID_KEYUSAGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054812
STATUS_TPM_WRONG_ENTITYTYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054811
STATUS_TPM_INVALID_POSTINIT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054810
STATUS_TPM_INAPPROPRIATE_SIG: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054809
STATUS_TPM_BAD_KEY_PROPERTY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054808
STATUS_TPM_BAD_MIGRATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054807
STATUS_TPM_BAD_SCHEME: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054806
STATUS_TPM_BAD_DATASIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054805
STATUS_TPM_BAD_MODE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054804
STATUS_TPM_BAD_PRESENCE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054803
STATUS_TPM_BAD_VERSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054802
STATUS_TPM_NO_WRAP_TRANSPORT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054801
STATUS_TPM_AUDITFAIL_UNSUCCESSFUL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054800
STATUS_TPM_AUDITFAIL_SUCCESSFUL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054799
STATUS_TPM_NOTRESETABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054798
STATUS_TPM_NOTLOCAL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054797
STATUS_TPM_BAD_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054796
STATUS_TPM_INVALID_RESOURCE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054795
STATUS_TPM_NOTFIPS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054794
STATUS_TPM_INVALID_FAMILY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054793
STATUS_TPM_NO_NV_PERMISSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054792
STATUS_TPM_REQUIRES_SIGN: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054791
STATUS_TPM_KEY_NOTSUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054790
STATUS_TPM_AUTH_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054789
STATUS_TPM_AREA_LOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054788
STATUS_TPM_BAD_LOCALITY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054787
STATUS_TPM_READ_ONLY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054786
STATUS_TPM_PER_NOWRITE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054785
STATUS_TPM_FAMILYCOUNT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054784
STATUS_TPM_WRITE_LOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054783
STATUS_TPM_BAD_ATTRIBUTES: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054782
STATUS_TPM_INVALID_STRUCTURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054781
STATUS_TPM_KEY_OWNER_CONTROL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054780
STATUS_TPM_BAD_COUNTER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054779
STATUS_TPM_NOT_FULLWRITE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054778
STATUS_TPM_CONTEXT_GAP: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054777
STATUS_TPM_MAXNVWRITES: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054776
STATUS_TPM_NOOPERATOR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054775
STATUS_TPM_RESOURCEMISSING: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054774
STATUS_TPM_DELEGATE_LOCK: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054773
STATUS_TPM_DELEGATE_FAMILY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054772
STATUS_TPM_DELEGATE_ADMIN: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054771
STATUS_TPM_TRANSPORT_NOTEXCLUSIVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054770
STATUS_TPM_OWNER_CONTROL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054769
STATUS_TPM_DAA_RESOURCES: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054768
STATUS_TPM_DAA_INPUT_DATA0: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054767
STATUS_TPM_DAA_INPUT_DATA1: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054766
STATUS_TPM_DAA_ISSUER_SETTINGS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054765
STATUS_TPM_DAA_TPM_SETTINGS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054764
STATUS_TPM_DAA_STAGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054763
STATUS_TPM_DAA_ISSUER_VALIDITY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054762
STATUS_TPM_DAA_WRONG_W: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054761
STATUS_TPM_BAD_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054760
STATUS_TPM_BAD_DELEGATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054759
STATUS_TPM_BADCONTEXT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054758
STATUS_TPM_TOOMANYCONTEXTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054757
STATUS_TPM_MA_TICKET_SIGNATURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054756
STATUS_TPM_MA_DESTINATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054755
STATUS_TPM_MA_SOURCE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054754
STATUS_TPM_MA_AUTHORITY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054753
STATUS_TPM_PERMANENTEK: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054751
STATUS_TPM_BAD_SIGNATURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054750
STATUS_TPM_NOCONTEXTSPACE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054749
STATUS_TPM_20_E_ASYMMETRIC: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054719
STATUS_TPM_20_E_ATTRIBUTES: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054718
STATUS_TPM_20_E_HASH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054717
STATUS_TPM_20_E_VALUE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054716
STATUS_TPM_20_E_HIERARCHY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054715
STATUS_TPM_20_E_KEY_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054713
STATUS_TPM_20_E_MGF: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054712
STATUS_TPM_20_E_MODE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054711
STATUS_TPM_20_E_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054710
STATUS_TPM_20_E_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054709
STATUS_TPM_20_E_KDF: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054708
STATUS_TPM_20_E_RANGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054707
STATUS_TPM_20_E_AUTH_FAIL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054706
STATUS_TPM_20_E_NONCE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054705
STATUS_TPM_20_E_PP: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054704
STATUS_TPM_20_E_SCHEME: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054702
STATUS_TPM_20_E_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054699
STATUS_TPM_20_E_SYMMETRIC: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054698
STATUS_TPM_20_E_TAG: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054697
STATUS_TPM_20_E_SELECTOR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054696
STATUS_TPM_20_E_INSUFFICIENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054694
STATUS_TPM_20_E_SIGNATURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054693
STATUS_TPM_20_E_KEY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054692
STATUS_TPM_20_E_POLICY_FAIL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054691
STATUS_TPM_20_E_INTEGRITY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054689
STATUS_TPM_20_E_TICKET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054688
STATUS_TPM_20_E_RESERVED_BITS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054687
STATUS_TPM_20_E_BAD_AUTH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054686
STATUS_TPM_20_E_EXPIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054685
STATUS_TPM_20_E_POLICY_CC: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054684
STATUS_TPM_20_E_BINDING: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054683
STATUS_TPM_20_E_CURVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054682
STATUS_TPM_20_E_ECC_POINT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054681
STATUS_TPM_20_E_INITIALIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054592
STATUS_TPM_20_E_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054591
STATUS_TPM_20_E_SEQUENCE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054589
STATUS_TPM_20_E_PRIVATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054581
STATUS_TPM_20_E_HMAC: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054567
STATUS_TPM_20_E_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054560
STATUS_TPM_20_E_EXCLUSIVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054559
STATUS_TPM_20_E_ECC_CURVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054557
STATUS_TPM_20_E_AUTH_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054556
STATUS_TPM_20_E_AUTH_MISSING: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054555
STATUS_TPM_20_E_POLICY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054554
STATUS_TPM_20_E_PCR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054553
STATUS_TPM_20_E_PCR_CHANGED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054552
STATUS_TPM_20_E_UPGRADE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054547
STATUS_TPM_20_E_TOO_MANY_CONTEXTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054546
STATUS_TPM_20_E_AUTH_UNAVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054545
STATUS_TPM_20_E_REBOOT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054544
STATUS_TPM_20_E_UNBALANCED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054543
STATUS_TPM_20_E_COMMAND_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054526
STATUS_TPM_20_E_COMMAND_CODE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054525
STATUS_TPM_20_E_AUTHSIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054524
STATUS_TPM_20_E_AUTH_CONTEXT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054523
STATUS_TPM_20_E_NV_RANGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054522
STATUS_TPM_20_E_NV_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054521
STATUS_TPM_20_E_NV_LOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054520
STATUS_TPM_20_E_NV_AUTHORIZATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054519
STATUS_TPM_20_E_NV_UNINITIALIZED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054518
STATUS_TPM_20_E_NV_SPACE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054517
STATUS_TPM_20_E_NV_DEFINED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054516
STATUS_TPM_20_E_BAD_CONTEXT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054512
STATUS_TPM_20_E_CPHASH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054511
STATUS_TPM_20_E_PARENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054510
STATUS_TPM_20_E_NEEDS_TEST: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054509
STATUS_TPM_20_E_NO_RESULT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054508
STATUS_TPM_20_E_SENSITIVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071054507
STATUS_TPM_COMMAND_BLOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071053824
STATUS_TPM_INVALID_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071053823
STATUS_TPM_DUPLICATE_VHANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071053822
STATUS_TPM_EMBEDDED_COMMAND_BLOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071053821
STATUS_TPM_EMBEDDED_COMMAND_UNSUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071053820
STATUS_TPM_RETRY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071052800
STATUS_TPM_NEEDS_SELFTEST: win32more.Windows.Win32.Foundation.NTSTATUS = -1071052799
STATUS_TPM_DOING_SELFTEST: win32more.Windows.Win32.Foundation.NTSTATUS = -1071052798
STATUS_TPM_DEFEND_LOCK_RUNNING: win32more.Windows.Win32.Foundation.NTSTATUS = -1071052797
STATUS_TPM_COMMAND_CANCELED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071050751
STATUS_TPM_TOO_MANY_CONTEXTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1071050750
STATUS_TPM_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071050749
STATUS_TPM_ACCESS_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071050748
STATUS_TPM_INSUFFICIENT_BUFFER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071050747
STATUS_TPM_PPI_FUNCTION_UNSUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071050746
STATUS_PCP_ERROR_MASK: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046656
STATUS_PCP_DEVICE_NOT_READY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046655
STATUS_PCP_INVALID_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046654
STATUS_PCP_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046653
STATUS_PCP_FLAG_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046652
STATUS_PCP_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046651
STATUS_PCP_BUFFER_TOO_SMALL: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046650
STATUS_PCP_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046649
STATUS_PCP_AUTHENTICATION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046648
STATUS_PCP_AUTHENTICATION_IGNORED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046647
STATUS_PCP_POLICY_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046646
STATUS_PCP_PROFILE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046645
STATUS_PCP_VALIDATION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046644
STATUS_PCP_DEVICE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046643
STATUS_PCP_WRONG_PARENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046642
STATUS_PCP_KEY_NOT_LOADED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046641
STATUS_PCP_NO_KEY_CERTIFICATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046640
STATUS_PCP_KEY_NOT_FINALIZED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046639
STATUS_PCP_ATTESTATION_CHALLENGE_NOT_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046638
STATUS_PCP_NOT_PCR_BOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046637
STATUS_PCP_KEY_ALREADY_FINALIZED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046636
STATUS_PCP_KEY_USAGE_POLICY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046635
STATUS_PCP_KEY_USAGE_POLICY_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046634
STATUS_PCP_SOFT_KEY_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046633
STATUS_PCP_KEY_NOT_AUTHENTICATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046632
STATUS_PCP_KEY_NOT_AIK: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046631
STATUS_PCP_KEY_NOT_SIGNING_KEY: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046630
STATUS_PCP_LOCKED_OUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046629
STATUS_PCP_CLAIM_TYPE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046628
STATUS_PCP_TPM_VERSION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046627
STATUS_PCP_BUFFER_LENGTH_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046626
STATUS_PCP_IFX_RSA_KEY_CREATION_BLOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046625
STATUS_PCP_TICKET_MISSING: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046624
STATUS_PCP_RAW_POLICY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046623
STATUS_PCP_KEY_HANDLE_INVALIDATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071046622
STATUS_PCP_UNSUPPORTED_PSS_SALT: win32more.Windows.Win32.Foundation.NTSTATUS = 1076437027
STATUS_RTPM_CONTEXT_CONTINUE: win32more.Windows.Win32.Foundation.NTSTATUS = 2699264
STATUS_RTPM_CONTEXT_COMPLETE: win32more.Windows.Win32.Foundation.NTSTATUS = 2699265
STATUS_RTPM_NO_RESULT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071042558
STATUS_RTPM_PCR_READ_INCOMPLETE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071042557
STATUS_RTPM_INVALID_CONTEXT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071042556
STATUS_RTPM_UNSUPPORTED_CMD: win32more.Windows.Win32.Foundation.NTSTATUS = -1071042555
STATUS_TPM_ZERO_EXHAUST_ENABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071038464
STATUS_HV_INVALID_HYPERCALL_CODE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268414
STATUS_HV_INVALID_HYPERCALL_INPUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268413
STATUS_HV_INVALID_ALIGNMENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268412
STATUS_HV_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268411
STATUS_HV_ACCESS_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268410
STATUS_HV_INVALID_PARTITION_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268409
STATUS_HV_OPERATION_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268408
STATUS_HV_UNKNOWN_PROPERTY: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268407
STATUS_HV_PROPERTY_VALUE_OUT_OF_RANGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268406
STATUS_HV_INSUFFICIENT_MEMORY: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268405
STATUS_HV_PARTITION_TOO_DEEP: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268404
STATUS_HV_INVALID_PARTITION_ID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268403
STATUS_HV_INVALID_VP_INDEX: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268402
STATUS_HV_INVALID_PORT_ID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268399
STATUS_HV_INVALID_CONNECTION_ID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268398
STATUS_HV_INSUFFICIENT_BUFFERS: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268397
STATUS_HV_NOT_ACKNOWLEDGED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268396
STATUS_HV_INVALID_VP_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268395
STATUS_HV_ACKNOWLEDGED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268394
STATUS_HV_INVALID_SAVE_RESTORE_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268393
STATUS_HV_INVALID_SYNIC_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268392
STATUS_HV_OBJECT_IN_USE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268391
STATUS_HV_INVALID_PROXIMITY_DOMAIN_INFO: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268390
STATUS_HV_NO_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268389
STATUS_HV_INACTIVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268388
STATUS_HV_NO_RESOURCES: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268387
STATUS_HV_FEATURE_UNAVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268386
STATUS_HV_INSUFFICIENT_BUFFER: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268365
STATUS_HV_INSUFFICIENT_DEVICE_DOMAINS: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268360
STATUS_HV_CPUID_FEATURE_VALIDATION_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268356
STATUS_HV_CPUID_XSAVE_FEATURE_VALIDATION_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268355
STATUS_HV_PROCESSOR_STARTUP_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268354
STATUS_HV_SMX_ENABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268353
STATUS_HV_INVALID_LP_INDEX: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268351
STATUS_HV_INVALID_REGISTER_VALUE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268336
STATUS_HV_INVALID_VTL_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268335
STATUS_HV_NX_NOT_DETECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268331
STATUS_HV_INVALID_DEVICE_ID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268329
STATUS_HV_INVALID_DEVICE_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268328
STATUS_HV_PENDING_PAGE_REQUESTS: win32more.Windows.Win32.Foundation.NTSTATUS = 3473497
STATUS_HV_PAGE_REQUEST_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268320
STATUS_HV_INVALID_CPU_GROUP_ID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268305
STATUS_HV_INVALID_CPU_GROUP_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268304
STATUS_HV_OPERATION_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268303
STATUS_HV_NOT_ALLOWED_WITH_NESTED_VIRT_ACTIVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268302
STATUS_HV_INSUFFICIENT_ROOT_MEMORY: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268301
STATUS_HV_EVENT_BUFFER_ALREADY_FREED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268300
STATUS_HV_INSUFFICIENT_CONTIGUOUS_MEMORY: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268299
STATUS_HV_DEVICE_NOT_IN_DOMAIN: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268298
STATUS_HV_NESTED_VM_EXIT: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268297
STATUS_HV_CALL_PENDING: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268295
STATUS_HV_MSR_ACCESS_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268288
STATUS_HV_INSUFFICIENT_MEMORY_MIRRORING: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268287
STATUS_HV_INSUFFICIENT_CONTIGUOUS_MEMORY_MIRRORING: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268286
STATUS_HV_INSUFFICIENT_CONTIGUOUS_ROOT_MEMORY: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268285
STATUS_HV_INSUFFICIENT_ROOT_MEMORY_MIRRORING: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268284
STATUS_HV_INSUFFICIENT_CONTIGUOUS_ROOT_MEMORY_MIRRORING: win32more.Windows.Win32.Foundation.NTSTATUS = -1070268283
STATUS_HV_NOT_PRESENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1070264320
STATUS_VID_DUPLICATE_HANDLER: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137343
STATUS_VID_TOO_MANY_HANDLERS: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137342
STATUS_VID_QUEUE_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137341
STATUS_VID_HANDLER_NOT_PRESENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137340
STATUS_VID_INVALID_OBJECT_NAME: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137339
STATUS_VID_PARTITION_NAME_TOO_LONG: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137338
STATUS_VID_MESSAGE_QUEUE_NAME_TOO_LONG: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137337
STATUS_VID_PARTITION_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137336
STATUS_VID_PARTITION_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137335
STATUS_VID_PARTITION_NAME_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137334
STATUS_VID_MESSAGE_QUEUE_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137333
STATUS_VID_EXCEEDED_MBP_ENTRY_MAP_LIMIT: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137332
STATUS_VID_MB_STILL_REFERENCED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137331
STATUS_VID_CHILD_GPA_PAGE_SET_CORRUPTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137330
STATUS_VID_INVALID_NUMA_SETTINGS: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137329
STATUS_VID_INVALID_NUMA_NODE_INDEX: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137328
STATUS_VID_NOTIFICATION_QUEUE_ALREADY_ASSOCIATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137327
STATUS_VID_INVALID_MEMORY_BLOCK_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137326
STATUS_VID_PAGE_RANGE_OVERFLOW: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137325
STATUS_VID_INVALID_MESSAGE_QUEUE_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137324
STATUS_VID_INVALID_GPA_RANGE_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137323
STATUS_VID_NO_MEMORY_BLOCK_NOTIFICATION_QUEUE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137322
STATUS_VID_MEMORY_BLOCK_LOCK_COUNT_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137321
STATUS_VID_INVALID_PPM_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137320
STATUS_VID_MBPS_ARE_LOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137319
STATUS_VID_MESSAGE_QUEUE_CLOSED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137318
STATUS_VID_VIRTUAL_PROCESSOR_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137317
STATUS_VID_STOP_PENDING: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137316
STATUS_VID_INVALID_PROCESSOR_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137315
STATUS_VID_EXCEEDED_KM_CONTEXT_COUNT_LIMIT: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137314
STATUS_VID_KM_INTERFACE_ALREADY_INITIALIZED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137313
STATUS_VID_MB_PROPERTY_ALREADY_SET_RESET: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137312
STATUS_VID_MMIO_RANGE_DESTROYED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137311
STATUS_VID_INVALID_CHILD_GPA_PAGE_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137310
STATUS_VID_RESERVE_PAGE_SET_IS_BEING_USED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137309
STATUS_VID_RESERVE_PAGE_SET_TOO_SMALL: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137308
STATUS_VID_MBP_ALREADY_LOCKED_USING_RESERVED_PAGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137307
STATUS_VID_MBP_COUNT_EXCEEDED_LIMIT: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137306
STATUS_VID_SAVED_STATE_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137305
STATUS_VID_SAVED_STATE_UNRECOGNIZED_ITEM: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137304
STATUS_VID_SAVED_STATE_INCOMPATIBLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137303
STATUS_VID_VTL_ACCESS_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137302
STATUS_VID_INSUFFICIENT_RESOURCES_RESERVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137301
STATUS_VID_INSUFFICIENT_RESOURCES_PHYSICAL_BUFFER: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137300
STATUS_VID_INSUFFICIENT_RESOURCES_HV_DEPOSIT: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137299
STATUS_VID_MEMORY_TYPE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137298
STATUS_VID_INSUFFICIENT_RESOURCES_WITHDRAW: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137297
STATUS_VID_PROCESS_ALREADY_SET: win32more.Windows.Win32.Foundation.NTSTATUS = -1070137296
STATUS_DM_OPERATION_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070135808
STATUS_VID_REMOTE_NODE_PARENT_GPA_PAGES_USED: win32more.Windows.Win32.Foundation.NTSTATUS = -2143879167
STATUS_IPSEC_BAD_SPI: win32more.Windows.Win32.Foundation.NTSTATUS = -1070202879
STATUS_IPSEC_SA_LIFETIME_EXPIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070202878
STATUS_IPSEC_WRONG_SA: win32more.Windows.Win32.Foundation.NTSTATUS = -1070202877
STATUS_IPSEC_REPLAY_CHECK_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070202876
STATUS_IPSEC_INVALID_PACKET: win32more.Windows.Win32.Foundation.NTSTATUS = -1070202875
STATUS_IPSEC_INTEGRITY_CHECK_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070202874
STATUS_IPSEC_CLEAR_TEXT_DROP: win32more.Windows.Win32.Foundation.NTSTATUS = -1070202873
STATUS_IPSEC_AUTH_FIREWALL_DROP: win32more.Windows.Win32.Foundation.NTSTATUS = -1070202872
STATUS_IPSEC_THROTTLE_DROP: win32more.Windows.Win32.Foundation.NTSTATUS = -1070202871
STATUS_IPSEC_DOSP_BLOCK: win32more.Windows.Win32.Foundation.NTSTATUS = -1070170112
STATUS_IPSEC_DOSP_RECEIVED_MULTICAST: win32more.Windows.Win32.Foundation.NTSTATUS = -1070170111
STATUS_IPSEC_DOSP_INVALID_PACKET: win32more.Windows.Win32.Foundation.NTSTATUS = -1070170110
STATUS_IPSEC_DOSP_STATE_LOOKUP_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070170109
STATUS_IPSEC_DOSP_MAX_ENTRIES: win32more.Windows.Win32.Foundation.NTSTATUS = -1070170108
STATUS_IPSEC_DOSP_KEYMOD_NOT_ALLOWED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070170107
STATUS_IPSEC_DOSP_MAX_PER_IP_RATELIMIT_QUEUES: win32more.Windows.Win32.Foundation.NTSTATUS = -1070170106
STATUS_VOLMGR_INCOMPLETE_REGENERATION: win32more.Windows.Win32.Foundation.NTSTATUS = -2143813631
STATUS_VOLMGR_INCOMPLETE_DISK_MIGRATION: win32more.Windows.Win32.Foundation.NTSTATUS = -2143813630
STATUS_VOLMGR_DATABASE_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071807
STATUS_VOLMGR_DISK_CONFIGURATION_CORRUPTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071806
STATUS_VOLMGR_DISK_CONFIGURATION_NOT_IN_SYNC: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071805
STATUS_VOLMGR_PACK_CONFIG_UPDATE_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071804
STATUS_VOLMGR_DISK_CONTAINS_NON_SIMPLE_VOLUME: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071803
STATUS_VOLMGR_DISK_DUPLICATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071802
STATUS_VOLMGR_DISK_DYNAMIC: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071801
STATUS_VOLMGR_DISK_ID_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071800
STATUS_VOLMGR_DISK_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071799
STATUS_VOLMGR_DISK_LAST_VOTER: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071798
STATUS_VOLMGR_DISK_LAYOUT_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071797
STATUS_VOLMGR_DISK_LAYOUT_NON_BASIC_BETWEEN_BASIC_PARTITIONS: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071796
STATUS_VOLMGR_DISK_LAYOUT_NOT_CYLINDER_ALIGNED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071795
STATUS_VOLMGR_DISK_LAYOUT_PARTITIONS_TOO_SMALL: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071794
STATUS_VOLMGR_DISK_LAYOUT_PRIMARY_BETWEEN_LOGICAL_PARTITIONS: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071793
STATUS_VOLMGR_DISK_LAYOUT_TOO_MANY_PARTITIONS: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071792
STATUS_VOLMGR_DISK_MISSING: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071791
STATUS_VOLMGR_DISK_NOT_EMPTY: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071790
STATUS_VOLMGR_DISK_NOT_ENOUGH_SPACE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071789
STATUS_VOLMGR_DISK_REVECTORING_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071788
STATUS_VOLMGR_DISK_SECTOR_SIZE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071787
STATUS_VOLMGR_DISK_SET_NOT_CONTAINED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071786
STATUS_VOLMGR_DISK_USED_BY_MULTIPLE_MEMBERS: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071785
STATUS_VOLMGR_DISK_USED_BY_MULTIPLE_PLEXES: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071784
STATUS_VOLMGR_DYNAMIC_DISK_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071783
STATUS_VOLMGR_EXTENT_ALREADY_USED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071782
STATUS_VOLMGR_EXTENT_NOT_CONTIGUOUS: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071781
STATUS_VOLMGR_EXTENT_NOT_IN_PUBLIC_REGION: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071780
STATUS_VOLMGR_EXTENT_NOT_SECTOR_ALIGNED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071779
STATUS_VOLMGR_EXTENT_OVERLAPS_EBR_PARTITION: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071778
STATUS_VOLMGR_EXTENT_VOLUME_LENGTHS_DO_NOT_MATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071777
STATUS_VOLMGR_FAULT_TOLERANT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071776
STATUS_VOLMGR_INTERLEAVE_LENGTH_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071775
STATUS_VOLMGR_MAXIMUM_REGISTERED_USERS: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071774
STATUS_VOLMGR_MEMBER_IN_SYNC: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071773
STATUS_VOLMGR_MEMBER_INDEX_DUPLICATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071772
STATUS_VOLMGR_MEMBER_INDEX_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071771
STATUS_VOLMGR_MEMBER_MISSING: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071770
STATUS_VOLMGR_MEMBER_NOT_DETACHED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071769
STATUS_VOLMGR_MEMBER_REGENERATING: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071768
STATUS_VOLMGR_ALL_DISKS_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071767
STATUS_VOLMGR_NO_REGISTERED_USERS: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071766
STATUS_VOLMGR_NO_SUCH_USER: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071765
STATUS_VOLMGR_NOTIFICATION_RESET: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071764
STATUS_VOLMGR_NUMBER_OF_MEMBERS_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071763
STATUS_VOLMGR_NUMBER_OF_PLEXES_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071762
STATUS_VOLMGR_PACK_DUPLICATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071761
STATUS_VOLMGR_PACK_ID_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071760
STATUS_VOLMGR_PACK_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071759
STATUS_VOLMGR_PACK_NAME_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071758
STATUS_VOLMGR_PACK_OFFLINE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071757
STATUS_VOLMGR_PACK_HAS_QUORUM: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071756
STATUS_VOLMGR_PACK_WITHOUT_QUORUM: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071755
STATUS_VOLMGR_PARTITION_STYLE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071754
STATUS_VOLMGR_PARTITION_UPDATE_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071753
STATUS_VOLMGR_PLEX_IN_SYNC: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071752
STATUS_VOLMGR_PLEX_INDEX_DUPLICATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071751
STATUS_VOLMGR_PLEX_INDEX_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071750
STATUS_VOLMGR_PLEX_LAST_ACTIVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071749
STATUS_VOLMGR_PLEX_MISSING: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071748
STATUS_VOLMGR_PLEX_REGENERATING: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071747
STATUS_VOLMGR_PLEX_TYPE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071746
STATUS_VOLMGR_PLEX_NOT_RAID5: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071745
STATUS_VOLMGR_PLEX_NOT_SIMPLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071744
STATUS_VOLMGR_STRUCTURE_SIZE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071743
STATUS_VOLMGR_TOO_MANY_NOTIFICATION_REQUESTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071742
STATUS_VOLMGR_TRANSACTION_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071741
STATUS_VOLMGR_UNEXPECTED_DISK_LAYOUT_CHANGE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071740
STATUS_VOLMGR_VOLUME_CONTAINS_MISSING_DISK: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071739
STATUS_VOLMGR_VOLUME_ID_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071738
STATUS_VOLMGR_VOLUME_LENGTH_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071737
STATUS_VOLMGR_VOLUME_LENGTH_NOT_SECTOR_SIZE_MULTIPLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071736
STATUS_VOLMGR_VOLUME_NOT_MIRRORED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071735
STATUS_VOLMGR_VOLUME_NOT_RETAINED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071734
STATUS_VOLMGR_VOLUME_OFFLINE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071733
STATUS_VOLMGR_VOLUME_RETAINED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071732
STATUS_VOLMGR_NUMBER_OF_EXTENTS_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071731
STATUS_VOLMGR_DIFFERENT_SECTOR_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071730
STATUS_VOLMGR_BAD_BOOT_DISK: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071729
STATUS_VOLMGR_PACK_CONFIG_OFFLINE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071728
STATUS_VOLMGR_PACK_CONFIG_ONLINE: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071727
STATUS_VOLMGR_NOT_PRIMARY_PACK: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071726
STATUS_VOLMGR_PACK_LOG_UPDATE_FAILED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071725
STATUS_VOLMGR_NUMBER_OF_DISKS_IN_PLEX_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071724
STATUS_VOLMGR_NUMBER_OF_DISKS_IN_MEMBER_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071723
STATUS_VOLMGR_VOLUME_MIRRORED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071722
STATUS_VOLMGR_PLEX_NOT_SIMPLE_SPANNED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071721
STATUS_VOLMGR_NO_VALID_LOG_COPIES: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071720
STATUS_VOLMGR_PRIMARY_PACK_PRESENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071719
STATUS_VOLMGR_NUMBER_OF_DISKS_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071718
STATUS_VOLMGR_MIRROR_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071717
STATUS_VOLMGR_RAID5_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1070071716
STATUS_BCD_NOT_ALL_ENTRIES_IMPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -2143748095
STATUS_BCD_TOO_MANY_ELEMENTS: win32more.Windows.Win32.Foundation.NTSTATUS = -1070006270
STATUS_BCD_NOT_ALL_ENTRIES_SYNCHRONIZED: win32more.Windows.Win32.Foundation.NTSTATUS = -2143748093
STATUS_VHD_DRIVE_FOOTER_MISSING: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940735
STATUS_VHD_DRIVE_FOOTER_CHECKSUM_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940734
STATUS_VHD_DRIVE_FOOTER_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940733
STATUS_VHD_FORMAT_UNKNOWN: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940732
STATUS_VHD_FORMAT_UNSUPPORTED_VERSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940731
STATUS_VHD_SPARSE_HEADER_CHECKSUM_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940730
STATUS_VHD_SPARSE_HEADER_UNSUPPORTED_VERSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940729
STATUS_VHD_SPARSE_HEADER_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940728
STATUS_VHD_BLOCK_ALLOCATION_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940727
STATUS_VHD_BLOCK_ALLOCATION_TABLE_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940726
STATUS_VHD_INVALID_BLOCK_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940725
STATUS_VHD_BITMAP_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940724
STATUS_VHD_PARENT_VHD_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940723
STATUS_VHD_CHILD_PARENT_ID_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940722
STATUS_VHD_CHILD_PARENT_TIMESTAMP_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940721
STATUS_VHD_METADATA_READ_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940720
STATUS_VHD_METADATA_WRITE_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940719
STATUS_VHD_INVALID_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940718
STATUS_VHD_INVALID_FILE_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940717
STATUS_VIRTDISK_PROVIDER_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940716
STATUS_VIRTDISK_NOT_VIRTUAL_DISK: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940715
STATUS_VHD_PARENT_VHD_ACCESS_DENIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940714
STATUS_VHD_CHILD_PARENT_SIZE_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940713
STATUS_VHD_DIFFERENCING_CHAIN_CYCLE_DETECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940712
STATUS_VHD_DIFFERENCING_CHAIN_ERROR_IN_PARENT: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940711
STATUS_VIRTUAL_DISK_LIMITATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940710
STATUS_VHD_INVALID_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940709
STATUS_VHD_INVALID_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940708
STATUS_VIRTDISK_UNSUPPORTED_DISK_SECTOR_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940707
STATUS_VIRTDISK_DISK_ALREADY_OWNED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940706
STATUS_VIRTDISK_DISK_ONLINE_AND_WRITABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940705
STATUS_CTLOG_TRACKING_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940704
STATUS_CTLOG_LOGFILE_SIZE_EXCEEDED_MAXSIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940703
STATUS_CTLOG_VHD_CHANGED_OFFLINE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940702
STATUS_CTLOG_INVALID_TRACKING_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940701
STATUS_CTLOG_INCONSISTENT_TRACKING_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940700
STATUS_VHD_METADATA_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940696
STATUS_VHD_INVALID_CHANGE_TRACKING_ID: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940695
STATUS_VHD_CHANGE_TRACKING_DISABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940694
STATUS_VHD_MISSING_CHANGE_TRACKING_INFORMATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940688
STATUS_VHD_RESIZE_WOULD_TRUNCATE_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940687
STATUS_VHD_COULD_NOT_COMPUTE_MINIMUM_VIRTUAL_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940686
STATUS_VHD_ALREADY_AT_OR_BELOW_MINIMUM_VIRTUAL_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940685
STATUS_VHD_UNEXPECTED_ID: win32more.Windows.Win32.Foundation.NTSTATUS = -1069940684
STATUS_QUERY_STORAGE_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -2143682559
STATUS_GDI_HANDLE_LEAK: win32more.Windows.Win32.Foundation.NTSTATUS = -2143354879
STATUS_RKF_KEY_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1069547519
STATUS_RKF_DUPLICATE_KEY: win32more.Windows.Win32.Foundation.NTSTATUS = -1069547518
STATUS_RKF_BLOB_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1069547517
STATUS_RKF_STORE_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1069547516
STATUS_RKF_FILE_BLOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069547515
STATUS_RKF_ACTIVE_KEY: win32more.Windows.Win32.Foundation.NTSTATUS = -1069547514
STATUS_RDBSS_RESTART_OPERATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1069481983
STATUS_RDBSS_CONTINUE_OPERATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1069481982
STATUS_RDBSS_POST_OPERATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1069481981
STATUS_RDBSS_RETRY_LOOKUP: win32more.Windows.Win32.Foundation.NTSTATUS = -1069481980
STATUS_BTH_ATT_INVALID_HANDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069416447
STATUS_BTH_ATT_READ_NOT_PERMITTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069416446
STATUS_BTH_ATT_WRITE_NOT_PERMITTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069416445
STATUS_BTH_ATT_INVALID_PDU: win32more.Windows.Win32.Foundation.NTSTATUS = -1069416444
STATUS_BTH_ATT_INSUFFICIENT_AUTHENTICATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1069416443
STATUS_BTH_ATT_REQUEST_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069416442
STATUS_BTH_ATT_INVALID_OFFSET: win32more.Windows.Win32.Foundation.NTSTATUS = -1069416441
STATUS_BTH_ATT_INSUFFICIENT_AUTHORIZATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1069416440
STATUS_BTH_ATT_PREPARE_QUEUE_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1069416439
STATUS_BTH_ATT_ATTRIBUTE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1069416438
STATUS_BTH_ATT_ATTRIBUTE_NOT_LONG: win32more.Windows.Win32.Foundation.NTSTATUS = -1069416437
STATUS_BTH_ATT_INSUFFICIENT_ENCRYPTION_KEY_SIZE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069416436
STATUS_BTH_ATT_INVALID_ATTRIBUTE_VALUE_LENGTH: win32more.Windows.Win32.Foundation.NTSTATUS = -1069416435
STATUS_BTH_ATT_UNLIKELY: win32more.Windows.Win32.Foundation.NTSTATUS = -1069416434
STATUS_BTH_ATT_INSUFFICIENT_ENCRYPTION: win32more.Windows.Win32.Foundation.NTSTATUS = -1069416433
STATUS_BTH_ATT_UNSUPPORTED_GROUP_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069416432
STATUS_BTH_ATT_INSUFFICIENT_RESOURCES: win32more.Windows.Win32.Foundation.NTSTATUS = -1069416431
STATUS_BTH_ATT_UNKNOWN_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1069412352
STATUS_SECUREBOOT_ROLLBACK_DETECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069350911
STATUS_SECUREBOOT_POLICY_VIOLATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1069350910
STATUS_SECUREBOOT_INVALID_POLICY: win32more.Windows.Win32.Foundation.NTSTATUS = -1069350909
STATUS_SECUREBOOT_POLICY_PUBLISHER_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1069350908
STATUS_SECUREBOOT_POLICY_NOT_SIGNED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069350907
STATUS_SECUREBOOT_NOT_ENABLED: win32more.Windows.Win32.Foundation.NTSTATUS = -2143092730
STATUS_SECUREBOOT_FILE_REPLACED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069350905
STATUS_SECUREBOOT_POLICY_NOT_AUTHORIZED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069350904
STATUS_SECUREBOOT_POLICY_UNKNOWN: win32more.Windows.Win32.Foundation.NTSTATUS = -1069350903
STATUS_SECUREBOOT_POLICY_MISSING_ANTIROLLBACKVERSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1069350902
STATUS_SECUREBOOT_PLATFORM_ID_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1069350901
STATUS_SECUREBOOT_POLICY_ROLLBACK_DETECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069350900
STATUS_SECUREBOOT_POLICY_UPGRADE_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1069350899
STATUS_SECUREBOOT_REQUIRED_POLICY_FILE_MISSING: win32more.Windows.Win32.Foundation.NTSTATUS = -1069350898
STATUS_SECUREBOOT_NOT_BASE_POLICY: win32more.Windows.Win32.Foundation.NTSTATUS = -1069350897
STATUS_SECUREBOOT_NOT_SUPPLEMENTAL_POLICY: win32more.Windows.Win32.Foundation.NTSTATUS = -1069350896
STATUS_PLATFORM_MANIFEST_NOT_AUTHORIZED: win32more.Windows.Win32.Foundation.NTSTATUS = -1058340863
STATUS_PLATFORM_MANIFEST_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1058340862
STATUS_PLATFORM_MANIFEST_FILE_NOT_AUTHORIZED: win32more.Windows.Win32.Foundation.NTSTATUS = -1058340861
STATUS_PLATFORM_MANIFEST_CATALOG_NOT_AUTHORIZED: win32more.Windows.Win32.Foundation.NTSTATUS = -1058340860
STATUS_PLATFORM_MANIFEST_BINARY_ID_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1058340859
STATUS_PLATFORM_MANIFEST_NOT_ACTIVE: win32more.Windows.Win32.Foundation.NTSTATUS = -1058340858
STATUS_PLATFORM_MANIFEST_NOT_SIGNED: win32more.Windows.Win32.Foundation.NTSTATUS = -1058340857
STATUS_SYSTEM_INTEGRITY_ROLLBACK_DETECTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1058471935
STATUS_SYSTEM_INTEGRITY_POLICY_VIOLATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1058471934
STATUS_SYSTEM_INTEGRITY_INVALID_POLICY: win32more.Windows.Win32.Foundation.NTSTATUS = -1058471933
STATUS_SYSTEM_INTEGRITY_POLICY_NOT_SIGNED: win32more.Windows.Win32.Foundation.NTSTATUS = -1058471932
STATUS_SYSTEM_INTEGRITY_TOO_MANY_POLICIES: win32more.Windows.Win32.Foundation.NTSTATUS = -1058471931
STATUS_SYSTEM_INTEGRITY_SUPPLEMENTAL_POLICY_NOT_AUTHORIZED: win32more.Windows.Win32.Foundation.NTSTATUS = -1058471930
STATUS_SYSTEM_INTEGRITY_REPUTATION_MALICIOUS: win32more.Windows.Win32.Foundation.NTSTATUS = -1058471929
STATUS_SYSTEM_INTEGRITY_REPUTATION_PUA: win32more.Windows.Win32.Foundation.NTSTATUS = -1058471928
STATUS_SYSTEM_INTEGRITY_REPUTATION_DANGEROUS_EXT: win32more.Windows.Win32.Foundation.NTSTATUS = -1058471927
STATUS_SYSTEM_INTEGRITY_REPUTATION_OFFLINE: win32more.Windows.Win32.Foundation.NTSTATUS = -1058471926
STATUS_SYSTEM_INTEGRITY_REPUTATION_UNFRIENDLY_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1058471925
STATUS_SYSTEM_INTEGRITY_REPUTATION_UNATTAINABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1058471924
STATUS_SYSTEM_INTEGRITY_REPUTATION_EXPLICIT_DENY_FILE: win32more.Windows.Win32.Foundation.NTSTATUS = -1058471923
STATUS_NO_APPLICABLE_APP_LICENSES_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1058406399
STATUS_CLIP_LICENSE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1058406398
STATUS_CLIP_DEVICE_LICENSE_MISSING: win32more.Windows.Win32.Foundation.NTSTATUS = -1058406397
STATUS_CLIP_LICENSE_INVALID_SIGNATURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1058406396
STATUS_CLIP_KEYHOLDER_LICENSE_MISSING_OR_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1058406395
STATUS_CLIP_LICENSE_EXPIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1058406394
STATUS_CLIP_LICENSE_SIGNED_BY_UNKNOWN_SOURCE: win32more.Windows.Win32.Foundation.NTSTATUS = -1058406393
STATUS_CLIP_LICENSE_NOT_SIGNED: win32more.Windows.Win32.Foundation.NTSTATUS = -1058406392
STATUS_CLIP_LICENSE_HARDWARE_ID_OUT_OF_TOLERANCE: win32more.Windows.Win32.Foundation.NTSTATUS = -1058406391
STATUS_CLIP_LICENSE_DEVICE_ID_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1058406390
STATUS_AUDIO_ENGINE_NODE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1069285375
STATUS_HDAUDIO_EMPTY_CONNECTION_LIST: win32more.Windows.Win32.Foundation.NTSTATUS = -1069285374
STATUS_HDAUDIO_CONNECTION_LIST_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069285373
STATUS_HDAUDIO_NO_LOGICAL_DEVICES_CREATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069285372
STATUS_HDAUDIO_NULL_LINKED_LIST_ENTRY: win32more.Windows.Win32.Foundation.NTSTATUS = -1069285371
STATUS_SPACES_REPAIRED: win32more.Windows.Win32.Foundation.NTSTATUS = 15138816
STATUS_SPACES_PAUSE: win32more.Windows.Win32.Foundation.NTSTATUS = 15138817
STATUS_SPACES_COMPLETE: win32more.Windows.Win32.Foundation.NTSTATUS = 15138818
STATUS_SPACES_REDIRECT: win32more.Windows.Win32.Foundation.NTSTATUS = 15138819
STATUS_SPACES_FAULT_DOMAIN_TYPE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1058603007
STATUS_SPACES_RESILIENCY_TYPE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1058603005
STATUS_SPACES_DRIVE_SECTOR_SIZE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1058603004
STATUS_SPACES_DRIVE_REDUNDANCY_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1058603002
STATUS_SPACES_NUMBER_OF_DATA_COPIES_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1058603001
STATUS_SPACES_INTERLEAVE_LENGTH_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602999
STATUS_SPACES_NUMBER_OF_COLUMNS_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602998
STATUS_SPACES_NOT_ENOUGH_DRIVES: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602997
STATUS_SPACES_EXTENDED_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602996
STATUS_SPACES_PROVISIONING_TYPE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602995
STATUS_SPACES_ALLOCATION_SIZE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602994
STATUS_SPACES_ENCLOSURE_AWARE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602993
STATUS_SPACES_WRITE_CACHE_SIZE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602992
STATUS_SPACES_NUMBER_OF_GROUPS_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602991
STATUS_SPACES_DRIVE_OPERATIONAL_STATE_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602990
STATUS_SPACES_UPDATE_COLUMN_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602989
STATUS_SPACES_MAP_REQUIRED: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602988
STATUS_SPACES_UNSUPPORTED_VERSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602987
STATUS_SPACES_CORRUPT_METADATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602986
STATUS_SPACES_DRT_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602985
STATUS_SPACES_INCONSISTENCY: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602984
STATUS_SPACES_LOG_NOT_READY: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602983
STATUS_SPACES_NO_REDUNDANCY: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602982
STATUS_SPACES_DRIVE_NOT_READY: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602981
STATUS_SPACES_DRIVE_SPLIT: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602980
STATUS_SPACES_DRIVE_LOST_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602979
STATUS_SPACES_ENTRY_INCOMPLETE: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602978
STATUS_SPACES_ENTRY_INVALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602977
STATUS_SPACES_MARK_DIRTY: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602976
STATUS_SPACES_PD_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602975
STATUS_SPACES_PD_LENGTH_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602974
STATUS_SPACES_PD_UNSUPPORTED_VERSION: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602973
STATUS_SPACES_PD_INVALID_DATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602972
STATUS_SPACES_FLUSH_METADATA: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602971
STATUS_SPACES_CACHE_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602970
STATUS_SPACES_REPAIR_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1058602969
STATUS_VOLSNAP_BOOTFILE_NOT_VALID: win32more.Windows.Win32.Foundation.NTSTATUS = -1068498941
STATUS_VOLSNAP_ACTIVATION_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1068498940
STATUS_VOLSNAP_NO_BYPASSIO_WITH_SNAPSHOT: win32more.Windows.Win32.Foundation.NTSTATUS = -1068498939
STATUS_IO_PREEMPTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1068433407
STATUS_SVHDX_ERROR_STORED: win32more.Windows.Win32.Foundation.NTSTATUS = -1067712512
STATUS_SVHDX_ERROR_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1067647232
STATUS_SVHDX_UNIT_ATTENTION_AVAILABLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1067647231
STATUS_SVHDX_UNIT_ATTENTION_CAPACITY_DATA_CHANGED: win32more.Windows.Win32.Foundation.NTSTATUS = -1067647230
STATUS_SVHDX_UNIT_ATTENTION_RESERVATIONS_PREEMPTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1067647229
STATUS_SVHDX_UNIT_ATTENTION_RESERVATIONS_RELEASED: win32more.Windows.Win32.Foundation.NTSTATUS = -1067647228
STATUS_SVHDX_UNIT_ATTENTION_REGISTRATIONS_PREEMPTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1067647227
STATUS_SVHDX_UNIT_ATTENTION_OPERATING_DEFINITION_CHANGED: win32more.Windows.Win32.Foundation.NTSTATUS = -1067647226
STATUS_SVHDX_RESERVATION_CONFLICT: win32more.Windows.Win32.Foundation.NTSTATUS = -1067647225
STATUS_SVHDX_WRONG_FILE_TYPE: win32more.Windows.Win32.Foundation.NTSTATUS = -1067647224
STATUS_SVHDX_VERSION_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1067647223
STATUS_VHD_SHARED: win32more.Windows.Win32.Foundation.NTSTATUS = -1067647222
STATUS_SVHDX_NO_INITIATOR: win32more.Windows.Win32.Foundation.NTSTATUS = -1067647221
STATUS_VHDSET_BACKING_STORAGE_NOT_FOUND: win32more.Windows.Win32.Foundation.NTSTATUS = -1067647220
STATUS_SMB_NO_PREAUTH_INTEGRITY_HASH_OVERLAP: win32more.Windows.Win32.Foundation.NTSTATUS = -1067646976
STATUS_SMB_BAD_CLUSTER_DIALECT: win32more.Windows.Win32.Foundation.NTSTATUS = -1067646975
STATUS_SMB_GUEST_LOGON_BLOCKED: win32more.Windows.Win32.Foundation.NTSTATUS = -1067646974
STATUS_SMB_NO_SIGNING_ALGORITHM_OVERLAP: win32more.Windows.Win32.Foundation.NTSTATUS = -1067646973
STATUS_NETWORK_AUTHENTICATION_PROMPT_CANCELED: win32more.Windows.Win32.Foundation.NTSTATUS = -1067646972
STATUS_SECCORE_INVALID_COMMAND: win32more.Windows.Win32.Foundation.NTSTATUS = -1058537472
STATUS_VSM_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069219840
STATUS_VSM_DMA_PROTECTION_NOT_IN_USE: win32more.Windows.Win32.Foundation.NTSTATUS = -1069219839
STATUS_APPEXEC_CONDITION_NOT_SATISFIED: win32more.Windows.Win32.Foundation.NTSTATUS = -1058275328
STATUS_APPEXEC_HANDLE_INVALIDATED: win32more.Windows.Win32.Foundation.NTSTATUS = -1058275327
STATUS_APPEXEC_INVALID_HOST_GENERATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1058275326
STATUS_APPEXEC_UNEXPECTED_PROCESS_REGISTRATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1058275325
STATUS_APPEXEC_INVALID_HOST_STATE: win32more.Windows.Win32.Foundation.NTSTATUS = -1058275324
STATUS_APPEXEC_NO_DONOR: win32more.Windows.Win32.Foundation.NTSTATUS = -1058275323
STATUS_APPEXEC_HOST_ID_MISMATCH: win32more.Windows.Win32.Foundation.NTSTATUS = -1058275322
STATUS_APPEXEC_UNKNOWN_USER: win32more.Windows.Win32.Foundation.NTSTATUS = -1058275321
STATUS_APPEXEC_APP_COMPAT_BLOCK: win32more.Windows.Win32.Foundation.NTSTATUS = -1058275320
STATUS_APPEXEC_CALLER_WAIT_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1058275319
STATUS_APPEXEC_CALLER_WAIT_TIMEOUT_TERMINATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1058275318
STATUS_APPEXEC_CALLER_WAIT_TIMEOUT_LICENSING: win32more.Windows.Win32.Foundation.NTSTATUS = -1058275317
STATUS_APPEXEC_CALLER_WAIT_TIMEOUT_RESOURCES: win32more.Windows.Win32.Foundation.NTSTATUS = -1058275316
STATUS_QUIC_HANDSHAKE_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071382528
STATUS_QUIC_VER_NEG_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071382527
STATUS_QUIC_USER_CANCELED: win32more.Windows.Win32.Foundation.NTSTATUS = -1071382526
STATUS_QUIC_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS = -1071382525
STATUS_QUIC_PROTOCOL_VIOLATION: win32more.Windows.Win32.Foundation.NTSTATUS = -1071382524
STATUS_QUIC_CONNECTION_IDLE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071382523
STATUS_QUIC_CONNECTION_TIMEOUT: win32more.Windows.Win32.Foundation.NTSTATUS = -1071382522
STATUS_QUIC_ALPN_NEG_FAILURE: win32more.Windows.Win32.Foundation.NTSTATUS = -1071382521
STATUS_IORING_REQUIRED_FLAG_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069154303
STATUS_IORING_SUBMISSION_QUEUE_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1069154302
STATUS_IORING_VERSION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.NTSTATUS = -1069154301
STATUS_IORING_SUBMISSION_QUEUE_TOO_BIG: win32more.Windows.Win32.Foundation.NTSTATUS = -1069154300
STATUS_IORING_COMPLETION_QUEUE_TOO_BIG: win32more.Windows.Win32.Foundation.NTSTATUS = -1069154299
STATUS_IORING_SUBMIT_IN_PROGRESS: win32more.Windows.Win32.Foundation.NTSTATUS = -1069154298
STATUS_IORING_CORRUPT: win32more.Windows.Win32.Foundation.NTSTATUS = -1069154297
STATUS_IORING_COMPLETION_QUEUE_TOO_FULL: win32more.Windows.Win32.Foundation.NTSTATUS = -1069154296
WINVER: UInt32 = 1280
APP_LOCAL_DEVICE_ID_SIZE: UInt32 = 32
SEC_E_OK: win32more.Windows.Win32.Foundation.HRESULT = 0
RPC_X_NO_MORE_ENTRIES: Int32 = 1772
RPC_X_SS_CHAR_TRANS_OPEN_FAIL: Int32 = 1773
RPC_X_SS_CHAR_TRANS_SHORT_FILE: Int32 = 1774
RPC_X_SS_IN_NULL_CONTEXT: Int32 = 1775
RPC_X_SS_CONTEXT_DAMAGED: Int32 = 1777
RPC_X_SS_HANDLES_MISMATCH: Int32 = 1778
RPC_X_SS_CANNOT_GET_CALL_HANDLE: Int32 = 1779
RPC_X_NULL_REF_POINTER: Int32 = 1780
RPC_X_ENUM_VALUE_OUT_OF_RANGE: Int32 = 1781
RPC_X_BYTE_COUNT_TOO_SMALL: Int32 = 1782
RPC_X_BAD_STUB_DATA: Int32 = 1783
RPC_X_INVALID_ES_ACTION: Int32 = 1827
RPC_X_WRONG_ES_VERSION: Int32 = 1828
RPC_X_WRONG_STUB_VERSION: Int32 = 1829
RPC_X_INVALID_PIPE_OBJECT: Int32 = 1830
RPC_X_WRONG_PIPE_ORDER: Int32 = 1831
RPC_X_WRONG_PIPE_VERSION: Int32 = 1832
OR_INVALID_OXID: Int32 = 1910
OR_INVALID_OID: Int32 = 1911
OR_INVALID_SET: Int32 = 1912
RPC_X_PIPE_CLOSED: Int32 = 1916
RPC_X_PIPE_DISCIPLINE_ERROR: Int32 = 1917
RPC_X_PIPE_EMPTY: Int32 = 1918
PEERDIST_ERROR_CONTENTINFO_VERSION_UNSUPPORTED: Int32 = 4050
PEERDIST_ERROR_CANNOT_PARSE_CONTENTINFO: Int32 = 4051
PEERDIST_ERROR_MISSING_DATA: Int32 = 4052
PEERDIST_ERROR_NO_MORE: Int32 = 4053
PEERDIST_ERROR_NOT_INITIALIZED: Int32 = 4054
PEERDIST_ERROR_ALREADY_INITIALIZED: Int32 = 4055
PEERDIST_ERROR_SHUTDOWN_IN_PROGRESS: Int32 = 4056
PEERDIST_ERROR_INVALIDATED: Int32 = 4057
PEERDIST_ERROR_ALREADY_EXISTS: Int32 = 4058
PEERDIST_ERROR_OPERATION_NOTFOUND: Int32 = 4059
PEERDIST_ERROR_ALREADY_COMPLETED: Int32 = 4060
PEERDIST_ERROR_OUT_OF_BOUNDS: Int32 = 4061
PEERDIST_ERROR_VERSION_UNSUPPORTED: Int32 = 4062
PEERDIST_ERROR_INVALID_CONFIGURATION: Int32 = 4063
PEERDIST_ERROR_NOT_LICENSED: Int32 = 4064
PEERDIST_ERROR_SERVICE_UNAVAILABLE: Int32 = 4065
PEERDIST_ERROR_TRUST_FAILURE: Int32 = 4066
SCHED_E_SERVICE_NOT_LOCALSYSTEM: Int32 = 6200
FRS_ERR_INVALID_API_SEQUENCE: Int32 = 8001
FRS_ERR_STARTING_SERVICE: Int32 = 8002
FRS_ERR_STOPPING_SERVICE: Int32 = 8003
FRS_ERR_INTERNAL_API: Int32 = 8004
FRS_ERR_INTERNAL: Int32 = 8005
FRS_ERR_SERVICE_COMM: Int32 = 8006
FRS_ERR_INSUFFICIENT_PRIV: Int32 = 8007
FRS_ERR_AUTHENTICATION: Int32 = 8008
FRS_ERR_PARENT_INSUFFICIENT_PRIV: Int32 = 8009
FRS_ERR_PARENT_AUTHENTICATION: Int32 = 8010
FRS_ERR_CHILD_TO_PARENT_COMM: Int32 = 8011
FRS_ERR_PARENT_TO_CHILD_COMM: Int32 = 8012
FRS_ERR_SYSVOL_POPULATE: Int32 = 8013
FRS_ERR_SYSVOL_POPULATE_TIMEOUT: Int32 = 8014
FRS_ERR_SYSVOL_IS_BUSY: Int32 = 8015
FRS_ERR_SYSVOL_DEMOTE: Int32 = 8016
FRS_ERR_INVALID_SERVICE_PARAMETER: Int32 = 8017
DNS_INFO_NO_RECORDS: Int32 = 9501
DNS_REQUEST_PENDING: Int32 = 9506
DNS_STATUS_FQDN: Int32 = 9557
DNS_STATUS_DOTTED_NAME: Int32 = 9558
DNS_STATUS_SINGLE_PART_NAME: Int32 = 9559
DNS_WARNING_PTR_CREATE_FAILED: Int32 = 9715
DNS_WARNING_DOMAIN_UNDELETED: Int32 = 9716
DNS_INFO_AXFR_COMPLETE: Int32 = 9751
DNS_INFO_ADDED_LOCAL_WINS: Int32 = 9753
DNS_STATUS_CONTINUE_NEEDED: Int32 = 9801
WARNING_IPSEC_MM_POLICY_PRUNED: Int32 = 13024
WARNING_IPSEC_QM_POLICY_PRUNED: Int32 = 13025
STORE_ERROR_UNLICENSED: Int32 = 15861
STORE_ERROR_UNLICENSED_USER: Int32 = 15862
STORE_ERROR_PENDING_COM_TRANSACTION: Int32 = 15863
STORE_ERROR_LICENSE_REVOKED: Int32 = 15864
SEVERITY_SUCCESS: UInt32 = 0
SEVERITY_ERROR: UInt32 = 1
NOERROR: UInt32 = 0
E_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2147418113
E_NOINTERFACE: win32more.Windows.Win32.Foundation.HRESULT = -2147467262
E_POINTER: win32more.Windows.Win32.Foundation.HRESULT = -2147467261
E_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2147024890
E_ABORT: win32more.Windows.Win32.Foundation.HRESULT = -2147467260
E_ACCESSDENIED: win32more.Windows.Win32.Foundation.HRESULT = -2147024891
E_BOUNDS: win32more.Windows.Win32.Foundation.HRESULT = -2147483637
E_CHANGED_STATE: win32more.Windows.Win32.Foundation.HRESULT = -2147483636
E_ILLEGAL_STATE_CHANGE: win32more.Windows.Win32.Foundation.HRESULT = -2147483635
E_ILLEGAL_METHOD_CALL: win32more.Windows.Win32.Foundation.HRESULT = -2147483634
RO_E_METADATA_NAME_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147483633
RO_E_METADATA_NAME_IS_NAMESPACE: win32more.Windows.Win32.Foundation.HRESULT = -2147483632
RO_E_METADATA_INVALID_TYPE_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2147483631
RO_E_INVALID_METADATA_FILE: win32more.Windows.Win32.Foundation.HRESULT = -2147483630
RO_E_CLOSED: win32more.Windows.Win32.Foundation.HRESULT = -2147483629
RO_E_EXCLUSIVE_WRITE: win32more.Windows.Win32.Foundation.HRESULT = -2147483628
RO_E_CHANGE_NOTIFICATION_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2147483627
RO_E_ERROR_STRING_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147483626
E_STRING_NOT_NULL_TERMINATED: win32more.Windows.Win32.Foundation.HRESULT = -2147483625
E_ILLEGAL_DELEGATE_ASSIGNMENT: win32more.Windows.Win32.Foundation.HRESULT = -2147483624
E_ASYNC_OPERATION_NOT_STARTED: win32more.Windows.Win32.Foundation.HRESULT = -2147483623
E_APPLICATION_EXITING: win32more.Windows.Win32.Foundation.HRESULT = -2147483622
E_APPLICATION_VIEW_EXITING: win32more.Windows.Win32.Foundation.HRESULT = -2147483621
RO_E_MUST_BE_AGILE: win32more.Windows.Win32.Foundation.HRESULT = -2147483620
RO_E_UNSUPPORTED_FROM_MTA: win32more.Windows.Win32.Foundation.HRESULT = -2147483619
RO_E_COMMITTED: win32more.Windows.Win32.Foundation.HRESULT = -2147483618
RO_E_BLOCKED_CROSS_ASTA_CALL: win32more.Windows.Win32.Foundation.HRESULT = -2147483617
RO_E_CANNOT_ACTIVATE_FULL_TRUST_SERVER: win32more.Windows.Win32.Foundation.HRESULT = -2147483616
RO_E_CANNOT_ACTIVATE_UNIVERSAL_APPLICATION_SERVER: win32more.Windows.Win32.Foundation.HRESULT = -2147483615
CO_E_INIT_TLS: win32more.Windows.Win32.Foundation.HRESULT = -2147467258
CO_E_INIT_SHARED_ALLOCATOR: win32more.Windows.Win32.Foundation.HRESULT = -2147467257
CO_E_INIT_MEMORY_ALLOCATOR: win32more.Windows.Win32.Foundation.HRESULT = -2147467256
CO_E_INIT_CLASS_CACHE: win32more.Windows.Win32.Foundation.HRESULT = -2147467255
CO_E_INIT_RPC_CHANNEL: win32more.Windows.Win32.Foundation.HRESULT = -2147467254
CO_E_INIT_TLS_SET_CHANNEL_CONTROL: win32more.Windows.Win32.Foundation.HRESULT = -2147467253
CO_E_INIT_TLS_CHANNEL_CONTROL: win32more.Windows.Win32.Foundation.HRESULT = -2147467252
CO_E_INIT_UNACCEPTED_USER_ALLOCATOR: win32more.Windows.Win32.Foundation.HRESULT = -2147467251
CO_E_INIT_SCM_MUTEX_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2147467250
CO_E_INIT_SCM_FILE_MAPPING_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2147467249
CO_E_INIT_SCM_MAP_VIEW_OF_FILE: win32more.Windows.Win32.Foundation.HRESULT = -2147467248
CO_E_INIT_SCM_EXEC_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2147467247
CO_E_INIT_ONLY_SINGLE_THREADED: win32more.Windows.Win32.Foundation.HRESULT = -2147467246
CO_E_CANT_REMOTE: win32more.Windows.Win32.Foundation.HRESULT = -2147467245
CO_E_BAD_SERVER_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2147467244
CO_E_WRONG_SERVER_IDENTITY: win32more.Windows.Win32.Foundation.HRESULT = -2147467243
CO_E_OLE1DDE_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2147467242
CO_E_RUNAS_SYNTAX: win32more.Windows.Win32.Foundation.HRESULT = -2147467241
CO_E_CREATEPROCESS_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2147467240
CO_E_RUNAS_CREATEPROCESS_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2147467239
CO_E_RUNAS_LOGON_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2147467238
CO_E_LAUNCH_PERMSSION_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2147467237
CO_E_START_SERVICE_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2147467236
CO_E_REMOTE_COMMUNICATION_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2147467235
CO_E_SERVER_START_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2147467234
CO_E_CLSREG_INCONSISTENT: win32more.Windows.Win32.Foundation.HRESULT = -2147467233
CO_E_IIDREG_INCONSISTENT: win32more.Windows.Win32.Foundation.HRESULT = -2147467232
CO_E_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147467231
CO_E_RELOAD_DLL: win32more.Windows.Win32.Foundation.HRESULT = -2147467230
CO_E_MSI_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147467229
CO_E_ATTEMPT_TO_CREATE_OUTSIDE_CLIENT_CONTEXT: win32more.Windows.Win32.Foundation.HRESULT = -2147467228
CO_E_SERVER_PAUSED: win32more.Windows.Win32.Foundation.HRESULT = -2147467227
CO_E_SERVER_NOT_PAUSED: win32more.Windows.Win32.Foundation.HRESULT = -2147467226
CO_E_CLASS_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2147467225
CO_E_CLRNOTAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147467224
CO_E_ASYNC_WORK_REJECTED: win32more.Windows.Win32.Foundation.HRESULT = -2147467223
CO_E_SERVER_INIT_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2147467222
CO_E_NO_SECCTX_IN_ACTIVATE: win32more.Windows.Win32.Foundation.HRESULT = -2147467221
CO_E_TRACKER_CONFIG: win32more.Windows.Win32.Foundation.HRESULT = -2147467216
CO_E_THREADPOOL_CONFIG: win32more.Windows.Win32.Foundation.HRESULT = -2147467215
CO_E_SXS_CONFIG: win32more.Windows.Win32.Foundation.HRESULT = -2147467214
CO_E_MALFORMED_SPN: win32more.Windows.Win32.Foundation.HRESULT = -2147467213
CO_E_UNREVOKED_REGISTRATION_ON_APARTMENT_SHUTDOWN: win32more.Windows.Win32.Foundation.HRESULT = -2147467212
CO_E_PREMATURE_STUB_RUNDOWN: win32more.Windows.Win32.Foundation.HRESULT = -2147467211
S_OK: win32more.Windows.Win32.Foundation.HRESULT = 0
S_FALSE: win32more.Windows.Win32.Foundation.HRESULT = 1
OLE_E_FIRST: win32more.Windows.Win32.Foundation.HRESULT = -2147221504
OLE_E_LAST: win32more.Windows.Win32.Foundation.HRESULT = -2147221249
OLE_S_FIRST: win32more.Windows.Win32.Foundation.HRESULT = 262144
OLE_S_LAST: win32more.Windows.Win32.Foundation.HRESULT = 262399
OLE_E_OLEVERB: win32more.Windows.Win32.Foundation.HRESULT = -2147221504
OLE_E_ADVF: win32more.Windows.Win32.Foundation.HRESULT = -2147221503
OLE_E_ENUM_NOMORE: win32more.Windows.Win32.Foundation.HRESULT = -2147221502
OLE_E_ADVISENOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147221501
OLE_E_NOCONNECTION: win32more.Windows.Win32.Foundation.HRESULT = -2147221500
OLE_E_NOTRUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2147221499
OLE_E_NOCACHE: win32more.Windows.Win32.Foundation.HRESULT = -2147221498
OLE_E_BLANK: win32more.Windows.Win32.Foundation.HRESULT = -2147221497
OLE_E_CLASSDIFF: win32more.Windows.Win32.Foundation.HRESULT = -2147221496
OLE_E_CANT_GETMONIKER: win32more.Windows.Win32.Foundation.HRESULT = -2147221495
OLE_E_CANT_BINDTOSOURCE: win32more.Windows.Win32.Foundation.HRESULT = -2147221494
OLE_E_STATIC: win32more.Windows.Win32.Foundation.HRESULT = -2147221493
OLE_E_PROMPTSAVECANCELLED: win32more.Windows.Win32.Foundation.HRESULT = -2147221492
OLE_E_INVALIDRECT: win32more.Windows.Win32.Foundation.HRESULT = -2147221491
OLE_E_WRONGCOMPOBJ: win32more.Windows.Win32.Foundation.HRESULT = -2147221490
OLE_E_INVALIDHWND: win32more.Windows.Win32.Foundation.HRESULT = -2147221489
OLE_E_NOT_INPLACEACTIVE: win32more.Windows.Win32.Foundation.HRESULT = -2147221488
OLE_E_CANTCONVERT: win32more.Windows.Win32.Foundation.HRESULT = -2147221487
OLE_E_NOSTORAGE: win32more.Windows.Win32.Foundation.HRESULT = -2147221486
DV_E_FORMATETC: win32more.Windows.Win32.Foundation.HRESULT = -2147221404
DV_E_DVTARGETDEVICE: win32more.Windows.Win32.Foundation.HRESULT = -2147221403
DV_E_STGMEDIUM: win32more.Windows.Win32.Foundation.HRESULT = -2147221402
DV_E_STATDATA: win32more.Windows.Win32.Foundation.HRESULT = -2147221401
DV_E_LINDEX: win32more.Windows.Win32.Foundation.HRESULT = -2147221400
DV_E_TYMED: win32more.Windows.Win32.Foundation.HRESULT = -2147221399
DV_E_CLIPFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2147221398
DV_E_DVASPECT: win32more.Windows.Win32.Foundation.HRESULT = -2147221397
DV_E_DVTARGETDEVICE_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2147221396
DV_E_NOIVIEWOBJECT: win32more.Windows.Win32.Foundation.HRESULT = -2147221395
DRAGDROP_E_FIRST: Int32 = -2147221248
DRAGDROP_E_LAST: Int32 = -2147221233
DRAGDROP_S_FIRST: Int32 = 262400
DRAGDROP_S_LAST: Int32 = 262415
DRAGDROP_E_NOTREGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2147221248
DRAGDROP_E_ALREADYREGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2147221247
DRAGDROP_E_INVALIDHWND: win32more.Windows.Win32.Foundation.HRESULT = -2147221246
DRAGDROP_E_CONCURRENT_DRAG_ATTEMPTED: win32more.Windows.Win32.Foundation.HRESULT = -2147221245
CLASSFACTORY_E_FIRST: Int32 = -2147221232
CLASSFACTORY_E_LAST: Int32 = -2147221217
CLASSFACTORY_S_FIRST: Int32 = 262416
CLASSFACTORY_S_LAST: Int32 = 262431
CLASS_E_NOAGGREGATION: win32more.Windows.Win32.Foundation.HRESULT = -2147221232
CLASS_E_CLASSNOTAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147221231
CLASS_E_NOTLICENSED: win32more.Windows.Win32.Foundation.HRESULT = -2147221230
MARSHAL_E_FIRST: Int32 = -2147221216
MARSHAL_E_LAST: Int32 = -2147221201
MARSHAL_S_FIRST: Int32 = 262432
MARSHAL_S_LAST: Int32 = 262447
DATA_E_FIRST: Int32 = -2147221200
DATA_E_LAST: Int32 = -2147221185
DATA_S_FIRST: Int32 = 262448
DATA_S_LAST: Int32 = 262463
VIEW_E_FIRST: Int32 = -2147221184
VIEW_E_LAST: Int32 = -2147221169
VIEW_S_FIRST: Int32 = 262464
VIEW_S_LAST: Int32 = 262479
VIEW_E_DRAW: win32more.Windows.Win32.Foundation.HRESULT = -2147221184
REGDB_E_FIRST: Int32 = -2147221168
REGDB_E_LAST: Int32 = -2147221153
REGDB_S_FIRST: Int32 = 262480
REGDB_S_LAST: Int32 = 262495
REGDB_E_READREGDB: win32more.Windows.Win32.Foundation.HRESULT = -2147221168
REGDB_E_WRITEREGDB: win32more.Windows.Win32.Foundation.HRESULT = -2147221167
REGDB_E_KEYMISSING: win32more.Windows.Win32.Foundation.HRESULT = -2147221166
REGDB_E_INVALIDVALUE: win32more.Windows.Win32.Foundation.HRESULT = -2147221165
REGDB_E_CLASSNOTREG: win32more.Windows.Win32.Foundation.HRESULT = -2147221164
REGDB_E_IIDNOTREG: win32more.Windows.Win32.Foundation.HRESULT = -2147221163
REGDB_E_BADTHREADINGMODEL: win32more.Windows.Win32.Foundation.HRESULT = -2147221162
REGDB_E_PACKAGEPOLICYVIOLATION: win32more.Windows.Win32.Foundation.HRESULT = -2147221161
CAT_E_FIRST: Int32 = -2147221152
CAT_E_LAST: Int32 = -2147221151
CAT_E_CATIDNOEXIST: win32more.Windows.Win32.Foundation.HRESULT = -2147221152
CAT_E_NODESCRIPTION: win32more.Windows.Win32.Foundation.HRESULT = -2147221151
CS_E_FIRST: Int32 = -2147221148
CS_E_LAST: Int32 = -2147221137
CS_E_PACKAGE_NOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147221148
CS_E_NOT_DELETABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147221147
CS_E_CLASS_NOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147221146
CS_E_INVALID_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2147221145
CS_E_NO_CLASSSTORE: win32more.Windows.Win32.Foundation.HRESULT = -2147221144
CS_E_OBJECT_NOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147221143
CS_E_OBJECT_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2147221142
CS_E_INVALID_PATH: win32more.Windows.Win32.Foundation.HRESULT = -2147221141
CS_E_NETWORK_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147221140
CS_E_ADMIN_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2147221139
CS_E_SCHEMA_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2147221138
CS_E_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147221137
CACHE_E_FIRST: Int32 = -2147221136
CACHE_E_LAST: Int32 = -2147221121
CACHE_S_FIRST: Int32 = 262512
CACHE_S_LAST: Int32 = 262527
CACHE_E_NOCACHE_UPDATED: win32more.Windows.Win32.Foundation.HRESULT = -2147221136
OLEOBJ_E_FIRST: Int32 = -2147221120
OLEOBJ_E_LAST: Int32 = -2147221105
OLEOBJ_S_FIRST: Int32 = 262528
OLEOBJ_S_LAST: Int32 = 262543
OLEOBJ_E_NOVERBS: win32more.Windows.Win32.Foundation.HRESULT = -2147221120
OLEOBJ_E_INVALIDVERB: win32more.Windows.Win32.Foundation.HRESULT = -2147221119
CLIENTSITE_E_FIRST: Int32 = -2147221104
CLIENTSITE_E_LAST: Int32 = -2147221089
CLIENTSITE_S_FIRST: Int32 = 262544
CLIENTSITE_S_LAST: Int32 = 262559
INPLACE_E_NOTUNDOABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147221088
INPLACE_E_NOTOOLSPACE: win32more.Windows.Win32.Foundation.HRESULT = -2147221087
INPLACE_E_FIRST: Int32 = -2147221088
INPLACE_E_LAST: Int32 = -2147221073
INPLACE_S_FIRST: Int32 = 262560
INPLACE_S_LAST: Int32 = 262575
ENUM_E_FIRST: Int32 = -2147221072
ENUM_E_LAST: Int32 = -2147221057
ENUM_S_FIRST: Int32 = 262576
ENUM_S_LAST: Int32 = 262591
CONVERT10_E_FIRST: Int32 = -2147221056
CONVERT10_E_LAST: Int32 = -2147221041
CONVERT10_S_FIRST: Int32 = 262592
CONVERT10_S_LAST: Int32 = 262607
CONVERT10_E_OLESTREAM_GET: win32more.Windows.Win32.Foundation.HRESULT = -2147221056
CONVERT10_E_OLESTREAM_PUT: win32more.Windows.Win32.Foundation.HRESULT = -2147221055
CONVERT10_E_OLESTREAM_FMT: win32more.Windows.Win32.Foundation.HRESULT = -2147221054
CONVERT10_E_OLESTREAM_BITMAP_TO_DIB: win32more.Windows.Win32.Foundation.HRESULT = -2147221053
CONVERT10_E_STG_FMT: win32more.Windows.Win32.Foundation.HRESULT = -2147221052
CONVERT10_E_STG_NO_STD_STREAM: win32more.Windows.Win32.Foundation.HRESULT = -2147221051
CONVERT10_E_STG_DIB_TO_BITMAP: win32more.Windows.Win32.Foundation.HRESULT = -2147221050
CONVERT10_E_OLELINK_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2147221049
CLIPBRD_E_FIRST: Int32 = -2147221040
CLIPBRD_E_LAST: Int32 = -2147221025
CLIPBRD_S_FIRST: Int32 = 262608
CLIPBRD_S_LAST: Int32 = 262623
CLIPBRD_E_CANT_OPEN: win32more.Windows.Win32.Foundation.HRESULT = -2147221040
CLIPBRD_E_CANT_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = -2147221039
CLIPBRD_E_CANT_SET: win32more.Windows.Win32.Foundation.HRESULT = -2147221038
CLIPBRD_E_BAD_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2147221037
CLIPBRD_E_CANT_CLOSE: win32more.Windows.Win32.Foundation.HRESULT = -2147221036
MK_E_FIRST: Int32 = -2147221024
MK_E_LAST: Int32 = -2147221009
MK_S_FIRST: Int32 = 262624
MK_S_LAST: Int32 = 262639
MK_E_CONNECTMANUALLY: win32more.Windows.Win32.Foundation.HRESULT = -2147221024
MK_E_EXCEEDEDDEADLINE: win32more.Windows.Win32.Foundation.HRESULT = -2147221023
MK_E_NEEDGENERIC: win32more.Windows.Win32.Foundation.HRESULT = -2147221022
MK_E_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147221021
MK_E_SYNTAX: win32more.Windows.Win32.Foundation.HRESULT = -2147221020
MK_E_NOOBJECT: win32more.Windows.Win32.Foundation.HRESULT = -2147221019
MK_E_INVALIDEXTENSION: win32more.Windows.Win32.Foundation.HRESULT = -2147221018
MK_E_INTERMEDIATEINTERFACENOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147221017
MK_E_NOTBINDABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147221016
MK_E_NOTBOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147221015
MK_E_CANTOPENFILE: win32more.Windows.Win32.Foundation.HRESULT = -2147221014
MK_E_MUSTBOTHERUSER: win32more.Windows.Win32.Foundation.HRESULT = -2147221013
MK_E_NOINVERSE: win32more.Windows.Win32.Foundation.HRESULT = -2147221012
MK_E_NOSTORAGE: win32more.Windows.Win32.Foundation.HRESULT = -2147221011
MK_E_NOPREFIX: win32more.Windows.Win32.Foundation.HRESULT = -2147221010
MK_E_ENUMERATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147221009
CO_E_FIRST: Int32 = -2147221008
CO_E_LAST: Int32 = -2147220993
CO_S_FIRST: Int32 = 262640
CO_S_LAST: Int32 = 262655
CO_E_ALREADYINITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2147221007
CO_E_CANTDETERMINECLASS: win32more.Windows.Win32.Foundation.HRESULT = -2147221006
CO_E_CLASSSTRING: win32more.Windows.Win32.Foundation.HRESULT = -2147221005
CO_E_IIDSTRING: win32more.Windows.Win32.Foundation.HRESULT = -2147221004
CO_E_APPNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147221003
CO_E_APPSINGLEUSE: win32more.Windows.Win32.Foundation.HRESULT = -2147221002
CO_E_ERRORINAPP: win32more.Windows.Win32.Foundation.HRESULT = -2147221001
CO_E_DLLNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147221000
CO_E_ERRORINDLL: win32more.Windows.Win32.Foundation.HRESULT = -2147220999
CO_E_WRONGOSFORAPP: win32more.Windows.Win32.Foundation.HRESULT = -2147220998
CO_E_OBJNOTREG: win32more.Windows.Win32.Foundation.HRESULT = -2147220997
CO_E_OBJISREG: win32more.Windows.Win32.Foundation.HRESULT = -2147220996
CO_E_OBJNOTCONNECTED: win32more.Windows.Win32.Foundation.HRESULT = -2147220995
CO_E_APPDIDNTREG: win32more.Windows.Win32.Foundation.HRESULT = -2147220994
CO_E_RELEASED: win32more.Windows.Win32.Foundation.HRESULT = -2147220993
EVENT_E_FIRST: Int32 = -2147220992
EVENT_E_LAST: Int32 = -2147220961
EVENT_S_FIRST: Int32 = 262656
EVENT_S_LAST: Int32 = 262687
EVENT_S_SOME_SUBSCRIBERS_FAILED: win32more.Windows.Win32.Foundation.HRESULT = 262656
EVENT_E_ALL_SUBSCRIBERS_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147220991
EVENT_S_NOSUBSCRIBERS: win32more.Windows.Win32.Foundation.HRESULT = 262658
EVENT_E_QUERYSYNTAX: win32more.Windows.Win32.Foundation.HRESULT = -2147220989
EVENT_E_QUERYFIELD: win32more.Windows.Win32.Foundation.HRESULT = -2147220988
EVENT_E_INTERNALEXCEPTION: win32more.Windows.Win32.Foundation.HRESULT = -2147220987
EVENT_E_INTERNALERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147220986
EVENT_E_INVALID_PER_USER_SID: win32more.Windows.Win32.Foundation.HRESULT = -2147220985
EVENT_E_USER_EXCEPTION: win32more.Windows.Win32.Foundation.HRESULT = -2147220984
EVENT_E_TOO_MANY_METHODS: win32more.Windows.Win32.Foundation.HRESULT = -2147220983
EVENT_E_MISSING_EVENTCLASS: win32more.Windows.Win32.Foundation.HRESULT = -2147220982
EVENT_E_NOT_ALL_REMOVED: win32more.Windows.Win32.Foundation.HRESULT = -2147220981
EVENT_E_COMPLUS_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -2147220980
EVENT_E_CANT_MODIFY_OR_DELETE_UNCONFIGURED_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -2147220979
EVENT_E_CANT_MODIFY_OR_DELETE_CONFIGURED_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -2147220978
EVENT_E_INVALID_EVENT_CLASS_PARTITION: win32more.Windows.Win32.Foundation.HRESULT = -2147220977
EVENT_E_PER_USER_SID_NOT_LOGGED_ON: win32more.Windows.Win32.Foundation.HRESULT = -2147220976
TPC_E_INVALID_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2147220927
TPC_E_NO_DEFAULT_TABLET: win32more.Windows.Win32.Foundation.HRESULT = -2147220974
TPC_E_UNKNOWN_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2147220965
TPC_E_INVALID_INPUT_RECT: win32more.Windows.Win32.Foundation.HRESULT = -2147220967
TPC_E_INVALID_STROKE: win32more.Windows.Win32.Foundation.HRESULT = -2147220958
TPC_E_INITIALIZE_FAIL: win32more.Windows.Win32.Foundation.HRESULT = -2147220957
TPC_E_NOT_RELEVANT: win32more.Windows.Win32.Foundation.HRESULT = -2147220942
TPC_E_INVALID_PACKET_DESCRIPTION: win32more.Windows.Win32.Foundation.HRESULT = -2147220941
TPC_E_RECOGNIZER_NOT_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2147220939
TPC_E_INVALID_RIGHTS: win32more.Windows.Win32.Foundation.HRESULT = -2147220938
TPC_E_OUT_OF_ORDER_CALL: win32more.Windows.Win32.Foundation.HRESULT = -2147220937
TPC_E_QUEUE_FULL: win32more.Windows.Win32.Foundation.HRESULT = -2147220936
TPC_E_INVALID_CONFIGURATION: win32more.Windows.Win32.Foundation.HRESULT = -2147220935
TPC_E_INVALID_DATA_FROM_RECOGNIZER: win32more.Windows.Win32.Foundation.HRESULT = -2147220934
TPC_S_TRUNCATED: win32more.Windows.Win32.Foundation.HRESULT = 262738
TPC_S_INTERRUPTED: win32more.Windows.Win32.Foundation.HRESULT = 262739
TPC_S_NO_DATA_TO_PROCESS: win32more.Windows.Win32.Foundation.HRESULT = 262740
XACT_E_FIRST: UInt32 = 2147799040
XACT_E_LAST: UInt32 = 2147799083
XACT_S_FIRST: UInt32 = 315392
XACT_S_LAST: UInt32 = 315408
XACT_E_ALREADYOTHERSINGLEPHASE: win32more.Windows.Win32.Foundation.HRESULT = -2147168256
XACT_E_CANTRETAIN: win32more.Windows.Win32.Foundation.HRESULT = -2147168255
XACT_E_COMMITFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147168254
XACT_E_COMMITPREVENTED: win32more.Windows.Win32.Foundation.HRESULT = -2147168253
XACT_E_HEURISTICABORT: win32more.Windows.Win32.Foundation.HRESULT = -2147168252
XACT_E_HEURISTICCOMMIT: win32more.Windows.Win32.Foundation.HRESULT = -2147168251
XACT_E_HEURISTICDAMAGE: win32more.Windows.Win32.Foundation.HRESULT = -2147168250
XACT_E_HEURISTICDANGER: win32more.Windows.Win32.Foundation.HRESULT = -2147168249
XACT_E_ISOLATIONLEVEL: win32more.Windows.Win32.Foundation.HRESULT = -2147168248
XACT_E_NOASYNC: win32more.Windows.Win32.Foundation.HRESULT = -2147168247
XACT_E_NOENLIST: win32more.Windows.Win32.Foundation.HRESULT = -2147168246
XACT_E_NOISORETAIN: win32more.Windows.Win32.Foundation.HRESULT = -2147168245
XACT_E_NORESOURCE: win32more.Windows.Win32.Foundation.HRESULT = -2147168244
XACT_E_NOTCURRENT: win32more.Windows.Win32.Foundation.HRESULT = -2147168243
XACT_E_NOTRANSACTION: win32more.Windows.Win32.Foundation.HRESULT = -2147168242
XACT_E_NOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147168241
XACT_E_UNKNOWNRMGRID: win32more.Windows.Win32.Foundation.HRESULT = -2147168240
XACT_E_WRONGSTATE: win32more.Windows.Win32.Foundation.HRESULT = -2147168239
XACT_E_WRONGUOW: win32more.Windows.Win32.Foundation.HRESULT = -2147168238
XACT_E_XTIONEXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2147168237
XACT_E_NOIMPORTOBJECT: win32more.Windows.Win32.Foundation.HRESULT = -2147168236
XACT_E_INVALIDCOOKIE: win32more.Windows.Win32.Foundation.HRESULT = -2147168235
XACT_E_INDOUBT: win32more.Windows.Win32.Foundation.HRESULT = -2147168234
XACT_E_NOTIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2147168233
XACT_E_ALREADYINPROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2147168232
XACT_E_ABORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147168231
XACT_E_LOGFULL: win32more.Windows.Win32.Foundation.HRESULT = -2147168230
XACT_E_TMNOTAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147168229
XACT_E_CONNECTION_DOWN: win32more.Windows.Win32.Foundation.HRESULT = -2147168228
XACT_E_CONNECTION_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2147168227
XACT_E_REENLISTTIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2147168226
XACT_E_TIP_CONNECT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147168225
XACT_E_TIP_PROTOCOL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147168224
XACT_E_TIP_PULL_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147168223
XACT_E_DEST_TMNOTAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147168222
XACT_E_TIP_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2147168221
XACT_E_NETWORK_TX_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2147168220
XACT_E_PARTNER_NETWORK_TX_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2147168219
XACT_E_XA_TX_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2147168218
XACT_E_UNABLE_TO_READ_DTC_CONFIG: win32more.Windows.Win32.Foundation.HRESULT = -2147168217
XACT_E_UNABLE_TO_LOAD_DTC_PROXY: win32more.Windows.Win32.Foundation.HRESULT = -2147168216
XACT_E_ABORTING: win32more.Windows.Win32.Foundation.HRESULT = -2147168215
XACT_E_PUSH_COMM_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2147168214
XACT_E_PULL_COMM_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2147168213
XACT_E_LU_TX_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2147168212
XACT_E_CLERKNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147168128
XACT_E_CLERKEXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2147168127
XACT_E_RECOVERYINPROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2147168126
XACT_E_TRANSACTIONCLOSED: win32more.Windows.Win32.Foundation.HRESULT = -2147168125
XACT_E_INVALIDLSN: win32more.Windows.Win32.Foundation.HRESULT = -2147168124
XACT_E_REPLAYREQUEST: win32more.Windows.Win32.Foundation.HRESULT = -2147168123
XACT_S_ASYNC: win32more.Windows.Win32.Foundation.HRESULT = 315392
XACT_S_DEFECT: win32more.Windows.Win32.Foundation.HRESULT = 315393
XACT_S_READONLY: win32more.Windows.Win32.Foundation.HRESULT = 315394
XACT_S_SOMENORETAIN: win32more.Windows.Win32.Foundation.HRESULT = 315395
XACT_S_OKINFORM: win32more.Windows.Win32.Foundation.HRESULT = 315396
XACT_S_MADECHANGESCONTENT: win32more.Windows.Win32.Foundation.HRESULT = 315397
XACT_S_MADECHANGESINFORM: win32more.Windows.Win32.Foundation.HRESULT = 315398
XACT_S_ALLNORETAIN: win32more.Windows.Win32.Foundation.HRESULT = 315399
XACT_S_ABORTING: win32more.Windows.Win32.Foundation.HRESULT = 315400
XACT_S_SINGLEPHASE: win32more.Windows.Win32.Foundation.HRESULT = 315401
XACT_S_LOCALLY_OK: win32more.Windows.Win32.Foundation.HRESULT = 315402
XACT_S_LASTRESOURCEMANAGER: win32more.Windows.Win32.Foundation.HRESULT = 315408
CONTEXT_E_FIRST: Int32 = -2147164160
CONTEXT_E_LAST: Int32 = -2147164113
CONTEXT_S_FIRST: Int32 = 319488
CONTEXT_S_LAST: Int32 = 319535
CONTEXT_E_ABORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147164158
CONTEXT_E_ABORTING: win32more.Windows.Win32.Foundation.HRESULT = -2147164157
CONTEXT_E_NOCONTEXT: win32more.Windows.Win32.Foundation.HRESULT = -2147164156
CONTEXT_E_WOULD_DEADLOCK: win32more.Windows.Win32.Foundation.HRESULT = -2147164155
CONTEXT_E_SYNCH_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2147164154
CONTEXT_E_OLDREF: win32more.Windows.Win32.Foundation.HRESULT = -2147164153
CONTEXT_E_ROLENOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147164148
CONTEXT_E_TMNOTAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147164145
CO_E_ACTIVATIONFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147164127
CO_E_ACTIVATIONFAILED_EVENTLOGGED: win32more.Windows.Win32.Foundation.HRESULT = -2147164126
CO_E_ACTIVATIONFAILED_CATALOGERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147164125
CO_E_ACTIVATIONFAILED_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2147164124
CO_E_INITIALIZATIONFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147164123
CONTEXT_E_NOJIT: win32more.Windows.Win32.Foundation.HRESULT = -2147164122
CONTEXT_E_NOTRANSACTION: win32more.Windows.Win32.Foundation.HRESULT = -2147164121
CO_E_THREADINGMODEL_CHANGED: win32more.Windows.Win32.Foundation.HRESULT = -2147164120
CO_E_NOIISINTRINSICS: win32more.Windows.Win32.Foundation.HRESULT = -2147164119
CO_E_NOCOOKIES: win32more.Windows.Win32.Foundation.HRESULT = -2147164118
CO_E_DBERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147164117
CO_E_NOTPOOLED: win32more.Windows.Win32.Foundation.HRESULT = -2147164116
CO_E_NOTCONSTRUCTED: win32more.Windows.Win32.Foundation.HRESULT = -2147164115
CO_E_NOSYNCHRONIZATION: win32more.Windows.Win32.Foundation.HRESULT = -2147164114
CO_E_ISOLEVELMISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2147164113
CO_E_CALL_OUT_OF_TX_SCOPE_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2147164112
CO_E_EXIT_TRANSACTION_SCOPE_NOT_CALLED: win32more.Windows.Win32.Foundation.HRESULT = -2147164111
OLE_S_USEREG: win32more.Windows.Win32.Foundation.HRESULT = 262144
OLE_S_STATIC: win32more.Windows.Win32.Foundation.HRESULT = 262145
OLE_S_MAC_CLIPFORMAT: win32more.Windows.Win32.Foundation.HRESULT = 262146
DRAGDROP_S_DROP: win32more.Windows.Win32.Foundation.HRESULT = 262400
DRAGDROP_S_CANCEL: win32more.Windows.Win32.Foundation.HRESULT = 262401
DRAGDROP_S_USEDEFAULTCURSORS: win32more.Windows.Win32.Foundation.HRESULT = 262402
DATA_S_SAMEFORMATETC: win32more.Windows.Win32.Foundation.HRESULT = 262448
VIEW_S_ALREADY_FROZEN: win32more.Windows.Win32.Foundation.HRESULT = 262464
CACHE_S_FORMATETC_NOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = 262512
CACHE_S_SAMECACHE: win32more.Windows.Win32.Foundation.HRESULT = 262513
CACHE_S_SOMECACHES_NOTUPDATED: win32more.Windows.Win32.Foundation.HRESULT = 262514
OLEOBJ_S_INVALIDVERB: win32more.Windows.Win32.Foundation.HRESULT = 262528
OLEOBJ_S_CANNOT_DOVERB_NOW: win32more.Windows.Win32.Foundation.HRESULT = 262529
OLEOBJ_S_INVALIDHWND: win32more.Windows.Win32.Foundation.HRESULT = 262530
INPLACE_S_TRUNCATED: win32more.Windows.Win32.Foundation.HRESULT = 262560
CONVERT10_S_NO_PRESENTATION: win32more.Windows.Win32.Foundation.HRESULT = 262592
MK_S_REDUCED_TO_SELF: win32more.Windows.Win32.Foundation.HRESULT = 262626
MK_S_ME: win32more.Windows.Win32.Foundation.HRESULT = 262628
MK_S_HIM: win32more.Windows.Win32.Foundation.HRESULT = 262629
MK_S_US: win32more.Windows.Win32.Foundation.HRESULT = 262630
MK_S_MONIKERALREADYREGISTERED: win32more.Windows.Win32.Foundation.HRESULT = 262631
SCHED_S_TASK_READY: win32more.Windows.Win32.Foundation.HRESULT = 267008
SCHED_S_TASK_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = 267009
SCHED_S_TASK_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = 267010
SCHED_S_TASK_HAS_NOT_RUN: win32more.Windows.Win32.Foundation.HRESULT = 267011
SCHED_S_TASK_NO_MORE_RUNS: win32more.Windows.Win32.Foundation.HRESULT = 267012
SCHED_S_TASK_NOT_SCHEDULED: win32more.Windows.Win32.Foundation.HRESULT = 267013
SCHED_S_TASK_TERMINATED: win32more.Windows.Win32.Foundation.HRESULT = 267014
SCHED_S_TASK_NO_VALID_TRIGGERS: win32more.Windows.Win32.Foundation.HRESULT = 267015
SCHED_S_EVENT_TRIGGER: win32more.Windows.Win32.Foundation.HRESULT = 267016
SCHED_E_TRIGGER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147216631
SCHED_E_TASK_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -2147216630
SCHED_E_TASK_NOT_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2147216629
SCHED_E_SERVICE_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -2147216628
SCHED_E_CANNOT_OPEN_TASK: win32more.Windows.Win32.Foundation.HRESULT = -2147216627
SCHED_E_INVALID_TASK: win32more.Windows.Win32.Foundation.HRESULT = -2147216626
SCHED_E_ACCOUNT_INFORMATION_NOT_SET: win32more.Windows.Win32.Foundation.HRESULT = -2147216625
SCHED_E_ACCOUNT_NAME_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147216624
SCHED_E_ACCOUNT_DBASE_CORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -2147216623
SCHED_E_NO_SECURITY_SERVICES: win32more.Windows.Win32.Foundation.HRESULT = -2147216622
SCHED_E_UNKNOWN_OBJECT_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2147216621
SCHED_E_UNSUPPORTED_ACCOUNT_OPTION: win32more.Windows.Win32.Foundation.HRESULT = -2147216620
SCHED_E_SERVICE_NOT_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2147216619
SCHED_E_UNEXPECTEDNODE: win32more.Windows.Win32.Foundation.HRESULT = -2147216618
SCHED_E_NAMESPACE: win32more.Windows.Win32.Foundation.HRESULT = -2147216617
SCHED_E_INVALIDVALUE: win32more.Windows.Win32.Foundation.HRESULT = -2147216616
SCHED_E_MISSINGNODE: win32more.Windows.Win32.Foundation.HRESULT = -2147216615
SCHED_E_MALFORMEDXML: win32more.Windows.Win32.Foundation.HRESULT = -2147216614
SCHED_S_SOME_TRIGGERS_FAILED: win32more.Windows.Win32.Foundation.HRESULT = 267035
SCHED_S_BATCH_LOGON_PROBLEM: win32more.Windows.Win32.Foundation.HRESULT = 267036
SCHED_E_TOO_MANY_NODES: win32more.Windows.Win32.Foundation.HRESULT = -2147216611
SCHED_E_PAST_END_BOUNDARY: win32more.Windows.Win32.Foundation.HRESULT = -2147216610
SCHED_E_ALREADY_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2147216609
SCHED_E_USER_NOT_LOGGED_ON: win32more.Windows.Win32.Foundation.HRESULT = -2147216608
SCHED_E_INVALID_TASK_HASH: win32more.Windows.Win32.Foundation.HRESULT = -2147216607
SCHED_E_SERVICE_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147216606
SCHED_E_SERVICE_TOO_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -2147216605
SCHED_E_TASK_ATTEMPTED: win32more.Windows.Win32.Foundation.HRESULT = -2147216604
SCHED_S_TASK_QUEUED: win32more.Windows.Win32.Foundation.HRESULT = 267045
SCHED_E_TASK_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2147216602
SCHED_E_TASK_NOT_V1_COMPAT: win32more.Windows.Win32.Foundation.HRESULT = -2147216601
SCHED_E_START_ON_DEMAND: win32more.Windows.Win32.Foundation.HRESULT = -2147216600
SCHED_E_TASK_NOT_UBPM_COMPAT: win32more.Windows.Win32.Foundation.HRESULT = -2147216599
SCHED_E_DEPRECATED_FEATURE_USED: win32more.Windows.Win32.Foundation.HRESULT = -2147216592
CO_E_CLASS_CREATE_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2146959359
CO_E_SCM_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2146959358
CO_E_SCM_RPC_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2146959357
CO_E_BAD_PATH: win32more.Windows.Win32.Foundation.HRESULT = -2146959356
CO_E_SERVER_EXEC_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2146959355
CO_E_OBJSRV_RPC_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2146959354
MK_E_NO_NORMALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2146959353
CO_E_SERVER_STOPPING: win32more.Windows.Win32.Foundation.HRESULT = -2146959352
MEM_E_INVALID_ROOT: win32more.Windows.Win32.Foundation.HRESULT = -2146959351
MEM_E_INVALID_LINK: win32more.Windows.Win32.Foundation.HRESULT = -2146959344
MEM_E_INVALID_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2146959343
CO_S_NOTALLINTERFACES: win32more.Windows.Win32.Foundation.HRESULT = 524306
CO_S_MACHINENAMENOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = 524307
CO_E_MISSING_DISPLAYNAME: win32more.Windows.Win32.Foundation.HRESULT = -2146959339
CO_E_RUNAS_VALUE_MUST_BE_AAA: win32more.Windows.Win32.Foundation.HRESULT = -2146959338
CO_E_ELEVATION_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2146959337
APPX_E_PACKAGING_INTERNAL: win32more.Windows.Win32.Foundation.HRESULT = -2146958848
APPX_E_INTERLEAVING_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2146958847
APPX_E_RELATIONSHIPS_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2146958846
APPX_E_MISSING_REQUIRED_FILE: win32more.Windows.Win32.Foundation.HRESULT = -2146958845
APPX_E_INVALID_MANIFEST: win32more.Windows.Win32.Foundation.HRESULT = -2146958844
APPX_E_INVALID_BLOCKMAP: win32more.Windows.Win32.Foundation.HRESULT = -2146958843
APPX_E_CORRUPT_CONTENT: win32more.Windows.Win32.Foundation.HRESULT = -2146958842
APPX_E_BLOCK_HASH_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2146958841
APPX_E_REQUESTED_RANGE_TOO_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -2146958840
APPX_E_INVALID_SIP_CLIENT_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2146958839
APPX_E_INVALID_KEY_INFO: win32more.Windows.Win32.Foundation.HRESULT = -2146958838
APPX_E_INVALID_CONTENTGROUPMAP: win32more.Windows.Win32.Foundation.HRESULT = -2146958837
APPX_E_INVALID_APPINSTALLER: win32more.Windows.Win32.Foundation.HRESULT = -2146958836
APPX_E_DELTA_BASELINE_VERSION_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146958835
APPX_E_DELTA_PACKAGE_MISSING_FILE: win32more.Windows.Win32.Foundation.HRESULT = -2146958834
APPX_E_INVALID_DELTA_PACKAGE: win32more.Windows.Win32.Foundation.HRESULT = -2146958833
APPX_E_DELTA_APPENDED_PACKAGE_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2146958832
APPX_E_INVALID_PACKAGING_LAYOUT: win32more.Windows.Win32.Foundation.HRESULT = -2146958831
APPX_E_INVALID_PACKAGESIGNCONFIG: win32more.Windows.Win32.Foundation.HRESULT = -2146958830
APPX_E_RESOURCESPRI_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2146958829
APPX_E_FILE_COMPRESSION_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146958828
APPX_E_INVALID_PAYLOAD_PACKAGE_EXTENSION: win32more.Windows.Win32.Foundation.HRESULT = -2146958827
APPX_E_INVALID_ENCRYPTION_EXCLUSION_FILE_LIST: win32more.Windows.Win32.Foundation.HRESULT = -2146958826
APPX_E_INVALID_PACKAGE_FOLDER_ACLS: win32more.Windows.Win32.Foundation.HRESULT = -2146958825
APPX_E_INVALID_PUBLISHER_BRIDGING: win32more.Windows.Win32.Foundation.HRESULT = -2146958824
APPX_E_DIGEST_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146958823
BT_E_SPURIOUS_ACTIVATION: win32more.Windows.Win32.Foundation.HRESULT = -2146958592
DISP_E_UNKNOWNINTERFACE: win32more.Windows.Win32.Foundation.HRESULT = -2147352575
DISP_E_MEMBERNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147352573
DISP_E_PARAMNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147352572
DISP_E_TYPEMISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2147352571
DISP_E_UNKNOWNNAME: win32more.Windows.Win32.Foundation.HRESULT = -2147352570
DISP_E_NONAMEDARGS: win32more.Windows.Win32.Foundation.HRESULT = -2147352569
DISP_E_BADVARTYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147352568
DISP_E_EXCEPTION: win32more.Windows.Win32.Foundation.HRESULT = -2147352567
DISP_E_OVERFLOW: win32more.Windows.Win32.Foundation.HRESULT = -2147352566
DISP_E_BADINDEX: win32more.Windows.Win32.Foundation.HRESULT = -2147352565
DISP_E_UNKNOWNLCID: win32more.Windows.Win32.Foundation.HRESULT = -2147352564
DISP_E_ARRAYISLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2147352563
DISP_E_BADPARAMCOUNT: win32more.Windows.Win32.Foundation.HRESULT = -2147352562
DISP_E_PARAMNOTOPTIONAL: win32more.Windows.Win32.Foundation.HRESULT = -2147352561
DISP_E_BADCALLEE: win32more.Windows.Win32.Foundation.HRESULT = -2147352560
DISP_E_NOTACOLLECTION: win32more.Windows.Win32.Foundation.HRESULT = -2147352559
DISP_E_DIVBYZERO: win32more.Windows.Win32.Foundation.HRESULT = -2147352558
DISP_E_BUFFERTOOSMALL: win32more.Windows.Win32.Foundation.HRESULT = -2147352557
TYPE_E_BUFFERTOOSMALL: win32more.Windows.Win32.Foundation.HRESULT = -2147319786
TYPE_E_FIELDNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147319785
TYPE_E_INVDATAREAD: win32more.Windows.Win32.Foundation.HRESULT = -2147319784
TYPE_E_UNSUPFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2147319783
TYPE_E_REGISTRYACCESS: win32more.Windows.Win32.Foundation.HRESULT = -2147319780
TYPE_E_LIBNOTREGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2147319779
TYPE_E_UNDEFINEDTYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147319769
TYPE_E_QUALIFIEDNAMEDISALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2147319768
TYPE_E_INVALIDSTATE: win32more.Windows.Win32.Foundation.HRESULT = -2147319767
TYPE_E_WRONGTYPEKIND: win32more.Windows.Win32.Foundation.HRESULT = -2147319766
TYPE_E_ELEMENTNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147319765
TYPE_E_AMBIGUOUSNAME: win32more.Windows.Win32.Foundation.HRESULT = -2147319764
TYPE_E_NAMECONFLICT: win32more.Windows.Win32.Foundation.HRESULT = -2147319763
TYPE_E_UNKNOWNLCID: win32more.Windows.Win32.Foundation.HRESULT = -2147319762
TYPE_E_DLLFUNCTIONNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147319761
TYPE_E_BADMODULEKIND: win32more.Windows.Win32.Foundation.HRESULT = -2147317571
TYPE_E_SIZETOOBIG: win32more.Windows.Win32.Foundation.HRESULT = -2147317563
TYPE_E_DUPLICATEID: win32more.Windows.Win32.Foundation.HRESULT = -2147317562
TYPE_E_INVALIDID: win32more.Windows.Win32.Foundation.HRESULT = -2147317553
TYPE_E_TYPEMISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2147316576
TYPE_E_OUTOFBOUNDS: win32more.Windows.Win32.Foundation.HRESULT = -2147316575
TYPE_E_IOERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147316574
TYPE_E_CANTCREATETMPFILE: win32more.Windows.Win32.Foundation.HRESULT = -2147316573
TYPE_E_CANTLOADLIBRARY: win32more.Windows.Win32.Foundation.HRESULT = -2147312566
TYPE_E_INCONSISTENTPROPFUNCS: win32more.Windows.Win32.Foundation.HRESULT = -2147312509
TYPE_E_CIRCULARTYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147312508
STG_E_INVALIDFUNCTION: win32more.Windows.Win32.Foundation.HRESULT = -2147287039
STG_E_FILENOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147287038
STG_E_PATHNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147287037
STG_E_TOOMANYOPENFILES: win32more.Windows.Win32.Foundation.HRESULT = -2147287036
STG_E_ACCESSDENIED: win32more.Windows.Win32.Foundation.HRESULT = -2147287035
STG_E_INVALIDHANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2147287034
STG_E_INSUFFICIENTMEMORY: win32more.Windows.Win32.Foundation.HRESULT = -2147287032
STG_E_INVALIDPOINTER: win32more.Windows.Win32.Foundation.HRESULT = -2147287031
STG_E_NOMOREFILES: win32more.Windows.Win32.Foundation.HRESULT = -2147287022
STG_E_DISKISWRITEPROTECTED: win32more.Windows.Win32.Foundation.HRESULT = -2147287021
STG_E_SEEKERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147287015
STG_E_WRITEFAULT: win32more.Windows.Win32.Foundation.HRESULT = -2147287011
STG_E_READFAULT: win32more.Windows.Win32.Foundation.HRESULT = -2147287010
STG_E_SHAREVIOLATION: win32more.Windows.Win32.Foundation.HRESULT = -2147287008
STG_E_LOCKVIOLATION: win32more.Windows.Win32.Foundation.HRESULT = -2147287007
STG_E_FILEALREADYEXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2147286960
STG_E_INVALIDPARAMETER: win32more.Windows.Win32.Foundation.HRESULT = -2147286953
STG_E_MEDIUMFULL: win32more.Windows.Win32.Foundation.HRESULT = -2147286928
STG_E_PROPSETMISMATCHED: win32more.Windows.Win32.Foundation.HRESULT = -2147286800
STG_E_ABNORMALAPIEXIT: win32more.Windows.Win32.Foundation.HRESULT = -2147286790
STG_E_INVALIDHEADER: win32more.Windows.Win32.Foundation.HRESULT = -2147286789
STG_E_INVALIDNAME: win32more.Windows.Win32.Foundation.HRESULT = -2147286788
STG_E_UNKNOWN: win32more.Windows.Win32.Foundation.HRESULT = -2147286787
STG_E_UNIMPLEMENTEDFUNCTION: win32more.Windows.Win32.Foundation.HRESULT = -2147286786
STG_E_INVALIDFLAG: win32more.Windows.Win32.Foundation.HRESULT = -2147286785
STG_E_INUSE: win32more.Windows.Win32.Foundation.HRESULT = -2147286784
STG_E_NOTCURRENT: win32more.Windows.Win32.Foundation.HRESULT = -2147286783
STG_E_REVERTED: win32more.Windows.Win32.Foundation.HRESULT = -2147286782
STG_E_CANTSAVE: win32more.Windows.Win32.Foundation.HRESULT = -2147286781
STG_E_OLDFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2147286780
STG_E_OLDDLL: win32more.Windows.Win32.Foundation.HRESULT = -2147286779
STG_E_SHAREREQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2147286778
STG_E_NOTFILEBASEDSTORAGE: win32more.Windows.Win32.Foundation.HRESULT = -2147286777
STG_E_EXTANTMARSHALLINGS: win32more.Windows.Win32.Foundation.HRESULT = -2147286776
STG_E_DOCFILECORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -2147286775
STG_E_BADBASEADDRESS: win32more.Windows.Win32.Foundation.HRESULT = -2147286768
STG_E_DOCFILETOOLARGE: win32more.Windows.Win32.Foundation.HRESULT = -2147286767
STG_E_NOTSIMPLEFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2147286766
STG_E_INCOMPLETE: win32more.Windows.Win32.Foundation.HRESULT = -2147286527
STG_E_TERMINATED: win32more.Windows.Win32.Foundation.HRESULT = -2147286526
STG_S_CONVERTED: win32more.Windows.Win32.Foundation.HRESULT = 197120
STG_S_BLOCK: win32more.Windows.Win32.Foundation.HRESULT = 197121
STG_S_RETRYNOW: win32more.Windows.Win32.Foundation.HRESULT = 197122
STG_S_MONITORING: win32more.Windows.Win32.Foundation.HRESULT = 197123
STG_S_MULTIPLEOPENS: win32more.Windows.Win32.Foundation.HRESULT = 197124
STG_S_CONSOLIDATIONFAILED: win32more.Windows.Win32.Foundation.HRESULT = 197125
STG_S_CANNOTCONSOLIDATE: win32more.Windows.Win32.Foundation.HRESULT = 197126
STG_S_POWER_CYCLE_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = 197127
STG_E_FIRMWARE_SLOT_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2147286520
STG_E_FIRMWARE_IMAGE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2147286519
STG_E_DEVICE_UNRESPONSIVE: win32more.Windows.Win32.Foundation.HRESULT = -2147286518
STG_E_STATUS_COPY_PROTECTION_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2147286267
STG_E_CSS_AUTHENTICATION_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2147286266
STG_E_CSS_KEY_NOT_PRESENT: win32more.Windows.Win32.Foundation.HRESULT = -2147286265
STG_E_CSS_KEY_NOT_ESTABLISHED: win32more.Windows.Win32.Foundation.HRESULT = -2147286264
STG_E_CSS_SCRAMBLED_SECTOR: win32more.Windows.Win32.Foundation.HRESULT = -2147286263
STG_E_CSS_REGION_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2147286262
STG_E_RESETS_EXHAUSTED: win32more.Windows.Win32.Foundation.HRESULT = -2147286261
RPC_E_CALL_REJECTED: win32more.Windows.Win32.Foundation.HRESULT = -2147418111
RPC_E_CALL_CANCELED: win32more.Windows.Win32.Foundation.HRESULT = -2147418110
RPC_E_CANTPOST_INSENDCALL: win32more.Windows.Win32.Foundation.HRESULT = -2147418109
RPC_E_CANTCALLOUT_INASYNCCALL: win32more.Windows.Win32.Foundation.HRESULT = -2147418108
RPC_E_CANTCALLOUT_INEXTERNALCALL: win32more.Windows.Win32.Foundation.HRESULT = -2147418107
RPC_E_CONNECTION_TERMINATED: win32more.Windows.Win32.Foundation.HRESULT = -2147418106
RPC_E_SERVER_DIED: win32more.Windows.Win32.Foundation.HRESULT = -2147418105
RPC_E_CLIENT_DIED: win32more.Windows.Win32.Foundation.HRESULT = -2147418104
RPC_E_INVALID_DATAPACKET: win32more.Windows.Win32.Foundation.HRESULT = -2147418103
RPC_E_CANTTRANSMIT_CALL: win32more.Windows.Win32.Foundation.HRESULT = -2147418102
RPC_E_CLIENT_CANTMARSHAL_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2147418101
RPC_E_CLIENT_CANTUNMARSHAL_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2147418100
RPC_E_SERVER_CANTMARSHAL_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2147418099
RPC_E_SERVER_CANTUNMARSHAL_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2147418098
RPC_E_INVALID_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2147418097
RPC_E_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.HRESULT = -2147418096
RPC_E_CANTCALLOUT_AGAIN: win32more.Windows.Win32.Foundation.HRESULT = -2147418095
RPC_E_SERVER_DIED_DNE: win32more.Windows.Win32.Foundation.HRESULT = -2147418094
RPC_E_SYS_CALL_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147417856
RPC_E_OUT_OF_RESOURCES: win32more.Windows.Win32.Foundation.HRESULT = -2147417855
RPC_E_ATTEMPTED_MULTITHREAD: win32more.Windows.Win32.Foundation.HRESULT = -2147417854
RPC_E_NOT_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2147417853
RPC_E_FAULT: win32more.Windows.Win32.Foundation.HRESULT = -2147417852
RPC_E_SERVERFAULT: win32more.Windows.Win32.Foundation.HRESULT = -2147417851
RPC_E_CHANGED_MODE: win32more.Windows.Win32.Foundation.HRESULT = -2147417850
RPC_E_INVALIDMETHOD: win32more.Windows.Win32.Foundation.HRESULT = -2147417849
RPC_E_DISCONNECTED: win32more.Windows.Win32.Foundation.HRESULT = -2147417848
RPC_E_RETRY: win32more.Windows.Win32.Foundation.HRESULT = -2147417847
RPC_E_SERVERCALL_RETRYLATER: win32more.Windows.Win32.Foundation.HRESULT = -2147417846
RPC_E_SERVERCALL_REJECTED: win32more.Windows.Win32.Foundation.HRESULT = -2147417845
RPC_E_INVALID_CALLDATA: win32more.Windows.Win32.Foundation.HRESULT = -2147417844
RPC_E_CANTCALLOUT_ININPUTSYNCCALL: win32more.Windows.Win32.Foundation.HRESULT = -2147417843
RPC_E_WRONG_THREAD: win32more.Windows.Win32.Foundation.HRESULT = -2147417842
RPC_E_THREAD_NOT_INIT: win32more.Windows.Win32.Foundation.HRESULT = -2147417841
RPC_E_VERSION_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2147417840
RPC_E_INVALID_HEADER: win32more.Windows.Win32.Foundation.HRESULT = -2147417839
RPC_E_INVALID_EXTENSION: win32more.Windows.Win32.Foundation.HRESULT = -2147417838
RPC_E_INVALID_IPID: win32more.Windows.Win32.Foundation.HRESULT = -2147417837
RPC_E_INVALID_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -2147417836
RPC_S_CALLPENDING: win32more.Windows.Win32.Foundation.HRESULT = -2147417835
RPC_S_WAITONTIMER: win32more.Windows.Win32.Foundation.HRESULT = -2147417834
RPC_E_CALL_COMPLETE: win32more.Windows.Win32.Foundation.HRESULT = -2147417833
RPC_E_UNSECURE_CALL: win32more.Windows.Win32.Foundation.HRESULT = -2147417832
RPC_E_TOO_LATE: win32more.Windows.Win32.Foundation.HRESULT = -2147417831
RPC_E_NO_GOOD_SECURITY_PACKAGES: win32more.Windows.Win32.Foundation.HRESULT = -2147417830
RPC_E_ACCESS_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2147417829
RPC_E_REMOTE_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2147417828
RPC_E_INVALID_OBJREF: win32more.Windows.Win32.Foundation.HRESULT = -2147417827
RPC_E_NO_CONTEXT: win32more.Windows.Win32.Foundation.HRESULT = -2147417826
RPC_E_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2147417825
RPC_E_NO_SYNC: win32more.Windows.Win32.Foundation.HRESULT = -2147417824
RPC_E_FULLSIC_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2147417823
RPC_E_INVALID_STD_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2147417822
CO_E_FAILEDTOIMPERSONATE: win32more.Windows.Win32.Foundation.HRESULT = -2147417821
CO_E_FAILEDTOGETSECCTX: win32more.Windows.Win32.Foundation.HRESULT = -2147417820
CO_E_FAILEDTOOPENTHREADTOKEN: win32more.Windows.Win32.Foundation.HRESULT = -2147417819
CO_E_FAILEDTOGETTOKENINFO: win32more.Windows.Win32.Foundation.HRESULT = -2147417818
CO_E_TRUSTEEDOESNTMATCHCLIENT: win32more.Windows.Win32.Foundation.HRESULT = -2147417817
CO_E_FAILEDTOQUERYCLIENTBLANKET: win32more.Windows.Win32.Foundation.HRESULT = -2147417816
CO_E_FAILEDTOSETDACL: win32more.Windows.Win32.Foundation.HRESULT = -2147417815
CO_E_ACCESSCHECKFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147417814
CO_E_NETACCESSAPIFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147417813
CO_E_WRONGTRUSTEENAMESYNTAX: win32more.Windows.Win32.Foundation.HRESULT = -2147417812
CO_E_INVALIDSID: win32more.Windows.Win32.Foundation.HRESULT = -2147417811
CO_E_CONVERSIONFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147417810
CO_E_NOMATCHINGSIDFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147417809
CO_E_LOOKUPACCSIDFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147417808
CO_E_NOMATCHINGNAMEFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147417807
CO_E_LOOKUPACCNAMEFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147417806
CO_E_SETSERLHNDLFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147417805
CO_E_FAILEDTOGETWINDIR: win32more.Windows.Win32.Foundation.HRESULT = -2147417804
CO_E_PATHTOOLONG: win32more.Windows.Win32.Foundation.HRESULT = -2147417803
CO_E_FAILEDTOGENUUID: win32more.Windows.Win32.Foundation.HRESULT = -2147417802
CO_E_FAILEDTOCREATEFILE: win32more.Windows.Win32.Foundation.HRESULT = -2147417801
CO_E_FAILEDTOCLOSEHANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2147417800
CO_E_EXCEEDSYSACLLIMIT: win32more.Windows.Win32.Foundation.HRESULT = -2147417799
CO_E_ACESINWRONGORDER: win32more.Windows.Win32.Foundation.HRESULT = -2147417798
CO_E_INCOMPATIBLESTREAMVERSION: win32more.Windows.Win32.Foundation.HRESULT = -2147417797
CO_E_FAILEDTOOPENPROCESSTOKEN: win32more.Windows.Win32.Foundation.HRESULT = -2147417796
CO_E_DECODEFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147417795
CO_E_ACNOTINITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2147417793
CO_E_CANCEL_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2147417792
RPC_E_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2147352577
ERROR_AUDITING_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -1073151999
ERROR_ALL_SIDS_FILTERED: win32more.Windows.Win32.Foundation.HRESULT = -1073151998
ERROR_BIZRULES_NOT_ENABLED: win32more.Windows.Win32.Foundation.HRESULT = -1073151997
NTE_BAD_UID: win32more.Windows.Win32.Foundation.HRESULT = -2146893823
NTE_BAD_HASH: win32more.Windows.Win32.Foundation.HRESULT = -2146893822
NTE_BAD_KEY: win32more.Windows.Win32.Foundation.HRESULT = -2146893821
NTE_BAD_LEN: win32more.Windows.Win32.Foundation.HRESULT = -2146893820
NTE_BAD_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2146893819
NTE_BAD_SIGNATURE: win32more.Windows.Win32.Foundation.HRESULT = -2146893818
NTE_BAD_VER: win32more.Windows.Win32.Foundation.HRESULT = -2146893817
NTE_BAD_ALGID: win32more.Windows.Win32.Foundation.HRESULT = -2146893816
NTE_BAD_FLAGS: win32more.Windows.Win32.Foundation.HRESULT = -2146893815
NTE_BAD_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2146893814
NTE_BAD_KEY_STATE: win32more.Windows.Win32.Foundation.HRESULT = -2146893813
NTE_BAD_HASH_STATE: win32more.Windows.Win32.Foundation.HRESULT = -2146893812
NTE_NO_KEY: win32more.Windows.Win32.Foundation.HRESULT = -2146893811
NTE_NO_MEMORY: win32more.Windows.Win32.Foundation.HRESULT = -2146893810
NTE_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2146893809
NTE_PERM: win32more.Windows.Win32.Foundation.HRESULT = -2146893808
NTE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2146893807
NTE_DOUBLE_ENCRYPT: win32more.Windows.Win32.Foundation.HRESULT = -2146893806
NTE_BAD_PROVIDER: win32more.Windows.Win32.Foundation.HRESULT = -2146893805
NTE_BAD_PROV_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2146893804
NTE_BAD_PUBLIC_KEY: win32more.Windows.Win32.Foundation.HRESULT = -2146893803
NTE_BAD_KEYSET: win32more.Windows.Win32.Foundation.HRESULT = -2146893802
NTE_PROV_TYPE_NOT_DEF: win32more.Windows.Win32.Foundation.HRESULT = -2146893801
NTE_PROV_TYPE_ENTRY_BAD: win32more.Windows.Win32.Foundation.HRESULT = -2146893800
NTE_KEYSET_NOT_DEF: win32more.Windows.Win32.Foundation.HRESULT = -2146893799
NTE_KEYSET_ENTRY_BAD: win32more.Windows.Win32.Foundation.HRESULT = -2146893798
NTE_PROV_TYPE_NO_MATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146893797
NTE_SIGNATURE_FILE_BAD: win32more.Windows.Win32.Foundation.HRESULT = -2146893796
NTE_PROVIDER_DLL_FAIL: win32more.Windows.Win32.Foundation.HRESULT = -2146893795
NTE_PROV_DLL_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2146893794
NTE_BAD_KEYSET_PARAM: win32more.Windows.Win32.Foundation.HRESULT = -2146893793
NTE_FAIL: win32more.Windows.Win32.Foundation.HRESULT = -2146893792
NTE_SYS_ERR: win32more.Windows.Win32.Foundation.HRESULT = -2146893791
NTE_SILENT_CONTEXT: win32more.Windows.Win32.Foundation.HRESULT = -2146893790
NTE_TOKEN_KEYSET_STORAGE_FULL: win32more.Windows.Win32.Foundation.HRESULT = -2146893789
NTE_TEMPORARY_PROFILE: win32more.Windows.Win32.Foundation.HRESULT = -2146893788
NTE_FIXEDPARAMETER: win32more.Windows.Win32.Foundation.HRESULT = -2146893787
NTE_INVALID_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2146893786
NTE_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.HRESULT = -2146893785
NTE_BUFFER_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -2146893784
NTE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2146893783
NTE_NO_MORE_ITEMS: win32more.Windows.Win32.Foundation.HRESULT = -2146893782
NTE_BUFFERS_OVERLAP: win32more.Windows.Win32.Foundation.HRESULT = -2146893781
NTE_DECRYPTION_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2146893780
NTE_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2146893779
NTE_UI_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146893778
NTE_HMAC_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2146893777
NTE_DEVICE_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -2146893776
NTE_AUTHENTICATION_IGNORED: win32more.Windows.Win32.Foundation.HRESULT = -2146893775
NTE_VALIDATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2146893774
NTE_INCORRECT_PASSWORD: win32more.Windows.Win32.Foundation.HRESULT = -2146893773
NTE_ENCRYPTION_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2146893772
NTE_DEVICE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2146893771
NTE_USER_CANCELLED: win32more.Windows.Win32.Foundation.HRESULT = -2146893770
NTE_PASSWORD_CHANGE_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146893769
NTE_NOT_ACTIVE_CONSOLE: win32more.Windows.Win32.Foundation.HRESULT = -2146893768
SEC_E_INSUFFICIENT_MEMORY: win32more.Windows.Win32.Foundation.HRESULT = -2146893056
SEC_E_INVALID_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2146893055
SEC_E_UNSUPPORTED_FUNCTION: win32more.Windows.Win32.Foundation.HRESULT = -2146893054
SEC_E_TARGET_UNKNOWN: win32more.Windows.Win32.Foundation.HRESULT = -2146893053
SEC_E_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2146893052
SEC_E_SECPKG_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2146893051
SEC_E_NOT_OWNER: win32more.Windows.Win32.Foundation.HRESULT = -2146893050
SEC_E_CANNOT_INSTALL: win32more.Windows.Win32.Foundation.HRESULT = -2146893049
SEC_E_INVALID_TOKEN: win32more.Windows.Win32.Foundation.HRESULT = -2146893048
SEC_E_CANNOT_PACK: win32more.Windows.Win32.Foundation.HRESULT = -2146893047
SEC_E_QOP_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2146893046
SEC_E_NO_IMPERSONATION: win32more.Windows.Win32.Foundation.HRESULT = -2146893045
SEC_E_LOGON_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2146893044
SEC_E_UNKNOWN_CREDENTIALS: win32more.Windows.Win32.Foundation.HRESULT = -2146893043
SEC_E_NO_CREDENTIALS: win32more.Windows.Win32.Foundation.HRESULT = -2146893042
SEC_E_MESSAGE_ALTERED: win32more.Windows.Win32.Foundation.HRESULT = -2146893041
SEC_E_OUT_OF_SEQUENCE: win32more.Windows.Win32.Foundation.HRESULT = -2146893040
SEC_E_NO_AUTHENTICATING_AUTHORITY: win32more.Windows.Win32.Foundation.HRESULT = -2146893039
SEC_I_CONTINUE_NEEDED: win32more.Windows.Win32.Foundation.HRESULT = 590610
SEC_I_COMPLETE_NEEDED: win32more.Windows.Win32.Foundation.HRESULT = 590611
SEC_I_COMPLETE_AND_CONTINUE: win32more.Windows.Win32.Foundation.HRESULT = 590612
SEC_I_LOCAL_LOGON: win32more.Windows.Win32.Foundation.HRESULT = 590613
SEC_I_GENERIC_EXTENSION_RECEIVED: win32more.Windows.Win32.Foundation.HRESULT = 590614
SEC_E_BAD_PKGID: win32more.Windows.Win32.Foundation.HRESULT = -2146893034
SEC_E_CONTEXT_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146893033
SEC_I_CONTEXT_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = 590615
SEC_E_INCOMPLETE_MESSAGE: win32more.Windows.Win32.Foundation.HRESULT = -2146893032
SEC_E_INCOMPLETE_CREDENTIALS: win32more.Windows.Win32.Foundation.HRESULT = -2146893024
SEC_E_BUFFER_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -2146893023
SEC_I_INCOMPLETE_CREDENTIALS: win32more.Windows.Win32.Foundation.HRESULT = 590624
SEC_I_RENEGOTIATE: win32more.Windows.Win32.Foundation.HRESULT = 590625
SEC_E_WRONG_PRINCIPAL: win32more.Windows.Win32.Foundation.HRESULT = -2146893022
SEC_I_NO_LSA_CONTEXT: win32more.Windows.Win32.Foundation.HRESULT = 590627
SEC_E_TIME_SKEW: win32more.Windows.Win32.Foundation.HRESULT = -2146893020
SEC_E_UNTRUSTED_ROOT: win32more.Windows.Win32.Foundation.HRESULT = -2146893019
SEC_E_ILLEGAL_MESSAGE: win32more.Windows.Win32.Foundation.HRESULT = -2146893018
SEC_E_CERT_UNKNOWN: win32more.Windows.Win32.Foundation.HRESULT = -2146893017
SEC_E_CERT_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146893016
SEC_E_ENCRYPT_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2146893015
SEC_E_DECRYPT_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2146893008
SEC_E_ALGORITHM_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146893007
SEC_E_SECURITY_QOS_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2146893006
SEC_E_UNFINISHED_CONTEXT_DELETED: win32more.Windows.Win32.Foundation.HRESULT = -2146893005
SEC_E_NO_TGT_REPLY: win32more.Windows.Win32.Foundation.HRESULT = -2146893004
SEC_E_NO_IP_ADDRESSES: win32more.Windows.Win32.Foundation.HRESULT = -2146893003
SEC_E_WRONG_CREDENTIAL_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2146893002
SEC_E_CRYPTO_SYSTEM_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2146893001
SEC_E_MAX_REFERRALS_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2146893000
SEC_E_MUST_BE_KDC: win32more.Windows.Win32.Foundation.HRESULT = -2146892999
SEC_E_STRONG_CRYPTO_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2146892998
SEC_E_TOO_MANY_PRINCIPALS: win32more.Windows.Win32.Foundation.HRESULT = -2146892997
SEC_E_NO_PA_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2146892996
SEC_E_PKINIT_NAME_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146892995
SEC_E_SMARTCARD_LOGON_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146892994
SEC_E_SHUTDOWN_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2146892993
SEC_E_KDC_INVALID_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -2146892992
SEC_E_KDC_UNABLE_TO_REFER: win32more.Windows.Win32.Foundation.HRESULT = -2146892991
SEC_E_KDC_UNKNOWN_ETYPE: win32more.Windows.Win32.Foundation.HRESULT = -2146892990
SEC_E_UNSUPPORTED_PREAUTH: win32more.Windows.Win32.Foundation.HRESULT = -2146892989
SEC_E_DELEGATION_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146892987
SEC_E_BAD_BINDINGS: win32more.Windows.Win32.Foundation.HRESULT = -2146892986
SEC_E_MULTIPLE_ACCOUNTS: win32more.Windows.Win32.Foundation.HRESULT = -2146892985
SEC_E_NO_KERB_KEY: win32more.Windows.Win32.Foundation.HRESULT = -2146892984
SEC_E_CERT_WRONG_USAGE: win32more.Windows.Win32.Foundation.HRESULT = -2146892983
SEC_E_DOWNGRADE_DETECTED: win32more.Windows.Win32.Foundation.HRESULT = -2146892976
SEC_E_SMARTCARD_CERT_REVOKED: win32more.Windows.Win32.Foundation.HRESULT = -2146892975
SEC_E_ISSUING_CA_UNTRUSTED: win32more.Windows.Win32.Foundation.HRESULT = -2146892974
SEC_E_REVOCATION_OFFLINE_C: win32more.Windows.Win32.Foundation.HRESULT = -2146892973
SEC_E_PKINIT_CLIENT_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2146892972
SEC_E_SMARTCARD_CERT_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146892971
SEC_E_NO_S4U_PROT_SUPPORT: win32more.Windows.Win32.Foundation.HRESULT = -2146892970
SEC_E_CROSSREALM_DELEGATION_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2146892969
SEC_E_REVOCATION_OFFLINE_KDC: win32more.Windows.Win32.Foundation.HRESULT = -2146892968
SEC_E_ISSUING_CA_UNTRUSTED_KDC: win32more.Windows.Win32.Foundation.HRESULT = -2146892967
SEC_E_KDC_CERT_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146892966
SEC_E_KDC_CERT_REVOKED: win32more.Windows.Win32.Foundation.HRESULT = -2146892965
SEC_I_SIGNATURE_NEEDED: win32more.Windows.Win32.Foundation.HRESULT = 590684
SEC_E_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.HRESULT = -2146892963
SEC_E_DELEGATION_POLICY: win32more.Windows.Win32.Foundation.HRESULT = -2146892962
SEC_E_POLICY_NLTM_ONLY: win32more.Windows.Win32.Foundation.HRESULT = -2146892961
SEC_I_NO_RENEGOTIATION: win32more.Windows.Win32.Foundation.HRESULT = 590688
SEC_E_NO_CONTEXT: win32more.Windows.Win32.Foundation.HRESULT = -2146892959
SEC_E_PKU2U_CERT_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2146892958
SEC_E_MUTUAL_AUTH_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2146892957
SEC_I_MESSAGE_FRAGMENT: win32more.Windows.Win32.Foundation.HRESULT = 590692
SEC_E_ONLY_HTTPS_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2146892955
SEC_I_CONTINUE_NEEDED_MESSAGE_OK: win32more.Windows.Win32.Foundation.HRESULT = 590694
SEC_E_APPLICATION_PROTOCOL_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146892953
SEC_I_ASYNC_CALL_PENDING: win32more.Windows.Win32.Foundation.HRESULT = 590696
SEC_E_INVALID_UPN_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2146892951
SEC_E_EXT_BUFFER_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -2146892950
SEC_E_INSUFFICIENT_BUFFERS: win32more.Windows.Win32.Foundation.HRESULT = -2146892949
SEC_E_NO_SPM: Int32 = -2146893052
SEC_E_NOT_SUPPORTED: Int32 = -2146893054
CRYPT_E_MSG_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2146889727
CRYPT_E_UNKNOWN_ALGO: win32more.Windows.Win32.Foundation.HRESULT = -2146889726
CRYPT_E_OID_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2146889725
CRYPT_E_INVALID_MSG_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2146889724
CRYPT_E_UNEXPECTED_ENCODING: win32more.Windows.Win32.Foundation.HRESULT = -2146889723
CRYPT_E_AUTH_ATTR_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2146889722
CRYPT_E_HASH_VALUE: win32more.Windows.Win32.Foundation.HRESULT = -2146889721
CRYPT_E_INVALID_INDEX: win32more.Windows.Win32.Foundation.HRESULT = -2146889720
CRYPT_E_ALREADY_DECRYPTED: win32more.Windows.Win32.Foundation.HRESULT = -2146889719
CRYPT_E_NOT_DECRYPTED: win32more.Windows.Win32.Foundation.HRESULT = -2146889718
CRYPT_E_RECIPIENT_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2146889717
CRYPT_E_CONTROL_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2146889716
CRYPT_E_ISSUER_SERIALNUMBER: win32more.Windows.Win32.Foundation.HRESULT = -2146889715
CRYPT_E_SIGNER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2146889714
CRYPT_E_ATTRIBUTES_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2146889713
CRYPT_E_STREAM_MSG_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -2146889712
CRYPT_E_STREAM_INSUFFICIENT_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2146889711
CRYPT_I_NEW_PROTECTION_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = 593938
CRYPT_E_BAD_LEN: win32more.Windows.Win32.Foundation.HRESULT = -2146885631
CRYPT_E_BAD_ENCODE: win32more.Windows.Win32.Foundation.HRESULT = -2146885630
CRYPT_E_FILE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2146885629
CRYPT_E_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2146885628
CRYPT_E_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2146885627
CRYPT_E_NO_PROVIDER: win32more.Windows.Win32.Foundation.HRESULT = -2146885626
CRYPT_E_SELF_SIGNED: win32more.Windows.Win32.Foundation.HRESULT = -2146885625
CRYPT_E_DELETED_PREV: win32more.Windows.Win32.Foundation.HRESULT = -2146885624
CRYPT_E_NO_MATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146885623
CRYPT_E_UNEXPECTED_MSG_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2146885622
CRYPT_E_NO_KEY_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2146885621
CRYPT_E_NO_DECRYPT_CERT: win32more.Windows.Win32.Foundation.HRESULT = -2146885620
CRYPT_E_BAD_MSG: win32more.Windows.Win32.Foundation.HRESULT = -2146885619
CRYPT_E_NO_SIGNER: win32more.Windows.Win32.Foundation.HRESULT = -2146885618
CRYPT_E_PENDING_CLOSE: win32more.Windows.Win32.Foundation.HRESULT = -2146885617
CRYPT_E_REVOKED: win32more.Windows.Win32.Foundation.HRESULT = -2146885616
CRYPT_E_NO_REVOCATION_DLL: win32more.Windows.Win32.Foundation.HRESULT = -2146885615
CRYPT_E_NO_REVOCATION_CHECK: win32more.Windows.Win32.Foundation.HRESULT = -2146885614
CRYPT_E_REVOCATION_OFFLINE: win32more.Windows.Win32.Foundation.HRESULT = -2146885613
CRYPT_E_NOT_IN_REVOCATION_DATABASE: win32more.Windows.Win32.Foundation.HRESULT = -2146885612
CRYPT_E_INVALID_NUMERIC_STRING: win32more.Windows.Win32.Foundation.HRESULT = -2146885600
CRYPT_E_INVALID_PRINTABLE_STRING: win32more.Windows.Win32.Foundation.HRESULT = -2146885599
CRYPT_E_INVALID_IA5_STRING: win32more.Windows.Win32.Foundation.HRESULT = -2146885598
CRYPT_E_INVALID_X500_STRING: win32more.Windows.Win32.Foundation.HRESULT = -2146885597
CRYPT_E_NOT_CHAR_STRING: win32more.Windows.Win32.Foundation.HRESULT = -2146885596
CRYPT_E_FILERESIZED: win32more.Windows.Win32.Foundation.HRESULT = -2146885595
CRYPT_E_SECURITY_SETTINGS: win32more.Windows.Win32.Foundation.HRESULT = -2146885594
CRYPT_E_NO_VERIFY_USAGE_DLL: win32more.Windows.Win32.Foundation.HRESULT = -2146885593
CRYPT_E_NO_VERIFY_USAGE_CHECK: win32more.Windows.Win32.Foundation.HRESULT = -2146885592
CRYPT_E_VERIFY_USAGE_OFFLINE: win32more.Windows.Win32.Foundation.HRESULT = -2146885591
CRYPT_E_NOT_IN_CTL: win32more.Windows.Win32.Foundation.HRESULT = -2146885590
CRYPT_E_NO_TRUSTED_SIGNER: win32more.Windows.Win32.Foundation.HRESULT = -2146885589
CRYPT_E_MISSING_PUBKEY_PARA: win32more.Windows.Win32.Foundation.HRESULT = -2146885588
CRYPT_E_OBJECT_LOCATOR_OBJECT_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2146885587
CRYPT_E_OSS_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2146881536
OSS_MORE_BUF: win32more.Windows.Win32.Foundation.HRESULT = -2146881535
OSS_NEGATIVE_UINTEGER: win32more.Windows.Win32.Foundation.HRESULT = -2146881534
OSS_PDU_RANGE: win32more.Windows.Win32.Foundation.HRESULT = -2146881533
OSS_MORE_INPUT: win32more.Windows.Win32.Foundation.HRESULT = -2146881532
OSS_DATA_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2146881531
OSS_BAD_ARG: win32more.Windows.Win32.Foundation.HRESULT = -2146881530
OSS_BAD_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2146881529
OSS_OUT_MEMORY: win32more.Windows.Win32.Foundation.HRESULT = -2146881528
OSS_PDU_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146881527
OSS_LIMITED: win32more.Windows.Win32.Foundation.HRESULT = -2146881526
OSS_BAD_PTR: win32more.Windows.Win32.Foundation.HRESULT = -2146881525
OSS_BAD_TIME: win32more.Windows.Win32.Foundation.HRESULT = -2146881524
OSS_INDEFINITE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2146881523
OSS_MEM_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2146881522
OSS_BAD_TABLE: win32more.Windows.Win32.Foundation.HRESULT = -2146881521
OSS_TOO_LONG: win32more.Windows.Win32.Foundation.HRESULT = -2146881520
OSS_CONSTRAINT_VIOLATED: win32more.Windows.Win32.Foundation.HRESULT = -2146881519
OSS_FATAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2146881518
OSS_ACCESS_SERIALIZATION_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2146881517
OSS_NULL_TBL: win32more.Windows.Win32.Foundation.HRESULT = -2146881516
OSS_NULL_FCN: win32more.Windows.Win32.Foundation.HRESULT = -2146881515
OSS_BAD_ENCRULES: win32more.Windows.Win32.Foundation.HRESULT = -2146881514
OSS_UNAVAIL_ENCRULES: win32more.Windows.Win32.Foundation.HRESULT = -2146881513
OSS_CANT_OPEN_TRACE_WINDOW: win32more.Windows.Win32.Foundation.HRESULT = -2146881512
OSS_UNIMPLEMENTED: win32more.Windows.Win32.Foundation.HRESULT = -2146881511
OSS_OID_DLL_NOT_LINKED: win32more.Windows.Win32.Foundation.HRESULT = -2146881510
OSS_CANT_OPEN_TRACE_FILE: win32more.Windows.Win32.Foundation.HRESULT = -2146881509
OSS_TRACE_FILE_ALREADY_OPEN: win32more.Windows.Win32.Foundation.HRESULT = -2146881508
OSS_TABLE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146881507
OSS_TYPE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2146881506
OSS_REAL_DLL_NOT_LINKED: win32more.Windows.Win32.Foundation.HRESULT = -2146881505
OSS_REAL_CODE_NOT_LINKED: win32more.Windows.Win32.Foundation.HRESULT = -2146881504
OSS_OUT_OF_RANGE: win32more.Windows.Win32.Foundation.HRESULT = -2146881503
OSS_COPIER_DLL_NOT_LINKED: win32more.Windows.Win32.Foundation.HRESULT = -2146881502
OSS_CONSTRAINT_DLL_NOT_LINKED: win32more.Windows.Win32.Foundation.HRESULT = -2146881501
OSS_COMPARATOR_DLL_NOT_LINKED: win32more.Windows.Win32.Foundation.HRESULT = -2146881500
OSS_COMPARATOR_CODE_NOT_LINKED: win32more.Windows.Win32.Foundation.HRESULT = -2146881499
OSS_MEM_MGR_DLL_NOT_LINKED: win32more.Windows.Win32.Foundation.HRESULT = -2146881498
OSS_PDV_DLL_NOT_LINKED: win32more.Windows.Win32.Foundation.HRESULT = -2146881497
OSS_PDV_CODE_NOT_LINKED: win32more.Windows.Win32.Foundation.HRESULT = -2146881496
OSS_API_DLL_NOT_LINKED: win32more.Windows.Win32.Foundation.HRESULT = -2146881495
OSS_BERDER_DLL_NOT_LINKED: win32more.Windows.Win32.Foundation.HRESULT = -2146881494
OSS_PER_DLL_NOT_LINKED: win32more.Windows.Win32.Foundation.HRESULT = -2146881493
OSS_OPEN_TYPE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2146881492
OSS_MUTEX_NOT_CREATED: win32more.Windows.Win32.Foundation.HRESULT = -2146881491
OSS_CANT_CLOSE_TRACE_FILE: win32more.Windows.Win32.Foundation.HRESULT = -2146881490
CRYPT_E_ASN1_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2146881280
CRYPT_E_ASN1_INTERNAL: win32more.Windows.Win32.Foundation.HRESULT = -2146881279
CRYPT_E_ASN1_EOD: win32more.Windows.Win32.Foundation.HRESULT = -2146881278
CRYPT_E_ASN1_CORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -2146881277
CRYPT_E_ASN1_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -2146881276
CRYPT_E_ASN1_CONSTRAINT: win32more.Windows.Win32.Foundation.HRESULT = -2146881275
CRYPT_E_ASN1_MEMORY: win32more.Windows.Win32.Foundation.HRESULT = -2146881274
CRYPT_E_ASN1_OVERFLOW: win32more.Windows.Win32.Foundation.HRESULT = -2146881273
CRYPT_E_ASN1_BADPDU: win32more.Windows.Win32.Foundation.HRESULT = -2146881272
CRYPT_E_ASN1_BADARGS: win32more.Windows.Win32.Foundation.HRESULT = -2146881271
CRYPT_E_ASN1_BADREAL: win32more.Windows.Win32.Foundation.HRESULT = -2146881270
CRYPT_E_ASN1_BADTAG: win32more.Windows.Win32.Foundation.HRESULT = -2146881269
CRYPT_E_ASN1_CHOICE: win32more.Windows.Win32.Foundation.HRESULT = -2146881268
CRYPT_E_ASN1_RULE: win32more.Windows.Win32.Foundation.HRESULT = -2146881267
CRYPT_E_ASN1_UTF8: win32more.Windows.Win32.Foundation.HRESULT = -2146881266
CRYPT_E_ASN1_PDU_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2146881229
CRYPT_E_ASN1_NYI: win32more.Windows.Win32.Foundation.HRESULT = -2146881228
CRYPT_E_ASN1_EXTENDED: win32more.Windows.Win32.Foundation.HRESULT = -2146881023
CRYPT_E_ASN1_NOEOD: win32more.Windows.Win32.Foundation.HRESULT = -2146881022
CERTSRV_E_BAD_REQUESTSUBJECT: win32more.Windows.Win32.Foundation.HRESULT = -2146877439
CERTSRV_E_NO_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -2146877438
CERTSRV_E_BAD_REQUESTSTATUS: win32more.Windows.Win32.Foundation.HRESULT = -2146877437
CERTSRV_E_PROPERTY_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = -2146877436
CERTSRV_E_INVALID_CA_CERTIFICATE: win32more.Windows.Win32.Foundation.HRESULT = -2146877435
CERTSRV_E_SERVER_SUSPENDED: win32more.Windows.Win32.Foundation.HRESULT = -2146877434
CERTSRV_E_ENCODING_LENGTH: win32more.Windows.Win32.Foundation.HRESULT = -2146877433
CERTSRV_E_ROLECONFLICT: win32more.Windows.Win32.Foundation.HRESULT = -2146877432
CERTSRV_E_RESTRICTEDOFFICER: win32more.Windows.Win32.Foundation.HRESULT = -2146877431
CERTSRV_E_KEY_ARCHIVAL_NOT_CONFIGURED: win32more.Windows.Win32.Foundation.HRESULT = -2146877430
CERTSRV_E_NO_VALID_KRA: win32more.Windows.Win32.Foundation.HRESULT = -2146877429
CERTSRV_E_BAD_REQUEST_KEY_ARCHIVAL: win32more.Windows.Win32.Foundation.HRESULT = -2146877428
CERTSRV_E_NO_CAADMIN_DEFINED: win32more.Windows.Win32.Foundation.HRESULT = -2146877427
CERTSRV_E_BAD_RENEWAL_CERT_ATTRIBUTE: win32more.Windows.Win32.Foundation.HRESULT = -2146877426
CERTSRV_E_NO_DB_SESSIONS: win32more.Windows.Win32.Foundation.HRESULT = -2146877425
CERTSRV_E_ALIGNMENT_FAULT: win32more.Windows.Win32.Foundation.HRESULT = -2146877424
CERTSRV_E_ENROLL_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2146877423
CERTSRV_E_TEMPLATE_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2146877422
CERTSRV_E_DOWNLEVEL_DC_SSL_OR_UPGRADE: win32more.Windows.Win32.Foundation.HRESULT = -2146877421
CERTSRV_E_ADMIN_DENIED_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -2146877420
CERTSRV_E_NO_POLICY_SERVER: win32more.Windows.Win32.Foundation.HRESULT = -2146877419
CERTSRV_E_WEAK_SIGNATURE_OR_KEY: win32more.Windows.Win32.Foundation.HRESULT = -2146877418
CERTSRV_E_KEY_ATTESTATION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2146877417
CERTSRV_E_ENCRYPTION_CERT_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146877416
CERTSRV_E_UNSUPPORTED_CERT_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2146875392
CERTSRV_E_NO_CERT_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2146875391
CERTSRV_E_TEMPLATE_CONFLICT: win32more.Windows.Win32.Foundation.HRESULT = -2146875390
CERTSRV_E_SUBJECT_ALT_NAME_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146875389
CERTSRV_E_ARCHIVED_KEY_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146875388
CERTSRV_E_SMIME_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146875387
CERTSRV_E_BAD_RENEWAL_SUBJECT: win32more.Windows.Win32.Foundation.HRESULT = -2146875386
CERTSRV_E_BAD_TEMPLATE_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2146875385
CERTSRV_E_TEMPLATE_POLICY_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146875384
CERTSRV_E_SIGNATURE_POLICY_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146875383
CERTSRV_E_SIGNATURE_COUNT: win32more.Windows.Win32.Foundation.HRESULT = -2146875382
CERTSRV_E_SIGNATURE_REJECTED: win32more.Windows.Win32.Foundation.HRESULT = -2146875381
CERTSRV_E_ISSUANCE_POLICY_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146875380
CERTSRV_E_SUBJECT_UPN_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146875379
CERTSRV_E_SUBJECT_DIRECTORY_GUID_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146875378
CERTSRV_E_SUBJECT_DNS_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146875377
CERTSRV_E_ARCHIVED_KEY_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2146875376
CERTSRV_E_KEY_LENGTH: win32more.Windows.Win32.Foundation.HRESULT = -2146875375
CERTSRV_E_SUBJECT_EMAIL_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146875374
CERTSRV_E_UNKNOWN_CERT_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2146875373
CERTSRV_E_CERT_TYPE_OVERLAP: win32more.Windows.Win32.Foundation.HRESULT = -2146875372
CERTSRV_E_TOO_MANY_SIGNATURES: win32more.Windows.Win32.Foundation.HRESULT = -2146875371
CERTSRV_E_RENEWAL_BAD_PUBLIC_KEY: win32more.Windows.Win32.Foundation.HRESULT = -2146875370
CERTSRV_E_INVALID_EK: win32more.Windows.Win32.Foundation.HRESULT = -2146875369
CERTSRV_E_INVALID_IDBINDING: win32more.Windows.Win32.Foundation.HRESULT = -2146875368
CERTSRV_E_INVALID_ATTESTATION: win32more.Windows.Win32.Foundation.HRESULT = -2146875367
CERTSRV_E_KEY_ATTESTATION: win32more.Windows.Win32.Foundation.HRESULT = -2146875366
CERTSRV_E_CORRUPT_KEY_ATTESTATION: win32more.Windows.Win32.Foundation.HRESULT = -2146875365
CERTSRV_E_EXPIRED_CHALLENGE: win32more.Windows.Win32.Foundation.HRESULT = -2146875364
CERTSRV_E_INVALID_RESPONSE: win32more.Windows.Win32.Foundation.HRESULT = -2146875363
CERTSRV_E_INVALID_REQUESTID: win32more.Windows.Win32.Foundation.HRESULT = -2146875362
CERTSRV_E_REQUEST_PRECERTIFICATE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146875361
CERTSRV_E_PENDING_CLIENT_RESPONSE: win32more.Windows.Win32.Foundation.HRESULT = -2146875360
CERTSRV_E_SEC_EXT_DIRECTORY_SID_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146875359
XENROLL_E_KEY_NOT_EXPORTABLE: win32more.Windows.Win32.Foundation.HRESULT = -2146873344
XENROLL_E_CANNOT_ADD_ROOT_CERT: win32more.Windows.Win32.Foundation.HRESULT = -2146873343
XENROLL_E_RESPONSE_KA_HASH_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2146873342
XENROLL_E_RESPONSE_UNEXPECTED_KA_HASH: win32more.Windows.Win32.Foundation.HRESULT = -2146873341
XENROLL_E_RESPONSE_KA_HASH_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146873340
XENROLL_E_KEYSPEC_SMIME_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146873339
TRUST_E_SYSTEM_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2146869247
TRUST_E_NO_SIGNER_CERT: win32more.Windows.Win32.Foundation.HRESULT = -2146869246
TRUST_E_COUNTER_SIGNER: win32more.Windows.Win32.Foundation.HRESULT = -2146869245
TRUST_E_CERT_SIGNATURE: win32more.Windows.Win32.Foundation.HRESULT = -2146869244
TRUST_E_TIME_STAMP: win32more.Windows.Win32.Foundation.HRESULT = -2146869243
TRUST_E_BAD_DIGEST: win32more.Windows.Win32.Foundation.HRESULT = -2146869232
TRUST_E_MALFORMED_SIGNATURE: win32more.Windows.Win32.Foundation.HRESULT = -2146869231
TRUST_E_BASIC_CONSTRAINTS: win32more.Windows.Win32.Foundation.HRESULT = -2146869223
TRUST_E_FINANCIAL_CRITERIA: win32more.Windows.Win32.Foundation.HRESULT = -2146869218
MSSIPOTF_E_OUTOFMEMRANGE: win32more.Windows.Win32.Foundation.HRESULT = -2146865151
MSSIPOTF_E_CANTGETOBJECT: win32more.Windows.Win32.Foundation.HRESULT = -2146865150
MSSIPOTF_E_NOHEADTABLE: win32more.Windows.Win32.Foundation.HRESULT = -2146865149
MSSIPOTF_E_BAD_MAGICNUMBER: win32more.Windows.Win32.Foundation.HRESULT = -2146865148
MSSIPOTF_E_BAD_OFFSET_TABLE: win32more.Windows.Win32.Foundation.HRESULT = -2146865147
MSSIPOTF_E_TABLE_TAGORDER: win32more.Windows.Win32.Foundation.HRESULT = -2146865146
MSSIPOTF_E_TABLE_LONGWORD: win32more.Windows.Win32.Foundation.HRESULT = -2146865145
MSSIPOTF_E_BAD_FIRST_TABLE_PLACEMENT: win32more.Windows.Win32.Foundation.HRESULT = -2146865144
MSSIPOTF_E_TABLES_OVERLAP: win32more.Windows.Win32.Foundation.HRESULT = -2146865143
MSSIPOTF_E_TABLE_PADBYTES: win32more.Windows.Win32.Foundation.HRESULT = -2146865142
MSSIPOTF_E_FILETOOSMALL: win32more.Windows.Win32.Foundation.HRESULT = -2146865141
MSSIPOTF_E_TABLE_CHECKSUM: win32more.Windows.Win32.Foundation.HRESULT = -2146865140
MSSIPOTF_E_FILE_CHECKSUM: win32more.Windows.Win32.Foundation.HRESULT = -2146865139
MSSIPOTF_E_FAILED_POLICY: win32more.Windows.Win32.Foundation.HRESULT = -2146865136
MSSIPOTF_E_FAILED_HINTS_CHECK: win32more.Windows.Win32.Foundation.HRESULT = -2146865135
MSSIPOTF_E_NOT_OPENTYPE: win32more.Windows.Win32.Foundation.HRESULT = -2146865134
MSSIPOTF_E_FILE: win32more.Windows.Win32.Foundation.HRESULT = -2146865133
MSSIPOTF_E_CRYPT: win32more.Windows.Win32.Foundation.HRESULT = -2146865132
MSSIPOTF_E_BADVERSION: win32more.Windows.Win32.Foundation.HRESULT = -2146865131
MSSIPOTF_E_DSIG_STRUCTURE: win32more.Windows.Win32.Foundation.HRESULT = -2146865130
MSSIPOTF_E_PCONST_CHECK: win32more.Windows.Win32.Foundation.HRESULT = -2146865129
MSSIPOTF_E_STRUCTURE: win32more.Windows.Win32.Foundation.HRESULT = -2146865128
ERROR_CRED_REQUIRES_CONFIRMATION: win32more.Windows.Win32.Foundation.HRESULT = -2146865127
NTE_OP_OK: UInt32 = 0
TRUST_E_PROVIDER_UNKNOWN: win32more.Windows.Win32.Foundation.HRESULT = -2146762751
TRUST_E_ACTION_UNKNOWN: win32more.Windows.Win32.Foundation.HRESULT = -2146762750
TRUST_E_SUBJECT_FORM_UNKNOWN: win32more.Windows.Win32.Foundation.HRESULT = -2146762749
TRUST_E_SUBJECT_NOT_TRUSTED: win32more.Windows.Win32.Foundation.HRESULT = -2146762748
DIGSIG_E_ENCODE: win32more.Windows.Win32.Foundation.HRESULT = -2146762747
DIGSIG_E_DECODE: win32more.Windows.Win32.Foundation.HRESULT = -2146762746
DIGSIG_E_EXTENSIBILITY: win32more.Windows.Win32.Foundation.HRESULT = -2146762745
DIGSIG_E_CRYPTO: win32more.Windows.Win32.Foundation.HRESULT = -2146762744
PERSIST_E_SIZEDEFINITE: win32more.Windows.Win32.Foundation.HRESULT = -2146762743
PERSIST_E_SIZEINDEFINITE: win32more.Windows.Win32.Foundation.HRESULT = -2146762742
PERSIST_E_NOTSELFSIZING: win32more.Windows.Win32.Foundation.HRESULT = -2146762741
TRUST_E_NOSIGNATURE: win32more.Windows.Win32.Foundation.HRESULT = -2146762496
CERT_E_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146762495
CERT_E_VALIDITYPERIODNESTING: win32more.Windows.Win32.Foundation.HRESULT = -2146762494
CERT_E_ROLE: win32more.Windows.Win32.Foundation.HRESULT = -2146762493
CERT_E_PATHLENCONST: win32more.Windows.Win32.Foundation.HRESULT = -2146762492
CERT_E_CRITICAL: win32more.Windows.Win32.Foundation.HRESULT = -2146762491
CERT_E_PURPOSE: win32more.Windows.Win32.Foundation.HRESULT = -2146762490
CERT_E_ISSUERCHAINING: win32more.Windows.Win32.Foundation.HRESULT = -2146762489
CERT_E_MALFORMED: win32more.Windows.Win32.Foundation.HRESULT = -2146762488
CERT_E_UNTRUSTEDROOT: win32more.Windows.Win32.Foundation.HRESULT = -2146762487
CERT_E_CHAINING: win32more.Windows.Win32.Foundation.HRESULT = -2146762486
TRUST_E_FAIL: win32more.Windows.Win32.Foundation.HRESULT = -2146762485
CERT_E_REVOKED: win32more.Windows.Win32.Foundation.HRESULT = -2146762484
CERT_E_UNTRUSTEDTESTROOT: win32more.Windows.Win32.Foundation.HRESULT = -2146762483
CERT_E_REVOCATION_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2146762482
CERT_E_CN_NO_MATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146762481
CERT_E_WRONG_USAGE: win32more.Windows.Win32.Foundation.HRESULT = -2146762480
TRUST_E_EXPLICIT_DISTRUST: win32more.Windows.Win32.Foundation.HRESULT = -2146762479
CERT_E_UNTRUSTEDCA: win32more.Windows.Win32.Foundation.HRESULT = -2146762478
CERT_E_INVALID_POLICY: win32more.Windows.Win32.Foundation.HRESULT = -2146762477
CERT_E_INVALID_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2146762476
SPAPI_E_EXPECTED_SECTION_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2146500608
SPAPI_E_BAD_SECTION_NAME_LINE: win32more.Windows.Win32.Foundation.HRESULT = -2146500607
SPAPI_E_SECTION_NAME_TOO_LONG: win32more.Windows.Win32.Foundation.HRESULT = -2146500606
SPAPI_E_GENERAL_SYNTAX: win32more.Windows.Win32.Foundation.HRESULT = -2146500605
SPAPI_E_WRONG_INF_STYLE: win32more.Windows.Win32.Foundation.HRESULT = -2146500352
SPAPI_E_SECTION_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2146500351
SPAPI_E_LINE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2146500350
SPAPI_E_NO_BACKUP: win32more.Windows.Win32.Foundation.HRESULT = -2146500349
SPAPI_E_NO_ASSOCIATED_CLASS: win32more.Windows.Win32.Foundation.HRESULT = -2146500096
SPAPI_E_CLASS_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146500095
SPAPI_E_DUPLICATE_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2146500094
SPAPI_E_NO_DRIVER_SELECTED: win32more.Windows.Win32.Foundation.HRESULT = -2146500093
SPAPI_E_KEY_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.HRESULT = -2146500092
SPAPI_E_INVALID_DEVINST_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2146500091
SPAPI_E_INVALID_CLASS: win32more.Windows.Win32.Foundation.HRESULT = -2146500090
SPAPI_E_DEVINST_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2146500089
SPAPI_E_DEVINFO_NOT_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2146500088
SPAPI_E_INVALID_REG_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2146500087
SPAPI_E_NO_INF: win32more.Windows.Win32.Foundation.HRESULT = -2146500086
SPAPI_E_NO_SUCH_DEVINST: win32more.Windows.Win32.Foundation.HRESULT = -2146500085
SPAPI_E_CANT_LOAD_CLASS_ICON: win32more.Windows.Win32.Foundation.HRESULT = -2146500084
SPAPI_E_INVALID_CLASS_INSTALLER: win32more.Windows.Win32.Foundation.HRESULT = -2146500083
SPAPI_E_DI_DO_DEFAULT: win32more.Windows.Win32.Foundation.HRESULT = -2146500082
SPAPI_E_DI_NOFILECOPY: win32more.Windows.Win32.Foundation.HRESULT = -2146500081
SPAPI_E_INVALID_HWPROFILE: win32more.Windows.Win32.Foundation.HRESULT = -2146500080
SPAPI_E_NO_DEVICE_SELECTED: win32more.Windows.Win32.Foundation.HRESULT = -2146500079
SPAPI_E_DEVINFO_LIST_LOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2146500078
SPAPI_E_DEVINFO_DATA_LOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2146500077
SPAPI_E_DI_BAD_PATH: win32more.Windows.Win32.Foundation.HRESULT = -2146500076
SPAPI_E_NO_CLASSINSTALL_PARAMS: win32more.Windows.Win32.Foundation.HRESULT = -2146500075
SPAPI_E_FILEQUEUE_LOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2146500074
SPAPI_E_BAD_SERVICE_INSTALLSECT: win32more.Windows.Win32.Foundation.HRESULT = -2146500073
SPAPI_E_NO_CLASS_DRIVER_LIST: win32more.Windows.Win32.Foundation.HRESULT = -2146500072
SPAPI_E_NO_ASSOCIATED_SERVICE: win32more.Windows.Win32.Foundation.HRESULT = -2146500071
SPAPI_E_NO_DEFAULT_DEVICE_INTERFACE: win32more.Windows.Win32.Foundation.HRESULT = -2146500070
SPAPI_E_DEVICE_INTERFACE_ACTIVE: win32more.Windows.Win32.Foundation.HRESULT = -2146500069
SPAPI_E_DEVICE_INTERFACE_REMOVED: win32more.Windows.Win32.Foundation.HRESULT = -2146500068
SPAPI_E_BAD_INTERFACE_INSTALLSECT: win32more.Windows.Win32.Foundation.HRESULT = -2146500067
SPAPI_E_NO_SUCH_INTERFACE_CLASS: win32more.Windows.Win32.Foundation.HRESULT = -2146500066
SPAPI_E_INVALID_REFERENCE_STRING: win32more.Windows.Win32.Foundation.HRESULT = -2146500065
SPAPI_E_INVALID_MACHINENAME: win32more.Windows.Win32.Foundation.HRESULT = -2146500064
SPAPI_E_REMOTE_COMM_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2146500063
SPAPI_E_MACHINE_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2146500062
SPAPI_E_NO_CONFIGMGR_SERVICES: win32more.Windows.Win32.Foundation.HRESULT = -2146500061
SPAPI_E_INVALID_PROPPAGE_PROVIDER: win32more.Windows.Win32.Foundation.HRESULT = -2146500060
SPAPI_E_NO_SUCH_DEVICE_INTERFACE: win32more.Windows.Win32.Foundation.HRESULT = -2146500059
SPAPI_E_DI_POSTPROCESSING_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146500058
SPAPI_E_INVALID_COINSTALLER: win32more.Windows.Win32.Foundation.HRESULT = -2146500057
SPAPI_E_NO_COMPAT_DRIVERS: win32more.Windows.Win32.Foundation.HRESULT = -2146500056
SPAPI_E_NO_DEVICE_ICON: win32more.Windows.Win32.Foundation.HRESULT = -2146500055
SPAPI_E_INVALID_INF_LOGCONFIG: win32more.Windows.Win32.Foundation.HRESULT = -2146500054
SPAPI_E_DI_DONT_INSTALL: win32more.Windows.Win32.Foundation.HRESULT = -2146500053
SPAPI_E_INVALID_FILTER_DRIVER: win32more.Windows.Win32.Foundation.HRESULT = -2146500052
SPAPI_E_NON_WINDOWS_NT_DRIVER: win32more.Windows.Win32.Foundation.HRESULT = -2146500051
SPAPI_E_NON_WINDOWS_DRIVER: win32more.Windows.Win32.Foundation.HRESULT = -2146500050
SPAPI_E_NO_CATALOG_FOR_OEM_INF: win32more.Windows.Win32.Foundation.HRESULT = -2146500049
SPAPI_E_DEVINSTALL_QUEUE_NONNATIVE: win32more.Windows.Win32.Foundation.HRESULT = -2146500048
SPAPI_E_NOT_DISABLEABLE: win32more.Windows.Win32.Foundation.HRESULT = -2146500047
SPAPI_E_CANT_REMOVE_DEVINST: win32more.Windows.Win32.Foundation.HRESULT = -2146500046
SPAPI_E_INVALID_TARGET: win32more.Windows.Win32.Foundation.HRESULT = -2146500045
SPAPI_E_DRIVER_NONNATIVE: win32more.Windows.Win32.Foundation.HRESULT = -2146500044
SPAPI_E_IN_WOW64: win32more.Windows.Win32.Foundation.HRESULT = -2146500043
SPAPI_E_SET_SYSTEM_RESTORE_POINT: win32more.Windows.Win32.Foundation.HRESULT = -2146500042
SPAPI_E_INCORRECTLY_COPIED_INF: win32more.Windows.Win32.Foundation.HRESULT = -2146500041
SPAPI_E_SCE_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2146500040
SPAPI_E_UNKNOWN_EXCEPTION: win32more.Windows.Win32.Foundation.HRESULT = -2146500039
SPAPI_E_PNP_REGISTRY_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2146500038
SPAPI_E_REMOTE_REQUEST_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2146500037
SPAPI_E_NOT_AN_INSTALLED_OEM_INF: win32more.Windows.Win32.Foundation.HRESULT = -2146500036
SPAPI_E_INF_IN_USE_BY_DEVICES: win32more.Windows.Win32.Foundation.HRESULT = -2146500035
SPAPI_E_DI_FUNCTION_OBSOLETE: win32more.Windows.Win32.Foundation.HRESULT = -2146500034
SPAPI_E_NO_AUTHENTICODE_CATALOG: win32more.Windows.Win32.Foundation.HRESULT = -2146500033
SPAPI_E_AUTHENTICODE_DISALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2146500032
SPAPI_E_AUTHENTICODE_TRUSTED_PUBLISHER: win32more.Windows.Win32.Foundation.HRESULT = -2146500031
SPAPI_E_AUTHENTICODE_TRUST_NOT_ESTABLISHED: win32more.Windows.Win32.Foundation.HRESULT = -2146500030
SPAPI_E_AUTHENTICODE_PUBLISHER_NOT_TRUSTED: win32more.Windows.Win32.Foundation.HRESULT = -2146500029
SPAPI_E_SIGNATURE_OSATTRIBUTE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146500028
SPAPI_E_ONLY_VALIDATE_VIA_AUTHENTICODE: win32more.Windows.Win32.Foundation.HRESULT = -2146500027
SPAPI_E_DEVICE_INSTALLER_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -2146500026
SPAPI_E_DRIVER_STORE_ADD_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2146500025
SPAPI_E_DEVICE_INSTALL_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2146500024
SPAPI_E_DRIVER_INSTALL_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2146500023
SPAPI_E_WRONG_INF_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2146500022
SPAPI_E_FILE_HASH_NOT_IN_CATALOG: win32more.Windows.Win32.Foundation.HRESULT = -2146500021
SPAPI_E_DRIVER_STORE_DELETE_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2146500020
SPAPI_E_UNRECOVERABLE_STACK_OVERFLOW: win32more.Windows.Win32.Foundation.HRESULT = -2146499840
SPAPI_E_ERROR_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -2146496512
SCARD_F_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2146435071
SCARD_E_CANCELLED: win32more.Windows.Win32.Foundation.HRESULT = -2146435070
SCARD_E_INVALID_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2146435069
SCARD_E_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.HRESULT = -2146435068
SCARD_E_INVALID_TARGET: win32more.Windows.Win32.Foundation.HRESULT = -2146435067
SCARD_E_NO_MEMORY: win32more.Windows.Win32.Foundation.HRESULT = -2146435066
SCARD_F_WAITED_TOO_LONG: win32more.Windows.Win32.Foundation.HRESULT = -2146435065
SCARD_E_INSUFFICIENT_BUFFER: win32more.Windows.Win32.Foundation.HRESULT = -2146435064
SCARD_E_UNKNOWN_READER: win32more.Windows.Win32.Foundation.HRESULT = -2146435063
SCARD_E_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2146435062
SCARD_E_SHARING_VIOLATION: win32more.Windows.Win32.Foundation.HRESULT = -2146435061
SCARD_E_NO_SMARTCARD: win32more.Windows.Win32.Foundation.HRESULT = -2146435060
SCARD_E_UNKNOWN_CARD: win32more.Windows.Win32.Foundation.HRESULT = -2146435059
SCARD_E_CANT_DISPOSE: win32more.Windows.Win32.Foundation.HRESULT = -2146435058
SCARD_E_PROTO_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146435057
SCARD_E_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -2146435056
SCARD_E_INVALID_VALUE: win32more.Windows.Win32.Foundation.HRESULT = -2146435055
SCARD_E_SYSTEM_CANCELLED: win32more.Windows.Win32.Foundation.HRESULT = -2146435054
SCARD_F_COMM_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2146435053
SCARD_F_UNKNOWN_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2146435052
SCARD_E_INVALID_ATR: win32more.Windows.Win32.Foundation.HRESULT = -2146435051
SCARD_E_NOT_TRANSACTED: win32more.Windows.Win32.Foundation.HRESULT = -2146435050
SCARD_E_READER_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2146435049
SCARD_P_SHUTDOWN: win32more.Windows.Win32.Foundation.HRESULT = -2146435048
SCARD_E_PCI_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -2146435047
SCARD_E_READER_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2146435046
SCARD_E_DUPLICATE_READER: win32more.Windows.Win32.Foundation.HRESULT = -2146435045
SCARD_E_CARD_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2146435044
SCARD_E_NO_SERVICE: win32more.Windows.Win32.Foundation.HRESULT = -2146435043
SCARD_E_SERVICE_STOPPED: win32more.Windows.Win32.Foundation.HRESULT = -2146435042
SCARD_E_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2146435041
SCARD_E_ICC_INSTALLATION: win32more.Windows.Win32.Foundation.HRESULT = -2146435040
SCARD_E_ICC_CREATEORDER: win32more.Windows.Win32.Foundation.HRESULT = -2146435039
SCARD_E_UNSUPPORTED_FEATURE: win32more.Windows.Win32.Foundation.HRESULT = -2146435038
SCARD_E_DIR_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2146435037
SCARD_E_FILE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2146435036
SCARD_E_NO_DIR: win32more.Windows.Win32.Foundation.HRESULT = -2146435035
SCARD_E_NO_FILE: win32more.Windows.Win32.Foundation.HRESULT = -2146435034
SCARD_E_NO_ACCESS: win32more.Windows.Win32.Foundation.HRESULT = -2146435033
SCARD_E_WRITE_TOO_MANY: win32more.Windows.Win32.Foundation.HRESULT = -2146435032
SCARD_E_BAD_SEEK: win32more.Windows.Win32.Foundation.HRESULT = -2146435031
SCARD_E_INVALID_CHV: win32more.Windows.Win32.Foundation.HRESULT = -2146435030
SCARD_E_UNKNOWN_RES_MNG: win32more.Windows.Win32.Foundation.HRESULT = -2146435029
SCARD_E_NO_SUCH_CERTIFICATE: win32more.Windows.Win32.Foundation.HRESULT = -2146435028
SCARD_E_CERTIFICATE_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2146435027
SCARD_E_NO_READERS_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2146435026
SCARD_E_COMM_DATA_LOST: win32more.Windows.Win32.Foundation.HRESULT = -2146435025
SCARD_E_NO_KEY_CONTAINER: win32more.Windows.Win32.Foundation.HRESULT = -2146435024
SCARD_E_SERVER_TOO_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -2146435023
SCARD_E_PIN_CACHE_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -2146435022
SCARD_E_NO_PIN_CACHE: win32more.Windows.Win32.Foundation.HRESULT = -2146435021
SCARD_E_READ_ONLY_CARD: win32more.Windows.Win32.Foundation.HRESULT = -2146435020
SCARD_W_UNSUPPORTED_CARD: win32more.Windows.Win32.Foundation.HRESULT = -2146434971
SCARD_W_UNRESPONSIVE_CARD: win32more.Windows.Win32.Foundation.HRESULT = -2146434970
SCARD_W_UNPOWERED_CARD: win32more.Windows.Win32.Foundation.HRESULT = -2146434969
SCARD_W_RESET_CARD: win32more.Windows.Win32.Foundation.HRESULT = -2146434968
SCARD_W_REMOVED_CARD: win32more.Windows.Win32.Foundation.HRESULT = -2146434967
SCARD_W_SECURITY_VIOLATION: win32more.Windows.Win32.Foundation.HRESULT = -2146434966
SCARD_W_WRONG_CHV: win32more.Windows.Win32.Foundation.HRESULT = -2146434965
SCARD_W_CHV_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2146434964
SCARD_W_EOF: win32more.Windows.Win32.Foundation.HRESULT = -2146434963
SCARD_W_CANCELLED_BY_USER: win32more.Windows.Win32.Foundation.HRESULT = -2146434962
SCARD_W_CARD_NOT_AUTHENTICATED: win32more.Windows.Win32.Foundation.HRESULT = -2146434961
SCARD_W_CACHE_ITEM_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2146434960
SCARD_W_CACHE_ITEM_STALE: win32more.Windows.Win32.Foundation.HRESULT = -2146434959
SCARD_W_CACHE_ITEM_TOO_BIG: win32more.Windows.Win32.Foundation.HRESULT = -2146434958
COMADMIN_E_OBJECTERRORS: win32more.Windows.Win32.Foundation.HRESULT = -2146368511
COMADMIN_E_OBJECTINVALID: win32more.Windows.Win32.Foundation.HRESULT = -2146368510
COMADMIN_E_KEYMISSING: win32more.Windows.Win32.Foundation.HRESULT = -2146368509
COMADMIN_E_ALREADYINSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -2146368508
COMADMIN_E_APP_FILE_WRITEFAIL: win32more.Windows.Win32.Foundation.HRESULT = -2146368505
COMADMIN_E_APP_FILE_READFAIL: win32more.Windows.Win32.Foundation.HRESULT = -2146368504
COMADMIN_E_APP_FILE_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2146368503
COMADMIN_E_BADPATH: win32more.Windows.Win32.Foundation.HRESULT = -2146368502
COMADMIN_E_APPLICATIONEXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2146368501
COMADMIN_E_ROLEEXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2146368500
COMADMIN_E_CANTCOPYFILE: win32more.Windows.Win32.Foundation.HRESULT = -2146368499
COMADMIN_E_NOUSER: win32more.Windows.Win32.Foundation.HRESULT = -2146368497
COMADMIN_E_INVALIDUSERIDS: win32more.Windows.Win32.Foundation.HRESULT = -2146368496
COMADMIN_E_NOREGISTRYCLSID: win32more.Windows.Win32.Foundation.HRESULT = -2146368495
COMADMIN_E_BADREGISTRYPROGID: win32more.Windows.Win32.Foundation.HRESULT = -2146368494
COMADMIN_E_AUTHENTICATIONLEVEL: win32more.Windows.Win32.Foundation.HRESULT = -2146368493
COMADMIN_E_USERPASSWDNOTVALID: win32more.Windows.Win32.Foundation.HRESULT = -2146368492
COMADMIN_E_CLSIDORIIDMISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146368488
COMADMIN_E_REMOTEINTERFACE: win32more.Windows.Win32.Foundation.HRESULT = -2146368487
COMADMIN_E_DLLREGISTERSERVER: win32more.Windows.Win32.Foundation.HRESULT = -2146368486
COMADMIN_E_NOSERVERSHARE: win32more.Windows.Win32.Foundation.HRESULT = -2146368485
COMADMIN_E_DLLLOADFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2146368483
COMADMIN_E_BADREGISTRYLIBID: win32more.Windows.Win32.Foundation.HRESULT = -2146368482
COMADMIN_E_APPDIRNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2146368481
COMADMIN_E_REGISTRARFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2146368477
COMADMIN_E_COMPFILE_DOESNOTEXIST: win32more.Windows.Win32.Foundation.HRESULT = -2146368476
COMADMIN_E_COMPFILE_LOADDLLFAIL: win32more.Windows.Win32.Foundation.HRESULT = -2146368475
COMADMIN_E_COMPFILE_GETCLASSOBJ: win32more.Windows.Win32.Foundation.HRESULT = -2146368474
COMADMIN_E_COMPFILE_CLASSNOTAVAIL: win32more.Windows.Win32.Foundation.HRESULT = -2146368473
COMADMIN_E_COMPFILE_BADTLB: win32more.Windows.Win32.Foundation.HRESULT = -2146368472
COMADMIN_E_COMPFILE_NOTINSTALLABLE: win32more.Windows.Win32.Foundation.HRESULT = -2146368471
COMADMIN_E_NOTCHANGEABLE: win32more.Windows.Win32.Foundation.HRESULT = -2146368470
COMADMIN_E_NOTDELETEABLE: win32more.Windows.Win32.Foundation.HRESULT = -2146368469
COMADMIN_E_SESSION: win32more.Windows.Win32.Foundation.HRESULT = -2146368468
COMADMIN_E_COMP_MOVE_LOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2146368467
COMADMIN_E_COMP_MOVE_BAD_DEST: win32more.Windows.Win32.Foundation.HRESULT = -2146368466
COMADMIN_E_REGISTERTLB: win32more.Windows.Win32.Foundation.HRESULT = -2146368464
COMADMIN_E_SYSTEMAPP: win32more.Windows.Win32.Foundation.HRESULT = -2146368461
COMADMIN_E_COMPFILE_NOREGISTRAR: win32more.Windows.Win32.Foundation.HRESULT = -2146368460
COMADMIN_E_COREQCOMPINSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -2146368459
COMADMIN_E_SERVICENOTINSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -2146368458
COMADMIN_E_PROPERTYSAVEFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2146368457
COMADMIN_E_OBJECTEXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2146368456
COMADMIN_E_COMPONENTEXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2146368455
COMADMIN_E_REGFILE_CORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -2146368453
COMADMIN_E_PROPERTY_OVERFLOW: win32more.Windows.Win32.Foundation.HRESULT = -2146368452
COMADMIN_E_NOTINREGISTRY: win32more.Windows.Win32.Foundation.HRESULT = -2146368450
COMADMIN_E_OBJECTNOTPOOLABLE: win32more.Windows.Win32.Foundation.HRESULT = -2146368449
COMADMIN_E_APPLID_MATCHES_CLSID: win32more.Windows.Win32.Foundation.HRESULT = -2146368442
COMADMIN_E_ROLE_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.HRESULT = -2146368441
COMADMIN_E_START_APP_NEEDS_COMPONENTS: win32more.Windows.Win32.Foundation.HRESULT = -2146368440
COMADMIN_E_REQUIRES_DIFFERENT_PLATFORM: win32more.Windows.Win32.Foundation.HRESULT = -2146368439
COMADMIN_E_CAN_NOT_EXPORT_APP_PROXY: win32more.Windows.Win32.Foundation.HRESULT = -2146368438
COMADMIN_E_CAN_NOT_START_APP: win32more.Windows.Win32.Foundation.HRESULT = -2146368437
COMADMIN_E_CAN_NOT_EXPORT_SYS_APP: win32more.Windows.Win32.Foundation.HRESULT = -2146368436
COMADMIN_E_CANT_SUBSCRIBE_TO_COMPONENT: win32more.Windows.Win32.Foundation.HRESULT = -2146368435
COMADMIN_E_EVENTCLASS_CANT_BE_SUBSCRIBER: win32more.Windows.Win32.Foundation.HRESULT = -2146368434
COMADMIN_E_LIB_APP_PROXY_INCOMPATIBLE: win32more.Windows.Win32.Foundation.HRESULT = -2146368433
COMADMIN_E_BASE_PARTITION_ONLY: win32more.Windows.Win32.Foundation.HRESULT = -2146368432
COMADMIN_E_START_APP_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2146368431
COMADMIN_E_CAT_DUPLICATE_PARTITION_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2146368425
COMADMIN_E_CAT_INVALID_PARTITION_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2146368424
COMADMIN_E_CAT_PARTITION_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -2146368423
COMADMIN_E_FILE_PARTITION_DUPLICATE_FILES: win32more.Windows.Win32.Foundation.HRESULT = -2146368422
COMADMIN_E_CAT_IMPORTED_COMPONENTS_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2146368421
COMADMIN_E_AMBIGUOUS_APPLICATION_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2146368420
COMADMIN_E_AMBIGUOUS_PARTITION_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2146368419
COMADMIN_E_REGDB_NOTINITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2146368398
COMADMIN_E_REGDB_NOTOPEN: win32more.Windows.Win32.Foundation.HRESULT = -2146368397
COMADMIN_E_REGDB_SYSTEMERR: win32more.Windows.Win32.Foundation.HRESULT = -2146368396
COMADMIN_E_REGDB_ALREADYRUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2146368395
COMADMIN_E_MIG_VERSIONNOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2146368384
COMADMIN_E_MIG_SCHEMANOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2146368383
COMADMIN_E_CAT_BITNESSMISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2146368382
COMADMIN_E_CAT_UNACCEPTABLEBITNESS: win32more.Windows.Win32.Foundation.HRESULT = -2146368381
COMADMIN_E_CAT_WRONGAPPBITNESS: win32more.Windows.Win32.Foundation.HRESULT = -2146368380
COMADMIN_E_CAT_PAUSE_RESUME_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2146368379
COMADMIN_E_CAT_SERVERFAULT: win32more.Windows.Win32.Foundation.HRESULT = -2146368378
COMQC_E_APPLICATION_NOT_QUEUED: win32more.Windows.Win32.Foundation.HRESULT = -2146368000
COMQC_E_NO_QUEUEABLE_INTERFACES: win32more.Windows.Win32.Foundation.HRESULT = -2146367999
COMQC_E_QUEUING_SERVICE_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2146367998
COMQC_E_NO_IPERSISTSTREAM: win32more.Windows.Win32.Foundation.HRESULT = -2146367997
COMQC_E_BAD_MESSAGE: win32more.Windows.Win32.Foundation.HRESULT = -2146367996
COMQC_E_UNAUTHENTICATED: win32more.Windows.Win32.Foundation.HRESULT = -2146367995
COMQC_E_UNTRUSTED_ENQUEUER: win32more.Windows.Win32.Foundation.HRESULT = -2146367994
MSDTC_E_DUPLICATE_RESOURCE: win32more.Windows.Win32.Foundation.HRESULT = -2146367743
COMADMIN_E_OBJECT_PARENT_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2146367480
COMADMIN_E_OBJECT_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.HRESULT = -2146367479
COMADMIN_E_APP_NOT_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2146367478
COMADMIN_E_INVALID_PARTITION: win32more.Windows.Win32.Foundation.HRESULT = -2146367477
COMADMIN_E_SVCAPP_NOT_POOLABLE_OR_RECYCLABLE: win32more.Windows.Win32.Foundation.HRESULT = -2146367475
COMADMIN_E_USER_IN_SET: win32more.Windows.Win32.Foundation.HRESULT = -2146367474
COMADMIN_E_CANTRECYCLELIBRARYAPPS: win32more.Windows.Win32.Foundation.HRESULT = -2146367473
COMADMIN_E_CANTRECYCLESERVICEAPPS: win32more.Windows.Win32.Foundation.HRESULT = -2146367471
COMADMIN_E_PROCESSALREADYRECYCLED: win32more.Windows.Win32.Foundation.HRESULT = -2146367470
COMADMIN_E_PAUSEDPROCESSMAYNOTBERECYCLED: win32more.Windows.Win32.Foundation.HRESULT = -2146367469
COMADMIN_E_CANTMAKEINPROCSERVICE: win32more.Windows.Win32.Foundation.HRESULT = -2146367468
COMADMIN_E_PROGIDINUSEBYCLSID: win32more.Windows.Win32.Foundation.HRESULT = -2146367467
COMADMIN_E_DEFAULT_PARTITION_NOT_IN_SET: win32more.Windows.Win32.Foundation.HRESULT = -2146367466
COMADMIN_E_RECYCLEDPROCESSMAYNOTBEPAUSED: win32more.Windows.Win32.Foundation.HRESULT = -2146367465
COMADMIN_E_PARTITION_ACCESSDENIED: win32more.Windows.Win32.Foundation.HRESULT = -2146367464
COMADMIN_E_PARTITION_MSI_ONLY: win32more.Windows.Win32.Foundation.HRESULT = -2146367463
COMADMIN_E_LEGACYCOMPS_NOT_ALLOWED_IN_1_0_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2146367462
COMADMIN_E_LEGACYCOMPS_NOT_ALLOWED_IN_NONBASE_PARTITIONS: win32more.Windows.Win32.Foundation.HRESULT = -2146367461
COMADMIN_E_COMP_MOVE_SOURCE: win32more.Windows.Win32.Foundation.HRESULT = -2146367460
COMADMIN_E_COMP_MOVE_DEST: win32more.Windows.Win32.Foundation.HRESULT = -2146367459
COMADMIN_E_COMP_MOVE_PRIVATE: win32more.Windows.Win32.Foundation.HRESULT = -2146367458
COMADMIN_E_BASEPARTITION_REQUIRED_IN_SET: win32more.Windows.Win32.Foundation.HRESULT = -2146367457
COMADMIN_E_CANNOT_ALIAS_EVENTCLASS: win32more.Windows.Win32.Foundation.HRESULT = -2146367456
COMADMIN_E_PRIVATE_ACCESSDENIED: win32more.Windows.Win32.Foundation.HRESULT = -2146367455
COMADMIN_E_SAFERINVALID: win32more.Windows.Win32.Foundation.HRESULT = -2146367454
COMADMIN_E_REGISTRY_ACCESSDENIED: win32more.Windows.Win32.Foundation.HRESULT = -2146367453
COMADMIN_E_PARTITIONS_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2146367452
MENROLL_S_ENROLLMENT_SUSPENDED: win32more.Windows.Win32.Foundation.HRESULT = 1572881
WER_S_REPORT_DEBUG: win32more.Windows.Win32.Foundation.HRESULT = 1769472
WER_S_REPORT_UPLOADED: win32more.Windows.Win32.Foundation.HRESULT = 1769473
WER_S_REPORT_QUEUED: win32more.Windows.Win32.Foundation.HRESULT = 1769474
WER_S_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = 1769475
WER_S_SUSPENDED_UPLOAD: win32more.Windows.Win32.Foundation.HRESULT = 1769476
WER_S_DISABLED_QUEUE: win32more.Windows.Win32.Foundation.HRESULT = 1769477
WER_S_DISABLED_ARCHIVE: win32more.Windows.Win32.Foundation.HRESULT = 1769478
WER_S_REPORT_ASYNC: win32more.Windows.Win32.Foundation.HRESULT = 1769479
WER_S_IGNORE_ASSERT_INSTANCE: win32more.Windows.Win32.Foundation.HRESULT = 1769480
WER_S_IGNORE_ALL_ASSERTS: win32more.Windows.Win32.Foundation.HRESULT = 1769481
WER_S_ASSERT_CONTINUE: win32more.Windows.Win32.Foundation.HRESULT = 1769482
WER_S_THROTTLED: win32more.Windows.Win32.Foundation.HRESULT = 1769483
WER_S_REPORT_UPLOADED_CAB: win32more.Windows.Win32.Foundation.HRESULT = 1769484
WER_E_CRASH_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2145681408
WER_E_CANCELED: win32more.Windows.Win32.Foundation.HRESULT = -2145681407
WER_E_NETWORK_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2145681406
WER_E_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2145681405
WER_E_ALREADY_REPORTING: win32more.Windows.Win32.Foundation.HRESULT = -2145681404
WER_E_DUMP_THROTTLED: win32more.Windows.Win32.Foundation.HRESULT = -2145681403
WER_E_INSUFFICIENT_CONSENT: win32more.Windows.Win32.Foundation.HRESULT = -2145681402
WER_E_TOO_HEAVY: win32more.Windows.Win32.Foundation.HRESULT = -2145681401
ERROR_FLT_IO_COMPLETE: win32more.Windows.Win32.Foundation.HRESULT = 2031617
ERROR_FLT_NO_HANDLER_DEFINED: win32more.Windows.Win32.Foundation.HRESULT = -2145452031
ERROR_FLT_CONTEXT_ALREADY_DEFINED: win32more.Windows.Win32.Foundation.HRESULT = -2145452030
ERROR_FLT_INVALID_ASYNCHRONOUS_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -2145452029
ERROR_FLT_DISALLOW_FAST_IO: win32more.Windows.Win32.Foundation.HRESULT = -2145452028
ERROR_FLT_INVALID_NAME_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -2145452027
ERROR_FLT_NOT_SAFE_TO_POST_OPERATION: win32more.Windows.Win32.Foundation.HRESULT = -2145452026
ERROR_FLT_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2145452025
ERROR_FLT_FILTER_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -2145452024
ERROR_FLT_POST_OPERATION_CLEANUP: win32more.Windows.Win32.Foundation.HRESULT = -2145452023
ERROR_FLT_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145452022
ERROR_FLT_DELETING_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -2145452021
ERROR_FLT_MUST_BE_NONPAGED_POOL: win32more.Windows.Win32.Foundation.HRESULT = -2145452020
ERROR_FLT_DUPLICATE_ENTRY: win32more.Windows.Win32.Foundation.HRESULT = -2145452019
ERROR_FLT_CBDQ_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2145452018
ERROR_FLT_DO_NOT_ATTACH: win32more.Windows.Win32.Foundation.HRESULT = -2145452017
ERROR_FLT_DO_NOT_DETACH: win32more.Windows.Win32.Foundation.HRESULT = -2145452016
ERROR_FLT_INSTANCE_ALTITUDE_COLLISION: win32more.Windows.Win32.Foundation.HRESULT = -2145452015
ERROR_FLT_INSTANCE_NAME_COLLISION: win32more.Windows.Win32.Foundation.HRESULT = -2145452014
ERROR_FLT_FILTER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145452013
ERROR_FLT_VOLUME_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145452012
ERROR_FLT_INSTANCE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145452011
ERROR_FLT_CONTEXT_ALLOCATION_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145452010
ERROR_FLT_INVALID_CONTEXT_REGISTRATION: win32more.Windows.Win32.Foundation.HRESULT = -2145452009
ERROR_FLT_NAME_CACHE_MISS: win32more.Windows.Win32.Foundation.HRESULT = -2145452008
ERROR_FLT_NO_DEVICE_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -2145452007
ERROR_FLT_VOLUME_ALREADY_MOUNTED: win32more.Windows.Win32.Foundation.HRESULT = -2145452006
ERROR_FLT_ALREADY_ENLISTED: win32more.Windows.Win32.Foundation.HRESULT = -2145452005
ERROR_FLT_CONTEXT_ALREADY_LINKED: win32more.Windows.Win32.Foundation.HRESULT = -2145452004
ERROR_FLT_NO_WAITER_FOR_REPLY: win32more.Windows.Win32.Foundation.HRESULT = -2145452000
ERROR_FLT_REGISTRATION_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -2145451997
ERROR_FLT_WCOS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2145451996
ERROR_HUNG_DISPLAY_DRIVER_THREAD: win32more.Windows.Win32.Foundation.HRESULT = -2144993279
DWM_E_COMPOSITIONDISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144980991
DWM_E_REMOTING_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144980990
DWM_E_NO_REDIRECTION_SURFACE_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2144980989
DWM_E_NOT_QUEUING_PRESENTS: win32more.Windows.Win32.Foundation.HRESULT = -2144980988
DWM_E_ADAPTER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144980987
DWM_S_GDI_REDIRECTION_SURFACE: win32more.Windows.Win32.Foundation.HRESULT = 2502661
DWM_E_TEXTURE_TOO_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -2144980985
DWM_S_GDI_REDIRECTION_SURFACE_BLT_VIA_GDI: win32more.Windows.Win32.Foundation.HRESULT = 2502664
ERROR_MONITOR_NO_DESCRIPTOR: win32more.Windows.Win32.Foundation.HRESULT = 2494465
ERROR_MONITOR_UNKNOWN_DESCRIPTOR_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = 2494466
ERROR_MONITOR_INVALID_DESCRIPTOR_CHECKSUM: win32more.Windows.Win32.Foundation.HRESULT = -1071247357
ERROR_MONITOR_INVALID_STANDARD_TIMING_BLOCK: win32more.Windows.Win32.Foundation.HRESULT = -1071247356
ERROR_MONITOR_WMI_DATABLOCK_REGISTRATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1071247355
ERROR_MONITOR_INVALID_SERIAL_NUMBER_MONDSC_BLOCK: win32more.Windows.Win32.Foundation.HRESULT = -1071247354
ERROR_MONITOR_INVALID_USER_FRIENDLY_MONDSC_BLOCK: win32more.Windows.Win32.Foundation.HRESULT = -1071247353
ERROR_MONITOR_NO_MORE_DESCRIPTOR_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1071247352
ERROR_MONITOR_INVALID_DETAILED_TIMING_BLOCK: win32more.Windows.Win32.Foundation.HRESULT = -1071247351
ERROR_MONITOR_INVALID_MANUFACTURE_DATE: win32more.Windows.Win32.Foundation.HRESULT = -1071247350
ERROR_GRAPHICS_NOT_EXCLUSIVE_MODE_OWNER: win32more.Windows.Win32.Foundation.HRESULT = -1071243264
ERROR_GRAPHICS_INSUFFICIENT_DMA_BUFFER: win32more.Windows.Win32.Foundation.HRESULT = -1071243263
ERROR_GRAPHICS_INVALID_DISPLAY_ADAPTER: win32more.Windows.Win32.Foundation.HRESULT = -1071243262
ERROR_GRAPHICS_ADAPTER_WAS_RESET: win32more.Windows.Win32.Foundation.HRESULT = -1071243261
ERROR_GRAPHICS_INVALID_DRIVER_MODEL: win32more.Windows.Win32.Foundation.HRESULT = -1071243260
ERROR_GRAPHICS_PRESENT_MODE_CHANGED: win32more.Windows.Win32.Foundation.HRESULT = -1071243259
ERROR_GRAPHICS_PRESENT_OCCLUDED: win32more.Windows.Win32.Foundation.HRESULT = -1071243258
ERROR_GRAPHICS_PRESENT_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -1071243257
ERROR_GRAPHICS_CANNOTCOLORCONVERT: win32more.Windows.Win32.Foundation.HRESULT = -1071243256
ERROR_GRAPHICS_DRIVER_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1071243255
ERROR_GRAPHICS_PARTIAL_DATA_POPULATED: win32more.Windows.Win32.Foundation.HRESULT = 1076240394
ERROR_GRAPHICS_PRESENT_REDIRECTION_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -1071243253
ERROR_GRAPHICS_PRESENT_UNOCCLUDED: win32more.Windows.Win32.Foundation.HRESULT = -1071243252
ERROR_GRAPHICS_WINDOWDC_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1071243251
ERROR_GRAPHICS_WINDOWLESS_PRESENT_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -1071243250
ERROR_GRAPHICS_PRESENT_INVALID_WINDOW: win32more.Windows.Win32.Foundation.HRESULT = -1071243249
ERROR_GRAPHICS_PRESENT_BUFFER_NOT_BOUND: win32more.Windows.Win32.Foundation.HRESULT = -1071243248
ERROR_GRAPHICS_VAIL_STATE_CHANGED: win32more.Windows.Win32.Foundation.HRESULT = -1071243247
ERROR_GRAPHICS_INDIRECT_DISPLAY_ABANDON_SWAPCHAIN: win32more.Windows.Win32.Foundation.HRESULT = -1071243246
ERROR_GRAPHICS_INDIRECT_DISPLAY_DEVICE_STOPPED: win32more.Windows.Win32.Foundation.HRESULT = -1071243245
ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_CREATE_SUPERWETINK_MESSAGE: win32more.Windows.Win32.Foundation.HRESULT = -1071243244
ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_DESTROY_SUPERWETINK_MESSAGE: win32more.Windows.Win32.Foundation.HRESULT = -1071243243
ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_COMPOSITION_WINDOW_DPI_MESSAGE: win32more.Windows.Win32.Foundation.HRESULT = -1071243242
ERROR_GRAPHICS_LINK_CONFIGURATION_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -1071243241
ERROR_GRAPHICS_MPO_ALLOCATION_UNPINNED: win32more.Windows.Win32.Foundation.HRESULT = -1071243240
ERROR_GRAPHICS_NO_VIDEO_MEMORY: win32more.Windows.Win32.Foundation.HRESULT = -1071243008
ERROR_GRAPHICS_CANT_LOCK_MEMORY: win32more.Windows.Win32.Foundation.HRESULT = -1071243007
ERROR_GRAPHICS_ALLOCATION_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -1071243006
ERROR_GRAPHICS_TOO_MANY_REFERENCES: win32more.Windows.Win32.Foundation.HRESULT = -1071243005
ERROR_GRAPHICS_TRY_AGAIN_LATER: win32more.Windows.Win32.Foundation.HRESULT = -1071243004
ERROR_GRAPHICS_TRY_AGAIN_NOW: win32more.Windows.Win32.Foundation.HRESULT = -1071243003
ERROR_GRAPHICS_ALLOCATION_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -1071243002
ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1071243001
ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1071243000
ERROR_GRAPHICS_CANT_EVICT_PINNED_ALLOCATION: win32more.Windows.Win32.Foundation.HRESULT = -1071242999
ERROR_GRAPHICS_INVALID_ALLOCATION_USAGE: win32more.Windows.Win32.Foundation.HRESULT = -1071242992
ERROR_GRAPHICS_CANT_RENDER_LOCKED_ALLOCATION: win32more.Windows.Win32.Foundation.HRESULT = -1071242991
ERROR_GRAPHICS_ALLOCATION_CLOSED: win32more.Windows.Win32.Foundation.HRESULT = -1071242990
ERROR_GRAPHICS_INVALID_ALLOCATION_INSTANCE: win32more.Windows.Win32.Foundation.HRESULT = -1071242989
ERROR_GRAPHICS_INVALID_ALLOCATION_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -1071242988
ERROR_GRAPHICS_WRONG_ALLOCATION_DEVICE: win32more.Windows.Win32.Foundation.HRESULT = -1071242987
ERROR_GRAPHICS_ALLOCATION_CONTENT_LOST: win32more.Windows.Win32.Foundation.HRESULT = -1071242986
ERROR_GRAPHICS_GPU_EXCEPTION_ON_DEVICE: win32more.Windows.Win32.Foundation.HRESULT = -1071242752
ERROR_GRAPHICS_SKIP_ALLOCATION_PREPARATION: win32more.Windows.Win32.Foundation.HRESULT = 1076240897
ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY: win32more.Windows.Win32.Foundation.HRESULT = -1071242496
ERROR_GRAPHICS_VIDPN_TOPOLOGY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1071242495
ERROR_GRAPHICS_VIDPN_TOPOLOGY_CURRENTLY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1071242494
ERROR_GRAPHICS_INVALID_VIDPN: win32more.Windows.Win32.Foundation.HRESULT = -1071242493
ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE: win32more.Windows.Win32.Foundation.HRESULT = -1071242492
ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET: win32more.Windows.Win32.Foundation.HRESULT = -1071242491
ERROR_GRAPHICS_VIDPN_MODALITY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1071242490
ERROR_GRAPHICS_MODE_NOT_PINNED: win32more.Windows.Win32.Foundation.HRESULT = 2499335
ERROR_GRAPHICS_INVALID_VIDPN_SOURCEMODESET: win32more.Windows.Win32.Foundation.HRESULT = -1071242488
ERROR_GRAPHICS_INVALID_VIDPN_TARGETMODESET: win32more.Windows.Win32.Foundation.HRESULT = -1071242487
ERROR_GRAPHICS_INVALID_FREQUENCY: win32more.Windows.Win32.Foundation.HRESULT = -1071242486
ERROR_GRAPHICS_INVALID_ACTIVE_REGION: win32more.Windows.Win32.Foundation.HRESULT = -1071242485
ERROR_GRAPHICS_INVALID_TOTAL_REGION: win32more.Windows.Win32.Foundation.HRESULT = -1071242484
ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE_MODE: win32more.Windows.Win32.Foundation.HRESULT = -1071242480
ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET_MODE: win32more.Windows.Win32.Foundation.HRESULT = -1071242479
ERROR_GRAPHICS_PINNED_MODE_MUST_REMAIN_IN_SET: win32more.Windows.Win32.Foundation.HRESULT = -1071242478
ERROR_GRAPHICS_PATH_ALREADY_IN_TOPOLOGY: win32more.Windows.Win32.Foundation.HRESULT = -1071242477
ERROR_GRAPHICS_MODE_ALREADY_IN_MODESET: win32more.Windows.Win32.Foundation.HRESULT = -1071242476
ERROR_GRAPHICS_INVALID_VIDEOPRESENTSOURCESET: win32more.Windows.Win32.Foundation.HRESULT = -1071242475
ERROR_GRAPHICS_INVALID_VIDEOPRESENTTARGETSET: win32more.Windows.Win32.Foundation.HRESULT = -1071242474
ERROR_GRAPHICS_SOURCE_ALREADY_IN_SET: win32more.Windows.Win32.Foundation.HRESULT = -1071242473
ERROR_GRAPHICS_TARGET_ALREADY_IN_SET: win32more.Windows.Win32.Foundation.HRESULT = -1071242472
ERROR_GRAPHICS_INVALID_VIDPN_PRESENT_PATH: win32more.Windows.Win32.Foundation.HRESULT = -1071242471
ERROR_GRAPHICS_NO_RECOMMENDED_VIDPN_TOPOLOGY: win32more.Windows.Win32.Foundation.HRESULT = -1071242470
ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGESET: win32more.Windows.Win32.Foundation.HRESULT = -1071242469
ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE: win32more.Windows.Win32.Foundation.HRESULT = -1071242468
ERROR_GRAPHICS_FREQUENCYRANGE_NOT_IN_SET: win32more.Windows.Win32.Foundation.HRESULT = -1071242467
ERROR_GRAPHICS_NO_PREFERRED_MODE: win32more.Windows.Win32.Foundation.HRESULT = 2499358
ERROR_GRAPHICS_FREQUENCYRANGE_ALREADY_IN_SET: win32more.Windows.Win32.Foundation.HRESULT = -1071242465
ERROR_GRAPHICS_STALE_MODESET: win32more.Windows.Win32.Foundation.HRESULT = -1071242464
ERROR_GRAPHICS_INVALID_MONITOR_SOURCEMODESET: win32more.Windows.Win32.Foundation.HRESULT = -1071242463
ERROR_GRAPHICS_INVALID_MONITOR_SOURCE_MODE: win32more.Windows.Win32.Foundation.HRESULT = -1071242462
ERROR_GRAPHICS_NO_RECOMMENDED_FUNCTIONAL_VIDPN: win32more.Windows.Win32.Foundation.HRESULT = -1071242461
ERROR_GRAPHICS_MODE_ID_MUST_BE_UNIQUE: win32more.Windows.Win32.Foundation.HRESULT = -1071242460
ERROR_GRAPHICS_EMPTY_ADAPTER_MONITOR_MODE_SUPPORT_INTERSECTION: win32more.Windows.Win32.Foundation.HRESULT = -1071242459
ERROR_GRAPHICS_VIDEO_PRESENT_TARGETS_LESS_THAN_SOURCES: win32more.Windows.Win32.Foundation.HRESULT = -1071242458
ERROR_GRAPHICS_PATH_NOT_IN_TOPOLOGY: win32more.Windows.Win32.Foundation.HRESULT = -1071242457
ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_SOURCE: win32more.Windows.Win32.Foundation.HRESULT = -1071242456
ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_TARGET: win32more.Windows.Win32.Foundation.HRESULT = -1071242455
ERROR_GRAPHICS_INVALID_MONITORDESCRIPTORSET: win32more.Windows.Win32.Foundation.HRESULT = -1071242454
ERROR_GRAPHICS_INVALID_MONITORDESCRIPTOR: win32more.Windows.Win32.Foundation.HRESULT = -1071242453
ERROR_GRAPHICS_MONITORDESCRIPTOR_NOT_IN_SET: win32more.Windows.Win32.Foundation.HRESULT = -1071242452
ERROR_GRAPHICS_MONITORDESCRIPTOR_ALREADY_IN_SET: win32more.Windows.Win32.Foundation.HRESULT = -1071242451
ERROR_GRAPHICS_MONITORDESCRIPTOR_ID_MUST_BE_UNIQUE: win32more.Windows.Win32.Foundation.HRESULT = -1071242450
ERROR_GRAPHICS_INVALID_VIDPN_TARGET_SUBSET_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -1071242449
ERROR_GRAPHICS_RESOURCES_NOT_RELATED: win32more.Windows.Win32.Foundation.HRESULT = -1071242448
ERROR_GRAPHICS_SOURCE_ID_MUST_BE_UNIQUE: win32more.Windows.Win32.Foundation.HRESULT = -1071242447
ERROR_GRAPHICS_TARGET_ID_MUST_BE_UNIQUE: win32more.Windows.Win32.Foundation.HRESULT = -1071242446
ERROR_GRAPHICS_NO_AVAILABLE_VIDPN_TARGET: win32more.Windows.Win32.Foundation.HRESULT = -1071242445
ERROR_GRAPHICS_MONITOR_COULD_NOT_BE_ASSOCIATED_WITH_ADAPTER: win32more.Windows.Win32.Foundation.HRESULT = -1071242444
ERROR_GRAPHICS_NO_VIDPNMGR: win32more.Windows.Win32.Foundation.HRESULT = -1071242443
ERROR_GRAPHICS_NO_ACTIVE_VIDPN: win32more.Windows.Win32.Foundation.HRESULT = -1071242442
ERROR_GRAPHICS_STALE_VIDPN_TOPOLOGY: win32more.Windows.Win32.Foundation.HRESULT = -1071242441
ERROR_GRAPHICS_MONITOR_NOT_CONNECTED: win32more.Windows.Win32.Foundation.HRESULT = -1071242440
ERROR_GRAPHICS_SOURCE_NOT_IN_TOPOLOGY: win32more.Windows.Win32.Foundation.HRESULT = -1071242439
ERROR_GRAPHICS_INVALID_PRIMARYSURFACE_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -1071242438
ERROR_GRAPHICS_INVALID_VISIBLEREGION_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -1071242437
ERROR_GRAPHICS_INVALID_STRIDE: win32more.Windows.Win32.Foundation.HRESULT = -1071242436
ERROR_GRAPHICS_INVALID_PIXELFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1071242435
ERROR_GRAPHICS_INVALID_COLORBASIS: win32more.Windows.Win32.Foundation.HRESULT = -1071242434
ERROR_GRAPHICS_INVALID_PIXELVALUEACCESSMODE: win32more.Windows.Win32.Foundation.HRESULT = -1071242433
ERROR_GRAPHICS_TARGET_NOT_IN_TOPOLOGY: win32more.Windows.Win32.Foundation.HRESULT = -1071242432
ERROR_GRAPHICS_NO_DISPLAY_MODE_MANAGEMENT_SUPPORT: win32more.Windows.Win32.Foundation.HRESULT = -1071242431
ERROR_GRAPHICS_VIDPN_SOURCE_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -1071242430
ERROR_GRAPHICS_CANT_ACCESS_ACTIVE_VIDPN: win32more.Windows.Win32.Foundation.HRESULT = -1071242429
ERROR_GRAPHICS_INVALID_PATH_IMPORTANCE_ORDINAL: win32more.Windows.Win32.Foundation.HRESULT = -1071242428
ERROR_GRAPHICS_INVALID_PATH_CONTENT_GEOMETRY_TRANSFORMATION: win32more.Windows.Win32.Foundation.HRESULT = -1071242427
ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1071242426
ERROR_GRAPHICS_INVALID_GAMMA_RAMP: win32more.Windows.Win32.Foundation.HRESULT = -1071242425
ERROR_GRAPHICS_GAMMA_RAMP_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1071242424
ERROR_GRAPHICS_MULTISAMPLING_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1071242423
ERROR_GRAPHICS_MODE_NOT_IN_MODESET: win32more.Windows.Win32.Foundation.HRESULT = -1071242422
ERROR_GRAPHICS_DATASET_IS_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = 2499403
ERROR_GRAPHICS_NO_MORE_ELEMENTS_IN_DATASET: win32more.Windows.Win32.Foundation.HRESULT = 2499404
ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY_RECOMMENDATION_REASON: win32more.Windows.Win32.Foundation.HRESULT = -1071242419
ERROR_GRAPHICS_INVALID_PATH_CONTENT_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -1071242418
ERROR_GRAPHICS_INVALID_COPYPROTECTION_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -1071242417
ERROR_GRAPHICS_UNASSIGNED_MODESET_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -1071242416
ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_PINNED: win32more.Windows.Win32.Foundation.HRESULT = 2499409
ERROR_GRAPHICS_INVALID_SCANLINE_ORDERING: win32more.Windows.Win32.Foundation.HRESULT = -1071242414
ERROR_GRAPHICS_TOPOLOGY_CHANGES_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -1071242413
ERROR_GRAPHICS_NO_AVAILABLE_IMPORTANCE_ORDINALS: win32more.Windows.Win32.Foundation.HRESULT = -1071242412
ERROR_GRAPHICS_INCOMPATIBLE_PRIVATE_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1071242411
ERROR_GRAPHICS_INVALID_MODE_PRUNING_ALGORITHM: win32more.Windows.Win32.Foundation.HRESULT = -1071242410
ERROR_GRAPHICS_INVALID_MONITOR_CAPABILITY_ORIGIN: win32more.Windows.Win32.Foundation.HRESULT = -1071242409
ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE_CONSTRAINT: win32more.Windows.Win32.Foundation.HRESULT = -1071242408
ERROR_GRAPHICS_MAX_NUM_PATHS_REACHED: win32more.Windows.Win32.Foundation.HRESULT = -1071242407
ERROR_GRAPHICS_CANCEL_VIDPN_TOPOLOGY_AUGMENTATION: win32more.Windows.Win32.Foundation.HRESULT = -1071242406
ERROR_GRAPHICS_INVALID_CLIENT_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -1071242405
ERROR_GRAPHICS_CLIENTVIDPN_NOT_SET: win32more.Windows.Win32.Foundation.HRESULT = -1071242404
ERROR_GRAPHICS_SPECIFIED_CHILD_ALREADY_CONNECTED: win32more.Windows.Win32.Foundation.HRESULT = -1071242240
ERROR_GRAPHICS_CHILD_DESCRIPTOR_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1071242239
ERROR_GRAPHICS_UNKNOWN_CHILD_STATUS: win32more.Windows.Win32.Foundation.HRESULT = 1076241455
ERROR_GRAPHICS_NOT_A_LINKED_ADAPTER: win32more.Windows.Win32.Foundation.HRESULT = -1071242192
ERROR_GRAPHICS_LEADLINK_NOT_ENUMERATED: win32more.Windows.Win32.Foundation.HRESULT = -1071242191
ERROR_GRAPHICS_CHAINLINKS_NOT_ENUMERATED: win32more.Windows.Win32.Foundation.HRESULT = -1071242190
ERROR_GRAPHICS_ADAPTER_CHAIN_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -1071242189
ERROR_GRAPHICS_CHAINLINKS_NOT_STARTED: win32more.Windows.Win32.Foundation.HRESULT = -1071242188
ERROR_GRAPHICS_CHAINLINKS_NOT_POWERED_ON: win32more.Windows.Win32.Foundation.HRESULT = -1071242187
ERROR_GRAPHICS_INCONSISTENT_DEVICE_LINK_STATE: win32more.Windows.Win32.Foundation.HRESULT = -1071242186
ERROR_GRAPHICS_LEADLINK_START_DEFERRED: win32more.Windows.Win32.Foundation.HRESULT = 1076241463
ERROR_GRAPHICS_NOT_POST_DEVICE_DRIVER: win32more.Windows.Win32.Foundation.HRESULT = -1071242184
ERROR_GRAPHICS_POLLING_TOO_FREQUENTLY: win32more.Windows.Win32.Foundation.HRESULT = 1076241465
ERROR_GRAPHICS_START_DEFERRED: win32more.Windows.Win32.Foundation.HRESULT = 1076241466
ERROR_GRAPHICS_ADAPTER_ACCESS_NOT_EXCLUDED: win32more.Windows.Win32.Foundation.HRESULT = -1071242181
ERROR_GRAPHICS_DEPENDABLE_CHILD_STATUS: win32more.Windows.Win32.Foundation.HRESULT = 1076241468
ERROR_GRAPHICS_OPM_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1071241984
ERROR_GRAPHICS_COPP_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1071241983
ERROR_GRAPHICS_UAB_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1071241982
ERROR_GRAPHICS_OPM_INVALID_ENCRYPTED_PARAMETERS: win32more.Windows.Win32.Foundation.HRESULT = -1071241981
ERROR_GRAPHICS_OPM_NO_VIDEO_OUTPUTS_EXIST: win32more.Windows.Win32.Foundation.HRESULT = -1071241979
ERROR_GRAPHICS_OPM_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1071241973
ERROR_GRAPHICS_OPM_INVALID_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -1071241972
ERROR_GRAPHICS_PVP_INVALID_CERTIFICATE_LENGTH: win32more.Windows.Win32.Foundation.HRESULT = -1071241970
ERROR_GRAPHICS_OPM_SPANNING_MODE_ENABLED: win32more.Windows.Win32.Foundation.HRESULT = -1071241969
ERROR_GRAPHICS_OPM_THEATER_MODE_ENABLED: win32more.Windows.Win32.Foundation.HRESULT = -1071241968
ERROR_GRAPHICS_PVP_HFS_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1071241967
ERROR_GRAPHICS_OPM_INVALID_SRM: win32more.Windows.Win32.Foundation.HRESULT = -1071241966
ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_HDCP: win32more.Windows.Win32.Foundation.HRESULT = -1071241965
ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_ACP: win32more.Windows.Win32.Foundation.HRESULT = -1071241964
ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_CGMSA: win32more.Windows.Win32.Foundation.HRESULT = -1071241963
ERROR_GRAPHICS_OPM_HDCP_SRM_NEVER_SET: win32more.Windows.Win32.Foundation.HRESULT = -1071241962
ERROR_GRAPHICS_OPM_RESOLUTION_TOO_HIGH: win32more.Windows.Win32.Foundation.HRESULT = -1071241961
ERROR_GRAPHICS_OPM_ALL_HDCP_HARDWARE_ALREADY_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -1071241960
ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_NO_LONGER_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -1071241958
ERROR_GRAPHICS_OPM_SESSION_TYPE_CHANGE_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -1071241957
ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_COPP_SEMANTICS: win32more.Windows.Win32.Foundation.HRESULT = -1071241956
ERROR_GRAPHICS_OPM_INVALID_INFORMATION_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -1071241955
ERROR_GRAPHICS_OPM_DRIVER_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1071241954
ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_OPM_SEMANTICS: win32more.Windows.Win32.Foundation.HRESULT = -1071241953
ERROR_GRAPHICS_OPM_SIGNALING_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1071241952
ERROR_GRAPHICS_OPM_INVALID_CONFIGURATION_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -1071241951
ERROR_GRAPHICS_I2C_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1071241856
ERROR_GRAPHICS_I2C_DEVICE_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.HRESULT = -1071241855
ERROR_GRAPHICS_I2C_ERROR_TRANSMITTING_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1071241854
ERROR_GRAPHICS_I2C_ERROR_RECEIVING_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1071241853
ERROR_GRAPHICS_DDCCI_VCP_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1071241852
ERROR_GRAPHICS_DDCCI_INVALID_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1071241851
ERROR_GRAPHICS_DDCCI_MONITOR_RETURNED_INVALID_TIMING_STATUS_BYTE: win32more.Windows.Win32.Foundation.HRESULT = -1071241850
ERROR_GRAPHICS_MCA_INVALID_CAPABILITIES_STRING: win32more.Windows.Win32.Foundation.HRESULT = -1071241849
ERROR_GRAPHICS_MCA_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1071241848
ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_COMMAND: win32more.Windows.Win32.Foundation.HRESULT = -1071241847
ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_LENGTH: win32more.Windows.Win32.Foundation.HRESULT = -1071241846
ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_CHECKSUM: win32more.Windows.Win32.Foundation.HRESULT = -1071241845
ERROR_GRAPHICS_INVALID_PHYSICAL_MONITOR_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -1071241844
ERROR_GRAPHICS_MONITOR_NO_LONGER_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -1071241843
ERROR_GRAPHICS_DDCCI_CURRENT_CURRENT_VALUE_GREATER_THAN_MAXIMUM_VALUE: win32more.Windows.Win32.Foundation.HRESULT = -1071241768
ERROR_GRAPHICS_MCA_INVALID_VCP_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -1071241767
ERROR_GRAPHICS_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION: win32more.Windows.Win32.Foundation.HRESULT = -1071241766
ERROR_GRAPHICS_MCA_MCCS_VERSION_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1071241765
ERROR_GRAPHICS_MCA_UNSUPPORTED_MCCS_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -1071241764
ERROR_GRAPHICS_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED: win32more.Windows.Win32.Foundation.HRESULT = -1071241762
ERROR_GRAPHICS_MCA_UNSUPPORTED_COLOR_TEMPERATURE: win32more.Windows.Win32.Foundation.HRESULT = -1071241761
ERROR_GRAPHICS_ONLY_CONSOLE_SESSION_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1071241760
ERROR_GRAPHICS_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME: win32more.Windows.Win32.Foundation.HRESULT = -1071241759
ERROR_GRAPHICS_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP: win32more.Windows.Win32.Foundation.HRESULT = -1071241758
ERROR_GRAPHICS_MIRRORING_DEVICES_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1071241757
ERROR_GRAPHICS_INVALID_POINTER: win32more.Windows.Win32.Foundation.HRESULT = -1071241756
ERROR_GRAPHICS_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE: win32more.Windows.Win32.Foundation.HRESULT = -1071241755
ERROR_GRAPHICS_PARAMETER_ARRAY_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -1071241754
ERROR_GRAPHICS_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1071241753
ERROR_GRAPHICS_SESSION_TYPE_CHANGE_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -1071249944
NAP_E_INVALID_PACKET: win32more.Windows.Win32.Foundation.HRESULT = -2144927743
NAP_E_MISSING_SOH: win32more.Windows.Win32.Foundation.HRESULT = -2144927742
NAP_E_CONFLICTING_ID: win32more.Windows.Win32.Foundation.HRESULT = -2144927741
NAP_E_NO_CACHED_SOH: win32more.Windows.Win32.Foundation.HRESULT = -2144927740
NAP_E_STILL_BOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144927739
NAP_E_NOT_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2144927738
NAP_E_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2144927737
NAP_E_MISMATCHED_ID: win32more.Windows.Win32.Foundation.HRESULT = -2144927736
NAP_E_NOT_PENDING: win32more.Windows.Win32.Foundation.HRESULT = -2144927735
NAP_E_ID_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144927734
NAP_E_MAXSIZE_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -2144927733
NAP_E_SERVICE_NOT_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2144927732
NAP_S_CERT_ALREADY_PRESENT: win32more.Windows.Win32.Foundation.HRESULT = 2555917
NAP_E_ENTITY_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144927730
NAP_E_NETSH_GROUPPOLICY_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2144927729
NAP_E_TOO_MANY_CALLS: win32more.Windows.Win32.Foundation.HRESULT = -2144927728
NAP_E_SHV_CONFIG_EXISTED: win32more.Windows.Win32.Foundation.HRESULT = -2144927727
NAP_E_SHV_CONFIG_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144927726
NAP_E_SHV_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2144927725
TPM_E_ERROR_MASK: win32more.Windows.Win32.Foundation.HRESULT = -2144862208
TPM_E_AUTHFAIL: win32more.Windows.Win32.Foundation.HRESULT = -2144862207
TPM_E_BADINDEX: win32more.Windows.Win32.Foundation.HRESULT = -2144862206
TPM_E_BAD_PARAMETER: win32more.Windows.Win32.Foundation.HRESULT = -2144862205
TPM_E_AUDITFAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2144862204
TPM_E_CLEAR_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144862203
TPM_E_DEACTIVATED: win32more.Windows.Win32.Foundation.HRESULT = -2144862202
TPM_E_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144862201
TPM_E_DISABLED_CMD: win32more.Windows.Win32.Foundation.HRESULT = -2144862200
TPM_E_FAIL: win32more.Windows.Win32.Foundation.HRESULT = -2144862199
TPM_E_BAD_ORDINAL: win32more.Windows.Win32.Foundation.HRESULT = -2144862198
TPM_E_INSTALL_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144862197
TPM_E_INVALID_KEYHANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2144862196
TPM_E_KEYNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144862195
TPM_E_INAPPROPRIATE_ENC: win32more.Windows.Win32.Foundation.HRESULT = -2144862194
TPM_E_MIGRATEFAIL: win32more.Windows.Win32.Foundation.HRESULT = -2144862193
TPM_E_INVALID_PCR_INFO: win32more.Windows.Win32.Foundation.HRESULT = -2144862192
TPM_E_NOSPACE: win32more.Windows.Win32.Foundation.HRESULT = -2144862191
TPM_E_NOSRK: win32more.Windows.Win32.Foundation.HRESULT = -2144862190
TPM_E_NOTSEALED_BLOB: win32more.Windows.Win32.Foundation.HRESULT = -2144862189
TPM_E_OWNER_SET: win32more.Windows.Win32.Foundation.HRESULT = -2144862188
TPM_E_RESOURCES: win32more.Windows.Win32.Foundation.HRESULT = -2144862187
TPM_E_SHORTRANDOM: win32more.Windows.Win32.Foundation.HRESULT = -2144862186
TPM_E_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2144862185
TPM_E_WRONGPCRVAL: win32more.Windows.Win32.Foundation.HRESULT = -2144862184
TPM_E_BAD_PARAM_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2144862183
TPM_E_SHA_THREAD: win32more.Windows.Win32.Foundation.HRESULT = -2144862182
TPM_E_SHA_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2144862181
TPM_E_FAILEDSELFTEST: win32more.Windows.Win32.Foundation.HRESULT = -2144862180
TPM_E_AUTH2FAIL: win32more.Windows.Win32.Foundation.HRESULT = -2144862179
TPM_E_BADTAG: win32more.Windows.Win32.Foundation.HRESULT = -2144862178
TPM_E_IOERROR: win32more.Windows.Win32.Foundation.HRESULT = -2144862177
TPM_E_ENCRYPT_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2144862176
TPM_E_DECRYPT_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2144862175
TPM_E_INVALID_AUTHHANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2144862174
TPM_E_NO_ENDORSEMENT: win32more.Windows.Win32.Foundation.HRESULT = -2144862173
TPM_E_INVALID_KEYUSAGE: win32more.Windows.Win32.Foundation.HRESULT = -2144862172
TPM_E_WRONG_ENTITYTYPE: win32more.Windows.Win32.Foundation.HRESULT = -2144862171
TPM_E_INVALID_POSTINIT: win32more.Windows.Win32.Foundation.HRESULT = -2144862170
TPM_E_INAPPROPRIATE_SIG: win32more.Windows.Win32.Foundation.HRESULT = -2144862169
TPM_E_BAD_KEY_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2144862168
TPM_E_BAD_MIGRATION: win32more.Windows.Win32.Foundation.HRESULT = -2144862167
TPM_E_BAD_SCHEME: win32more.Windows.Win32.Foundation.HRESULT = -2144862166
TPM_E_BAD_DATASIZE: win32more.Windows.Win32.Foundation.HRESULT = -2144862165
TPM_E_BAD_MODE: win32more.Windows.Win32.Foundation.HRESULT = -2144862164
TPM_E_BAD_PRESENCE: win32more.Windows.Win32.Foundation.HRESULT = -2144862163
TPM_E_BAD_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2144862162
TPM_E_NO_WRAP_TRANSPORT: win32more.Windows.Win32.Foundation.HRESULT = -2144862161
TPM_E_AUDITFAIL_UNSUCCESSFUL: win32more.Windows.Win32.Foundation.HRESULT = -2144862160
TPM_E_AUDITFAIL_SUCCESSFUL: win32more.Windows.Win32.Foundation.HRESULT = -2144862159
TPM_E_NOTRESETABLE: win32more.Windows.Win32.Foundation.HRESULT = -2144862158
TPM_E_NOTLOCAL: win32more.Windows.Win32.Foundation.HRESULT = -2144862157
TPM_E_BAD_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2144862156
TPM_E_INVALID_RESOURCE: win32more.Windows.Win32.Foundation.HRESULT = -2144862155
TPM_E_NOTFIPS: win32more.Windows.Win32.Foundation.HRESULT = -2144862154
TPM_E_INVALID_FAMILY: win32more.Windows.Win32.Foundation.HRESULT = -2144862153
TPM_E_NO_NV_PERMISSION: win32more.Windows.Win32.Foundation.HRESULT = -2144862152
TPM_E_REQUIRES_SIGN: win32more.Windows.Win32.Foundation.HRESULT = -2144862151
TPM_E_KEY_NOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144862150
TPM_E_AUTH_CONFLICT: win32more.Windows.Win32.Foundation.HRESULT = -2144862149
TPM_E_AREA_LOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2144862148
TPM_E_BAD_LOCALITY: win32more.Windows.Win32.Foundation.HRESULT = -2144862147
TPM_E_READ_ONLY: win32more.Windows.Win32.Foundation.HRESULT = -2144862146
TPM_E_PER_NOWRITE: win32more.Windows.Win32.Foundation.HRESULT = -2144862145
TPM_E_FAMILYCOUNT: win32more.Windows.Win32.Foundation.HRESULT = -2144862144
TPM_E_WRITE_LOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2144862143
TPM_E_BAD_ATTRIBUTES: win32more.Windows.Win32.Foundation.HRESULT = -2144862142
TPM_E_INVALID_STRUCTURE: win32more.Windows.Win32.Foundation.HRESULT = -2144862141
TPM_E_KEY_OWNER_CONTROL: win32more.Windows.Win32.Foundation.HRESULT = -2144862140
TPM_E_BAD_COUNTER: win32more.Windows.Win32.Foundation.HRESULT = -2144862139
TPM_E_NOT_FULLWRITE: win32more.Windows.Win32.Foundation.HRESULT = -2144862138
TPM_E_CONTEXT_GAP: win32more.Windows.Win32.Foundation.HRESULT = -2144862137
TPM_E_MAXNVWRITES: win32more.Windows.Win32.Foundation.HRESULT = -2144862136
TPM_E_NOOPERATOR: win32more.Windows.Win32.Foundation.HRESULT = -2144862135
TPM_E_RESOURCEMISSING: win32more.Windows.Win32.Foundation.HRESULT = -2144862134
TPM_E_DELEGATE_LOCK: win32more.Windows.Win32.Foundation.HRESULT = -2144862133
TPM_E_DELEGATE_FAMILY: win32more.Windows.Win32.Foundation.HRESULT = -2144862132
TPM_E_DELEGATE_ADMIN: win32more.Windows.Win32.Foundation.HRESULT = -2144862131
TPM_E_TRANSPORT_NOTEXCLUSIVE: win32more.Windows.Win32.Foundation.HRESULT = -2144862130
TPM_E_OWNER_CONTROL: win32more.Windows.Win32.Foundation.HRESULT = -2144862129
TPM_E_DAA_RESOURCES: win32more.Windows.Win32.Foundation.HRESULT = -2144862128
TPM_E_DAA_INPUT_DATA0: win32more.Windows.Win32.Foundation.HRESULT = -2144862127
TPM_E_DAA_INPUT_DATA1: win32more.Windows.Win32.Foundation.HRESULT = -2144862126
TPM_E_DAA_ISSUER_SETTINGS: win32more.Windows.Win32.Foundation.HRESULT = -2144862125
TPM_E_DAA_TPM_SETTINGS: win32more.Windows.Win32.Foundation.HRESULT = -2144862124
TPM_E_DAA_STAGE: win32more.Windows.Win32.Foundation.HRESULT = -2144862123
TPM_E_DAA_ISSUER_VALIDITY: win32more.Windows.Win32.Foundation.HRESULT = -2144862122
TPM_E_DAA_WRONG_W: win32more.Windows.Win32.Foundation.HRESULT = -2144862121
TPM_E_BAD_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2144862120
TPM_E_BAD_DELEGATE: win32more.Windows.Win32.Foundation.HRESULT = -2144862119
TPM_E_BADCONTEXT: win32more.Windows.Win32.Foundation.HRESULT = -2144862118
TPM_E_TOOMANYCONTEXTS: win32more.Windows.Win32.Foundation.HRESULT = -2144862117
TPM_E_MA_TICKET_SIGNATURE: win32more.Windows.Win32.Foundation.HRESULT = -2144862116
TPM_E_MA_DESTINATION: win32more.Windows.Win32.Foundation.HRESULT = -2144862115
TPM_E_MA_SOURCE: win32more.Windows.Win32.Foundation.HRESULT = -2144862114
TPM_E_MA_AUTHORITY: win32more.Windows.Win32.Foundation.HRESULT = -2144862113
TPM_E_PERMANENTEK: win32more.Windows.Win32.Foundation.HRESULT = -2144862111
TPM_E_BAD_SIGNATURE: win32more.Windows.Win32.Foundation.HRESULT = -2144862110
TPM_E_NOCONTEXTSPACE: win32more.Windows.Win32.Foundation.HRESULT = -2144862109
TPM_20_E_ASYMMETRIC: win32more.Windows.Win32.Foundation.HRESULT = -2144862079
TPM_20_E_ATTRIBUTES: win32more.Windows.Win32.Foundation.HRESULT = -2144862078
TPM_20_E_HASH: win32more.Windows.Win32.Foundation.HRESULT = -2144862077
TPM_20_E_VALUE: win32more.Windows.Win32.Foundation.HRESULT = -2144862076
TPM_20_E_HIERARCHY: win32more.Windows.Win32.Foundation.HRESULT = -2144862075
TPM_20_E_KEY_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2144862073
TPM_20_E_MGF: win32more.Windows.Win32.Foundation.HRESULT = -2144862072
TPM_20_E_MODE: win32more.Windows.Win32.Foundation.HRESULT = -2144862071
TPM_20_E_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2144862070
TPM_20_E_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2144862069
TPM_20_E_KDF: win32more.Windows.Win32.Foundation.HRESULT = -2144862068
TPM_20_E_RANGE: win32more.Windows.Win32.Foundation.HRESULT = -2144862067
TPM_20_E_AUTH_FAIL: win32more.Windows.Win32.Foundation.HRESULT = -2144862066
TPM_20_E_NONCE: win32more.Windows.Win32.Foundation.HRESULT = -2144862065
TPM_20_E_PP: win32more.Windows.Win32.Foundation.HRESULT = -2144862064
TPM_20_E_SCHEME: win32more.Windows.Win32.Foundation.HRESULT = -2144862062
TPM_20_E_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2144862059
TPM_20_E_SYMMETRIC: win32more.Windows.Win32.Foundation.HRESULT = -2144862058
TPM_20_E_TAG: win32more.Windows.Win32.Foundation.HRESULT = -2144862057
TPM_20_E_SELECTOR: win32more.Windows.Win32.Foundation.HRESULT = -2144862056
TPM_20_E_INSUFFICIENT: win32more.Windows.Win32.Foundation.HRESULT = -2144862054
TPM_20_E_SIGNATURE: win32more.Windows.Win32.Foundation.HRESULT = -2144862053
TPM_20_E_KEY: win32more.Windows.Win32.Foundation.HRESULT = -2144862052
TPM_20_E_POLICY_FAIL: win32more.Windows.Win32.Foundation.HRESULT = -2144862051
TPM_20_E_INTEGRITY: win32more.Windows.Win32.Foundation.HRESULT = -2144862049
TPM_20_E_TICKET: win32more.Windows.Win32.Foundation.HRESULT = -2144862048
TPM_20_E_RESERVED_BITS: win32more.Windows.Win32.Foundation.HRESULT = -2144862047
TPM_20_E_BAD_AUTH: win32more.Windows.Win32.Foundation.HRESULT = -2144862046
TPM_20_E_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144862045
TPM_20_E_POLICY_CC: win32more.Windows.Win32.Foundation.HRESULT = -2144862044
TPM_20_E_BINDING: win32more.Windows.Win32.Foundation.HRESULT = -2144862043
TPM_20_E_CURVE: win32more.Windows.Win32.Foundation.HRESULT = -2144862042
TPM_20_E_ECC_POINT: win32more.Windows.Win32.Foundation.HRESULT = -2144862041
TPM_20_E_INITIALIZE: win32more.Windows.Win32.Foundation.HRESULT = -2144861952
TPM_20_E_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2144861951
TPM_20_E_SEQUENCE: win32more.Windows.Win32.Foundation.HRESULT = -2144861949
TPM_20_E_PRIVATE: win32more.Windows.Win32.Foundation.HRESULT = -2144861941
TPM_20_E_HMAC: win32more.Windows.Win32.Foundation.HRESULT = -2144861927
TPM_20_E_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144861920
TPM_20_E_EXCLUSIVE: win32more.Windows.Win32.Foundation.HRESULT = -2144861919
TPM_20_E_ECC_CURVE: win32more.Windows.Win32.Foundation.HRESULT = -2144861917
TPM_20_E_AUTH_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2144861916
TPM_20_E_AUTH_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2144861915
TPM_20_E_POLICY: win32more.Windows.Win32.Foundation.HRESULT = -2144861914
TPM_20_E_PCR: win32more.Windows.Win32.Foundation.HRESULT = -2144861913
TPM_20_E_PCR_CHANGED: win32more.Windows.Win32.Foundation.HRESULT = -2144861912
TPM_20_E_UPGRADE: win32more.Windows.Win32.Foundation.HRESULT = -2144861907
TPM_20_E_TOO_MANY_CONTEXTS: win32more.Windows.Win32.Foundation.HRESULT = -2144861906
TPM_20_E_AUTH_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2144861905
TPM_20_E_REBOOT: win32more.Windows.Win32.Foundation.HRESULT = -2144861904
TPM_20_E_UNBALANCED: win32more.Windows.Win32.Foundation.HRESULT = -2144861903
TPM_20_E_COMMAND_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2144861886
TPM_20_E_COMMAND_CODE: win32more.Windows.Win32.Foundation.HRESULT = -2144861885
TPM_20_E_AUTHSIZE: win32more.Windows.Win32.Foundation.HRESULT = -2144861884
TPM_20_E_AUTH_CONTEXT: win32more.Windows.Win32.Foundation.HRESULT = -2144861883
TPM_20_E_NV_RANGE: win32more.Windows.Win32.Foundation.HRESULT = -2144861882
TPM_20_E_NV_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2144861881
TPM_20_E_NV_LOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2144861880
TPM_20_E_NV_AUTHORIZATION: win32more.Windows.Win32.Foundation.HRESULT = -2144861879
TPM_20_E_NV_UNINITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2144861878
TPM_20_E_NV_SPACE: win32more.Windows.Win32.Foundation.HRESULT = -2144861877
TPM_20_E_NV_DEFINED: win32more.Windows.Win32.Foundation.HRESULT = -2144861876
TPM_20_E_BAD_CONTEXT: win32more.Windows.Win32.Foundation.HRESULT = -2144861872
TPM_20_E_CPHASH: win32more.Windows.Win32.Foundation.HRESULT = -2144861871
TPM_20_E_PARENT: win32more.Windows.Win32.Foundation.HRESULT = -2144861870
TPM_20_E_NEEDS_TEST: win32more.Windows.Win32.Foundation.HRESULT = -2144861869
TPM_20_E_NO_RESULT: win32more.Windows.Win32.Foundation.HRESULT = -2144861868
TPM_20_E_SENSITIVE: win32more.Windows.Win32.Foundation.HRESULT = -2144861867
TPM_E_COMMAND_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2144861184
TPM_E_INVALID_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2144861183
TPM_E_DUPLICATE_VHANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2144861182
TPM_E_EMBEDDED_COMMAND_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2144861181
TPM_E_EMBEDDED_COMMAND_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144861180
TPM_E_RETRY: win32more.Windows.Win32.Foundation.HRESULT = -2144860160
TPM_E_NEEDS_SELFTEST: win32more.Windows.Win32.Foundation.HRESULT = -2144860159
TPM_E_DOING_SELFTEST: win32more.Windows.Win32.Foundation.HRESULT = -2144860158
TPM_E_DEFEND_LOCK_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2144860157
TPM_20_E_CONTEXT_GAP: win32more.Windows.Win32.Foundation.HRESULT = -2144859903
TPM_20_E_OBJECT_MEMORY: win32more.Windows.Win32.Foundation.HRESULT = -2144859902
TPM_20_E_SESSION_MEMORY: win32more.Windows.Win32.Foundation.HRESULT = -2144859901
TPM_20_E_MEMORY: win32more.Windows.Win32.Foundation.HRESULT = -2144859900
TPM_20_E_SESSION_HANDLES: win32more.Windows.Win32.Foundation.HRESULT = -2144859899
TPM_20_E_OBJECT_HANDLES: win32more.Windows.Win32.Foundation.HRESULT = -2144859898
TPM_20_E_LOCALITY: win32more.Windows.Win32.Foundation.HRESULT = -2144859897
TPM_20_E_YIELDED: win32more.Windows.Win32.Foundation.HRESULT = -2144859896
TPM_20_E_CANCELED: win32more.Windows.Win32.Foundation.HRESULT = -2144859895
TPM_20_E_TESTING: win32more.Windows.Win32.Foundation.HRESULT = -2144859894
TPM_20_E_NV_RATE: win32more.Windows.Win32.Foundation.HRESULT = -2144859872
TPM_20_E_LOCKOUT: win32more.Windows.Win32.Foundation.HRESULT = -2144859871
TPM_20_E_RETRY: win32more.Windows.Win32.Foundation.HRESULT = -2144859870
TPM_20_E_NV_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2144859869
TBS_E_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2144845823
TBS_E_BAD_PARAMETER: win32more.Windows.Win32.Foundation.HRESULT = -2144845822
TBS_E_INVALID_OUTPUT_POINTER: win32more.Windows.Win32.Foundation.HRESULT = -2144845821
TBS_E_INVALID_CONTEXT: win32more.Windows.Win32.Foundation.HRESULT = -2144845820
TBS_E_INSUFFICIENT_BUFFER: win32more.Windows.Win32.Foundation.HRESULT = -2144845819
TBS_E_IOERROR: win32more.Windows.Win32.Foundation.HRESULT = -2144845818
TBS_E_INVALID_CONTEXT_PARAM: win32more.Windows.Win32.Foundation.HRESULT = -2144845817
TBS_E_SERVICE_NOT_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2144845816
TBS_E_TOO_MANY_TBS_CONTEXTS: win32more.Windows.Win32.Foundation.HRESULT = -2144845815
TBS_E_TOO_MANY_RESOURCES: win32more.Windows.Win32.Foundation.HRESULT = -2144845814
TBS_E_SERVICE_START_PENDING: win32more.Windows.Win32.Foundation.HRESULT = -2144845813
TBS_E_PPI_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144845812
TBS_E_COMMAND_CANCELED: win32more.Windows.Win32.Foundation.HRESULT = -2144845811
TBS_E_BUFFER_TOO_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -2144845810
TBS_E_TPM_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144845809
TBS_E_SERVICE_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144845808
TBS_E_NO_EVENT_LOG: win32more.Windows.Win32.Foundation.HRESULT = -2144845807
TBS_E_ACCESS_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2144845806
TBS_E_PROVISIONING_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144845805
TBS_E_PPI_FUNCTION_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144845804
TBS_E_OWNERAUTH_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144845803
TBS_E_PROVISIONING_INCOMPLETE: win32more.Windows.Win32.Foundation.HRESULT = -2144845802
TPMAPI_E_INVALID_STATE: win32more.Windows.Win32.Foundation.HRESULT = -2144796416
TPMAPI_E_NOT_ENOUGH_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2144796415
TPMAPI_E_TOO_MUCH_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2144796414
TPMAPI_E_INVALID_OUTPUT_POINTER: win32more.Windows.Win32.Foundation.HRESULT = -2144796413
TPMAPI_E_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.HRESULT = -2144796412
TPMAPI_E_OUT_OF_MEMORY: win32more.Windows.Win32.Foundation.HRESULT = -2144796411
TPMAPI_E_BUFFER_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -2144796410
TPMAPI_E_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2144796409
TPMAPI_E_ACCESS_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2144796408
TPMAPI_E_AUTHORIZATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144796407
TPMAPI_E_INVALID_CONTEXT_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2144796406
TPMAPI_E_TBS_COMMUNICATION_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2144796405
TPMAPI_E_TPM_COMMAND_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2144796404
TPMAPI_E_MESSAGE_TOO_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -2144796403
TPMAPI_E_INVALID_ENCODING: win32more.Windows.Win32.Foundation.HRESULT = -2144796402
TPMAPI_E_INVALID_KEY_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2144796401
TPMAPI_E_ENCRYPTION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144796400
TPMAPI_E_INVALID_KEY_PARAMS: win32more.Windows.Win32.Foundation.HRESULT = -2144796399
TPMAPI_E_INVALID_MIGRATION_AUTHORIZATION_BLOB: win32more.Windows.Win32.Foundation.HRESULT = -2144796398
TPMAPI_E_INVALID_PCR_INDEX: win32more.Windows.Win32.Foundation.HRESULT = -2144796397
TPMAPI_E_INVALID_DELEGATE_BLOB: win32more.Windows.Win32.Foundation.HRESULT = -2144796396
TPMAPI_E_INVALID_CONTEXT_PARAMS: win32more.Windows.Win32.Foundation.HRESULT = -2144796395
TPMAPI_E_INVALID_KEY_BLOB: win32more.Windows.Win32.Foundation.HRESULT = -2144796394
TPMAPI_E_INVALID_PCR_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2144796393
TPMAPI_E_INVALID_OWNER_AUTH: win32more.Windows.Win32.Foundation.HRESULT = -2144796392
TPMAPI_E_FIPS_RNG_CHECK_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144796391
TPMAPI_E_EMPTY_TCG_LOG: win32more.Windows.Win32.Foundation.HRESULT = -2144796390
TPMAPI_E_INVALID_TCG_LOG_ENTRY: win32more.Windows.Win32.Foundation.HRESULT = -2144796389
TPMAPI_E_TCG_SEPARATOR_ABSENT: win32more.Windows.Win32.Foundation.HRESULT = -2144796388
TPMAPI_E_TCG_INVALID_DIGEST_ENTRY: win32more.Windows.Win32.Foundation.HRESULT = -2144796387
TPMAPI_E_POLICY_DENIES_OPERATION: win32more.Windows.Win32.Foundation.HRESULT = -2144796386
TPMAPI_E_NV_BITS_NOT_DEFINED: win32more.Windows.Win32.Foundation.HRESULT = -2144796385
TPMAPI_E_NV_BITS_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -2144796384
TPMAPI_E_SEALING_KEY_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2144796383
TPMAPI_E_NO_AUTHORIZATION_CHAIN_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144796382
TPMAPI_E_SVN_COUNTER_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2144796381
TPMAPI_E_OWNER_AUTH_NOT_NULL: win32more.Windows.Win32.Foundation.HRESULT = -2144796380
TPMAPI_E_ENDORSEMENT_AUTH_NOT_NULL: win32more.Windows.Win32.Foundation.HRESULT = -2144796379
TPMAPI_E_AUTHORIZATION_REVOKED: win32more.Windows.Win32.Foundation.HRESULT = -2144796378
TPMAPI_E_MALFORMED_AUTHORIZATION_KEY: win32more.Windows.Win32.Foundation.HRESULT = -2144796377
TPMAPI_E_AUTHORIZING_KEY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144796376
TPMAPI_E_INVALID_AUTHORIZATION_SIGNATURE: win32more.Windows.Win32.Foundation.HRESULT = -2144796375
TPMAPI_E_MALFORMED_AUTHORIZATION_POLICY: win32more.Windows.Win32.Foundation.HRESULT = -2144796374
TPMAPI_E_MALFORMED_AUTHORIZATION_OTHER: win32more.Windows.Win32.Foundation.HRESULT = -2144796373
TPMAPI_E_SEALING_KEY_CHANGED: win32more.Windows.Win32.Foundation.HRESULT = -2144796372
TPMAPI_E_INVALID_TPM_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2144796371
TPMAPI_E_INVALID_POLICYAUTH_BLOB_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2144796370
TBSIMP_E_BUFFER_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -2144796160
TBSIMP_E_CLEANUP_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144796159
TBSIMP_E_INVALID_CONTEXT_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2144796158
TBSIMP_E_INVALID_CONTEXT_PARAM: win32more.Windows.Win32.Foundation.HRESULT = -2144796157
TBSIMP_E_TPM_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2144796156
TBSIMP_E_HASH_BAD_KEY: win32more.Windows.Win32.Foundation.HRESULT = -2144796155
TBSIMP_E_DUPLICATE_VHANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2144796154
TBSIMP_E_INVALID_OUTPUT_POINTER: win32more.Windows.Win32.Foundation.HRESULT = -2144796153
TBSIMP_E_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.HRESULT = -2144796152
TBSIMP_E_RPC_INIT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144796151
TBSIMP_E_SCHEDULER_NOT_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2144796150
TBSIMP_E_COMMAND_CANCELED: win32more.Windows.Win32.Foundation.HRESULT = -2144796149
TBSIMP_E_OUT_OF_MEMORY: win32more.Windows.Win32.Foundation.HRESULT = -2144796148
TBSIMP_E_LIST_NO_MORE_ITEMS: win32more.Windows.Win32.Foundation.HRESULT = -2144796147
TBSIMP_E_LIST_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144796146
TBSIMP_E_NOT_ENOUGH_SPACE: win32more.Windows.Win32.Foundation.HRESULT = -2144796145
TBSIMP_E_NOT_ENOUGH_TPM_CONTEXTS: win32more.Windows.Win32.Foundation.HRESULT = -2144796144
TBSIMP_E_COMMAND_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144796143
TBSIMP_E_UNKNOWN_ORDINAL: win32more.Windows.Win32.Foundation.HRESULT = -2144796142
TBSIMP_E_RESOURCE_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144796141
TBSIMP_E_INVALID_RESOURCE: win32more.Windows.Win32.Foundation.HRESULT = -2144796140
TBSIMP_E_NOTHING_TO_UNLOAD: win32more.Windows.Win32.Foundation.HRESULT = -2144796139
TBSIMP_E_HASH_TABLE_FULL: win32more.Windows.Win32.Foundation.HRESULT = -2144796138
TBSIMP_E_TOO_MANY_TBS_CONTEXTS: win32more.Windows.Win32.Foundation.HRESULT = -2144796137
TBSIMP_E_TOO_MANY_RESOURCES: win32more.Windows.Win32.Foundation.HRESULT = -2144796136
TBSIMP_E_PPI_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144796135
TBSIMP_E_TPM_INCOMPATIBLE: win32more.Windows.Win32.Foundation.HRESULT = -2144796134
TBSIMP_E_NO_EVENT_LOG: win32more.Windows.Win32.Foundation.HRESULT = -2144796133
TPM_E_PPI_ACPI_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2144795904
TPM_E_PPI_USER_ABORT: win32more.Windows.Win32.Foundation.HRESULT = -2144795903
TPM_E_PPI_BIOS_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2144795902
TPM_E_PPI_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144795901
TPM_E_PPI_BLOCKED_IN_BIOS: win32more.Windows.Win32.Foundation.HRESULT = -2144795900
TPM_E_PCP_ERROR_MASK: win32more.Windows.Win32.Foundation.HRESULT = -2144795648
TPM_E_PCP_DEVICE_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -2144795647
TPM_E_PCP_INVALID_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2144795646
TPM_E_PCP_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.HRESULT = -2144795645
TPM_E_PCP_FLAG_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144795644
TPM_E_PCP_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144795643
TPM_E_PCP_BUFFER_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -2144795642
TPM_E_PCP_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2144795641
TPM_E_PCP_AUTHENTICATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144795640
TPM_E_PCP_AUTHENTICATION_IGNORED: win32more.Windows.Win32.Foundation.HRESULT = -2144795639
TPM_E_PCP_POLICY_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144795638
TPM_E_PCP_PROFILE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144795637
TPM_E_PCP_VALIDATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144795636
TPM_E_PCP_WRONG_PARENT: win32more.Windows.Win32.Foundation.HRESULT = -2144795634
TPM_E_KEY_NOT_LOADED: win32more.Windows.Win32.Foundation.HRESULT = -2144795633
TPM_E_NO_KEY_CERTIFICATION: win32more.Windows.Win32.Foundation.HRESULT = -2144795632
TPM_E_KEY_NOT_FINALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2144795631
TPM_E_ATTESTATION_CHALLENGE_NOT_SET: win32more.Windows.Win32.Foundation.HRESULT = -2144795630
TPM_E_NOT_PCR_BOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144795629
TPM_E_KEY_ALREADY_FINALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2144795628
TPM_E_KEY_USAGE_POLICY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144795627
TPM_E_KEY_USAGE_POLICY_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2144795626
TPM_E_SOFT_KEY_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2144795625
TPM_E_KEY_NOT_AUTHENTICATED: win32more.Windows.Win32.Foundation.HRESULT = -2144795624
TPM_E_PCP_KEY_NOT_AIK: win32more.Windows.Win32.Foundation.HRESULT = -2144795623
TPM_E_KEY_NOT_SIGNING_KEY: win32more.Windows.Win32.Foundation.HRESULT = -2144795622
TPM_E_LOCKED_OUT: win32more.Windows.Win32.Foundation.HRESULT = -2144795621
TPM_E_CLAIM_TYPE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144795620
TPM_E_VERSION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144795619
TPM_E_BUFFER_LENGTH_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2144795618
TPM_E_PCP_IFX_RSA_KEY_CREATION_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2144795617
TPM_E_PCP_TICKET_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2144795616
TPM_E_PCP_RAW_POLICY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144795615
TPM_E_PCP_KEY_HANDLE_INVALIDATED: win32more.Windows.Win32.Foundation.HRESULT = -2144795614
TPM_E_PCP_UNSUPPORTED_PSS_SALT: win32more.Windows.Win32.Foundation.HRESULT = 1076429859
TPM_E_PCP_PLATFORM_CLAIM_MAY_BE_OUTDATED: win32more.Windows.Win32.Foundation.HRESULT = 1076429860
TPM_E_PCP_PLATFORM_CLAIM_OUTDATED: win32more.Windows.Win32.Foundation.HRESULT = 1076429861
TPM_E_PCP_PLATFORM_CLAIM_REBOOT: win32more.Windows.Win32.Foundation.HRESULT = 1076429862
TPM_E_ZERO_EXHAUST_ENABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144795392
TPM_E_PROVISIONING_INCOMPLETE: win32more.Windows.Win32.Foundation.HRESULT = -2144795136
TPM_E_INVALID_OWNER_AUTH: win32more.Windows.Win32.Foundation.HRESULT = -2144795135
TPM_E_TOO_MUCH_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2144795134
TPM_E_TPM_GENERATED_EPS: win32more.Windows.Win32.Foundation.HRESULT = -2144795133
PLA_E_DCS_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144337918
PLA_E_DCS_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -2144337750
PLA_E_TOO_MANY_FOLDERS: win32more.Windows.Win32.Foundation.HRESULT = -2144337851
PLA_E_NO_MIN_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2144337808
PLA_E_DCS_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2144337737
PLA_S_PROPERTY_IGNORED: win32more.Windows.Win32.Foundation.HRESULT = 3145984
PLA_E_PROPERTY_CONFLICT: win32more.Windows.Win32.Foundation.HRESULT = -2144337663
PLA_E_DCS_SINGLETON_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144337662
PLA_E_CREDENTIALS_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144337661
PLA_E_DCS_NOT_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2144337660
PLA_E_CONFLICT_INCL_EXCL_API: win32more.Windows.Win32.Foundation.HRESULT = -2144337659
PLA_E_NETWORK_EXE_NOT_VALID: win32more.Windows.Win32.Foundation.HRESULT = -2144337658
PLA_E_EXE_ALREADY_CONFIGURED: win32more.Windows.Win32.Foundation.HRESULT = -2144337657
PLA_E_EXE_PATH_NOT_VALID: win32more.Windows.Win32.Foundation.HRESULT = -2144337656
PLA_E_DC_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2144337655
PLA_E_DCS_START_WAIT_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2144337654
PLA_E_DC_START_WAIT_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2144337653
PLA_E_REPORT_WAIT_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2144337652
PLA_E_NO_DUPLICATES: win32more.Windows.Win32.Foundation.HRESULT = -2144337651
PLA_E_EXE_FULL_PATH_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144337650
PLA_E_INVALID_SESSION_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2144337649
PLA_E_PLA_CHANNEL_NOT_ENABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144337648
PLA_E_TASKSCHED_CHANNEL_NOT_ENABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144337647
PLA_E_RULES_MANAGER_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144337646
PLA_E_CABAPI_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2144337645
FVE_E_LOCKED_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2144272384
FVE_E_NOT_ENCRYPTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272383
FVE_E_NO_TPM_BIOS: win32more.Windows.Win32.Foundation.HRESULT = -2144272382
FVE_E_NO_MBR_METRIC: win32more.Windows.Win32.Foundation.HRESULT = -2144272381
FVE_E_NO_BOOTSECTOR_METRIC: win32more.Windows.Win32.Foundation.HRESULT = -2144272380
FVE_E_NO_BOOTMGR_METRIC: win32more.Windows.Win32.Foundation.HRESULT = -2144272379
FVE_E_WRONG_BOOTMGR: win32more.Windows.Win32.Foundation.HRESULT = -2144272378
FVE_E_SECURE_KEY_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144272377
FVE_E_NOT_ACTIVATED: win32more.Windows.Win32.Foundation.HRESULT = -2144272376
FVE_E_ACTION_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272375
FVE_E_AD_SCHEMA_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -2144272374
FVE_E_AD_INVALID_DATATYPE: win32more.Windows.Win32.Foundation.HRESULT = -2144272373
FVE_E_AD_INVALID_DATASIZE: win32more.Windows.Win32.Foundation.HRESULT = -2144272372
FVE_E_AD_NO_VALUES: win32more.Windows.Win32.Foundation.HRESULT = -2144272371
FVE_E_AD_ATTR_NOT_SET: win32more.Windows.Win32.Foundation.HRESULT = -2144272370
FVE_E_AD_GUID_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144272369
FVE_E_BAD_INFORMATION: win32more.Windows.Win32.Foundation.HRESULT = -2144272368
FVE_E_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -2144272367
FVE_E_SYSTEM_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2144272366
FVE_E_FAILED_WRONG_FS: win32more.Windows.Win32.Foundation.HRESULT = -2144272365
FVE_E_BAD_PARTITION_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2144272364
FVE_E_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272363
FVE_E_BAD_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2144272362
FVE_E_VOLUME_NOT_BOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144272361
FVE_E_TPM_NOT_OWNED: win32more.Windows.Win32.Foundation.HRESULT = -2144272360
FVE_E_NOT_DATA_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2144272359
FVE_E_AD_INSUFFICIENT_BUFFER: win32more.Windows.Win32.Foundation.HRESULT = -2144272358
FVE_E_CONV_READ: win32more.Windows.Win32.Foundation.HRESULT = -2144272357
FVE_E_CONV_WRITE: win32more.Windows.Win32.Foundation.HRESULT = -2144272356
FVE_E_KEY_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144272355
FVE_E_CLUSTERING_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272354
FVE_E_VOLUME_BOUND_ALREADY: win32more.Windows.Win32.Foundation.HRESULT = -2144272353
FVE_E_OS_NOT_PROTECTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272352
FVE_E_PROTECTION_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144272351
FVE_E_RECOVERY_KEY_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144272350
FVE_E_FOREIGN_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2144272349
FVE_E_OVERLAPPED_UPDATE: win32more.Windows.Win32.Foundation.HRESULT = -2144272348
FVE_E_TPM_SRK_AUTH_NOT_ZERO: win32more.Windows.Win32.Foundation.HRESULT = -2144272347
FVE_E_FAILED_SECTOR_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2144272346
FVE_E_FAILED_AUTHENTICATION: win32more.Windows.Win32.Foundation.HRESULT = -2144272345
FVE_E_NOT_OS_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2144272344
FVE_E_AUTOUNLOCK_ENABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144272343
FVE_E_WRONG_BOOTSECTOR: win32more.Windows.Win32.Foundation.HRESULT = -2144272342
FVE_E_WRONG_SYSTEM_FS: win32more.Windows.Win32.Foundation.HRESULT = -2144272341
FVE_E_POLICY_PASSWORD_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144272340
FVE_E_CANNOT_SET_FVEK_ENCRYPTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272339
FVE_E_CANNOT_ENCRYPT_NO_KEY: win32more.Windows.Win32.Foundation.HRESULT = -2144272338
FVE_E_BOOTABLE_CDDVD: win32more.Windows.Win32.Foundation.HRESULT = -2144272336
FVE_E_PROTECTOR_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2144272335
FVE_E_RELATIVE_PATH: win32more.Windows.Win32.Foundation.HRESULT = -2144272334
FVE_E_PROTECTOR_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144272333
FVE_E_INVALID_KEY_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2144272332
FVE_E_INVALID_PASSWORD_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2144272331
FVE_E_FIPS_RNG_CHECK_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144272330
FVE_E_FIPS_PREVENTS_RECOVERY_PASSWORD: win32more.Windows.Win32.Foundation.HRESULT = -2144272329
FVE_E_FIPS_PREVENTS_EXTERNAL_KEY_EXPORT: win32more.Windows.Win32.Foundation.HRESULT = -2144272328
FVE_E_NOT_DECRYPTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272327
FVE_E_INVALID_PROTECTOR_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2144272326
FVE_E_NO_PROTECTORS_TO_TEST: win32more.Windows.Win32.Foundation.HRESULT = -2144272325
FVE_E_KEYFILE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144272324
FVE_E_KEYFILE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2144272323
FVE_E_KEYFILE_NO_VMK: win32more.Windows.Win32.Foundation.HRESULT = -2144272322
FVE_E_TPM_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144272321
FVE_E_NOT_ALLOWED_IN_SAFE_MODE: win32more.Windows.Win32.Foundation.HRESULT = -2144272320
FVE_E_TPM_INVALID_PCR: win32more.Windows.Win32.Foundation.HRESULT = -2144272319
FVE_E_TPM_NO_VMK: win32more.Windows.Win32.Foundation.HRESULT = -2144272318
FVE_E_PIN_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2144272317
FVE_E_AUTH_INVALID_APPLICATION: win32more.Windows.Win32.Foundation.HRESULT = -2144272316
FVE_E_AUTH_INVALID_CONFIG: win32more.Windows.Win32.Foundation.HRESULT = -2144272315
FVE_E_FIPS_DISABLE_PROTECTION_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272314
FVE_E_FS_NOT_EXTENDED: win32more.Windows.Win32.Foundation.HRESULT = -2144272313
FVE_E_FIRMWARE_TYPE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272312
FVE_E_NO_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -2144272311
FVE_E_NOT_ON_STACK: win32more.Windows.Win32.Foundation.HRESULT = -2144272310
FVE_E_FS_MOUNTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272309
FVE_E_TOKEN_NOT_IMPERSONATED: win32more.Windows.Win32.Foundation.HRESULT = -2144272308
FVE_E_DRY_RUN_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144272307
FVE_E_REBOOT_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144272306
FVE_E_DEBUGGER_ENABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144272305
FVE_E_RAW_ACCESS: win32more.Windows.Win32.Foundation.HRESULT = -2144272304
FVE_E_RAW_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2144272303
FVE_E_BCD_APPLICATIONS_PATH_INCORRECT: win32more.Windows.Win32.Foundation.HRESULT = -2144272302
FVE_E_NOT_ALLOWED_IN_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2144272301
FVE_E_NO_AUTOUNLOCK_MASTER_KEY: win32more.Windows.Win32.Foundation.HRESULT = -2144272300
FVE_E_MOR_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144272299
FVE_E_HIDDEN_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2144272298
FVE_E_TRANSIENT_STATE: win32more.Windows.Win32.Foundation.HRESULT = -2144272297
FVE_E_PUBKEY_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272296
FVE_E_VOLUME_HANDLE_OPEN: win32more.Windows.Win32.Foundation.HRESULT = -2144272295
FVE_E_NO_FEATURE_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -2144272294
FVE_E_INVALID_STARTUP_OPTIONS: win32more.Windows.Win32.Foundation.HRESULT = -2144272293
FVE_E_POLICY_RECOVERY_PASSWORD_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272292
FVE_E_POLICY_RECOVERY_PASSWORD_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144272291
FVE_E_POLICY_RECOVERY_KEY_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272290
FVE_E_POLICY_RECOVERY_KEY_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144272289
FVE_E_POLICY_STARTUP_PIN_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272288
FVE_E_POLICY_STARTUP_PIN_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144272287
FVE_E_POLICY_STARTUP_KEY_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272286
FVE_E_POLICY_STARTUP_KEY_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144272285
FVE_E_POLICY_STARTUP_PIN_KEY_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272284
FVE_E_POLICY_STARTUP_PIN_KEY_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144272283
FVE_E_POLICY_STARTUP_TPM_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272282
FVE_E_POLICY_STARTUP_TPM_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144272281
FVE_E_POLICY_INVALID_PIN_LENGTH: win32more.Windows.Win32.Foundation.HRESULT = -2144272280
FVE_E_KEY_PROTECTOR_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272279
FVE_E_POLICY_PASSPHRASE_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272278
FVE_E_POLICY_PASSPHRASE_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144272277
FVE_E_FIPS_PREVENTS_PASSPHRASE: win32more.Windows.Win32.Foundation.HRESULT = -2144272276
FVE_E_OS_VOLUME_PASSPHRASE_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272275
FVE_E_INVALID_BITLOCKER_OID: win32more.Windows.Win32.Foundation.HRESULT = -2144272274
FVE_E_VOLUME_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -2144272273
FVE_E_DV_NOT_SUPPORTED_ON_FS: win32more.Windows.Win32.Foundation.HRESULT = -2144272272
FVE_E_DV_NOT_ALLOWED_BY_GP: win32more.Windows.Win32.Foundation.HRESULT = -2144272271
FVE_E_POLICY_USER_CERTIFICATE_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272270
FVE_E_POLICY_USER_CERTIFICATE_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144272269
FVE_E_POLICY_USER_CERT_MUST_BE_HW: win32more.Windows.Win32.Foundation.HRESULT = -2144272268
FVE_E_POLICY_USER_CONFIGURE_FDV_AUTOUNLOCK_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272267
FVE_E_POLICY_USER_CONFIGURE_RDV_AUTOUNLOCK_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272266
FVE_E_POLICY_USER_CONFIGURE_RDV_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272265
FVE_E_POLICY_USER_ENABLE_RDV_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272264
FVE_E_POLICY_USER_DISABLE_RDV_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272263
FVE_E_POLICY_INVALID_PASSPHRASE_LENGTH: win32more.Windows.Win32.Foundation.HRESULT = -2144272256
FVE_E_POLICY_PASSPHRASE_TOO_SIMPLE: win32more.Windows.Win32.Foundation.HRESULT = -2144272255
FVE_E_RECOVERY_PARTITION: win32more.Windows.Win32.Foundation.HRESULT = -2144272254
FVE_E_POLICY_CONFLICT_FDV_RK_OFF_AUK_ON: win32more.Windows.Win32.Foundation.HRESULT = -2144272253
FVE_E_POLICY_CONFLICT_RDV_RK_OFF_AUK_ON: win32more.Windows.Win32.Foundation.HRESULT = -2144272252
FVE_E_NON_BITLOCKER_OID: win32more.Windows.Win32.Foundation.HRESULT = -2144272251
FVE_E_POLICY_PROHIBITS_SELFSIGNED: win32more.Windows.Win32.Foundation.HRESULT = -2144272250
FVE_E_POLICY_CONFLICT_RO_AND_STARTUP_KEY_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144272249
FVE_E_CONV_RECOVERY_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144272248
FVE_E_VIRTUALIZED_SPACE_TOO_BIG: win32more.Windows.Win32.Foundation.HRESULT = -2144272247
FVE_E_POLICY_CONFLICT_OSV_RP_OFF_ADB_ON: win32more.Windows.Win32.Foundation.HRESULT = -2144272240
FVE_E_POLICY_CONFLICT_FDV_RP_OFF_ADB_ON: win32more.Windows.Win32.Foundation.HRESULT = -2144272239
FVE_E_POLICY_CONFLICT_RDV_RP_OFF_ADB_ON: win32more.Windows.Win32.Foundation.HRESULT = -2144272238
FVE_E_NON_BITLOCKER_KU: win32more.Windows.Win32.Foundation.HRESULT = -2144272237
FVE_E_PRIVATEKEY_AUTH_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144272236
FVE_E_REMOVAL_OF_DRA_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144272235
FVE_E_OPERATION_NOT_SUPPORTED_ON_VISTA_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2144272234
FVE_E_CANT_LOCK_AUTOUNLOCK_ENABLED_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2144272233
FVE_E_FIPS_HASH_KDF_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272232
FVE_E_ENH_PIN_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2144272231
FVE_E_INVALID_PIN_CHARS: win32more.Windows.Win32.Foundation.HRESULT = -2144272230
FVE_E_INVALID_DATUM_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2144272229
FVE_E_EFI_ONLY: win32more.Windows.Win32.Foundation.HRESULT = -2144272228
FVE_E_MULTIPLE_NKP_CERTS: win32more.Windows.Win32.Foundation.HRESULT = -2144272227
FVE_E_REMOVAL_OF_NKP_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144272226
FVE_E_INVALID_NKP_CERT: win32more.Windows.Win32.Foundation.HRESULT = -2144272225
FVE_E_NO_EXISTING_PIN: win32more.Windows.Win32.Foundation.HRESULT = -2144272224
FVE_E_PROTECTOR_CHANGE_PIN_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2144272223
FVE_E_PIN_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272222
FVE_E_PROTECTOR_CHANGE_MAX_PIN_CHANGE_ATTEMPTS_REACHED: win32more.Windows.Win32.Foundation.HRESULT = -2144272221
FVE_E_POLICY_PASSPHRASE_REQUIRES_ASCII: win32more.Windows.Win32.Foundation.HRESULT = -2144272220
FVE_E_FULL_ENCRYPTION_NOT_ALLOWED_ON_TP_STORAGE: win32more.Windows.Win32.Foundation.HRESULT = -2144272219
FVE_E_WIPE_NOT_ALLOWED_ON_TP_STORAGE: win32more.Windows.Win32.Foundation.HRESULT = -2144272218
FVE_E_KEY_LENGTH_NOT_SUPPORTED_BY_EDRIVE: win32more.Windows.Win32.Foundation.HRESULT = -2144272217
FVE_E_NO_EXISTING_PASSPHRASE: win32more.Windows.Win32.Foundation.HRESULT = -2144272216
FVE_E_PROTECTOR_CHANGE_PASSPHRASE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2144272215
FVE_E_PASSPHRASE_TOO_LONG: win32more.Windows.Win32.Foundation.HRESULT = -2144272214
FVE_E_NO_PASSPHRASE_WITH_TPM: win32more.Windows.Win32.Foundation.HRESULT = -2144272213
FVE_E_NO_TPM_WITH_PASSPHRASE: win32more.Windows.Win32.Foundation.HRESULT = -2144272212
FVE_E_NOT_ALLOWED_ON_CSV_STACK: win32more.Windows.Win32.Foundation.HRESULT = -2144272211
FVE_E_NOT_ALLOWED_ON_CLUSTER: win32more.Windows.Win32.Foundation.HRESULT = -2144272210
FVE_E_EDRIVE_NO_FAILOVER_TO_SW: win32more.Windows.Win32.Foundation.HRESULT = -2144272209
FVE_E_EDRIVE_BAND_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -2144272208
FVE_E_EDRIVE_DISALLOWED_BY_GP: win32more.Windows.Win32.Foundation.HRESULT = -2144272207
FVE_E_EDRIVE_INCOMPATIBLE_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2144272206
FVE_E_NOT_ALLOWED_TO_UPGRADE_WHILE_CONVERTING: win32more.Windows.Win32.Foundation.HRESULT = -2144272205
FVE_E_EDRIVE_DV_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272204
FVE_E_NO_PREBOOT_KEYBOARD_DETECTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272203
FVE_E_NO_PREBOOT_KEYBOARD_OR_WINRE_DETECTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272202
FVE_E_POLICY_REQUIRES_STARTUP_PIN_ON_TOUCH_DEVICE: win32more.Windows.Win32.Foundation.HRESULT = -2144272201
FVE_E_POLICY_REQUIRES_RECOVERY_PASSWORD_ON_TOUCH_DEVICE: win32more.Windows.Win32.Foundation.HRESULT = -2144272200
FVE_E_WIPE_CANCEL_NOT_APPLICABLE: win32more.Windows.Win32.Foundation.HRESULT = -2144272199
FVE_E_SECUREBOOT_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144272198
FVE_E_SECUREBOOT_CONFIGURATION_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2144272197
FVE_E_EDRIVE_DRY_RUN_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144272196
FVE_E_SHADOW_COPY_PRESENT: win32more.Windows.Win32.Foundation.HRESULT = -2144272195
FVE_E_POLICY_INVALID_ENHANCED_BCD_SETTINGS: win32more.Windows.Win32.Foundation.HRESULT = -2144272194
FVE_E_EDRIVE_INCOMPATIBLE_FIRMWARE: win32more.Windows.Win32.Foundation.HRESULT = -2144272193
FVE_E_PROTECTOR_CHANGE_MAX_PASSPHRASE_CHANGE_ATTEMPTS_REACHED: win32more.Windows.Win32.Foundation.HRESULT = -2144272192
FVE_E_PASSPHRASE_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272191
FVE_E_LIVEID_ACCOUNT_SUSPENDED: win32more.Windows.Win32.Foundation.HRESULT = -2144272190
FVE_E_LIVEID_ACCOUNT_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2144272189
FVE_E_NOT_PROVISIONED_ON_ALL_VOLUMES: win32more.Windows.Win32.Foundation.HRESULT = -2144272188
FVE_E_DE_FIXED_DATA_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272187
FVE_E_DE_HARDWARE_NOT_COMPLIANT: win32more.Windows.Win32.Foundation.HRESULT = -2144272186
FVE_E_DE_WINRE_NOT_CONFIGURED: win32more.Windows.Win32.Foundation.HRESULT = -2144272185
FVE_E_DE_PROTECTION_SUSPENDED: win32more.Windows.Win32.Foundation.HRESULT = -2144272184
FVE_E_DE_OS_VOLUME_NOT_PROTECTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272183
FVE_E_DE_DEVICE_LOCKEDOUT: win32more.Windows.Win32.Foundation.HRESULT = -2144272182
FVE_E_DE_PROTECTION_NOT_YET_ENABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144272181
FVE_E_INVALID_PIN_CHARS_DETAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144272180
FVE_E_DEVICE_LOCKOUT_COUNTER_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2144272179
FVE_E_DEVICELOCKOUT_COUNTER_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2144272178
FVE_E_BUFFER_TOO_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -2144272177
FVE_E_NO_SUCH_CAPABILITY_ON_TARGET: win32more.Windows.Win32.Foundation.HRESULT = -2144272176
FVE_E_DE_PREVENTED_FOR_OS: win32more.Windows.Win32.Foundation.HRESULT = -2144272175
FVE_E_DE_VOLUME_OPTED_OUT: win32more.Windows.Win32.Foundation.HRESULT = -2144272174
FVE_E_DE_VOLUME_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272173
FVE_E_EOW_NOT_SUPPORTED_IN_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2144272172
FVE_E_ADBACKUP_NOT_ENABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144272171
FVE_E_VOLUME_EXTEND_PREVENTS_EOW_DECRYPT: win32more.Windows.Win32.Foundation.HRESULT = -2144272170
FVE_E_NOT_DE_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2144272169
FVE_E_PROTECTION_CANNOT_BE_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144272168
FVE_E_OSV_KSR_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2144272167
FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_OS_DRIVE: win32more.Windows.Win32.Foundation.HRESULT = -2144272166
FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_FIXED_DRIVE: win32more.Windows.Win32.Foundation.HRESULT = -2144272165
FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_REMOVABLE_DRIVE: win32more.Windows.Win32.Foundation.HRESULT = -2144272164
FVE_E_KEY_ROTATION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272163
FVE_E_EXECUTE_REQUEST_SENT_TOO_SOON: win32more.Windows.Win32.Foundation.HRESULT = -2144272162
FVE_E_KEY_ROTATION_NOT_ENABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144272161
FVE_E_DEVICE_NOT_JOINED: win32more.Windows.Win32.Foundation.HRESULT = -2144272160
FVE_E_AAD_ENDPOINT_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -2144272159
FVE_E_INVALID_NBP_CERT: win32more.Windows.Win32.Foundation.HRESULT = -2144272158
FVE_E_EDRIVE_BAND_ENUMERATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144272157
FVE_E_POLICY_ON_RDV_EXCLUSION_LIST: win32more.Windows.Win32.Foundation.HRESULT = -2144272156
FVE_E_PREDICTED_TPM_PROTECTOR_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272155
FVE_E_SETUP_TPM_CALLBACK_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272154
FVE_E_TPM_CONTEXT_SETUP_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144272153
FVE_E_UPDATE_INVALID_CONFIG: win32more.Windows.Win32.Foundation.HRESULT = -2144272152
FVE_E_AAD_SERVER_FAIL_RETRY_AFTER: win32more.Windows.Win32.Foundation.HRESULT = -2144272151
FVE_E_AAD_SERVER_FAIL_BACKOFF: win32more.Windows.Win32.Foundation.HRESULT = -2144272150
FVE_E_DATASET_FULL: win32more.Windows.Win32.Foundation.HRESULT = -2144272149
FVE_E_METADATA_FULL: win32more.Windows.Win32.Foundation.HRESULT = -2144272148
FWP_E_CALLOUT_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144206847
FWP_E_CONDITION_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144206846
FWP_E_FILTER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144206845
FWP_E_LAYER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144206844
FWP_E_PROVIDER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144206843
FWP_E_PROVIDER_CONTEXT_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144206842
FWP_E_SUBLAYER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144206841
FWP_E_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2144206840
FWP_E_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2144206839
FWP_E_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -2144206838
FWP_E_DYNAMIC_SESSION_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2144206837
FWP_E_WRONG_SESSION: win32more.Windows.Win32.Foundation.HRESULT = -2144206836
FWP_E_NO_TXN_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2144206835
FWP_E_TXN_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2144206834
FWP_E_TXN_ABORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144206833
FWP_E_SESSION_ABORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144206832
FWP_E_INCOMPATIBLE_TXN: win32more.Windows.Win32.Foundation.HRESULT = -2144206831
FWP_E_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2144206830
FWP_E_NET_EVENTS_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144206829
FWP_E_INCOMPATIBLE_LAYER: win32more.Windows.Win32.Foundation.HRESULT = -2144206828
FWP_E_KM_CLIENTS_ONLY: win32more.Windows.Win32.Foundation.HRESULT = -2144206827
FWP_E_LIFETIME_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2144206826
FWP_E_BUILTIN_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -2144206825
FWP_E_TOO_MANY_CALLOUTS: win32more.Windows.Win32.Foundation.HRESULT = -2144206824
FWP_E_NOTIFICATION_DROPPED: win32more.Windows.Win32.Foundation.HRESULT = -2144206823
FWP_E_TRAFFIC_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2144206822
FWP_E_INCOMPATIBLE_SA_STATE: win32more.Windows.Win32.Foundation.HRESULT = -2144206821
FWP_E_NULL_POINTER: win32more.Windows.Win32.Foundation.HRESULT = -2144206820
FWP_E_INVALID_ENUMERATOR: win32more.Windows.Win32.Foundation.HRESULT = -2144206819
FWP_E_INVALID_FLAGS: win32more.Windows.Win32.Foundation.HRESULT = -2144206818
FWP_E_INVALID_NET_MASK: win32more.Windows.Win32.Foundation.HRESULT = -2144206817
FWP_E_INVALID_RANGE: win32more.Windows.Win32.Foundation.HRESULT = -2144206816
FWP_E_INVALID_INTERVAL: win32more.Windows.Win32.Foundation.HRESULT = -2144206815
FWP_E_ZERO_LENGTH_ARRAY: win32more.Windows.Win32.Foundation.HRESULT = -2144206814
FWP_E_NULL_DISPLAY_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2144206813
FWP_E_INVALID_ACTION_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2144206812
FWP_E_INVALID_WEIGHT: win32more.Windows.Win32.Foundation.HRESULT = -2144206811
FWP_E_MATCH_TYPE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2144206810
FWP_E_TYPE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2144206809
FWP_E_OUT_OF_BOUNDS: win32more.Windows.Win32.Foundation.HRESULT = -2144206808
FWP_E_RESERVED: win32more.Windows.Win32.Foundation.HRESULT = -2144206807
FWP_E_DUPLICATE_CONDITION: win32more.Windows.Win32.Foundation.HRESULT = -2144206806
FWP_E_DUPLICATE_KEYMOD: win32more.Windows.Win32.Foundation.HRESULT = -2144206805
FWP_E_ACTION_INCOMPATIBLE_WITH_LAYER: win32more.Windows.Win32.Foundation.HRESULT = -2144206804
FWP_E_ACTION_INCOMPATIBLE_WITH_SUBLAYER: win32more.Windows.Win32.Foundation.HRESULT = -2144206803
FWP_E_CONTEXT_INCOMPATIBLE_WITH_LAYER: win32more.Windows.Win32.Foundation.HRESULT = -2144206802
FWP_E_CONTEXT_INCOMPATIBLE_WITH_CALLOUT: win32more.Windows.Win32.Foundation.HRESULT = -2144206801
FWP_E_INCOMPATIBLE_AUTH_METHOD: win32more.Windows.Win32.Foundation.HRESULT = -2144206800
FWP_E_INCOMPATIBLE_DH_GROUP: win32more.Windows.Win32.Foundation.HRESULT = -2144206799
FWP_E_EM_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144206798
FWP_E_NEVER_MATCH: win32more.Windows.Win32.Foundation.HRESULT = -2144206797
FWP_E_PROVIDER_CONTEXT_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2144206796
FWP_E_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.HRESULT = -2144206795
FWP_E_TOO_MANY_SUBLAYERS: win32more.Windows.Win32.Foundation.HRESULT = -2144206794
FWP_E_CALLOUT_NOTIFICATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144206793
FWP_E_INVALID_AUTH_TRANSFORM: win32more.Windows.Win32.Foundation.HRESULT = -2144206792
FWP_E_INVALID_CIPHER_TRANSFORM: win32more.Windows.Win32.Foundation.HRESULT = -2144206791
FWP_E_INCOMPATIBLE_CIPHER_TRANSFORM: win32more.Windows.Win32.Foundation.HRESULT = -2144206790
FWP_E_INVALID_TRANSFORM_COMBINATION: win32more.Windows.Win32.Foundation.HRESULT = -2144206789
FWP_E_DUPLICATE_AUTH_METHOD: win32more.Windows.Win32.Foundation.HRESULT = -2144206788
FWP_E_INVALID_TUNNEL_ENDPOINT: win32more.Windows.Win32.Foundation.HRESULT = -2144206787
FWP_E_L2_DRIVER_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -2144206786
FWP_E_KEY_DICTATOR_ALREADY_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2144206785
FWP_E_KEY_DICTATION_INVALID_KEYING_MATERIAL: win32more.Windows.Win32.Foundation.HRESULT = -2144206784
FWP_E_CONNECTIONS_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144206783
FWP_E_INVALID_DNS_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2144206782
FWP_E_STILL_ON: win32more.Windows.Win32.Foundation.HRESULT = -2144206781
FWP_E_IKEEXT_NOT_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2144206780
FWP_E_DROP_NOICMP: win32more.Windows.Win32.Foundation.HRESULT = -2144206588
WS_S_ASYNC: win32more.Windows.Win32.Foundation.HRESULT = 3997696
WS_S_END: win32more.Windows.Win32.Foundation.HRESULT = 3997697
WS_E_INVALID_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2143485952
WS_E_OBJECT_FAULTED: win32more.Windows.Win32.Foundation.HRESULT = -2143485951
WS_E_NUMERIC_OVERFLOW: win32more.Windows.Win32.Foundation.HRESULT = -2143485950
WS_E_INVALID_OPERATION: win32more.Windows.Win32.Foundation.HRESULT = -2143485949
WS_E_OPERATION_ABORTED: win32more.Windows.Win32.Foundation.HRESULT = -2143485948
WS_E_ENDPOINT_ACCESS_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2143485947
WS_E_OPERATION_TIMED_OUT: win32more.Windows.Win32.Foundation.HRESULT = -2143485946
WS_E_OPERATION_ABANDONED: win32more.Windows.Win32.Foundation.HRESULT = -2143485945
WS_E_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2143485944
WS_E_NO_TRANSLATION_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2143485943
WS_E_SECURITY_VERIFICATION_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2143485942
WS_E_ADDRESS_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -2143485941
WS_E_ADDRESS_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2143485940
WS_E_ENDPOINT_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2143485939
WS_E_ENDPOINT_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2143485938
WS_E_ENDPOINT_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2143485937
WS_E_ENDPOINT_UNREACHABLE: win32more.Windows.Win32.Foundation.HRESULT = -2143485936
WS_E_ENDPOINT_ACTION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2143485935
WS_E_ENDPOINT_TOO_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -2143485934
WS_E_ENDPOINT_FAULT_RECEIVED: win32more.Windows.Win32.Foundation.HRESULT = -2143485933
WS_E_ENDPOINT_DISCONNECTED: win32more.Windows.Win32.Foundation.HRESULT = -2143485932
WS_E_PROXY_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2143485931
WS_E_PROXY_ACCESS_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2143485930
WS_E_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2143485929
WS_E_PROXY_REQUIRES_BASIC_AUTH: win32more.Windows.Win32.Foundation.HRESULT = -2143485928
WS_E_PROXY_REQUIRES_DIGEST_AUTH: win32more.Windows.Win32.Foundation.HRESULT = -2143485927
WS_E_PROXY_REQUIRES_NTLM_AUTH: win32more.Windows.Win32.Foundation.HRESULT = -2143485926
WS_E_PROXY_REQUIRES_NEGOTIATE_AUTH: win32more.Windows.Win32.Foundation.HRESULT = -2143485925
WS_E_SERVER_REQUIRES_BASIC_AUTH: win32more.Windows.Win32.Foundation.HRESULT = -2143485924
WS_E_SERVER_REQUIRES_DIGEST_AUTH: win32more.Windows.Win32.Foundation.HRESULT = -2143485923
WS_E_SERVER_REQUIRES_NTLM_AUTH: win32more.Windows.Win32.Foundation.HRESULT = -2143485922
WS_E_SERVER_REQUIRES_NEGOTIATE_AUTH: win32more.Windows.Win32.Foundation.HRESULT = -2143485921
WS_E_INVALID_ENDPOINT_URL: win32more.Windows.Win32.Foundation.HRESULT = -2143485920
WS_E_OTHER: win32more.Windows.Win32.Foundation.HRESULT = -2143485919
WS_E_SECURITY_TOKEN_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -2143485918
WS_E_SECURITY_SYSTEM_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2143485917
HCS_E_TERMINATED_DURING_START: win32more.Windows.Win32.Foundation.HRESULT = -2143878912
HCS_E_IMAGE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2143878911
HCS_E_HYPERV_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -2143878910
HCS_E_INVALID_STATE: win32more.Windows.Win32.Foundation.HRESULT = -2143878907
HCS_E_UNEXPECTED_EXIT: win32more.Windows.Win32.Foundation.HRESULT = -2143878906
HCS_E_TERMINATED: win32more.Windows.Win32.Foundation.HRESULT = -2143878905
HCS_E_CONNECT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2143878904
HCS_E_CONNECTION_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2143878903
HCS_E_CONNECTION_CLOSED: win32more.Windows.Win32.Foundation.HRESULT = -2143878902
HCS_E_UNKNOWN_MESSAGE: win32more.Windows.Win32.Foundation.HRESULT = -2143878901
HCS_E_UNSUPPORTED_PROTOCOL_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2143878900
HCS_E_INVALID_JSON: win32more.Windows.Win32.Foundation.HRESULT = -2143878899
HCS_E_SYSTEM_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2143878898
HCS_E_SYSTEM_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2143878897
HCS_E_SYSTEM_ALREADY_STOPPED: win32more.Windows.Win32.Foundation.HRESULT = -2143878896
HCS_E_PROTOCOL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2143878895
HCS_E_INVALID_LAYER: win32more.Windows.Win32.Foundation.HRESULT = -2143878894
HCS_E_WINDOWS_INSIDER_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2143878893
HCS_E_SERVICE_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2143878892
HCS_E_OPERATION_NOT_STARTED: win32more.Windows.Win32.Foundation.HRESULT = -2143878891
HCS_E_OPERATION_ALREADY_STARTED: win32more.Windows.Win32.Foundation.HRESULT = -2143878890
HCS_E_OPERATION_PENDING: win32more.Windows.Win32.Foundation.HRESULT = -2143878889
HCS_E_OPERATION_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2143878888
HCS_E_OPERATION_SYSTEM_CALLBACK_ALREADY_SET: win32more.Windows.Win32.Foundation.HRESULT = -2143878887
HCS_E_OPERATION_RESULT_ALLOCATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2143878886
HCS_E_ACCESS_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2143878885
HCS_E_GUEST_CRITICAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2143878884
HCS_E_PROCESS_INFO_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2143878883
HCS_E_SERVICE_DISCONNECT: win32more.Windows.Win32.Foundation.HRESULT = -2143878882
HCS_E_PROCESS_ALREADY_STOPPED: win32more.Windows.Win32.Foundation.HRESULT = -2143878881
HCS_E_SYSTEM_NOT_CONFIGURED_FOR_OPERATION: win32more.Windows.Win32.Foundation.HRESULT = -2143878880
HCS_E_OPERATION_ALREADY_CANCELLED: win32more.Windows.Win32.Foundation.HRESULT = -2143878879
WHV_E_UNKNOWN_CAPABILITY: win32more.Windows.Win32.Foundation.HRESULT = -2143878400
WHV_E_INSUFFICIENT_BUFFER: win32more.Windows.Win32.Foundation.HRESULT = -2143878399
WHV_E_UNKNOWN_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2143878398
WHV_E_UNSUPPORTED_HYPERVISOR_CONFIG: win32more.Windows.Win32.Foundation.HRESULT = -2143878397
WHV_E_INVALID_PARTITION_CONFIG: win32more.Windows.Win32.Foundation.HRESULT = -2143878396
WHV_E_GPA_RANGE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2143878395
WHV_E_VP_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2143878394
WHV_E_VP_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.HRESULT = -2143878393
WHV_E_INVALID_VP_STATE: win32more.Windows.Win32.Foundation.HRESULT = -2143878392
WHV_E_INVALID_VP_REGISTER_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2143878391
WHV_E_UNSUPPORTED_PROCESSOR_CONFIG: win32more.Windows.Win32.Foundation.HRESULT = -2143878384
VM_SAVED_STATE_DUMP_E_PARTITION_STATE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1070136064
VM_SAVED_STATE_DUMP_E_GUEST_MEMORY_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1070136063
VM_SAVED_STATE_DUMP_E_NO_VP_FOUND_IN_PARTITION_STATE: win32more.Windows.Win32.Foundation.HRESULT = -1070136062
VM_SAVED_STATE_DUMP_E_NESTED_VIRTUALIZATION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1070136061
VM_SAVED_STATE_DUMP_E_WINDOWS_KERNEL_IMAGE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1070136060
VM_SAVED_STATE_DUMP_E_VA_NOT_MAPPED: win32more.Windows.Win32.Foundation.HRESULT = -1070136059
VM_SAVED_STATE_DUMP_E_INVALID_VP_STATE: win32more.Windows.Win32.Foundation.HRESULT = -1070136058
VM_SAVED_STATE_DUMP_E_VP_VTL_NOT_ENABLED: win32more.Windows.Win32.Foundation.HRESULT = -1070136055
ERROR_DM_OPERATION_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -1070135808
HCN_E_NETWORK_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2143617023
HCN_E_ENDPOINT_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2143617022
HCN_E_LAYER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2143617021
HCN_E_SWITCH_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2143617020
HCN_E_SUBNET_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2143617019
HCN_E_ADAPTER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2143617018
HCN_E_PORT_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2143617017
HCN_E_POLICY_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2143617016
HCN_E_VFP_PORTSETTING_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2143617015
HCN_E_INVALID_NETWORK: win32more.Windows.Win32.Foundation.HRESULT = -2143617014
HCN_E_INVALID_NETWORK_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2143617013
HCN_E_INVALID_ENDPOINT: win32more.Windows.Win32.Foundation.HRESULT = -2143617012
HCN_E_INVALID_POLICY: win32more.Windows.Win32.Foundation.HRESULT = -2143617011
HCN_E_INVALID_POLICY_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2143617010
HCN_E_INVALID_REMOTE_ENDPOINT_OPERATION: win32more.Windows.Win32.Foundation.HRESULT = -2143617009
HCN_E_NETWORK_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2143617008
HCN_E_LAYER_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2143617007
HCN_E_POLICY_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2143617006
HCN_E_PORT_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2143617005
HCN_E_ENDPOINT_ALREADY_ATTACHED: win32more.Windows.Win32.Foundation.HRESULT = -2143617004
HCN_E_REQUEST_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2143617003
HCN_E_MAPPING_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2143617002
HCN_E_DEGRADED_OPERATION: win32more.Windows.Win32.Foundation.HRESULT = -2143617001
HCN_E_SHARED_SWITCH_MODIFICATION: win32more.Windows.Win32.Foundation.HRESULT = -2143617000
HCN_E_GUID_CONVERSION_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2143616999
HCN_E_REGKEY_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2143616998
HCN_E_INVALID_JSON: win32more.Windows.Win32.Foundation.HRESULT = -2143616997
HCN_E_INVALID_JSON_REFERENCE: win32more.Windows.Win32.Foundation.HRESULT = -2143616996
HCN_E_ENDPOINT_SHARING_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2143616995
HCN_E_INVALID_IP: win32more.Windows.Win32.Foundation.HRESULT = -2143616994
HCN_E_SWITCH_EXTENSION_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2143616993
HCN_E_MANAGER_STOPPED: win32more.Windows.Win32.Foundation.HRESULT = -2143616992
GCN_E_MODULE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2143616991
GCN_E_NO_REQUEST_HANDLERS: win32more.Windows.Win32.Foundation.HRESULT = -2143616990
GCN_E_REQUEST_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2143616989
GCN_E_RUNTIMEKEYS_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2143616988
GCN_E_NETADAPTER_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2143616987
GCN_E_NETADAPTER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2143616986
GCN_E_NETCOMPARTMENT_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2143616985
GCN_E_NETINTERFACE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2143616984
GCN_E_DEFAULTNAMESPACE_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2143616983
HCN_E_ICS_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2143616982
HCN_E_ENDPOINT_NAMESPACE_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2143616981
HCN_E_ENTITY_HAS_REFERENCES: win32more.Windows.Win32.Foundation.HRESULT = -2143616980
HCN_E_INVALID_INTERNAL_PORT: win32more.Windows.Win32.Foundation.HRESULT = -2143616979
HCN_E_NAMESPACE_ATTACH_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2143616978
HCN_E_ADDR_INVALID_OR_RESERVED: win32more.Windows.Win32.Foundation.HRESULT = -2143616977
HCN_E_INVALID_PREFIX: win32more.Windows.Win32.Foundation.HRESULT = -2143616976
HCN_E_OBJECT_USED_AFTER_UNLOAD: win32more.Windows.Win32.Foundation.HRESULT = -2143616975
HCN_E_INVALID_SUBNET: win32more.Windows.Win32.Foundation.HRESULT = -2143616974
HCN_E_INVALID_IP_SUBNET: win32more.Windows.Win32.Foundation.HRESULT = -2143616973
HCN_E_ENDPOINT_NOT_ATTACHED: win32more.Windows.Win32.Foundation.HRESULT = -2143616972
HCN_E_ENDPOINT_NOT_LOCAL: win32more.Windows.Win32.Foundation.HRESULT = -2143616971
HCN_INTERFACEPARAMETERS_ALREADY_APPLIED: win32more.Windows.Win32.Foundation.HRESULT = -2143616970
HCN_E_VFP_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2143616969
SDIAG_E_CANCELLED: Int32 = -2143551232
SDIAG_E_SCRIPT: Int32 = -2143551231
SDIAG_E_POWERSHELL: Int32 = -2143551230
SDIAG_E_MANAGEDHOST: Int32 = -2143551229
SDIAG_E_NOVERIFIER: Int32 = -2143551228
SDIAG_S_CANNOTRUN: Int32 = 3932421
SDIAG_E_DISABLED: Int32 = -2143551226
SDIAG_E_TRUST: Int32 = -2143551225
SDIAG_E_CANNOTRUN: Int32 = -2143551224
SDIAG_E_VERSION: Int32 = -2143551223
SDIAG_E_RESOURCE: Int32 = -2143551222
SDIAG_E_ROOTCAUSE: Int32 = -2143551221
WPN_E_CHANNEL_CLOSED: win32more.Windows.Win32.Foundation.HRESULT = -2143420160
WPN_E_CHANNEL_REQUEST_NOT_COMPLETE: win32more.Windows.Win32.Foundation.HRESULT = -2143420159
WPN_E_INVALID_APP: win32more.Windows.Win32.Foundation.HRESULT = -2143420158
WPN_E_OUTSTANDING_CHANNEL_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -2143420157
WPN_E_DUPLICATE_CHANNEL: win32more.Windows.Win32.Foundation.HRESULT = -2143420156
WPN_E_PLATFORM_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2143420155
WPN_E_NOTIFICATION_POSTED: win32more.Windows.Win32.Foundation.HRESULT = -2143420154
WPN_E_NOTIFICATION_HIDDEN: win32more.Windows.Win32.Foundation.HRESULT = -2143420153
WPN_E_NOTIFICATION_NOT_POSTED: win32more.Windows.Win32.Foundation.HRESULT = -2143420152
WPN_E_CLOUD_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2143420151
WPN_E_CLOUD_INCAPABLE: win32more.Windows.Win32.Foundation.HRESULT = -2143420144
WPN_E_CLOUD_AUTH_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2143420134
WPN_E_CLOUD_SERVICE_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2143420133
WPN_E_FAILED_LOCK_SCREEN_UPDATE_INTIALIZATION: win32more.Windows.Win32.Foundation.HRESULT = -2143420132
WPN_E_NOTIFICATION_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2143420143
WPN_E_NOTIFICATION_INCAPABLE: win32more.Windows.Win32.Foundation.HRESULT = -2143420142
WPN_E_INTERNET_INCAPABLE: win32more.Windows.Win32.Foundation.HRESULT = -2143420141
WPN_E_NOTIFICATION_TYPE_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2143420140
WPN_E_NOTIFICATION_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2143420139
WPN_E_TAG_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2143420138
WPN_E_ACCESS_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2143420137
WPN_E_DUPLICATE_REGISTRATION: win32more.Windows.Win32.Foundation.HRESULT = -2143420136
WPN_E_PUSH_NOTIFICATION_INCAPABLE: win32more.Windows.Win32.Foundation.HRESULT = -2143420135
WPN_E_DEV_ID_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2143420128
WPN_E_TAG_ALPHANUMERIC: win32more.Windows.Win32.Foundation.HRESULT = -2143420118
WPN_E_INVALID_HTTP_STATUS_CODE: win32more.Windows.Win32.Foundation.HRESULT = -2143420117
WPN_E_OUT_OF_SESSION: win32more.Windows.Win32.Foundation.HRESULT = -2143419904
WPN_E_POWER_SAVE: win32more.Windows.Win32.Foundation.HRESULT = -2143419903
WPN_E_IMAGE_NOT_FOUND_IN_CACHE: win32more.Windows.Win32.Foundation.HRESULT = -2143419902
WPN_E_ALL_URL_NOT_COMPLETED: win32more.Windows.Win32.Foundation.HRESULT = -2143419901
WPN_E_INVALID_CLOUD_IMAGE: win32more.Windows.Win32.Foundation.HRESULT = -2143419900
WPN_E_NOTIFICATION_ID_MATCHED: win32more.Windows.Win32.Foundation.HRESULT = -2143419899
WPN_E_CALLBACK_ALREADY_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2143419898
WPN_E_TOAST_NOTIFICATION_DROPPED: win32more.Windows.Win32.Foundation.HRESULT = -2143419897
WPN_E_STORAGE_LOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2143419896
WPN_E_GROUP_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2143419895
WPN_E_GROUP_ALPHANUMERIC: win32more.Windows.Win32.Foundation.HRESULT = -2143419894
WPN_E_CLOUD_DISABLED_FOR_APP: win32more.Windows.Win32.Foundation.HRESULT = -2143419893
E_MBN_CONTEXT_NOT_ACTIVATED: win32more.Windows.Win32.Foundation.HRESULT = -2141945343
E_MBN_BAD_SIM: win32more.Windows.Win32.Foundation.HRESULT = -2141945342
E_MBN_DATA_CLASS_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2141945341
E_MBN_INVALID_ACCESS_STRING: win32more.Windows.Win32.Foundation.HRESULT = -2141945340
E_MBN_MAX_ACTIVATED_CONTEXTS: win32more.Windows.Win32.Foundation.HRESULT = -2141945339
E_MBN_PACKET_SVC_DETACHED: win32more.Windows.Win32.Foundation.HRESULT = -2141945338
E_MBN_PROVIDER_NOT_VISIBLE: win32more.Windows.Win32.Foundation.HRESULT = -2141945337
E_MBN_RADIO_POWER_OFF: win32more.Windows.Win32.Foundation.HRESULT = -2141945336
E_MBN_SERVICE_NOT_ACTIVATED: win32more.Windows.Win32.Foundation.HRESULT = -2141945335
E_MBN_SIM_NOT_INSERTED: win32more.Windows.Win32.Foundation.HRESULT = -2141945334
E_MBN_VOICE_CALL_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2141945333
E_MBN_INVALID_CACHE: win32more.Windows.Win32.Foundation.HRESULT = -2141945332
E_MBN_NOT_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2141945331
E_MBN_PROVIDERS_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2141945330
E_MBN_PIN_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2141945329
E_MBN_PIN_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2141945328
E_MBN_PIN_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2141945327
E_MBN_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2141945326
E_MBN_INVALID_PROFILE: win32more.Windows.Win32.Foundation.HRESULT = -2141945320
E_MBN_DEFAULT_PROFILE_EXIST: win32more.Windows.Win32.Foundation.HRESULT = -2141945319
E_MBN_SMS_ENCODING_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2141945312
E_MBN_SMS_FILTER_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2141945311
E_MBN_SMS_INVALID_MEMORY_INDEX: win32more.Windows.Win32.Foundation.HRESULT = -2141945310
E_MBN_SMS_LANG_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2141945309
E_MBN_SMS_MEMORY_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2141945308
E_MBN_SMS_NETWORK_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2141945307
E_MBN_SMS_UNKNOWN_SMSC_ADDRESS: win32more.Windows.Win32.Foundation.HRESULT = -2141945306
E_MBN_SMS_FORMAT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2141945305
E_MBN_SMS_OPERATION_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2141945304
E_MBN_SMS_MEMORY_FULL: win32more.Windows.Win32.Foundation.HRESULT = -2141945303
PEER_E_IPV6_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -2140995583
PEER_E_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2140995582
PEER_E_CANNOT_START_SERVICE: win32more.Windows.Win32.Foundation.HRESULT = -2140995581
PEER_E_NOT_LICENSED: win32more.Windows.Win32.Foundation.HRESULT = -2140995580
PEER_E_INVALID_GRAPH: win32more.Windows.Win32.Foundation.HRESULT = -2140995568
PEER_E_DBNAME_CHANGED: win32more.Windows.Win32.Foundation.HRESULT = -2140995567
PEER_E_DUPLICATE_GRAPH: win32more.Windows.Win32.Foundation.HRESULT = -2140995566
PEER_E_GRAPH_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -2140995565
PEER_E_GRAPH_SHUTTING_DOWN: win32more.Windows.Win32.Foundation.HRESULT = -2140995564
PEER_E_GRAPH_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -2140995563
PEER_E_INVALID_DATABASE: win32more.Windows.Win32.Foundation.HRESULT = -2140995562
PEER_E_TOO_MANY_ATTRIBUTES: win32more.Windows.Win32.Foundation.HRESULT = -2140995561
PEER_E_CONNECTION_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2140995325
PEER_E_CONNECT_SELF: win32more.Windows.Win32.Foundation.HRESULT = -2140995322
PEER_E_ALREADY_LISTENING: win32more.Windows.Win32.Foundation.HRESULT = -2140995321
PEER_E_NODE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2140995320
PEER_E_CONNECTION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2140995319
PEER_E_CONNECTION_NOT_AUTHENTICATED: win32more.Windows.Win32.Foundation.HRESULT = -2140995318
PEER_E_CONNECTION_REFUSED: win32more.Windows.Win32.Foundation.HRESULT = -2140995317
PEER_E_CLASSIFIER_TOO_LONG: win32more.Windows.Win32.Foundation.HRESULT = -2140995071
PEER_E_TOO_MANY_IDENTITIES: win32more.Windows.Win32.Foundation.HRESULT = -2140995070
PEER_E_NO_KEY_ACCESS: win32more.Windows.Win32.Foundation.HRESULT = -2140995069
PEER_E_GROUPS_EXIST: win32more.Windows.Win32.Foundation.HRESULT = -2140995068
PEER_E_RECORD_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2140994815
PEER_E_DATABASE_ACCESSDENIED: win32more.Windows.Win32.Foundation.HRESULT = -2140994814
PEER_E_DBINITIALIZATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2140994813
PEER_E_MAX_RECORD_SIZE_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2140994812
PEER_E_DATABASE_ALREADY_PRESENT: win32more.Windows.Win32.Foundation.HRESULT = -2140994811
PEER_E_DATABASE_NOT_PRESENT: win32more.Windows.Win32.Foundation.HRESULT = -2140994810
PEER_E_IDENTITY_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2140994559
PEER_E_EVENT_HANDLE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2140994303
PEER_E_INVALID_SEARCH: win32more.Windows.Win32.Foundation.HRESULT = -2140994047
PEER_E_INVALID_ATTRIBUTES: win32more.Windows.Win32.Foundation.HRESULT = -2140994046
PEER_E_INVITATION_NOT_TRUSTED: win32more.Windows.Win32.Foundation.HRESULT = -2140993791
PEER_E_CHAIN_TOO_LONG: win32more.Windows.Win32.Foundation.HRESULT = -2140993789
PEER_E_INVALID_TIME_PERIOD: win32more.Windows.Win32.Foundation.HRESULT = -2140993787
PEER_E_CIRCULAR_CHAIN_DETECTED: win32more.Windows.Win32.Foundation.HRESULT = -2140993786
PEER_E_CERT_STORE_CORRUPTED: win32more.Windows.Win32.Foundation.HRESULT = -2140993535
PEER_E_NO_CLOUD: win32more.Windows.Win32.Foundation.HRESULT = -2140991487
PEER_E_CLOUD_NAME_AMBIGUOUS: win32more.Windows.Win32.Foundation.HRESULT = -2140991483
PEER_E_INVALID_RECORD: win32more.Windows.Win32.Foundation.HRESULT = -2140987376
PEER_E_NOT_AUTHORIZED: win32more.Windows.Win32.Foundation.HRESULT = -2140987360
PEER_E_PASSWORD_DOES_NOT_MEET_POLICY: win32more.Windows.Win32.Foundation.HRESULT = -2140987359
PEER_E_DEFERRED_VALIDATION: win32more.Windows.Win32.Foundation.HRESULT = -2140987344
PEER_E_INVALID_GROUP_PROPERTIES: win32more.Windows.Win32.Foundation.HRESULT = -2140987328
PEER_E_INVALID_PEER_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2140987312
PEER_E_INVALID_CLASSIFIER: win32more.Windows.Win32.Foundation.HRESULT = -2140987296
PEER_E_INVALID_FRIENDLY_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2140987280
PEER_E_INVALID_ROLE_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2140987279
PEER_E_INVALID_CLASSIFIER_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2140987278
PEER_E_INVALID_RECORD_EXPIRATION: win32more.Windows.Win32.Foundation.HRESULT = -2140987264
PEER_E_INVALID_CREDENTIAL_INFO: win32more.Windows.Win32.Foundation.HRESULT = -2140987263
PEER_E_INVALID_CREDENTIAL: win32more.Windows.Win32.Foundation.HRESULT = -2140987262
PEER_E_INVALID_RECORD_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2140987261
PEER_E_UNSUPPORTED_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2140987248
PEER_E_GROUP_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -2140987247
PEER_E_GROUP_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -2140987246
PEER_E_INVALID_GROUP: win32more.Windows.Win32.Foundation.HRESULT = -2140987245
PEER_E_NO_MEMBERS_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2140987244
PEER_E_NO_MEMBER_CONNECTIONS: win32more.Windows.Win32.Foundation.HRESULT = -2140987243
PEER_E_UNABLE_TO_LISTEN: win32more.Windows.Win32.Foundation.HRESULT = -2140987242
PEER_E_IDENTITY_DELETED: win32more.Windows.Win32.Foundation.HRESULT = -2140987232
PEER_E_SERVICE_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2140987231
PEER_E_CONTACT_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2140971007
PEER_S_GRAPH_DATA_CREATED: win32more.Windows.Win32.Foundation.HRESULT = 6488065
PEER_S_NO_EVENT_DATA: win32more.Windows.Win32.Foundation.HRESULT = 6488066
PEER_S_ALREADY_CONNECTED: win32more.Windows.Win32.Foundation.HRESULT = 6496256
PEER_S_SUBSCRIPTION_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = 6512640
PEER_S_NO_CONNECTIVITY: win32more.Windows.Win32.Foundation.HRESULT = 6488069
PEER_S_ALREADY_A_MEMBER: win32more.Windows.Win32.Foundation.HRESULT = 6488070
PEER_E_CANNOT_CONVERT_PEER_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2140979199
PEER_E_INVALID_PEER_HOST_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2140979198
PEER_E_NO_MORE: win32more.Windows.Win32.Foundation.HRESULT = -2140979197
PEER_E_PNRP_DUPLICATE_PEER_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2140979195
PEER_E_INVITE_CANCELLED: win32more.Windows.Win32.Foundation.HRESULT = -2140966912
PEER_E_INVITE_RESPONSE_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2140966911
PEER_E_NOT_SIGNED_IN: win32more.Windows.Win32.Foundation.HRESULT = -2140966909
PEER_E_PRIVACY_DECLINED: win32more.Windows.Win32.Foundation.HRESULT = -2140966908
PEER_E_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2140966907
PEER_E_INVALID_ADDRESS: win32more.Windows.Win32.Foundation.HRESULT = -2140966905
PEER_E_FW_EXCEPTION_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2140966904
PEER_E_FW_BLOCKED_BY_POLICY: win32more.Windows.Win32.Foundation.HRESULT = -2140966903
PEER_E_FW_BLOCKED_BY_SHIELDS_UP: win32more.Windows.Win32.Foundation.HRESULT = -2140966902
PEER_E_FW_DECLINED: win32more.Windows.Win32.Foundation.HRESULT = -2140966901
UI_E_CREATE_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2144731135
UI_E_SHUTDOWN_CALLED: win32more.Windows.Win32.Foundation.HRESULT = -2144731134
UI_E_ILLEGAL_REENTRANCY: win32more.Windows.Win32.Foundation.HRESULT = -2144731133
UI_E_OBJECT_SEALED: win32more.Windows.Win32.Foundation.HRESULT = -2144731132
UI_E_VALUE_NOT_SET: win32more.Windows.Win32.Foundation.HRESULT = -2144731131
UI_E_VALUE_NOT_DETERMINED: win32more.Windows.Win32.Foundation.HRESULT = -2144731130
UI_E_INVALID_OUTPUT: win32more.Windows.Win32.Foundation.HRESULT = -2144731129
UI_E_BOOLEAN_EXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2144731128
UI_E_DIFFERENT_OWNER: win32more.Windows.Win32.Foundation.HRESULT = -2144731127
UI_E_AMBIGUOUS_MATCH: win32more.Windows.Win32.Foundation.HRESULT = -2144731126
UI_E_FP_OVERFLOW: win32more.Windows.Win32.Foundation.HRESULT = -2144731125
UI_E_WRONG_THREAD: win32more.Windows.Win32.Foundation.HRESULT = -2144731124
UI_E_STORYBOARD_ACTIVE: win32more.Windows.Win32.Foundation.HRESULT = -2144730879
UI_E_STORYBOARD_NOT_PLAYING: win32more.Windows.Win32.Foundation.HRESULT = -2144730878
UI_E_START_KEYFRAME_AFTER_END: win32more.Windows.Win32.Foundation.HRESULT = -2144730877
UI_E_END_KEYFRAME_NOT_DETERMINED: win32more.Windows.Win32.Foundation.HRESULT = -2144730876
UI_E_LOOPS_OVERLAP: win32more.Windows.Win32.Foundation.HRESULT = -2144730875
UI_E_TRANSITION_ALREADY_USED: win32more.Windows.Win32.Foundation.HRESULT = -2144730874
UI_E_TRANSITION_NOT_IN_STORYBOARD: win32more.Windows.Win32.Foundation.HRESULT = -2144730873
UI_E_TRANSITION_ECLIPSED: win32more.Windows.Win32.Foundation.HRESULT = -2144730872
UI_E_TIME_BEFORE_LAST_UPDATE: win32more.Windows.Win32.Foundation.HRESULT = -2144730871
UI_E_TIMER_CLIENT_ALREADY_CONNECTED: win32more.Windows.Win32.Foundation.HRESULT = -2144730870
UI_E_INVALID_DIMENSION: win32more.Windows.Win32.Foundation.HRESULT = -2144730869
UI_E_PRIMITIVE_OUT_OF_BOUNDS: win32more.Windows.Win32.Foundation.HRESULT = -2144730868
UI_E_WINDOW_CLOSED: win32more.Windows.Win32.Foundation.HRESULT = -2144730623
E_BLUETOOTH_ATT_INVALID_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2140864511
E_BLUETOOTH_ATT_READ_NOT_PERMITTED: win32more.Windows.Win32.Foundation.HRESULT = -2140864510
E_BLUETOOTH_ATT_WRITE_NOT_PERMITTED: win32more.Windows.Win32.Foundation.HRESULT = -2140864509
E_BLUETOOTH_ATT_INVALID_PDU: win32more.Windows.Win32.Foundation.HRESULT = -2140864508
E_BLUETOOTH_ATT_INSUFFICIENT_AUTHENTICATION: win32more.Windows.Win32.Foundation.HRESULT = -2140864507
E_BLUETOOTH_ATT_REQUEST_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2140864506
E_BLUETOOTH_ATT_INVALID_OFFSET: win32more.Windows.Win32.Foundation.HRESULT = -2140864505
E_BLUETOOTH_ATT_INSUFFICIENT_AUTHORIZATION: win32more.Windows.Win32.Foundation.HRESULT = -2140864504
E_BLUETOOTH_ATT_PREPARE_QUEUE_FULL: win32more.Windows.Win32.Foundation.HRESULT = -2140864503
E_BLUETOOTH_ATT_ATTRIBUTE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2140864502
E_BLUETOOTH_ATT_ATTRIBUTE_NOT_LONG: win32more.Windows.Win32.Foundation.HRESULT = -2140864501
E_BLUETOOTH_ATT_INSUFFICIENT_ENCRYPTION_KEY_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2140864500
E_BLUETOOTH_ATT_INVALID_ATTRIBUTE_VALUE_LENGTH: win32more.Windows.Win32.Foundation.HRESULT = -2140864499
E_BLUETOOTH_ATT_UNLIKELY: win32more.Windows.Win32.Foundation.HRESULT = -2140864498
E_BLUETOOTH_ATT_INSUFFICIENT_ENCRYPTION: win32more.Windows.Win32.Foundation.HRESULT = -2140864497
E_BLUETOOTH_ATT_UNSUPPORTED_GROUP_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2140864496
E_BLUETOOTH_ATT_INSUFFICIENT_RESOURCES: win32more.Windows.Win32.Foundation.HRESULT = -2140864495
E_BLUETOOTH_ATT_UNKNOWN_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2140860416
E_AUDIO_ENGINE_NODE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2140798975
E_HDAUDIO_EMPTY_CONNECTION_LIST: win32more.Windows.Win32.Foundation.HRESULT = -2140798974
E_HDAUDIO_CONNECTION_LIST_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2140798973
E_HDAUDIO_NO_LOGICAL_DEVICES_CREATED: win32more.Windows.Win32.Foundation.HRESULT = -2140798972
E_HDAUDIO_NULL_LINKED_LIST_ENTRY: win32more.Windows.Win32.Foundation.HRESULT = -2140798971
STATEREPOSITORY_E_CONCURRENCY_LOCKING_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2140733439
STATEREPOSITORY_E_STATEMENT_INPROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2140733438
STATEREPOSITORY_E_CONFIGURATION_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2140733437
STATEREPOSITORY_E_UNKNOWN_SCHEMA_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2140733436
STATEREPOSITORY_ERROR_DICTIONARY_CORRUPTED: win32more.Windows.Win32.Foundation.HRESULT = -2140733435
STATEREPOSITORY_E_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2140733434
STATEREPOSITORY_E_BUSY_RETRY: win32more.Windows.Win32.Foundation.HRESULT = -2140733433
STATEREPOSITORY_E_BUSY_RECOVERY_RETRY: win32more.Windows.Win32.Foundation.HRESULT = -2140733432
STATEREPOSITORY_E_LOCKED_RETRY: win32more.Windows.Win32.Foundation.HRESULT = -2140733431
STATEREPOSITORY_E_LOCKED_SHAREDCACHE_RETRY: win32more.Windows.Win32.Foundation.HRESULT = -2140733430
STATEREPOSITORY_E_TRANSACTION_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2140733429
STATEREPOSITORY_E_BUSY_TIMEOUT_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2140733428
STATEREPOSITORY_E_BUSY_RECOVERY_TIMEOUT_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2140733427
STATEREPOSITORY_E_LOCKED_TIMEOUT_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2140733426
STATEREPOSITORY_E_LOCKED_SHAREDCACHE_TIMEOUT_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2140733425
STATEREPOSITORY_E_SERVICE_STOP_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2140733424
STATEREPOSTORY_E_NESTED_TRANSACTION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2140733423
STATEREPOSITORY_ERROR_CACHE_CORRUPTED: win32more.Windows.Win32.Foundation.HRESULT = -2140733422
STATEREPOSITORY_TRANSACTION_CALLER_ID_CHANGED: win32more.Windows.Win32.Foundation.HRESULT = 6750227
STATEREPOSITORY_TRANSACTION_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2140733420
STATEREPOSITORY_E_CACHE_NOT_INIITALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2140733419
STATEREPOSITORY_E_DEPENDENCY_NOT_RESOLVED: win32more.Windows.Win32.Foundation.HRESULT = -2140733418
ERROR_SPACES_POOL_WAS_DELETED: win32more.Windows.Win32.Foundation.HRESULT = 15138817
ERROR_SPACES_FAULT_DOMAIN_TYPE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2132344831
ERROR_SPACES_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2132344830
ERROR_SPACES_RESILIENCY_TYPE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2132344829
ERROR_SPACES_DRIVE_SECTOR_SIZE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2132344828
ERROR_SPACES_DRIVE_REDUNDANCY_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2132344826
ERROR_SPACES_NUMBER_OF_DATA_COPIES_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2132344825
ERROR_SPACES_PARITY_LAYOUT_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2132344824
ERROR_SPACES_INTERLEAVE_LENGTH_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2132344823
ERROR_SPACES_NUMBER_OF_COLUMNS_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2132344822
ERROR_SPACES_NOT_ENOUGH_DRIVES: win32more.Windows.Win32.Foundation.HRESULT = -2132344821
ERROR_SPACES_EXTENDED_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2132344820
ERROR_SPACES_PROVISIONING_TYPE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2132344819
ERROR_SPACES_ALLOCATION_SIZE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2132344818
ERROR_SPACES_ENCLOSURE_AWARE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2132344817
ERROR_SPACES_WRITE_CACHE_SIZE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2132344816
ERROR_SPACES_NUMBER_OF_GROUPS_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2132344815
ERROR_SPACES_DRIVE_OPERATIONAL_STATE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2132344814
ERROR_SPACES_ENTRY_INCOMPLETE: win32more.Windows.Win32.Foundation.HRESULT = -2132344813
ERROR_SPACES_ENTRY_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2132344812
ERROR_SPACES_UPDATE_COLUMN_STATE: win32more.Windows.Win32.Foundation.HRESULT = -2132344811
ERROR_SPACES_MAP_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2132344810
ERROR_SPACES_UNSUPPORTED_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2132344809
ERROR_SPACES_CORRUPT_METADATA: win32more.Windows.Win32.Foundation.HRESULT = -2132344808
ERROR_SPACES_DRT_FULL: win32more.Windows.Win32.Foundation.HRESULT = -2132344807
ERROR_SPACES_INCONSISTENCY: win32more.Windows.Win32.Foundation.HRESULT = -2132344806
ERROR_SPACES_LOG_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -2132344805
ERROR_SPACES_NO_REDUNDANCY: win32more.Windows.Win32.Foundation.HRESULT = -2132344804
ERROR_SPACES_DRIVE_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -2132344803
ERROR_SPACES_DRIVE_SPLIT: win32more.Windows.Win32.Foundation.HRESULT = -2132344802
ERROR_SPACES_DRIVE_LOST_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2132344801
ERROR_SPACES_MARK_DIRTY: win32more.Windows.Win32.Foundation.HRESULT = -2132344800
ERROR_SPACES_FLUSH_METADATA: win32more.Windows.Win32.Foundation.HRESULT = -2132344795
ERROR_SPACES_CACHE_FULL: win32more.Windows.Win32.Foundation.HRESULT = -2132344794
ERROR_SPACES_REPAIR_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2132344793
ERROR_VOLSNAP_BOOTFILE_NOT_VALID: win32more.Windows.Win32.Foundation.HRESULT = -2138963967
ERROR_VOLSNAP_ACTIVATION_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2138963966
ERROR_VOLSNAP_NO_BYPASSIO_WITH_SNAPSHOT: win32more.Windows.Win32.Foundation.HRESULT = -2138963965
ERROR_TIERING_NOT_SUPPORTED_ON_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2138898431
ERROR_TIERING_VOLUME_DISMOUNT_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2138898430
ERROR_TIERING_STORAGE_TIER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2138898429
ERROR_TIERING_INVALID_FILE_ID: win32more.Windows.Win32.Foundation.HRESULT = -2138898428
ERROR_TIERING_WRONG_CLUSTER_NODE: win32more.Windows.Win32.Foundation.HRESULT = -2138898427
ERROR_TIERING_ALREADY_PROCESSING: win32more.Windows.Win32.Foundation.HRESULT = -2138898426
ERROR_TIERING_CANNOT_PIN_OBJECT: win32more.Windows.Win32.Foundation.HRESULT = -2138898425
ERROR_TIERING_FILE_IS_NOT_PINNED: win32more.Windows.Win32.Foundation.HRESULT = -2138898424
ERROR_NOT_A_TIERED_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2138898423
ERROR_ATTRIBUTE_NOT_PRESENT: win32more.Windows.Win32.Foundation.HRESULT = -2138898422
ERROR_SECCORE_INVALID_COMMAND: win32more.Windows.Win32.Foundation.HRESULT = -1058537472
ERROR_NO_APPLICABLE_APP_LICENSES_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1058406399
ERROR_CLIP_LICENSE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1058406398
ERROR_CLIP_DEVICE_LICENSE_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -1058406397
ERROR_CLIP_LICENSE_INVALID_SIGNATURE: win32more.Windows.Win32.Foundation.HRESULT = -1058406396
ERROR_CLIP_KEYHOLDER_LICENSE_MISSING_OR_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -1058406395
ERROR_CLIP_LICENSE_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -1058406394
ERROR_CLIP_LICENSE_SIGNED_BY_UNKNOWN_SOURCE: win32more.Windows.Win32.Foundation.HRESULT = -1058406393
ERROR_CLIP_LICENSE_NOT_SIGNED: win32more.Windows.Win32.Foundation.HRESULT = -1058406392
ERROR_CLIP_LICENSE_HARDWARE_ID_OUT_OF_TOLERANCE: win32more.Windows.Win32.Foundation.HRESULT = -1058406391
ERROR_CLIP_LICENSE_DEVICE_ID_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1058406390
DXGI_STATUS_OCCLUDED: win32more.Windows.Win32.Foundation.HRESULT = 142213121
DXGI_STATUS_CLIPPED: win32more.Windows.Win32.Foundation.HRESULT = 142213122
DXGI_STATUS_NO_REDIRECTION: win32more.Windows.Win32.Foundation.HRESULT = 142213124
DXGI_STATUS_NO_DESKTOP_ACCESS: win32more.Windows.Win32.Foundation.HRESULT = 142213125
DXGI_STATUS_GRAPHICS_VIDPN_SOURCE_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = 142213126
DXGI_STATUS_MODE_CHANGED: win32more.Windows.Win32.Foundation.HRESULT = 142213127
DXGI_STATUS_MODE_CHANGE_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = 142213128
DXCORE_ERROR_EVENT_NOT_UNREGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2004877311
PRESENTATION_ERROR_LOST: win32more.Windows.Win32.Foundation.HRESULT = -2004811775
DXGI_STATUS_UNOCCLUDED: win32more.Windows.Win32.Foundation.HRESULT = 142213129
DXGI_STATUS_DDA_WAS_STILL_DRAWING: win32more.Windows.Win32.Foundation.HRESULT = 142213130
DXGI_STATUS_PRESENT_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = 142213167
DXGI_DDI_ERR_WASSTILLDRAWING: win32more.Windows.Win32.Foundation.HRESULT = -2005204991
DXGI_DDI_ERR_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2005204990
DXGI_DDI_ERR_NONEXCLUSIVE: win32more.Windows.Win32.Foundation.HRESULT = -2005204989
D3D10_ERROR_TOO_MANY_UNIQUE_STATE_OBJECTS: win32more.Windows.Win32.Foundation.HRESULT = -2005336063
D3D10_ERROR_FILE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2005336062
D3D11_ERROR_TOO_MANY_UNIQUE_STATE_OBJECTS: win32more.Windows.Win32.Foundation.HRESULT = -2005139455
D3D11_ERROR_FILE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2005139454
D3D11_ERROR_TOO_MANY_UNIQUE_VIEW_OBJECTS: win32more.Windows.Win32.Foundation.HRESULT = -2005139453
D3D11_ERROR_DEFERRED_CONTEXT_MAP_WITHOUT_INITIAL_DISCARD: win32more.Windows.Win32.Foundation.HRESULT = -2005139452
D3D12_ERROR_ADAPTER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2005008383
D3D12_ERROR_DRIVER_VERSION_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2005008382
D3D12_ERROR_INVALID_REDIST: win32more.Windows.Win32.Foundation.HRESULT = -2005008381
D2DERR_WRONG_STATE: win32more.Windows.Win32.Foundation.HRESULT = -2003238911
D2DERR_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2003238910
D2DERR_UNSUPPORTED_OPERATION: win32more.Windows.Win32.Foundation.HRESULT = -2003238909
D2DERR_SCANNER_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2003238908
D2DERR_SCREEN_ACCESS_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2003238907
D2DERR_DISPLAY_STATE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2003238906
D2DERR_ZERO_VECTOR: win32more.Windows.Win32.Foundation.HRESULT = -2003238905
D2DERR_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2003238904
D2DERR_DISPLAY_FORMAT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2003238903
D2DERR_INVALID_CALL: win32more.Windows.Win32.Foundation.HRESULT = -2003238902
D2DERR_NO_HARDWARE_DEVICE: win32more.Windows.Win32.Foundation.HRESULT = -2003238901
D2DERR_RECREATE_TARGET: win32more.Windows.Win32.Foundation.HRESULT = -2003238900
D2DERR_TOO_MANY_SHADER_ELEMENTS: win32more.Windows.Win32.Foundation.HRESULT = -2003238899
D2DERR_SHADER_COMPILE_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2003238898
D2DERR_MAX_TEXTURE_SIZE_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2003238897
D2DERR_UNSUPPORTED_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2003238896
D2DERR_BAD_NUMBER: win32more.Windows.Win32.Foundation.HRESULT = -2003238895
D2DERR_WRONG_FACTORY: win32more.Windows.Win32.Foundation.HRESULT = -2003238894
D2DERR_LAYER_ALREADY_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -2003238893
D2DERR_POP_CALL_DID_NOT_MATCH_PUSH: win32more.Windows.Win32.Foundation.HRESULT = -2003238892
D2DERR_WRONG_RESOURCE_DOMAIN: win32more.Windows.Win32.Foundation.HRESULT = -2003238891
D2DERR_PUSH_POP_UNBALANCED: win32more.Windows.Win32.Foundation.HRESULT = -2003238890
D2DERR_RENDER_TARGET_HAS_LAYER_OR_CLIPRECT: win32more.Windows.Win32.Foundation.HRESULT = -2003238889
D2DERR_INCOMPATIBLE_BRUSH_TYPES: win32more.Windows.Win32.Foundation.HRESULT = -2003238888
D2DERR_WIN32_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2003238887
D2DERR_TARGET_NOT_GDI_COMPATIBLE: win32more.Windows.Win32.Foundation.HRESULT = -2003238886
D2DERR_TEXT_EFFECT_IS_WRONG_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2003238885
D2DERR_TEXT_RENDERER_NOT_RELEASED: win32more.Windows.Win32.Foundation.HRESULT = -2003238884
D2DERR_EXCEEDS_MAX_BITMAP_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2003238883
D2DERR_INVALID_GRAPH_CONFIGURATION: win32more.Windows.Win32.Foundation.HRESULT = -2003238882
D2DERR_INVALID_INTERNAL_GRAPH_CONFIGURATION: win32more.Windows.Win32.Foundation.HRESULT = -2003238881
D2DERR_CYCLIC_GRAPH: win32more.Windows.Win32.Foundation.HRESULT = -2003238880
D2DERR_BITMAP_CANNOT_DRAW: win32more.Windows.Win32.Foundation.HRESULT = -2003238879
D2DERR_OUTSTANDING_BITMAP_REFERENCES: win32more.Windows.Win32.Foundation.HRESULT = -2003238878
D2DERR_ORIGINAL_TARGET_NOT_BOUND: win32more.Windows.Win32.Foundation.HRESULT = -2003238877
D2DERR_INVALID_TARGET: win32more.Windows.Win32.Foundation.HRESULT = -2003238876
D2DERR_BITMAP_BOUND_AS_TARGET: win32more.Windows.Win32.Foundation.HRESULT = -2003238875
D2DERR_INSUFFICIENT_DEVICE_CAPABILITIES: win32more.Windows.Win32.Foundation.HRESULT = -2003238874
D2DERR_INTERMEDIATE_TOO_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -2003238873
D2DERR_EFFECT_IS_NOT_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2003238872
D2DERR_INVALID_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2003238871
D2DERR_NO_SUBPROPERTIES: win32more.Windows.Win32.Foundation.HRESULT = -2003238870
D2DERR_PRINT_JOB_CLOSED: win32more.Windows.Win32.Foundation.HRESULT = -2003238869
D2DERR_PRINT_FORMAT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2003238868
D2DERR_TOO_MANY_TRANSFORM_INPUTS: win32more.Windows.Win32.Foundation.HRESULT = -2003238867
D2DERR_INVALID_GLYPH_IMAGE: win32more.Windows.Win32.Foundation.HRESULT = -2003238866
DWRITE_E_FILEFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2003283968
DWRITE_E_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2003283967
DWRITE_E_NOFONT: win32more.Windows.Win32.Foundation.HRESULT = -2003283966
DWRITE_E_FILENOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2003283965
DWRITE_E_FILEACCESS: win32more.Windows.Win32.Foundation.HRESULT = -2003283964
DWRITE_E_FONTCOLLECTIONOBSOLETE: win32more.Windows.Win32.Foundation.HRESULT = -2003283963
DWRITE_E_ALREADYREGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2003283962
DWRITE_E_CACHEFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2003283961
DWRITE_E_CACHEVERSION: win32more.Windows.Win32.Foundation.HRESULT = -2003283960
DWRITE_E_UNSUPPORTEDOPERATION: win32more.Windows.Win32.Foundation.HRESULT = -2003283959
DWRITE_E_TEXTRENDERERINCOMPATIBLE: win32more.Windows.Win32.Foundation.HRESULT = -2003283958
DWRITE_E_FLOWDIRECTIONCONFLICTS: win32more.Windows.Win32.Foundation.HRESULT = -2003283957
DWRITE_E_NOCOLOR: win32more.Windows.Win32.Foundation.HRESULT = -2003283956
WINCODEC_ERR_WRONGSTATE: win32more.Windows.Win32.Foundation.HRESULT = -2003292412
WINCODEC_ERR_VALUEOUTOFRANGE: win32more.Windows.Win32.Foundation.HRESULT = -2003292411
WINCODEC_ERR_UNKNOWNIMAGEFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2003292409
WINCODEC_ERR_UNSUPPORTEDVERSION: win32more.Windows.Win32.Foundation.HRESULT = -2003292405
WINCODEC_ERR_NOTINITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2003292404
WINCODEC_ERR_ALREADYLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2003292403
WINCODEC_ERR_PROPERTYNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2003292352
WINCODEC_ERR_PROPERTYNOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2003292351
WINCODEC_ERR_PROPERTYSIZE: win32more.Windows.Win32.Foundation.HRESULT = -2003292350
WINCODEC_ERR_CODECPRESENT: win32more.Windows.Win32.Foundation.HRESULT = -2003292349
WINCODEC_ERR_CODECNOTHUMBNAIL: win32more.Windows.Win32.Foundation.HRESULT = -2003292348
WINCODEC_ERR_PALETTEUNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2003292347
WINCODEC_ERR_CODECTOOMANYSCANLINES: win32more.Windows.Win32.Foundation.HRESULT = -2003292346
WINCODEC_ERR_INTERNALERROR: win32more.Windows.Win32.Foundation.HRESULT = -2003292344
WINCODEC_ERR_SOURCERECTDOESNOTMATCHDIMENSIONS: win32more.Windows.Win32.Foundation.HRESULT = -2003292343
WINCODEC_ERR_COMPONENTNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2003292336
WINCODEC_ERR_IMAGESIZEOUTOFRANGE: win32more.Windows.Win32.Foundation.HRESULT = -2003292335
WINCODEC_ERR_TOOMUCHMETADATA: win32more.Windows.Win32.Foundation.HRESULT = -2003292334
WINCODEC_ERR_BADIMAGE: win32more.Windows.Win32.Foundation.HRESULT = -2003292320
WINCODEC_ERR_BADHEADER: win32more.Windows.Win32.Foundation.HRESULT = -2003292319
WINCODEC_ERR_FRAMEMISSING: win32more.Windows.Win32.Foundation.HRESULT = -2003292318
WINCODEC_ERR_BADMETADATAHEADER: win32more.Windows.Win32.Foundation.HRESULT = -2003292317
WINCODEC_ERR_BADSTREAMDATA: win32more.Windows.Win32.Foundation.HRESULT = -2003292304
WINCODEC_ERR_STREAMWRITE: win32more.Windows.Win32.Foundation.HRESULT = -2003292303
WINCODEC_ERR_STREAMREAD: win32more.Windows.Win32.Foundation.HRESULT = -2003292302
WINCODEC_ERR_STREAMNOTAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2003292301
WINCODEC_ERR_UNSUPPORTEDPIXELFORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2003292288
WINCODEC_ERR_UNSUPPORTEDOPERATION: win32more.Windows.Win32.Foundation.HRESULT = -2003292287
WINCODEC_ERR_INVALIDREGISTRATION: win32more.Windows.Win32.Foundation.HRESULT = -2003292278
WINCODEC_ERR_COMPONENTINITIALIZEFAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2003292277
WINCODEC_ERR_INSUFFICIENTBUFFER: win32more.Windows.Win32.Foundation.HRESULT = -2003292276
WINCODEC_ERR_DUPLICATEMETADATAPRESENT: win32more.Windows.Win32.Foundation.HRESULT = -2003292275
WINCODEC_ERR_PROPERTYUNEXPECTEDTYPE: win32more.Windows.Win32.Foundation.HRESULT = -2003292274
WINCODEC_ERR_UNEXPECTEDSIZE: win32more.Windows.Win32.Foundation.HRESULT = -2003292273
WINCODEC_ERR_INVALIDQUERYREQUEST: win32more.Windows.Win32.Foundation.HRESULT = -2003292272
WINCODEC_ERR_UNEXPECTEDMETADATATYPE: win32more.Windows.Win32.Foundation.HRESULT = -2003292271
WINCODEC_ERR_REQUESTONLYVALIDATMETADATAROOT: win32more.Windows.Win32.Foundation.HRESULT = -2003292270
WINCODEC_ERR_INVALIDQUERYCHARACTER: win32more.Windows.Win32.Foundation.HRESULT = -2003292269
WINCODEC_ERR_WIN32ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2003292268
WINCODEC_ERR_INVALIDPROGRESSIVELEVEL: win32more.Windows.Win32.Foundation.HRESULT = -2003292267
WINCODEC_ERR_INVALIDJPEGSCANINDEX: win32more.Windows.Win32.Foundation.HRESULT = -2003292266
MILERR_OBJECTBUSY: win32more.Windows.Win32.Foundation.HRESULT = -2003304447
MILERR_INSUFFICIENTBUFFER: win32more.Windows.Win32.Foundation.HRESULT = -2003304446
MILERR_WIN32ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2003304445
MILERR_SCANNER_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2003304444
MILERR_SCREENACCESSDENIED: win32more.Windows.Win32.Foundation.HRESULT = -2003304443
MILERR_DISPLAYSTATEINVALID: win32more.Windows.Win32.Foundation.HRESULT = -2003304442
MILERR_NONINVERTIBLEMATRIX: win32more.Windows.Win32.Foundation.HRESULT = -2003304441
MILERR_ZEROVECTOR: win32more.Windows.Win32.Foundation.HRESULT = -2003304440
MILERR_TERMINATED: win32more.Windows.Win32.Foundation.HRESULT = -2003304439
MILERR_BADNUMBER: win32more.Windows.Win32.Foundation.HRESULT = -2003304438
MILERR_INTERNALERROR: win32more.Windows.Win32.Foundation.HRESULT = -2003304320
MILERR_DISPLAYFORMATNOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2003304316
MILERR_INVALIDCALL: win32more.Windows.Win32.Foundation.HRESULT = -2003304315
MILERR_ALREADYLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2003304314
MILERR_NOTLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2003304313
MILERR_DEVICECANNOTRENDERTEXT: win32more.Windows.Win32.Foundation.HRESULT = -2003304312
MILERR_GLYPHBITMAPMISSED: win32more.Windows.Win32.Foundation.HRESULT = -2003304311
MILERR_MALFORMEDGLYPHCACHE: win32more.Windows.Win32.Foundation.HRESULT = -2003304310
MILERR_GENERIC_IGNORE: win32more.Windows.Win32.Foundation.HRESULT = -2003304309
MILERR_MALFORMED_GUIDELINE_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2003304308
MILERR_NO_HARDWARE_DEVICE: win32more.Windows.Win32.Foundation.HRESULT = -2003304307
MILERR_NEED_RECREATE_AND_PRESENT: win32more.Windows.Win32.Foundation.HRESULT = -2003304306
MILERR_ALREADY_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2003304305
MILERR_MISMATCHED_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2003304304
MILERR_NO_REDIRECTION_SURFACE_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2003304303
MILERR_REMOTING_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2003304302
MILERR_QUEUED_PRESENT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2003304301
MILERR_NOT_QUEUING_PRESENTS: win32more.Windows.Win32.Foundation.HRESULT = -2003304300
MILERR_NO_REDIRECTION_SURFACE_RETRY_LATER: win32more.Windows.Win32.Foundation.HRESULT = -2003304299
MILERR_TOOMANYSHADERELEMNTS: win32more.Windows.Win32.Foundation.HRESULT = -2003304298
MILERR_MROW_READLOCK_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2003304297
MILERR_MROW_UPDATE_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2003304296
MILERR_SHADER_COMPILE_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2003304295
MILERR_MAX_TEXTURE_SIZE_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2003304294
MILERR_QPC_TIME_WENT_BACKWARD: win32more.Windows.Win32.Foundation.HRESULT = -2003304293
MILERR_DXGI_ENUMERATION_OUT_OF_SYNC: win32more.Windows.Win32.Foundation.HRESULT = -2003304291
MILERR_ADAPTER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2003304290
MILERR_COLORSPACE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2003304289
MILERR_PREFILTER_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2003304288
MILERR_DISPLAYID_ACCESS_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2003304287
UCEERR_INVALIDPACKETHEADER: win32more.Windows.Win32.Foundation.HRESULT = -2003303424
UCEERR_UNKNOWNPACKET: win32more.Windows.Win32.Foundation.HRESULT = -2003303423
UCEERR_ILLEGALPACKET: win32more.Windows.Win32.Foundation.HRESULT = -2003303422
UCEERR_MALFORMEDPACKET: win32more.Windows.Win32.Foundation.HRESULT = -2003303421
UCEERR_ILLEGALHANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2003303420
UCEERR_HANDLELOOKUPFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2003303419
UCEERR_RENDERTHREADFAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2003303418
UCEERR_CTXSTACKFRSTTARGETNULL: win32more.Windows.Win32.Foundation.HRESULT = -2003303417
UCEERR_CONNECTIONIDLOOKUPFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2003303416
UCEERR_BLOCKSFULL: win32more.Windows.Win32.Foundation.HRESULT = -2003303415
UCEERR_MEMORYFAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2003303414
UCEERR_PACKETRECORDOUTOFRANGE: win32more.Windows.Win32.Foundation.HRESULT = -2003303413
UCEERR_ILLEGALRECORDTYPE: win32more.Windows.Win32.Foundation.HRESULT = -2003303412
UCEERR_OUTOFHANDLES: win32more.Windows.Win32.Foundation.HRESULT = -2003303411
UCEERR_UNCHANGABLE_UPDATE_ATTEMPTED: win32more.Windows.Win32.Foundation.HRESULT = -2003303410
UCEERR_NO_MULTIPLE_WORKER_THREADS: win32more.Windows.Win32.Foundation.HRESULT = -2003303409
UCEERR_REMOTINGNOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2003303408
UCEERR_MISSINGENDCOMMAND: win32more.Windows.Win32.Foundation.HRESULT = -2003303407
UCEERR_MISSINGBEGINCOMMAND: win32more.Windows.Win32.Foundation.HRESULT = -2003303406
UCEERR_CHANNELSYNCTIMEDOUT: win32more.Windows.Win32.Foundation.HRESULT = -2003303405
UCEERR_CHANNELSYNCABANDONED: win32more.Windows.Win32.Foundation.HRESULT = -2003303404
UCEERR_UNSUPPORTEDTRANSPORTVERSION: win32more.Windows.Win32.Foundation.HRESULT = -2003303403
UCEERR_TRANSPORTUNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2003303402
UCEERR_FEEDBACK_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2003303401
UCEERR_COMMANDTRANSPORTDENIED: win32more.Windows.Win32.Foundation.HRESULT = -2003303400
UCEERR_GRAPHICSSTREAMUNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2003303399
UCEERR_GRAPHICSSTREAMALREADYOPEN: win32more.Windows.Win32.Foundation.HRESULT = -2003303392
UCEERR_TRANSPORTDISCONNECTED: win32more.Windows.Win32.Foundation.HRESULT = -2003303391
UCEERR_TRANSPORTOVERLOADED: win32more.Windows.Win32.Foundation.HRESULT = -2003303390
UCEERR_PARTITION_ZOMBIED: win32more.Windows.Win32.Foundation.HRESULT = -2003303389
MILAVERR_NOCLOCK: win32more.Windows.Win32.Foundation.HRESULT = -2003303168
MILAVERR_NOMEDIATYPE: win32more.Windows.Win32.Foundation.HRESULT = -2003303167
MILAVERR_NOVIDEOMIXER: win32more.Windows.Win32.Foundation.HRESULT = -2003303166
MILAVERR_NOVIDEOPRESENTER: win32more.Windows.Win32.Foundation.HRESULT = -2003303165
MILAVERR_NOREADYFRAMES: win32more.Windows.Win32.Foundation.HRESULT = -2003303164
MILAVERR_MODULENOTLOADED: win32more.Windows.Win32.Foundation.HRESULT = -2003303163
MILAVERR_WMPFACTORYNOTREGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2003303162
MILAVERR_INVALIDWMPVERSION: win32more.Windows.Win32.Foundation.HRESULT = -2003303161
MILAVERR_INSUFFICIENTVIDEORESOURCES: win32more.Windows.Win32.Foundation.HRESULT = -2003303160
MILAVERR_VIDEOACCELERATIONNOTAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2003303159
MILAVERR_REQUESTEDTEXTURETOOBIG: win32more.Windows.Win32.Foundation.HRESULT = -2003303158
MILAVERR_SEEKFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2003303157
MILAVERR_UNEXPECTEDWMPFAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2003303156
MILAVERR_MEDIAPLAYERCLOSED: win32more.Windows.Win32.Foundation.HRESULT = -2003303155
MILAVERR_UNKNOWNHARDWAREERROR: win32more.Windows.Win32.Foundation.HRESULT = -2003303154
MILEFFECTSERR_UNKNOWNPROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2003302898
MILEFFECTSERR_EFFECTNOTPARTOFGROUP: win32more.Windows.Win32.Foundation.HRESULT = -2003302897
MILEFFECTSERR_NOINPUTSOURCEATTACHED: win32more.Windows.Win32.Foundation.HRESULT = -2003302896
MILEFFECTSERR_CONNECTORNOTCONNECTED: win32more.Windows.Win32.Foundation.HRESULT = -2003302895
MILEFFECTSERR_CONNECTORNOTASSOCIATEDWITHEFFECT: win32more.Windows.Win32.Foundation.HRESULT = -2003302894
MILEFFECTSERR_RESERVED: win32more.Windows.Win32.Foundation.HRESULT = -2003302893
MILEFFECTSERR_CYCLEDETECTED: win32more.Windows.Win32.Foundation.HRESULT = -2003302892
MILEFFECTSERR_EFFECTINMORETHANONEGRAPH: win32more.Windows.Win32.Foundation.HRESULT = -2003302891
MILEFFECTSERR_EFFECTALREADYINAGRAPH: win32more.Windows.Win32.Foundation.HRESULT = -2003302890
MILEFFECTSERR_EFFECTHASNOCHILDREN: win32more.Windows.Win32.Foundation.HRESULT = -2003302889
MILEFFECTSERR_ALREADYATTACHEDTOLISTENER: win32more.Windows.Win32.Foundation.HRESULT = -2003302888
MILEFFECTSERR_NOTAFFINETRANSFORM: win32more.Windows.Win32.Foundation.HRESULT = -2003302887
MILEFFECTSERR_EMPTYBOUNDS: win32more.Windows.Win32.Foundation.HRESULT = -2003302886
MILEFFECTSERR_OUTPUTSIZETOOLARGE: win32more.Windows.Win32.Foundation.HRESULT = -2003302885
DWMERR_STATE_TRANSITION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2003302656
DWMERR_THEME_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2003302655
DWMERR_CATASTROPHIC_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2003302654
DCOMPOSITION_ERROR_WINDOW_ALREADY_COMPOSED: win32more.Windows.Win32.Foundation.HRESULT = -2003302400
DCOMPOSITION_ERROR_SURFACE_BEING_RENDERED: win32more.Windows.Win32.Foundation.HRESULT = -2003302399
DCOMPOSITION_ERROR_SURFACE_NOT_BEING_RENDERED: win32more.Windows.Win32.Foundation.HRESULT = -2003302398
ONL_E_INVALID_AUTHENTICATION_TARGET: win32more.Windows.Win32.Foundation.HRESULT = -2138701823
ONL_E_ACCESS_DENIED_BY_TOU: win32more.Windows.Win32.Foundation.HRESULT = -2138701822
ONL_E_INVALID_APPLICATION: win32more.Windows.Win32.Foundation.HRESULT = -2138701821
ONL_E_PASSWORD_UPDATE_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2138701820
ONL_E_ACCOUNT_UPDATE_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2138701819
ONL_E_FORCESIGNIN: win32more.Windows.Win32.Foundation.HRESULT = -2138701818
ONL_E_ACCOUNT_LOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2138701817
ONL_E_PARENTAL_CONSENT_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2138701816
ONL_E_EMAIL_VERIFICATION_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2138701815
ONL_E_ACCOUNT_SUSPENDED_COMPROIMISE: win32more.Windows.Win32.Foundation.HRESULT = -2138701814
ONL_E_ACCOUNT_SUSPENDED_ABUSE: win32more.Windows.Win32.Foundation.HRESULT = -2138701813
ONL_E_ACTION_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2138701812
ONL_CONNECTION_COUNT_LIMIT: win32more.Windows.Win32.Foundation.HRESULT = -2138701811
ONL_E_CONNECTED_ACCOUNT_CAN_NOT_SIGNOUT: win32more.Windows.Win32.Foundation.HRESULT = -2138701810
ONL_E_USER_AUTHENTICATION_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2138701809
ONL_E_REQUEST_THROTTLED: win32more.Windows.Win32.Foundation.HRESULT = -2138701808
FA_E_MAX_PERSISTED_ITEMS_REACHED: win32more.Windows.Win32.Foundation.HRESULT = -2144927200
FA_E_HOMEGROUP_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2144927198
E_MONITOR_RESOLUTION_TOO_LOW: win32more.Windows.Win32.Foundation.HRESULT = -2144927152
E_ELEVATED_ACTIVATION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144927151
E_UAC_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2144927150
E_FULL_ADMIN_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144927149
E_APPLICATION_NOT_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2144927148
E_MULTIPLE_EXTENSIONS_FOR_APPLICATION: win32more.Windows.Win32.Foundation.HRESULT = -2144927147
E_MULTIPLE_PACKAGES_FOR_FAMILY: win32more.Windows.Win32.Foundation.HRESULT = -2144927146
E_APPLICATION_MANAGER_NOT_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2144927145
S_STORE_LAUNCHED_FOR_REMEDIATION: win32more.Windows.Win32.Foundation.HRESULT = 2556504
S_APPLICATION_ACTIVATION_ERROR_HANDLED_BY_DIALOG: win32more.Windows.Win32.Foundation.HRESULT = 2556505
E_APPLICATION_ACTIVATION_TIMED_OUT: win32more.Windows.Win32.Foundation.HRESULT = -2144927142
E_APPLICATION_ACTIVATION_EXEC_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2144927141
E_APPLICATION_TEMPORARY_LICENSE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2144927140
E_APPLICATION_TRIAL_LICENSE_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -2144927139
E_SKYDRIVE_ROOT_TARGET_FILE_SYSTEM_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144927136
E_SKYDRIVE_ROOT_TARGET_OVERLAP: win32more.Windows.Win32.Foundation.HRESULT = -2144927135
E_SKYDRIVE_ROOT_TARGET_CANNOT_INDEX: win32more.Windows.Win32.Foundation.HRESULT = -2144927134
E_SKYDRIVE_FILE_NOT_UPLOADED: win32more.Windows.Win32.Foundation.HRESULT = -2144927133
E_SKYDRIVE_UPDATE_AVAILABILITY_FAIL: win32more.Windows.Win32.Foundation.HRESULT = -2144927132
E_SKYDRIVE_ROOT_TARGET_VOLUME_ROOT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2144927131
E_SYNCENGINE_FILE_SIZE_OVER_LIMIT: win32more.Windows.Win32.Foundation.HRESULT = -2013089791
E_SYNCENGINE_FILE_SIZE_EXCEEDS_REMAINING_QUOTA: win32more.Windows.Win32.Foundation.HRESULT = -2013089790
E_SYNCENGINE_UNSUPPORTED_FILE_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2013089789
E_SYNCENGINE_FOLDER_ITEM_COUNT_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2013089788
E_SYNCENGINE_FILE_SYNC_PARTNER_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2013089787
E_SYNCENGINE_SYNC_PAUSED_BY_SERVICE: win32more.Windows.Win32.Foundation.HRESULT = -2013089786
E_SYNCENGINE_FILE_IDENTIFIER_UNKNOWN: win32more.Windows.Win32.Foundation.HRESULT = -2013085694
E_SYNCENGINE_SERVICE_AUTHENTICATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2013085693
E_SYNCENGINE_UNKNOWN_SERVICE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2013085692
E_SYNCENGINE_SERVICE_RETURNED_UNEXPECTED_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2013085691
E_SYNCENGINE_REQUEST_BLOCKED_BY_SERVICE: win32more.Windows.Win32.Foundation.HRESULT = -2013085690
E_SYNCENGINE_REQUEST_BLOCKED_DUE_TO_CLIENT_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2013085689
E_SYNCENGINE_FOLDER_INACCESSIBLE: win32more.Windows.Win32.Foundation.HRESULT = -2013081599
E_SYNCENGINE_UNSUPPORTED_FOLDER_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2013081598
E_SYNCENGINE_UNSUPPORTED_MARKET: win32more.Windows.Win32.Foundation.HRESULT = -2013081597
E_SYNCENGINE_PATH_LENGTH_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2013081596
E_SYNCENGINE_REMOTE_PATH_LENGTH_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2013081595
E_SYNCENGINE_CLIENT_UPDATE_NEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2013081594
E_SYNCENGINE_PROXY_AUTHENTICATION_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2013081593
E_SYNCENGINE_STORAGE_SERVICE_PROVISIONING_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2013081592
E_SYNCENGINE_UNSUPPORTED_REPARSE_POINT: win32more.Windows.Win32.Foundation.HRESULT = -2013081591
E_SYNCENGINE_STORAGE_SERVICE_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2013081590
E_SYNCENGINE_FOLDER_IN_REDIRECTION: win32more.Windows.Win32.Foundation.HRESULT = -2013081589
EAS_E_POLICY_NOT_MANAGED_BY_OS: win32more.Windows.Win32.Foundation.HRESULT = -2141913087
EAS_E_POLICY_COMPLIANT_WITH_ACTIONS: win32more.Windows.Win32.Foundation.HRESULT = -2141913086
EAS_E_REQUESTED_POLICY_NOT_ENFORCEABLE: win32more.Windows.Win32.Foundation.HRESULT = -2141913085
EAS_E_CURRENT_USER_HAS_BLANK_PASSWORD: win32more.Windows.Win32.Foundation.HRESULT = -2141913084
EAS_E_REQUESTED_POLICY_PASSWORD_EXPIRATION_INCOMPATIBLE: win32more.Windows.Win32.Foundation.HRESULT = -2141913083
EAS_E_USER_CANNOT_CHANGE_PASSWORD: win32more.Windows.Win32.Foundation.HRESULT = -2141913082
EAS_E_ADMINS_HAVE_BLANK_PASSWORD: win32more.Windows.Win32.Foundation.HRESULT = -2141913081
EAS_E_ADMINS_CANNOT_CHANGE_PASSWORD: win32more.Windows.Win32.Foundation.HRESULT = -2141913080
EAS_E_LOCAL_CONTROLLED_USERS_CANNOT_CHANGE_PASSWORD: win32more.Windows.Win32.Foundation.HRESULT = -2141913079
EAS_E_PASSWORD_POLICY_NOT_ENFORCEABLE_FOR_CONNECTED_ADMINS: win32more.Windows.Win32.Foundation.HRESULT = -2141913078
EAS_E_CONNECTED_ADMINS_NEED_TO_CHANGE_PASSWORD: win32more.Windows.Win32.Foundation.HRESULT = -2141913077
EAS_E_PASSWORD_POLICY_NOT_ENFORCEABLE_FOR_CURRENT_CONNECTED_USER: win32more.Windows.Win32.Foundation.HRESULT = -2141913076
EAS_E_CURRENT_CONNECTED_USER_NEED_TO_CHANGE_PASSWORD: win32more.Windows.Win32.Foundation.HRESULT = -2141913075
WEB_E_UNSUPPORTED_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2089484287
WEB_E_INVALID_XML: win32more.Windows.Win32.Foundation.HRESULT = -2089484286
WEB_E_MISSING_REQUIRED_ELEMENT: win32more.Windows.Win32.Foundation.HRESULT = -2089484285
WEB_E_MISSING_REQUIRED_ATTRIBUTE: win32more.Windows.Win32.Foundation.HRESULT = -2089484284
WEB_E_UNEXPECTED_CONTENT: win32more.Windows.Win32.Foundation.HRESULT = -2089484283
WEB_E_RESOURCE_TOO_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -2089484282
WEB_E_INVALID_JSON_STRING: win32more.Windows.Win32.Foundation.HRESULT = -2089484281
WEB_E_INVALID_JSON_NUMBER: win32more.Windows.Win32.Foundation.HRESULT = -2089484280
WEB_E_JSON_VALUE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2089484279
HTTP_E_STATUS_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145845247
HTTP_E_STATUS_UNEXPECTED_REDIRECTION: win32more.Windows.Win32.Foundation.HRESULT = -2145845245
HTTP_E_STATUS_UNEXPECTED_CLIENT_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145845244
HTTP_E_STATUS_UNEXPECTED_SERVER_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145845243
HTTP_E_STATUS_AMBIGUOUS: win32more.Windows.Win32.Foundation.HRESULT = -2145844948
HTTP_E_STATUS_MOVED: win32more.Windows.Win32.Foundation.HRESULT = -2145844947
HTTP_E_STATUS_REDIRECT: win32more.Windows.Win32.Foundation.HRESULT = -2145844946
HTTP_E_STATUS_REDIRECT_METHOD: win32more.Windows.Win32.Foundation.HRESULT = -2145844945
HTTP_E_STATUS_NOT_MODIFIED: win32more.Windows.Win32.Foundation.HRESULT = -2145844944
HTTP_E_STATUS_USE_PROXY: win32more.Windows.Win32.Foundation.HRESULT = -2145844943
HTTP_E_STATUS_REDIRECT_KEEP_VERB: win32more.Windows.Win32.Foundation.HRESULT = -2145844941
HTTP_E_STATUS_BAD_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -2145844848
HTTP_E_STATUS_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2145844847
HTTP_E_STATUS_PAYMENT_REQ: win32more.Windows.Win32.Foundation.HRESULT = -2145844846
HTTP_E_STATUS_FORBIDDEN: win32more.Windows.Win32.Foundation.HRESULT = -2145844845
HTTP_E_STATUS_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145844844
HTTP_E_STATUS_BAD_METHOD: win32more.Windows.Win32.Foundation.HRESULT = -2145844843
HTTP_E_STATUS_NONE_ACCEPTABLE: win32more.Windows.Win32.Foundation.HRESULT = -2145844842
HTTP_E_STATUS_PROXY_AUTH_REQ: win32more.Windows.Win32.Foundation.HRESULT = -2145844841
HTTP_E_STATUS_REQUEST_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2145844840
HTTP_E_STATUS_CONFLICT: win32more.Windows.Win32.Foundation.HRESULT = -2145844839
HTTP_E_STATUS_GONE: win32more.Windows.Win32.Foundation.HRESULT = -2145844838
HTTP_E_STATUS_LENGTH_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2145844837
HTTP_E_STATUS_PRECOND_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145844836
HTTP_E_STATUS_REQUEST_TOO_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -2145844835
HTTP_E_STATUS_URI_TOO_LONG: win32more.Windows.Win32.Foundation.HRESULT = -2145844834
HTTP_E_STATUS_UNSUPPORTED_MEDIA: win32more.Windows.Win32.Foundation.HRESULT = -2145844833
HTTP_E_STATUS_RANGE_NOT_SATISFIABLE: win32more.Windows.Win32.Foundation.HRESULT = -2145844832
HTTP_E_STATUS_EXPECTATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145844831
HTTP_E_STATUS_SERVER_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145844748
HTTP_E_STATUS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2145844747
HTTP_E_STATUS_BAD_GATEWAY: win32more.Windows.Win32.Foundation.HRESULT = -2145844746
HTTP_E_STATUS_SERVICE_UNAVAIL: win32more.Windows.Win32.Foundation.HRESULT = -2145844745
HTTP_E_STATUS_GATEWAY_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2145844744
HTTP_E_STATUS_VERSION_NOT_SUP: win32more.Windows.Win32.Foundation.HRESULT = -2145844743
E_INVALID_PROTOCOL_OPERATION: win32more.Windows.Win32.Foundation.HRESULT = -2089418751
E_INVALID_PROTOCOL_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2089418750
E_PROTOCOL_EXTENSIONS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2089418749
E_SUBPROTOCOL_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2089418748
E_PROTOCOL_VERSION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2089418747
INPUT_E_OUT_OF_ORDER: win32more.Windows.Win32.Foundation.HRESULT = -2143289344
INPUT_E_REENTRANCY: win32more.Windows.Win32.Foundation.HRESULT = -2143289343
INPUT_E_MULTIMODAL: win32more.Windows.Win32.Foundation.HRESULT = -2143289342
INPUT_E_PACKET: win32more.Windows.Win32.Foundation.HRESULT = -2143289341
INPUT_E_FRAME: win32more.Windows.Win32.Foundation.HRESULT = -2143289340
INPUT_E_HISTORY: win32more.Windows.Win32.Foundation.HRESULT = -2143289339
INPUT_E_DEVICE_INFO: win32more.Windows.Win32.Foundation.HRESULT = -2143289338
INPUT_E_TRANSFORM: win32more.Windows.Win32.Foundation.HRESULT = -2143289337
INPUT_E_DEVICE_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2143289336
ERROR_DBG_CREATE_PROCESS_FAILURE_LOCKDOWN: win32more.Windows.Win32.Foundation.HRESULT = -2135949311
ERROR_DBG_ATTACH_PROCESS_FAILURE_LOCKDOWN: win32more.Windows.Win32.Foundation.HRESULT = -2135949310
ERROR_DBG_CONNECT_SERVER_FAILURE_LOCKDOWN: win32more.Windows.Win32.Foundation.HRESULT = -2135949309
ERROR_DBG_START_SERVER_FAILURE_LOCKDOWN: win32more.Windows.Win32.Foundation.HRESULT = -2135949308
HSP_E_ERROR_MASK: win32more.Windows.Win32.Foundation.HRESULT = -2128084992
HSP_E_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2128080897
HSP_BS_ERROR_MASK: win32more.Windows.Win32.Foundation.HRESULT = -2128080896
HSP_BS_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2128080641
HSP_DRV_ERROR_MASK: win32more.Windows.Win32.Foundation.HRESULT = -2128019456
HSP_DRV_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2128019201
HSP_BASE_ERROR_MASK: win32more.Windows.Win32.Foundation.HRESULT = -2128019200
HSP_BASE_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2128018945
HSP_KSP_ERROR_MASK: win32more.Windows.Win32.Foundation.HRESULT = -2128018944
HSP_KSP_DEVICE_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -2128018943
HSP_KSP_INVALID_PROVIDER_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2128018942
HSP_KSP_INVALID_KEY_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2128018941
HSP_KSP_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.HRESULT = -2128018940
HSP_KSP_BUFFER_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -2128018939
HSP_KSP_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2128018938
HSP_KSP_INVALID_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2128018937
HSP_KSP_INVALID_FLAGS: win32more.Windows.Win32.Foundation.HRESULT = -2128018936
HSP_KSP_ALGORITHM_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2128018935
HSP_KSP_KEY_ALREADY_FINALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2128018934
HSP_KSP_KEY_NOT_FINALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2128018933
HSP_KSP_INVALID_KEY_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2128018932
HSP_KSP_NO_MEMORY: win32more.Windows.Win32.Foundation.HRESULT = -2128018928
HSP_KSP_PARAMETER_NOT_SET: win32more.Windows.Win32.Foundation.HRESULT = -2128018927
HSP_KSP_KEY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2128018923
HSP_KSP_KEY_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2128018922
HSP_KSP_KEY_LOAD_FAIL: win32more.Windows.Win32.Foundation.HRESULT = -2128018921
HSP_KSP_NO_MORE_ITEMS: win32more.Windows.Win32.Foundation.HRESULT = -2128018920
HSP_KSP_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2128018689
ERROR_IO_PREEMPTED: win32more.Windows.Win32.Foundation.HRESULT = -1996423167
JSCRIPT_E_CANTEXECUTE: win32more.Windows.Win32.Foundation.HRESULT = -1996357631
WEP_E_NOT_PROVISIONED_ON_ALL_VOLUMES: win32more.Windows.Win32.Foundation.HRESULT = -2013200383
WEP_E_FIXED_DATA_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2013200382
WEP_E_HARDWARE_NOT_COMPLIANT: win32more.Windows.Win32.Foundation.HRESULT = -2013200381
WEP_E_LOCK_NOT_CONFIGURED: win32more.Windows.Win32.Foundation.HRESULT = -2013200380
WEP_E_PROTECTION_SUSPENDED: win32more.Windows.Win32.Foundation.HRESULT = -2013200379
WEP_E_NO_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -2013200378
WEP_E_OS_NOT_PROTECTED: win32more.Windows.Win32.Foundation.HRESULT = -2013200377
WEP_E_UNEXPECTED_FAIL: win32more.Windows.Win32.Foundation.HRESULT = -2013200376
WEP_E_BUFFER_TOO_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -2013200375
ERROR_SVHDX_ERROR_STORED: win32more.Windows.Win32.Foundation.HRESULT = -1067712512
ERROR_SVHDX_ERROR_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1067647232
ERROR_SVHDX_UNIT_ATTENTION_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1067647231
ERROR_SVHDX_UNIT_ATTENTION_CAPACITY_DATA_CHANGED: win32more.Windows.Win32.Foundation.HRESULT = -1067647230
ERROR_SVHDX_UNIT_ATTENTION_RESERVATIONS_PREEMPTED: win32more.Windows.Win32.Foundation.HRESULT = -1067647229
ERROR_SVHDX_UNIT_ATTENTION_RESERVATIONS_RELEASED: win32more.Windows.Win32.Foundation.HRESULT = -1067647228
ERROR_SVHDX_UNIT_ATTENTION_REGISTRATIONS_PREEMPTED: win32more.Windows.Win32.Foundation.HRESULT = -1067647227
ERROR_SVHDX_UNIT_ATTENTION_OPERATING_DEFINITION_CHANGED: win32more.Windows.Win32.Foundation.HRESULT = -1067647226
ERROR_SVHDX_RESERVATION_CONFLICT: win32more.Windows.Win32.Foundation.HRESULT = -1067647225
ERROR_SVHDX_WRONG_FILE_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -1067647224
ERROR_SVHDX_VERSION_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1067647223
ERROR_VHD_SHARED: win32more.Windows.Win32.Foundation.HRESULT = -1067647222
ERROR_SVHDX_NO_INITIATOR: win32more.Windows.Win32.Foundation.HRESULT = -1067647221
ERROR_VHDSET_BACKING_STORAGE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1067647220
ERROR_SMB_NO_PREAUTH_INTEGRITY_HASH_OVERLAP: win32more.Windows.Win32.Foundation.HRESULT = -1067646976
ERROR_SMB_BAD_CLUSTER_DIALECT: win32more.Windows.Win32.Foundation.HRESULT = -1067646975
ERROR_SMB_NO_SIGNING_ALGORITHM_OVERLAP: win32more.Windows.Win32.Foundation.HRESULT = -1067646974
WININET_E_OUT_OF_HANDLES: win32more.Windows.Win32.Foundation.HRESULT = -2147012895
WININET_E_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2147012894
WININET_E_EXTENDED_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147012893
WININET_E_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147012892
WININET_E_INVALID_URL: win32more.Windows.Win32.Foundation.HRESULT = -2147012891
WININET_E_UNRECOGNIZED_SCHEME: win32more.Windows.Win32.Foundation.HRESULT = -2147012890
WININET_E_NAME_NOT_RESOLVED: win32more.Windows.Win32.Foundation.HRESULT = -2147012889
WININET_E_PROTOCOL_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147012888
WININET_E_INVALID_OPTION: win32more.Windows.Win32.Foundation.HRESULT = -2147012887
WININET_E_BAD_OPTION_LENGTH: win32more.Windows.Win32.Foundation.HRESULT = -2147012886
WININET_E_OPTION_NOT_SETTABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147012885
WININET_E_SHUTDOWN: win32more.Windows.Win32.Foundation.HRESULT = -2147012884
WININET_E_INCORRECT_USER_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2147012883
WININET_E_INCORRECT_PASSWORD: win32more.Windows.Win32.Foundation.HRESULT = -2147012882
WININET_E_LOGIN_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2147012881
WININET_E_INVALID_OPERATION: win32more.Windows.Win32.Foundation.HRESULT = -2147012880
WININET_E_OPERATION_CANCELLED: win32more.Windows.Win32.Foundation.HRESULT = -2147012879
WININET_E_INCORRECT_HANDLE_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147012878
WININET_E_INCORRECT_HANDLE_STATE: win32more.Windows.Win32.Foundation.HRESULT = -2147012877
WININET_E_NOT_PROXY_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -2147012876
WININET_E_REGISTRY_VALUE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147012875
WININET_E_BAD_REGISTRY_PARAMETER: win32more.Windows.Win32.Foundation.HRESULT = -2147012874
WININET_E_NO_DIRECT_ACCESS: win32more.Windows.Win32.Foundation.HRESULT = -2147012873
WININET_E_NO_CONTEXT: win32more.Windows.Win32.Foundation.HRESULT = -2147012872
WININET_E_NO_CALLBACK: win32more.Windows.Win32.Foundation.HRESULT = -2147012871
WININET_E_REQUEST_PENDING: win32more.Windows.Win32.Foundation.HRESULT = -2147012870
WININET_E_INCORRECT_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2147012869
WININET_E_ITEM_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147012868
WININET_E_CANNOT_CONNECT: win32more.Windows.Win32.Foundation.HRESULT = -2147012867
WININET_E_CONNECTION_ABORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147012866
WININET_E_CONNECTION_RESET: win32more.Windows.Win32.Foundation.HRESULT = -2147012865
WININET_E_FORCE_RETRY: win32more.Windows.Win32.Foundation.HRESULT = -2147012864
WININET_E_INVALID_PROXY_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -2147012863
WININET_E_NEED_UI: win32more.Windows.Win32.Foundation.HRESULT = -2147012862
WININET_E_HANDLE_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2147012860
WININET_E_SEC_CERT_DATE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2147012859
WININET_E_SEC_CERT_CN_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2147012858
WININET_E_HTTP_TO_HTTPS_ON_REDIR: win32more.Windows.Win32.Foundation.HRESULT = -2147012857
WININET_E_HTTPS_TO_HTTP_ON_REDIR: win32more.Windows.Win32.Foundation.HRESULT = -2147012856
WININET_E_MIXED_SECURITY: win32more.Windows.Win32.Foundation.HRESULT = -2147012855
WININET_E_CHG_POST_IS_NON_SECURE: win32more.Windows.Win32.Foundation.HRESULT = -2147012854
WININET_E_POST_IS_NON_SECURE: win32more.Windows.Win32.Foundation.HRESULT = -2147012853
WININET_E_CLIENT_AUTH_CERT_NEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2147012852
WININET_E_INVALID_CA: win32more.Windows.Win32.Foundation.HRESULT = -2147012851
WININET_E_CLIENT_AUTH_NOT_SETUP: win32more.Windows.Win32.Foundation.HRESULT = -2147012850
WININET_E_ASYNC_THREAD_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147012849
WININET_E_REDIRECT_SCHEME_CHANGE: win32more.Windows.Win32.Foundation.HRESULT = -2147012848
WININET_E_DIALOG_PENDING: win32more.Windows.Win32.Foundation.HRESULT = -2147012847
WININET_E_RETRY_DIALOG: win32more.Windows.Win32.Foundation.HRESULT = -2147012846
WININET_E_NO_NEW_CONTAINERS: win32more.Windows.Win32.Foundation.HRESULT = -2147012845
WININET_E_HTTPS_HTTP_SUBMIT_REDIR: win32more.Windows.Win32.Foundation.HRESULT = -2147012844
WININET_E_SEC_CERT_ERRORS: win32more.Windows.Win32.Foundation.HRESULT = -2147012841
WININET_E_SEC_CERT_REV_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147012839
WININET_E_HEADER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147012746
WININET_E_DOWNLEVEL_SERVER: win32more.Windows.Win32.Foundation.HRESULT = -2147012745
WININET_E_INVALID_SERVER_RESPONSE: win32more.Windows.Win32.Foundation.HRESULT = -2147012744
WININET_E_INVALID_HEADER: win32more.Windows.Win32.Foundation.HRESULT = -2147012743
WININET_E_INVALID_QUERY_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -2147012742
WININET_E_HEADER_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2147012741
WININET_E_REDIRECT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147012740
WININET_E_SECURITY_CHANNEL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147012739
WININET_E_UNABLE_TO_CACHE_FILE: win32more.Windows.Win32.Foundation.HRESULT = -2147012738
WININET_E_TCPIP_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -2147012737
WININET_E_DISCONNECTED: win32more.Windows.Win32.Foundation.HRESULT = -2147012733
WININET_E_SERVER_UNREACHABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147012732
WININET_E_PROXY_SERVER_UNREACHABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147012731
WININET_E_BAD_AUTO_PROXY_SCRIPT: win32more.Windows.Win32.Foundation.HRESULT = -2147012730
WININET_E_UNABLE_TO_DOWNLOAD_SCRIPT: win32more.Windows.Win32.Foundation.HRESULT = -2147012729
WININET_E_SEC_INVALID_CERT: win32more.Windows.Win32.Foundation.HRESULT = -2147012727
WININET_E_SEC_CERT_REVOKED: win32more.Windows.Win32.Foundation.HRESULT = -2147012726
WININET_E_FAILED_DUETOSECURITYCHECK: win32more.Windows.Win32.Foundation.HRESULT = -2147012725
WININET_E_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2147012724
WININET_E_LOGIN_FAILURE_DISPLAY_ENTITY_BODY: win32more.Windows.Win32.Foundation.HRESULT = -2147012722
WININET_E_DECODING_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147012721
WININET_E_NOT_REDIRECTED: win32more.Windows.Win32.Foundation.HRESULT = -2147012736
WININET_E_COOKIE_NEEDS_CONFIRMATION: win32more.Windows.Win32.Foundation.HRESULT = -2147012735
WININET_E_COOKIE_DECLINED: win32more.Windows.Win32.Foundation.HRESULT = -2147012734
WININET_E_REDIRECT_NEEDS_CONFIRMATION: win32more.Windows.Win32.Foundation.HRESULT = -2147012728
SQLITE_E_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2018574335
SQLITE_E_INTERNAL: win32more.Windows.Win32.Foundation.HRESULT = -2018574334
SQLITE_E_PERM: win32more.Windows.Win32.Foundation.HRESULT = -2018574333
SQLITE_E_ABORT: win32more.Windows.Win32.Foundation.HRESULT = -2018574332
SQLITE_E_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -2018574331
SQLITE_E_LOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2018574330
SQLITE_E_NOMEM: win32more.Windows.Win32.Foundation.HRESULT = -2018574329
SQLITE_E_READONLY: win32more.Windows.Win32.Foundation.HRESULT = -2018574328
SQLITE_E_INTERRUPT: win32more.Windows.Win32.Foundation.HRESULT = -2018574327
SQLITE_E_IOERR: win32more.Windows.Win32.Foundation.HRESULT = -2018574326
SQLITE_E_CORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -2018574325
SQLITE_E_NOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2018574324
SQLITE_E_FULL: win32more.Windows.Win32.Foundation.HRESULT = -2018574323
SQLITE_E_CANTOPEN: win32more.Windows.Win32.Foundation.HRESULT = -2018574322
SQLITE_E_PROTOCOL: win32more.Windows.Win32.Foundation.HRESULT = -2018574321
SQLITE_E_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = -2018574320
SQLITE_E_SCHEMA: win32more.Windows.Win32.Foundation.HRESULT = -2018574319
SQLITE_E_TOOBIG: win32more.Windows.Win32.Foundation.HRESULT = -2018574318
SQLITE_E_CONSTRAINT: win32more.Windows.Win32.Foundation.HRESULT = -2018574317
SQLITE_E_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2018574316
SQLITE_E_MISUSE: win32more.Windows.Win32.Foundation.HRESULT = -2018574315
SQLITE_E_NOLFS: win32more.Windows.Win32.Foundation.HRESULT = -2018574314
SQLITE_E_AUTH: win32more.Windows.Win32.Foundation.HRESULT = -2018574313
SQLITE_E_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2018574312
SQLITE_E_RANGE: win32more.Windows.Win32.Foundation.HRESULT = -2018574311
SQLITE_E_NOTADB: win32more.Windows.Win32.Foundation.HRESULT = -2018574310
SQLITE_E_NOTICE: win32more.Windows.Win32.Foundation.HRESULT = -2018574309
SQLITE_E_WARNING: win32more.Windows.Win32.Foundation.HRESULT = -2018574308
SQLITE_E_ROW: win32more.Windows.Win32.Foundation.HRESULT = -2018574236
SQLITE_E_DONE: win32more.Windows.Win32.Foundation.HRESULT = -2018574235
SQLITE_E_IOERR_READ: win32more.Windows.Win32.Foundation.HRESULT = -2018574070
SQLITE_E_IOERR_SHORT_READ: win32more.Windows.Win32.Foundation.HRESULT = -2018573814
SQLITE_E_IOERR_WRITE: win32more.Windows.Win32.Foundation.HRESULT = -2018573558
SQLITE_E_IOERR_FSYNC: win32more.Windows.Win32.Foundation.HRESULT = -2018573302
SQLITE_E_IOERR_DIR_FSYNC: win32more.Windows.Win32.Foundation.HRESULT = -2018573046
SQLITE_E_IOERR_TRUNCATE: win32more.Windows.Win32.Foundation.HRESULT = -2018572790
SQLITE_E_IOERR_FSTAT: win32more.Windows.Win32.Foundation.HRESULT = -2018572534
SQLITE_E_IOERR_UNLOCK: win32more.Windows.Win32.Foundation.HRESULT = -2018572278
SQLITE_E_IOERR_RDLOCK: win32more.Windows.Win32.Foundation.HRESULT = -2018572022
SQLITE_E_IOERR_DELETE: win32more.Windows.Win32.Foundation.HRESULT = -2018571766
SQLITE_E_IOERR_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2018571510
SQLITE_E_IOERR_NOMEM: win32more.Windows.Win32.Foundation.HRESULT = -2018571254
SQLITE_E_IOERR_ACCESS: win32more.Windows.Win32.Foundation.HRESULT = -2018570998
SQLITE_E_IOERR_CHECKRESERVEDLOCK: win32more.Windows.Win32.Foundation.HRESULT = -2018570742
SQLITE_E_IOERR_LOCK: win32more.Windows.Win32.Foundation.HRESULT = -2018570486
SQLITE_E_IOERR_CLOSE: win32more.Windows.Win32.Foundation.HRESULT = -2018570230
SQLITE_E_IOERR_DIR_CLOSE: win32more.Windows.Win32.Foundation.HRESULT = -2018569974
SQLITE_E_IOERR_SHMOPEN: win32more.Windows.Win32.Foundation.HRESULT = -2018569718
SQLITE_E_IOERR_SHMSIZE: win32more.Windows.Win32.Foundation.HRESULT = -2018569462
SQLITE_E_IOERR_SHMLOCK: win32more.Windows.Win32.Foundation.HRESULT = -2018569206
SQLITE_E_IOERR_SHMMAP: win32more.Windows.Win32.Foundation.HRESULT = -2018568950
SQLITE_E_IOERR_SEEK: win32more.Windows.Win32.Foundation.HRESULT = -2018568694
SQLITE_E_IOERR_DELETE_NOENT: win32more.Windows.Win32.Foundation.HRESULT = -2018568438
SQLITE_E_IOERR_MMAP: win32more.Windows.Win32.Foundation.HRESULT = -2018568182
SQLITE_E_IOERR_GETTEMPPATH: win32more.Windows.Win32.Foundation.HRESULT = -2018567926
SQLITE_E_IOERR_CONVPATH: win32more.Windows.Win32.Foundation.HRESULT = -2018567670
SQLITE_E_IOERR_VNODE: win32more.Windows.Win32.Foundation.HRESULT = -2018567678
SQLITE_E_IOERR_AUTH: win32more.Windows.Win32.Foundation.HRESULT = -2018567677
SQLITE_E_LOCKED_SHAREDCACHE: win32more.Windows.Win32.Foundation.HRESULT = -2018574074
SQLITE_E_BUSY_RECOVERY: win32more.Windows.Win32.Foundation.HRESULT = -2018574075
SQLITE_E_BUSY_SNAPSHOT: win32more.Windows.Win32.Foundation.HRESULT = -2018573819
SQLITE_E_CANTOPEN_NOTEMPDIR: win32more.Windows.Win32.Foundation.HRESULT = -2018574066
SQLITE_E_CANTOPEN_ISDIR: win32more.Windows.Win32.Foundation.HRESULT = -2018573810
SQLITE_E_CANTOPEN_FULLPATH: win32more.Windows.Win32.Foundation.HRESULT = -2018573554
SQLITE_E_CANTOPEN_CONVPATH: win32more.Windows.Win32.Foundation.HRESULT = -2018573298
SQLITE_E_CORRUPT_VTAB: win32more.Windows.Win32.Foundation.HRESULT = -2018574069
SQLITE_E_READONLY_RECOVERY: win32more.Windows.Win32.Foundation.HRESULT = -2018574072
SQLITE_E_READONLY_CANTLOCK: win32more.Windows.Win32.Foundation.HRESULT = -2018573816
SQLITE_E_READONLY_ROLLBACK: win32more.Windows.Win32.Foundation.HRESULT = -2018573560
SQLITE_E_READONLY_DBMOVED: win32more.Windows.Win32.Foundation.HRESULT = -2018573304
SQLITE_E_ABORT_ROLLBACK: win32more.Windows.Win32.Foundation.HRESULT = -2018573820
SQLITE_E_CONSTRAINT_CHECK: win32more.Windows.Win32.Foundation.HRESULT = -2018574061
SQLITE_E_CONSTRAINT_COMMITHOOK: win32more.Windows.Win32.Foundation.HRESULT = -2018573805
SQLITE_E_CONSTRAINT_FOREIGNKEY: win32more.Windows.Win32.Foundation.HRESULT = -2018573549
SQLITE_E_CONSTRAINT_FUNCTION: win32more.Windows.Win32.Foundation.HRESULT = -2018573293
SQLITE_E_CONSTRAINT_NOTNULL: win32more.Windows.Win32.Foundation.HRESULT = -2018573037
SQLITE_E_CONSTRAINT_PRIMARYKEY: win32more.Windows.Win32.Foundation.HRESULT = -2018572781
SQLITE_E_CONSTRAINT_TRIGGER: win32more.Windows.Win32.Foundation.HRESULT = -2018572525
SQLITE_E_CONSTRAINT_UNIQUE: win32more.Windows.Win32.Foundation.HRESULT = -2018572269
SQLITE_E_CONSTRAINT_VTAB: win32more.Windows.Win32.Foundation.HRESULT = -2018572013
SQLITE_E_CONSTRAINT_ROWID: win32more.Windows.Win32.Foundation.HRESULT = -2018571757
SQLITE_E_NOTICE_RECOVER_WAL: win32more.Windows.Win32.Foundation.HRESULT = -2018574053
SQLITE_E_NOTICE_RECOVER_ROLLBACK: win32more.Windows.Win32.Foundation.HRESULT = -2018573797
SQLITE_E_WARNING_AUTOINDEX: win32more.Windows.Win32.Foundation.HRESULT = -2018574052
UTC_E_TOGGLE_TRACE_STARTED: win32more.Windows.Win32.Foundation.HRESULT = -2017128447
UTC_E_ALTERNATIVE_TRACE_CANNOT_PREEMPT: win32more.Windows.Win32.Foundation.HRESULT = -2017128446
UTC_E_AOT_NOT_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2017128445
UTC_E_SCRIPT_TYPE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2017128444
UTC_E_SCENARIODEF_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2017128443
UTC_E_TRACEPROFILE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2017128442
UTC_E_FORWARDER_ALREADY_ENABLED: win32more.Windows.Win32.Foundation.HRESULT = -2017128441
UTC_E_FORWARDER_ALREADY_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2017128440
UTC_E_EVENTLOG_ENTRY_MALFORMED: win32more.Windows.Win32.Foundation.HRESULT = -2017128439
UTC_E_DIAGRULES_SCHEMAVERSION_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2017128438
UTC_E_SCRIPT_TERMINATED: win32more.Windows.Win32.Foundation.HRESULT = -2017128437
UTC_E_INVALID_CUSTOM_FILTER: win32more.Windows.Win32.Foundation.HRESULT = -2017128436
UTC_E_TRACE_NOT_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2017128435
UTC_E_REESCALATED_TOO_QUICKLY: win32more.Windows.Win32.Foundation.HRESULT = -2017128434
UTC_E_ESCALATION_ALREADY_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2017128433
UTC_E_PERFTRACK_ALREADY_TRACING: win32more.Windows.Win32.Foundation.HRESULT = -2017128432
UTC_E_REACHED_MAX_ESCALATIONS: win32more.Windows.Win32.Foundation.HRESULT = -2017128431
UTC_E_FORWARDER_PRODUCER_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2017128430
UTC_E_INTENTIONAL_SCRIPT_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2017128429
UTC_E_SQM_INIT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2017128428
UTC_E_NO_WER_LOGGER_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2017128427
UTC_E_TRACERS_DONT_EXIST: win32more.Windows.Win32.Foundation.HRESULT = -2017128426
UTC_E_WINRT_INIT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2017128425
UTC_E_SCENARIODEF_SCHEMAVERSION_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2017128424
UTC_E_INVALID_FILTER: win32more.Windows.Win32.Foundation.HRESULT = -2017128423
UTC_E_EXE_TERMINATED: win32more.Windows.Win32.Foundation.HRESULT = -2017128422
UTC_E_ESCALATION_NOT_AUTHORIZED: win32more.Windows.Win32.Foundation.HRESULT = -2017128421
UTC_E_SETUP_NOT_AUTHORIZED: win32more.Windows.Win32.Foundation.HRESULT = -2017128420
UTC_E_CHILD_PROCESS_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2017128419
UTC_E_COMMAND_LINE_NOT_AUTHORIZED: win32more.Windows.Win32.Foundation.HRESULT = -2017128418
UTC_E_CANNOT_LOAD_SCENARIO_EDITOR_XML: win32more.Windows.Win32.Foundation.HRESULT = -2017128417
UTC_E_ESCALATION_TIMED_OUT: win32more.Windows.Win32.Foundation.HRESULT = -2017128416
UTC_E_SETUP_TIMED_OUT: win32more.Windows.Win32.Foundation.HRESULT = -2017128415
UTC_E_TRIGGER_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2017128414
UTC_E_TRIGGER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2017128413
UTC_E_SIF_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2017128412
UTC_E_DELAY_TERMINATED: win32more.Windows.Win32.Foundation.HRESULT = -2017128411
UTC_E_DEVICE_TICKET_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2017128410
UTC_E_TRACE_BUFFER_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2017128409
UTC_E_API_RESULT_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2017128408
UTC_E_RPC_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2017128407
UTC_E_RPC_WAIT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2017128406
UTC_E_API_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -2017128405
UTC_E_TRACE_MIN_DURATION_REQUIREMENT_NOT_MET: win32more.Windows.Win32.Foundation.HRESULT = -2017128404
UTC_E_EXCLUSIVITY_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2017128403
UTC_E_GETFILE_FILE_PATH_NOT_APPROVED: win32more.Windows.Win32.Foundation.HRESULT = -2017128402
UTC_E_ESCALATION_DIRECTORY_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2017128401
UTC_E_TIME_TRIGGER_ON_START_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2017128400
UTC_E_TIME_TRIGGER_ONLY_VALID_ON_SINGLE_TRANSITION: win32more.Windows.Win32.Foundation.HRESULT = -2017128399
UTC_E_TIME_TRIGGER_INVALID_TIME_RANGE: win32more.Windows.Win32.Foundation.HRESULT = -2017128398
UTC_E_MULTIPLE_TIME_TRIGGER_ON_SINGLE_STATE: win32more.Windows.Win32.Foundation.HRESULT = -2017128397
UTC_E_BINARY_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2017128396
UTC_E_FAILED_TO_RESOLVE_CONTAINER_ID: win32more.Windows.Win32.Foundation.HRESULT = -2017128394
UTC_E_UNABLE_TO_RESOLVE_SESSION: win32more.Windows.Win32.Foundation.HRESULT = -2017128393
UTC_E_THROTTLED: win32more.Windows.Win32.Foundation.HRESULT = -2017128392
UTC_E_UNAPPROVED_SCRIPT: win32more.Windows.Win32.Foundation.HRESULT = -2017128391
UTC_E_SCRIPT_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2017128390
UTC_E_SCENARIO_THROTTLED: win32more.Windows.Win32.Foundation.HRESULT = -2017128389
UTC_E_API_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2017128388
UTC_E_GETFILE_EXTERNAL_PATH_NOT_APPROVED: win32more.Windows.Win32.Foundation.HRESULT = -2017128387
UTC_E_TRY_GET_SCENARIO_TIMEOUT_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2017128386
UTC_E_CERT_REV_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2017128385
UTC_E_FAILED_TO_START_NDISCAP: win32more.Windows.Win32.Foundation.HRESULT = -2017128384
UTC_E_KERNELDUMP_LIMIT_REACHED: win32more.Windows.Win32.Foundation.HRESULT = -2017128383
UTC_E_MISSING_AGGREGATE_EVENT_TAG: win32more.Windows.Win32.Foundation.HRESULT = -2017128382
UTC_E_INVALID_AGGREGATION_STRUCT: win32more.Windows.Win32.Foundation.HRESULT = -2017128381
UTC_E_ACTION_NOT_SUPPORTED_IN_DESTINATION: win32more.Windows.Win32.Foundation.HRESULT = -2017128380
UTC_E_FILTER_MISSING_ATTRIBUTE: win32more.Windows.Win32.Foundation.HRESULT = -2017128379
UTC_E_FILTER_INVALID_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2017128378
UTC_E_FILTER_VARIABLE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2017128377
UTC_E_FILTER_FUNCTION_RESTRICTED: win32more.Windows.Win32.Foundation.HRESULT = -2017128376
UTC_E_FILTER_VERSION_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2017128375
UTC_E_FILTER_INVALID_FUNCTION: win32more.Windows.Win32.Foundation.HRESULT = -2017128368
UTC_E_FILTER_INVALID_FUNCTION_PARAMS: win32more.Windows.Win32.Foundation.HRESULT = -2017128367
UTC_E_FILTER_INVALID_COMMAND: win32more.Windows.Win32.Foundation.HRESULT = -2017128366
UTC_E_FILTER_ILLEGAL_EVAL: win32more.Windows.Win32.Foundation.HRESULT = -2017128365
UTC_E_TTTRACER_RETURNED_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2017128364
UTC_E_AGENT_DIAGNOSTICS_TOO_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -2017128363
UTC_E_FAILED_TO_RECEIVE_AGENT_DIAGNOSTICS: win32more.Windows.Win32.Foundation.HRESULT = -2017128362
UTC_E_SCENARIO_HAS_NO_ACTIONS: win32more.Windows.Win32.Foundation.HRESULT = -2017128361
UTC_E_TTTRACER_STORAGE_FULL: win32more.Windows.Win32.Foundation.HRESULT = -2017128360
UTC_E_INSUFFICIENT_SPACE_TO_START_TRACE: win32more.Windows.Win32.Foundation.HRESULT = -2017128359
UTC_E_ESCALATION_CANCELLED_AT_SHUTDOWN: win32more.Windows.Win32.Foundation.HRESULT = -2017128358
UTC_E_GETFILEINFOACTION_FILE_NOT_APPROVED: win32more.Windows.Win32.Foundation.HRESULT = -2017128357
UTC_E_SETREGKEYACTION_TYPE_NOT_APPROVED: win32more.Windows.Win32.Foundation.HRESULT = -2017128356
UTC_E_TRACE_THROTTLED: win32more.Windows.Win32.Foundation.HRESULT = -2017128355
WINML_ERR_INVALID_DEVICE: win32more.Windows.Win32.Foundation.HRESULT = -2003828735
WINML_ERR_INVALID_BINDING: win32more.Windows.Win32.Foundation.HRESULT = -2003828734
WINML_ERR_VALUE_NOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2003828733
WINML_ERR_SIZE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2003828732
ERROR_QUIC_HANDSHAKE_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2143223808
ERROR_QUIC_VER_NEG_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2143223807
ERROR_QUIC_USER_CANCELED: win32more.Windows.Win32.Foundation.HRESULT = -2143223806
ERROR_QUIC_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2143223805
ERROR_QUIC_PROTOCOL_VIOLATION: win32more.Windows.Win32.Foundation.HRESULT = -2143223804
ERROR_QUIC_CONNECTION_IDLE: win32more.Windows.Win32.Foundation.HRESULT = -2143223803
ERROR_QUIC_CONNECTION_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2143223802
ERROR_QUIC_ALPN_NEG_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2143223801
IORING_E_REQUIRED_FLAG_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2142896127
IORING_E_SUBMISSION_QUEUE_FULL: win32more.Windows.Win32.Foundation.HRESULT = -2142896126
IORING_E_VERSION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2142896125
IORING_E_SUBMISSION_QUEUE_TOO_BIG: win32more.Windows.Win32.Foundation.HRESULT = -2142896124
IORING_E_COMPLETION_QUEUE_TOO_BIG: win32more.Windows.Win32.Foundation.HRESULT = -2142896123
IORING_E_SUBMIT_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2142896122
IORING_E_CORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -2142896121
IORING_E_COMPLETION_QUEUE_TOO_FULL: win32more.Windows.Win32.Foundation.HRESULT = -2142896120
RPC_X_ENUM_VALUE_TOO_LARGE: Int32 = 1781
RPC_X_INVALID_PIPE_OPERATION: Int32 = 1831
RPC_X_SS_CONTEXT_MISMATCH: Int32 = -1073545211
RPC_X_NO_MEMORY: Int32 = -1073741801
RPC_X_INVALID_BOUND: Int32 = -1073610717
RPC_X_INVALID_TAG: Int32 = -1073610718
RPC_X_INVALID_BUFFER: Int32 = -1073741306
RPC_X_PIPE_APP_MEMORY: Int32 = -1073741801
STATUS_SEVERITY_COERROR: UInt32 = 2
STATUS_SEVERITY_COFAIL: UInt32 = 3
NOT_AN_ERROR1: win32more.Windows.Win32.Foundation.HRESULT = 529920
QUERY_E_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147215872
QUERY_E_INVALIDQUERY: win32more.Windows.Win32.Foundation.HRESULT = -2147215871
QUERY_E_INVALIDRESTRICTION: win32more.Windows.Win32.Foundation.HRESULT = -2147215870
QUERY_E_INVALIDSORT: win32more.Windows.Win32.Foundation.HRESULT = -2147215869
QUERY_E_INVALIDCATEGORIZE: win32more.Windows.Win32.Foundation.HRESULT = -2147215868
QUERY_E_ALLNOISE: win32more.Windows.Win32.Foundation.HRESULT = -2147215867
QUERY_E_TOOCOMPLEX: win32more.Windows.Win32.Foundation.HRESULT = -2147215866
QUERY_E_TIMEDOUT: win32more.Windows.Win32.Foundation.HRESULT = -2147215865
QUERY_E_DUPLICATE_OUTPUT_COLUMN: win32more.Windows.Win32.Foundation.HRESULT = -2147215864
QUERY_E_INVALID_OUTPUT_COLUMN: win32more.Windows.Win32.Foundation.HRESULT = -2147215863
QUERY_E_INVALID_DIRECTORY: win32more.Windows.Win32.Foundation.HRESULT = -2147215862
QUERY_E_DIR_ON_REMOVABLE_DRIVE: win32more.Windows.Win32.Foundation.HRESULT = -2147215861
QUERY_S_NO_QUERY: win32more.Windows.Win32.Foundation.HRESULT = -2147215860
QPLIST_E_CANT_OPEN_FILE: win32more.Windows.Win32.Foundation.HRESULT = -2147215791
QPLIST_E_READ_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147215790
QPLIST_E_EXPECTING_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2147215789
QPLIST_E_EXPECTING_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147215788
QPLIST_E_UNRECOGNIZED_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147215787
QPLIST_E_EXPECTING_INTEGER: win32more.Windows.Win32.Foundation.HRESULT = -2147215786
QPLIST_E_EXPECTING_CLOSE_PAREN: win32more.Windows.Win32.Foundation.HRESULT = -2147215785
QPLIST_E_EXPECTING_GUID: win32more.Windows.Win32.Foundation.HRESULT = -2147215784
QPLIST_E_BAD_GUID: win32more.Windows.Win32.Foundation.HRESULT = -2147215783
QPLIST_E_EXPECTING_PROP_SPEC: win32more.Windows.Win32.Foundation.HRESULT = -2147215782
QPLIST_E_CANT_SET_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2147215781
QPLIST_E_DUPLICATE: win32more.Windows.Win32.Foundation.HRESULT = -2147215780
QPLIST_E_VECTORBYREF_USED_ALONE: win32more.Windows.Win32.Foundation.HRESULT = -2147215779
QPLIST_E_BYREF_USED_WITHOUT_PTRTYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147215778
QPARSE_E_UNEXPECTED_NOT: win32more.Windows.Win32.Foundation.HRESULT = -2147215776
QPARSE_E_EXPECTING_INTEGER: win32more.Windows.Win32.Foundation.HRESULT = -2147215775
QPARSE_E_EXPECTING_REAL: win32more.Windows.Win32.Foundation.HRESULT = -2147215774
QPARSE_E_EXPECTING_DATE: win32more.Windows.Win32.Foundation.HRESULT = -2147215773
QPARSE_E_EXPECTING_CURRENCY: win32more.Windows.Win32.Foundation.HRESULT = -2147215772
QPARSE_E_EXPECTING_GUID: win32more.Windows.Win32.Foundation.HRESULT = -2147215771
QPARSE_E_EXPECTING_BRACE: win32more.Windows.Win32.Foundation.HRESULT = -2147215770
QPARSE_E_EXPECTING_PAREN: win32more.Windows.Win32.Foundation.HRESULT = -2147215769
QPARSE_E_EXPECTING_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2147215768
QPARSE_E_NOT_YET_IMPLEMENTED: win32more.Windows.Win32.Foundation.HRESULT = -2147215767
QPARSE_E_EXPECTING_PHRASE: win32more.Windows.Win32.Foundation.HRESULT = -2147215766
QPARSE_E_UNSUPPORTED_PROPERTY_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147215765
QPARSE_E_EXPECTING_REGEX: win32more.Windows.Win32.Foundation.HRESULT = -2147215764
QPARSE_E_EXPECTING_REGEX_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2147215763
QPARSE_E_INVALID_LITERAL: win32more.Windows.Win32.Foundation.HRESULT = -2147215762
QPARSE_E_NO_SUCH_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2147215761
QPARSE_E_EXPECTING_EOS: win32more.Windows.Win32.Foundation.HRESULT = -2147215760
QPARSE_E_EXPECTING_COMMA: win32more.Windows.Win32.Foundation.HRESULT = -2147215759
QPARSE_E_UNEXPECTED_EOS: win32more.Windows.Win32.Foundation.HRESULT = -2147215758
QPARSE_E_WEIGHT_OUT_OF_RANGE: win32more.Windows.Win32.Foundation.HRESULT = -2147215757
QPARSE_E_NO_SUCH_SORT_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2147215756
QPARSE_E_INVALID_SORT_ORDER: win32more.Windows.Win32.Foundation.HRESULT = -2147215755
QUTIL_E_CANT_CONVERT_VROOT: win32more.Windows.Win32.Foundation.HRESULT = -2147215754
QPARSE_E_INVALID_GROUPING: win32more.Windows.Win32.Foundation.HRESULT = -2147215753
QUTIL_E_INVALID_CODEPAGE: win32more.Windows.Win32.Foundation.HRESULT = -1073473928
QPLIST_S_DUPLICATE: win32more.Windows.Win32.Foundation.HRESULT = 267897
QPARSE_E_INVALID_QUERY: win32more.Windows.Win32.Foundation.HRESULT = -2147215750
QPARSE_E_INVALID_RANKMETHOD: win32more.Windows.Win32.Foundation.HRESULT = -2147215749
FDAEMON_W_WORDLISTFULL: win32more.Windows.Win32.Foundation.HRESULT = 267904
FDAEMON_E_LOWRESOURCE: win32more.Windows.Win32.Foundation.HRESULT = -2147215743
FDAEMON_E_FATALERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147215742
FDAEMON_E_PARTITIONDELETED: win32more.Windows.Win32.Foundation.HRESULT = -2147215741
FDAEMON_E_CHANGEUPDATEFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147215740
FDAEMON_W_EMPTYWORDLIST: win32more.Windows.Win32.Foundation.HRESULT = 267909
FDAEMON_E_WORDLISTCOMMITFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147215738
FDAEMON_E_NOWORDLIST: win32more.Windows.Win32.Foundation.HRESULT = -2147215737
FDAEMON_E_TOOMANYFILTEREDBLOCKS: win32more.Windows.Win32.Foundation.HRESULT = -2147215736
SEARCH_S_NOMOREHITS: win32more.Windows.Win32.Foundation.HRESULT = 267936
SEARCH_E_NOMONIKER: win32more.Windows.Win32.Foundation.HRESULT = -2147215711
SEARCH_E_NOREGION: win32more.Windows.Win32.Foundation.HRESULT = -2147215710
FILTER_E_TOO_BIG: win32more.Windows.Win32.Foundation.HRESULT = -2147215568
FILTER_S_PARTIAL_CONTENTSCAN_IMMEDIATE: win32more.Windows.Win32.Foundation.HRESULT = 268081
FILTER_S_FULL_CONTENTSCAN_IMMEDIATE: win32more.Windows.Win32.Foundation.HRESULT = 268082
FILTER_S_CONTENTSCAN_DELAYED: win32more.Windows.Win32.Foundation.HRESULT = 268083
FILTER_E_CONTENTINDEXCORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -1073473740
FILTER_S_DISK_FULL: win32more.Windows.Win32.Foundation.HRESULT = 268085
FILTER_E_ALREADY_OPEN: win32more.Windows.Win32.Foundation.HRESULT = -2147215562
FILTER_E_UNREACHABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147215561
FILTER_E_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -2147215560
FILTER_E_NOT_OPEN: win32more.Windows.Win32.Foundation.HRESULT = -2147215559
FILTER_S_NO_PROPSETS: win32more.Windows.Win32.Foundation.HRESULT = 268090
FILTER_E_NO_SUCH_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2147215557
FILTER_S_NO_SECURITY_DESCRIPTOR: win32more.Windows.Win32.Foundation.HRESULT = 268092
FILTER_E_OFFLINE: win32more.Windows.Win32.Foundation.HRESULT = -2147215555
FILTER_E_PARTIALLY_FILTERED: win32more.Windows.Win32.Foundation.HRESULT = -2147215554
WBREAK_E_END_OF_TEXT: win32more.Windows.Win32.Foundation.HRESULT = -2147215488
LANGUAGE_S_LARGE_WORD: win32more.Windows.Win32.Foundation.HRESULT = 268161
WBREAK_E_QUERY_ONLY: win32more.Windows.Win32.Foundation.HRESULT = -2147215486
WBREAK_E_BUFFER_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -2147215485
LANGUAGE_E_DATABASE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147215484
WBREAK_E_INIT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147215483
PSINK_E_QUERY_ONLY: win32more.Windows.Win32.Foundation.HRESULT = -2147215472
PSINK_E_INDEX_ONLY: win32more.Windows.Win32.Foundation.HRESULT = -2147215471
PSINK_E_LARGE_ATTACHMENT: win32more.Windows.Win32.Foundation.HRESULT = -2147215470
PSINK_S_LARGE_WORD: win32more.Windows.Win32.Foundation.HRESULT = 268179
CI_CORRUPT_DATABASE: win32more.Windows.Win32.Foundation.HRESULT = -1073473536
CI_CORRUPT_CATALOG: win32more.Windows.Win32.Foundation.HRESULT = -1073473535
CI_INVALID_PARTITION: win32more.Windows.Win32.Foundation.HRESULT = -1073473534
CI_INVALID_PRIORITY: win32more.Windows.Win32.Foundation.HRESULT = -1073473533
CI_NO_STARTING_KEY: win32more.Windows.Win32.Foundation.HRESULT = -1073473532
CI_OUT_OF_INDEX_IDS: win32more.Windows.Win32.Foundation.HRESULT = -1073473531
CI_NO_CATALOG: win32more.Windows.Win32.Foundation.HRESULT = -1073473530
CI_CORRUPT_FILTER_BUFFER: win32more.Windows.Win32.Foundation.HRESULT = -1073473529
CI_INVALID_INDEX: win32more.Windows.Win32.Foundation.HRESULT = -1073473528
CI_PROPSTORE_INCONSISTENCY: win32more.Windows.Win32.Foundation.HRESULT = -1073473527
CI_E_ALREADY_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2147215350
CI_E_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2147215349
CI_E_BUFFERTOOSMALL: win32more.Windows.Win32.Foundation.HRESULT = -2147215348
CI_E_PROPERTY_NOT_CACHED: win32more.Windows.Win32.Foundation.HRESULT = -2147215347
CI_S_WORKID_DELETED: win32more.Windows.Win32.Foundation.HRESULT = 268302
CI_E_INVALID_STATE: win32more.Windows.Win32.Foundation.HRESULT = -2147215345
CI_E_FILTERING_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2147215344
CI_E_DISK_FULL: win32more.Windows.Win32.Foundation.HRESULT = -2147215343
CI_E_SHUTDOWN: win32more.Windows.Win32.Foundation.HRESULT = -2147215342
CI_E_WORKID_NOTVALID: win32more.Windows.Win32.Foundation.HRESULT = -2147215341
CI_S_END_OF_ENUMERATION: win32more.Windows.Win32.Foundation.HRESULT = 268308
CI_E_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147215339
CI_E_USE_DEFAULT_PID: win32more.Windows.Win32.Foundation.HRESULT = -2147215338
CI_E_DUPLICATE_NOTIFICATION: win32more.Windows.Win32.Foundation.HRESULT = -2147215337
CI_E_UPDATES_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2147215336
CI_E_INVALID_FLAGS_COMBINATION: win32more.Windows.Win32.Foundation.HRESULT = -2147215335
CI_E_OUTOFSEQ_INCREMENT_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2147215334
CI_E_SHARING_VIOLATION: win32more.Windows.Win32.Foundation.HRESULT = -2147215333
CI_E_LOGON_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2147215332
CI_E_NO_CATALOG: win32more.Windows.Win32.Foundation.HRESULT = -2147215331
CI_E_STRANGE_PAGEORSECTOR_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2147215330
CI_E_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2147215329
CI_E_NOT_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2147215328
CI_INCORRECT_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -1073473503
CI_E_ENUMERATION_STARTED: win32more.Windows.Win32.Foundation.HRESULT = -1073473502
CI_E_PROPERTY_TOOLARGE: win32more.Windows.Win32.Foundation.HRESULT = -1073473501
CI_E_CLIENT_FILTER_ABORT: win32more.Windows.Win32.Foundation.HRESULT = -1073473500
CI_S_NO_DOCSTORE: win32more.Windows.Win32.Foundation.HRESULT = 268325
CI_S_CAT_STOPPED: win32more.Windows.Win32.Foundation.HRESULT = 268326
CI_E_CARDINALITY_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2147215321
CI_E_CONFIG_DISK_FULL: win32more.Windows.Win32.Foundation.HRESULT = -2147215320
CI_E_DISTRIBUTED_GROUPBY_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147215319
ROUTEBASE: UInt32 = 900
SUCCESS: UInt32 = 0
ERROR_ROUTER_STOPPED: UInt32 = 900
ERROR_ALREADY_CONNECTED: UInt32 = 901
ERROR_UNKNOWN_PROTOCOL_ID: UInt32 = 902
ERROR_DDM_NOT_RUNNING: UInt32 = 903
ERROR_INTERFACE_ALREADY_EXISTS: UInt32 = 904
ERROR_NO_SUCH_INTERFACE: UInt32 = 905
ERROR_INTERFACE_NOT_CONNECTED: UInt32 = 906
ERROR_PROTOCOL_STOP_PENDING: UInt32 = 907
ERROR_INTERFACE_CONNECTED: UInt32 = 908
ERROR_NO_INTERFACE_CREDENTIALS_SET: UInt32 = 909
ERROR_ALREADY_CONNECTING: UInt32 = 910
ERROR_UPDATE_IN_PROGRESS: UInt32 = 911
ERROR_INTERFACE_CONFIGURATION: UInt32 = 912
ERROR_NOT_CLIENT_PORT: UInt32 = 913
ERROR_NOT_ROUTER_PORT: UInt32 = 914
ERROR_CLIENT_INTERFACE_ALREADY_EXISTS: UInt32 = 915
ERROR_INTERFACE_DISABLED: UInt32 = 916
ERROR_AUTH_PROTOCOL_REJECTED: UInt32 = 917
ERROR_NO_AUTH_PROTOCOL_AVAILABLE: UInt32 = 918
ERROR_PEER_REFUSED_AUTH: UInt32 = 919
ERROR_REMOTE_NO_DIALIN_PERMISSION: UInt32 = 920
ERROR_REMOTE_PASSWD_EXPIRED: UInt32 = 921
ERROR_REMOTE_ACCT_DISABLED: UInt32 = 922
ERROR_REMOTE_RESTRICTED_LOGON_HOURS: UInt32 = 923
ERROR_REMOTE_AUTHENTICATION_FAILURE: UInt32 = 924
ERROR_INTERFACE_HAS_NO_DEVICES: UInt32 = 925
ERROR_IDLE_DISCONNECTED: UInt32 = 926
ERROR_INTERFACE_UNREACHABLE: UInt32 = 927
ERROR_SERVICE_IS_PAUSED: UInt32 = 928
ERROR_INTERFACE_DISCONNECTED: UInt32 = 929
ERROR_AUTH_SERVER_TIMEOUT: UInt32 = 930
ERROR_PORT_LIMIT_REACHED: UInt32 = 931
ERROR_PPP_SESSION_TIMEOUT: UInt32 = 932
ERROR_MAX_LAN_INTERFACE_LIMIT: UInt32 = 933
ERROR_MAX_WAN_INTERFACE_LIMIT: UInt32 = 934
ERROR_MAX_CLIENT_INTERFACE_LIMIT: UInt32 = 935
ERROR_BAP_DISCONNECTED: UInt32 = 936
ERROR_USER_LIMIT: UInt32 = 937
ERROR_NO_RADIUS_SERVERS: UInt32 = 938
ERROR_INVALID_RADIUS_RESPONSE: UInt32 = 939
ERROR_DIALIN_HOURS_RESTRICTION: UInt32 = 940
ERROR_ALLOWED_PORT_TYPE_RESTRICTION: UInt32 = 941
ERROR_AUTH_PROTOCOL_RESTRICTION: UInt32 = 942
ERROR_BAP_REQUIRED: UInt32 = 943
ERROR_DIALOUT_HOURS_RESTRICTION: UInt32 = 944
ERROR_ROUTER_CONFIG_INCOMPATIBLE: UInt32 = 945
WARNING_NO_MD5_MIGRATION: UInt32 = 946
ERROR_PROTOCOL_ALREADY_INSTALLED: UInt32 = 948
ERROR_INVALID_SIGNATURE_LENGTH: UInt32 = 949
ERROR_INVALID_SIGNATURE: UInt32 = 950
ERROR_NO_SIGNATURE: UInt32 = 951
ERROR_INVALID_PACKET_LENGTH_OR_ID: UInt32 = 952
ERROR_INVALID_ATTRIBUTE_LENGTH: UInt32 = 953
ERROR_INVALID_PACKET: UInt32 = 954
ERROR_AUTHENTICATOR_MISMATCH: UInt32 = 955
ERROR_REMOTEACCESS_NOT_CONFIGURED: UInt32 = 956
ROUTEBASEEND: UInt32 = 957
_WIN32_MAXVER: UInt32 = 2560
_WIN32_WINDOWS_MAXVER: UInt32 = 2560
NTDDI_MAXVER: UInt32 = 2560
_WIN32_IE_MAXVER: UInt32 = 2560
_WIN32_WINNT_MAXVER: UInt32 = 2560
WINVER_MAXVER: UInt32 = 2560
@winfunctype('OLEAUT32.dll')
def SysAllocString(psz: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BSTR: ...
@winfunctype('OLEAUT32.dll')
def SysReAllocString(pbstr: POINTER(win32more.Windows.Win32.Foundation.BSTR), psz: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
@winfunctype('OLEAUT32.dll')
def SysAllocStringLen(strIn: win32more.Windows.Win32.Foundation.PWSTR, ui: UInt32) -> win32more.Windows.Win32.Foundation.BSTR: ...
@winfunctype('OLEAUT32.dll')
def SysReAllocStringLen(pbstr: POINTER(win32more.Windows.Win32.Foundation.BSTR), psz: win32more.Windows.Win32.Foundation.PWSTR, len: UInt32) -> Int32: ...
@winfunctype('OLEAUT32.dll')
def SysAddRefString(bstrString: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('OLEAUT32.dll')
def SysReleaseString(bstrString: win32more.Windows.Win32.Foundation.BSTR) -> Void: ...
@winfunctype('OLEAUT32.dll')
def SysFreeString(bstrString: win32more.Windows.Win32.Foundation.BSTR) -> Void: ...
@winfunctype('OLEAUT32.dll')
def SysStringLen(pbstr: win32more.Windows.Win32.Foundation.BSTR) -> UInt32: ...
@winfunctype('OLEAUT32.dll')
def SysStringByteLen(bstr: win32more.Windows.Win32.Foundation.BSTR) -> UInt32: ...
@winfunctype('OLEAUT32.dll')
def SysAllocStringByteLen(psz: win32more.Windows.Win32.Foundation.PSTR, len: UInt32) -> win32more.Windows.Win32.Foundation.BSTR: ...
@winfunctype('KERNEL32.dll')
def CloseHandle(hObject: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def DuplicateHandle(hSourceProcessHandle: win32more.Windows.Win32.Foundation.HANDLE, hSourceHandle: win32more.Windows.Win32.Foundation.HANDLE, hTargetProcessHandle: win32more.Windows.Win32.Foundation.HANDLE, lpTargetHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE), dwDesiredAccess: UInt32, bInheritHandle: win32more.Windows.Win32.Foundation.BOOL, dwOptions: win32more.Windows.Win32.Foundation.DUPLICATE_HANDLE_OPTIONS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('api-ms-win-core-handle-l1-1-0.dll')
def CompareObjectHandles(hFirstObjectHandle: win32more.Windows.Win32.Foundation.HANDLE, hSecondObjectHandle: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetHandleInformation(hObject: win32more.Windows.Win32.Foundation.HANDLE, lpdwFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetHandleInformation(hObject: win32more.Windows.Win32.Foundation.HANDLE, dwMask: UInt32, dwFlags: win32more.Windows.Win32.Foundation.HANDLE_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def FreeLibrary(hLibModule: win32more.Windows.Win32.Foundation.HMODULE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetLastError() -> win32more.Windows.Win32.Foundation.WIN32_ERROR: ...
@winfunctype('KERNEL32.dll')
def SetLastError(dwErrCode: win32more.Windows.Win32.Foundation.WIN32_ERROR) -> Void: ...
@winfunctype('USER32.dll')
def SetLastErrorEx(dwErrCode: win32more.Windows.Win32.Foundation.WIN32_ERROR, dwType: UInt32) -> Void: ...
@winfunctype('KERNEL32.dll')
def GlobalFree(hMem: win32more.Windows.Win32.Foundation.HGLOBAL) -> win32more.Windows.Win32.Foundation.HGLOBAL: ...
@winfunctype('KERNEL32.dll')
def LocalFree(hMem: win32more.Windows.Win32.Foundation.HLOCAL) -> win32more.Windows.Win32.Foundation.HLOCAL: ...
@winfunctype('ntdll.dll')
def RtlNtStatusToDosError(Status: win32more.Windows.Win32.Foundation.NTSTATUS) -> UInt32: ...
BOOL = Int32
BOOLEAN = Byte
BSTR = String
CHAR = SByte
COLORREF = UInt32
class DECIMAL(Structure):
    wReserved: UInt16
    Anonymous1: _Anonymous1_e__Union
    Hi32: UInt32
    Anonymous2: _Anonymous2_e__Union
    class _Anonymous1_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        signscale: UInt16
        class _Anonymous_e__Struct(Structure):
            scale: Byte
            sign: Byte
    class _Anonymous2_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        Lo64: UInt64
        class _Anonymous_e__Struct(Structure):
            Lo32: UInt32
            Mid32: UInt32
class DEVPROPKEY(Structure):
    fmtid: Guid
    pid: UInt32
DUPLICATE_HANDLE_OPTIONS = UInt32
DUPLICATE_CLOSE_SOURCE: win32more.Windows.Win32.Foundation.DUPLICATE_HANDLE_OPTIONS = 1
DUPLICATE_SAME_ACCESS: win32more.Windows.Win32.Foundation.DUPLICATE_HANDLE_OPTIONS = 2
@winfunctype_pointer
def FARPROC() -> IntPtr: ...
class FILETIME(Structure):
    dwLowDateTime: UInt32
    dwHighDateTime: UInt32
class FLOAT128(Structure):
    LowPart: Int64
    HighPart: Int64
GENERIC_ACCESS_RIGHTS = UInt32
GENERIC_READ: win32more.Windows.Win32.Foundation.GENERIC_ACCESS_RIGHTS = 2147483648
GENERIC_WRITE: win32more.Windows.Win32.Foundation.GENERIC_ACCESS_RIGHTS = 1073741824
GENERIC_EXECUTE: win32more.Windows.Win32.Foundation.GENERIC_ACCESS_RIGHTS = 536870912
GENERIC_ALL: win32more.Windows.Win32.Foundation.GENERIC_ACCESS_RIGHTS = 268435456
HANDLE = VoidPtr
HANDLE_FLAGS = UInt32
HANDLE_FLAG_INHERIT: win32more.Windows.Win32.Foundation.HANDLE_FLAGS = 1
HANDLE_FLAG_PROTECT_FROM_CLOSE: win32more.Windows.Win32.Foundation.HANDLE_FLAGS = 2
HANDLE_PTR = UIntPtr
HGLOBAL = VoidPtr
HINSTANCE = VoidPtr
HLOCAL = VoidPtr
HLSURF = VoidPtr
HMODULE = VoidPtr
HRESULT = Int32
HRSRC = VoidPtr
HSPRITE = VoidPtr
HSTR = VoidPtr
HUMPD = VoidPtr
HWND = VoidPtr
LPARAM = IntPtr
LRESULT = IntPtr
class LUID(Structure):
    LowPart: UInt32
    HighPart: Int32
@winfunctype_pointer
def NEARPROC() -> IntPtr: ...
NTSTATUS = Int32
NTSTATUS_FACILITY_CODE = UInt32
FACILITY_MCA_ERROR_CODE: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 5
FACILITY_DEBUGGER: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 1
FACILITY_RPC_RUNTIME: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 2
FACILITY_RPC_STUBS: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 3
FACILITY_IO_ERROR_CODE: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 4
FACILITY_CODCLASS_ERROR_CODE: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 6
FACILITY_NTWIN32: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 7
FACILITY_NTCERT: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 8
FACILITY_NTSSPI: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 9
FACILITY_TERMINAL_SERVER: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 10
FACILITY_USB_ERROR_CODE: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 16
FACILITY_HID_ERROR_CODE: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 17
FACILITY_FIREWIRE_ERROR_CODE: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 18
FACILITY_CLUSTER_ERROR_CODE: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 19
FACILITY_ACPI_ERROR_CODE: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 20
FACILITY_SXS_ERROR_CODE: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 21
FACILITY_TRANSACTION: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 25
FACILITY_COMMONLOG: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 26
FACILITY_VIDEO: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 27
FACILITY_FILTER_MANAGER: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 28
FACILITY_MONITOR: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 29
FACILITY_GRAPHICS_KERNEL: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 30
FACILITY_DRIVER_FRAMEWORK: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 32
FACILITY_FVE_ERROR_CODE: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 33
FACILITY_FWP_ERROR_CODE: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 34
FACILITY_NDIS_ERROR_CODE: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 35
FACILITY_QUIC_ERROR_CODE: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 36
FACILITY_TPM: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 41
FACILITY_RTPM: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 42
FACILITY_HYPERVISOR: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 53
FACILITY_IPSEC: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 54
FACILITY_VIRTUALIZATION: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 55
FACILITY_VOLMGR: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 56
FACILITY_BCD_ERROR_CODE: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 57
FACILITY_WIN32K_NTUSER: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 62
FACILITY_WIN32K_NTGDI: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 63
FACILITY_RESUME_KEY_FILTER: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 64
FACILITY_RDBSS: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 65
FACILITY_BTH_ATT: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 66
FACILITY_SECUREBOOT: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 67
FACILITY_AUDIO_KERNEL: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 68
FACILITY_VSM: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 69
FACILITY_NT_IORING: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 70
FACILITY_VOLSNAP: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 80
FACILITY_SDBUS: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 81
FACILITY_SHARED_VHDX: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 92
FACILITY_SMB: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 93
FACILITY_XVS: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 94
FACILITY_INTERIX: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 153
FACILITY_SPACES: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 231
FACILITY_SECURITY_CORE: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 232
FACILITY_SYSTEM_INTEGRITY: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 233
FACILITY_LICENSING: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 234
FACILITY_PLATFORM_MANIFEST: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 235
FACILITY_APP_EXEC: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 236
FACILITY_MAXIMUM_VALUE: win32more.Windows.Win32.Foundation.NTSTATUS_FACILITY_CODE = 237
NTSTATUS_SEVERITY_CODE = UInt32
STATUS_SEVERITY_SUCCESS: win32more.Windows.Win32.Foundation.NTSTATUS_SEVERITY_CODE = 0
STATUS_SEVERITY_INFORMATIONAL: win32more.Windows.Win32.Foundation.NTSTATUS_SEVERITY_CODE = 1
STATUS_SEVERITY_WARNING: win32more.Windows.Win32.Foundation.NTSTATUS_SEVERITY_CODE = 2
STATUS_SEVERITY_ERROR: win32more.Windows.Win32.Foundation.NTSTATUS_SEVERITY_CODE = 3
OBJECT_ATTRIBUTE_FLAGS = UInt32
OBJ_INHERIT: win32more.Windows.Win32.Foundation.OBJECT_ATTRIBUTE_FLAGS = 2
OBJ_PERMANENT: win32more.Windows.Win32.Foundation.OBJECT_ATTRIBUTE_FLAGS = 16
OBJ_EXCLUSIVE: win32more.Windows.Win32.Foundation.OBJECT_ATTRIBUTE_FLAGS = 32
OBJ_CASE_INSENSITIVE: win32more.Windows.Win32.Foundation.OBJECT_ATTRIBUTE_FLAGS = 64
OBJ_OPENIF: win32more.Windows.Win32.Foundation.OBJECT_ATTRIBUTE_FLAGS = 128
OBJ_OPENLINK: win32more.Windows.Win32.Foundation.OBJECT_ATTRIBUTE_FLAGS = 256
OBJ_KERNEL_HANDLE: win32more.Windows.Win32.Foundation.OBJECT_ATTRIBUTE_FLAGS = 512
OBJ_FORCE_ACCESS_CHECK: win32more.Windows.Win32.Foundation.OBJECT_ATTRIBUTE_FLAGS = 1024
OBJ_IGNORE_IMPERSONATED_DEVICEMAP: win32more.Windows.Win32.Foundation.OBJECT_ATTRIBUTE_FLAGS = 2048
OBJ_DONT_REPARSE: win32more.Windows.Win32.Foundation.OBJECT_ATTRIBUTE_FLAGS = 4096
OBJ_VALID_ATTRIBUTES: win32more.Windows.Win32.Foundation.OBJECT_ATTRIBUTE_FLAGS = 8178
@winfunctype_pointer
def PAPCFUNC(Parameter: UIntPtr) -> Void: ...
class POINT(Structure):
    x: Int32
    y: Int32
class POINTL(Structure):
    x: Int32
    y: Int32
class POINTS(Structure):
    x: Int16
    y: Int16
@winfunctype_pointer
def PROC() -> IntPtr: ...
class PROPERTYKEY(Structure):
    fmtid: Guid
    pid: UInt32
PSTR = Bytes
PWSTR = String
class RECT(Structure):
    left: Int32
    top: Int32
    right: Int32
    bottom: Int32
class RECTL(Structure):
    left: Int32
    top: Int32
    right: Int32
    bottom: Int32
SHANDLE_PTR = IntPtr
class SIZE(Structure):
    cx: Int32
    cy: Int32
class SYSTEMTIME(Structure):
    wYear: UInt16
    wMonth: UInt16
    wDayOfWeek: UInt16
    wDay: UInt16
    wHour: UInt16
    wMinute: UInt16
    wSecond: UInt16
    wMilliseconds: UInt16
class UNICODE_STRING(Structure):
    Length: UInt16
    MaximumLength: UInt16
    Buffer: win32more.Windows.Win32.Foundation.PWSTR
VARIANT_BOOL = Int16
WAIT_EVENT = UInt32
WAIT_OBJECT_0: win32more.Windows.Win32.Foundation.WAIT_EVENT = 0
WAIT_ABANDONED: win32more.Windows.Win32.Foundation.WAIT_EVENT = 128
WAIT_ABANDONED_0: win32more.Windows.Win32.Foundation.WAIT_EVENT = 128
WAIT_IO_COMPLETION: win32more.Windows.Win32.Foundation.WAIT_EVENT = 192
WAIT_TIMEOUT: win32more.Windows.Win32.Foundation.WAIT_EVENT = 258
WAIT_FAILED: win32more.Windows.Win32.Foundation.WAIT_EVENT = 4294967295
WIN32_ERROR = UInt32
NO_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 0
ERROR_EXPECTED_SECTION_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096384
ERROR_BAD_SECTION_NAME_LINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096385
ERROR_SECTION_NAME_TOO_LONG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096386
ERROR_GENERAL_SYNTAX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096387
ERROR_WRONG_INF_STYLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096640
ERROR_SECTION_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096641
ERROR_LINE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096642
ERROR_NO_BACKUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096643
ERROR_NO_ASSOCIATED_CLASS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096896
ERROR_CLASS_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096897
ERROR_DUPLICATE_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096898
ERROR_NO_DRIVER_SELECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096899
ERROR_KEY_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096900
ERROR_INVALID_DEVINST_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096901
ERROR_INVALID_CLASS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096902
ERROR_DEVINST_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096903
ERROR_DEVINFO_NOT_REGISTERED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096904
ERROR_INVALID_REG_PROPERTY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096905
ERROR_NO_INF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096906
ERROR_NO_SUCH_DEVINST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096907
ERROR_CANT_LOAD_CLASS_ICON: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096908
ERROR_INVALID_CLASS_INSTALLER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096909
ERROR_DI_DO_DEFAULT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096910
ERROR_DI_NOFILECOPY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096911
ERROR_INVALID_HWPROFILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096912
ERROR_NO_DEVICE_SELECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096913
ERROR_DEVINFO_LIST_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096914
ERROR_DEVINFO_DATA_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096915
ERROR_DI_BAD_PATH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096916
ERROR_NO_CLASSINSTALL_PARAMS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096917
ERROR_FILEQUEUE_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096918
ERROR_BAD_SERVICE_INSTALLSECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096919
ERROR_NO_CLASS_DRIVER_LIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096920
ERROR_NO_ASSOCIATED_SERVICE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096921
ERROR_NO_DEFAULT_DEVICE_INTERFACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096922
ERROR_DEVICE_INTERFACE_ACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096923
ERROR_DEVICE_INTERFACE_REMOVED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096924
ERROR_BAD_INTERFACE_INSTALLSECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096925
ERROR_NO_SUCH_INTERFACE_CLASS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096926
ERROR_INVALID_REFERENCE_STRING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096927
ERROR_INVALID_MACHINENAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096928
ERROR_REMOTE_COMM_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096929
ERROR_MACHINE_UNAVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096930
ERROR_NO_CONFIGMGR_SERVICES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096931
ERROR_INVALID_PROPPAGE_PROVIDER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096932
ERROR_NO_SUCH_DEVICE_INTERFACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096933
ERROR_DI_POSTPROCESSING_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096934
ERROR_INVALID_COINSTALLER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096935
ERROR_NO_COMPAT_DRIVERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096936
ERROR_NO_DEVICE_ICON: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096937
ERROR_INVALID_INF_LOGCONFIG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096938
ERROR_DI_DONT_INSTALL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096939
ERROR_INVALID_FILTER_DRIVER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096940
ERROR_NON_WINDOWS_NT_DRIVER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096941
ERROR_NON_WINDOWS_DRIVER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096942
ERROR_NO_CATALOG_FOR_OEM_INF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096943
ERROR_DEVINSTALL_QUEUE_NONNATIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096944
ERROR_NOT_DISABLEABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096945
ERROR_CANT_REMOVE_DEVINST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096946
ERROR_INVALID_TARGET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096947
ERROR_DRIVER_NONNATIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096948
ERROR_IN_WOW64: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096949
ERROR_SET_SYSTEM_RESTORE_POINT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096950
ERROR_SCE_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096952
ERROR_UNKNOWN_EXCEPTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096953
ERROR_PNP_REGISTRY_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096954
ERROR_REMOTE_REQUEST_UNSUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096955
ERROR_NOT_AN_INSTALLED_OEM_INF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096956
ERROR_INF_IN_USE_BY_DEVICES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096957
ERROR_DI_FUNCTION_OBSOLETE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096958
ERROR_NO_AUTHENTICODE_CATALOG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096959
ERROR_AUTHENTICODE_DISALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096960
ERROR_AUTHENTICODE_TRUSTED_PUBLISHER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096961
ERROR_AUTHENTICODE_TRUST_NOT_ESTABLISHED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096962
ERROR_AUTHENTICODE_PUBLISHER_NOT_TRUSTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096963
ERROR_SIGNATURE_OSATTRIBUTE_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096964
ERROR_ONLY_VALIDATE_VIA_AUTHENTICODE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096965
ERROR_DEVICE_INSTALLER_NOT_READY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096966
ERROR_DRIVER_STORE_ADD_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096967
ERROR_DEVICE_INSTALL_BLOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096968
ERROR_DRIVER_INSTALL_BLOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096969
ERROR_WRONG_INF_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096970
ERROR_FILE_HASH_NOT_IN_CATALOG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096971
ERROR_DRIVER_STORE_DELETE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096972
ERROR_UNRECOVERABLE_STACK_OVERFLOW: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758097152
ERROR_NO_DEFAULT_INTERFACE_DEVICE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096922
ERROR_INTERFACE_DEVICE_ACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096923
ERROR_INTERFACE_DEVICE_REMOVED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096924
ERROR_NO_SUCH_INTERFACE_DEVICE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758096933
ERROR_NOT_INSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3758100480
ERROR_SUCCESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 0
ERROR_INVALID_FUNCTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1
ERROR_FILE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2
ERROR_PATH_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3
ERROR_TOO_MANY_OPEN_FILES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4
ERROR_ACCESS_DENIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5
ERROR_INVALID_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6
ERROR_ARENA_TRASHED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7
ERROR_NOT_ENOUGH_MEMORY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8
ERROR_INVALID_BLOCK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9
ERROR_BAD_ENVIRONMENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 10
ERROR_BAD_FORMAT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 11
ERROR_INVALID_ACCESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 12
ERROR_INVALID_DATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13
ERROR_OUTOFMEMORY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14
ERROR_INVALID_DRIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15
ERROR_CURRENT_DIRECTORY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 16
ERROR_NOT_SAME_DEVICE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 17
ERROR_NO_MORE_FILES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 18
ERROR_WRITE_PROTECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 19
ERROR_BAD_UNIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 20
ERROR_NOT_READY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 21
ERROR_BAD_COMMAND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 22
ERROR_CRC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 23
ERROR_BAD_LENGTH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 24
ERROR_SEEK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 25
ERROR_NOT_DOS_DISK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 26
ERROR_SECTOR_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 27
ERROR_OUT_OF_PAPER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 28
ERROR_WRITE_FAULT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 29
ERROR_READ_FAULT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 30
ERROR_GEN_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 31
ERROR_SHARING_VIOLATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 32
ERROR_LOCK_VIOLATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 33
ERROR_WRONG_DISK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 34
ERROR_SHARING_BUFFER_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 36
ERROR_HANDLE_EOF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 38
ERROR_HANDLE_DISK_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 39
ERROR_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 50
ERROR_REM_NOT_LIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 51
ERROR_DUP_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 52
ERROR_BAD_NETPATH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 53
ERROR_NETWORK_BUSY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 54
ERROR_DEV_NOT_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 55
ERROR_TOO_MANY_CMDS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 56
ERROR_ADAP_HDW_ERR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 57
ERROR_BAD_NET_RESP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 58
ERROR_UNEXP_NET_ERR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 59
ERROR_BAD_REM_ADAP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 60
ERROR_PRINTQ_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 61
ERROR_NO_SPOOL_SPACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 62
ERROR_PRINT_CANCELLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 63
ERROR_NETNAME_DELETED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 64
ERROR_NETWORK_ACCESS_DENIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 65
ERROR_BAD_DEV_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 66
ERROR_BAD_NET_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 67
ERROR_TOO_MANY_NAMES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 68
ERROR_TOO_MANY_SESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 69
ERROR_SHARING_PAUSED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 70
ERROR_REQ_NOT_ACCEP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 71
ERROR_REDIR_PAUSED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 72
ERROR_FILE_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 80
ERROR_CANNOT_MAKE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 82
ERROR_FAIL_I24: win32more.Windows.Win32.Foundation.WIN32_ERROR = 83
ERROR_OUT_OF_STRUCTURES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 84
ERROR_ALREADY_ASSIGNED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 85
ERROR_INVALID_PASSWORD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 86
ERROR_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 87
ERROR_NET_WRITE_FAULT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 88
ERROR_NO_PROC_SLOTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 89
ERROR_TOO_MANY_SEMAPHORES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 100
ERROR_EXCL_SEM_ALREADY_OWNED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 101
ERROR_SEM_IS_SET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 102
ERROR_TOO_MANY_SEM_REQUESTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 103
ERROR_INVALID_AT_INTERRUPT_TIME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 104
ERROR_SEM_OWNER_DIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 105
ERROR_SEM_USER_LIMIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 106
ERROR_DISK_CHANGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 107
ERROR_DRIVE_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 108
ERROR_BROKEN_PIPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 109
ERROR_OPEN_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 110
ERROR_BUFFER_OVERFLOW: win32more.Windows.Win32.Foundation.WIN32_ERROR = 111
ERROR_DISK_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 112
ERROR_NO_MORE_SEARCH_HANDLES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 113
ERROR_INVALID_TARGET_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 114
ERROR_INVALID_CATEGORY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 117
ERROR_INVALID_VERIFY_SWITCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 118
ERROR_BAD_DRIVER_LEVEL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 119
ERROR_CALL_NOT_IMPLEMENTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 120
ERROR_SEM_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 121
ERROR_INSUFFICIENT_BUFFER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 122
ERROR_INVALID_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 123
ERROR_INVALID_LEVEL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 124
ERROR_NO_VOLUME_LABEL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 125
ERROR_MOD_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 126
ERROR_PROC_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 127
ERROR_WAIT_NO_CHILDREN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 128
ERROR_CHILD_NOT_COMPLETE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 129
ERROR_DIRECT_ACCESS_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 130
ERROR_NEGATIVE_SEEK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 131
ERROR_SEEK_ON_DEVICE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 132
ERROR_IS_JOIN_TARGET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 133
ERROR_IS_JOINED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 134
ERROR_IS_SUBSTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 135
ERROR_NOT_JOINED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 136
ERROR_NOT_SUBSTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 137
ERROR_JOIN_TO_JOIN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 138
ERROR_SUBST_TO_SUBST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 139
ERROR_JOIN_TO_SUBST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 140
ERROR_SUBST_TO_JOIN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 141
ERROR_BUSY_DRIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 142
ERROR_SAME_DRIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 143
ERROR_DIR_NOT_ROOT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 144
ERROR_DIR_NOT_EMPTY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 145
ERROR_IS_SUBST_PATH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 146
ERROR_IS_JOIN_PATH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 147
ERROR_PATH_BUSY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 148
ERROR_IS_SUBST_TARGET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 149
ERROR_SYSTEM_TRACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 150
ERROR_INVALID_EVENT_COUNT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 151
ERROR_TOO_MANY_MUXWAITERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 152
ERROR_INVALID_LIST_FORMAT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 153
ERROR_LABEL_TOO_LONG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 154
ERROR_TOO_MANY_TCBS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 155
ERROR_SIGNAL_REFUSED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 156
ERROR_DISCARDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 157
ERROR_NOT_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 158
ERROR_BAD_THREADID_ADDR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 159
ERROR_BAD_ARGUMENTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 160
ERROR_BAD_PATHNAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 161
ERROR_SIGNAL_PENDING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 162
ERROR_MAX_THRDS_REACHED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 164
ERROR_LOCK_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 167
ERROR_BUSY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 170
ERROR_DEVICE_SUPPORT_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 171
ERROR_CANCEL_VIOLATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 173
ERROR_ATOMIC_LOCKS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 174
ERROR_INVALID_SEGMENT_NUMBER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 180
ERROR_INVALID_ORDINAL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 182
ERROR_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 183
ERROR_INVALID_FLAG_NUMBER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 186
ERROR_SEM_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 187
ERROR_INVALID_STARTING_CODESEG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 188
ERROR_INVALID_STACKSEG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 189
ERROR_INVALID_MODULETYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 190
ERROR_INVALID_EXE_SIGNATURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 191
ERROR_EXE_MARKED_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 192
ERROR_BAD_EXE_FORMAT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 193
ERROR_ITERATED_DATA_EXCEEDS_64k: win32more.Windows.Win32.Foundation.WIN32_ERROR = 194
ERROR_INVALID_MINALLOCSIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 195
ERROR_DYNLINK_FROM_INVALID_RING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 196
ERROR_IOPL_NOT_ENABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 197
ERROR_INVALID_SEGDPL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 198
ERROR_AUTODATASEG_EXCEEDS_64k: win32more.Windows.Win32.Foundation.WIN32_ERROR = 199
ERROR_RING2SEG_MUST_BE_MOVABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 200
ERROR_RELOC_CHAIN_XEEDS_SEGLIM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 201
ERROR_INFLOOP_IN_RELOC_CHAIN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 202
ERROR_ENVVAR_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 203
ERROR_NO_SIGNAL_SENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 205
ERROR_FILENAME_EXCED_RANGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 206
ERROR_RING2_STACK_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 207
ERROR_META_EXPANSION_TOO_LONG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 208
ERROR_INVALID_SIGNAL_NUMBER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 209
ERROR_THREAD_1_INACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 210
ERROR_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 212
ERROR_TOO_MANY_MODULES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 214
ERROR_NESTING_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 215
ERROR_EXE_MACHINE_TYPE_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 216
ERROR_EXE_CANNOT_MODIFY_SIGNED_BINARY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 217
ERROR_EXE_CANNOT_MODIFY_STRONG_SIGNED_BINARY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 218
ERROR_FILE_CHECKED_OUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 220
ERROR_CHECKOUT_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 221
ERROR_BAD_FILE_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 222
ERROR_FILE_TOO_LARGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 223
ERROR_FORMS_AUTH_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 224
ERROR_VIRUS_INFECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 225
ERROR_VIRUS_DELETED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 226
ERROR_PIPE_LOCAL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 229
ERROR_BAD_PIPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 230
ERROR_PIPE_BUSY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 231
ERROR_NO_DATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 232
ERROR_PIPE_NOT_CONNECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 233
ERROR_MORE_DATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 234
ERROR_NO_WORK_DONE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 235
ERROR_VC_DISCONNECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 240
ERROR_INVALID_EA_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 254
ERROR_EA_LIST_INCONSISTENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 255
ERROR_NO_MORE_ITEMS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 259
ERROR_CANNOT_COPY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 266
ERROR_DIRECTORY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 267
ERROR_EAS_DIDNT_FIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 275
ERROR_EA_FILE_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 276
ERROR_EA_TABLE_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 277
ERROR_INVALID_EA_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 278
ERROR_EAS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 282
ERROR_NOT_OWNER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 288
ERROR_TOO_MANY_POSTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 298
ERROR_PARTIAL_COPY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 299
ERROR_OPLOCK_NOT_GRANTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 300
ERROR_INVALID_OPLOCK_PROTOCOL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 301
ERROR_DISK_TOO_FRAGMENTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 302
ERROR_DELETE_PENDING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 303
ERROR_INCOMPATIBLE_WITH_GLOBAL_SHORT_NAME_REGISTRY_SETTING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 304
ERROR_SHORT_NAMES_NOT_ENABLED_ON_VOLUME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 305
ERROR_SECURITY_STREAM_IS_INCONSISTENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 306
ERROR_INVALID_LOCK_RANGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 307
ERROR_IMAGE_SUBSYSTEM_NOT_PRESENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 308
ERROR_NOTIFICATION_GUID_ALREADY_DEFINED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 309
ERROR_INVALID_EXCEPTION_HANDLER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 310
ERROR_DUPLICATE_PRIVILEGES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 311
ERROR_NO_RANGES_PROCESSED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 312
ERROR_NOT_ALLOWED_ON_SYSTEM_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 313
ERROR_DISK_RESOURCES_EXHAUSTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 314
ERROR_INVALID_TOKEN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 315
ERROR_DEVICE_FEATURE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 316
ERROR_MR_MID_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 317
ERROR_SCOPE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 318
ERROR_UNDEFINED_SCOPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 319
ERROR_INVALID_CAP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 320
ERROR_DEVICE_UNREACHABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 321
ERROR_DEVICE_NO_RESOURCES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 322
ERROR_DATA_CHECKSUM_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 323
ERROR_INTERMIXED_KERNEL_EA_OPERATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 324
ERROR_FILE_LEVEL_TRIM_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 326
ERROR_OFFSET_ALIGNMENT_VIOLATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 327
ERROR_INVALID_FIELD_IN_PARAMETER_LIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 328
ERROR_OPERATION_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 329
ERROR_BAD_DEVICE_PATH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 330
ERROR_TOO_MANY_DESCRIPTORS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 331
ERROR_SCRUB_DATA_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 332
ERROR_NOT_REDUNDANT_STORAGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 333
ERROR_RESIDENT_FILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 334
ERROR_COMPRESSED_FILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 335
ERROR_DIRECTORY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 336
ERROR_NOT_READ_FROM_COPY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 337
ERROR_FT_WRITE_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 338
ERROR_FT_DI_SCAN_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 339
ERROR_INVALID_KERNEL_INFO_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 340
ERROR_INVALID_PEP_INFO_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 341
ERROR_OBJECT_NOT_EXTERNALLY_BACKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 342
ERROR_EXTERNAL_BACKING_PROVIDER_UNKNOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 343
ERROR_COMPRESSION_NOT_BENEFICIAL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 344
ERROR_STORAGE_TOPOLOGY_ID_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 345
ERROR_BLOCKED_BY_PARENTAL_CONTROLS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 346
ERROR_BLOCK_TOO_MANY_REFERENCES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 347
ERROR_MARKED_TO_DISALLOW_WRITES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 348
ERROR_ENCLAVE_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 349
ERROR_FAIL_NOACTION_REBOOT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 350
ERROR_FAIL_SHUTDOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 351
ERROR_FAIL_RESTART: win32more.Windows.Win32.Foundation.WIN32_ERROR = 352
ERROR_MAX_SESSIONS_REACHED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 353
ERROR_NETWORK_ACCESS_DENIED_EDP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 354
ERROR_DEVICE_HINT_NAME_BUFFER_TOO_SMALL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 355
ERROR_EDP_POLICY_DENIES_OPERATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 356
ERROR_EDP_DPL_POLICY_CANT_BE_SATISFIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 357
ERROR_CLOUD_FILE_SYNC_ROOT_METADATA_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 358
ERROR_DEVICE_IN_MAINTENANCE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 359
ERROR_NOT_SUPPORTED_ON_DAX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 360
ERROR_DAX_MAPPING_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 361
ERROR_CLOUD_FILE_PROVIDER_NOT_RUNNING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 362
ERROR_CLOUD_FILE_METADATA_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 363
ERROR_CLOUD_FILE_METADATA_TOO_LARGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 364
ERROR_CLOUD_FILE_PROPERTY_BLOB_TOO_LARGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 365
ERROR_CLOUD_FILE_PROPERTY_BLOB_CHECKSUM_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 366
ERROR_CHILD_PROCESS_BLOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 367
ERROR_STORAGE_LOST_DATA_PERSISTENCE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 368
ERROR_FILE_SYSTEM_VIRTUALIZATION_UNAVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 369
ERROR_FILE_SYSTEM_VIRTUALIZATION_METADATA_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 370
ERROR_FILE_SYSTEM_VIRTUALIZATION_BUSY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 371
ERROR_FILE_SYSTEM_VIRTUALIZATION_PROVIDER_UNKNOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 372
ERROR_GDI_HANDLE_LEAK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 373
ERROR_CLOUD_FILE_TOO_MANY_PROPERTY_BLOBS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 374
ERROR_CLOUD_FILE_PROPERTY_VERSION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 375
ERROR_NOT_A_CLOUD_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 376
ERROR_CLOUD_FILE_NOT_IN_SYNC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 377
ERROR_CLOUD_FILE_ALREADY_CONNECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 378
ERROR_CLOUD_FILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 379
ERROR_CLOUD_FILE_INVALID_REQUEST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 380
ERROR_CLOUD_FILE_READ_ONLY_VOLUME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 381
ERROR_CLOUD_FILE_CONNECTED_PROVIDER_ONLY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 382
ERROR_CLOUD_FILE_VALIDATION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 383
ERROR_SMB1_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 384
ERROR_FILE_SYSTEM_VIRTUALIZATION_INVALID_OPERATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 385
ERROR_CLOUD_FILE_AUTHENTICATION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 386
ERROR_CLOUD_FILE_INSUFFICIENT_RESOURCES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 387
ERROR_CLOUD_FILE_NETWORK_UNAVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 388
ERROR_CLOUD_FILE_UNSUCCESSFUL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 389
ERROR_CLOUD_FILE_NOT_UNDER_SYNC_ROOT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 390
ERROR_CLOUD_FILE_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 391
ERROR_CLOUD_FILE_PINNED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 392
ERROR_CLOUD_FILE_REQUEST_ABORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 393
ERROR_CLOUD_FILE_PROPERTY_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 394
ERROR_CLOUD_FILE_ACCESS_DENIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 395
ERROR_CLOUD_FILE_INCOMPATIBLE_HARDLINKS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 396
ERROR_CLOUD_FILE_PROPERTY_LOCK_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 397
ERROR_CLOUD_FILE_REQUEST_CANCELED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 398
ERROR_EXTERNAL_SYSKEY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 399
ERROR_THREAD_MODE_ALREADY_BACKGROUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 400
ERROR_THREAD_MODE_NOT_BACKGROUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 401
ERROR_PROCESS_MODE_ALREADY_BACKGROUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 402
ERROR_PROCESS_MODE_NOT_BACKGROUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 403
ERROR_CLOUD_FILE_PROVIDER_TERMINATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 404
ERROR_NOT_A_CLOUD_SYNC_ROOT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 405
ERROR_FILE_PROTECTED_UNDER_DPL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 406
ERROR_VOLUME_NOT_CLUSTER_ALIGNED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 407
ERROR_NO_PHYSICALLY_ALIGNED_FREE_SPACE_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 408
ERROR_APPX_FILE_NOT_ENCRYPTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 409
ERROR_RWRAW_ENCRYPTED_FILE_NOT_ENCRYPTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 410
ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILEOFFSET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 411
ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILERANGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 412
ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_PARAMETER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 413
ERROR_LINUX_SUBSYSTEM_NOT_PRESENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 414
ERROR_FT_READ_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 415
ERROR_STORAGE_RESERVE_ID_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 416
ERROR_STORAGE_RESERVE_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 417
ERROR_STORAGE_RESERVE_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 418
ERROR_STORAGE_RESERVE_NOT_EMPTY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 419
ERROR_NOT_A_DAX_VOLUME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 420
ERROR_NOT_DAX_MAPPABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 421
ERROR_TIME_SENSITIVE_THREAD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 422
ERROR_DPL_NOT_SUPPORTED_FOR_USER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 423
ERROR_CASE_DIFFERING_NAMES_IN_DIR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 424
ERROR_FILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 425
ERROR_CLOUD_FILE_REQUEST_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 426
ERROR_NO_TASK_QUEUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 427
ERROR_SRC_SRV_DLL_LOAD_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 428
ERROR_NOT_SUPPORTED_WITH_BTT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 429
ERROR_ENCRYPTION_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 430
ERROR_ENCRYPTING_METADATA_DISALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 431
ERROR_CANT_CLEAR_ENCRYPTION_FLAG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 432
ERROR_NO_SUCH_DEVICE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 433
ERROR_CLOUD_FILE_DEHYDRATION_DISALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 434
ERROR_FILE_SNAP_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 435
ERROR_FILE_SNAP_USER_SECTION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 436
ERROR_FILE_SNAP_MODIFY_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 437
ERROR_FILE_SNAP_IO_NOT_COORDINATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 438
ERROR_FILE_SNAP_UNEXPECTED_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 439
ERROR_FILE_SNAP_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 440
ERROR_UNSATISFIED_DEPENDENCIES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 441
ERROR_CASE_SENSITIVE_PATH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 442
ERROR_UNEXPECTED_NTCACHEMANAGER_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 443
ERROR_LINUX_SUBSYSTEM_UPDATE_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 444
ERROR_DLP_POLICY_WARNS_AGAINST_OPERATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 445
ERROR_DLP_POLICY_DENIES_OPERATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 446
ERROR_SECURITY_DENIES_OPERATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 447
ERROR_UNTRUSTED_MOUNT_POINT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 448
ERROR_DLP_POLICY_SILENTLY_FAIL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 449
ERROR_CAPAUTHZ_NOT_DEVUNLOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 450
ERROR_CAPAUTHZ_CHANGE_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 451
ERROR_CAPAUTHZ_NOT_PROVISIONED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 452
ERROR_CAPAUTHZ_NOT_AUTHORIZED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 453
ERROR_CAPAUTHZ_NO_POLICY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 454
ERROR_CAPAUTHZ_DB_CORRUPTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 455
ERROR_CAPAUTHZ_SCCD_INVALID_CATALOG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 456
ERROR_CAPAUTHZ_SCCD_NO_AUTH_ENTITY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 457
ERROR_CAPAUTHZ_SCCD_PARSE_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 458
ERROR_CAPAUTHZ_SCCD_DEV_MODE_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 459
ERROR_CAPAUTHZ_SCCD_NO_CAPABILITY_MATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 460
ERROR_CIMFS_IMAGE_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 470
ERROR_CIMFS_IMAGE_VERSION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 471
ERROR_STORAGE_STACK_ACCESS_DENIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 472
ERROR_INSUFFICIENT_VIRTUAL_ADDR_RESOURCES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 473
ERROR_INDEX_OUT_OF_BOUNDS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 474
ERROR_CLOUD_FILE_US_MESSAGE_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 475
ERROR_NOT_A_DEV_VOLUME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 476
ERROR_FS_GUID_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 477
ERROR_CANT_ATTACH_TO_DEV_VOLUME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 478
ERROR_INVALID_CONFIG_VALUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 479
ERROR_PNP_QUERY_REMOVE_DEVICE_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 480
ERROR_PNP_QUERY_REMOVE_RELATED_DEVICE_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 481
ERROR_PNP_QUERY_REMOVE_UNRELATED_DEVICE_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 482
ERROR_DEVICE_HARDWARE_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 483
ERROR_INVALID_ADDRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 487
ERROR_HAS_SYSTEM_CRITICAL_FILES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 488
ERROR_ENCRYPTED_FILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 489
ERROR_SPARSE_FILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 490
ERROR_PAGEFILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 491
ERROR_VOLUME_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 492
ERROR_NOT_SUPPORTED_WITH_BYPASSIO: win32more.Windows.Win32.Foundation.WIN32_ERROR = 493
ERROR_NO_BYPASSIO_DRIVER_SUPPORT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 494
ERROR_NOT_SUPPORTED_WITH_ENCRYPTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 495
ERROR_NOT_SUPPORTED_WITH_COMPRESSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 496
ERROR_NOT_SUPPORTED_WITH_REPLICATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 497
ERROR_NOT_SUPPORTED_WITH_DEDUPLICATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 498
ERROR_NOT_SUPPORTED_WITH_AUDITING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 499
ERROR_USER_PROFILE_LOAD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 500
ERROR_SESSION_KEY_TOO_SHORT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 501
ERROR_ACCESS_DENIED_APPDATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 502
ERROR_NOT_SUPPORTED_WITH_MONITORING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 503
ERROR_NOT_SUPPORTED_WITH_SNAPSHOT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 504
ERROR_NOT_SUPPORTED_WITH_VIRTUALIZATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 505
ERROR_BYPASSIO_FLT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 506
ERROR_DEVICE_RESET_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 507
ERROR_VOLUME_WRITE_ACCESS_DENIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 508
ERROR_NOT_SUPPORTED_WITH_CACHED_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 509
ERROR_FS_METADATA_INCONSISTENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 510
ERROR_BLOCK_WEAK_REFERENCE_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 511
ERROR_BLOCK_SOURCE_WEAK_REFERENCE_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 512
ERROR_BLOCK_TARGET_WEAK_REFERENCE_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 513
ERROR_BLOCK_SHARED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 514
ERROR_VOLUME_UPGRADE_NOT_NEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 515
ERROR_VOLUME_UPGRADE_PENDING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 516
ERROR_VOLUME_UPGRADE_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 517
ERROR_VOLUME_UPGRADE_DISABLED_TILL_OS_DOWNGRADE_EXPIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 518
ERROR_ARITHMETIC_OVERFLOW: win32more.Windows.Win32.Foundation.WIN32_ERROR = 534
ERROR_PIPE_CONNECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 535
ERROR_PIPE_LISTENING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 536
ERROR_VERIFIER_STOP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 537
ERROR_ABIOS_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 538
ERROR_WX86_WARNING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 539
ERROR_WX86_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 540
ERROR_TIMER_NOT_CANCELED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 541
ERROR_UNWIND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 542
ERROR_BAD_STACK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 543
ERROR_INVALID_UNWIND_TARGET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 544
ERROR_INVALID_PORT_ATTRIBUTES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 545
ERROR_PORT_MESSAGE_TOO_LONG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 546
ERROR_INVALID_QUOTA_LOWER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 547
ERROR_DEVICE_ALREADY_ATTACHED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 548
ERROR_INSTRUCTION_MISALIGNMENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 549
ERROR_PROFILING_NOT_STARTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 550
ERROR_PROFILING_NOT_STOPPED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 551
ERROR_COULD_NOT_INTERPRET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 552
ERROR_PROFILING_AT_LIMIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 553
ERROR_CANT_WAIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 554
ERROR_CANT_TERMINATE_SELF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 555
ERROR_UNEXPECTED_MM_CREATE_ERR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 556
ERROR_UNEXPECTED_MM_MAP_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 557
ERROR_UNEXPECTED_MM_EXTEND_ERR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 558
ERROR_BAD_FUNCTION_TABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 559
ERROR_NO_GUID_TRANSLATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 560
ERROR_INVALID_LDT_SIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 561
ERROR_INVALID_LDT_OFFSET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 563
ERROR_INVALID_LDT_DESCRIPTOR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 564
ERROR_TOO_MANY_THREADS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 565
ERROR_THREAD_NOT_IN_PROCESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 566
ERROR_PAGEFILE_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 567
ERROR_LOGON_SERVER_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 568
ERROR_SYNCHRONIZATION_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 569
ERROR_NET_OPEN_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 570
ERROR_IO_PRIVILEGE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 571
ERROR_CONTROL_C_EXIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 572
ERROR_MISSING_SYSTEMFILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 573
ERROR_UNHANDLED_EXCEPTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 574
ERROR_APP_INIT_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 575
ERROR_PAGEFILE_CREATE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 576
ERROR_INVALID_IMAGE_HASH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 577
ERROR_NO_PAGEFILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 578
ERROR_ILLEGAL_FLOAT_CONTEXT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 579
ERROR_NO_EVENT_PAIR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 580
ERROR_DOMAIN_CTRLR_CONFIG_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 581
ERROR_ILLEGAL_CHARACTER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 582
ERROR_UNDEFINED_CHARACTER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 583
ERROR_FLOPPY_VOLUME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 584
ERROR_BIOS_FAILED_TO_CONNECT_INTERRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 585
ERROR_BACKUP_CONTROLLER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 586
ERROR_MUTANT_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 587
ERROR_FS_DRIVER_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 588
ERROR_CANNOT_LOAD_REGISTRY_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 589
ERROR_DEBUG_ATTACH_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 590
ERROR_SYSTEM_PROCESS_TERMINATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 591
ERROR_DATA_NOT_ACCEPTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 592
ERROR_VDM_HARD_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 593
ERROR_DRIVER_CANCEL_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 594
ERROR_REPLY_MESSAGE_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 595
ERROR_LOST_WRITEBEHIND_DATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 596
ERROR_CLIENT_SERVER_PARAMETERS_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 597
ERROR_NOT_TINY_STREAM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 598
ERROR_STACK_OVERFLOW_READ: win32more.Windows.Win32.Foundation.WIN32_ERROR = 599
ERROR_CONVERT_TO_LARGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 600
ERROR_FOUND_OUT_OF_SCOPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 601
ERROR_ALLOCATE_BUCKET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 602
ERROR_MARSHALL_OVERFLOW: win32more.Windows.Win32.Foundation.WIN32_ERROR = 603
ERROR_INVALID_VARIANT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 604
ERROR_BAD_COMPRESSION_BUFFER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 605
ERROR_AUDIT_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 606
ERROR_TIMER_RESOLUTION_NOT_SET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 607
ERROR_INSUFFICIENT_LOGON_INFO: win32more.Windows.Win32.Foundation.WIN32_ERROR = 608
ERROR_BAD_DLL_ENTRYPOINT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 609
ERROR_BAD_SERVICE_ENTRYPOINT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 610
ERROR_IP_ADDRESS_CONFLICT1: win32more.Windows.Win32.Foundation.WIN32_ERROR = 611
ERROR_IP_ADDRESS_CONFLICT2: win32more.Windows.Win32.Foundation.WIN32_ERROR = 612
ERROR_REGISTRY_QUOTA_LIMIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 613
ERROR_NO_CALLBACK_ACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 614
ERROR_PWD_TOO_SHORT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 615
ERROR_PWD_TOO_RECENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 616
ERROR_PWD_HISTORY_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 617
ERROR_UNSUPPORTED_COMPRESSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 618
ERROR_INVALID_HW_PROFILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 619
ERROR_INVALID_PLUGPLAY_DEVICE_PATH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 620
ERROR_QUOTA_LIST_INCONSISTENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 621
ERROR_EVALUATION_EXPIRATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 622
ERROR_ILLEGAL_DLL_RELOCATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 623
ERROR_DLL_INIT_FAILED_LOGOFF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 624
ERROR_VALIDATE_CONTINUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 625
ERROR_NO_MORE_MATCHES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 626
ERROR_RANGE_LIST_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 627
ERROR_SERVER_SID_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 628
ERROR_CANT_ENABLE_DENY_ONLY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 629
ERROR_FLOAT_MULTIPLE_FAULTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 630
ERROR_FLOAT_MULTIPLE_TRAPS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 631
ERROR_NOINTERFACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 632
ERROR_DRIVER_FAILED_SLEEP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 633
ERROR_CORRUPT_SYSTEM_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 634
ERROR_COMMITMENT_MINIMUM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 635
ERROR_PNP_RESTART_ENUMERATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 636
ERROR_SYSTEM_IMAGE_BAD_SIGNATURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 637
ERROR_PNP_REBOOT_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 638
ERROR_INSUFFICIENT_POWER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 639
ERROR_MULTIPLE_FAULT_VIOLATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 640
ERROR_SYSTEM_SHUTDOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 641
ERROR_PORT_NOT_SET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 642
ERROR_DS_VERSION_CHECK_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 643
ERROR_RANGE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 644
ERROR_NOT_SAFE_MODE_DRIVER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 646
ERROR_FAILED_DRIVER_ENTRY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 647
ERROR_DEVICE_ENUMERATION_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 648
ERROR_MOUNT_POINT_NOT_RESOLVED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 649
ERROR_INVALID_DEVICE_OBJECT_PARAMETER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 650
ERROR_MCA_OCCURED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 651
ERROR_DRIVER_DATABASE_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 652
ERROR_SYSTEM_HIVE_TOO_LARGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 653
ERROR_DRIVER_FAILED_PRIOR_UNLOAD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 654
ERROR_VOLSNAP_PREPARE_HIBERNATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 655
ERROR_HIBERNATION_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 656
ERROR_PWD_TOO_LONG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 657
ERROR_FILE_SYSTEM_LIMITATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 665
ERROR_ASSERTION_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 668
ERROR_ACPI_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 669
ERROR_WOW_ASSERTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 670
ERROR_PNP_BAD_MPS_TABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 671
ERROR_PNP_TRANSLATION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 672
ERROR_PNP_IRQ_TRANSLATION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 673
ERROR_PNP_INVALID_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 674
ERROR_WAKE_SYSTEM_DEBUGGER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 675
ERROR_HANDLES_CLOSED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 676
ERROR_EXTRANEOUS_INFORMATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 677
ERROR_RXACT_COMMIT_NECESSARY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 678
ERROR_MEDIA_CHECK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 679
ERROR_GUID_SUBSTITUTION_MADE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 680
ERROR_STOPPED_ON_SYMLINK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 681
ERROR_LONGJUMP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 682
ERROR_PLUGPLAY_QUERY_VETOED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 683
ERROR_UNWIND_CONSOLIDATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 684
ERROR_REGISTRY_HIVE_RECOVERED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 685
ERROR_DLL_MIGHT_BE_INSECURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 686
ERROR_DLL_MIGHT_BE_INCOMPATIBLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 687
ERROR_DBG_EXCEPTION_NOT_HANDLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 688
ERROR_DBG_REPLY_LATER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 689
ERROR_DBG_UNABLE_TO_PROVIDE_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 690
ERROR_DBG_TERMINATE_THREAD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 691
ERROR_DBG_TERMINATE_PROCESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 692
ERROR_DBG_CONTROL_C: win32more.Windows.Win32.Foundation.WIN32_ERROR = 693
ERROR_DBG_PRINTEXCEPTION_C: win32more.Windows.Win32.Foundation.WIN32_ERROR = 694
ERROR_DBG_RIPEXCEPTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 695
ERROR_DBG_CONTROL_BREAK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 696
ERROR_DBG_COMMAND_EXCEPTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 697
ERROR_OBJECT_NAME_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 698
ERROR_THREAD_WAS_SUSPENDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 699
ERROR_IMAGE_NOT_AT_BASE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 700
ERROR_RXACT_STATE_CREATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 701
ERROR_SEGMENT_NOTIFICATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 702
ERROR_BAD_CURRENT_DIRECTORY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 703
ERROR_FT_READ_RECOVERY_FROM_BACKUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 704
ERROR_FT_WRITE_RECOVERY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 705
ERROR_IMAGE_MACHINE_TYPE_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 706
ERROR_RECEIVE_PARTIAL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 707
ERROR_RECEIVE_EXPEDITED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 708
ERROR_RECEIVE_PARTIAL_EXPEDITED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 709
ERROR_EVENT_DONE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 710
ERROR_EVENT_PENDING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 711
ERROR_CHECKING_FILE_SYSTEM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 712
ERROR_FATAL_APP_EXIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 713
ERROR_PREDEFINED_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 714
ERROR_WAS_UNLOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 715
ERROR_SERVICE_NOTIFICATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 716
ERROR_WAS_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 717
ERROR_LOG_HARD_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 718
ERROR_ALREADY_WIN32: win32more.Windows.Win32.Foundation.WIN32_ERROR = 719
ERROR_IMAGE_MACHINE_TYPE_MISMATCH_EXE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 720
ERROR_NO_YIELD_PERFORMED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 721
ERROR_TIMER_RESUME_IGNORED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 722
ERROR_ARBITRATION_UNHANDLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 723
ERROR_CARDBUS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 724
ERROR_MP_PROCESSOR_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 725
ERROR_HIBERNATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 726
ERROR_RESUME_HIBERNATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 727
ERROR_FIRMWARE_UPDATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 728
ERROR_DRIVERS_LEAKING_LOCKED_PAGES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 729
ERROR_WAKE_SYSTEM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 730
ERROR_WAIT_1: win32more.Windows.Win32.Foundation.WIN32_ERROR = 731
ERROR_WAIT_2: win32more.Windows.Win32.Foundation.WIN32_ERROR = 732
ERROR_WAIT_3: win32more.Windows.Win32.Foundation.WIN32_ERROR = 733
ERROR_WAIT_63: win32more.Windows.Win32.Foundation.WIN32_ERROR = 734
ERROR_ABANDONED_WAIT_0: win32more.Windows.Win32.Foundation.WIN32_ERROR = 735
ERROR_ABANDONED_WAIT_63: win32more.Windows.Win32.Foundation.WIN32_ERROR = 736
ERROR_USER_APC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 737
ERROR_KERNEL_APC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 738
ERROR_ALERTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 739
ERROR_ELEVATION_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 740
ERROR_REPARSE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 741
ERROR_OPLOCK_BREAK_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 742
ERROR_VOLUME_MOUNTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 743
ERROR_RXACT_COMMITTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 744
ERROR_NOTIFY_CLEANUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 745
ERROR_PRIMARY_TRANSPORT_CONNECT_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 746
ERROR_PAGE_FAULT_TRANSITION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 747
ERROR_PAGE_FAULT_DEMAND_ZERO: win32more.Windows.Win32.Foundation.WIN32_ERROR = 748
ERROR_PAGE_FAULT_COPY_ON_WRITE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 749
ERROR_PAGE_FAULT_GUARD_PAGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 750
ERROR_PAGE_FAULT_PAGING_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 751
ERROR_CACHE_PAGE_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 752
ERROR_CRASH_DUMP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 753
ERROR_BUFFER_ALL_ZEROS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 754
ERROR_REPARSE_OBJECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 755
ERROR_RESOURCE_REQUIREMENTS_CHANGED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 756
ERROR_TRANSLATION_COMPLETE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 757
ERROR_NOTHING_TO_TERMINATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 758
ERROR_PROCESS_NOT_IN_JOB: win32more.Windows.Win32.Foundation.WIN32_ERROR = 759
ERROR_PROCESS_IN_JOB: win32more.Windows.Win32.Foundation.WIN32_ERROR = 760
ERROR_VOLSNAP_HIBERNATE_READY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 761
ERROR_FSFILTER_OP_COMPLETED_SUCCESSFULLY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 762
ERROR_INTERRUPT_VECTOR_ALREADY_CONNECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 763
ERROR_INTERRUPT_STILL_CONNECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 764
ERROR_WAIT_FOR_OPLOCK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 765
ERROR_DBG_EXCEPTION_HANDLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 766
ERROR_DBG_CONTINUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 767
ERROR_CALLBACK_POP_STACK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 768
ERROR_COMPRESSION_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 769
ERROR_CANTFETCHBACKWARDS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 770
ERROR_CANTSCROLLBACKWARDS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 771
ERROR_ROWSNOTRELEASED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 772
ERROR_BAD_ACCESSOR_FLAGS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 773
ERROR_ERRORS_ENCOUNTERED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 774
ERROR_NOT_CAPABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 775
ERROR_REQUEST_OUT_OF_SEQUENCE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 776
ERROR_VERSION_PARSE_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 777
ERROR_BADSTARTPOSITION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 778
ERROR_MEMORY_HARDWARE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 779
ERROR_DISK_REPAIR_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 780
ERROR_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 781
ERROR_SYSTEM_POWERSTATE_TRANSITION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 782
ERROR_SYSTEM_POWERSTATE_COMPLEX_TRANSITION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 783
ERROR_MCA_EXCEPTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 784
ERROR_ACCESS_AUDIT_BY_POLICY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 785
ERROR_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 786
ERROR_ABANDON_HIBERFILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 787
ERROR_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 788
ERROR_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 789
ERROR_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 790
ERROR_BAD_MCFG_TABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 791
ERROR_DISK_REPAIR_REDIRECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 792
ERROR_DISK_REPAIR_UNSUCCESSFUL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 793
ERROR_CORRUPT_LOG_OVERFULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 794
ERROR_CORRUPT_LOG_CORRUPTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 795
ERROR_CORRUPT_LOG_UNAVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 796
ERROR_CORRUPT_LOG_DELETED_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 797
ERROR_CORRUPT_LOG_CLEARED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 798
ERROR_ORPHAN_NAME_EXHAUSTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 799
ERROR_OPLOCK_SWITCHED_TO_NEW_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 800
ERROR_CANNOT_GRANT_REQUESTED_OPLOCK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 801
ERROR_CANNOT_BREAK_OPLOCK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 802
ERROR_OPLOCK_HANDLE_CLOSED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 803
ERROR_NO_ACE_CONDITION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 804
ERROR_INVALID_ACE_CONDITION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 805
ERROR_FILE_HANDLE_REVOKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 806
ERROR_IMAGE_AT_DIFFERENT_BASE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 807
ERROR_ENCRYPTED_IO_NOT_POSSIBLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 808
ERROR_FILE_METADATA_OPTIMIZATION_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 809
ERROR_QUOTA_ACTIVITY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 810
ERROR_HANDLE_REVOKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 811
ERROR_CALLBACK_INVOKE_INLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 812
ERROR_CPU_SET_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 813
ERROR_ENCLAVE_NOT_TERMINATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 814
ERROR_ENCLAVE_VIOLATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 815
ERROR_SERVER_TRANSPORT_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 816
ERROR_CERTIFICATE_VALIDATION_PREFERENCE_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 817
ERROR_FT_READ_FROM_COPY_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 818
ERROR_SECTION_DIRECT_MAP_ONLY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 819
ERROR_EA_ACCESS_DENIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 994
ERROR_OPERATION_ABORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 995
ERROR_IO_INCOMPLETE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 996
ERROR_IO_PENDING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 997
ERROR_NOACCESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 998
ERROR_SWAPERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 999
ERROR_STACK_OVERFLOW: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1001
ERROR_INVALID_MESSAGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1002
ERROR_CAN_NOT_COMPLETE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1003
ERROR_INVALID_FLAGS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1004
ERROR_UNRECOGNIZED_VOLUME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1005
ERROR_FILE_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1006
ERROR_FULLSCREEN_MODE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1007
ERROR_NO_TOKEN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1008
ERROR_BADDB: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1009
ERROR_BADKEY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1010
ERROR_CANTOPEN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1011
ERROR_CANTREAD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1012
ERROR_CANTWRITE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1013
ERROR_REGISTRY_RECOVERED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1014
ERROR_REGISTRY_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1015
ERROR_REGISTRY_IO_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1016
ERROR_NOT_REGISTRY_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1017
ERROR_KEY_DELETED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1018
ERROR_NO_LOG_SPACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1019
ERROR_KEY_HAS_CHILDREN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1020
ERROR_CHILD_MUST_BE_VOLATILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1021
ERROR_NOTIFY_ENUM_DIR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1022
ERROR_DEPENDENT_SERVICES_RUNNING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1051
ERROR_INVALID_SERVICE_CONTROL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1052
ERROR_SERVICE_REQUEST_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1053
ERROR_SERVICE_NO_THREAD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1054
ERROR_SERVICE_DATABASE_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1055
ERROR_SERVICE_ALREADY_RUNNING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1056
ERROR_INVALID_SERVICE_ACCOUNT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1057
ERROR_SERVICE_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1058
ERROR_CIRCULAR_DEPENDENCY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1059
ERROR_SERVICE_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1060
ERROR_SERVICE_CANNOT_ACCEPT_CTRL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1061
ERROR_SERVICE_NOT_ACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1062
ERROR_FAILED_SERVICE_CONTROLLER_CONNECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1063
ERROR_EXCEPTION_IN_SERVICE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1064
ERROR_DATABASE_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1065
ERROR_SERVICE_SPECIFIC_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1066
ERROR_PROCESS_ABORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1067
ERROR_SERVICE_DEPENDENCY_FAIL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1068
ERROR_SERVICE_LOGON_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1069
ERROR_SERVICE_START_HANG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1070
ERROR_INVALID_SERVICE_LOCK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1071
ERROR_SERVICE_MARKED_FOR_DELETE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1072
ERROR_SERVICE_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1073
ERROR_ALREADY_RUNNING_LKG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1074
ERROR_SERVICE_DEPENDENCY_DELETED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1075
ERROR_BOOT_ALREADY_ACCEPTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1076
ERROR_SERVICE_NEVER_STARTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1077
ERROR_DUPLICATE_SERVICE_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1078
ERROR_DIFFERENT_SERVICE_ACCOUNT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1079
ERROR_CANNOT_DETECT_DRIVER_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1080
ERROR_CANNOT_DETECT_PROCESS_ABORT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1081
ERROR_NO_RECOVERY_PROGRAM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1082
ERROR_SERVICE_NOT_IN_EXE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1083
ERROR_NOT_SAFEBOOT_SERVICE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1084
ERROR_END_OF_MEDIA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1100
ERROR_FILEMARK_DETECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1101
ERROR_BEGINNING_OF_MEDIA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1102
ERROR_SETMARK_DETECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1103
ERROR_NO_DATA_DETECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1104
ERROR_PARTITION_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1105
ERROR_INVALID_BLOCK_LENGTH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1106
ERROR_DEVICE_NOT_PARTITIONED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1107
ERROR_UNABLE_TO_LOCK_MEDIA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1108
ERROR_UNABLE_TO_UNLOAD_MEDIA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1109
ERROR_MEDIA_CHANGED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1110
ERROR_BUS_RESET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1111
ERROR_NO_MEDIA_IN_DRIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1112
ERROR_NO_UNICODE_TRANSLATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1113
ERROR_DLL_INIT_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1114
ERROR_SHUTDOWN_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1115
ERROR_NO_SHUTDOWN_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1116
ERROR_IO_DEVICE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1117
ERROR_SERIAL_NO_DEVICE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1118
ERROR_IRQ_BUSY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1119
ERROR_MORE_WRITES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1120
ERROR_COUNTER_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1121
ERROR_FLOPPY_ID_MARK_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1122
ERROR_FLOPPY_WRONG_CYLINDER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1123
ERROR_FLOPPY_UNKNOWN_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1124
ERROR_FLOPPY_BAD_REGISTERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1125
ERROR_DISK_RECALIBRATE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1126
ERROR_DISK_OPERATION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1127
ERROR_DISK_RESET_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1128
ERROR_EOM_OVERFLOW: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1129
ERROR_NOT_ENOUGH_SERVER_MEMORY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1130
ERROR_POSSIBLE_DEADLOCK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1131
ERROR_MAPPED_ALIGNMENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1132
ERROR_SET_POWER_STATE_VETOED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1140
ERROR_SET_POWER_STATE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1141
ERROR_TOO_MANY_LINKS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1142
ERROR_OLD_WIN_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1150
ERROR_APP_WRONG_OS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1151
ERROR_SINGLE_INSTANCE_APP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1152
ERROR_RMODE_APP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1153
ERROR_INVALID_DLL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1154
ERROR_NO_ASSOCIATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1155
ERROR_DDE_FAIL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1156
ERROR_DLL_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1157
ERROR_NO_MORE_USER_HANDLES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1158
ERROR_MESSAGE_SYNC_ONLY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1159
ERROR_SOURCE_ELEMENT_EMPTY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1160
ERROR_DESTINATION_ELEMENT_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1161
ERROR_ILLEGAL_ELEMENT_ADDRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1162
ERROR_MAGAZINE_NOT_PRESENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1163
ERROR_DEVICE_REINITIALIZATION_NEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1164
ERROR_DEVICE_REQUIRES_CLEANING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1165
ERROR_DEVICE_DOOR_OPEN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1166
ERROR_DEVICE_NOT_CONNECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1167
ERROR_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1168
ERROR_NO_MATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1169
ERROR_SET_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1170
ERROR_POINT_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1171
ERROR_NO_TRACKING_SERVICE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1172
ERROR_NO_VOLUME_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1173
ERROR_UNABLE_TO_REMOVE_REPLACED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1175
ERROR_UNABLE_TO_MOVE_REPLACEMENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1176
ERROR_UNABLE_TO_MOVE_REPLACEMENT_2: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1177
ERROR_JOURNAL_DELETE_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1178
ERROR_JOURNAL_NOT_ACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1179
ERROR_POTENTIAL_FILE_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1180
ERROR_JOURNAL_ENTRY_DELETED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1181
ERROR_PARTITION_TERMINATING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1184
ERROR_SHUTDOWN_IS_SCHEDULED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1190
ERROR_SHUTDOWN_USERS_LOGGED_ON: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1191
ERROR_SHUTDOWN_DISKS_NOT_IN_MAINTENANCE_MODE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1192
ERROR_BAD_DEVICE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1200
ERROR_CONNECTION_UNAVAIL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1201
ERROR_DEVICE_ALREADY_REMEMBERED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1202
ERROR_NO_NET_OR_BAD_PATH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1203
ERROR_BAD_PROVIDER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1204
ERROR_CANNOT_OPEN_PROFILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1205
ERROR_BAD_PROFILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1206
ERROR_NOT_CONTAINER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1207
ERROR_EXTENDED_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1208
ERROR_INVALID_GROUPNAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1209
ERROR_INVALID_COMPUTERNAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1210
ERROR_INVALID_EVENTNAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1211
ERROR_INVALID_DOMAINNAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1212
ERROR_INVALID_SERVICENAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1213
ERROR_INVALID_NETNAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1214
ERROR_INVALID_SHARENAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1215
ERROR_INVALID_PASSWORDNAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1216
ERROR_INVALID_MESSAGENAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1217
ERROR_INVALID_MESSAGEDEST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1218
ERROR_SESSION_CREDENTIAL_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1219
ERROR_REMOTE_SESSION_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1220
ERROR_DUP_DOMAINNAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1221
ERROR_NO_NETWORK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1222
ERROR_CANCELLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1223
ERROR_USER_MAPPED_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1224
ERROR_CONNECTION_REFUSED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1225
ERROR_GRACEFUL_DISCONNECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1226
ERROR_ADDRESS_ALREADY_ASSOCIATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1227
ERROR_ADDRESS_NOT_ASSOCIATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1228
ERROR_CONNECTION_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1229
ERROR_CONNECTION_ACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1230
ERROR_NETWORK_UNREACHABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1231
ERROR_HOST_UNREACHABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1232
ERROR_PROTOCOL_UNREACHABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1233
ERROR_PORT_UNREACHABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1234
ERROR_REQUEST_ABORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1235
ERROR_CONNECTION_ABORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1236
ERROR_RETRY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1237
ERROR_CONNECTION_COUNT_LIMIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1238
ERROR_LOGIN_TIME_RESTRICTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1239
ERROR_LOGIN_WKSTA_RESTRICTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1240
ERROR_INCORRECT_ADDRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1241
ERROR_ALREADY_REGISTERED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1242
ERROR_SERVICE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1243
ERROR_NOT_AUTHENTICATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1244
ERROR_NOT_LOGGED_ON: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1245
ERROR_CONTINUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1246
ERROR_ALREADY_INITIALIZED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1247
ERROR_NO_MORE_DEVICES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1248
ERROR_NO_SUCH_SITE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1249
ERROR_DOMAIN_CONTROLLER_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1250
ERROR_ONLY_IF_CONNECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1251
ERROR_OVERRIDE_NOCHANGES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1252
ERROR_BAD_USER_PROFILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1253
ERROR_NOT_SUPPORTED_ON_SBS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1254
ERROR_SERVER_SHUTDOWN_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1255
ERROR_HOST_DOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1256
ERROR_NON_ACCOUNT_SID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1257
ERROR_NON_DOMAIN_SID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1258
ERROR_APPHELP_BLOCK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1259
ERROR_ACCESS_DISABLED_BY_POLICY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1260
ERROR_REG_NAT_CONSUMPTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1261
ERROR_CSCSHARE_OFFLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1262
ERROR_PKINIT_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1263
ERROR_SMARTCARD_SUBSYSTEM_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1264
ERROR_DOWNGRADE_DETECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1265
ERROR_MACHINE_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1271
ERROR_SMB_GUEST_LOGON_BLOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1272
ERROR_CALLBACK_SUPPLIED_INVALID_DATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1273
ERROR_SYNC_FOREGROUND_REFRESH_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1274
ERROR_DRIVER_BLOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1275
ERROR_INVALID_IMPORT_OF_NON_DLL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1276
ERROR_ACCESS_DISABLED_WEBBLADE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1277
ERROR_ACCESS_DISABLED_WEBBLADE_TAMPER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1278
ERROR_RECOVERY_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1279
ERROR_ALREADY_FIBER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1280
ERROR_ALREADY_THREAD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1281
ERROR_STACK_BUFFER_OVERRUN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1282
ERROR_PARAMETER_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1283
ERROR_DEBUGGER_INACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1284
ERROR_DELAY_LOAD_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1285
ERROR_VDM_DISALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1286
ERROR_UNIDENTIFIED_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1287
ERROR_INVALID_CRUNTIME_PARAMETER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1288
ERROR_BEYOND_VDL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1289
ERROR_INCOMPATIBLE_SERVICE_SID_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1290
ERROR_DRIVER_PROCESS_TERMINATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1291
ERROR_IMPLEMENTATION_LIMIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1292
ERROR_PROCESS_IS_PROTECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1293
ERROR_SERVICE_NOTIFY_CLIENT_LAGGING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1294
ERROR_DISK_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1295
ERROR_CONTENT_BLOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1296
ERROR_INCOMPATIBLE_SERVICE_PRIVILEGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1297
ERROR_APP_HANG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1298
ERROR_INVALID_LABEL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1299
ERROR_NOT_ALL_ASSIGNED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1300
ERROR_SOME_NOT_MAPPED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1301
ERROR_NO_QUOTAS_FOR_ACCOUNT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1302
ERROR_LOCAL_USER_SESSION_KEY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1303
ERROR_NULL_LM_PASSWORD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1304
ERROR_UNKNOWN_REVISION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1305
ERROR_REVISION_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1306
ERROR_INVALID_OWNER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1307
ERROR_INVALID_PRIMARY_GROUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1308
ERROR_NO_IMPERSONATION_TOKEN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1309
ERROR_CANT_DISABLE_MANDATORY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1310
ERROR_NO_LOGON_SERVERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1311
ERROR_NO_SUCH_LOGON_SESSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1312
ERROR_NO_SUCH_PRIVILEGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1313
ERROR_PRIVILEGE_NOT_HELD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1314
ERROR_INVALID_ACCOUNT_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1315
ERROR_USER_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1316
ERROR_NO_SUCH_USER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1317
ERROR_GROUP_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1318
ERROR_NO_SUCH_GROUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1319
ERROR_MEMBER_IN_GROUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1320
ERROR_MEMBER_NOT_IN_GROUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1321
ERROR_LAST_ADMIN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1322
ERROR_WRONG_PASSWORD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1323
ERROR_ILL_FORMED_PASSWORD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1324
ERROR_PASSWORD_RESTRICTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1325
ERROR_LOGON_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1326
ERROR_ACCOUNT_RESTRICTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1327
ERROR_INVALID_LOGON_HOURS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1328
ERROR_INVALID_WORKSTATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1329
ERROR_PASSWORD_EXPIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1330
ERROR_ACCOUNT_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1331
ERROR_NONE_MAPPED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1332
ERROR_TOO_MANY_LUIDS_REQUESTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1333
ERROR_LUIDS_EXHAUSTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1334
ERROR_INVALID_SUB_AUTHORITY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1335
ERROR_INVALID_ACL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1336
ERROR_INVALID_SID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1337
ERROR_INVALID_SECURITY_DESCR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1338
ERROR_BAD_INHERITANCE_ACL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1340
ERROR_SERVER_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1341
ERROR_SERVER_NOT_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1342
ERROR_INVALID_ID_AUTHORITY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1343
ERROR_ALLOTTED_SPACE_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1344
ERROR_INVALID_GROUP_ATTRIBUTES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1345
ERROR_BAD_IMPERSONATION_LEVEL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1346
ERROR_CANT_OPEN_ANONYMOUS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1347
ERROR_BAD_VALIDATION_CLASS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1348
ERROR_BAD_TOKEN_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1349
ERROR_NO_SECURITY_ON_OBJECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1350
ERROR_CANT_ACCESS_DOMAIN_INFO: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1351
ERROR_INVALID_SERVER_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1352
ERROR_INVALID_DOMAIN_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1353
ERROR_INVALID_DOMAIN_ROLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1354
ERROR_NO_SUCH_DOMAIN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1355
ERROR_DOMAIN_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1356
ERROR_DOMAIN_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1357
ERROR_INTERNAL_DB_CORRUPTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1358
ERROR_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1359
ERROR_GENERIC_NOT_MAPPED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1360
ERROR_BAD_DESCRIPTOR_FORMAT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1361
ERROR_NOT_LOGON_PROCESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1362
ERROR_LOGON_SESSION_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1363
ERROR_NO_SUCH_PACKAGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1364
ERROR_BAD_LOGON_SESSION_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1365
ERROR_LOGON_SESSION_COLLISION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1366
ERROR_INVALID_LOGON_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1367
ERROR_CANNOT_IMPERSONATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1368
ERROR_RXACT_INVALID_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1369
ERROR_RXACT_COMMIT_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1370
ERROR_SPECIAL_ACCOUNT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1371
ERROR_SPECIAL_GROUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1372
ERROR_SPECIAL_USER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1373
ERROR_MEMBERS_PRIMARY_GROUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1374
ERROR_TOKEN_ALREADY_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1375
ERROR_NO_SUCH_ALIAS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1376
ERROR_MEMBER_NOT_IN_ALIAS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1377
ERROR_MEMBER_IN_ALIAS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1378
ERROR_ALIAS_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1379
ERROR_LOGON_NOT_GRANTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1380
ERROR_TOO_MANY_SECRETS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1381
ERROR_SECRET_TOO_LONG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1382
ERROR_INTERNAL_DB_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1383
ERROR_TOO_MANY_CONTEXT_IDS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1384
ERROR_LOGON_TYPE_NOT_GRANTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1385
ERROR_NT_CROSS_ENCRYPTION_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1386
ERROR_NO_SUCH_MEMBER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1387
ERROR_INVALID_MEMBER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1388
ERROR_TOO_MANY_SIDS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1389
ERROR_LM_CROSS_ENCRYPTION_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1390
ERROR_NO_INHERITANCE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1391
ERROR_FILE_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1392
ERROR_DISK_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1393
ERROR_NO_USER_SESSION_KEY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1394
ERROR_LICENSE_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1395
ERROR_WRONG_TARGET_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1396
ERROR_MUTUAL_AUTH_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1397
ERROR_TIME_SKEW: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1398
ERROR_CURRENT_DOMAIN_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1399
ERROR_INVALID_WINDOW_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1400
ERROR_INVALID_MENU_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1401
ERROR_INVALID_CURSOR_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1402
ERROR_INVALID_ACCEL_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1403
ERROR_INVALID_HOOK_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1404
ERROR_INVALID_DWP_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1405
ERROR_TLW_WITH_WSCHILD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1406
ERROR_CANNOT_FIND_WND_CLASS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1407
ERROR_WINDOW_OF_OTHER_THREAD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1408
ERROR_HOTKEY_ALREADY_REGISTERED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1409
ERROR_CLASS_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1410
ERROR_CLASS_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1411
ERROR_CLASS_HAS_WINDOWS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1412
ERROR_INVALID_INDEX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1413
ERROR_INVALID_ICON_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1414
ERROR_PRIVATE_DIALOG_INDEX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1415
ERROR_LISTBOX_ID_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1416
ERROR_NO_WILDCARD_CHARACTERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1417
ERROR_CLIPBOARD_NOT_OPEN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1418
ERROR_HOTKEY_NOT_REGISTERED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1419
ERROR_WINDOW_NOT_DIALOG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1420
ERROR_CONTROL_ID_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1421
ERROR_INVALID_COMBOBOX_MESSAGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1422
ERROR_WINDOW_NOT_COMBOBOX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1423
ERROR_INVALID_EDIT_HEIGHT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1424
ERROR_DC_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1425
ERROR_INVALID_HOOK_FILTER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1426
ERROR_INVALID_FILTER_PROC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1427
ERROR_HOOK_NEEDS_HMOD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1428
ERROR_GLOBAL_ONLY_HOOK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1429
ERROR_JOURNAL_HOOK_SET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1430
ERROR_HOOK_NOT_INSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1431
ERROR_INVALID_LB_MESSAGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1432
ERROR_SETCOUNT_ON_BAD_LB: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1433
ERROR_LB_WITHOUT_TABSTOPS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1434
ERROR_DESTROY_OBJECT_OF_OTHER_THREAD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1435
ERROR_CHILD_WINDOW_MENU: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1436
ERROR_NO_SYSTEM_MENU: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1437
ERROR_INVALID_MSGBOX_STYLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1438
ERROR_INVALID_SPI_VALUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1439
ERROR_SCREEN_ALREADY_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1440
ERROR_HWNDS_HAVE_DIFF_PARENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1441
ERROR_NOT_CHILD_WINDOW: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1442
ERROR_INVALID_GW_COMMAND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1443
ERROR_INVALID_THREAD_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1444
ERROR_NON_MDICHILD_WINDOW: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1445
ERROR_POPUP_ALREADY_ACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1446
ERROR_NO_SCROLLBARS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1447
ERROR_INVALID_SCROLLBAR_RANGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1448
ERROR_INVALID_SHOWWIN_COMMAND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1449
ERROR_NO_SYSTEM_RESOURCES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1450
ERROR_NONPAGED_SYSTEM_RESOURCES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1451
ERROR_PAGED_SYSTEM_RESOURCES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1452
ERROR_WORKING_SET_QUOTA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1453
ERROR_PAGEFILE_QUOTA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1454
ERROR_COMMITMENT_LIMIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1455
ERROR_MENU_ITEM_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1456
ERROR_INVALID_KEYBOARD_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1457
ERROR_HOOK_TYPE_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1458
ERROR_REQUIRES_INTERACTIVE_WINDOWSTATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1459
ERROR_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1460
ERROR_INVALID_MONITOR_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1461
ERROR_INCORRECT_SIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1462
ERROR_SYMLINK_CLASS_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1463
ERROR_SYMLINK_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1464
ERROR_XML_PARSE_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1465
ERROR_XMLDSIG_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1466
ERROR_RESTART_APPLICATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1467
ERROR_WRONG_COMPARTMENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1468
ERROR_AUTHIP_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1469
ERROR_NO_NVRAM_RESOURCES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1470
ERROR_NOT_GUI_PROCESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1471
ERROR_EVENTLOG_FILE_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1500
ERROR_EVENTLOG_CANT_START: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1501
ERROR_LOG_FILE_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1502
ERROR_EVENTLOG_FILE_CHANGED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1503
ERROR_CONTAINER_ASSIGNED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1504
ERROR_JOB_NO_CONTAINER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1505
ERROR_INVALID_TASK_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1550
ERROR_INVALID_TASK_INDEX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1551
ERROR_THREAD_ALREADY_IN_TASK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1552
ERROR_INSTALL_SERVICE_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1601
ERROR_INSTALL_USEREXIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1602
ERROR_INSTALL_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1603
ERROR_INSTALL_SUSPEND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1604
ERROR_UNKNOWN_PRODUCT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1605
ERROR_UNKNOWN_FEATURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1606
ERROR_UNKNOWN_COMPONENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1607
ERROR_UNKNOWN_PROPERTY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1608
ERROR_INVALID_HANDLE_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1609
ERROR_BAD_CONFIGURATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1610
ERROR_INDEX_ABSENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1611
ERROR_INSTALL_SOURCE_ABSENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1612
ERROR_INSTALL_PACKAGE_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1613
ERROR_PRODUCT_UNINSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1614
ERROR_BAD_QUERY_SYNTAX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1615
ERROR_INVALID_FIELD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1616
ERROR_DEVICE_REMOVED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1617
ERROR_INSTALL_ALREADY_RUNNING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1618
ERROR_INSTALL_PACKAGE_OPEN_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1619
ERROR_INSTALL_PACKAGE_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1620
ERROR_INSTALL_UI_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1621
ERROR_INSTALL_LOG_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1622
ERROR_INSTALL_LANGUAGE_UNSUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1623
ERROR_INSTALL_TRANSFORM_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1624
ERROR_INSTALL_PACKAGE_REJECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1625
ERROR_FUNCTION_NOT_CALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1626
ERROR_FUNCTION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1627
ERROR_INVALID_TABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1628
ERROR_DATATYPE_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1629
ERROR_UNSUPPORTED_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1630
ERROR_CREATE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1631
ERROR_INSTALL_TEMP_UNWRITABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1632
ERROR_INSTALL_PLATFORM_UNSUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1633
ERROR_INSTALL_NOTUSED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1634
ERROR_PATCH_PACKAGE_OPEN_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1635
ERROR_PATCH_PACKAGE_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1636
ERROR_PATCH_PACKAGE_UNSUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1637
ERROR_PRODUCT_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1638
ERROR_INVALID_COMMAND_LINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1639
ERROR_INSTALL_REMOTE_DISALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1640
ERROR_SUCCESS_REBOOT_INITIATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1641
ERROR_PATCH_TARGET_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1642
ERROR_PATCH_PACKAGE_REJECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1643
ERROR_INSTALL_TRANSFORM_REJECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1644
ERROR_INSTALL_REMOTE_PROHIBITED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1645
ERROR_PATCH_REMOVAL_UNSUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1646
ERROR_UNKNOWN_PATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1647
ERROR_PATCH_NO_SEQUENCE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1648
ERROR_PATCH_REMOVAL_DISALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1649
ERROR_INVALID_PATCH_XML: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1650
ERROR_PATCH_MANAGED_ADVERTISED_PRODUCT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1651
ERROR_INSTALL_SERVICE_SAFEBOOT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1652
ERROR_FAIL_FAST_EXCEPTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1653
ERROR_INSTALL_REJECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1654
ERROR_DYNAMIC_CODE_BLOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1655
ERROR_NOT_SAME_OBJECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1656
ERROR_STRICT_CFG_VIOLATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1657
ERROR_SET_CONTEXT_DENIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1660
ERROR_CROSS_PARTITION_VIOLATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1661
ERROR_RETURN_ADDRESS_HIJACK_ATTEMPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1662
ERROR_INVALID_USER_BUFFER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1784
ERROR_UNRECOGNIZED_MEDIA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1785
ERROR_NO_TRUST_LSA_SECRET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1786
ERROR_NO_TRUST_SAM_ACCOUNT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1787
ERROR_TRUSTED_DOMAIN_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1788
ERROR_TRUSTED_RELATIONSHIP_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1789
ERROR_TRUST_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1790
ERROR_NETLOGON_NOT_STARTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1792
ERROR_ACCOUNT_EXPIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1793
ERROR_REDIRECTOR_HAS_OPEN_HANDLES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1794
ERROR_PRINTER_DRIVER_ALREADY_INSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1795
ERROR_UNKNOWN_PORT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1796
ERROR_UNKNOWN_PRINTER_DRIVER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1797
ERROR_UNKNOWN_PRINTPROCESSOR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1798
ERROR_INVALID_SEPARATOR_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1799
ERROR_INVALID_PRIORITY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1800
ERROR_INVALID_PRINTER_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1801
ERROR_PRINTER_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1802
ERROR_INVALID_PRINTER_COMMAND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1803
ERROR_INVALID_DATATYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1804
ERROR_INVALID_ENVIRONMENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1805
ERROR_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1807
ERROR_NOLOGON_WORKSTATION_TRUST_ACCOUNT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1808
ERROR_NOLOGON_SERVER_TRUST_ACCOUNT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1809
ERROR_DOMAIN_TRUST_INCONSISTENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1810
ERROR_SERVER_HAS_OPEN_HANDLES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1811
ERROR_RESOURCE_DATA_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1812
ERROR_RESOURCE_TYPE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1813
ERROR_RESOURCE_NAME_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1814
ERROR_RESOURCE_LANG_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1815
ERROR_NOT_ENOUGH_QUOTA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1816
ERROR_INVALID_TIME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1901
ERROR_INVALID_FORM_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1902
ERROR_INVALID_FORM_SIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1903
ERROR_ALREADY_WAITING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1904
ERROR_PRINTER_DELETED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1905
ERROR_INVALID_PRINTER_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1906
ERROR_PASSWORD_MUST_CHANGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1907
ERROR_DOMAIN_CONTROLLER_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1908
ERROR_ACCOUNT_LOCKED_OUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1909
ERROR_NO_SITENAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1919
ERROR_CANT_ACCESS_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1920
ERROR_CANT_RESOLVE_FILENAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1921
ERROR_KM_DRIVER_BLOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1930
ERROR_CONTEXT_EXPIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1931
ERROR_PER_USER_TRUST_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1932
ERROR_ALL_USER_TRUST_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1933
ERROR_USER_DELETE_TRUST_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1934
ERROR_AUTHENTICATION_FIREWALL_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1935
ERROR_REMOTE_PRINT_CONNECTIONS_BLOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1936
ERROR_NTLM_BLOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1937
ERROR_PASSWORD_CHANGE_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1938
ERROR_LOST_MODE_LOGON_RESTRICTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 1939
ERROR_INVALID_PIXEL_FORMAT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2000
ERROR_BAD_DRIVER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2001
ERROR_INVALID_WINDOW_STYLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2002
ERROR_METAFILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2003
ERROR_TRANSFORM_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2004
ERROR_CLIPPING_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2005
ERROR_INVALID_CMM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2010
ERROR_INVALID_PROFILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2011
ERROR_TAG_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2012
ERROR_TAG_NOT_PRESENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2013
ERROR_DUPLICATE_TAG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2014
ERROR_PROFILE_NOT_ASSOCIATED_WITH_DEVICE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2015
ERROR_PROFILE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2016
ERROR_INVALID_COLORSPACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2017
ERROR_ICM_NOT_ENABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2018
ERROR_DELETING_ICM_XFORM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2019
ERROR_INVALID_TRANSFORM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2020
ERROR_COLORSPACE_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2021
ERROR_INVALID_COLORINDEX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2022
ERROR_PROFILE_DOES_NOT_MATCH_DEVICE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2023
ERROR_CONNECTED_OTHER_PASSWORD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2108
ERROR_CONNECTED_OTHER_PASSWORD_DEFAULT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2109
ERROR_BAD_USERNAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2202
ERROR_NOT_CONNECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2250
ERROR_OPEN_FILES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2401
ERROR_ACTIVE_CONNECTIONS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2402
ERROR_DEVICE_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2404
ERROR_UNKNOWN_PRINT_MONITOR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3000
ERROR_PRINTER_DRIVER_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3001
ERROR_SPOOL_FILE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3002
ERROR_SPL_NO_STARTDOC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3003
ERROR_SPL_NO_ADDJOB: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3004
ERROR_PRINT_PROCESSOR_ALREADY_INSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3005
ERROR_PRINT_MONITOR_ALREADY_INSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3006
ERROR_INVALID_PRINT_MONITOR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3007
ERROR_PRINT_MONITOR_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3008
ERROR_PRINTER_HAS_JOBS_QUEUED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3009
ERROR_SUCCESS_REBOOT_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3010
ERROR_SUCCESS_RESTART_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3011
ERROR_PRINTER_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3012
ERROR_PRINTER_DRIVER_WARNED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3013
ERROR_PRINTER_DRIVER_BLOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3014
ERROR_PRINTER_DRIVER_PACKAGE_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3015
ERROR_CORE_DRIVER_PACKAGE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3016
ERROR_FAIL_REBOOT_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3017
ERROR_FAIL_REBOOT_INITIATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3018
ERROR_PRINTER_DRIVER_DOWNLOAD_NEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3019
ERROR_PRINT_JOB_RESTART_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3020
ERROR_INVALID_PRINTER_DRIVER_MANIFEST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3021
ERROR_PRINTER_NOT_SHAREABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3022
ERROR_SERVER_SERVICE_CALL_REQUIRES_SMB1: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3023
ERROR_NETWORK_AUTHENTICATION_PROMPT_CANCELED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3024
ERROR_REQUEST_PAUSED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3050
ERROR_APPEXEC_CONDITION_NOT_SATISFIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3060
ERROR_APPEXEC_HANDLE_INVALIDATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3061
ERROR_APPEXEC_INVALID_HOST_GENERATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3062
ERROR_APPEXEC_UNEXPECTED_PROCESS_REGISTRATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3063
ERROR_APPEXEC_INVALID_HOST_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3064
ERROR_APPEXEC_NO_DONOR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3065
ERROR_APPEXEC_HOST_ID_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3066
ERROR_APPEXEC_UNKNOWN_USER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3067
ERROR_APPEXEC_APP_COMPAT_BLOCK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3068
ERROR_APPEXEC_CALLER_WAIT_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3069
ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_TERMINATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3070
ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_LICENSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3071
ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_RESOURCES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3072
ERROR_VRF_VOLATILE_CFG_AND_IO_ENABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3080
ERROR_VRF_VOLATILE_NOT_STOPPABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3081
ERROR_VRF_VOLATILE_SAFE_MODE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3082
ERROR_VRF_VOLATILE_NOT_RUNNABLE_SYSTEM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3083
ERROR_VRF_VOLATILE_NOT_SUPPORTED_RULECLASS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3084
ERROR_VRF_VOLATILE_PROTECTED_DRIVER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3085
ERROR_VRF_VOLATILE_NMI_REGISTERED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3086
ERROR_VRF_VOLATILE_SETTINGS_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3087
ERROR_DIF_IOCALLBACK_NOT_REPLACED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3190
ERROR_DIF_LIVEDUMP_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3191
ERROR_DIF_VOLATILE_SECTION_NOT_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3192
ERROR_DIF_VOLATILE_DRIVER_HOTPATCHED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3193
ERROR_DIF_VOLATILE_INVALID_INFO: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3194
ERROR_DIF_VOLATILE_DRIVER_IS_NOT_RUNNING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3195
ERROR_DIF_VOLATILE_PLUGIN_IS_NOT_RUNNING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3196
ERROR_DIF_VOLATILE_PLUGIN_CHANGE_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3197
ERROR_DIF_VOLATILE_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3198
ERROR_DIF_BINDING_API_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3199
ERROR_IO_REISSUE_AS_CACHED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3950
ERROR_WINS_INTERNAL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4000
ERROR_CAN_NOT_DEL_LOCAL_WINS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4001
ERROR_STATIC_INIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4002
ERROR_INC_BACKUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4003
ERROR_FULL_BACKUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4004
ERROR_REC_NON_EXISTENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4005
ERROR_RPL_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4006
ERROR_DHCP_ADDRESS_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4100
ERROR_WMI_GUID_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4200
ERROR_WMI_INSTANCE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4201
ERROR_WMI_ITEMID_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4202
ERROR_WMI_TRY_AGAIN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4203
ERROR_WMI_DP_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4204
ERROR_WMI_UNRESOLVED_INSTANCE_REF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4205
ERROR_WMI_ALREADY_ENABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4206
ERROR_WMI_GUID_DISCONNECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4207
ERROR_WMI_SERVER_UNAVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4208
ERROR_WMI_DP_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4209
ERROR_WMI_INVALID_MOF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4210
ERROR_WMI_INVALID_REGINFO: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4211
ERROR_WMI_ALREADY_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4212
ERROR_WMI_READ_ONLY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4213
ERROR_WMI_SET_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4214
ERROR_NOT_APPCONTAINER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4250
ERROR_APPCONTAINER_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4251
ERROR_NOT_SUPPORTED_IN_APPCONTAINER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4252
ERROR_INVALID_PACKAGE_SID_LENGTH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4253
ERROR_INVALID_MEDIA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4300
ERROR_INVALID_LIBRARY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4301
ERROR_INVALID_MEDIA_POOL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4302
ERROR_DRIVE_MEDIA_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4303
ERROR_MEDIA_OFFLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4304
ERROR_LIBRARY_OFFLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4305
ERROR_EMPTY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4306
ERROR_NOT_EMPTY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4307
ERROR_MEDIA_UNAVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4308
ERROR_RESOURCE_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4309
ERROR_INVALID_CLEANER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4310
ERROR_UNABLE_TO_CLEAN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4311
ERROR_OBJECT_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4312
ERROR_DATABASE_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4313
ERROR_DATABASE_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4314
ERROR_MEDIA_INCOMPATIBLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4315
ERROR_RESOURCE_NOT_PRESENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4316
ERROR_INVALID_OPERATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4317
ERROR_MEDIA_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4318
ERROR_DEVICE_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4319
ERROR_REQUEST_REFUSED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4320
ERROR_INVALID_DRIVE_OBJECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4321
ERROR_LIBRARY_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4322
ERROR_MEDIUM_NOT_ACCESSIBLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4323
ERROR_UNABLE_TO_LOAD_MEDIUM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4324
ERROR_UNABLE_TO_INVENTORY_DRIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4325
ERROR_UNABLE_TO_INVENTORY_SLOT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4326
ERROR_UNABLE_TO_INVENTORY_TRANSPORT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4327
ERROR_TRANSPORT_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4328
ERROR_CONTROLLING_IEPORT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4329
ERROR_UNABLE_TO_EJECT_MOUNTED_MEDIA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4330
ERROR_CLEANER_SLOT_SET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4331
ERROR_CLEANER_SLOT_NOT_SET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4332
ERROR_CLEANER_CARTRIDGE_SPENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4333
ERROR_UNEXPECTED_OMID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4334
ERROR_CANT_DELETE_LAST_ITEM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4335
ERROR_MESSAGE_EXCEEDS_MAX_SIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4336
ERROR_VOLUME_CONTAINS_SYS_FILES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4337
ERROR_INDIGENOUS_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4338
ERROR_NO_SUPPORTING_DRIVES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4339
ERROR_CLEANER_CARTRIDGE_INSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4340
ERROR_IEPORT_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4341
ERROR_FILE_OFFLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4350
ERROR_REMOTE_STORAGE_NOT_ACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4351
ERROR_REMOTE_STORAGE_MEDIA_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4352
ERROR_NOT_A_REPARSE_POINT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4390
ERROR_REPARSE_ATTRIBUTE_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4391
ERROR_INVALID_REPARSE_DATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4392
ERROR_REPARSE_TAG_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4393
ERROR_REPARSE_TAG_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4394
ERROR_REPARSE_POINT_ENCOUNTERED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4395
ERROR_APP_DATA_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4400
ERROR_APP_DATA_EXPIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4401
ERROR_APP_DATA_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4402
ERROR_APP_DATA_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4403
ERROR_APP_DATA_REBOOT_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4404
ERROR_SECUREBOOT_ROLLBACK_DETECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4420
ERROR_SECUREBOOT_POLICY_VIOLATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4421
ERROR_SECUREBOOT_INVALID_POLICY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4422
ERROR_SECUREBOOT_POLICY_PUBLISHER_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4423
ERROR_SECUREBOOT_POLICY_NOT_SIGNED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4424
ERROR_SECUREBOOT_NOT_ENABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4425
ERROR_SECUREBOOT_FILE_REPLACED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4426
ERROR_SECUREBOOT_POLICY_NOT_AUTHORIZED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4427
ERROR_SECUREBOOT_POLICY_UNKNOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4428
ERROR_SECUREBOOT_POLICY_MISSING_ANTIROLLBACKVERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4429
ERROR_SECUREBOOT_PLATFORM_ID_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4430
ERROR_SECUREBOOT_POLICY_ROLLBACK_DETECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4431
ERROR_SECUREBOOT_POLICY_UPGRADE_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4432
ERROR_SECUREBOOT_REQUIRED_POLICY_FILE_MISSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4433
ERROR_SECUREBOOT_NOT_BASE_POLICY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4434
ERROR_SECUREBOOT_NOT_SUPPLEMENTAL_POLICY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4435
ERROR_OFFLOAD_READ_FLT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4440
ERROR_OFFLOAD_WRITE_FLT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4441
ERROR_OFFLOAD_READ_FILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4442
ERROR_OFFLOAD_WRITE_FILE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4443
ERROR_ALREADY_HAS_STREAM_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4444
ERROR_SMR_GARBAGE_COLLECTION_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4445
ERROR_WOF_WIM_HEADER_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4446
ERROR_WOF_WIM_RESOURCE_TABLE_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4447
ERROR_WOF_FILE_RESOURCE_TABLE_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4448
ERROR_OBJECT_IS_IMMUTABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4449
ERROR_VOLUME_NOT_SIS_ENABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4500
ERROR_SYSTEM_INTEGRITY_ROLLBACK_DETECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4550
ERROR_SYSTEM_INTEGRITY_POLICY_VIOLATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4551
ERROR_SYSTEM_INTEGRITY_INVALID_POLICY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4552
ERROR_SYSTEM_INTEGRITY_POLICY_NOT_SIGNED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4553
ERROR_SYSTEM_INTEGRITY_TOO_MANY_POLICIES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4554
ERROR_SYSTEM_INTEGRITY_SUPPLEMENTAL_POLICY_NOT_AUTHORIZED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4555
ERROR_SYSTEM_INTEGRITY_REPUTATION_MALICIOUS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4556
ERROR_SYSTEM_INTEGRITY_REPUTATION_PUA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4557
ERROR_SYSTEM_INTEGRITY_REPUTATION_DANGEROUS_EXT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4558
ERROR_SYSTEM_INTEGRITY_REPUTATION_OFFLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4559
ERROR_VSM_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4560
ERROR_VSM_DMA_PROTECTION_NOT_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4561
ERROR_PLATFORM_MANIFEST_NOT_AUTHORIZED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4570
ERROR_PLATFORM_MANIFEST_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4571
ERROR_PLATFORM_MANIFEST_FILE_NOT_AUTHORIZED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4572
ERROR_PLATFORM_MANIFEST_CATALOG_NOT_AUTHORIZED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4573
ERROR_PLATFORM_MANIFEST_BINARY_ID_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4574
ERROR_PLATFORM_MANIFEST_NOT_ACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4575
ERROR_PLATFORM_MANIFEST_NOT_SIGNED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4576
ERROR_SYSTEM_INTEGRITY_REPUTATION_UNFRIENDLY_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4580
ERROR_SYSTEM_INTEGRITY_REPUTATION_UNATTAINABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4581
ERROR_SYSTEM_INTEGRITY_REPUTATION_EXPLICIT_DENY_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 4582
ERROR_DEPENDENT_RESOURCE_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5001
ERROR_DEPENDENCY_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5002
ERROR_DEPENDENCY_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5003
ERROR_RESOURCE_NOT_ONLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5004
ERROR_HOST_NODE_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5005
ERROR_RESOURCE_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5006
ERROR_RESOURCE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5007
ERROR_SHUTDOWN_CLUSTER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5008
ERROR_CANT_EVICT_ACTIVE_NODE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5009
ERROR_OBJECT_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5010
ERROR_OBJECT_IN_LIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5011
ERROR_GROUP_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5012
ERROR_GROUP_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5013
ERROR_GROUP_NOT_ONLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5014
ERROR_HOST_NODE_NOT_RESOURCE_OWNER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5015
ERROR_HOST_NODE_NOT_GROUP_OWNER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5016
ERROR_RESMON_CREATE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5017
ERROR_RESMON_ONLINE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5018
ERROR_RESOURCE_ONLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5019
ERROR_QUORUM_RESOURCE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5020
ERROR_NOT_QUORUM_CAPABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5021
ERROR_CLUSTER_SHUTTING_DOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5022
ERROR_INVALID_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5023
ERROR_RESOURCE_PROPERTIES_STORED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5024
ERROR_NOT_QUORUM_CLASS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5025
ERROR_CORE_RESOURCE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5026
ERROR_QUORUM_RESOURCE_ONLINE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5027
ERROR_QUORUMLOG_OPEN_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5028
ERROR_CLUSTERLOG_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5029
ERROR_CLUSTERLOG_RECORD_EXCEEDS_MAXSIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5030
ERROR_CLUSTERLOG_EXCEEDS_MAXSIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5031
ERROR_CLUSTERLOG_CHKPOINT_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5032
ERROR_CLUSTERLOG_NOT_ENOUGH_SPACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5033
ERROR_QUORUM_OWNER_ALIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5034
ERROR_NETWORK_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5035
ERROR_NODE_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5036
ERROR_ALL_NODES_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5037
ERROR_RESOURCE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5038
ERROR_CLUSTER_INVALID_NODE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5039
ERROR_CLUSTER_NODE_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5040
ERROR_CLUSTER_JOIN_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5041
ERROR_CLUSTER_NODE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5042
ERROR_CLUSTER_LOCAL_NODE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5043
ERROR_CLUSTER_NETWORK_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5044
ERROR_CLUSTER_NETWORK_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5045
ERROR_CLUSTER_NETINTERFACE_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5046
ERROR_CLUSTER_NETINTERFACE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5047
ERROR_CLUSTER_INVALID_REQUEST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5048
ERROR_CLUSTER_INVALID_NETWORK_PROVIDER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5049
ERROR_CLUSTER_NODE_DOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5050
ERROR_CLUSTER_NODE_UNREACHABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5051
ERROR_CLUSTER_NODE_NOT_MEMBER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5052
ERROR_CLUSTER_JOIN_NOT_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5053
ERROR_CLUSTER_INVALID_NETWORK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5054
ERROR_CLUSTER_NODE_UP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5056
ERROR_CLUSTER_IPADDR_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5057
ERROR_CLUSTER_NODE_NOT_PAUSED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5058
ERROR_CLUSTER_NO_SECURITY_CONTEXT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5059
ERROR_CLUSTER_NETWORK_NOT_INTERNAL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5060
ERROR_CLUSTER_NODE_ALREADY_UP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5061
ERROR_CLUSTER_NODE_ALREADY_DOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5062
ERROR_CLUSTER_NETWORK_ALREADY_ONLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5063
ERROR_CLUSTER_NETWORK_ALREADY_OFFLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5064
ERROR_CLUSTER_NODE_ALREADY_MEMBER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5065
ERROR_CLUSTER_LAST_INTERNAL_NETWORK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5066
ERROR_CLUSTER_NETWORK_HAS_DEPENDENTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5067
ERROR_INVALID_OPERATION_ON_QUORUM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5068
ERROR_DEPENDENCY_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5069
ERROR_CLUSTER_NODE_PAUSED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5070
ERROR_NODE_CANT_HOST_RESOURCE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5071
ERROR_CLUSTER_NODE_NOT_READY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5072
ERROR_CLUSTER_NODE_SHUTTING_DOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5073
ERROR_CLUSTER_JOIN_ABORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5074
ERROR_CLUSTER_INCOMPATIBLE_VERSIONS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5075
ERROR_CLUSTER_MAXNUM_OF_RESOURCES_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5076
ERROR_CLUSTER_SYSTEM_CONFIG_CHANGED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5077
ERROR_CLUSTER_RESOURCE_TYPE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5078
ERROR_CLUSTER_RESTYPE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5079
ERROR_CLUSTER_RESNAME_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5080
ERROR_CLUSTER_NO_RPC_PACKAGES_REGISTERED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5081
ERROR_CLUSTER_OWNER_NOT_IN_PREFLIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5082
ERROR_CLUSTER_DATABASE_SEQMISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5083
ERROR_RESMON_INVALID_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5084
ERROR_CLUSTER_GUM_NOT_LOCKER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5085
ERROR_QUORUM_DISK_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5086
ERROR_DATABASE_BACKUP_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5087
ERROR_CLUSTER_NODE_ALREADY_HAS_DFS_ROOT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5088
ERROR_RESOURCE_PROPERTY_UNCHANGEABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5089
ERROR_NO_ADMIN_ACCESS_POINT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5090
ERROR_CLUSTER_MEMBERSHIP_INVALID_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5890
ERROR_CLUSTER_QUORUMLOG_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5891
ERROR_CLUSTER_MEMBERSHIP_HALT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5892
ERROR_CLUSTER_INSTANCE_ID_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5893
ERROR_CLUSTER_NETWORK_NOT_FOUND_FOR_IP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5894
ERROR_CLUSTER_PROPERTY_DATA_TYPE_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5895
ERROR_CLUSTER_EVICT_WITHOUT_CLEANUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5896
ERROR_CLUSTER_PARAMETER_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5897
ERROR_NODE_CANNOT_BE_CLUSTERED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5898
ERROR_CLUSTER_WRONG_OS_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5899
ERROR_CLUSTER_CANT_CREATE_DUP_CLUSTER_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5900
ERROR_CLUSCFG_ALREADY_COMMITTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5901
ERROR_CLUSCFG_ROLLBACK_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5902
ERROR_CLUSCFG_SYSTEM_DISK_DRIVE_LETTER_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5903
ERROR_CLUSTER_OLD_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5904
ERROR_CLUSTER_MISMATCHED_COMPUTER_ACCT_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5905
ERROR_CLUSTER_NO_NET_ADAPTERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5906
ERROR_CLUSTER_POISONED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5907
ERROR_CLUSTER_GROUP_MOVING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5908
ERROR_CLUSTER_RESOURCE_TYPE_BUSY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5909
ERROR_RESOURCE_CALL_TIMED_OUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5910
ERROR_INVALID_CLUSTER_IPV6_ADDRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5911
ERROR_CLUSTER_INTERNAL_INVALID_FUNCTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5912
ERROR_CLUSTER_PARAMETER_OUT_OF_BOUNDS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5913
ERROR_CLUSTER_PARTIAL_SEND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5914
ERROR_CLUSTER_REGISTRY_INVALID_FUNCTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5915
ERROR_CLUSTER_INVALID_STRING_TERMINATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5916
ERROR_CLUSTER_INVALID_STRING_FORMAT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5917
ERROR_CLUSTER_DATABASE_TRANSACTION_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5918
ERROR_CLUSTER_DATABASE_TRANSACTION_NOT_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5919
ERROR_CLUSTER_NULL_DATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5920
ERROR_CLUSTER_PARTIAL_READ: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5921
ERROR_CLUSTER_PARTIAL_WRITE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5922
ERROR_CLUSTER_CANT_DESERIALIZE_DATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5923
ERROR_DEPENDENT_RESOURCE_PROPERTY_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5924
ERROR_CLUSTER_NO_QUORUM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5925
ERROR_CLUSTER_INVALID_IPV6_NETWORK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5926
ERROR_CLUSTER_INVALID_IPV6_TUNNEL_NETWORK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5927
ERROR_QUORUM_NOT_ALLOWED_IN_THIS_GROUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5928
ERROR_DEPENDENCY_TREE_TOO_COMPLEX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5929
ERROR_EXCEPTION_IN_RESOURCE_CALL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5930
ERROR_CLUSTER_RHS_FAILED_INITIALIZATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5931
ERROR_CLUSTER_NOT_INSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5932
ERROR_CLUSTER_RESOURCES_MUST_BE_ONLINE_ON_THE_SAME_NODE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5933
ERROR_CLUSTER_MAX_NODES_IN_CLUSTER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5934
ERROR_CLUSTER_TOO_MANY_NODES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5935
ERROR_CLUSTER_OBJECT_ALREADY_USED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5936
ERROR_NONCORE_GROUPS_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5937
ERROR_FILE_SHARE_RESOURCE_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5938
ERROR_CLUSTER_EVICT_INVALID_REQUEST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5939
ERROR_CLUSTER_SINGLETON_RESOURCE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5940
ERROR_CLUSTER_GROUP_SINGLETON_RESOURCE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5941
ERROR_CLUSTER_RESOURCE_PROVIDER_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5942
ERROR_CLUSTER_RESOURCE_CONFIGURATION_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5943
ERROR_CLUSTER_GROUP_BUSY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5944
ERROR_CLUSTER_NOT_SHARED_VOLUME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5945
ERROR_CLUSTER_INVALID_SECURITY_DESCRIPTOR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5946
ERROR_CLUSTER_SHARED_VOLUMES_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5947
ERROR_CLUSTER_USE_SHARED_VOLUMES_API: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5948
ERROR_CLUSTER_BACKUP_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5949
ERROR_NON_CSV_PATH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5950
ERROR_CSV_VOLUME_NOT_LOCAL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5951
ERROR_CLUSTER_WATCHDOG_TERMINATING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5952
ERROR_CLUSTER_RESOURCE_VETOED_MOVE_INCOMPATIBLE_NODES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5953
ERROR_CLUSTER_INVALID_NODE_WEIGHT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5954
ERROR_CLUSTER_RESOURCE_VETOED_CALL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5955
ERROR_RESMON_SYSTEM_RESOURCES_LACKING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5956
ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_DESTINATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5957
ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_SOURCE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5958
ERROR_CLUSTER_GROUP_QUEUED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5959
ERROR_CLUSTER_RESOURCE_LOCKED_STATUS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5960
ERROR_CLUSTER_SHARED_VOLUME_FAILOVER_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5961
ERROR_CLUSTER_NODE_DRAIN_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5962
ERROR_CLUSTER_DISK_NOT_CONNECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5963
ERROR_DISK_NOT_CSV_CAPABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5964
ERROR_RESOURCE_NOT_IN_AVAILABLE_STORAGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5965
ERROR_CLUSTER_SHARED_VOLUME_REDIRECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5966
ERROR_CLUSTER_SHARED_VOLUME_NOT_REDIRECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5967
ERROR_CLUSTER_CANNOT_RETURN_PROPERTIES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5968
ERROR_CLUSTER_RESOURCE_CONTAINS_UNSUPPORTED_DIFF_AREA_FOR_SHARED_VOLUMES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5969
ERROR_CLUSTER_RESOURCE_IS_IN_MAINTENANCE_MODE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5970
ERROR_CLUSTER_AFFINITY_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5971
ERROR_CLUSTER_RESOURCE_IS_REPLICA_VIRTUAL_MACHINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5972
ERROR_CLUSTER_UPGRADE_INCOMPATIBLE_VERSIONS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5973
ERROR_CLUSTER_UPGRADE_FIX_QUORUM_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5974
ERROR_CLUSTER_UPGRADE_RESTART_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5975
ERROR_CLUSTER_UPGRADE_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5976
ERROR_CLUSTER_UPGRADE_INCOMPLETE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5977
ERROR_CLUSTER_NODE_IN_GRACE_PERIOD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5978
ERROR_CLUSTER_CSV_IO_PAUSE_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5979
ERROR_NODE_NOT_ACTIVE_CLUSTER_MEMBER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5980
ERROR_CLUSTER_RESOURCE_NOT_MONITORED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5981
ERROR_CLUSTER_RESOURCE_DOES_NOT_SUPPORT_UNMONITORED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5982
ERROR_CLUSTER_RESOURCE_IS_REPLICATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5983
ERROR_CLUSTER_NODE_ISOLATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5984
ERROR_CLUSTER_NODE_QUARANTINED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5985
ERROR_CLUSTER_DATABASE_UPDATE_CONDITION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5986
ERROR_CLUSTER_SPACE_DEGRADED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5987
ERROR_CLUSTER_TOKEN_DELEGATION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5988
ERROR_CLUSTER_CSV_INVALID_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5989
ERROR_CLUSTER_CSV_SUPPORTED_ONLY_ON_COORDINATOR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5990
ERROR_GROUPSET_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5991
ERROR_GROUPSET_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5992
ERROR_GROUPSET_CANT_PROVIDE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5993
ERROR_CLUSTER_FAULT_DOMAIN_PARENT_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5994
ERROR_CLUSTER_FAULT_DOMAIN_INVALID_HIERARCHY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5995
ERROR_CLUSTER_FAULT_DOMAIN_FAILED_S2D_VALIDATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5996
ERROR_CLUSTER_FAULT_DOMAIN_S2D_CONNECTIVITY_LOSS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5997
ERROR_CLUSTER_INVALID_INFRASTRUCTURE_FILESERVER_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5998
ERROR_CLUSTERSET_MANAGEMENT_CLUSTER_UNREACHABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 5999
ERROR_ENCRYPTION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6000
ERROR_DECRYPTION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6001
ERROR_FILE_ENCRYPTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6002
ERROR_NO_RECOVERY_POLICY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6003
ERROR_NO_EFS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6004
ERROR_WRONG_EFS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6005
ERROR_NO_USER_KEYS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6006
ERROR_FILE_NOT_ENCRYPTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6007
ERROR_NOT_EXPORT_FORMAT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6008
ERROR_FILE_READ_ONLY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6009
ERROR_DIR_EFS_DISALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6010
ERROR_EFS_SERVER_NOT_TRUSTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6011
ERROR_BAD_RECOVERY_POLICY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6012
ERROR_EFS_ALG_BLOB_TOO_BIG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6013
ERROR_VOLUME_NOT_SUPPORT_EFS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6014
ERROR_EFS_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6015
ERROR_EFS_VERSION_NOT_SUPPORT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6016
ERROR_CS_ENCRYPTION_INVALID_SERVER_RESPONSE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6017
ERROR_CS_ENCRYPTION_UNSUPPORTED_SERVER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6018
ERROR_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6019
ERROR_CS_ENCRYPTION_NEW_ENCRYPTED_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6020
ERROR_CS_ENCRYPTION_FILE_NOT_CSE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6021
ERROR_ENCRYPTION_POLICY_DENIES_OPERATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6022
ERROR_WIP_ENCRYPTION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6023
ERROR_NO_BROWSER_SERVERS_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6118
ERROR_CLUSTER_OBJECT_IS_CLUSTER_SET_VM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6250
ERROR_LOG_SECTOR_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6600
ERROR_LOG_SECTOR_PARITY_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6601
ERROR_LOG_SECTOR_REMAPPED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6602
ERROR_LOG_BLOCK_INCOMPLETE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6603
ERROR_LOG_INVALID_RANGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6604
ERROR_LOG_BLOCKS_EXHAUSTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6605
ERROR_LOG_READ_CONTEXT_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6606
ERROR_LOG_RESTART_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6607
ERROR_LOG_BLOCK_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6608
ERROR_LOG_BLOCK_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6609
ERROR_LOG_READ_MODE_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6610
ERROR_LOG_NO_RESTART: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6611
ERROR_LOG_METADATA_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6612
ERROR_LOG_METADATA_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6613
ERROR_LOG_METADATA_INCONSISTENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6614
ERROR_LOG_RESERVATION_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6615
ERROR_LOG_CANT_DELETE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6616
ERROR_LOG_CONTAINER_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6617
ERROR_LOG_START_OF_LOG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6618
ERROR_LOG_POLICY_ALREADY_INSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6619
ERROR_LOG_POLICY_NOT_INSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6620
ERROR_LOG_POLICY_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6621
ERROR_LOG_POLICY_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6622
ERROR_LOG_PINNED_ARCHIVE_TAIL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6623
ERROR_LOG_RECORD_NONEXISTENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6624
ERROR_LOG_RECORDS_RESERVED_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6625
ERROR_LOG_SPACE_RESERVED_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6626
ERROR_LOG_TAIL_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6627
ERROR_LOG_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6628
ERROR_COULD_NOT_RESIZE_LOG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6629
ERROR_LOG_MULTIPLEXED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6630
ERROR_LOG_DEDICATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6631
ERROR_LOG_ARCHIVE_NOT_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6632
ERROR_LOG_ARCHIVE_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6633
ERROR_LOG_EPHEMERAL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6634
ERROR_LOG_NOT_ENOUGH_CONTAINERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6635
ERROR_LOG_CLIENT_ALREADY_REGISTERED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6636
ERROR_LOG_CLIENT_NOT_REGISTERED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6637
ERROR_LOG_FULL_HANDLER_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6638
ERROR_LOG_CONTAINER_READ_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6639
ERROR_LOG_CONTAINER_WRITE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6640
ERROR_LOG_CONTAINER_OPEN_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6641
ERROR_LOG_CONTAINER_STATE_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6642
ERROR_LOG_STATE_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6643
ERROR_LOG_PINNED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6644
ERROR_LOG_METADATA_FLUSH_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6645
ERROR_LOG_INCONSISTENT_SECURITY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6646
ERROR_LOG_APPENDED_FLUSH_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6647
ERROR_LOG_PINNED_RESERVATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6648
ERROR_INVALID_TRANSACTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6700
ERROR_TRANSACTION_NOT_ACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6701
ERROR_TRANSACTION_REQUEST_NOT_VALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6702
ERROR_TRANSACTION_NOT_REQUESTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6703
ERROR_TRANSACTION_ALREADY_ABORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6704
ERROR_TRANSACTION_ALREADY_COMMITTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6705
ERROR_TM_INITIALIZATION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6706
ERROR_RESOURCEMANAGER_READ_ONLY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6707
ERROR_TRANSACTION_NOT_JOINED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6708
ERROR_TRANSACTION_SUPERIOR_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6709
ERROR_CRM_PROTOCOL_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6710
ERROR_TRANSACTION_PROPAGATION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6711
ERROR_CRM_PROTOCOL_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6712
ERROR_TRANSACTION_INVALID_MARSHALL_BUFFER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6713
ERROR_CURRENT_TRANSACTION_NOT_VALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6714
ERROR_TRANSACTION_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6715
ERROR_RESOURCEMANAGER_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6716
ERROR_ENLISTMENT_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6717
ERROR_TRANSACTIONMANAGER_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6718
ERROR_TRANSACTIONMANAGER_NOT_ONLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6719
ERROR_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6720
ERROR_TRANSACTION_NOT_ROOT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6721
ERROR_TRANSACTION_OBJECT_EXPIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6722
ERROR_TRANSACTION_RESPONSE_NOT_ENLISTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6723
ERROR_TRANSACTION_RECORD_TOO_LONG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6724
ERROR_IMPLICIT_TRANSACTION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6725
ERROR_TRANSACTION_INTEGRITY_VIOLATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6726
ERROR_TRANSACTIONMANAGER_IDENTITY_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6727
ERROR_RM_CANNOT_BE_FROZEN_FOR_SNAPSHOT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6728
ERROR_TRANSACTION_MUST_WRITETHROUGH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6729
ERROR_TRANSACTION_NO_SUPERIOR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6730
ERROR_HEURISTIC_DAMAGE_POSSIBLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6731
ERROR_TRANSACTIONAL_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6800
ERROR_RM_NOT_ACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6801
ERROR_RM_METADATA_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6802
ERROR_DIRECTORY_NOT_RM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6803
ERROR_TRANSACTIONS_UNSUPPORTED_REMOTE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6805
ERROR_LOG_RESIZE_INVALID_SIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6806
ERROR_OBJECT_NO_LONGER_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6807
ERROR_STREAM_MINIVERSION_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6808
ERROR_STREAM_MINIVERSION_NOT_VALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6809
ERROR_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6810
ERROR_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6811
ERROR_CANT_CREATE_MORE_STREAM_MINIVERSIONS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6812
ERROR_REMOTE_FILE_VERSION_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6814
ERROR_HANDLE_NO_LONGER_VALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6815
ERROR_NO_TXF_METADATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6816
ERROR_LOG_CORRUPTION_DETECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6817
ERROR_CANT_RECOVER_WITH_HANDLE_OPEN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6818
ERROR_RM_DISCONNECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6819
ERROR_ENLISTMENT_NOT_SUPERIOR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6820
ERROR_RECOVERY_NOT_NEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6821
ERROR_RM_ALREADY_STARTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6822
ERROR_FILE_IDENTITY_NOT_PERSISTENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6823
ERROR_CANT_BREAK_TRANSACTIONAL_DEPENDENCY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6824
ERROR_CANT_CROSS_RM_BOUNDARY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6825
ERROR_TXF_DIR_NOT_EMPTY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6826
ERROR_INDOUBT_TRANSACTIONS_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6827
ERROR_TM_VOLATILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6828
ERROR_ROLLBACK_TIMER_EXPIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6829
ERROR_TXF_ATTRIBUTE_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6830
ERROR_EFS_NOT_ALLOWED_IN_TRANSACTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6831
ERROR_TRANSACTIONAL_OPEN_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6832
ERROR_LOG_GROWTH_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6833
ERROR_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6834
ERROR_TXF_METADATA_ALREADY_PRESENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6835
ERROR_TRANSACTION_SCOPE_CALLBACKS_NOT_SET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6836
ERROR_TRANSACTION_REQUIRED_PROMOTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6837
ERROR_CANNOT_EXECUTE_FILE_IN_TRANSACTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6838
ERROR_TRANSACTIONS_NOT_FROZEN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6839
ERROR_TRANSACTION_FREEZE_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6840
ERROR_NOT_SNAPSHOT_VOLUME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6841
ERROR_NO_SAVEPOINT_WITH_OPEN_FILES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6842
ERROR_DATA_LOST_REPAIR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6843
ERROR_SPARSE_NOT_ALLOWED_IN_TRANSACTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6844
ERROR_TM_IDENTITY_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6845
ERROR_FLOATED_SECTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6846
ERROR_CANNOT_ACCEPT_TRANSACTED_WORK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6847
ERROR_CANNOT_ABORT_TRANSACTIONS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6848
ERROR_BAD_CLUSTERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6849
ERROR_COMPRESSION_NOT_ALLOWED_IN_TRANSACTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6850
ERROR_VOLUME_DIRTY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6851
ERROR_NO_LINK_TRACKING_IN_TRANSACTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6852
ERROR_OPERATION_NOT_SUPPORTED_IN_TRANSACTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6853
ERROR_EXPIRED_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6854
ERROR_TRANSACTION_NOT_ENLISTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 6855
ERROR_CTX_WINSTATION_NAME_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7001
ERROR_CTX_INVALID_PD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7002
ERROR_CTX_PD_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7003
ERROR_CTX_WD_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7004
ERROR_CTX_CANNOT_MAKE_EVENTLOG_ENTRY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7005
ERROR_CTX_SERVICE_NAME_COLLISION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7006
ERROR_CTX_CLOSE_PENDING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7007
ERROR_CTX_NO_OUTBUF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7008
ERROR_CTX_MODEM_INF_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7009
ERROR_CTX_INVALID_MODEMNAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7010
ERROR_CTX_MODEM_RESPONSE_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7011
ERROR_CTX_MODEM_RESPONSE_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7012
ERROR_CTX_MODEM_RESPONSE_NO_CARRIER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7013
ERROR_CTX_MODEM_RESPONSE_NO_DIALTONE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7014
ERROR_CTX_MODEM_RESPONSE_BUSY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7015
ERROR_CTX_MODEM_RESPONSE_VOICE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7016
ERROR_CTX_TD_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7017
ERROR_CTX_WINSTATION_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7022
ERROR_CTX_WINSTATION_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7023
ERROR_CTX_WINSTATION_BUSY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7024
ERROR_CTX_BAD_VIDEO_MODE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7025
ERROR_CTX_GRAPHICS_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7035
ERROR_CTX_LOGON_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7037
ERROR_CTX_NOT_CONSOLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7038
ERROR_CTX_CLIENT_QUERY_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7040
ERROR_CTX_CONSOLE_DISCONNECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7041
ERROR_CTX_CONSOLE_CONNECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7042
ERROR_CTX_SHADOW_DENIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7044
ERROR_CTX_WINSTATION_ACCESS_DENIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7045
ERROR_CTX_INVALID_WD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7049
ERROR_CTX_SHADOW_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7050
ERROR_CTX_SHADOW_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7051
ERROR_CTX_CLIENT_LICENSE_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7052
ERROR_CTX_CLIENT_LICENSE_NOT_SET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7053
ERROR_CTX_LICENSE_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7054
ERROR_CTX_LICENSE_CLIENT_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7055
ERROR_CTX_LICENSE_EXPIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7056
ERROR_CTX_SHADOW_NOT_RUNNING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7057
ERROR_CTX_SHADOW_ENDED_BY_MODE_CHANGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7058
ERROR_ACTIVATION_COUNT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7059
ERROR_CTX_WINSTATIONS_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7060
ERROR_CTX_ENCRYPTION_LEVEL_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7061
ERROR_CTX_SESSION_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7062
ERROR_CTX_NO_FORCE_LOGOFF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7063
ERROR_CTX_ACCOUNT_RESTRICTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7064
ERROR_RDP_PROTOCOL_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7065
ERROR_CTX_CDM_CONNECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7066
ERROR_CTX_CDM_DISCONNECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7067
ERROR_CTX_SECURITY_LAYER_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7068
ERROR_TS_INCOMPATIBLE_SESSIONS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7069
ERROR_TS_VIDEO_SUBSYSTEM_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 7070
ERROR_DS_NOT_INSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8200
ERROR_DS_MEMBERSHIP_EVALUATED_LOCALLY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8201
ERROR_DS_NO_ATTRIBUTE_OR_VALUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8202
ERROR_DS_INVALID_ATTRIBUTE_SYNTAX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8203
ERROR_DS_ATTRIBUTE_TYPE_UNDEFINED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8204
ERROR_DS_ATTRIBUTE_OR_VALUE_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8205
ERROR_DS_BUSY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8206
ERROR_DS_UNAVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8207
ERROR_DS_NO_RIDS_ALLOCATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8208
ERROR_DS_NO_MORE_RIDS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8209
ERROR_DS_INCORRECT_ROLE_OWNER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8210
ERROR_DS_RIDMGR_INIT_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8211
ERROR_DS_OBJ_CLASS_VIOLATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8212
ERROR_DS_CANT_ON_NON_LEAF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8213
ERROR_DS_CANT_ON_RDN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8214
ERROR_DS_CANT_MOD_OBJ_CLASS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8215
ERROR_DS_CROSS_DOM_MOVE_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8216
ERROR_DS_GC_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8217
ERROR_SHARED_POLICY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8218
ERROR_POLICY_OBJECT_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8219
ERROR_POLICY_ONLY_IN_DS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8220
ERROR_PROMOTION_ACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8221
ERROR_NO_PROMOTION_ACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8222
ERROR_DS_OPERATIONS_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8224
ERROR_DS_PROTOCOL_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8225
ERROR_DS_TIMELIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8226
ERROR_DS_SIZELIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8227
ERROR_DS_ADMIN_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8228
ERROR_DS_COMPARE_FALSE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8229
ERROR_DS_COMPARE_TRUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8230
ERROR_DS_AUTH_METHOD_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8231
ERROR_DS_STRONG_AUTH_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8232
ERROR_DS_INAPPROPRIATE_AUTH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8233
ERROR_DS_AUTH_UNKNOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8234
ERROR_DS_REFERRAL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8235
ERROR_DS_UNAVAILABLE_CRIT_EXTENSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8236
ERROR_DS_CONFIDENTIALITY_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8237
ERROR_DS_INAPPROPRIATE_MATCHING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8238
ERROR_DS_CONSTRAINT_VIOLATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8239
ERROR_DS_NO_SUCH_OBJECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8240
ERROR_DS_ALIAS_PROBLEM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8241
ERROR_DS_INVALID_DN_SYNTAX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8242
ERROR_DS_IS_LEAF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8243
ERROR_DS_ALIAS_DEREF_PROBLEM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8244
ERROR_DS_UNWILLING_TO_PERFORM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8245
ERROR_DS_LOOP_DETECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8246
ERROR_DS_NAMING_VIOLATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8247
ERROR_DS_OBJECT_RESULTS_TOO_LARGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8248
ERROR_DS_AFFECTS_MULTIPLE_DSAS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8249
ERROR_DS_SERVER_DOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8250
ERROR_DS_LOCAL_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8251
ERROR_DS_ENCODING_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8252
ERROR_DS_DECODING_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8253
ERROR_DS_FILTER_UNKNOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8254
ERROR_DS_PARAM_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8255
ERROR_DS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8256
ERROR_DS_NO_RESULTS_RETURNED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8257
ERROR_DS_CONTROL_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8258
ERROR_DS_CLIENT_LOOP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8259
ERROR_DS_REFERRAL_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8260
ERROR_DS_SORT_CONTROL_MISSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8261
ERROR_DS_OFFSET_RANGE_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8262
ERROR_DS_RIDMGR_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8263
ERROR_DS_ROOT_MUST_BE_NC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8301
ERROR_DS_ADD_REPLICA_INHIBITED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8302
ERROR_DS_ATT_NOT_DEF_IN_SCHEMA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8303
ERROR_DS_MAX_OBJ_SIZE_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8304
ERROR_DS_OBJ_STRING_NAME_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8305
ERROR_DS_NO_RDN_DEFINED_IN_SCHEMA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8306
ERROR_DS_RDN_DOESNT_MATCH_SCHEMA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8307
ERROR_DS_NO_REQUESTED_ATTS_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8308
ERROR_DS_USER_BUFFER_TO_SMALL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8309
ERROR_DS_ATT_IS_NOT_ON_OBJ: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8310
ERROR_DS_ILLEGAL_MOD_OPERATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8311
ERROR_DS_OBJ_TOO_LARGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8312
ERROR_DS_BAD_INSTANCE_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8313
ERROR_DS_MASTERDSA_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8314
ERROR_DS_OBJECT_CLASS_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8315
ERROR_DS_MISSING_REQUIRED_ATT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8316
ERROR_DS_ATT_NOT_DEF_FOR_CLASS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8317
ERROR_DS_ATT_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8318
ERROR_DS_CANT_ADD_ATT_VALUES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8320
ERROR_DS_SINGLE_VALUE_CONSTRAINT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8321
ERROR_DS_RANGE_CONSTRAINT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8322
ERROR_DS_ATT_VAL_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8323
ERROR_DS_CANT_REM_MISSING_ATT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8324
ERROR_DS_CANT_REM_MISSING_ATT_VAL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8325
ERROR_DS_ROOT_CANT_BE_SUBREF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8326
ERROR_DS_NO_CHAINING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8327
ERROR_DS_NO_CHAINED_EVAL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8328
ERROR_DS_NO_PARENT_OBJECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8329
ERROR_DS_PARENT_IS_AN_ALIAS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8330
ERROR_DS_CANT_MIX_MASTER_AND_REPS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8331
ERROR_DS_CHILDREN_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8332
ERROR_DS_OBJ_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8333
ERROR_DS_ALIASED_OBJ_MISSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8334
ERROR_DS_BAD_NAME_SYNTAX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8335
ERROR_DS_ALIAS_POINTS_TO_ALIAS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8336
ERROR_DS_CANT_DEREF_ALIAS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8337
ERROR_DS_OUT_OF_SCOPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8338
ERROR_DS_OBJECT_BEING_REMOVED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8339
ERROR_DS_CANT_DELETE_DSA_OBJ: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8340
ERROR_DS_GENERIC_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8341
ERROR_DS_DSA_MUST_BE_INT_MASTER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8342
ERROR_DS_CLASS_NOT_DSA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8343
ERROR_DS_INSUFF_ACCESS_RIGHTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8344
ERROR_DS_ILLEGAL_SUPERIOR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8345
ERROR_DS_ATTRIBUTE_OWNED_BY_SAM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8346
ERROR_DS_NAME_TOO_MANY_PARTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8347
ERROR_DS_NAME_TOO_LONG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8348
ERROR_DS_NAME_VALUE_TOO_LONG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8349
ERROR_DS_NAME_UNPARSEABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8350
ERROR_DS_NAME_TYPE_UNKNOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8351
ERROR_DS_NOT_AN_OBJECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8352
ERROR_DS_SEC_DESC_TOO_SHORT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8353
ERROR_DS_SEC_DESC_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8354
ERROR_DS_NO_DELETED_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8355
ERROR_DS_SUBREF_MUST_HAVE_PARENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8356
ERROR_DS_NCNAME_MUST_BE_NC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8357
ERROR_DS_CANT_ADD_SYSTEM_ONLY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8358
ERROR_DS_CLASS_MUST_BE_CONCRETE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8359
ERROR_DS_INVALID_DMD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8360
ERROR_DS_OBJ_GUID_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8361
ERROR_DS_NOT_ON_BACKLINK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8362
ERROR_DS_NO_CROSSREF_FOR_NC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8363
ERROR_DS_SHUTTING_DOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8364
ERROR_DS_UNKNOWN_OPERATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8365
ERROR_DS_INVALID_ROLE_OWNER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8366
ERROR_DS_COULDNT_CONTACT_FSMO: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8367
ERROR_DS_CROSS_NC_DN_RENAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8368
ERROR_DS_CANT_MOD_SYSTEM_ONLY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8369
ERROR_DS_REPLICATOR_ONLY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8370
ERROR_DS_OBJ_CLASS_NOT_DEFINED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8371
ERROR_DS_OBJ_CLASS_NOT_SUBCLASS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8372
ERROR_DS_NAME_REFERENCE_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8373
ERROR_DS_CROSS_REF_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8374
ERROR_DS_CANT_DEL_MASTER_CROSSREF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8375
ERROR_DS_SUBTREE_NOTIFY_NOT_NC_HEAD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8376
ERROR_DS_NOTIFY_FILTER_TOO_COMPLEX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8377
ERROR_DS_DUP_RDN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8378
ERROR_DS_DUP_OID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8379
ERROR_DS_DUP_MAPI_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8380
ERROR_DS_DUP_SCHEMA_ID_GUID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8381
ERROR_DS_DUP_LDAP_DISPLAY_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8382
ERROR_DS_SEMANTIC_ATT_TEST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8383
ERROR_DS_SYNTAX_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8384
ERROR_DS_EXISTS_IN_MUST_HAVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8385
ERROR_DS_EXISTS_IN_MAY_HAVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8386
ERROR_DS_NONEXISTENT_MAY_HAVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8387
ERROR_DS_NONEXISTENT_MUST_HAVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8388
ERROR_DS_AUX_CLS_TEST_FAIL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8389
ERROR_DS_NONEXISTENT_POSS_SUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8390
ERROR_DS_SUB_CLS_TEST_FAIL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8391
ERROR_DS_BAD_RDN_ATT_ID_SYNTAX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8392
ERROR_DS_EXISTS_IN_AUX_CLS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8393
ERROR_DS_EXISTS_IN_SUB_CLS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8394
ERROR_DS_EXISTS_IN_POSS_SUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8395
ERROR_DS_RECALCSCHEMA_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8396
ERROR_DS_TREE_DELETE_NOT_FINISHED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8397
ERROR_DS_CANT_DELETE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8398
ERROR_DS_ATT_SCHEMA_REQ_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8399
ERROR_DS_BAD_ATT_SCHEMA_SYNTAX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8400
ERROR_DS_CANT_CACHE_ATT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8401
ERROR_DS_CANT_CACHE_CLASS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8402
ERROR_DS_CANT_REMOVE_ATT_CACHE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8403
ERROR_DS_CANT_REMOVE_CLASS_CACHE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8404
ERROR_DS_CANT_RETRIEVE_DN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8405
ERROR_DS_MISSING_SUPREF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8406
ERROR_DS_CANT_RETRIEVE_INSTANCE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8407
ERROR_DS_CODE_INCONSISTENCY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8408
ERROR_DS_DATABASE_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8409
ERROR_DS_GOVERNSID_MISSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8410
ERROR_DS_MISSING_EXPECTED_ATT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8411
ERROR_DS_NCNAME_MISSING_CR_REF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8412
ERROR_DS_SECURITY_CHECKING_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8413
ERROR_DS_SCHEMA_NOT_LOADED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8414
ERROR_DS_SCHEMA_ALLOC_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8415
ERROR_DS_ATT_SCHEMA_REQ_SYNTAX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8416
ERROR_DS_GCVERIFY_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8417
ERROR_DS_DRA_SCHEMA_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8418
ERROR_DS_CANT_FIND_DSA_OBJ: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8419
ERROR_DS_CANT_FIND_EXPECTED_NC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8420
ERROR_DS_CANT_FIND_NC_IN_CACHE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8421
ERROR_DS_CANT_RETRIEVE_CHILD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8422
ERROR_DS_SECURITY_ILLEGAL_MODIFY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8423
ERROR_DS_CANT_REPLACE_HIDDEN_REC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8424
ERROR_DS_BAD_HIERARCHY_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8425
ERROR_DS_BUILD_HIERARCHY_TABLE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8426
ERROR_DS_CONFIG_PARAM_MISSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8427
ERROR_DS_COUNTING_AB_INDICES_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8428
ERROR_DS_HIERARCHY_TABLE_MALLOC_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8429
ERROR_DS_INTERNAL_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8430
ERROR_DS_UNKNOWN_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8431
ERROR_DS_ROOT_REQUIRES_CLASS_TOP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8432
ERROR_DS_REFUSING_FSMO_ROLES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8433
ERROR_DS_MISSING_FSMO_SETTINGS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8434
ERROR_DS_UNABLE_TO_SURRENDER_ROLES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8435
ERROR_DS_DRA_GENERIC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8436
ERROR_DS_DRA_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8437
ERROR_DS_DRA_BUSY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8438
ERROR_DS_DRA_BAD_DN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8439
ERROR_DS_DRA_BAD_NC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8440
ERROR_DS_DRA_DN_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8441
ERROR_DS_DRA_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8442
ERROR_DS_DRA_INCONSISTENT_DIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8443
ERROR_DS_DRA_CONNECTION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8444
ERROR_DS_DRA_BAD_INSTANCE_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8445
ERROR_DS_DRA_OUT_OF_MEM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8446
ERROR_DS_DRA_MAIL_PROBLEM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8447
ERROR_DS_DRA_REF_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8448
ERROR_DS_DRA_REF_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8449
ERROR_DS_DRA_OBJ_IS_REP_SOURCE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8450
ERROR_DS_DRA_DB_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8451
ERROR_DS_DRA_NO_REPLICA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8452
ERROR_DS_DRA_ACCESS_DENIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8453
ERROR_DS_DRA_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8454
ERROR_DS_DRA_RPC_CANCELLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8455
ERROR_DS_DRA_SOURCE_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8456
ERROR_DS_DRA_SINK_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8457
ERROR_DS_DRA_NAME_COLLISION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8458
ERROR_DS_DRA_SOURCE_REINSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8459
ERROR_DS_DRA_MISSING_PARENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8460
ERROR_DS_DRA_PREEMPTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8461
ERROR_DS_DRA_ABANDON_SYNC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8462
ERROR_DS_DRA_SHUTDOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8463
ERROR_DS_DRA_INCOMPATIBLE_PARTIAL_SET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8464
ERROR_DS_DRA_SOURCE_IS_PARTIAL_REPLICA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8465
ERROR_DS_DRA_EXTN_CONNECTION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8466
ERROR_DS_INSTALL_SCHEMA_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8467
ERROR_DS_DUP_LINK_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8468
ERROR_DS_NAME_ERROR_RESOLVING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8469
ERROR_DS_NAME_ERROR_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8470
ERROR_DS_NAME_ERROR_NOT_UNIQUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8471
ERROR_DS_NAME_ERROR_NO_MAPPING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8472
ERROR_DS_NAME_ERROR_DOMAIN_ONLY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8473
ERROR_DS_NAME_ERROR_NO_SYNTACTICAL_MAPPING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8474
ERROR_DS_CONSTRUCTED_ATT_MOD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8475
ERROR_DS_WRONG_OM_OBJ_CLASS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8476
ERROR_DS_DRA_REPL_PENDING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8477
ERROR_DS_DS_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8478
ERROR_DS_INVALID_LDAP_DISPLAY_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8479
ERROR_DS_NON_BASE_SEARCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8480
ERROR_DS_CANT_RETRIEVE_ATTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8481
ERROR_DS_BACKLINK_WITHOUT_LINK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8482
ERROR_DS_EPOCH_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8483
ERROR_DS_SRC_NAME_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8484
ERROR_DS_SRC_AND_DST_NC_IDENTICAL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8485
ERROR_DS_DST_NC_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8486
ERROR_DS_NOT_AUTHORITIVE_FOR_DST_NC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8487
ERROR_DS_SRC_GUID_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8488
ERROR_DS_CANT_MOVE_DELETED_OBJECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8489
ERROR_DS_PDC_OPERATION_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8490
ERROR_DS_CROSS_DOMAIN_CLEANUP_REQD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8491
ERROR_DS_ILLEGAL_XDOM_MOVE_OPERATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8492
ERROR_DS_CANT_WITH_ACCT_GROUP_MEMBERSHPS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8493
ERROR_DS_NC_MUST_HAVE_NC_PARENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8494
ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8495
ERROR_DS_DST_DOMAIN_NOT_NATIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8496
ERROR_DS_MISSING_INFRASTRUCTURE_CONTAINER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8497
ERROR_DS_CANT_MOVE_ACCOUNT_GROUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8498
ERROR_DS_CANT_MOVE_RESOURCE_GROUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8499
ERROR_DS_INVALID_SEARCH_FLAG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8500
ERROR_DS_NO_TREE_DELETE_ABOVE_NC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8501
ERROR_DS_COULDNT_LOCK_TREE_FOR_DELETE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8502
ERROR_DS_COULDNT_IDENTIFY_OBJECTS_FOR_TREE_DELETE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8503
ERROR_DS_SAM_INIT_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8504
ERROR_DS_SENSITIVE_GROUP_VIOLATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8505
ERROR_DS_CANT_MOD_PRIMARYGROUPID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8506
ERROR_DS_ILLEGAL_BASE_SCHEMA_MOD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8507
ERROR_DS_NONSAFE_SCHEMA_CHANGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8508
ERROR_DS_SCHEMA_UPDATE_DISALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8509
ERROR_DS_CANT_CREATE_UNDER_SCHEMA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8510
ERROR_DS_INSTALL_NO_SRC_SCH_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8511
ERROR_DS_INSTALL_NO_SCH_VERSION_IN_INIFILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8512
ERROR_DS_INVALID_GROUP_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8513
ERROR_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8514
ERROR_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8515
ERROR_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8516
ERROR_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8517
ERROR_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8518
ERROR_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8519
ERROR_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8520
ERROR_DS_HAVE_PRIMARY_MEMBERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8521
ERROR_DS_STRING_SD_CONVERSION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8522
ERROR_DS_NAMING_MASTER_GC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8523
ERROR_DS_DNS_LOOKUP_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8524
ERROR_DS_COULDNT_UPDATE_SPNS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8525
ERROR_DS_CANT_RETRIEVE_SD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8526
ERROR_DS_KEY_NOT_UNIQUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8527
ERROR_DS_WRONG_LINKED_ATT_SYNTAX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8528
ERROR_DS_SAM_NEED_BOOTKEY_PASSWORD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8529
ERROR_DS_SAM_NEED_BOOTKEY_FLOPPY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8530
ERROR_DS_CANT_START: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8531
ERROR_DS_INIT_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8532
ERROR_DS_NO_PKT_PRIVACY_ON_CONNECTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8533
ERROR_DS_SOURCE_DOMAIN_IN_FOREST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8534
ERROR_DS_DESTINATION_DOMAIN_NOT_IN_FOREST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8535
ERROR_DS_DESTINATION_AUDITING_NOT_ENABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8536
ERROR_DS_CANT_FIND_DC_FOR_SRC_DOMAIN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8537
ERROR_DS_SRC_OBJ_NOT_GROUP_OR_USER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8538
ERROR_DS_SRC_SID_EXISTS_IN_FOREST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8539
ERROR_DS_SRC_AND_DST_OBJECT_CLASS_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8540
ERROR_SAM_INIT_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8541
ERROR_DS_DRA_SCHEMA_INFO_SHIP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8542
ERROR_DS_DRA_SCHEMA_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8543
ERROR_DS_DRA_EARLIER_SCHEMA_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8544
ERROR_DS_DRA_OBJ_NC_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8545
ERROR_DS_NC_STILL_HAS_DSAS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8546
ERROR_DS_GC_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8547
ERROR_DS_LOCAL_MEMBER_OF_LOCAL_ONLY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8548
ERROR_DS_NO_FPO_IN_UNIVERSAL_GROUPS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8549
ERROR_DS_CANT_ADD_TO_GC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8550
ERROR_DS_NO_CHECKPOINT_WITH_PDC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8551
ERROR_DS_SOURCE_AUDITING_NOT_ENABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8552
ERROR_DS_CANT_CREATE_IN_NONDOMAIN_NC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8553
ERROR_DS_INVALID_NAME_FOR_SPN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8554
ERROR_DS_FILTER_USES_CONTRUCTED_ATTRS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8555
ERROR_DS_UNICODEPWD_NOT_IN_QUOTES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8556
ERROR_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8557
ERROR_DS_MUST_BE_RUN_ON_DST_DC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8558
ERROR_DS_SRC_DC_MUST_BE_SP4_OR_GREATER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8559
ERROR_DS_CANT_TREE_DELETE_CRITICAL_OBJ: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8560
ERROR_DS_INIT_FAILURE_CONSOLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8561
ERROR_DS_SAM_INIT_FAILURE_CONSOLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8562
ERROR_DS_FOREST_VERSION_TOO_HIGH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8563
ERROR_DS_DOMAIN_VERSION_TOO_HIGH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8564
ERROR_DS_FOREST_VERSION_TOO_LOW: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8565
ERROR_DS_DOMAIN_VERSION_TOO_LOW: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8566
ERROR_DS_INCOMPATIBLE_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8567
ERROR_DS_LOW_DSA_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8568
ERROR_DS_NO_BEHAVIOR_VERSION_IN_MIXEDDOMAIN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8569
ERROR_DS_NOT_SUPPORTED_SORT_ORDER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8570
ERROR_DS_NAME_NOT_UNIQUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8571
ERROR_DS_MACHINE_ACCOUNT_CREATED_PRENT4: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8572
ERROR_DS_OUT_OF_VERSION_STORE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8573
ERROR_DS_INCOMPATIBLE_CONTROLS_USED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8574
ERROR_DS_NO_REF_DOMAIN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8575
ERROR_DS_RESERVED_LINK_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8576
ERROR_DS_LINK_ID_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8577
ERROR_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8578
ERROR_DS_MODIFYDN_DISALLOWED_BY_INSTANCE_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8579
ERROR_DS_NO_OBJECT_MOVE_IN_SCHEMA_NC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8580
ERROR_DS_MODIFYDN_DISALLOWED_BY_FLAG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8581
ERROR_DS_MODIFYDN_WRONG_GRANDPARENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8582
ERROR_DS_NAME_ERROR_TRUST_REFERRAL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8583
ERROR_NOT_SUPPORTED_ON_STANDARD_SERVER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8584
ERROR_DS_CANT_ACCESS_REMOTE_PART_OF_AD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8585
ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE_V2: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8586
ERROR_DS_THREAD_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8587
ERROR_DS_NOT_CLOSEST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8588
ERROR_DS_CANT_DERIVE_SPN_WITHOUT_SERVER_REF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8589
ERROR_DS_SINGLE_USER_MODE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8590
ERROR_DS_NTDSCRIPT_SYNTAX_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8591
ERROR_DS_NTDSCRIPT_PROCESS_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8592
ERROR_DS_DIFFERENT_REPL_EPOCHS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8593
ERROR_DS_DRS_EXTENSIONS_CHANGED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8594
ERROR_DS_REPLICA_SET_CHANGE_NOT_ALLOWED_ON_DISABLED_CR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8595
ERROR_DS_NO_MSDS_INTID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8596
ERROR_DS_DUP_MSDS_INTID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8597
ERROR_DS_EXISTS_IN_RDNATTID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8598
ERROR_DS_AUTHORIZATION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8599
ERROR_DS_INVALID_SCRIPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8600
ERROR_DS_REMOTE_CROSSREF_OP_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8601
ERROR_DS_CROSS_REF_BUSY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8602
ERROR_DS_CANT_DERIVE_SPN_FOR_DELETED_DOMAIN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8603
ERROR_DS_CANT_DEMOTE_WITH_WRITEABLE_NC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8604
ERROR_DS_DUPLICATE_ID_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8605
ERROR_DS_INSUFFICIENT_ATTR_TO_CREATE_OBJECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8606
ERROR_DS_GROUP_CONVERSION_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8607
ERROR_DS_CANT_MOVE_APP_BASIC_GROUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8608
ERROR_DS_CANT_MOVE_APP_QUERY_GROUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8609
ERROR_DS_ROLE_NOT_VERIFIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8610
ERROR_DS_WKO_CONTAINER_CANNOT_BE_SPECIAL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8611
ERROR_DS_DOMAIN_RENAME_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8612
ERROR_DS_EXISTING_AD_CHILD_NC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8613
ERROR_DS_REPL_LIFETIME_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8614
ERROR_DS_DISALLOWED_IN_SYSTEM_CONTAINER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8615
ERROR_DS_LDAP_SEND_QUEUE_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8616
ERROR_DS_DRA_OUT_SCHEDULE_WINDOW: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8617
ERROR_DS_POLICY_NOT_KNOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8618
ERROR_NO_SITE_SETTINGS_OBJECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8619
ERROR_NO_SECRETS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8620
ERROR_NO_WRITABLE_DC_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8621
ERROR_DS_NO_SERVER_OBJECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8622
ERROR_DS_NO_NTDSA_OBJECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8623
ERROR_DS_NON_ASQ_SEARCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8624
ERROR_DS_AUDIT_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8625
ERROR_DS_INVALID_SEARCH_FLAG_SUBTREE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8626
ERROR_DS_INVALID_SEARCH_FLAG_TUPLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8627
ERROR_DS_HIERARCHY_TABLE_TOO_DEEP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8628
ERROR_DS_DRA_CORRUPT_UTD_VECTOR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8629
ERROR_DS_DRA_SECRETS_DENIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8630
ERROR_DS_RESERVED_MAPI_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8631
ERROR_DS_MAPI_ID_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8632
ERROR_DS_DRA_MISSING_KRBTGT_SECRET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8633
ERROR_DS_DOMAIN_NAME_EXISTS_IN_FOREST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8634
ERROR_DS_FLAT_NAME_EXISTS_IN_FOREST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8635
ERROR_INVALID_USER_PRINCIPAL_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8636
ERROR_DS_OID_MAPPED_GROUP_CANT_HAVE_MEMBERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8637
ERROR_DS_OID_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8638
ERROR_DS_DRA_RECYCLED_TARGET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8639
ERROR_DS_DISALLOWED_NC_REDIRECT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8640
ERROR_DS_HIGH_ADLDS_FFL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8641
ERROR_DS_HIGH_DSA_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8642
ERROR_DS_LOW_ADLDS_FFL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8643
ERROR_DOMAIN_SID_SAME_AS_LOCAL_WORKSTATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8644
ERROR_DS_UNDELETE_SAM_VALIDATION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8645
ERROR_INCORRECT_ACCOUNT_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8646
ERROR_DS_SPN_VALUE_NOT_UNIQUE_IN_FOREST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8647
ERROR_DS_UPN_VALUE_NOT_UNIQUE_IN_FOREST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8648
ERROR_DS_MISSING_FOREST_TRUST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8649
ERROR_DS_VALUE_KEY_NOT_UNIQUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8650
ERROR_WEAK_WHFBKEY_BLOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8651
ERROR_DS_PER_ATTRIBUTE_AUTHZ_FAILED_DURING_ADD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8652
ERROR_LOCAL_POLICY_MODIFICATION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8653
ERROR_POLICY_CONTROLLED_ACCOUNT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8654
ERROR_LAPS_LEGACY_SCHEMA_MISSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8655
ERROR_LAPS_SCHEMA_MISSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8656
ERROR_LAPS_ENCRYPTION_REQUIRES_2016_DFL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 8657
DNS_ERROR_RESPONSE_CODES_BASE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9000
DNS_ERROR_RCODE_NO_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 0
DNS_ERROR_MASK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9000
DNS_ERROR_RCODE_FORMAT_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9001
DNS_ERROR_RCODE_SERVER_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9002
DNS_ERROR_RCODE_NAME_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9003
DNS_ERROR_RCODE_NOT_IMPLEMENTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9004
DNS_ERROR_RCODE_REFUSED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9005
DNS_ERROR_RCODE_YXDOMAIN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9006
DNS_ERROR_RCODE_YXRRSET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9007
DNS_ERROR_RCODE_NXRRSET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9008
DNS_ERROR_RCODE_NOTAUTH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9009
DNS_ERROR_RCODE_NOTZONE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9010
DNS_ERROR_RCODE_BADSIG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9016
DNS_ERROR_RCODE_BADKEY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9017
DNS_ERROR_RCODE_BADTIME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9018
DNS_ERROR_RCODE_LAST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9018
DNS_ERROR_DNSSEC_BASE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9100
DNS_ERROR_KEYMASTER_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9101
DNS_ERROR_NOT_ALLOWED_ON_SIGNED_ZONE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9102
DNS_ERROR_NSEC3_INCOMPATIBLE_WITH_RSA_SHA1: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9103
DNS_ERROR_NOT_ENOUGH_SIGNING_KEY_DESCRIPTORS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9104
DNS_ERROR_UNSUPPORTED_ALGORITHM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9105
DNS_ERROR_INVALID_KEY_SIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9106
DNS_ERROR_SIGNING_KEY_NOT_ACCESSIBLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9107
DNS_ERROR_KSP_DOES_NOT_SUPPORT_PROTECTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9108
DNS_ERROR_UNEXPECTED_DATA_PROTECTION_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9109
DNS_ERROR_UNEXPECTED_CNG_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9110
DNS_ERROR_UNKNOWN_SIGNING_PARAMETER_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9111
DNS_ERROR_KSP_NOT_ACCESSIBLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9112
DNS_ERROR_TOO_MANY_SKDS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9113
DNS_ERROR_INVALID_ROLLOVER_PERIOD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9114
DNS_ERROR_INVALID_INITIAL_ROLLOVER_OFFSET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9115
DNS_ERROR_ROLLOVER_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9116
DNS_ERROR_STANDBY_KEY_NOT_PRESENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9117
DNS_ERROR_NOT_ALLOWED_ON_ZSK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9118
DNS_ERROR_NOT_ALLOWED_ON_ACTIVE_SKD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9119
DNS_ERROR_ROLLOVER_ALREADY_QUEUED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9120
DNS_ERROR_NOT_ALLOWED_ON_UNSIGNED_ZONE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9121
DNS_ERROR_BAD_KEYMASTER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9122
DNS_ERROR_INVALID_SIGNATURE_VALIDITY_PERIOD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9123
DNS_ERROR_INVALID_NSEC3_ITERATION_COUNT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9124
DNS_ERROR_DNSSEC_IS_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9125
DNS_ERROR_INVALID_XML: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9126
DNS_ERROR_NO_VALID_TRUST_ANCHORS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9127
DNS_ERROR_ROLLOVER_NOT_POKEABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9128
DNS_ERROR_NSEC3_NAME_COLLISION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9129
DNS_ERROR_NSEC_INCOMPATIBLE_WITH_NSEC3_RSA_SHA1: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9130
DNS_ERROR_PACKET_FMT_BASE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9500
DNS_ERROR_BAD_PACKET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9502
DNS_ERROR_NO_PACKET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9503
DNS_ERROR_RCODE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9504
DNS_ERROR_UNSECURE_PACKET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9505
DNS_ERROR_NO_MEMORY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14
DNS_ERROR_INVALID_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 123
DNS_ERROR_INVALID_DATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13
DNS_ERROR_GENERAL_API_BASE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9550
DNS_ERROR_INVALID_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9551
DNS_ERROR_INVALID_IP_ADDRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9552
DNS_ERROR_INVALID_PROPERTY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9553
DNS_ERROR_TRY_AGAIN_LATER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9554
DNS_ERROR_NOT_UNIQUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9555
DNS_ERROR_NON_RFC_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9556
DNS_ERROR_INVALID_NAME_CHAR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9560
DNS_ERROR_NUMERIC_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9561
DNS_ERROR_NOT_ALLOWED_ON_ROOT_SERVER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9562
DNS_ERROR_NOT_ALLOWED_UNDER_DELEGATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9563
DNS_ERROR_CANNOT_FIND_ROOT_HINTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9564
DNS_ERROR_INCONSISTENT_ROOT_HINTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9565
DNS_ERROR_DWORD_VALUE_TOO_SMALL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9566
DNS_ERROR_DWORD_VALUE_TOO_LARGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9567
DNS_ERROR_BACKGROUND_LOADING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9568
DNS_ERROR_NOT_ALLOWED_ON_RODC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9569
DNS_ERROR_NOT_ALLOWED_UNDER_DNAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9570
DNS_ERROR_DELEGATION_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9571
DNS_ERROR_INVALID_POLICY_TABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9572
DNS_ERROR_ADDRESS_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9573
DNS_ERROR_ZONE_BASE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9600
DNS_ERROR_ZONE_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9601
DNS_ERROR_NO_ZONE_INFO: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9602
DNS_ERROR_INVALID_ZONE_OPERATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9603
DNS_ERROR_ZONE_CONFIGURATION_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9604
DNS_ERROR_ZONE_HAS_NO_SOA_RECORD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9605
DNS_ERROR_ZONE_HAS_NO_NS_RECORDS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9606
DNS_ERROR_ZONE_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9607
DNS_ERROR_ZONE_CREATION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9608
DNS_ERROR_ZONE_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9609
DNS_ERROR_AUTOZONE_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9610
DNS_ERROR_INVALID_ZONE_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9611
DNS_ERROR_SECONDARY_REQUIRES_MASTER_IP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9612
DNS_ERROR_ZONE_NOT_SECONDARY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9613
DNS_ERROR_NEED_SECONDARY_ADDRESSES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9614
DNS_ERROR_WINS_INIT_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9615
DNS_ERROR_NEED_WINS_SERVERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9616
DNS_ERROR_NBSTAT_INIT_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9617
DNS_ERROR_SOA_DELETE_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9618
DNS_ERROR_FORWARDER_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9619
DNS_ERROR_ZONE_REQUIRES_MASTER_IP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9620
DNS_ERROR_ZONE_IS_SHUTDOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9621
DNS_ERROR_ZONE_LOCKED_FOR_SIGNING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9622
DNS_ERROR_DATAFILE_BASE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9650
DNS_ERROR_PRIMARY_REQUIRES_DATAFILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9651
DNS_ERROR_INVALID_DATAFILE_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9652
DNS_ERROR_DATAFILE_OPEN_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9653
DNS_ERROR_FILE_WRITEBACK_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9654
DNS_ERROR_DATAFILE_PARSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9655
DNS_ERROR_DATABASE_BASE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9700
DNS_ERROR_RECORD_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9701
DNS_ERROR_RECORD_FORMAT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9702
DNS_ERROR_NODE_CREATION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9703
DNS_ERROR_UNKNOWN_RECORD_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9704
DNS_ERROR_RECORD_TIMED_OUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9705
DNS_ERROR_NAME_NOT_IN_ZONE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9706
DNS_ERROR_CNAME_LOOP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9707
DNS_ERROR_NODE_IS_CNAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9708
DNS_ERROR_CNAME_COLLISION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9709
DNS_ERROR_RECORD_ONLY_AT_ZONE_ROOT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9710
DNS_ERROR_RECORD_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9711
DNS_ERROR_SECONDARY_DATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9712
DNS_ERROR_NO_CREATE_CACHE_DATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9713
DNS_ERROR_NAME_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9714
DNS_ERROR_DS_UNAVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9717
DNS_ERROR_DS_ZONE_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9718
DNS_ERROR_NO_BOOTFILE_IF_DS_ZONE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9719
DNS_ERROR_NODE_IS_DNAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9720
DNS_ERROR_DNAME_COLLISION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9721
DNS_ERROR_ALIAS_LOOP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9722
DNS_ERROR_OPERATION_BASE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9750
DNS_ERROR_AXFR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9752
DNS_ERROR_SECURE_BASE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9800
DNS_ERROR_SETUP_BASE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9850
DNS_ERROR_NO_TCPIP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9851
DNS_ERROR_NO_DNS_SERVERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9852
DNS_ERROR_DP_BASE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9900
DNS_ERROR_DP_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9901
DNS_ERROR_DP_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9902
DNS_ERROR_DP_NOT_ENLISTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9903
DNS_ERROR_DP_ALREADY_ENLISTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9904
DNS_ERROR_DP_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9905
DNS_ERROR_DP_FSMO_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9906
DNS_ERROR_RRL_NOT_ENABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9911
DNS_ERROR_RRL_INVALID_WINDOW_SIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9912
DNS_ERROR_RRL_INVALID_IPV4_PREFIX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9913
DNS_ERROR_RRL_INVALID_IPV6_PREFIX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9914
DNS_ERROR_RRL_INVALID_TC_RATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9915
DNS_ERROR_RRL_INVALID_LEAK_RATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9916
DNS_ERROR_RRL_LEAK_RATE_LESSTHAN_TC_RATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9917
DNS_ERROR_VIRTUALIZATION_INSTANCE_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9921
DNS_ERROR_VIRTUALIZATION_INSTANCE_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9922
DNS_ERROR_VIRTUALIZATION_TREE_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9923
DNS_ERROR_INVAILD_VIRTUALIZATION_INSTANCE_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9924
DNS_ERROR_DEFAULT_VIRTUALIZATION_INSTANCE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9925
DNS_ERROR_ZONESCOPE_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9951
DNS_ERROR_ZONESCOPE_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9952
DNS_ERROR_DEFAULT_ZONESCOPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9953
DNS_ERROR_INVALID_ZONESCOPE_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9954
DNS_ERROR_NOT_ALLOWED_WITH_ZONESCOPES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9955
DNS_ERROR_LOAD_ZONESCOPE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9956
DNS_ERROR_ZONESCOPE_FILE_WRITEBACK_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9957
DNS_ERROR_INVALID_SCOPE_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9958
DNS_ERROR_SCOPE_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9959
DNS_ERROR_DEFAULT_SCOPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9960
DNS_ERROR_INVALID_SCOPE_OPERATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9961
DNS_ERROR_SCOPE_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9962
DNS_ERROR_SCOPE_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9963
DNS_ERROR_POLICY_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9971
DNS_ERROR_POLICY_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9972
DNS_ERROR_POLICY_INVALID_CRITERIA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9973
DNS_ERROR_POLICY_INVALID_SETTINGS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9974
DNS_ERROR_CLIENT_SUBNET_IS_ACCESSED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9975
DNS_ERROR_CLIENT_SUBNET_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9976
DNS_ERROR_CLIENT_SUBNET_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9977
DNS_ERROR_SUBNET_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9978
DNS_ERROR_SUBNET_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9979
DNS_ERROR_POLICY_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9980
DNS_ERROR_POLICY_INVALID_WEIGHT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9981
DNS_ERROR_POLICY_INVALID_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9982
DNS_ERROR_POLICY_MISSING_CRITERIA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9983
DNS_ERROR_INVALID_CLIENT_SUBNET_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9984
DNS_ERROR_POLICY_PROCESSING_ORDER_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9985
DNS_ERROR_POLICY_SCOPE_MISSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9986
DNS_ERROR_POLICY_SCOPE_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9987
DNS_ERROR_SERVERSCOPE_IS_REFERENCED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9988
DNS_ERROR_ZONESCOPE_IS_REFERENCED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9989
DNS_ERROR_POLICY_INVALID_CRITERIA_CLIENT_SUBNET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9990
DNS_ERROR_POLICY_INVALID_CRITERIA_TRANSPORT_PROTOCOL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9991
DNS_ERROR_POLICY_INVALID_CRITERIA_NETWORK_PROTOCOL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9992
DNS_ERROR_POLICY_INVALID_CRITERIA_INTERFACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9993
DNS_ERROR_POLICY_INVALID_CRITERIA_FQDN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9994
DNS_ERROR_POLICY_INVALID_CRITERIA_QUERY_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9995
DNS_ERROR_POLICY_INVALID_CRITERIA_TIME_OF_DAY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 9996
ERROR_IPSEC_QM_POLICY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13000
ERROR_IPSEC_QM_POLICY_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13001
ERROR_IPSEC_QM_POLICY_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13002
ERROR_IPSEC_MM_POLICY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13003
ERROR_IPSEC_MM_POLICY_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13004
ERROR_IPSEC_MM_POLICY_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13005
ERROR_IPSEC_MM_FILTER_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13006
ERROR_IPSEC_MM_FILTER_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13007
ERROR_IPSEC_TRANSPORT_FILTER_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13008
ERROR_IPSEC_TRANSPORT_FILTER_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13009
ERROR_IPSEC_MM_AUTH_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13010
ERROR_IPSEC_MM_AUTH_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13011
ERROR_IPSEC_MM_AUTH_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13012
ERROR_IPSEC_DEFAULT_MM_POLICY_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13013
ERROR_IPSEC_DEFAULT_MM_AUTH_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13014
ERROR_IPSEC_DEFAULT_QM_POLICY_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13015
ERROR_IPSEC_TUNNEL_FILTER_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13016
ERROR_IPSEC_TUNNEL_FILTER_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13017
ERROR_IPSEC_MM_FILTER_PENDING_DELETION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13018
ERROR_IPSEC_TRANSPORT_FILTER_PENDING_DELETION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13019
ERROR_IPSEC_TUNNEL_FILTER_PENDING_DELETION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13020
ERROR_IPSEC_MM_POLICY_PENDING_DELETION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13021
ERROR_IPSEC_MM_AUTH_PENDING_DELETION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13022
ERROR_IPSEC_QM_POLICY_PENDING_DELETION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13023
ERROR_IPSEC_IKE_NEG_STATUS_BEGIN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13800
ERROR_IPSEC_IKE_AUTH_FAIL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13801
ERROR_IPSEC_IKE_ATTRIB_FAIL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13802
ERROR_IPSEC_IKE_NEGOTIATION_PENDING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13803
ERROR_IPSEC_IKE_GENERAL_PROCESSING_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13804
ERROR_IPSEC_IKE_TIMED_OUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13805
ERROR_IPSEC_IKE_NO_CERT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13806
ERROR_IPSEC_IKE_SA_DELETED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13807
ERROR_IPSEC_IKE_SA_REAPED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13808
ERROR_IPSEC_IKE_MM_ACQUIRE_DROP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13809
ERROR_IPSEC_IKE_QM_ACQUIRE_DROP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13810
ERROR_IPSEC_IKE_QUEUE_DROP_MM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13811
ERROR_IPSEC_IKE_QUEUE_DROP_NO_MM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13812
ERROR_IPSEC_IKE_DROP_NO_RESPONSE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13813
ERROR_IPSEC_IKE_MM_DELAY_DROP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13814
ERROR_IPSEC_IKE_QM_DELAY_DROP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13815
ERROR_IPSEC_IKE_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13816
ERROR_IPSEC_IKE_CRL_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13817
ERROR_IPSEC_IKE_INVALID_KEY_USAGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13818
ERROR_IPSEC_IKE_INVALID_CERT_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13819
ERROR_IPSEC_IKE_NO_PRIVATE_KEY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13820
ERROR_IPSEC_IKE_SIMULTANEOUS_REKEY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13821
ERROR_IPSEC_IKE_DH_FAIL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13822
ERROR_IPSEC_IKE_CRITICAL_PAYLOAD_NOT_RECOGNIZED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13823
ERROR_IPSEC_IKE_INVALID_HEADER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13824
ERROR_IPSEC_IKE_NO_POLICY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13825
ERROR_IPSEC_IKE_INVALID_SIGNATURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13826
ERROR_IPSEC_IKE_KERBEROS_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13827
ERROR_IPSEC_IKE_NO_PUBLIC_KEY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13828
ERROR_IPSEC_IKE_PROCESS_ERR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13829
ERROR_IPSEC_IKE_PROCESS_ERR_SA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13830
ERROR_IPSEC_IKE_PROCESS_ERR_PROP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13831
ERROR_IPSEC_IKE_PROCESS_ERR_TRANS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13832
ERROR_IPSEC_IKE_PROCESS_ERR_KE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13833
ERROR_IPSEC_IKE_PROCESS_ERR_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13834
ERROR_IPSEC_IKE_PROCESS_ERR_CERT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13835
ERROR_IPSEC_IKE_PROCESS_ERR_CERT_REQ: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13836
ERROR_IPSEC_IKE_PROCESS_ERR_HASH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13837
ERROR_IPSEC_IKE_PROCESS_ERR_SIG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13838
ERROR_IPSEC_IKE_PROCESS_ERR_NONCE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13839
ERROR_IPSEC_IKE_PROCESS_ERR_NOTIFY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13840
ERROR_IPSEC_IKE_PROCESS_ERR_DELETE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13841
ERROR_IPSEC_IKE_PROCESS_ERR_VENDOR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13842
ERROR_IPSEC_IKE_INVALID_PAYLOAD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13843
ERROR_IPSEC_IKE_LOAD_SOFT_SA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13844
ERROR_IPSEC_IKE_SOFT_SA_TORN_DOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13845
ERROR_IPSEC_IKE_INVALID_COOKIE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13846
ERROR_IPSEC_IKE_NO_PEER_CERT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13847
ERROR_IPSEC_IKE_PEER_CRL_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13848
ERROR_IPSEC_IKE_POLICY_CHANGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13849
ERROR_IPSEC_IKE_NO_MM_POLICY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13850
ERROR_IPSEC_IKE_NOTCBPRIV: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13851
ERROR_IPSEC_IKE_SECLOADFAIL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13852
ERROR_IPSEC_IKE_FAILSSPINIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13853
ERROR_IPSEC_IKE_FAILQUERYSSP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13854
ERROR_IPSEC_IKE_SRVACQFAIL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13855
ERROR_IPSEC_IKE_SRVQUERYCRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13856
ERROR_IPSEC_IKE_GETSPIFAIL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13857
ERROR_IPSEC_IKE_INVALID_FILTER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13858
ERROR_IPSEC_IKE_OUT_OF_MEMORY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13859
ERROR_IPSEC_IKE_ADD_UPDATE_KEY_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13860
ERROR_IPSEC_IKE_INVALID_POLICY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13861
ERROR_IPSEC_IKE_UNKNOWN_DOI: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13862
ERROR_IPSEC_IKE_INVALID_SITUATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13863
ERROR_IPSEC_IKE_DH_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13864
ERROR_IPSEC_IKE_INVALID_GROUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13865
ERROR_IPSEC_IKE_ENCRYPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13866
ERROR_IPSEC_IKE_DECRYPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13867
ERROR_IPSEC_IKE_POLICY_MATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13868
ERROR_IPSEC_IKE_UNSUPPORTED_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13869
ERROR_IPSEC_IKE_INVALID_HASH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13870
ERROR_IPSEC_IKE_INVALID_HASH_ALG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13871
ERROR_IPSEC_IKE_INVALID_HASH_SIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13872
ERROR_IPSEC_IKE_INVALID_ENCRYPT_ALG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13873
ERROR_IPSEC_IKE_INVALID_AUTH_ALG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13874
ERROR_IPSEC_IKE_INVALID_SIG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13875
ERROR_IPSEC_IKE_LOAD_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13876
ERROR_IPSEC_IKE_RPC_DELETE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13877
ERROR_IPSEC_IKE_BENIGN_REINIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13878
ERROR_IPSEC_IKE_INVALID_RESPONDER_LIFETIME_NOTIFY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13879
ERROR_IPSEC_IKE_INVALID_MAJOR_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13880
ERROR_IPSEC_IKE_INVALID_CERT_KEYLEN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13881
ERROR_IPSEC_IKE_MM_LIMIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13882
ERROR_IPSEC_IKE_NEGOTIATION_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13883
ERROR_IPSEC_IKE_QM_LIMIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13884
ERROR_IPSEC_IKE_MM_EXPIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13885
ERROR_IPSEC_IKE_PEER_MM_ASSUMED_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13886
ERROR_IPSEC_IKE_CERT_CHAIN_POLICY_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13887
ERROR_IPSEC_IKE_UNEXPECTED_MESSAGE_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13888
ERROR_IPSEC_IKE_INVALID_AUTH_PAYLOAD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13889
ERROR_IPSEC_IKE_DOS_COOKIE_SENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13890
ERROR_IPSEC_IKE_SHUTTING_DOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13891
ERROR_IPSEC_IKE_CGA_AUTH_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13892
ERROR_IPSEC_IKE_PROCESS_ERR_NATOA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13893
ERROR_IPSEC_IKE_INVALID_MM_FOR_QM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13894
ERROR_IPSEC_IKE_QM_EXPIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13895
ERROR_IPSEC_IKE_TOO_MANY_FILTERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13896
ERROR_IPSEC_IKE_NEG_STATUS_END: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13897
ERROR_IPSEC_IKE_KILL_DUMMY_NAP_TUNNEL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13898
ERROR_IPSEC_IKE_INNER_IP_ASSIGNMENT_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13899
ERROR_IPSEC_IKE_REQUIRE_CP_PAYLOAD_MISSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13900
ERROR_IPSEC_KEY_MODULE_IMPERSONATION_NEGOTIATION_PENDING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13901
ERROR_IPSEC_IKE_COEXISTENCE_SUPPRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13902
ERROR_IPSEC_IKE_RATELIMIT_DROP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13903
ERROR_IPSEC_IKE_PEER_DOESNT_SUPPORT_MOBIKE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13904
ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13905
ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13906
ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE_WITH_OPTIONAL_RETRY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13907
ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_AND_CERTMAP_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13908
ERROR_IPSEC_IKE_NEG_STATUS_EXTENDED_END: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13909
ERROR_IPSEC_BAD_SPI: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13910
ERROR_IPSEC_SA_LIFETIME_EXPIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13911
ERROR_IPSEC_WRONG_SA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13912
ERROR_IPSEC_REPLAY_CHECK_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13913
ERROR_IPSEC_INVALID_PACKET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13914
ERROR_IPSEC_INTEGRITY_CHECK_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13915
ERROR_IPSEC_CLEAR_TEXT_DROP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13916
ERROR_IPSEC_AUTH_FIREWALL_DROP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13917
ERROR_IPSEC_THROTTLE_DROP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13918
ERROR_IPSEC_DOSP_BLOCK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13925
ERROR_IPSEC_DOSP_RECEIVED_MULTICAST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13926
ERROR_IPSEC_DOSP_INVALID_PACKET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13927
ERROR_IPSEC_DOSP_STATE_LOOKUP_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13928
ERROR_IPSEC_DOSP_MAX_ENTRIES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13929
ERROR_IPSEC_DOSP_KEYMOD_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13930
ERROR_IPSEC_DOSP_NOT_INSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13931
ERROR_IPSEC_DOSP_MAX_PER_IP_RATELIMIT_QUEUES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 13932
ERROR_SXS_SECTION_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14000
ERROR_SXS_CANT_GEN_ACTCTX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14001
ERROR_SXS_INVALID_ACTCTXDATA_FORMAT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14002
ERROR_SXS_ASSEMBLY_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14003
ERROR_SXS_MANIFEST_FORMAT_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14004
ERROR_SXS_MANIFEST_PARSE_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14005
ERROR_SXS_ACTIVATION_CONTEXT_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14006
ERROR_SXS_KEY_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14007
ERROR_SXS_VERSION_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14008
ERROR_SXS_WRONG_SECTION_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14009
ERROR_SXS_THREAD_QUERIES_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14010
ERROR_SXS_PROCESS_DEFAULT_ALREADY_SET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14011
ERROR_SXS_UNKNOWN_ENCODING_GROUP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14012
ERROR_SXS_UNKNOWN_ENCODING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14013
ERROR_SXS_INVALID_XML_NAMESPACE_URI: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14014
ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_NOT_INSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14015
ERROR_SXS_LEAF_MANIFEST_DEPENDENCY_NOT_INSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14016
ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14017
ERROR_SXS_MANIFEST_MISSING_REQUIRED_DEFAULT_NAMESPACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14018
ERROR_SXS_MANIFEST_INVALID_REQUIRED_DEFAULT_NAMESPACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14019
ERROR_SXS_PRIVATE_MANIFEST_CROSS_PATH_WITH_REPARSE_POINT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14020
ERROR_SXS_DUPLICATE_DLL_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14021
ERROR_SXS_DUPLICATE_WINDOWCLASS_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14022
ERROR_SXS_DUPLICATE_CLSID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14023
ERROR_SXS_DUPLICATE_IID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14024
ERROR_SXS_DUPLICATE_TLBID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14025
ERROR_SXS_DUPLICATE_PROGID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14026
ERROR_SXS_DUPLICATE_ASSEMBLY_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14027
ERROR_SXS_FILE_HASH_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14028
ERROR_SXS_POLICY_PARSE_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14029
ERROR_SXS_XML_E_MISSINGQUOTE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14030
ERROR_SXS_XML_E_COMMENTSYNTAX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14031
ERROR_SXS_XML_E_BADSTARTNAMECHAR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14032
ERROR_SXS_XML_E_BADNAMECHAR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14033
ERROR_SXS_XML_E_BADCHARINSTRING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14034
ERROR_SXS_XML_E_XMLDECLSYNTAX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14035
ERROR_SXS_XML_E_BADCHARDATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14036
ERROR_SXS_XML_E_MISSINGWHITESPACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14037
ERROR_SXS_XML_E_EXPECTINGTAGEND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14038
ERROR_SXS_XML_E_MISSINGSEMICOLON: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14039
ERROR_SXS_XML_E_UNBALANCEDPAREN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14040
ERROR_SXS_XML_E_INTERNALERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14041
ERROR_SXS_XML_E_UNEXPECTED_WHITESPACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14042
ERROR_SXS_XML_E_INCOMPLETE_ENCODING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14043
ERROR_SXS_XML_E_MISSING_PAREN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14044
ERROR_SXS_XML_E_EXPECTINGCLOSEQUOTE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14045
ERROR_SXS_XML_E_MULTIPLE_COLONS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14046
ERROR_SXS_XML_E_INVALID_DECIMAL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14047
ERROR_SXS_XML_E_INVALID_HEXIDECIMAL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14048
ERROR_SXS_XML_E_INVALID_UNICODE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14049
ERROR_SXS_XML_E_WHITESPACEORQUESTIONMARK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14050
ERROR_SXS_XML_E_UNEXPECTEDENDTAG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14051
ERROR_SXS_XML_E_UNCLOSEDTAG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14052
ERROR_SXS_XML_E_DUPLICATEATTRIBUTE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14053
ERROR_SXS_XML_E_MULTIPLEROOTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14054
ERROR_SXS_XML_E_INVALIDATROOTLEVEL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14055
ERROR_SXS_XML_E_BADXMLDECL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14056
ERROR_SXS_XML_E_MISSINGROOT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14057
ERROR_SXS_XML_E_UNEXPECTEDEOF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14058
ERROR_SXS_XML_E_BADPEREFINSUBSET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14059
ERROR_SXS_XML_E_UNCLOSEDSTARTTAG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14060
ERROR_SXS_XML_E_UNCLOSEDENDTAG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14061
ERROR_SXS_XML_E_UNCLOSEDSTRING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14062
ERROR_SXS_XML_E_UNCLOSEDCOMMENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14063
ERROR_SXS_XML_E_UNCLOSEDDECL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14064
ERROR_SXS_XML_E_UNCLOSEDCDATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14065
ERROR_SXS_XML_E_RESERVEDNAMESPACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14066
ERROR_SXS_XML_E_INVALIDENCODING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14067
ERROR_SXS_XML_E_INVALIDSWITCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14068
ERROR_SXS_XML_E_BADXMLCASE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14069
ERROR_SXS_XML_E_INVALID_STANDALONE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14070
ERROR_SXS_XML_E_UNEXPECTED_STANDALONE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14071
ERROR_SXS_XML_E_INVALID_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14072
ERROR_SXS_XML_E_MISSINGEQUALS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14073
ERROR_SXS_PROTECTION_RECOVERY_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14074
ERROR_SXS_PROTECTION_PUBLIC_KEY_TOO_SHORT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14075
ERROR_SXS_PROTECTION_CATALOG_NOT_VALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14076
ERROR_SXS_UNTRANSLATABLE_HRESULT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14077
ERROR_SXS_PROTECTION_CATALOG_FILE_MISSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14078
ERROR_SXS_MISSING_ASSEMBLY_IDENTITY_ATTRIBUTE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14079
ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14080
ERROR_SXS_ASSEMBLY_MISSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14081
ERROR_SXS_CORRUPT_ACTIVATION_STACK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14082
ERROR_SXS_CORRUPTION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14083
ERROR_SXS_EARLY_DEACTIVATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14084
ERROR_SXS_INVALID_DEACTIVATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14085
ERROR_SXS_MULTIPLE_DEACTIVATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14086
ERROR_SXS_PROCESS_TERMINATION_REQUESTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14087
ERROR_SXS_RELEASE_ACTIVATION_CONTEXT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14088
ERROR_SXS_SYSTEM_DEFAULT_ACTIVATION_CONTEXT_EMPTY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14089
ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_VALUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14090
ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14091
ERROR_SXS_IDENTITY_DUPLICATE_ATTRIBUTE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14092
ERROR_SXS_IDENTITY_PARSE_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14093
ERROR_MALFORMED_SUBSTITUTION_STRING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14094
ERROR_SXS_INCORRECT_PUBLIC_KEY_TOKEN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14095
ERROR_UNMAPPED_SUBSTITUTION_STRING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14096
ERROR_SXS_ASSEMBLY_NOT_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14097
ERROR_SXS_COMPONENT_STORE_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14098
ERROR_ADVANCED_INSTALLER_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14099
ERROR_XML_ENCODING_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14100
ERROR_SXS_MANIFEST_IDENTITY_SAME_BUT_CONTENTS_DIFFERENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14101
ERROR_SXS_IDENTITIES_DIFFERENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14102
ERROR_SXS_ASSEMBLY_IS_NOT_A_DEPLOYMENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14103
ERROR_SXS_FILE_NOT_PART_OF_ASSEMBLY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14104
ERROR_SXS_MANIFEST_TOO_BIG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14105
ERROR_SXS_SETTING_NOT_REGISTERED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14106
ERROR_SXS_TRANSACTION_CLOSURE_INCOMPLETE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14107
ERROR_SMI_PRIMITIVE_INSTALLER_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14108
ERROR_GENERIC_COMMAND_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14109
ERROR_SXS_FILE_HASH_MISSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14110
ERROR_SXS_DUPLICATE_ACTIVATABLE_CLASS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 14111
ERROR_EVT_INVALID_CHANNEL_PATH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15000
ERROR_EVT_INVALID_QUERY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15001
ERROR_EVT_PUBLISHER_METADATA_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15002
ERROR_EVT_EVENT_TEMPLATE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15003
ERROR_EVT_INVALID_PUBLISHER_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15004
ERROR_EVT_INVALID_EVENT_DATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15005
ERROR_EVT_CHANNEL_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15007
ERROR_EVT_MALFORMED_XML_TEXT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15008
ERROR_EVT_SUBSCRIPTION_TO_DIRECT_CHANNEL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15009
ERROR_EVT_CONFIGURATION_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15010
ERROR_EVT_QUERY_RESULT_STALE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15011
ERROR_EVT_QUERY_RESULT_INVALID_POSITION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15012
ERROR_EVT_NON_VALIDATING_MSXML: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15013
ERROR_EVT_FILTER_ALREADYSCOPED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15014
ERROR_EVT_FILTER_NOTELTSET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15015
ERROR_EVT_FILTER_INVARG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15016
ERROR_EVT_FILTER_INVTEST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15017
ERROR_EVT_FILTER_INVTYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15018
ERROR_EVT_FILTER_PARSEERR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15019
ERROR_EVT_FILTER_UNSUPPORTEDOP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15020
ERROR_EVT_FILTER_UNEXPECTEDTOKEN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15021
ERROR_EVT_INVALID_OPERATION_OVER_ENABLED_DIRECT_CHANNEL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15022
ERROR_EVT_INVALID_CHANNEL_PROPERTY_VALUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15023
ERROR_EVT_INVALID_PUBLISHER_PROPERTY_VALUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15024
ERROR_EVT_CHANNEL_CANNOT_ACTIVATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15025
ERROR_EVT_FILTER_TOO_COMPLEX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15026
ERROR_EVT_MESSAGE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15027
ERROR_EVT_MESSAGE_ID_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15028
ERROR_EVT_UNRESOLVED_VALUE_INSERT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15029
ERROR_EVT_UNRESOLVED_PARAMETER_INSERT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15030
ERROR_EVT_MAX_INSERTS_REACHED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15031
ERROR_EVT_EVENT_DEFINITION_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15032
ERROR_EVT_MESSAGE_LOCALE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15033
ERROR_EVT_VERSION_TOO_OLD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15034
ERROR_EVT_VERSION_TOO_NEW: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15035
ERROR_EVT_CANNOT_OPEN_CHANNEL_OF_QUERY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15036
ERROR_EVT_PUBLISHER_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15037
ERROR_EVT_FILTER_OUT_OF_RANGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15038
ERROR_EC_SUBSCRIPTION_CANNOT_ACTIVATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15080
ERROR_EC_LOG_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15081
ERROR_EC_CIRCULAR_FORWARDING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15082
ERROR_EC_CREDSTORE_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15083
ERROR_EC_CRED_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15084
ERROR_EC_NO_ACTIVE_CHANNEL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15085
ERROR_MUI_FILE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15100
ERROR_MUI_INVALID_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15101
ERROR_MUI_INVALID_RC_CONFIG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15102
ERROR_MUI_INVALID_LOCALE_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15103
ERROR_MUI_INVALID_ULTIMATEFALLBACK_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15104
ERROR_MUI_FILE_NOT_LOADED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15105
ERROR_RESOURCE_ENUM_USER_STOP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15106
ERROR_MUI_INTLSETTINGS_UILANG_NOT_INSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15107
ERROR_MUI_INTLSETTINGS_INVALID_LOCALE_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15108
ERROR_MRM_RUNTIME_NO_DEFAULT_OR_NEUTRAL_RESOURCE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15110
ERROR_MRM_INVALID_PRICONFIG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15111
ERROR_MRM_INVALID_FILE_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15112
ERROR_MRM_UNKNOWN_QUALIFIER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15113
ERROR_MRM_INVALID_QUALIFIER_VALUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15114
ERROR_MRM_NO_CANDIDATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15115
ERROR_MRM_NO_MATCH_OR_DEFAULT_CANDIDATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15116
ERROR_MRM_RESOURCE_TYPE_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15117
ERROR_MRM_DUPLICATE_MAP_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15118
ERROR_MRM_DUPLICATE_ENTRY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15119
ERROR_MRM_INVALID_RESOURCE_IDENTIFIER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15120
ERROR_MRM_FILEPATH_TOO_LONG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15121
ERROR_MRM_UNSUPPORTED_DIRECTORY_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15122
ERROR_MRM_INVALID_PRI_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15126
ERROR_MRM_NAMED_RESOURCE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15127
ERROR_MRM_MAP_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15135
ERROR_MRM_UNSUPPORTED_PROFILE_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15136
ERROR_MRM_INVALID_QUALIFIER_OPERATOR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15137
ERROR_MRM_INDETERMINATE_QUALIFIER_VALUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15138
ERROR_MRM_AUTOMERGE_ENABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15139
ERROR_MRM_TOO_MANY_RESOURCES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15140
ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_MERGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15141
ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_LOAD_UNLOAD_PRI_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15142
ERROR_MRM_NO_CURRENT_VIEW_ON_THREAD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15143
ERROR_DIFFERENT_PROFILE_RESOURCE_MANAGER_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15144
ERROR_OPERATION_NOT_ALLOWED_FROM_SYSTEM_COMPONENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15145
ERROR_MRM_DIRECT_REF_TO_NON_DEFAULT_RESOURCE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15146
ERROR_MRM_GENERATION_COUNT_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15147
ERROR_PRI_MERGE_VERSION_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15148
ERROR_PRI_MERGE_MISSING_SCHEMA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15149
ERROR_PRI_MERGE_LOAD_FILE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15150
ERROR_PRI_MERGE_ADD_FILE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15151
ERROR_PRI_MERGE_WRITE_FILE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15152
ERROR_PRI_MERGE_MULTIPLE_PACKAGE_FAMILIES_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15153
ERROR_PRI_MERGE_MULTIPLE_MAIN_PACKAGES_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15154
ERROR_PRI_MERGE_BUNDLE_PACKAGES_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15155
ERROR_PRI_MERGE_MAIN_PACKAGE_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15156
ERROR_PRI_MERGE_RESOURCE_PACKAGE_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15157
ERROR_PRI_MERGE_INVALID_FILE_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15158
ERROR_MRM_PACKAGE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15159
ERROR_MRM_MISSING_DEFAULT_LANGUAGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15160
ERROR_MRM_SCOPE_ITEM_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15161
ERROR_MCA_INVALID_CAPABILITIES_STRING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15200
ERROR_MCA_INVALID_VCP_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15201
ERROR_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15202
ERROR_MCA_MCCS_VERSION_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15203
ERROR_MCA_UNSUPPORTED_MCCS_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15204
ERROR_MCA_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15205
ERROR_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15206
ERROR_MCA_UNSUPPORTED_COLOR_TEMPERATURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15207
ERROR_AMBIGUOUS_SYSTEM_DEVICE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15250
ERROR_SYSTEM_DEVICE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15299
ERROR_HASH_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15300
ERROR_HASH_NOT_PRESENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15301
ERROR_SECONDARY_IC_PROVIDER_NOT_REGISTERED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15321
ERROR_GPIO_CLIENT_INFORMATION_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15322
ERROR_GPIO_VERSION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15323
ERROR_GPIO_INVALID_REGISTRATION_PACKET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15324
ERROR_GPIO_OPERATION_DENIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15325
ERROR_GPIO_INCOMPATIBLE_CONNECT_MODE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15326
ERROR_GPIO_INTERRUPT_ALREADY_UNMASKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15327
ERROR_CANNOT_SWITCH_RUNLEVEL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15400
ERROR_INVALID_RUNLEVEL_SETTING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15401
ERROR_RUNLEVEL_SWITCH_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15402
ERROR_RUNLEVEL_SWITCH_AGENT_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15403
ERROR_RUNLEVEL_SWITCH_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15404
ERROR_SERVICES_FAILED_AUTOSTART: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15405
ERROR_COM_TASK_STOP_PENDING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15501
ERROR_INSTALL_OPEN_PACKAGE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15600
ERROR_INSTALL_PACKAGE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15601
ERROR_INSTALL_INVALID_PACKAGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15602
ERROR_INSTALL_RESOLVE_DEPENDENCY_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15603
ERROR_INSTALL_OUT_OF_DISK_SPACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15604
ERROR_INSTALL_NETWORK_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15605
ERROR_INSTALL_REGISTRATION_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15606
ERROR_INSTALL_DEREGISTRATION_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15607
ERROR_INSTALL_CANCEL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15608
ERROR_INSTALL_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15609
ERROR_REMOVE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15610
ERROR_PACKAGE_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15611
ERROR_NEEDS_REMEDIATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15612
ERROR_INSTALL_PREREQUISITE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15613
ERROR_PACKAGE_REPOSITORY_CORRUPTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15614
ERROR_INSTALL_POLICY_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15615
ERROR_PACKAGE_UPDATING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15616
ERROR_DEPLOYMENT_BLOCKED_BY_POLICY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15617
ERROR_PACKAGES_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15618
ERROR_RECOVERY_FILE_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15619
ERROR_INVALID_STAGED_SIGNATURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15620
ERROR_DELETING_EXISTING_APPLICATIONDATA_STORE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15621
ERROR_INSTALL_PACKAGE_DOWNGRADE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15622
ERROR_SYSTEM_NEEDS_REMEDIATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15623
ERROR_APPX_INTEGRITY_FAILURE_CLR_NGEN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15624
ERROR_RESILIENCY_FILE_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15625
ERROR_INSTALL_FIREWALL_SERVICE_NOT_RUNNING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15626
ERROR_PACKAGE_MOVE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15627
ERROR_INSTALL_VOLUME_NOT_EMPTY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15628
ERROR_INSTALL_VOLUME_OFFLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15629
ERROR_INSTALL_VOLUME_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15630
ERROR_NEEDS_REGISTRATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15631
ERROR_INSTALL_WRONG_PROCESSOR_ARCHITECTURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15632
ERROR_DEV_SIDELOAD_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15633
ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15634
ERROR_PACKAGE_NOT_SUPPORTED_ON_FILESYSTEM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15635
ERROR_PACKAGE_MOVE_BLOCKED_BY_STREAMING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15636
ERROR_INSTALL_OPTIONAL_PACKAGE_APPLICATIONID_NOT_UNIQUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15637
ERROR_PACKAGE_STAGING_ONHOLD: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15638
ERROR_INSTALL_INVALID_RELATED_SET_UPDATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15639
ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15640
ERROR_DEPLOYMENT_BLOCKED_BY_USER_LOG_OFF: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15641
ERROR_PROVISION_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_PROVISIONED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15642
ERROR_PACKAGES_REPUTATION_CHECK_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15643
ERROR_PACKAGES_REPUTATION_CHECK_TIMEDOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15644
ERROR_DEPLOYMENT_OPTION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15645
ERROR_APPINSTALLER_ACTIVATION_BLOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15646
ERROR_REGISTRATION_FROM_REMOTE_DRIVE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15647
ERROR_APPX_RAW_DATA_WRITE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15648
ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_PACKAGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15649
ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_MACHINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15650
ERROR_DEPLOYMENT_BLOCKED_BY_PROFILE_POLICY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15651
ERROR_DEPLOYMENT_FAILED_CONFLICTING_MUTABLE_PACKAGE_DIRECTORY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15652
ERROR_SINGLETON_RESOURCE_INSTALLED_IN_ACTIVE_USER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15653
ERROR_DIFFERENT_VERSION_OF_PACKAGED_SERVICE_INSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15654
ERROR_SERVICE_EXISTS_AS_NON_PACKAGED_SERVICE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15655
ERROR_PACKAGED_SERVICE_REQUIRES_ADMIN_PRIVILEGES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15656
ERROR_REDIRECTION_TO_DEFAULT_ACCOUNT_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15657
ERROR_PACKAGE_LACKS_CAPABILITY_TO_DEPLOY_ON_HOST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15658
ERROR_UNSIGNED_PACKAGE_INVALID_CONTENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15659
ERROR_UNSIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15660
ERROR_SIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15661
ERROR_PACKAGE_EXTERNAL_LOCATION_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15662
ERROR_INSTALL_FULLTRUST_HOSTRUNTIME_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15663
ERROR_PACKAGE_LACKS_CAPABILITY_FOR_MANDATORY_STARTUPTASKS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15664
ERROR_INSTALL_RESOLVE_HOSTRUNTIME_DEPENDENCY_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15665
ERROR_MACHINE_SCOPE_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15666
ERROR_CLASSIC_COMPAT_MODE_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15667
ERROR_STAGEFROMUPDATEAGENT_PACKAGE_NOT_APPLICABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15668
ERROR_PACKAGE_NOT_REGISTERED_FOR_USER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15669
ERROR_PACKAGE_NAME_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15670
ERROR_APPINSTALLER_URI_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15671
ERROR_APPINSTALLER_IS_MANAGED_BY_SYSTEM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15672
APPMODEL_ERROR_NO_PACKAGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15700
APPMODEL_ERROR_PACKAGE_RUNTIME_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15701
APPMODEL_ERROR_PACKAGE_IDENTITY_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15702
APPMODEL_ERROR_NO_APPLICATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15703
APPMODEL_ERROR_DYNAMIC_PROPERTY_READ_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15704
APPMODEL_ERROR_DYNAMIC_PROPERTY_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15705
APPMODEL_ERROR_PACKAGE_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15706
APPMODEL_ERROR_NO_MUTABLE_DIRECTORY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15707
ERROR_STATE_LOAD_STORE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15800
ERROR_STATE_GET_VERSION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15801
ERROR_STATE_SET_VERSION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15802
ERROR_STATE_STRUCTURED_RESET_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15803
ERROR_STATE_OPEN_CONTAINER_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15804
ERROR_STATE_CREATE_CONTAINER_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15805
ERROR_STATE_DELETE_CONTAINER_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15806
ERROR_STATE_READ_SETTING_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15807
ERROR_STATE_WRITE_SETTING_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15808
ERROR_STATE_DELETE_SETTING_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15809
ERROR_STATE_QUERY_SETTING_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15810
ERROR_STATE_READ_COMPOSITE_SETTING_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15811
ERROR_STATE_WRITE_COMPOSITE_SETTING_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15812
ERROR_STATE_ENUMERATE_CONTAINER_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15813
ERROR_STATE_ENUMERATE_SETTINGS_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15814
ERROR_STATE_COMPOSITE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15815
ERROR_STATE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15816
ERROR_STATE_SETTING_NAME_SIZE_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15817
ERROR_STATE_CONTAINER_NAME_SIZE_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15818
ERROR_API_UNAVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 15841
ERROR_NDIS_INTERFACE_CLOSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891522
ERROR_NDIS_BAD_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891524
ERROR_NDIS_BAD_CHARACTERISTICS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891525
ERROR_NDIS_ADAPTER_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891526
ERROR_NDIS_OPEN_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891527
ERROR_NDIS_DEVICE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891528
ERROR_NDIS_MULTICAST_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891529
ERROR_NDIS_MULTICAST_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891530
ERROR_NDIS_MULTICAST_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891531
ERROR_NDIS_REQUEST_ABORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891532
ERROR_NDIS_RESET_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891533
ERROR_NDIS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891707
ERROR_NDIS_INVALID_PACKET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891535
ERROR_NDIS_ADAPTER_NOT_READY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891537
ERROR_NDIS_INVALID_LENGTH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891540
ERROR_NDIS_INVALID_DATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891541
ERROR_NDIS_BUFFER_TOO_SHORT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891542
ERROR_NDIS_INVALID_OID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891543
ERROR_NDIS_ADAPTER_REMOVED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891544
ERROR_NDIS_UNSUPPORTED_MEDIA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891545
ERROR_NDIS_GROUP_ADDRESS_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891546
ERROR_NDIS_FILE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891547
ERROR_NDIS_ERROR_READING_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891548
ERROR_NDIS_ALREADY_MAPPED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891549
ERROR_NDIS_RESOURCE_CONFLICT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891550
ERROR_NDIS_MEDIA_DISCONNECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891551
ERROR_NDIS_INVALID_ADDRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891554
ERROR_NDIS_INVALID_DEVICE_REQUEST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891536
ERROR_NDIS_PAUSED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891562
ERROR_NDIS_INTERFACE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891563
ERROR_NDIS_UNSUPPORTED_REVISION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891564
ERROR_NDIS_INVALID_PORT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891565
ERROR_NDIS_INVALID_PORT_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891566
ERROR_NDIS_LOW_POWER_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891567
ERROR_NDIS_REINIT_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891568
ERROR_NDIS_NO_QUEUES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150891569
ERROR_NDIS_DOT11_AUTO_CONFIG_ENABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150899712
ERROR_NDIS_DOT11_MEDIA_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150899713
ERROR_NDIS_DOT11_POWER_STATE_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150899714
ERROR_NDIS_PM_WOL_PATTERN_LIST_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150899715
ERROR_NDIS_PM_PROTOCOL_OFFLOAD_LIST_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150899716
ERROR_NDIS_DOT11_AP_CHANNEL_CURRENTLY_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150899717
ERROR_NDIS_DOT11_AP_BAND_CURRENTLY_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150899718
ERROR_NDIS_DOT11_AP_CHANNEL_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150899719
ERROR_NDIS_DOT11_AP_BAND_NOT_ALLOWED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2150899720
ERROR_NDIS_INDICATION_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3407873
ERROR_NDIS_OFFLOAD_POLICY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224637455
ERROR_NDIS_OFFLOAD_CONNECTION_REJECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224637458
ERROR_NDIS_OFFLOAD_PATH_REJECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224637459
ERROR_HV_INVALID_HYPERCALL_CODE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698882
ERROR_HV_INVALID_HYPERCALL_INPUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698883
ERROR_HV_INVALID_ALIGNMENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698884
ERROR_HV_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698885
ERROR_HV_ACCESS_DENIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698886
ERROR_HV_INVALID_PARTITION_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698887
ERROR_HV_OPERATION_DENIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698888
ERROR_HV_UNKNOWN_PROPERTY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698889
ERROR_HV_PROPERTY_VALUE_OUT_OF_RANGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698890
ERROR_HV_INSUFFICIENT_MEMORY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698891
ERROR_HV_PARTITION_TOO_DEEP: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698892
ERROR_HV_INVALID_PARTITION_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698893
ERROR_HV_INVALID_VP_INDEX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698894
ERROR_HV_INVALID_PORT_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698897
ERROR_HV_INVALID_CONNECTION_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698898
ERROR_HV_INSUFFICIENT_BUFFERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698899
ERROR_HV_NOT_ACKNOWLEDGED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698900
ERROR_HV_INVALID_VP_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698901
ERROR_HV_ACKNOWLEDGED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698902
ERROR_HV_INVALID_SAVE_RESTORE_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698903
ERROR_HV_INVALID_SYNIC_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698904
ERROR_HV_OBJECT_IN_USE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698905
ERROR_HV_INVALID_PROXIMITY_DOMAIN_INFO: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698906
ERROR_HV_NO_DATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698907
ERROR_HV_INACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698908
ERROR_HV_NO_RESOURCES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698909
ERROR_HV_FEATURE_UNAVAILABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698910
ERROR_HV_INSUFFICIENT_BUFFER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698931
ERROR_HV_INSUFFICIENT_DEVICE_DOMAINS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698936
ERROR_HV_CPUID_FEATURE_VALIDATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698940
ERROR_HV_CPUID_XSAVE_FEATURE_VALIDATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698941
ERROR_HV_PROCESSOR_STARTUP_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698942
ERROR_HV_SMX_ENABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698943
ERROR_HV_INVALID_LP_INDEX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698945
ERROR_HV_INVALID_REGISTER_VALUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698960
ERROR_HV_INVALID_VTL_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698961
ERROR_HV_NX_NOT_DETECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698965
ERROR_HV_INVALID_DEVICE_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698967
ERROR_HV_INVALID_DEVICE_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698968
ERROR_HV_PENDING_PAGE_REQUESTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3473497
ERROR_HV_PAGE_REQUEST_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698976
ERROR_HV_INVALID_CPU_GROUP_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698991
ERROR_HV_INVALID_CPU_GROUP_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698992
ERROR_HV_OPERATION_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698993
ERROR_HV_NOT_ALLOWED_WITH_NESTED_VIRT_ACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698994
ERROR_HV_INSUFFICIENT_ROOT_MEMORY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698995
ERROR_HV_EVENT_BUFFER_ALREADY_FREED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698996
ERROR_HV_INSUFFICIENT_CONTIGUOUS_MEMORY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698997
ERROR_HV_DEVICE_NOT_IN_DOMAIN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698998
ERROR_HV_NESTED_VM_EXIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224698999
ERROR_HV_MSR_ACCESS_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224699008
ERROR_HV_INSUFFICIENT_MEMORY_MIRRORING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224699009
ERROR_HV_INSUFFICIENT_CONTIGUOUS_MEMORY_MIRRORING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224699010
ERROR_HV_INSUFFICIENT_CONTIGUOUS_ROOT_MEMORY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224699011
ERROR_HV_INSUFFICIENT_ROOT_MEMORY_MIRRORING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224699012
ERROR_HV_INSUFFICIENT_CONTIGUOUS_ROOT_MEMORY_MIRRORING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224699013
ERROR_HV_NOT_PRESENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224702976
ERROR_VID_DUPLICATE_HANDLER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829953
ERROR_VID_TOO_MANY_HANDLERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829954
ERROR_VID_QUEUE_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829955
ERROR_VID_HANDLER_NOT_PRESENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829956
ERROR_VID_INVALID_OBJECT_NAME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829957
ERROR_VID_PARTITION_NAME_TOO_LONG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829958
ERROR_VID_MESSAGE_QUEUE_NAME_TOO_LONG: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829959
ERROR_VID_PARTITION_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829960
ERROR_VID_PARTITION_DOES_NOT_EXIST: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829961
ERROR_VID_PARTITION_NAME_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829962
ERROR_VID_MESSAGE_QUEUE_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829963
ERROR_VID_EXCEEDED_MBP_ENTRY_MAP_LIMIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829964
ERROR_VID_MB_STILL_REFERENCED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829965
ERROR_VID_CHILD_GPA_PAGE_SET_CORRUPTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829966
ERROR_VID_INVALID_NUMA_SETTINGS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829967
ERROR_VID_INVALID_NUMA_NODE_INDEX: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829968
ERROR_VID_NOTIFICATION_QUEUE_ALREADY_ASSOCIATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829969
ERROR_VID_INVALID_MEMORY_BLOCK_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829970
ERROR_VID_PAGE_RANGE_OVERFLOW: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829971
ERROR_VID_INVALID_MESSAGE_QUEUE_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829972
ERROR_VID_INVALID_GPA_RANGE_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829973
ERROR_VID_NO_MEMORY_BLOCK_NOTIFICATION_QUEUE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829974
ERROR_VID_MEMORY_BLOCK_LOCK_COUNT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829975
ERROR_VID_INVALID_PPM_HANDLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829976
ERROR_VID_MBPS_ARE_LOCKED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829977
ERROR_VID_MESSAGE_QUEUE_CLOSED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829978
ERROR_VID_VIRTUAL_PROCESSOR_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829979
ERROR_VID_STOP_PENDING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829980
ERROR_VID_INVALID_PROCESSOR_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829981
ERROR_VID_EXCEEDED_KM_CONTEXT_COUNT_LIMIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829982
ERROR_VID_KM_INTERFACE_ALREADY_INITIALIZED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829983
ERROR_VID_MB_PROPERTY_ALREADY_SET_RESET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829984
ERROR_VID_MMIO_RANGE_DESTROYED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829985
ERROR_VID_INVALID_CHILD_GPA_PAGE_SET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829986
ERROR_VID_RESERVE_PAGE_SET_IS_BEING_USED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829987
ERROR_VID_RESERVE_PAGE_SET_TOO_SMALL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829988
ERROR_VID_MBP_ALREADY_LOCKED_USING_RESERVED_PAGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829989
ERROR_VID_MBP_COUNT_EXCEEDED_LIMIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829990
ERROR_VID_SAVED_STATE_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829991
ERROR_VID_SAVED_STATE_UNRECOGNIZED_ITEM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829992
ERROR_VID_SAVED_STATE_INCOMPATIBLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829993
ERROR_VID_VTL_ACCESS_DENIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829994
ERROR_VID_INSUFFICIENT_RESOURCES_RESERVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829995
ERROR_VID_INSUFFICIENT_RESOURCES_PHYSICAL_BUFFER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829996
ERROR_VID_INSUFFICIENT_RESOURCES_HV_DEPOSIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829997
ERROR_VID_MEMORY_TYPE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829998
ERROR_VID_INSUFFICIENT_RESOURCES_WITHDRAW: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224829999
ERROR_VID_PROCESS_ALREADY_SET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830000
ERROR_VMCOMPUTE_TERMINATED_DURING_START: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830208
ERROR_VMCOMPUTE_IMAGE_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830209
ERROR_VMCOMPUTE_HYPERV_NOT_INSTALLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830210
ERROR_VMCOMPUTE_OPERATION_PENDING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830211
ERROR_VMCOMPUTE_TOO_MANY_NOTIFICATIONS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830212
ERROR_VMCOMPUTE_INVALID_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830213
ERROR_VMCOMPUTE_UNEXPECTED_EXIT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830214
ERROR_VMCOMPUTE_TERMINATED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830215
ERROR_VMCOMPUTE_CONNECT_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830216
ERROR_VMCOMPUTE_TIMEOUT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830217
ERROR_VMCOMPUTE_CONNECTION_CLOSED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830218
ERROR_VMCOMPUTE_UNKNOWN_MESSAGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830219
ERROR_VMCOMPUTE_UNSUPPORTED_PROTOCOL_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830220
ERROR_VMCOMPUTE_INVALID_JSON: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830221
ERROR_VMCOMPUTE_SYSTEM_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830222
ERROR_VMCOMPUTE_SYSTEM_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830223
ERROR_VMCOMPUTE_SYSTEM_ALREADY_STOPPED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830224
ERROR_VMCOMPUTE_PROTOCOL_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830225
ERROR_VMCOMPUTE_INVALID_LAYER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830226
ERROR_VMCOMPUTE_WINDOWS_INSIDER_REQUIRED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830227
ERROR_VNET_VIRTUAL_SWITCH_NAME_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830464
ERROR_VID_REMOTE_NODE_PARENT_GPA_PAGES_USED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2151088129
ERROR_VSMB_SAVED_STATE_FILE_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830976
ERROR_VSMB_SAVED_STATE_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224830977
ERROR_VOLMGR_INCOMPLETE_REGENERATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2151153665
ERROR_VOLMGR_INCOMPLETE_DISK_MIGRATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2151153666
ERROR_VOLMGR_DATABASE_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895489
ERROR_VOLMGR_DISK_CONFIGURATION_CORRUPTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895490
ERROR_VOLMGR_DISK_CONFIGURATION_NOT_IN_SYNC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895491
ERROR_VOLMGR_PACK_CONFIG_UPDATE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895492
ERROR_VOLMGR_DISK_CONTAINS_NON_SIMPLE_VOLUME: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895493
ERROR_VOLMGR_DISK_DUPLICATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895494
ERROR_VOLMGR_DISK_DYNAMIC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895495
ERROR_VOLMGR_DISK_ID_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895496
ERROR_VOLMGR_DISK_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895497
ERROR_VOLMGR_DISK_LAST_VOTER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895498
ERROR_VOLMGR_DISK_LAYOUT_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895499
ERROR_VOLMGR_DISK_LAYOUT_NON_BASIC_BETWEEN_BASIC_PARTITIONS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895500
ERROR_VOLMGR_DISK_LAYOUT_NOT_CYLINDER_ALIGNED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895501
ERROR_VOLMGR_DISK_LAYOUT_PARTITIONS_TOO_SMALL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895502
ERROR_VOLMGR_DISK_LAYOUT_PRIMARY_BETWEEN_LOGICAL_PARTITIONS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895503
ERROR_VOLMGR_DISK_LAYOUT_TOO_MANY_PARTITIONS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895504
ERROR_VOLMGR_DISK_MISSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895505
ERROR_VOLMGR_DISK_NOT_EMPTY: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895506
ERROR_VOLMGR_DISK_NOT_ENOUGH_SPACE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895507
ERROR_VOLMGR_DISK_REVECTORING_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895508
ERROR_VOLMGR_DISK_SECTOR_SIZE_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895509
ERROR_VOLMGR_DISK_SET_NOT_CONTAINED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895510
ERROR_VOLMGR_DISK_USED_BY_MULTIPLE_MEMBERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895511
ERROR_VOLMGR_DISK_USED_BY_MULTIPLE_PLEXES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895512
ERROR_VOLMGR_DYNAMIC_DISK_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895513
ERROR_VOLMGR_EXTENT_ALREADY_USED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895514
ERROR_VOLMGR_EXTENT_NOT_CONTIGUOUS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895515
ERROR_VOLMGR_EXTENT_NOT_IN_PUBLIC_REGION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895516
ERROR_VOLMGR_EXTENT_NOT_SECTOR_ALIGNED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895517
ERROR_VOLMGR_EXTENT_OVERLAPS_EBR_PARTITION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895518
ERROR_VOLMGR_EXTENT_VOLUME_LENGTHS_DO_NOT_MATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895519
ERROR_VOLMGR_FAULT_TOLERANT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895520
ERROR_VOLMGR_INTERLEAVE_LENGTH_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895521
ERROR_VOLMGR_MAXIMUM_REGISTERED_USERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895522
ERROR_VOLMGR_MEMBER_IN_SYNC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895523
ERROR_VOLMGR_MEMBER_INDEX_DUPLICATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895524
ERROR_VOLMGR_MEMBER_INDEX_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895525
ERROR_VOLMGR_MEMBER_MISSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895526
ERROR_VOLMGR_MEMBER_NOT_DETACHED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895527
ERROR_VOLMGR_MEMBER_REGENERATING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895528
ERROR_VOLMGR_ALL_DISKS_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895529
ERROR_VOLMGR_NO_REGISTERED_USERS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895530
ERROR_VOLMGR_NO_SUCH_USER: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895531
ERROR_VOLMGR_NOTIFICATION_RESET: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895532
ERROR_VOLMGR_NUMBER_OF_MEMBERS_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895533
ERROR_VOLMGR_NUMBER_OF_PLEXES_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895534
ERROR_VOLMGR_PACK_DUPLICATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895535
ERROR_VOLMGR_PACK_ID_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895536
ERROR_VOLMGR_PACK_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895537
ERROR_VOLMGR_PACK_NAME_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895538
ERROR_VOLMGR_PACK_OFFLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895539
ERROR_VOLMGR_PACK_HAS_QUORUM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895540
ERROR_VOLMGR_PACK_WITHOUT_QUORUM: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895541
ERROR_VOLMGR_PARTITION_STYLE_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895542
ERROR_VOLMGR_PARTITION_UPDATE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895543
ERROR_VOLMGR_PLEX_IN_SYNC: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895544
ERROR_VOLMGR_PLEX_INDEX_DUPLICATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895545
ERROR_VOLMGR_PLEX_INDEX_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895546
ERROR_VOLMGR_PLEX_LAST_ACTIVE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895547
ERROR_VOLMGR_PLEX_MISSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895548
ERROR_VOLMGR_PLEX_REGENERATING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895549
ERROR_VOLMGR_PLEX_TYPE_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895550
ERROR_VOLMGR_PLEX_NOT_RAID5: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895551
ERROR_VOLMGR_PLEX_NOT_SIMPLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895552
ERROR_VOLMGR_STRUCTURE_SIZE_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895553
ERROR_VOLMGR_TOO_MANY_NOTIFICATION_REQUESTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895554
ERROR_VOLMGR_TRANSACTION_IN_PROGRESS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895555
ERROR_VOLMGR_UNEXPECTED_DISK_LAYOUT_CHANGE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895556
ERROR_VOLMGR_VOLUME_CONTAINS_MISSING_DISK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895557
ERROR_VOLMGR_VOLUME_ID_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895558
ERROR_VOLMGR_VOLUME_LENGTH_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895559
ERROR_VOLMGR_VOLUME_LENGTH_NOT_SECTOR_SIZE_MULTIPLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895560
ERROR_VOLMGR_VOLUME_NOT_MIRRORED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895561
ERROR_VOLMGR_VOLUME_NOT_RETAINED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895562
ERROR_VOLMGR_VOLUME_OFFLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895563
ERROR_VOLMGR_VOLUME_RETAINED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895564
ERROR_VOLMGR_NUMBER_OF_EXTENTS_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895565
ERROR_VOLMGR_DIFFERENT_SECTOR_SIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895566
ERROR_VOLMGR_BAD_BOOT_DISK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895567
ERROR_VOLMGR_PACK_CONFIG_OFFLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895568
ERROR_VOLMGR_PACK_CONFIG_ONLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895569
ERROR_VOLMGR_NOT_PRIMARY_PACK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895570
ERROR_VOLMGR_PACK_LOG_UPDATE_FAILED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895571
ERROR_VOLMGR_NUMBER_OF_DISKS_IN_PLEX_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895572
ERROR_VOLMGR_NUMBER_OF_DISKS_IN_MEMBER_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895573
ERROR_VOLMGR_VOLUME_MIRRORED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895574
ERROR_VOLMGR_PLEX_NOT_SIMPLE_SPANNED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895575
ERROR_VOLMGR_NO_VALID_LOG_COPIES: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895576
ERROR_VOLMGR_PRIMARY_PACK_PRESENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895577
ERROR_VOLMGR_NUMBER_OF_DISKS_INVALID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895578
ERROR_VOLMGR_MIRROR_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895579
ERROR_VOLMGR_RAID5_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224895580
ERROR_BCD_NOT_ALL_ENTRIES_IMPORTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2151219201
ERROR_BCD_TOO_MANY_ELEMENTS: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3224961026
ERROR_BCD_NOT_ALL_ENTRIES_SYNCHRONIZED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2151219203
ERROR_VHD_DRIVE_FOOTER_MISSING: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026561
ERROR_VHD_DRIVE_FOOTER_CHECKSUM_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026562
ERROR_VHD_DRIVE_FOOTER_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026563
ERROR_VHD_FORMAT_UNKNOWN: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026564
ERROR_VHD_FORMAT_UNSUPPORTED_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026565
ERROR_VHD_SPARSE_HEADER_CHECKSUM_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026566
ERROR_VHD_SPARSE_HEADER_UNSUPPORTED_VERSION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026567
ERROR_VHD_SPARSE_HEADER_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026568
ERROR_VHD_BLOCK_ALLOCATION_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026569
ERROR_VHD_BLOCK_ALLOCATION_TABLE_CORRUPT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026570
ERROR_VHD_INVALID_BLOCK_SIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026571
ERROR_VHD_BITMAP_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026572
ERROR_VHD_PARENT_VHD_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026573
ERROR_VHD_CHILD_PARENT_ID_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026574
ERROR_VHD_CHILD_PARENT_TIMESTAMP_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026575
ERROR_VHD_METADATA_READ_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026576
ERROR_VHD_METADATA_WRITE_FAILURE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026577
ERROR_VHD_INVALID_SIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026578
ERROR_VHD_INVALID_FILE_SIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026579
ERROR_VIRTDISK_PROVIDER_NOT_FOUND: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026580
ERROR_VIRTDISK_NOT_VIRTUAL_DISK: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026581
ERROR_VHD_PARENT_VHD_ACCESS_DENIED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026582
ERROR_VHD_CHILD_PARENT_SIZE_MISMATCH: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026583
ERROR_VHD_DIFFERENCING_CHAIN_CYCLE_DETECTED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026584
ERROR_VHD_DIFFERENCING_CHAIN_ERROR_IN_PARENT: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026585
ERROR_VIRTUAL_DISK_LIMITATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026586
ERROR_VHD_INVALID_TYPE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026587
ERROR_VHD_INVALID_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026588
ERROR_VIRTDISK_UNSUPPORTED_DISK_SECTOR_SIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026589
ERROR_VIRTDISK_DISK_ALREADY_OWNED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026590
ERROR_VIRTDISK_DISK_ONLINE_AND_WRITABLE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026591
ERROR_CTLOG_TRACKING_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026592
ERROR_CTLOG_LOGFILE_SIZE_EXCEEDED_MAXSIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026593
ERROR_CTLOG_VHD_CHANGED_OFFLINE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026594
ERROR_CTLOG_INVALID_TRACKING_STATE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026595
ERROR_CTLOG_INCONSISTENT_TRACKING_FILE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026596
ERROR_VHD_RESIZE_WOULD_TRUNCATE_DATA: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026597
ERROR_VHD_COULD_NOT_COMPUTE_MINIMUM_VIRTUAL_SIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026598
ERROR_VHD_ALREADY_AT_OR_BELOW_MINIMUM_VIRTUAL_SIZE: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026599
ERROR_VHD_METADATA_FULL: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026600
ERROR_VHD_INVALID_CHANGE_TRACKING_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026601
ERROR_VHD_CHANGE_TRACKING_DISABLED: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026602
ERROR_VHD_MISSING_CHANGE_TRACKING_INFORMATION: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026608
ERROR_VHD_UNEXPECTED_ID: win32more.Windows.Win32.Foundation.WIN32_ERROR = 3225026612
ERROR_QUERY_STORAGE_ERROR: win32more.Windows.Win32.Foundation.WIN32_ERROR = 2151284737
WPARAM = UIntPtr


make_ready(__name__)
