from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Contacts
import win32more.Windows.ApplicationModel.DataTransfer
import win32more.Windows.ApplicationModel.Search
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Globalization
import win32more.Windows.Media.Capture
import win32more.Windows.Media.Casting
import win32more.Windows.Media.Core
import win32more.Windows.Media.PlayTo
import win32more.Windows.Media.Playback
import win32more.Windows.Media.Protection
import win32more.Windows.Storage.Streams
import win32more.Windows.System
import win32more.Windows.UI
import win32more.Windows.UI.Composition
import win32more.Windows.UI.Core
import win32more.Windows.UI.Input.Inking
import win32more.Windows.UI.Text
import win32more.Windows.UI.Xaml
import win32more.Windows.UI.Xaml.Automation
import win32more.Windows.UI.Xaml.Automation.Peers
import win32more.Windows.UI.Xaml.Automation.Provider
import win32more.Windows.UI.Xaml.Controls
import win32more.Windows.UI.Xaml.Controls.Primitives
import win32more.Windows.UI.Xaml.Data
import win32more.Windows.UI.Xaml.Documents
import win32more.Windows.UI.Xaml.Input
import win32more.Windows.UI.Xaml.Interop
import win32more.Windows.UI.Xaml.Media
import win32more.Windows.UI.Xaml.Media.Animation
import win32more.Windows.UI.Xaml.Navigation
import win32more.Windows.Web
import win32more.Windows.Web.Http
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
class AnchorRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IAnchorRequestedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.AnchorRequestedEventArgs'
    @winrt_mixinmethod
    def get_Anchor(self: win32more.Windows.UI.Xaml.Controls.IAnchorRequestedEventArgs) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Anchor(self: win32more.Windows.UI.Xaml.Controls.IAnchorRequestedEventArgs, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_AnchorCandidates(self: win32more.Windows.UI.Xaml.Controls.IAnchorRequestedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.UIElement]: ...
    Anchor = property(get_Anchor, put_Anchor)
    AnchorCandidates = property(get_AnchorCandidates, None)
class _AppBar_Meta_(ComPtr.__class__):
    pass
class AppBar(ComPtr, metaclass=_AppBar_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Windows.UI.Xaml.Controls.IAppBar
    _classid_ = 'Windows.UI.Xaml.Controls.AppBar'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.AppBar.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IAppBarFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.AppBar: ...
    @winrt_mixinmethod
    def get_IsOpen(self: win32more.Windows.UI.Xaml.Controls.IAppBar) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsOpen(self: win32more.Windows.UI.Xaml.Controls.IAppBar, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSticky(self: win32more.Windows.UI.Xaml.Controls.IAppBar) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSticky(self: win32more.Windows.UI.Xaml.Controls.IAppBar, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_Opened(self: win32more.Windows.UI.Xaml.Controls.IAppBar, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Opened(self: win32more.Windows.UI.Xaml.Controls.IAppBar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Windows.UI.Xaml.Controls.IAppBar, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Windows.UI.Xaml.Controls.IAppBar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_ClosedDisplayMode(self: win32more.Windows.UI.Xaml.Controls.IAppBar2) -> win32more.Windows.UI.Xaml.Controls.AppBarClosedDisplayMode: ...
    @winrt_mixinmethod
    def put_ClosedDisplayMode(self: win32more.Windows.UI.Xaml.Controls.IAppBar2, value: win32more.Windows.UI.Xaml.Controls.AppBarClosedDisplayMode) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Windows.UI.Xaml.Controls.IAppBar3) -> win32more.Windows.UI.Xaml.Controls.Primitives.AppBarTemplateSettings: ...
    @winrt_mixinmethod
    def add_Opening(self: win32more.Windows.UI.Xaml.Controls.IAppBar3, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Opening(self: win32more.Windows.UI.Xaml.Controls.IAppBar3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Closing(self: win32more.Windows.UI.Xaml.Controls.IAppBar3, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closing(self: win32more.Windows.UI.Xaml.Controls.IAppBar3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_LightDismissOverlayMode(self: win32more.Windows.UI.Xaml.Controls.IAppBar4) -> win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_mixinmethod
    def put_LightDismissOverlayMode(self: win32more.Windows.UI.Xaml.Controls.IAppBar4, value: win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_mixinmethod
    def OnClosed(self: win32more.Windows.UI.Xaml.Controls.IAppBarOverrides, e: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnOpened(self: win32more.Windows.UI.Xaml.Controls.IAppBarOverrides, e: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnClosing(self: win32more.Windows.UI.Xaml.Controls.IAppBarOverrides3, e: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnOpening(self: win32more.Windows.UI.Xaml.Controls.IAppBarOverrides3, e: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_LightDismissOverlayModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ClosedDisplayModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsOpenProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsStickyProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ClosedDisplayMode = property(get_ClosedDisplayMode, put_ClosedDisplayMode)
    IsOpen = property(get_IsOpen, put_IsOpen)
    IsSticky = property(get_IsSticky, put_IsSticky)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    TemplateSettings = property(get_TemplateSettings, None)
    _AppBar_Meta_.ClosedDisplayModeProperty = property(get_ClosedDisplayModeProperty, None)
    _AppBar_Meta_.IsOpenProperty = property(get_IsOpenProperty, None)
    _AppBar_Meta_.IsStickyProperty = property(get_IsStickyProperty, None)
    _AppBar_Meta_.LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    Opened = event()
    Closed = event()
    Opening = event()
    Closing = event()
class _AppBarButton_Meta_(ComPtr.__class__):
    pass
class AppBarButton(ComPtr, metaclass=_AppBarButton_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Button
    default_interface: win32more.Windows.UI.Xaml.Controls.IAppBarButton
    _classid_ = 'Windows.UI.Xaml.Controls.AppBarButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.AppBarButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IAppBarButtonFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.AppBarButton: ...
    @winrt_mixinmethod
    def get_Label(self: win32more.Windows.UI.Xaml.Controls.IAppBarButton) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Label(self: win32more.Windows.UI.Xaml.Controls.IAppBarButton, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Icon(self: win32more.Windows.UI.Xaml.Controls.IAppBarButton) -> win32more.Windows.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def put_Icon(self: win32more.Windows.UI.Xaml.Controls.IAppBarButton, value: win32more.Windows.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_mixinmethod
    def get_LabelPosition(self: win32more.Windows.UI.Xaml.Controls.IAppBarButton3) -> win32more.Windows.UI.Xaml.Controls.CommandBarLabelPosition: ...
    @winrt_mixinmethod
    def put_LabelPosition(self: win32more.Windows.UI.Xaml.Controls.IAppBarButton3, value: win32more.Windows.UI.Xaml.Controls.CommandBarLabelPosition) -> Void: ...
    @winrt_mixinmethod
    def get_KeyboardAcceleratorTextOverride(self: win32more.Windows.UI.Xaml.Controls.IAppBarButton4) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_KeyboardAcceleratorTextOverride(self: win32more.Windows.UI.Xaml.Controls.IAppBarButton4, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Windows.UI.Xaml.Controls.IAppBarButton5) -> win32more.Windows.UI.Xaml.Controls.Primitives.AppBarButtonTemplateSettings: ...
    @winrt_mixinmethod
    def get_IsCompact(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCompact(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsInOverflow(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement2) -> Boolean: ...
    @winrt_mixinmethod
    def get_DynamicOverflowOrder(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement2) -> Int32: ...
    @winrt_mixinmethod
    def put_DynamicOverflowOrder(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement2, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_KeyboardAcceleratorTextOverrideProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarButtonStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LabelPositionProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarButtonStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsInOverflowProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarButtonStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DynamicOverflowOrderProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarButtonStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LabelProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsCompactProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DynamicOverflowOrder = property(get_DynamicOverflowOrder, put_DynamicOverflowOrder)
    Icon = property(get_Icon, put_Icon)
    IsCompact = property(get_IsCompact, put_IsCompact)
    IsInOverflow = property(get_IsInOverflow, None)
    KeyboardAcceleratorTextOverride = property(get_KeyboardAcceleratorTextOverride, put_KeyboardAcceleratorTextOverride)
    Label = property(get_Label, put_Label)
    LabelPosition = property(get_LabelPosition, put_LabelPosition)
    TemplateSettings = property(get_TemplateSettings, None)
    _AppBarButton_Meta_.DynamicOverflowOrderProperty = property(get_DynamicOverflowOrderProperty, None)
    _AppBarButton_Meta_.IconProperty = property(get_IconProperty, None)
    _AppBarButton_Meta_.IsCompactProperty = property(get_IsCompactProperty, None)
    _AppBarButton_Meta_.IsInOverflowProperty = property(get_IsInOverflowProperty, None)
    _AppBarButton_Meta_.KeyboardAcceleratorTextOverrideProperty = property(get_KeyboardAcceleratorTextOverrideProperty, None)
    _AppBarButton_Meta_.LabelPositionProperty = property(get_LabelPositionProperty, None)
    _AppBarButton_Meta_.LabelProperty = property(get_LabelProperty, None)
class AppBarClosedDisplayMode(Enum, Int32):
    Compact = 0
    Minimal = 1
    Hidden = 2
class _AppBarElementContainer_Meta_(ComPtr.__class__):
    pass
class AppBarElementContainer(ComPtr, metaclass=_AppBarElementContainer_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Windows.UI.Xaml.Controls.IAppBarElementContainer
    _classid_ = 'Windows.UI.Xaml.Controls.AppBarElementContainer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.AppBarElementContainer.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IAppBarElementContainerFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.AppBarElementContainer: ...
    @winrt_mixinmethod
    def get_IsCompact(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCompact(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsInOverflow(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement2) -> Boolean: ...
    @winrt_mixinmethod
    def get_DynamicOverflowOrder(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement2) -> Int32: ...
    @winrt_mixinmethod
    def put_DynamicOverflowOrder(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement2, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_IsCompactProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarElementContainerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsInOverflowProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarElementContainerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DynamicOverflowOrderProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarElementContainerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DynamicOverflowOrder = property(get_DynamicOverflowOrder, put_DynamicOverflowOrder)
    IsCompact = property(get_IsCompact, put_IsCompact)
    IsInOverflow = property(get_IsInOverflow, None)
    _AppBarElementContainer_Meta_.DynamicOverflowOrderProperty = property(get_DynamicOverflowOrderProperty, None)
    _AppBarElementContainer_Meta_.IsCompactProperty = property(get_IsCompactProperty, None)
    _AppBarElementContainer_Meta_.IsInOverflowProperty = property(get_IsInOverflowProperty, None)
class _AppBarSeparator_Meta_(ComPtr.__class__):
    pass
class AppBarSeparator(ComPtr, metaclass=_AppBarSeparator_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IAppBarSeparator
    _classid_ = 'Windows.UI.Xaml.Controls.AppBarSeparator'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.AppBarSeparator.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IAppBarSeparatorFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.AppBarSeparator: ...
    @winrt_mixinmethod
    def get_IsCompact(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCompact(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsInOverflow(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement2) -> Boolean: ...
    @winrt_mixinmethod
    def get_DynamicOverflowOrder(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement2) -> Int32: ...
    @winrt_mixinmethod
    def put_DynamicOverflowOrder(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement2, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_IsInOverflowProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarSeparatorStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DynamicOverflowOrderProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarSeparatorStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsCompactProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarSeparatorStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DynamicOverflowOrder = property(get_DynamicOverflowOrder, put_DynamicOverflowOrder)
    IsCompact = property(get_IsCompact, put_IsCompact)
    IsInOverflow = property(get_IsInOverflow, None)
    _AppBarSeparator_Meta_.DynamicOverflowOrderProperty = property(get_DynamicOverflowOrderProperty, None)
    _AppBarSeparator_Meta_.IsCompactProperty = property(get_IsCompactProperty, None)
    _AppBarSeparator_Meta_.IsInOverflowProperty = property(get_IsInOverflowProperty, None)
class _AppBarToggleButton_Meta_(ComPtr.__class__):
    pass
class AppBarToggleButton(ComPtr, metaclass=_AppBarToggleButton_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.ToggleButton
    default_interface: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButton
    _classid_ = 'Windows.UI.Xaml.Controls.AppBarToggleButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.AppBarToggleButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButtonFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.AppBarToggleButton: ...
    @winrt_mixinmethod
    def get_Label(self: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButton) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Label(self: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButton, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Icon(self: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButton) -> win32more.Windows.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def put_Icon(self: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButton, value: win32more.Windows.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_mixinmethod
    def get_LabelPosition(self: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButton3) -> win32more.Windows.UI.Xaml.Controls.CommandBarLabelPosition: ...
    @winrt_mixinmethod
    def put_LabelPosition(self: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButton3, value: win32more.Windows.UI.Xaml.Controls.CommandBarLabelPosition) -> Void: ...
    @winrt_mixinmethod
    def get_KeyboardAcceleratorTextOverride(self: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButton4) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_KeyboardAcceleratorTextOverride(self: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButton4, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButton5) -> win32more.Windows.UI.Xaml.Controls.Primitives.AppBarToggleButtonTemplateSettings: ...
    @winrt_mixinmethod
    def get_IsCompact(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCompact(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsInOverflow(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement2) -> Boolean: ...
    @winrt_mixinmethod
    def get_DynamicOverflowOrder(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement2) -> Int32: ...
    @winrt_mixinmethod
    def put_DynamicOverflowOrder(self: win32more.Windows.UI.Xaml.Controls.ICommandBarElement2, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_KeyboardAcceleratorTextOverrideProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButtonStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LabelPositionProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButtonStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsInOverflowProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButtonStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DynamicOverflowOrderProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButtonStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LabelProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsCompactProperty(cls: win32more.Windows.UI.Xaml.Controls.IAppBarToggleButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DynamicOverflowOrder = property(get_DynamicOverflowOrder, put_DynamicOverflowOrder)
    Icon = property(get_Icon, put_Icon)
    IsCompact = property(get_IsCompact, put_IsCompact)
    IsInOverflow = property(get_IsInOverflow, None)
    KeyboardAcceleratorTextOverride = property(get_KeyboardAcceleratorTextOverride, put_KeyboardAcceleratorTextOverride)
    Label = property(get_Label, put_Label)
    LabelPosition = property(get_LabelPosition, put_LabelPosition)
    TemplateSettings = property(get_TemplateSettings, None)
    _AppBarToggleButton_Meta_.DynamicOverflowOrderProperty = property(get_DynamicOverflowOrderProperty, None)
    _AppBarToggleButton_Meta_.IconProperty = property(get_IconProperty, None)
    _AppBarToggleButton_Meta_.IsCompactProperty = property(get_IsCompactProperty, None)
    _AppBarToggleButton_Meta_.IsInOverflowProperty = property(get_IsInOverflowProperty, None)
    _AppBarToggleButton_Meta_.KeyboardAcceleratorTextOverrideProperty = property(get_KeyboardAcceleratorTextOverrideProperty, None)
    _AppBarToggleButton_Meta_.LabelPositionProperty = property(get_LabelPositionProperty, None)
    _AppBarToggleButton_Meta_.LabelProperty = property(get_LabelProperty, None)
class _AutoSuggestBox_Meta_(ComPtr.__class__):
    pass
class AutoSuggestBox(ComPtr, metaclass=_AutoSuggestBox_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ItemsControl
    default_interface: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox
    _classid_ = 'Windows.UI.Xaml.Controls.AutoSuggestBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.AutoSuggestBox.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.AutoSuggestBox: ...
    @winrt_mixinmethod
    def get_MaxSuggestionListHeight(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox) -> Double: ...
    @winrt_mixinmethod
    def put_MaxSuggestionListHeight(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_IsSuggestionListOpen(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSuggestionListOpen(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TextMemberPath(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_TextMemberPath(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_UpdateTextOnSelect(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_UpdateTextOnSelect(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderText(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PlaceholderText(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_AutoMaximizeSuggestionArea(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_AutoMaximizeSuggestionArea(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TextBoxStyle(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_TextBoxStyle(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def add_SuggestionChosen(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.AutoSuggestBox, win32more.Windows.UI.Xaml.Controls.AutoSuggestBoxSuggestionChosenEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SuggestionChosen(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextChanged(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.AutoSuggestBox, win32more.Windows.UI.Xaml.Controls.AutoSuggestBoxTextChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextChanged(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_QueryIcon(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox2) -> win32more.Windows.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def put_QueryIcon(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox2, value: win32more.Windows.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_mixinmethod
    def add_QuerySubmitted(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.AutoSuggestBox, win32more.Windows.UI.Xaml.Controls.AutoSuggestBoxQuerySubmittedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_QuerySubmitted(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_LightDismissOverlayMode(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox3) -> win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_mixinmethod
    def put_LightDismissOverlayMode(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox3, value: win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox4) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBox4, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_DescriptionProperty(cls: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LightDismissOverlayModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_QueryIconProperty(cls: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxSuggestionListHeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSuggestionListOpenProperty(cls: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextMemberPathProperty(cls: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextProperty(cls: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_UpdateTextOnSelectProperty(cls: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderTextProperty(cls: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AutoMaximizeSuggestionAreaProperty(cls: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextBoxStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AutoMaximizeSuggestionArea = property(get_AutoMaximizeSuggestionArea, put_AutoMaximizeSuggestionArea)
    Description = property(get_Description, put_Description)
    Header = property(get_Header, put_Header)
    IsSuggestionListOpen = property(get_IsSuggestionListOpen, put_IsSuggestionListOpen)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    MaxSuggestionListHeight = property(get_MaxSuggestionListHeight, put_MaxSuggestionListHeight)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    QueryIcon = property(get_QueryIcon, put_QueryIcon)
    Text = property(get_Text, put_Text)
    TextBoxStyle = property(get_TextBoxStyle, put_TextBoxStyle)
    TextMemberPath = property(get_TextMemberPath, put_TextMemberPath)
    UpdateTextOnSelect = property(get_UpdateTextOnSelect, put_UpdateTextOnSelect)
    _AutoSuggestBox_Meta_.AutoMaximizeSuggestionAreaProperty = property(get_AutoMaximizeSuggestionAreaProperty, None)
    _AutoSuggestBox_Meta_.DescriptionProperty = property(get_DescriptionProperty, None)
    _AutoSuggestBox_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _AutoSuggestBox_Meta_.IsSuggestionListOpenProperty = property(get_IsSuggestionListOpenProperty, None)
    _AutoSuggestBox_Meta_.LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    _AutoSuggestBox_Meta_.MaxSuggestionListHeightProperty = property(get_MaxSuggestionListHeightProperty, None)
    _AutoSuggestBox_Meta_.PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    _AutoSuggestBox_Meta_.QueryIconProperty = property(get_QueryIconProperty, None)
    _AutoSuggestBox_Meta_.TextBoxStyleProperty = property(get_TextBoxStyleProperty, None)
    _AutoSuggestBox_Meta_.TextMemberPathProperty = property(get_TextMemberPathProperty, None)
    _AutoSuggestBox_Meta_.TextProperty = property(get_TextProperty, None)
    _AutoSuggestBox_Meta_.UpdateTextOnSelectProperty = property(get_UpdateTextOnSelectProperty, None)
    SuggestionChosen = event()
    TextChanged = event()
    QuerySubmitted = event()
class AutoSuggestBoxQuerySubmittedEventArgs(ComPtr):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxQuerySubmittedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.AutoSuggestBoxQuerySubmittedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.AutoSuggestBoxQuerySubmittedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.AutoSuggestBoxQuerySubmittedEventArgs: ...
    @winrt_mixinmethod
    def get_QueryText(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxQuerySubmittedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ChosenSuggestion(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxQuerySubmittedEventArgs) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    ChosenSuggestion = property(get_ChosenSuggestion, None)
    QueryText = property(get_QueryText, None)
class AutoSuggestBoxSuggestionChosenEventArgs(ComPtr):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxSuggestionChosenEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.AutoSuggestBoxSuggestionChosenEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.AutoSuggestBoxSuggestionChosenEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.AutoSuggestBoxSuggestionChosenEventArgs: ...
    @winrt_mixinmethod
    def get_SelectedItem(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxSuggestionChosenEventArgs) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    SelectedItem = property(get_SelectedItem, None)
class _AutoSuggestBoxTextChangedEventArgs_Meta_(ComPtr.__class__):
    pass
class AutoSuggestBoxTextChangedEventArgs(ComPtr, metaclass=_AutoSuggestBoxTextChangedEventArgs_Meta_):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxTextChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.AutoSuggestBoxTextChangedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.AutoSuggestBoxTextChangedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.AutoSuggestBoxTextChangedEventArgs: ...
    @winrt_mixinmethod
    def get_Reason(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxTextChangedEventArgs) -> win32more.Windows.UI.Xaml.Controls.AutoSuggestionBoxTextChangeReason: ...
    @winrt_mixinmethod
    def put_Reason(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxTextChangedEventArgs, value: win32more.Windows.UI.Xaml.Controls.AutoSuggestionBoxTextChangeReason) -> Void: ...
    @winrt_mixinmethod
    def CheckCurrent(self: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxTextChangedEventArgs) -> Boolean: ...
    @winrt_classmethod
    def get_ReasonProperty(cls: win32more.Windows.UI.Xaml.Controls.IAutoSuggestBoxTextChangedEventArgsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Reason = property(get_Reason, put_Reason)
    _AutoSuggestBoxTextChangedEventArgs_Meta_.ReasonProperty = property(get_ReasonProperty, None)
class AutoSuggestionBoxTextChangeReason(Enum, Int32):
    UserInput = 0
    ProgrammaticChange = 1
    SuggestionChosen = 2
class BackClickEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IBackClickEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.BackClickEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.BackClickEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.BackClickEventArgs: ...
    @winrt_mixinmethod
    def get_Handled(self: win32more.Windows.UI.Xaml.Controls.IBackClickEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Windows.UI.Xaml.Controls.IBackClickEventArgs, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class BackClickEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{fa9bc21f-9892-482e-abf6-eb2d607d32de}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Controls.BackClickEventArgs) -> Void: ...
class BackgroundSizing(Enum, Int32):
    InnerBorderEdge = 0
    OuterBorderEdge = 1
class _BitmapIcon_Meta_(ComPtr.__class__):
    pass
class BitmapIcon(ComPtr, metaclass=_BitmapIcon_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.IconElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IBitmapIcon
    _classid_ = 'Windows.UI.Xaml.Controls.BitmapIcon'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.BitmapIcon.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IBitmapIconFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.BitmapIcon: ...
    @winrt_mixinmethod
    def get_UriSource(self: win32more.Windows.UI.Xaml.Controls.IBitmapIcon) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_UriSource(self: win32more.Windows.UI.Xaml.Controls.IBitmapIcon, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_ShowAsMonochrome(self: win32more.Windows.UI.Xaml.Controls.IBitmapIcon2) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShowAsMonochrome(self: win32more.Windows.UI.Xaml.Controls.IBitmapIcon2, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_ShowAsMonochromeProperty(cls: win32more.Windows.UI.Xaml.Controls.IBitmapIconStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_UriSourceProperty(cls: win32more.Windows.UI.Xaml.Controls.IBitmapIconStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ShowAsMonochrome = property(get_ShowAsMonochrome, put_ShowAsMonochrome)
    UriSource = property(get_UriSource, put_UriSource)
    _BitmapIcon_Meta_.ShowAsMonochromeProperty = property(get_ShowAsMonochromeProperty, None)
    _BitmapIcon_Meta_.UriSourceProperty = property(get_UriSourceProperty, None)
class _BitmapIconSource_Meta_(ComPtr.__class__):
    pass
class BitmapIconSource(ComPtr, metaclass=_BitmapIconSource_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.IconSource
    default_interface: win32more.Windows.UI.Xaml.Controls.IBitmapIconSource
    _classid_ = 'Windows.UI.Xaml.Controls.BitmapIconSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.BitmapIconSource.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IBitmapIconSourceFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.BitmapIconSource: ...
    @winrt_mixinmethod
    def get_UriSource(self: win32more.Windows.UI.Xaml.Controls.IBitmapIconSource) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_UriSource(self: win32more.Windows.UI.Xaml.Controls.IBitmapIconSource, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_ShowAsMonochrome(self: win32more.Windows.UI.Xaml.Controls.IBitmapIconSource) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShowAsMonochrome(self: win32more.Windows.UI.Xaml.Controls.IBitmapIconSource, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_UriSourceProperty(cls: win32more.Windows.UI.Xaml.Controls.IBitmapIconSourceStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ShowAsMonochromeProperty(cls: win32more.Windows.UI.Xaml.Controls.IBitmapIconSourceStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ShowAsMonochrome = property(get_ShowAsMonochrome, put_ShowAsMonochrome)
    UriSource = property(get_UriSource, put_UriSource)
    _BitmapIconSource_Meta_.ShowAsMonochromeProperty = property(get_ShowAsMonochromeProperty, None)
    _BitmapIconSource_Meta_.UriSourceProperty = property(get_UriSourceProperty, None)
class _Border_Meta_(ComPtr.__class__):
    pass
class Border(ComPtr, metaclass=_Border_Meta_):
    extends: win32more.Windows.UI.Xaml.FrameworkElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IBorder
    _classid_ = 'Windows.UI.Xaml.Controls.Border'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.Border.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.Border: ...
    @winrt_mixinmethod
    def get_BorderBrush(self: win32more.Windows.UI.Xaml.Controls.IBorder) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BorderBrush(self: win32more.Windows.UI.Xaml.Controls.IBorder, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BorderThickness(self: win32more.Windows.UI.Xaml.Controls.IBorder) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_BorderThickness(self: win32more.Windows.UI.Xaml.Controls.IBorder, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_Background(self: win32more.Windows.UI.Xaml.Controls.IBorder) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Background(self: win32more.Windows.UI.Xaml.Controls.IBorder, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_CornerRadius(self: win32more.Windows.UI.Xaml.Controls.IBorder) -> win32more.Windows.UI.Xaml.CornerRadius: ...
    @winrt_mixinmethod
    def put_CornerRadius(self: win32more.Windows.UI.Xaml.Controls.IBorder, value: win32more.Windows.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Windows.UI.Xaml.Controls.IBorder) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Windows.UI.Xaml.Controls.IBorder, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_Child(self: win32more.Windows.UI.Xaml.Controls.IBorder) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Child(self: win32more.Windows.UI.Xaml.Controls.IBorder, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_ChildTransitions(self: win32more.Windows.UI.Xaml.Controls.IBorder) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_ChildTransitions(self: win32more.Windows.UI.Xaml.Controls.IBorder, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_BackgroundSizing(self: win32more.Windows.UI.Xaml.Controls.IBorder2) -> win32more.Windows.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_mixinmethod
    def put_BackgroundSizing(self: win32more.Windows.UI.Xaml.Controls.IBorder2, value: win32more.Windows.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_mixinmethod
    def get_BackgroundTransition(self: win32more.Windows.UI.Xaml.Controls.IBorder2) -> win32more.Windows.UI.Xaml.BrushTransition: ...
    @winrt_mixinmethod
    def put_BackgroundTransition(self: win32more.Windows.UI.Xaml.Controls.IBorder2, value: win32more.Windows.UI.Xaml.BrushTransition) -> Void: ...
    @winrt_classmethod
    def get_BackgroundSizingProperty(cls: win32more.Windows.UI.Xaml.Controls.IBorderStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.IBorderStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderThicknessProperty(cls: win32more.Windows.UI.Xaml.Controls.IBorderStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.IBorderStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CornerRadiusProperty(cls: win32more.Windows.UI.Xaml.Controls.IBorderStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Windows.UI.Xaml.Controls.IBorderStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ChildTransitionsProperty(cls: win32more.Windows.UI.Xaml.Controls.IBorderStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Background = property(get_Background, put_Background)
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BackgroundTransition = property(get_BackgroundTransition, put_BackgroundTransition)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    Child = property(get_Child, put_Child)
    ChildTransitions = property(get_ChildTransitions, put_ChildTransitions)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    Padding = property(get_Padding, put_Padding)
    _Border_Meta_.BackgroundProperty = property(get_BackgroundProperty, None)
    _Border_Meta_.BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    _Border_Meta_.BorderBrushProperty = property(get_BorderBrushProperty, None)
    _Border_Meta_.BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    _Border_Meta_.ChildTransitionsProperty = property(get_ChildTransitionsProperty, None)
    _Border_Meta_.CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    _Border_Meta_.PaddingProperty = property(get_PaddingProperty, None)
class _Button_Meta_(ComPtr.__class__):
    pass
class Button(ComPtr, metaclass=_Button_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.ButtonBase
    default_interface: win32more.Windows.UI.Xaml.Controls.IButton
    _classid_ = 'Windows.UI.Xaml.Controls.Button'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.Button.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IButtonFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Button: ...
    @winrt_mixinmethod
    def get_Flyout(self: win32more.Windows.UI.Xaml.Controls.IButtonWithFlyout) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def put_Flyout(self: win32more.Windows.UI.Xaml.Controls.IButtonWithFlyout, value: win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_classmethod
    def get_FlyoutProperty(cls: win32more.Windows.UI.Xaml.Controls.IButtonStaticsWithFlyout) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Flyout = property(get_Flyout, put_Flyout)
    _Button_Meta_.FlyoutProperty = property(get_FlyoutProperty, None)
class _CalendarDatePicker_Meta_(ComPtr.__class__):
    pass
class CalendarDatePicker(ComPtr, metaclass=_CalendarDatePicker_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker
    _classid_ = 'Windows.UI.Xaml.Controls.CalendarDatePicker'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.CalendarDatePicker.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.CalendarDatePicker: ...
    @winrt_mixinmethod
    def get_Date(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def put_Date(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_mixinmethod
    def get_IsCalendarOpen(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCalendarOpen(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_DateFormat(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DateFormat(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderText(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PlaceholderText(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarViewStyle(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_CalendarViewStyle(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_MinDate(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_MinDate(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_MaxDate(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_MaxDate(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_IsTodayHighlighted(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTodayHighlighted(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayMode(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker) -> win32more.Windows.UI.Xaml.Controls.CalendarViewDisplayMode: ...
    @winrt_mixinmethod
    def put_DisplayMode(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, value: win32more.Windows.UI.Xaml.Controls.CalendarViewDisplayMode) -> Void: ...
    @winrt_mixinmethod
    def get_FirstDayOfWeek(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker) -> win32more.Windows.Globalization.DayOfWeek: ...
    @winrt_mixinmethod
    def put_FirstDayOfWeek(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, value: win32more.Windows.Globalization.DayOfWeek) -> Void: ...
    @winrt_mixinmethod
    def get_DayOfWeekFormat(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DayOfWeekFormat(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarIdentifier(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_CalendarIdentifier(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IsOutOfScopeEnabled(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsOutOfScopeEnabled(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsGroupLabelVisible(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsGroupLabelVisible(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_CalendarViewDayItemChanging(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, handler: win32more.Windows.UI.Xaml.Controls.CalendarViewDayItemChangingEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CalendarViewDayItemChanging(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DateChanged(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.CalendarDatePicker, win32more.Windows.UI.Xaml.Controls.CalendarDatePickerDateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DateChanged(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Opened(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Opened(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def SetDisplayDate(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, date: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def SetYearDecadeDisplayDimensions(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker, columns: Int32, rows: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_LightDismissOverlayMode(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker2) -> win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_mixinmethod
    def put_LightDismissOverlayMode(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker2, value: win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker3) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePicker3, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_DescriptionProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LightDismissOverlayModeProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DateProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsCalendarOpenProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DateFormatProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderTextProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarViewStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinDateProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxDateProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTodayHighlightedProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisplayModeProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstDayOfWeekProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayOfWeekFormatProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarIdentifierProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsOutOfScopeEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsGroupLabelVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CalendarIdentifier = property(get_CalendarIdentifier, put_CalendarIdentifier)
    CalendarViewStyle = property(get_CalendarViewStyle, put_CalendarViewStyle)
    Date = property(get_Date, put_Date)
    DateFormat = property(get_DateFormat, put_DateFormat)
    DayOfWeekFormat = property(get_DayOfWeekFormat, put_DayOfWeekFormat)
    Description = property(get_Description, put_Description)
    DisplayMode = property(get_DisplayMode, put_DisplayMode)
    FirstDayOfWeek = property(get_FirstDayOfWeek, put_FirstDayOfWeek)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsCalendarOpen = property(get_IsCalendarOpen, put_IsCalendarOpen)
    IsGroupLabelVisible = property(get_IsGroupLabelVisible, put_IsGroupLabelVisible)
    IsOutOfScopeEnabled = property(get_IsOutOfScopeEnabled, put_IsOutOfScopeEnabled)
    IsTodayHighlighted = property(get_IsTodayHighlighted, put_IsTodayHighlighted)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    MaxDate = property(get_MaxDate, put_MaxDate)
    MinDate = property(get_MinDate, put_MinDate)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    _CalendarDatePicker_Meta_.CalendarIdentifierProperty = property(get_CalendarIdentifierProperty, None)
    _CalendarDatePicker_Meta_.CalendarViewStyleProperty = property(get_CalendarViewStyleProperty, None)
    _CalendarDatePicker_Meta_.DateFormatProperty = property(get_DateFormatProperty, None)
    _CalendarDatePicker_Meta_.DateProperty = property(get_DateProperty, None)
    _CalendarDatePicker_Meta_.DayOfWeekFormatProperty = property(get_DayOfWeekFormatProperty, None)
    _CalendarDatePicker_Meta_.DescriptionProperty = property(get_DescriptionProperty, None)
    _CalendarDatePicker_Meta_.DisplayModeProperty = property(get_DisplayModeProperty, None)
    _CalendarDatePicker_Meta_.FirstDayOfWeekProperty = property(get_FirstDayOfWeekProperty, None)
    _CalendarDatePicker_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _CalendarDatePicker_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _CalendarDatePicker_Meta_.IsCalendarOpenProperty = property(get_IsCalendarOpenProperty, None)
    _CalendarDatePicker_Meta_.IsGroupLabelVisibleProperty = property(get_IsGroupLabelVisibleProperty, None)
    _CalendarDatePicker_Meta_.IsOutOfScopeEnabledProperty = property(get_IsOutOfScopeEnabledProperty, None)
    _CalendarDatePicker_Meta_.IsTodayHighlightedProperty = property(get_IsTodayHighlightedProperty, None)
    _CalendarDatePicker_Meta_.LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    _CalendarDatePicker_Meta_.MaxDateProperty = property(get_MaxDateProperty, None)
    _CalendarDatePicker_Meta_.MinDateProperty = property(get_MinDateProperty, None)
    _CalendarDatePicker_Meta_.PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    CalendarViewDayItemChanging = event()
    DateChanged = event()
    Opened = event()
    Closed = event()
class CalendarDatePickerDateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerDateChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.CalendarDatePickerDateChangedEventArgs'
    @winrt_mixinmethod
    def get_NewDate(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerDateChangedEventArgs) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def get_OldDate(self: win32more.Windows.UI.Xaml.Controls.ICalendarDatePickerDateChangedEventArgs) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    NewDate = property(get_NewDate, None)
    OldDate = property(get_OldDate, None)
class _CalendarView_Meta_(ComPtr.__class__):
    pass
class CalendarView(ComPtr, metaclass=_CalendarView_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.ICalendarView
    _classid_ = 'Windows.UI.Xaml.Controls.CalendarView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.CalendarView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.CalendarView: ...
    @winrt_mixinmethod
    def get_CalendarIdentifier(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_CalendarIdentifier(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_DayOfWeekFormat(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DayOfWeekFormat(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IsGroupLabelVisible(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsGroupLabelVisible(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayMode(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Controls.CalendarViewDisplayMode: ...
    @winrt_mixinmethod
    def put_DisplayMode(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Controls.CalendarViewDisplayMode) -> Void: ...
    @winrt_mixinmethod
    def get_FirstDayOfWeek(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.Globalization.DayOfWeek: ...
    @winrt_mixinmethod
    def put_FirstDayOfWeek(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.Globalization.DayOfWeek) -> Void: ...
    @winrt_mixinmethod
    def get_IsOutOfScopeEnabled(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsOutOfScopeEnabled(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsTodayHighlighted(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTodayHighlighted(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MaxDate(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_MaxDate(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_MinDate(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_MinDate(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_NumberOfWeeksInView(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> Int32: ...
    @winrt_mixinmethod
    def put_NumberOfWeeksInView(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedDates(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def get_SelectionMode(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Controls.CalendarViewSelectionMode: ...
    @winrt_mixinmethod
    def put_SelectionMode(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Controls.CalendarViewSelectionMode) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Controls.Primitives.CalendarViewTemplateSettings: ...
    @winrt_mixinmethod
    def get_FocusBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_FocusBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedHoverBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_SelectedHoverBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedPressedBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_SelectedPressedBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_SelectedBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_HoverBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_HoverBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_PressedBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_PressedBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarItemBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_CalendarItemBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_OutOfScopeBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_OutOfScopeBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarItemBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_CalendarItemBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_PressedForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_PressedForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TodayForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_TodayForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BlackoutForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BlackoutForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_SelectedForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_OutOfScopeForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_OutOfScopeForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarItemForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_CalendarItemForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_DayItemFontFamily(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_DayItemFontFamily(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_DayItemFontSize(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> Double: ...
    @winrt_mixinmethod
    def put_DayItemFontSize(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_DayItemFontStyle(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_DayItemFontStyle(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_DayItemFontWeight(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_DayItemFontWeight(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_TodayFontWeight(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_TodayFontWeight(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfMonthLabelFontFamily(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_FirstOfMonthLabelFontFamily(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfMonthLabelFontSize(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> Double: ...
    @winrt_mixinmethod
    def put_FirstOfMonthLabelFontSize(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfMonthLabelFontStyle(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_FirstOfMonthLabelFontStyle(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfMonthLabelFontWeight(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_FirstOfMonthLabelFontWeight(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_MonthYearItemFontFamily(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_MonthYearItemFontFamily(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_MonthYearItemFontSize(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> Double: ...
    @winrt_mixinmethod
    def put_MonthYearItemFontSize(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_MonthYearItemFontStyle(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_MonthYearItemFontStyle(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_MonthYearItemFontWeight(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_MonthYearItemFontWeight(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfYearDecadeLabelFontFamily(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_FirstOfYearDecadeLabelFontFamily(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfYearDecadeLabelFontSize(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> Double: ...
    @winrt_mixinmethod
    def put_FirstOfYearDecadeLabelFontSize(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfYearDecadeLabelFontStyle(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_FirstOfYearDecadeLabelFontStyle(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfYearDecadeLabelFontWeight(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_FirstOfYearDecadeLabelFontWeight(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalDayItemAlignment(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.HorizontalAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalDayItemAlignment(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalDayItemAlignment(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.VerticalAlignment: ...
    @winrt_mixinmethod
    def put_VerticalDayItemAlignment(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalFirstOfMonthLabelAlignment(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.HorizontalAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalFirstOfMonthLabelAlignment(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalFirstOfMonthLabelAlignment(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.VerticalAlignment: ...
    @winrt_mixinmethod
    def put_VerticalFirstOfMonthLabelAlignment(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarItemBorderThickness(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_CalendarItemBorderThickness(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarViewDayItemStyle(self: win32more.Windows.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_CalendarViewDayItemStyle(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def add_CalendarViewDayItemChanging(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.CalendarView, win32more.Windows.UI.Xaml.Controls.CalendarViewDayItemChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CalendarViewDayItemChanging(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SelectedDatesChanged(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.CalendarView, win32more.Windows.UI.Xaml.Controls.CalendarViewSelectedDatesChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectedDatesChanged(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def SetDisplayDate(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, date: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def SetYearDecadeDisplayDimensions(self: win32more.Windows.UI.Xaml.Controls.ICalendarView, columns: Int32, rows: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedDisabledBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_SelectedDisabledBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TodaySelectedInnerBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_TodaySelectedInnerBorderBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BlackoutStrikethroughBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BlackoutStrikethroughBrush(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BlackoutBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BlackoutBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarItemHoverBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_CalendarItemHoverBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarItemPressedBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_CalendarItemPressedBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarItemDisabledBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_CalendarItemDisabledBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TodayBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_TodayBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TodayBlackoutBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_TodayBlackoutBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TodayHoverBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_TodayHoverBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TodayPressedBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_TodayPressedBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TodayDisabledBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_TodayDisabledBackground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TodayBlackoutForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_TodayBlackoutForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedHoverForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_SelectedHoverForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedPressedForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_SelectedPressedForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedDisabledForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_SelectedDisabledForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_OutOfScopeHoverForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_OutOfScopeHoverForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_OutOfScopePressedForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_OutOfScopePressedForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_DisabledForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_DisabledForeground(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_DayItemMargin(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_DayItemMargin(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_MonthYearItemMargin(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_MonthYearItemMargin(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfMonthLabelMargin(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_FirstOfMonthLabelMargin(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfYearDecadeLabelMargin(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_FirstOfYearDecadeLabelMargin(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarItemCornerRadius(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2) -> win32more.Windows.UI.Xaml.CornerRadius: ...
    @winrt_mixinmethod
    def put_CalendarItemCornerRadius(self: win32more.Windows.UI.Xaml.Controls.ICalendarView2, value: win32more.Windows.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_classmethod
    def get_SelectedDisabledBorderBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodaySelectedInnerBorderBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BlackoutStrikethroughBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BlackoutBackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarItemHoverBackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarItemPressedBackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarItemDisabledBackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodayBackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodayBlackoutBackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodayHoverBackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodayPressedBackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodayDisabledBackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodayBlackoutForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedHoverForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedPressedForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedDisabledForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OutOfScopeHoverForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OutOfScopePressedForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisabledForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayItemMarginProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthYearItemMarginProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfMonthLabelMarginProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfYearDecadeLabelMarginProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarItemCornerRadiusProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarIdentifierProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayOfWeekFormatProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsGroupLabelVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisplayModeProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstDayOfWeekProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsOutOfScopeEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTodayHighlightedProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxDateProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinDateProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_NumberOfWeeksInViewProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedDatesProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionModeProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TemplateSettingsProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FocusBorderBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedHoverBorderBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedPressedBorderBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedBorderBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HoverBorderBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PressedBorderBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarItemBorderBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OutOfScopeBackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarItemBackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PressedForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodayForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BlackoutForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OutOfScopeForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarItemForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayItemFontFamilyProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayItemFontSizeProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayItemFontStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayItemFontWeightProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodayFontWeightProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfMonthLabelFontFamilyProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfMonthLabelFontSizeProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfMonthLabelFontStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfMonthLabelFontWeightProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthYearItemFontFamilyProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthYearItemFontSizeProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthYearItemFontStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthYearItemFontWeightProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfYearDecadeLabelFontFamilyProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfYearDecadeLabelFontSizeProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfYearDecadeLabelFontStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfYearDecadeLabelFontWeightProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalDayItemAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalDayItemAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalFirstOfMonthLabelAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalFirstOfMonthLabelAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarItemBorderThicknessProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarViewDayItemStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BlackoutBackground = property(get_BlackoutBackground, put_BlackoutBackground)
    BlackoutForeground = property(get_BlackoutForeground, put_BlackoutForeground)
    BlackoutStrikethroughBrush = property(get_BlackoutStrikethroughBrush, put_BlackoutStrikethroughBrush)
    CalendarIdentifier = property(get_CalendarIdentifier, put_CalendarIdentifier)
    CalendarItemBackground = property(get_CalendarItemBackground, put_CalendarItemBackground)
    CalendarItemBorderBrush = property(get_CalendarItemBorderBrush, put_CalendarItemBorderBrush)
    CalendarItemBorderThickness = property(get_CalendarItemBorderThickness, put_CalendarItemBorderThickness)
    CalendarItemCornerRadius = property(get_CalendarItemCornerRadius, put_CalendarItemCornerRadius)
    CalendarItemDisabledBackground = property(get_CalendarItemDisabledBackground, put_CalendarItemDisabledBackground)
    CalendarItemForeground = property(get_CalendarItemForeground, put_CalendarItemForeground)
    CalendarItemHoverBackground = property(get_CalendarItemHoverBackground, put_CalendarItemHoverBackground)
    CalendarItemPressedBackground = property(get_CalendarItemPressedBackground, put_CalendarItemPressedBackground)
    CalendarViewDayItemStyle = property(get_CalendarViewDayItemStyle, put_CalendarViewDayItemStyle)
    DayItemFontFamily = property(get_DayItemFontFamily, put_DayItemFontFamily)
    DayItemFontSize = property(get_DayItemFontSize, put_DayItemFontSize)
    DayItemFontStyle = property(get_DayItemFontStyle, put_DayItemFontStyle)
    DayItemFontWeight = property(get_DayItemFontWeight, put_DayItemFontWeight)
    DayItemMargin = property(get_DayItemMargin, put_DayItemMargin)
    DayOfWeekFormat = property(get_DayOfWeekFormat, put_DayOfWeekFormat)
    DisabledForeground = property(get_DisabledForeground, put_DisabledForeground)
    DisplayMode = property(get_DisplayMode, put_DisplayMode)
    FirstDayOfWeek = property(get_FirstDayOfWeek, put_FirstDayOfWeek)
    FirstOfMonthLabelFontFamily = property(get_FirstOfMonthLabelFontFamily, put_FirstOfMonthLabelFontFamily)
    FirstOfMonthLabelFontSize = property(get_FirstOfMonthLabelFontSize, put_FirstOfMonthLabelFontSize)
    FirstOfMonthLabelFontStyle = property(get_FirstOfMonthLabelFontStyle, put_FirstOfMonthLabelFontStyle)
    FirstOfMonthLabelFontWeight = property(get_FirstOfMonthLabelFontWeight, put_FirstOfMonthLabelFontWeight)
    FirstOfMonthLabelMargin = property(get_FirstOfMonthLabelMargin, put_FirstOfMonthLabelMargin)
    FirstOfYearDecadeLabelFontFamily = property(get_FirstOfYearDecadeLabelFontFamily, put_FirstOfYearDecadeLabelFontFamily)
    FirstOfYearDecadeLabelFontSize = property(get_FirstOfYearDecadeLabelFontSize, put_FirstOfYearDecadeLabelFontSize)
    FirstOfYearDecadeLabelFontStyle = property(get_FirstOfYearDecadeLabelFontStyle, put_FirstOfYearDecadeLabelFontStyle)
    FirstOfYearDecadeLabelFontWeight = property(get_FirstOfYearDecadeLabelFontWeight, put_FirstOfYearDecadeLabelFontWeight)
    FirstOfYearDecadeLabelMargin = property(get_FirstOfYearDecadeLabelMargin, put_FirstOfYearDecadeLabelMargin)
    FocusBorderBrush = property(get_FocusBorderBrush, put_FocusBorderBrush)
    HorizontalDayItemAlignment = property(get_HorizontalDayItemAlignment, put_HorizontalDayItemAlignment)
    HorizontalFirstOfMonthLabelAlignment = property(get_HorizontalFirstOfMonthLabelAlignment, put_HorizontalFirstOfMonthLabelAlignment)
    HoverBorderBrush = property(get_HoverBorderBrush, put_HoverBorderBrush)
    IsGroupLabelVisible = property(get_IsGroupLabelVisible, put_IsGroupLabelVisible)
    IsOutOfScopeEnabled = property(get_IsOutOfScopeEnabled, put_IsOutOfScopeEnabled)
    IsTodayHighlighted = property(get_IsTodayHighlighted, put_IsTodayHighlighted)
    MaxDate = property(get_MaxDate, put_MaxDate)
    MinDate = property(get_MinDate, put_MinDate)
    MonthYearItemFontFamily = property(get_MonthYearItemFontFamily, put_MonthYearItemFontFamily)
    MonthYearItemFontSize = property(get_MonthYearItemFontSize, put_MonthYearItemFontSize)
    MonthYearItemFontStyle = property(get_MonthYearItemFontStyle, put_MonthYearItemFontStyle)
    MonthYearItemFontWeight = property(get_MonthYearItemFontWeight, put_MonthYearItemFontWeight)
    MonthYearItemMargin = property(get_MonthYearItemMargin, put_MonthYearItemMargin)
    NumberOfWeeksInView = property(get_NumberOfWeeksInView, put_NumberOfWeeksInView)
    OutOfScopeBackground = property(get_OutOfScopeBackground, put_OutOfScopeBackground)
    OutOfScopeForeground = property(get_OutOfScopeForeground, put_OutOfScopeForeground)
    OutOfScopeHoverForeground = property(get_OutOfScopeHoverForeground, put_OutOfScopeHoverForeground)
    OutOfScopePressedForeground = property(get_OutOfScopePressedForeground, put_OutOfScopePressedForeground)
    PressedBorderBrush = property(get_PressedBorderBrush, put_PressedBorderBrush)
    PressedForeground = property(get_PressedForeground, put_PressedForeground)
    SelectedBorderBrush = property(get_SelectedBorderBrush, put_SelectedBorderBrush)
    SelectedDates = property(get_SelectedDates, None)
    SelectedDisabledBorderBrush = property(get_SelectedDisabledBorderBrush, put_SelectedDisabledBorderBrush)
    SelectedDisabledForeground = property(get_SelectedDisabledForeground, put_SelectedDisabledForeground)
    SelectedForeground = property(get_SelectedForeground, put_SelectedForeground)
    SelectedHoverBorderBrush = property(get_SelectedHoverBorderBrush, put_SelectedHoverBorderBrush)
    SelectedHoverForeground = property(get_SelectedHoverForeground, put_SelectedHoverForeground)
    SelectedPressedBorderBrush = property(get_SelectedPressedBorderBrush, put_SelectedPressedBorderBrush)
    SelectedPressedForeground = property(get_SelectedPressedForeground, put_SelectedPressedForeground)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    TemplateSettings = property(get_TemplateSettings, None)
    TodayBackground = property(get_TodayBackground, put_TodayBackground)
    TodayBlackoutBackground = property(get_TodayBlackoutBackground, put_TodayBlackoutBackground)
    TodayBlackoutForeground = property(get_TodayBlackoutForeground, put_TodayBlackoutForeground)
    TodayDisabledBackground = property(get_TodayDisabledBackground, put_TodayDisabledBackground)
    TodayFontWeight = property(get_TodayFontWeight, put_TodayFontWeight)
    TodayForeground = property(get_TodayForeground, put_TodayForeground)
    TodayHoverBackground = property(get_TodayHoverBackground, put_TodayHoverBackground)
    TodayPressedBackground = property(get_TodayPressedBackground, put_TodayPressedBackground)
    TodaySelectedInnerBorderBrush = property(get_TodaySelectedInnerBorderBrush, put_TodaySelectedInnerBorderBrush)
    VerticalDayItemAlignment = property(get_VerticalDayItemAlignment, put_VerticalDayItemAlignment)
    VerticalFirstOfMonthLabelAlignment = property(get_VerticalFirstOfMonthLabelAlignment, put_VerticalFirstOfMonthLabelAlignment)
    _CalendarView_Meta_.BlackoutBackgroundProperty = property(get_BlackoutBackgroundProperty, None)
    _CalendarView_Meta_.BlackoutForegroundProperty = property(get_BlackoutForegroundProperty, None)
    _CalendarView_Meta_.BlackoutStrikethroughBrushProperty = property(get_BlackoutStrikethroughBrushProperty, None)
    _CalendarView_Meta_.CalendarIdentifierProperty = property(get_CalendarIdentifierProperty, None)
    _CalendarView_Meta_.CalendarItemBackgroundProperty = property(get_CalendarItemBackgroundProperty, None)
    _CalendarView_Meta_.CalendarItemBorderBrushProperty = property(get_CalendarItemBorderBrushProperty, None)
    _CalendarView_Meta_.CalendarItemBorderThicknessProperty = property(get_CalendarItemBorderThicknessProperty, None)
    _CalendarView_Meta_.CalendarItemCornerRadiusProperty = property(get_CalendarItemCornerRadiusProperty, None)
    _CalendarView_Meta_.CalendarItemDisabledBackgroundProperty = property(get_CalendarItemDisabledBackgroundProperty, None)
    _CalendarView_Meta_.CalendarItemForegroundProperty = property(get_CalendarItemForegroundProperty, None)
    _CalendarView_Meta_.CalendarItemHoverBackgroundProperty = property(get_CalendarItemHoverBackgroundProperty, None)
    _CalendarView_Meta_.CalendarItemPressedBackgroundProperty = property(get_CalendarItemPressedBackgroundProperty, None)
    _CalendarView_Meta_.CalendarViewDayItemStyleProperty = property(get_CalendarViewDayItemStyleProperty, None)
    _CalendarView_Meta_.DayItemFontFamilyProperty = property(get_DayItemFontFamilyProperty, None)
    _CalendarView_Meta_.DayItemFontSizeProperty = property(get_DayItemFontSizeProperty, None)
    _CalendarView_Meta_.DayItemFontStyleProperty = property(get_DayItemFontStyleProperty, None)
    _CalendarView_Meta_.DayItemFontWeightProperty = property(get_DayItemFontWeightProperty, None)
    _CalendarView_Meta_.DayItemMarginProperty = property(get_DayItemMarginProperty, None)
    _CalendarView_Meta_.DayOfWeekFormatProperty = property(get_DayOfWeekFormatProperty, None)
    _CalendarView_Meta_.DisabledForegroundProperty = property(get_DisabledForegroundProperty, None)
    _CalendarView_Meta_.DisplayModeProperty = property(get_DisplayModeProperty, None)
    _CalendarView_Meta_.FirstDayOfWeekProperty = property(get_FirstDayOfWeekProperty, None)
    _CalendarView_Meta_.FirstOfMonthLabelFontFamilyProperty = property(get_FirstOfMonthLabelFontFamilyProperty, None)
    _CalendarView_Meta_.FirstOfMonthLabelFontSizeProperty = property(get_FirstOfMonthLabelFontSizeProperty, None)
    _CalendarView_Meta_.FirstOfMonthLabelFontStyleProperty = property(get_FirstOfMonthLabelFontStyleProperty, None)
    _CalendarView_Meta_.FirstOfMonthLabelFontWeightProperty = property(get_FirstOfMonthLabelFontWeightProperty, None)
    _CalendarView_Meta_.FirstOfMonthLabelMarginProperty = property(get_FirstOfMonthLabelMarginProperty, None)
    _CalendarView_Meta_.FirstOfYearDecadeLabelFontFamilyProperty = property(get_FirstOfYearDecadeLabelFontFamilyProperty, None)
    _CalendarView_Meta_.FirstOfYearDecadeLabelFontSizeProperty = property(get_FirstOfYearDecadeLabelFontSizeProperty, None)
    _CalendarView_Meta_.FirstOfYearDecadeLabelFontStyleProperty = property(get_FirstOfYearDecadeLabelFontStyleProperty, None)
    _CalendarView_Meta_.FirstOfYearDecadeLabelFontWeightProperty = property(get_FirstOfYearDecadeLabelFontWeightProperty, None)
    _CalendarView_Meta_.FirstOfYearDecadeLabelMarginProperty = property(get_FirstOfYearDecadeLabelMarginProperty, None)
    _CalendarView_Meta_.FocusBorderBrushProperty = property(get_FocusBorderBrushProperty, None)
    _CalendarView_Meta_.HorizontalDayItemAlignmentProperty = property(get_HorizontalDayItemAlignmentProperty, None)
    _CalendarView_Meta_.HorizontalFirstOfMonthLabelAlignmentProperty = property(get_HorizontalFirstOfMonthLabelAlignmentProperty, None)
    _CalendarView_Meta_.HoverBorderBrushProperty = property(get_HoverBorderBrushProperty, None)
    _CalendarView_Meta_.IsGroupLabelVisibleProperty = property(get_IsGroupLabelVisibleProperty, None)
    _CalendarView_Meta_.IsOutOfScopeEnabledProperty = property(get_IsOutOfScopeEnabledProperty, None)
    _CalendarView_Meta_.IsTodayHighlightedProperty = property(get_IsTodayHighlightedProperty, None)
    _CalendarView_Meta_.MaxDateProperty = property(get_MaxDateProperty, None)
    _CalendarView_Meta_.MinDateProperty = property(get_MinDateProperty, None)
    _CalendarView_Meta_.MonthYearItemFontFamilyProperty = property(get_MonthYearItemFontFamilyProperty, None)
    _CalendarView_Meta_.MonthYearItemFontSizeProperty = property(get_MonthYearItemFontSizeProperty, None)
    _CalendarView_Meta_.MonthYearItemFontStyleProperty = property(get_MonthYearItemFontStyleProperty, None)
    _CalendarView_Meta_.MonthYearItemFontWeightProperty = property(get_MonthYearItemFontWeightProperty, None)
    _CalendarView_Meta_.MonthYearItemMarginProperty = property(get_MonthYearItemMarginProperty, None)
    _CalendarView_Meta_.NumberOfWeeksInViewProperty = property(get_NumberOfWeeksInViewProperty, None)
    _CalendarView_Meta_.OutOfScopeBackgroundProperty = property(get_OutOfScopeBackgroundProperty, None)
    _CalendarView_Meta_.OutOfScopeForegroundProperty = property(get_OutOfScopeForegroundProperty, None)
    _CalendarView_Meta_.OutOfScopeHoverForegroundProperty = property(get_OutOfScopeHoverForegroundProperty, None)
    _CalendarView_Meta_.OutOfScopePressedForegroundProperty = property(get_OutOfScopePressedForegroundProperty, None)
    _CalendarView_Meta_.PressedBorderBrushProperty = property(get_PressedBorderBrushProperty, None)
    _CalendarView_Meta_.PressedForegroundProperty = property(get_PressedForegroundProperty, None)
    _CalendarView_Meta_.SelectedBorderBrushProperty = property(get_SelectedBorderBrushProperty, None)
    _CalendarView_Meta_.SelectedDatesProperty = property(get_SelectedDatesProperty, None)
    _CalendarView_Meta_.SelectedDisabledBorderBrushProperty = property(get_SelectedDisabledBorderBrushProperty, None)
    _CalendarView_Meta_.SelectedDisabledForegroundProperty = property(get_SelectedDisabledForegroundProperty, None)
    _CalendarView_Meta_.SelectedForegroundProperty = property(get_SelectedForegroundProperty, None)
    _CalendarView_Meta_.SelectedHoverBorderBrushProperty = property(get_SelectedHoverBorderBrushProperty, None)
    _CalendarView_Meta_.SelectedHoverForegroundProperty = property(get_SelectedHoverForegroundProperty, None)
    _CalendarView_Meta_.SelectedPressedBorderBrushProperty = property(get_SelectedPressedBorderBrushProperty, None)
    _CalendarView_Meta_.SelectedPressedForegroundProperty = property(get_SelectedPressedForegroundProperty, None)
    _CalendarView_Meta_.SelectionModeProperty = property(get_SelectionModeProperty, None)
    _CalendarView_Meta_.TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
    _CalendarView_Meta_.TodayBackgroundProperty = property(get_TodayBackgroundProperty, None)
    _CalendarView_Meta_.TodayBlackoutBackgroundProperty = property(get_TodayBlackoutBackgroundProperty, None)
    _CalendarView_Meta_.TodayBlackoutForegroundProperty = property(get_TodayBlackoutForegroundProperty, None)
    _CalendarView_Meta_.TodayDisabledBackgroundProperty = property(get_TodayDisabledBackgroundProperty, None)
    _CalendarView_Meta_.TodayFontWeightProperty = property(get_TodayFontWeightProperty, None)
    _CalendarView_Meta_.TodayForegroundProperty = property(get_TodayForegroundProperty, None)
    _CalendarView_Meta_.TodayHoverBackgroundProperty = property(get_TodayHoverBackgroundProperty, None)
    _CalendarView_Meta_.TodayPressedBackgroundProperty = property(get_TodayPressedBackgroundProperty, None)
    _CalendarView_Meta_.TodaySelectedInnerBorderBrushProperty = property(get_TodaySelectedInnerBorderBrushProperty, None)
    _CalendarView_Meta_.VerticalDayItemAlignmentProperty = property(get_VerticalDayItemAlignmentProperty, None)
    _CalendarView_Meta_.VerticalFirstOfMonthLabelAlignmentProperty = property(get_VerticalFirstOfMonthLabelAlignmentProperty, None)
    CalendarViewDayItemChanging = event()
    SelectedDatesChanged = event()
class _CalendarViewDayItem_Meta_(ComPtr.__class__):
    pass
class CalendarViewDayItem(ComPtr, metaclass=_CalendarViewDayItem_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.ICalendarViewDayItem
    _classid_ = 'Windows.UI.Xaml.Controls.CalendarViewDayItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.CalendarViewDayItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewDayItemFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.CalendarViewDayItem: ...
    @winrt_mixinmethod
    def get_IsBlackout(self: win32more.Windows.UI.Xaml.Controls.ICalendarViewDayItem) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsBlackout(self: win32more.Windows.UI.Xaml.Controls.ICalendarViewDayItem, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Date(self: win32more.Windows.UI.Xaml.Controls.ICalendarViewDayItem) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def SetDensityColors(self: win32more.Windows.UI.Xaml.Controls.ICalendarViewDayItem, colors: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_classmethod
    def get_IsBlackoutProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewDayItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DateProperty(cls: win32more.Windows.UI.Xaml.Controls.ICalendarViewDayItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Date = property(get_Date, None)
    IsBlackout = property(get_IsBlackout, put_IsBlackout)
    _CalendarViewDayItem_Meta_.DateProperty = property(get_DateProperty, None)
    _CalendarViewDayItem_Meta_.IsBlackoutProperty = property(get_IsBlackoutProperty, None)
class CalendarViewDayItemChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ICalendarViewDayItemChangingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.CalendarViewDayItemChangingEventArgs'
    @winrt_mixinmethod
    def get_InRecycleQueue(self: win32more.Windows.UI.Xaml.Controls.ICalendarViewDayItemChangingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Windows.UI.Xaml.Controls.ICalendarViewDayItemChangingEventArgs) -> win32more.Windows.UI.Xaml.Controls.CalendarViewDayItem: ...
    @winrt_mixinmethod
    def get_Phase(self: win32more.Windows.UI.Xaml.Controls.ICalendarViewDayItemChangingEventArgs) -> UInt32: ...
    @winrt_mixinmethod
    def RegisterUpdateCallback(self: win32more.Windows.UI.Xaml.Controls.ICalendarViewDayItemChangingEventArgs, callback: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.CalendarView, win32more.Windows.UI.Xaml.Controls.CalendarViewDayItemChangingEventArgs]) -> Void: ...
    @winrt_mixinmethod
    def RegisterUpdateCallbackWithPhase(self: win32more.Windows.UI.Xaml.Controls.ICalendarViewDayItemChangingEventArgs, callbackPhase: UInt32, callback: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.CalendarView, win32more.Windows.UI.Xaml.Controls.CalendarViewDayItemChangingEventArgs]) -> Void: ...
    InRecycleQueue = property(get_InRecycleQueue, None)
    Item = property(get_Item, None)
    Phase = property(get_Phase, None)
class CalendarViewDayItemChangingEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8d745891-4de3-49cb-974b-083871a3afe6}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.UI.Xaml.Controls.CalendarView, e: win32more.Windows.UI.Xaml.Controls.CalendarViewDayItemChangingEventArgs) -> Void: ...
class CalendarViewDisplayMode(Enum, Int32):
    Month = 0
    Year = 1
    Decade = 2
class CalendarViewSelectedDatesChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ICalendarViewSelectedDatesChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.CalendarViewSelectedDatesChangedEventArgs'
    @winrt_mixinmethod
    def get_AddedDates(self: win32more.Windows.UI.Xaml.Controls.ICalendarViewSelectedDatesChangedEventArgs) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def get_RemovedDates(self: win32more.Windows.UI.Xaml.Controls.ICalendarViewSelectedDatesChangedEventArgs) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Foundation.DateTime]: ...
    AddedDates = property(get_AddedDates, None)
    RemovedDates = property(get_RemovedDates, None)
class CalendarViewSelectionMode(Enum, Int32):
    None_ = 0
    Single = 1
    Multiple = 2
class CandidateWindowAlignment(Enum, Int32):
    Default = 0
    BottomEdge = 1
class CandidateWindowBoundsChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ICandidateWindowBoundsChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.CandidateWindowBoundsChangedEventArgs'
    @winrt_mixinmethod
    def get_Bounds(self: win32more.Windows.UI.Xaml.Controls.ICandidateWindowBoundsChangedEventArgs) -> win32more.Windows.Foundation.Rect: ...
    Bounds = property(get_Bounds, None)
class _Canvas_Meta_(ComPtr.__class__):
    pass
class Canvas(ComPtr, metaclass=_Canvas_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Panel
    default_interface: win32more.Windows.UI.Xaml.Controls.ICanvas
    _classid_ = 'Windows.UI.Xaml.Controls.Canvas'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.Canvas.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ICanvasFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Canvas: ...
    @winrt_classmethod
    def get_LeftProperty(cls: win32more.Windows.UI.Xaml.Controls.ICanvasStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetLeft(cls: win32more.Windows.UI.Xaml.Controls.ICanvasStatics, element: win32more.Windows.UI.Xaml.UIElement) -> Double: ...
    @winrt_classmethod
    def SetLeft(cls: win32more.Windows.UI.Xaml.Controls.ICanvasStatics, element: win32more.Windows.UI.Xaml.UIElement, length: Double) -> Void: ...
    @winrt_classmethod
    def get_TopProperty(cls: win32more.Windows.UI.Xaml.Controls.ICanvasStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetTop(cls: win32more.Windows.UI.Xaml.Controls.ICanvasStatics, element: win32more.Windows.UI.Xaml.UIElement) -> Double: ...
    @winrt_classmethod
    def SetTop(cls: win32more.Windows.UI.Xaml.Controls.ICanvasStatics, element: win32more.Windows.UI.Xaml.UIElement, length: Double) -> Void: ...
    @winrt_classmethod
    def get_ZIndexProperty(cls: win32more.Windows.UI.Xaml.Controls.ICanvasStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetZIndex(cls: win32more.Windows.UI.Xaml.Controls.ICanvasStatics, element: win32more.Windows.UI.Xaml.UIElement) -> Int32: ...
    @winrt_classmethod
    def SetZIndex(cls: win32more.Windows.UI.Xaml.Controls.ICanvasStatics, element: win32more.Windows.UI.Xaml.UIElement, value: Int32) -> Void: ...
    _Canvas_Meta_.LeftProperty = property(get_LeftProperty, None)
    _Canvas_Meta_.TopProperty = property(get_TopProperty, None)
    _Canvas_Meta_.ZIndexProperty = property(get_ZIndexProperty, None)
class _CaptureElement_Meta_(ComPtr.__class__):
    pass
class CaptureElement(ComPtr, metaclass=_CaptureElement_Meta_):
    extends: win32more.Windows.UI.Xaml.FrameworkElement
    default_interface: win32more.Windows.UI.Xaml.Controls.ICaptureElement
    _classid_ = 'Windows.UI.Xaml.Controls.CaptureElement'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.CaptureElement.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.CaptureElement: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Windows.UI.Xaml.Controls.ICaptureElement) -> win32more.Windows.Media.Capture.MediaCapture: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Windows.UI.Xaml.Controls.ICaptureElement, value: win32more.Windows.Media.Capture.MediaCapture) -> Void: ...
    @winrt_mixinmethod
    def get_Stretch(self: win32more.Windows.UI.Xaml.Controls.ICaptureElement) -> win32more.Windows.UI.Xaml.Media.Stretch: ...
    @winrt_mixinmethod
    def put_Stretch(self: win32more.Windows.UI.Xaml.Controls.ICaptureElement, value: win32more.Windows.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_classmethod
    def get_SourceProperty(cls: win32more.Windows.UI.Xaml.Controls.ICaptureElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StretchProperty(cls: win32more.Windows.UI.Xaml.Controls.ICaptureElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Source = property(get_Source, put_Source)
    Stretch = property(get_Stretch, put_Stretch)
    _CaptureElement_Meta_.SourceProperty = property(get_SourceProperty, None)
    _CaptureElement_Meta_.StretchProperty = property(get_StretchProperty, None)
class CharacterCasing(Enum, Int32):
    Normal = 0
    Lower = 1
    Upper = 2
class CheckBox(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.ToggleButton
    default_interface: win32more.Windows.UI.Xaml.Controls.ICheckBox
    _classid_ = 'Windows.UI.Xaml.Controls.CheckBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.CheckBox.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ICheckBoxFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.CheckBox: ...
class ChoosingGroupHeaderContainerEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IChoosingGroupHeaderContainerEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.ChoosingGroupHeaderContainerEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ChoosingGroupHeaderContainerEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.ChoosingGroupHeaderContainerEventArgs: ...
    @winrt_mixinmethod
    def get_GroupHeaderContainer(self: win32more.Windows.UI.Xaml.Controls.IChoosingGroupHeaderContainerEventArgs) -> win32more.Windows.UI.Xaml.Controls.ListViewBaseHeaderItem: ...
    @winrt_mixinmethod
    def put_GroupHeaderContainer(self: win32more.Windows.UI.Xaml.Controls.IChoosingGroupHeaderContainerEventArgs, value: win32more.Windows.UI.Xaml.Controls.ListViewBaseHeaderItem) -> Void: ...
    @winrt_mixinmethod
    def get_GroupIndex(self: win32more.Windows.UI.Xaml.Controls.IChoosingGroupHeaderContainerEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Group(self: win32more.Windows.UI.Xaml.Controls.IChoosingGroupHeaderContainerEventArgs) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    Group = property(get_Group, None)
    GroupHeaderContainer = property(get_GroupHeaderContainer, put_GroupHeaderContainer)
    GroupIndex = property(get_GroupIndex, None)
class ChoosingItemContainerEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IChoosingItemContainerEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.ChoosingItemContainerEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ChoosingItemContainerEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.ChoosingItemContainerEventArgs: ...
    @winrt_mixinmethod
    def get_ItemIndex(self: win32more.Windows.UI.Xaml.Controls.IChoosingItemContainerEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Windows.UI.Xaml.Controls.IChoosingItemContainerEventArgs) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_ItemContainer(self: win32more.Windows.UI.Xaml.Controls.IChoosingItemContainerEventArgs) -> win32more.Windows.UI.Xaml.Controls.Primitives.SelectorItem: ...
    @winrt_mixinmethod
    def put_ItemContainer(self: win32more.Windows.UI.Xaml.Controls.IChoosingItemContainerEventArgs, value: win32more.Windows.UI.Xaml.Controls.Primitives.SelectorItem) -> Void: ...
    @winrt_mixinmethod
    def get_IsContainerPrepared(self: win32more.Windows.UI.Xaml.Controls.IChoosingItemContainerEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsContainerPrepared(self: win32more.Windows.UI.Xaml.Controls.IChoosingItemContainerEventArgs, value: Boolean) -> Void: ...
    IsContainerPrepared = property(get_IsContainerPrepared, put_IsContainerPrepared)
    Item = property(get_Item, None)
    ItemContainer = property(get_ItemContainer, put_ItemContainer)
    ItemIndex = property(get_ItemIndex, None)
class CleanUpVirtualizedItemEventArgs(ComPtr):
    extends: win32more.Windows.UI.Xaml.RoutedEventArgs
    default_interface: win32more.Windows.UI.Xaml.Controls.ICleanUpVirtualizedItemEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.CleanUpVirtualizedItemEventArgs'
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.UI.Xaml.Controls.ICleanUpVirtualizedItemEventArgs) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_UIElement(self: win32more.Windows.UI.Xaml.Controls.ICleanUpVirtualizedItemEventArgs) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Windows.UI.Xaml.Controls.ICleanUpVirtualizedItemEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Windows.UI.Xaml.Controls.ICleanUpVirtualizedItemEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    UIElement = property(get_UIElement, None)
    Value = property(get_Value, None)
class CleanUpVirtualizedItemEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{cacad0d6-0f0d-4870-884d-f2dedf674288}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Controls.CleanUpVirtualizedItemEventArgs) -> Void: ...
class ClickMode(Enum, Int32):
    Release = 0
    Press = 1
    Hover = 2
class ColorChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IColorChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.ColorChangedEventArgs'
    @winrt_mixinmethod
    def get_OldColor(self: win32more.Windows.UI.Xaml.Controls.IColorChangedEventArgs) -> win32more.Windows.UI.Color: ...
    @winrt_mixinmethod
    def get_NewColor(self: win32more.Windows.UI.Xaml.Controls.IColorChangedEventArgs) -> win32more.Windows.UI.Color: ...
    NewColor = property(get_NewColor, None)
    OldColor = property(get_OldColor, None)
class _ColorPicker_Meta_(ComPtr.__class__):
    pass
class ColorPicker(ComPtr, metaclass=_ColorPicker_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IColorPicker
    _classid_ = 'Windows.UI.Xaml.Controls.ColorPicker'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ColorPicker.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ColorPicker: ...
    @winrt_mixinmethod
    def get_Color(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> win32more.Windows.UI.Color: ...
    @winrt_mixinmethod
    def put_Color(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_mixinmethod
    def get_PreviousColor(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_mixinmethod
    def put_PreviousColor(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_mixinmethod
    def get_IsAlphaEnabled(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsAlphaEnabled(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsColorSpectrumVisible(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsColorSpectrumVisible(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsColorPreviewVisible(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsColorPreviewVisible(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsColorSliderVisible(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsColorSliderVisible(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsAlphaSliderVisible(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsAlphaSliderVisible(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsMoreButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsMoreButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsColorChannelTextInputVisible(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsColorChannelTextInputVisible(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsAlphaTextInputVisible(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsAlphaTextInputVisible(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsHexInputVisible(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsHexInputVisible(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MinHue(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> Int32: ...
    @winrt_mixinmethod
    def put_MinHue(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_MaxHue(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxHue(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_MinSaturation(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> Int32: ...
    @winrt_mixinmethod
    def put_MinSaturation(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_MaxSaturation(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxSaturation(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_MinValue(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> Int32: ...
    @winrt_mixinmethod
    def put_MinValue(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_MaxValue(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxValue(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_ColorSpectrumShape(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> win32more.Windows.UI.Xaml.Controls.ColorSpectrumShape: ...
    @winrt_mixinmethod
    def put_ColorSpectrumShape(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: win32more.Windows.UI.Xaml.Controls.ColorSpectrumShape) -> Void: ...
    @winrt_mixinmethod
    def get_ColorSpectrumComponents(self: win32more.Windows.UI.Xaml.Controls.IColorPicker) -> win32more.Windows.UI.Xaml.Controls.ColorSpectrumComponents: ...
    @winrt_mixinmethod
    def put_ColorSpectrumComponents(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, value: win32more.Windows.UI.Xaml.Controls.ColorSpectrumComponents) -> Void: ...
    @winrt_mixinmethod
    def add_ColorChanged(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ColorPicker, win32more.Windows.UI.Xaml.Controls.ColorChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ColorChanged(self: win32more.Windows.UI.Xaml.Controls.IColorPicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_ColorProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PreviousColorProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsAlphaEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsColorSpectrumVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsColorPreviewVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsColorSliderVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsAlphaSliderVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsMoreButtonVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsColorChannelTextInputVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsAlphaTextInputVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsHexInputVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinHueProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxHueProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinSaturationProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxSaturationProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinValueProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxValueProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ColorSpectrumShapeProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ColorSpectrumComponentsProperty(cls: win32more.Windows.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Color = property(get_Color, put_Color)
    ColorSpectrumComponents = property(get_ColorSpectrumComponents, put_ColorSpectrumComponents)
    ColorSpectrumShape = property(get_ColorSpectrumShape, put_ColorSpectrumShape)
    IsAlphaEnabled = property(get_IsAlphaEnabled, put_IsAlphaEnabled)
    IsAlphaSliderVisible = property(get_IsAlphaSliderVisible, put_IsAlphaSliderVisible)
    IsAlphaTextInputVisible = property(get_IsAlphaTextInputVisible, put_IsAlphaTextInputVisible)
    IsColorChannelTextInputVisible = property(get_IsColorChannelTextInputVisible, put_IsColorChannelTextInputVisible)
    IsColorPreviewVisible = property(get_IsColorPreviewVisible, put_IsColorPreviewVisible)
    IsColorSliderVisible = property(get_IsColorSliderVisible, put_IsColorSliderVisible)
    IsColorSpectrumVisible = property(get_IsColorSpectrumVisible, put_IsColorSpectrumVisible)
    IsHexInputVisible = property(get_IsHexInputVisible, put_IsHexInputVisible)
    IsMoreButtonVisible = property(get_IsMoreButtonVisible, put_IsMoreButtonVisible)
    MaxHue = property(get_MaxHue, put_MaxHue)
    MaxSaturation = property(get_MaxSaturation, put_MaxSaturation)
    MaxValue = property(get_MaxValue, put_MaxValue)
    MinHue = property(get_MinHue, put_MinHue)
    MinSaturation = property(get_MinSaturation, put_MinSaturation)
    MinValue = property(get_MinValue, put_MinValue)
    PreviousColor = property(get_PreviousColor, put_PreviousColor)
    _ColorPicker_Meta_.ColorProperty = property(get_ColorProperty, None)
    _ColorPicker_Meta_.ColorSpectrumComponentsProperty = property(get_ColorSpectrumComponentsProperty, None)
    _ColorPicker_Meta_.ColorSpectrumShapeProperty = property(get_ColorSpectrumShapeProperty, None)
    _ColorPicker_Meta_.IsAlphaEnabledProperty = property(get_IsAlphaEnabledProperty, None)
    _ColorPicker_Meta_.IsAlphaSliderVisibleProperty = property(get_IsAlphaSliderVisibleProperty, None)
    _ColorPicker_Meta_.IsAlphaTextInputVisibleProperty = property(get_IsAlphaTextInputVisibleProperty, None)
    _ColorPicker_Meta_.IsColorChannelTextInputVisibleProperty = property(get_IsColorChannelTextInputVisibleProperty, None)
    _ColorPicker_Meta_.IsColorPreviewVisibleProperty = property(get_IsColorPreviewVisibleProperty, None)
    _ColorPicker_Meta_.IsColorSliderVisibleProperty = property(get_IsColorSliderVisibleProperty, None)
    _ColorPicker_Meta_.IsColorSpectrumVisibleProperty = property(get_IsColorSpectrumVisibleProperty, None)
    _ColorPicker_Meta_.IsHexInputVisibleProperty = property(get_IsHexInputVisibleProperty, None)
    _ColorPicker_Meta_.IsMoreButtonVisibleProperty = property(get_IsMoreButtonVisibleProperty, None)
    _ColorPicker_Meta_.MaxHueProperty = property(get_MaxHueProperty, None)
    _ColorPicker_Meta_.MaxSaturationProperty = property(get_MaxSaturationProperty, None)
    _ColorPicker_Meta_.MaxValueProperty = property(get_MaxValueProperty, None)
    _ColorPicker_Meta_.MinHueProperty = property(get_MinHueProperty, None)
    _ColorPicker_Meta_.MinSaturationProperty = property(get_MinSaturationProperty, None)
    _ColorPicker_Meta_.MinValueProperty = property(get_MinValueProperty, None)
    _ColorPicker_Meta_.PreviousColorProperty = property(get_PreviousColorProperty, None)
    ColorChanged = event()
class ColorPickerHsvChannel(Enum, Int32):
    Hue = 0
    Saturation = 1
    Value = 2
    Alpha = 3
class ColorSpectrumComponents(Enum, Int32):
    HueValue = 0
    ValueHue = 1
    HueSaturation = 2
    SaturationHue = 3
    SaturationValue = 4
    ValueSaturation = 5
class ColorSpectrumShape(Enum, Int32):
    Box = 0
    Ring = 1
class _ColumnDefinition_Meta_(ComPtr.__class__):
    pass
class ColumnDefinition(ComPtr, metaclass=_ColumnDefinition_Meta_):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Controls.IColumnDefinition
    _classid_ = 'Windows.UI.Xaml.Controls.ColumnDefinition'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ColumnDefinition.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.ColumnDefinition: ...
    @winrt_mixinmethod
    def get_Width(self: win32more.Windows.UI.Xaml.Controls.IColumnDefinition) -> win32more.Windows.UI.Xaml.GridLength: ...
    @winrt_mixinmethod
    def put_Width(self: win32more.Windows.UI.Xaml.Controls.IColumnDefinition, value: win32more.Windows.UI.Xaml.GridLength) -> Void: ...
    @winrt_mixinmethod
    def get_MaxWidth(self: win32more.Windows.UI.Xaml.Controls.IColumnDefinition) -> Double: ...
    @winrt_mixinmethod
    def put_MaxWidth(self: win32more.Windows.UI.Xaml.Controls.IColumnDefinition, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_MinWidth(self: win32more.Windows.UI.Xaml.Controls.IColumnDefinition) -> Double: ...
    @winrt_mixinmethod
    def put_MinWidth(self: win32more.Windows.UI.Xaml.Controls.IColumnDefinition, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ActualWidth(self: win32more.Windows.UI.Xaml.Controls.IColumnDefinition) -> Double: ...
    @winrt_classmethod
    def get_WidthProperty(cls: win32more.Windows.UI.Xaml.Controls.IColumnDefinitionStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxWidthProperty(cls: win32more.Windows.UI.Xaml.Controls.IColumnDefinitionStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinWidthProperty(cls: win32more.Windows.UI.Xaml.Controls.IColumnDefinitionStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ActualWidth = property(get_ActualWidth, None)
    MaxWidth = property(get_MaxWidth, put_MaxWidth)
    MinWidth = property(get_MinWidth, put_MinWidth)
    Width = property(get_Width, put_Width)
    _ColumnDefinition_Meta_.MaxWidthProperty = property(get_MaxWidthProperty, None)
    _ColumnDefinition_Meta_.MinWidthProperty = property(get_MinWidthProperty, None)
    _ColumnDefinition_Meta_.WidthProperty = property(get_WidthProperty, None)
class ColumnDefinitionCollection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[win32more.Windows.UI.Xaml.Controls.ColumnDefinition]]
    default_interface: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.ColumnDefinition]
    _classid_ = 'Windows.UI.Xaml.Controls.ColumnDefinitionCollection'
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.ColumnDefinition], index: UInt32) -> win32more.Windows.UI.Xaml.Controls.ColumnDefinition: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.ColumnDefinition]) -> UInt32: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.ColumnDefinition]) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.UI.Xaml.Controls.ColumnDefinition]: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.ColumnDefinition], value: win32more.Windows.UI.Xaml.Controls.ColumnDefinition, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def SetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.ColumnDefinition], index: UInt32, value: win32more.Windows.UI.Xaml.Controls.ColumnDefinition) -> Void: ...
    @winrt_mixinmethod
    def InsertAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.ColumnDefinition], index: UInt32, value: win32more.Windows.UI.Xaml.Controls.ColumnDefinition) -> Void: ...
    @winrt_mixinmethod
    def RemoveAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.ColumnDefinition], index: UInt32) -> Void: ...
    @winrt_mixinmethod
    def Append(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.ColumnDefinition], value: win32more.Windows.UI.Xaml.Controls.ColumnDefinition) -> Void: ...
    @winrt_mixinmethod
    def RemoveAtEnd(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.ColumnDefinition]) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.ColumnDefinition]) -> Void: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.ColumnDefinition], startIndex: UInt32, items: FillArray[win32more.Windows.UI.Xaml.Controls.ColumnDefinition]) -> UInt32: ...
    @winrt_mixinmethod
    def ReplaceAll(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.ColumnDefinition], items: PassArray[win32more.Windows.UI.Xaml.Controls.ColumnDefinition]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.UI.Xaml.Controls.ColumnDefinition]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.UI.Xaml.Controls.ColumnDefinition]: ...
    Size = property(get_Size, None)
class _ComboBox_Meta_(ComPtr.__class__):
    pass
class ComboBox(ComPtr, metaclass=_ComboBox_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.Selector
    default_interface: win32more.Windows.UI.Xaml.Controls.IComboBox
    _classid_ = 'Windows.UI.Xaml.Controls.ComboBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ComboBox.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IComboBoxFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ComboBox: ...
    @winrt_mixinmethod
    def get_IsDropDownOpen(self: win32more.Windows.UI.Xaml.Controls.IComboBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDropDownOpen(self: win32more.Windows.UI.Xaml.Controls.IComboBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsEditable(self: win32more.Windows.UI.Xaml.Controls.IComboBox) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsSelectionBoxHighlighted(self: win32more.Windows.UI.Xaml.Controls.IComboBox) -> Boolean: ...
    @winrt_mixinmethod
    def get_MaxDropDownHeight(self: win32more.Windows.UI.Xaml.Controls.IComboBox) -> Double: ...
    @winrt_mixinmethod
    def put_MaxDropDownHeight(self: win32more.Windows.UI.Xaml.Controls.IComboBox, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionBoxItem(self: win32more.Windows.UI.Xaml.Controls.IComboBox) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_SelectionBoxItemTemplate(self: win32more.Windows.UI.Xaml.Controls.IComboBox) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Windows.UI.Xaml.Controls.IComboBox) -> win32more.Windows.UI.Xaml.Controls.Primitives.ComboBoxTemplateSettings: ...
    @winrt_mixinmethod
    def add_DropDownClosed(self: win32more.Windows.UI.Xaml.Controls.IComboBox, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DropDownClosed(self: win32more.Windows.UI.Xaml.Controls.IComboBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DropDownOpened(self: win32more.Windows.UI.Xaml.Controls.IComboBox, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DropDownOpened(self: win32more.Windows.UI.Xaml.Controls.IComboBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Windows.UI.Xaml.Controls.IComboBox2) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Windows.UI.Xaml.Controls.IComboBox2, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IComboBox2) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IComboBox2, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderText(self: win32more.Windows.UI.Xaml.Controls.IComboBox2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PlaceholderText(self: win32more.Windows.UI.Xaml.Controls.IComboBox2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_LightDismissOverlayMode(self: win32more.Windows.UI.Xaml.Controls.IComboBox3) -> win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_mixinmethod
    def put_LightDismissOverlayMode(self: win32more.Windows.UI.Xaml.Controls.IComboBox3, value: win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextSearchEnabled(self: win32more.Windows.UI.Xaml.Controls.IComboBox3) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextSearchEnabled(self: win32more.Windows.UI.Xaml.Controls.IComboBox3, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionChangedTrigger(self: win32more.Windows.UI.Xaml.Controls.IComboBox4) -> win32more.Windows.UI.Xaml.Controls.ComboBoxSelectionChangedTrigger: ...
    @winrt_mixinmethod
    def put_SelectionChangedTrigger(self: win32more.Windows.UI.Xaml.Controls.IComboBox4, value: win32more.Windows.UI.Xaml.Controls.ComboBoxSelectionChangedTrigger) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderForeground(self: win32more.Windows.UI.Xaml.Controls.IComboBox5) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_PlaceholderForeground(self: win32more.Windows.UI.Xaml.Controls.IComboBox5, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def put_IsEditable(self: win32more.Windows.UI.Xaml.Controls.IComboBox6, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.UI.Xaml.Controls.IComboBox6) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Windows.UI.Xaml.Controls.IComboBox6, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_TextBoxStyle(self: win32more.Windows.UI.Xaml.Controls.IComboBox6) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_TextBoxStyle(self: win32more.Windows.UI.Xaml.Controls.IComboBox6, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.UI.Xaml.Controls.IComboBox6) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.UI.Xaml.Controls.IComboBox6, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def add_TextSubmitted(self: win32more.Windows.UI.Xaml.Controls.IComboBox6, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ComboBox, win32more.Windows.UI.Xaml.Controls.ComboBoxTextSubmittedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextSubmitted(self: win32more.Windows.UI.Xaml.Controls.IComboBox6, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def OnDropDownClosed(self: win32more.Windows.UI.Xaml.Controls.IComboBoxOverrides, e: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnDropDownOpened(self: win32more.Windows.UI.Xaml.Controls.IComboBoxOverrides, e: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_IsEditableProperty(cls: win32more.Windows.UI.Xaml.Controls.IComboBoxStatics6) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextProperty(cls: win32more.Windows.UI.Xaml.Controls.IComboBoxStatics6) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextBoxStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.IComboBoxStatics6) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DescriptionProperty(cls: win32more.Windows.UI.Xaml.Controls.IComboBoxStatics6) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.IComboBoxStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionChangedTriggerProperty(cls: win32more.Windows.UI.Xaml.Controls.IComboBoxStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LightDismissOverlayModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IComboBoxStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextSearchEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IComboBoxStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.IComboBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IComboBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderTextProperty(cls: win32more.Windows.UI.Xaml.Controls.IComboBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsDropDownOpenProperty(cls: win32more.Windows.UI.Xaml.Controls.IComboBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxDropDownHeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IComboBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Description = property(get_Description, put_Description)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsDropDownOpen = property(get_IsDropDownOpen, put_IsDropDownOpen)
    IsEditable = property(get_IsEditable, put_IsEditable)
    IsSelectionBoxHighlighted = property(get_IsSelectionBoxHighlighted, None)
    IsTextSearchEnabled = property(get_IsTextSearchEnabled, put_IsTextSearchEnabled)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    MaxDropDownHeight = property(get_MaxDropDownHeight, put_MaxDropDownHeight)
    PlaceholderForeground = property(get_PlaceholderForeground, put_PlaceholderForeground)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    SelectionBoxItem = property(get_SelectionBoxItem, None)
    SelectionBoxItemTemplate = property(get_SelectionBoxItemTemplate, None)
    SelectionChangedTrigger = property(get_SelectionChangedTrigger, put_SelectionChangedTrigger)
    TemplateSettings = property(get_TemplateSettings, None)
    Text = property(get_Text, put_Text)
    TextBoxStyle = property(get_TextBoxStyle, put_TextBoxStyle)
    _ComboBox_Meta_.DescriptionProperty = property(get_DescriptionProperty, None)
    _ComboBox_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _ComboBox_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _ComboBox_Meta_.IsDropDownOpenProperty = property(get_IsDropDownOpenProperty, None)
    _ComboBox_Meta_.IsEditableProperty = property(get_IsEditableProperty, None)
    _ComboBox_Meta_.IsTextSearchEnabledProperty = property(get_IsTextSearchEnabledProperty, None)
    _ComboBox_Meta_.LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    _ComboBox_Meta_.MaxDropDownHeightProperty = property(get_MaxDropDownHeightProperty, None)
    _ComboBox_Meta_.PlaceholderForegroundProperty = property(get_PlaceholderForegroundProperty, None)
    _ComboBox_Meta_.PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    _ComboBox_Meta_.SelectionChangedTriggerProperty = property(get_SelectionChangedTriggerProperty, None)
    _ComboBox_Meta_.TextBoxStyleProperty = property(get_TextBoxStyleProperty, None)
    _ComboBox_Meta_.TextProperty = property(get_TextProperty, None)
    DropDownClosed = event()
    DropDownOpened = event()
    TextSubmitted = event()
class ComboBoxItem(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.SelectorItem
    default_interface: win32more.Windows.UI.Xaml.Controls.IComboBoxItem
    _classid_ = 'Windows.UI.Xaml.Controls.ComboBoxItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ComboBoxItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IComboBoxItemFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ComboBoxItem: ...
class ComboBoxSelectionChangedTrigger(Enum, Int32):
    Committed = 0
    Always = 1
class ComboBoxTextSubmittedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IComboBoxTextSubmittedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.ComboBoxTextSubmittedEventArgs'
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.UI.Xaml.Controls.IComboBoxTextSubmittedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Handled(self: win32more.Windows.UI.Xaml.Controls.IComboBoxTextSubmittedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Windows.UI.Xaml.Controls.IComboBoxTextSubmittedEventArgs, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
    Text = property(get_Text, None)
class _CommandBar_Meta_(ComPtr.__class__):
    pass
class CommandBar(ComPtr, metaclass=_CommandBar_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.AppBar
    default_interface: win32more.Windows.UI.Xaml.Controls.ICommandBar
    _classid_ = 'Windows.UI.Xaml.Controls.CommandBar'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.CommandBar.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ICommandBarFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.CommandBar: ...
    @winrt_mixinmethod
    def get_PrimaryCommands(self: win32more.Windows.UI.Xaml.Controls.ICommandBar) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Windows.UI.Xaml.Controls.ICommandBarElement]: ...
    @winrt_mixinmethod
    def get_SecondaryCommands(self: win32more.Windows.UI.Xaml.Controls.ICommandBar) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Windows.UI.Xaml.Controls.ICommandBarElement]: ...
    @winrt_mixinmethod
    def get_CommandBarOverflowPresenterStyle(self: win32more.Windows.UI.Xaml.Controls.ICommandBar2) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_CommandBarOverflowPresenterStyle(self: win32more.Windows.UI.Xaml.Controls.ICommandBar2, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_CommandBarTemplateSettings(self: win32more.Windows.UI.Xaml.Controls.ICommandBar2) -> win32more.Windows.UI.Xaml.Controls.Primitives.CommandBarTemplateSettings: ...
    @winrt_mixinmethod
    def get_DefaultLabelPosition(self: win32more.Windows.UI.Xaml.Controls.ICommandBar3) -> win32more.Windows.UI.Xaml.Controls.CommandBarDefaultLabelPosition: ...
    @winrt_mixinmethod
    def put_DefaultLabelPosition(self: win32more.Windows.UI.Xaml.Controls.ICommandBar3, value: win32more.Windows.UI.Xaml.Controls.CommandBarDefaultLabelPosition) -> Void: ...
    @winrt_mixinmethod
    def get_OverflowButtonVisibility(self: win32more.Windows.UI.Xaml.Controls.ICommandBar3) -> win32more.Windows.UI.Xaml.Controls.CommandBarOverflowButtonVisibility: ...
    @winrt_mixinmethod
    def put_OverflowButtonVisibility(self: win32more.Windows.UI.Xaml.Controls.ICommandBar3, value: win32more.Windows.UI.Xaml.Controls.CommandBarOverflowButtonVisibility) -> Void: ...
    @winrt_mixinmethod
    def get_IsDynamicOverflowEnabled(self: win32more.Windows.UI.Xaml.Controls.ICommandBar3) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDynamicOverflowEnabled(self: win32more.Windows.UI.Xaml.Controls.ICommandBar3, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_DynamicOverflowItemsChanging(self: win32more.Windows.UI.Xaml.Controls.ICommandBar3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.CommandBar, win32more.Windows.UI.Xaml.Controls.DynamicOverflowItemsChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DynamicOverflowItemsChanging(self: win32more.Windows.UI.Xaml.Controls.ICommandBar3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_DefaultLabelPositionProperty(cls: win32more.Windows.UI.Xaml.Controls.ICommandBarStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OverflowButtonVisibilityProperty(cls: win32more.Windows.UI.Xaml.Controls.ICommandBarStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsDynamicOverflowEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.ICommandBarStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CommandBarOverflowPresenterStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.ICommandBarStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PrimaryCommandsProperty(cls: win32more.Windows.UI.Xaml.Controls.ICommandBarStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SecondaryCommandsProperty(cls: win32more.Windows.UI.Xaml.Controls.ICommandBarStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CommandBarOverflowPresenterStyle = property(get_CommandBarOverflowPresenterStyle, put_CommandBarOverflowPresenterStyle)
    CommandBarTemplateSettings = property(get_CommandBarTemplateSettings, None)
    DefaultLabelPosition = property(get_DefaultLabelPosition, put_DefaultLabelPosition)
    IsDynamicOverflowEnabled = property(get_IsDynamicOverflowEnabled, put_IsDynamicOverflowEnabled)
    OverflowButtonVisibility = property(get_OverflowButtonVisibility, put_OverflowButtonVisibility)
    PrimaryCommands = property(get_PrimaryCommands, None)
    SecondaryCommands = property(get_SecondaryCommands, None)
    _CommandBar_Meta_.CommandBarOverflowPresenterStyleProperty = property(get_CommandBarOverflowPresenterStyleProperty, None)
    _CommandBar_Meta_.DefaultLabelPositionProperty = property(get_DefaultLabelPositionProperty, None)
    _CommandBar_Meta_.IsDynamicOverflowEnabledProperty = property(get_IsDynamicOverflowEnabledProperty, None)
    _CommandBar_Meta_.OverflowButtonVisibilityProperty = property(get_OverflowButtonVisibilityProperty, None)
    _CommandBar_Meta_.PrimaryCommandsProperty = property(get_PrimaryCommandsProperty, None)
    _CommandBar_Meta_.SecondaryCommandsProperty = property(get_SecondaryCommandsProperty, None)
    DynamicOverflowItemsChanging = event()
class CommandBarDefaultLabelPosition(Enum, Int32):
    Bottom = 0
    Right = 1
    Collapsed = 2
class CommandBarDynamicOverflowAction(Enum, Int32):
    AddingToOverflow = 0
    RemovingFromOverflow = 1
class CommandBarFlyout(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase
    default_interface: win32more.Windows.UI.Xaml.Controls.ICommandBarFlyout
    _classid_ = 'Windows.UI.Xaml.Controls.CommandBarFlyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.CommandBarFlyout.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ICommandBarFlyoutFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.CommandBarFlyout: ...
    @winrt_mixinmethod
    def get_PrimaryCommands(self: win32more.Windows.UI.Xaml.Controls.ICommandBarFlyout) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Windows.UI.Xaml.Controls.ICommandBarElement]: ...
    @winrt_mixinmethod
    def get_SecondaryCommands(self: win32more.Windows.UI.Xaml.Controls.ICommandBarFlyout) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Windows.UI.Xaml.Controls.ICommandBarElement]: ...
    PrimaryCommands = property(get_PrimaryCommands, None)
    SecondaryCommands = property(get_SecondaryCommands, None)
class CommandBarLabelPosition(Enum, Int32):
    Default = 0
    Collapsed = 1
class CommandBarOverflowButtonVisibility(Enum, Int32):
    Auto = 0
    Visible = 1
    Collapsed = 2
class CommandBarOverflowPresenter(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.ItemsControl
    default_interface: win32more.Windows.UI.Xaml.Controls.ICommandBarOverflowPresenter
    _classid_ = 'Windows.UI.Xaml.Controls.CommandBarOverflowPresenter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.CommandBarOverflowPresenter.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ICommandBarOverflowPresenterFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.CommandBarOverflowPresenter: ...
class ContainerContentChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IContainerContentChangingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.ContainerContentChangingEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ContainerContentChangingEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.ContainerContentChangingEventArgs: ...
    @winrt_mixinmethod
    def get_ItemContainer(self: win32more.Windows.UI.Xaml.Controls.IContainerContentChangingEventArgs) -> win32more.Windows.UI.Xaml.Controls.Primitives.SelectorItem: ...
    @winrt_mixinmethod
    def get_InRecycleQueue(self: win32more.Windows.UI.Xaml.Controls.IContainerContentChangingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_ItemIndex(self: win32more.Windows.UI.Xaml.Controls.IContainerContentChangingEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Windows.UI.Xaml.Controls.IContainerContentChangingEventArgs) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Phase(self: win32more.Windows.UI.Xaml.Controls.IContainerContentChangingEventArgs) -> UInt32: ...
    @winrt_mixinmethod
    def get_Handled(self: win32more.Windows.UI.Xaml.Controls.IContainerContentChangingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Windows.UI.Xaml.Controls.IContainerContentChangingEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def RegisterUpdateCallback(self: win32more.Windows.UI.Xaml.Controls.IContainerContentChangingEventArgs, callback: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ListViewBase, win32more.Windows.UI.Xaml.Controls.ContainerContentChangingEventArgs]) -> Void: ...
    @winrt_mixinmethod
    def RegisterUpdateCallbackWithPhase(self: win32more.Windows.UI.Xaml.Controls.IContainerContentChangingEventArgs, callbackPhase: UInt32, callback: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ListViewBase, win32more.Windows.UI.Xaml.Controls.ContainerContentChangingEventArgs]) -> Void: ...
    Handled = property(get_Handled, put_Handled)
    InRecycleQueue = property(get_InRecycleQueue, None)
    Item = property(get_Item, None)
    ItemContainer = property(get_ItemContainer, None)
    ItemIndex = property(get_ItemIndex, None)
    Phase = property(get_Phase, None)
class _ContentControl_Meta_(ComPtr.__class__):
    pass
class ContentControl(ComPtr, metaclass=_ContentControl_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IContentControl
    _classid_ = 'Windows.UI.Xaml.Controls.ContentControl'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ContentControl.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IContentControlFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ContentControl: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Windows.UI.Xaml.Controls.IContentControl) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Windows.UI.Xaml.Controls.IContentControl, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_ContentTemplate(self: win32more.Windows.UI.Xaml.Controls.IContentControl) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_ContentTemplate(self: win32more.Windows.UI.Xaml.Controls.IContentControl, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_ContentTemplateSelector(self: win32more.Windows.UI.Xaml.Controls.IContentControl) -> win32more.Windows.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_mixinmethod
    def put_ContentTemplateSelector(self: win32more.Windows.UI.Xaml.Controls.IContentControl, value: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_mixinmethod
    def get_ContentTransitions(self: win32more.Windows.UI.Xaml.Controls.IContentControl) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_ContentTransitions(self: win32more.Windows.UI.Xaml.Controls.IContentControl, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_ContentTemplateRoot(self: win32more.Windows.UI.Xaml.Controls.IContentControl2) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def OnContentChanged(self: win32more.Windows.UI.Xaml.Controls.IContentControlOverrides, oldContent: win32more.Windows.Win32.System.WinRT.IInspectable, newContent: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnContentTemplateChanged(self: win32more.Windows.UI.Xaml.Controls.IContentControlOverrides, oldContentTemplate: win32more.Windows.UI.Xaml.DataTemplate, newContentTemplate: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def OnContentTemplateSelectorChanged(self: win32more.Windows.UI.Xaml.Controls.IContentControlOverrides, oldContentTemplateSelector: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector, newContentTemplateSelector: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentTemplateSelectorProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentTransitionsProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Content = property(get_Content, put_Content)
    ContentTemplate = property(get_ContentTemplate, put_ContentTemplate)
    ContentTemplateRoot = property(get_ContentTemplateRoot, None)
    ContentTemplateSelector = property(get_ContentTemplateSelector, put_ContentTemplateSelector)
    ContentTransitions = property(get_ContentTransitions, put_ContentTransitions)
    _ContentControl_Meta_.ContentProperty = property(get_ContentProperty, None)
    _ContentControl_Meta_.ContentTemplateProperty = property(get_ContentTemplateProperty, None)
    _ContentControl_Meta_.ContentTemplateSelectorProperty = property(get_ContentTemplateSelectorProperty, None)
    _ContentControl_Meta_.ContentTransitionsProperty = property(get_ContentTransitionsProperty, None)
class _ContentDialog_Meta_(ComPtr.__class__):
    pass
class ContentDialog(ComPtr, metaclass=_ContentDialog_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Windows.UI.Xaml.Controls.IContentDialog
    _classid_ = 'Windows.UI.Xaml.Controls.ContentDialog'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ContentDialog.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ContentDialog: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Windows.UI.Xaml.Controls.IContentDialog) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_TitleTemplate(self: win32more.Windows.UI.Xaml.Controls.IContentDialog) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_TitleTemplate(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_FullSizeDesired(self: win32more.Windows.UI.Xaml.Controls.IContentDialog) -> Boolean: ...
    @winrt_mixinmethod
    def put_FullSizeDesired(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_PrimaryButtonText(self: win32more.Windows.UI.Xaml.Controls.IContentDialog) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PrimaryButtonText(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SecondaryButtonText(self: win32more.Windows.UI.Xaml.Controls.IContentDialog) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SecondaryButtonText(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_PrimaryButtonCommand(self: win32more.Windows.UI.Xaml.Controls.IContentDialog) -> win32more.Windows.UI.Xaml.Input.ICommand: ...
    @winrt_mixinmethod
    def put_PrimaryButtonCommand(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, value: win32more.Windows.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_mixinmethod
    def get_SecondaryButtonCommand(self: win32more.Windows.UI.Xaml.Controls.IContentDialog) -> win32more.Windows.UI.Xaml.Input.ICommand: ...
    @winrt_mixinmethod
    def put_SecondaryButtonCommand(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, value: win32more.Windows.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_mixinmethod
    def get_PrimaryButtonCommandParameter(self: win32more.Windows.UI.Xaml.Controls.IContentDialog) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_PrimaryButtonCommandParameter(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_SecondaryButtonCommandParameter(self: win32more.Windows.UI.Xaml.Controls.IContentDialog) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_SecondaryButtonCommandParameter(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_IsPrimaryButtonEnabled(self: win32more.Windows.UI.Xaml.Controls.IContentDialog) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPrimaryButtonEnabled(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSecondaryButtonEnabled(self: win32more.Windows.UI.Xaml.Controls.IContentDialog) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSecondaryButtonEnabled(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_Closing(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ContentDialog, win32more.Windows.UI.Xaml.Controls.ContentDialogClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closing(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ContentDialog, win32more.Windows.UI.Xaml.Controls.ContentDialogClosedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Opened(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ContentDialog, win32more.Windows.UI.Xaml.Controls.ContentDialogOpenedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Opened(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PrimaryButtonClick(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ContentDialog, win32more.Windows.UI.Xaml.Controls.ContentDialogButtonClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PrimaryButtonClick(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SecondaryButtonClick(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ContentDialog, win32more.Windows.UI.Xaml.Controls.ContentDialogButtonClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SecondaryButtonClick(self: win32more.Windows.UI.Xaml.Controls.IContentDialog, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Hide(self: win32more.Windows.UI.Xaml.Controls.IContentDialog) -> Void: ...
    @winrt_mixinmethod
    def ShowAsync(self: win32more.Windows.UI.Xaml.Controls.IContentDialog) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.UI.Xaml.Controls.ContentDialogResult]: ...
    @winrt_mixinmethod
    def get_CloseButtonText(self: win32more.Windows.UI.Xaml.Controls.IContentDialog2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_CloseButtonText(self: win32more.Windows.UI.Xaml.Controls.IContentDialog2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_CloseButtonCommand(self: win32more.Windows.UI.Xaml.Controls.IContentDialog2) -> win32more.Windows.UI.Xaml.Input.ICommand: ...
    @winrt_mixinmethod
    def put_CloseButtonCommand(self: win32more.Windows.UI.Xaml.Controls.IContentDialog2, value: win32more.Windows.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_mixinmethod
    def get_CloseButtonCommandParameter(self: win32more.Windows.UI.Xaml.Controls.IContentDialog2) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_CloseButtonCommandParameter(self: win32more.Windows.UI.Xaml.Controls.IContentDialog2, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_PrimaryButtonStyle(self: win32more.Windows.UI.Xaml.Controls.IContentDialog2) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_PrimaryButtonStyle(self: win32more.Windows.UI.Xaml.Controls.IContentDialog2, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_SecondaryButtonStyle(self: win32more.Windows.UI.Xaml.Controls.IContentDialog2) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_SecondaryButtonStyle(self: win32more.Windows.UI.Xaml.Controls.IContentDialog2, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_CloseButtonStyle(self: win32more.Windows.UI.Xaml.Controls.IContentDialog2) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_CloseButtonStyle(self: win32more.Windows.UI.Xaml.Controls.IContentDialog2, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_DefaultButton(self: win32more.Windows.UI.Xaml.Controls.IContentDialog2) -> win32more.Windows.UI.Xaml.Controls.ContentDialogButton: ...
    @winrt_mixinmethod
    def put_DefaultButton(self: win32more.Windows.UI.Xaml.Controls.IContentDialog2, value: win32more.Windows.UI.Xaml.Controls.ContentDialogButton) -> Void: ...
    @winrt_mixinmethod
    def add_CloseButtonClick(self: win32more.Windows.UI.Xaml.Controls.IContentDialog2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ContentDialog, win32more.Windows.UI.Xaml.Controls.ContentDialogButtonClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CloseButtonClick(self: win32more.Windows.UI.Xaml.Controls.IContentDialog2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ShowAsyncWithPlacement(self: win32more.Windows.UI.Xaml.Controls.IContentDialog3, placement: win32more.Windows.UI.Xaml.Controls.ContentDialogPlacement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.UI.Xaml.Controls.ContentDialogResult]: ...
    @winrt_classmethod
    def get_CloseButtonTextProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CloseButtonCommandProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CloseButtonCommandParameterProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PrimaryButtonStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SecondaryButtonStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CloseButtonStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DefaultButtonProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TitleProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TitleTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FullSizeDesiredProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PrimaryButtonTextProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SecondaryButtonTextProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PrimaryButtonCommandProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SecondaryButtonCommandProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PrimaryButtonCommandParameterProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SecondaryButtonCommandParameterProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPrimaryButtonEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSecondaryButtonEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CloseButtonCommand = property(get_CloseButtonCommand, put_CloseButtonCommand)
    CloseButtonCommandParameter = property(get_CloseButtonCommandParameter, put_CloseButtonCommandParameter)
    CloseButtonStyle = property(get_CloseButtonStyle, put_CloseButtonStyle)
    CloseButtonText = property(get_CloseButtonText, put_CloseButtonText)
    DefaultButton = property(get_DefaultButton, put_DefaultButton)
    FullSizeDesired = property(get_FullSizeDesired, put_FullSizeDesired)
    IsPrimaryButtonEnabled = property(get_IsPrimaryButtonEnabled, put_IsPrimaryButtonEnabled)
    IsSecondaryButtonEnabled = property(get_IsSecondaryButtonEnabled, put_IsSecondaryButtonEnabled)
    PrimaryButtonCommand = property(get_PrimaryButtonCommand, put_PrimaryButtonCommand)
    PrimaryButtonCommandParameter = property(get_PrimaryButtonCommandParameter, put_PrimaryButtonCommandParameter)
    PrimaryButtonStyle = property(get_PrimaryButtonStyle, put_PrimaryButtonStyle)
    PrimaryButtonText = property(get_PrimaryButtonText, put_PrimaryButtonText)
    SecondaryButtonCommand = property(get_SecondaryButtonCommand, put_SecondaryButtonCommand)
    SecondaryButtonCommandParameter = property(get_SecondaryButtonCommandParameter, put_SecondaryButtonCommandParameter)
    SecondaryButtonStyle = property(get_SecondaryButtonStyle, put_SecondaryButtonStyle)
    SecondaryButtonText = property(get_SecondaryButtonText, put_SecondaryButtonText)
    Title = property(get_Title, put_Title)
    TitleTemplate = property(get_TitleTemplate, put_TitleTemplate)
    _ContentDialog_Meta_.CloseButtonCommandParameterProperty = property(get_CloseButtonCommandParameterProperty, None)
    _ContentDialog_Meta_.CloseButtonCommandProperty = property(get_CloseButtonCommandProperty, None)
    _ContentDialog_Meta_.CloseButtonStyleProperty = property(get_CloseButtonStyleProperty, None)
    _ContentDialog_Meta_.CloseButtonTextProperty = property(get_CloseButtonTextProperty, None)
    _ContentDialog_Meta_.DefaultButtonProperty = property(get_DefaultButtonProperty, None)
    _ContentDialog_Meta_.FullSizeDesiredProperty = property(get_FullSizeDesiredProperty, None)
    _ContentDialog_Meta_.IsPrimaryButtonEnabledProperty = property(get_IsPrimaryButtonEnabledProperty, None)
    _ContentDialog_Meta_.IsSecondaryButtonEnabledProperty = property(get_IsSecondaryButtonEnabledProperty, None)
    _ContentDialog_Meta_.PrimaryButtonCommandParameterProperty = property(get_PrimaryButtonCommandParameterProperty, None)
    _ContentDialog_Meta_.PrimaryButtonCommandProperty = property(get_PrimaryButtonCommandProperty, None)
    _ContentDialog_Meta_.PrimaryButtonStyleProperty = property(get_PrimaryButtonStyleProperty, None)
    _ContentDialog_Meta_.PrimaryButtonTextProperty = property(get_PrimaryButtonTextProperty, None)
    _ContentDialog_Meta_.SecondaryButtonCommandParameterProperty = property(get_SecondaryButtonCommandParameterProperty, None)
    _ContentDialog_Meta_.SecondaryButtonCommandProperty = property(get_SecondaryButtonCommandProperty, None)
    _ContentDialog_Meta_.SecondaryButtonStyleProperty = property(get_SecondaryButtonStyleProperty, None)
    _ContentDialog_Meta_.SecondaryButtonTextProperty = property(get_SecondaryButtonTextProperty, None)
    _ContentDialog_Meta_.TitleProperty = property(get_TitleProperty, None)
    _ContentDialog_Meta_.TitleTemplateProperty = property(get_TitleTemplateProperty, None)
    Closing = event()
    Closed = event()
    Opened = event()
    PrimaryButtonClick = event()
    SecondaryButtonClick = event()
    CloseButtonClick = event()
class ContentDialogButton(Enum, Int32):
    None_ = 0
    Primary = 1
    Secondary = 2
    Close = 3
class ContentDialogButtonClickDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IContentDialogButtonClickDeferral
    _classid_ = 'Windows.UI.Xaml.Controls.ContentDialogButtonClickDeferral'
    @winrt_mixinmethod
    def Complete(self: win32more.Windows.UI.Xaml.Controls.IContentDialogButtonClickDeferral) -> Void: ...
class ContentDialogButtonClickEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IContentDialogButtonClickEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.ContentDialogButtonClickEventArgs'
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Windows.UI.Xaml.Controls.IContentDialogButtonClickEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Windows.UI.Xaml.Controls.IContentDialogButtonClickEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.UI.Xaml.Controls.IContentDialogButtonClickEventArgs) -> win32more.Windows.UI.Xaml.Controls.ContentDialogButtonClickDeferral: ...
    Cancel = property(get_Cancel, put_Cancel)
class ContentDialogClosedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IContentDialogClosedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.ContentDialogClosedEventArgs'
    @winrt_mixinmethod
    def get_Result(self: win32more.Windows.UI.Xaml.Controls.IContentDialogClosedEventArgs) -> win32more.Windows.UI.Xaml.Controls.ContentDialogResult: ...
    Result = property(get_Result, None)
class ContentDialogClosingDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IContentDialogClosingDeferral
    _classid_ = 'Windows.UI.Xaml.Controls.ContentDialogClosingDeferral'
    @winrt_mixinmethod
    def Complete(self: win32more.Windows.UI.Xaml.Controls.IContentDialogClosingDeferral) -> Void: ...
class ContentDialogClosingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IContentDialogClosingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.ContentDialogClosingEventArgs'
    @winrt_mixinmethod
    def get_Result(self: win32more.Windows.UI.Xaml.Controls.IContentDialogClosingEventArgs) -> win32more.Windows.UI.Xaml.Controls.ContentDialogResult: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Windows.UI.Xaml.Controls.IContentDialogClosingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Windows.UI.Xaml.Controls.IContentDialogClosingEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.UI.Xaml.Controls.IContentDialogClosingEventArgs) -> win32more.Windows.UI.Xaml.Controls.ContentDialogClosingDeferral: ...
    Cancel = property(get_Cancel, put_Cancel)
    Result = property(get_Result, None)
class ContentDialogOpenedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IContentDialogOpenedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.ContentDialogOpenedEventArgs'
class ContentDialogPlacement(Enum, Int32):
    Popup = 0
    InPlace = 1
class ContentDialogResult(Enum, Int32):
    None_ = 0
    Primary = 1
    Secondary = 2
class ContentLinkChangeKind(Enum, Int32):
    Inserted = 0
    Removed = 1
    Edited = 2
class ContentLinkChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IContentLinkChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.ContentLinkChangedEventArgs'
    @winrt_mixinmethod
    def get_ChangeKind(self: win32more.Windows.UI.Xaml.Controls.IContentLinkChangedEventArgs) -> win32more.Windows.UI.Xaml.Controls.ContentLinkChangeKind: ...
    @winrt_mixinmethod
    def get_ContentLinkInfo(self: win32more.Windows.UI.Xaml.Controls.IContentLinkChangedEventArgs) -> win32more.Windows.UI.Text.ContentLinkInfo: ...
    @winrt_mixinmethod
    def get_TextRange(self: win32more.Windows.UI.Xaml.Controls.IContentLinkChangedEventArgs) -> win32more.Windows.UI.Xaml.Documents.TextRange: ...
    ChangeKind = property(get_ChangeKind, None)
    ContentLinkInfo = property(get_ContentLinkInfo, None)
    TextRange = property(get_TextRange, None)
class _ContentPresenter_Meta_(ComPtr.__class__):
    pass
class ContentPresenter(ComPtr, metaclass=_ContentPresenter_Meta_):
    extends: win32more.Windows.UI.Xaml.FrameworkElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IContentPresenter
    _classid_ = 'Windows.UI.Xaml.Controls.ContentPresenter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ContentPresenter.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ContentPresenter: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_ContentTemplate(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_ContentTemplate(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_ContentTemplateSelector(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter) -> win32more.Windows.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_mixinmethod
    def put_ContentTemplateSelector(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter, value: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_mixinmethod
    def get_ContentTransitions(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_ContentTransitions(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_FontSize(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter) -> Double: ...
    @winrt_mixinmethod
    def put_FontSize(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FontFamily(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_FontFamily(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_FontWeight(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_FontWeight(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_FontStyle(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_FontStyle(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_FontStretch(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_mixinmethod
    def put_FontStretch(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_mixinmethod
    def get_CharacterSpacing(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter) -> Int32: ...
    @winrt_mixinmethod
    def put_CharacterSpacing(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_Foreground(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Foreground(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_OpticalMarginAlignment(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter2) -> win32more.Windows.UI.Xaml.OpticalMarginAlignment: ...
    @winrt_mixinmethod
    def put_OpticalMarginAlignment(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter2, value: win32more.Windows.UI.Xaml.OpticalMarginAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_TextLineBounds(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter2) -> win32more.Windows.UI.Xaml.TextLineBounds: ...
    @winrt_mixinmethod
    def put_TextLineBounds(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter2, value: win32more.Windows.UI.Xaml.TextLineBounds) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextScaleFactorEnabled(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter3) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextScaleFactorEnabled(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter3, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TextWrapping(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4) -> win32more.Windows.UI.Xaml.TextWrapping: ...
    @winrt_mixinmethod
    def put_TextWrapping(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4, value: win32more.Windows.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_mixinmethod
    def get_MaxLines(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxLines(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_LineStackingStrategy(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4) -> win32more.Windows.UI.Xaml.LineStackingStrategy: ...
    @winrt_mixinmethod
    def put_LineStackingStrategy(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4, value: win32more.Windows.UI.Xaml.LineStackingStrategy) -> Void: ...
    @winrt_mixinmethod
    def get_LineHeight(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4) -> Double: ...
    @winrt_mixinmethod
    def put_LineHeight(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_BorderBrush(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BorderBrush(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BorderThickness(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_BorderThickness(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_CornerRadius(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4) -> win32more.Windows.UI.Xaml.CornerRadius: ...
    @winrt_mixinmethod
    def put_CornerRadius(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4, value: win32more.Windows.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_Background(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Background(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalContentAlignment(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4) -> win32more.Windows.UI.Xaml.HorizontalAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalContentAlignment(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4, value: win32more.Windows.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalContentAlignment(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4) -> win32more.Windows.UI.Xaml.VerticalAlignment: ...
    @winrt_mixinmethod
    def put_VerticalContentAlignment(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter4, value: win32more.Windows.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_BackgroundTransition(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter5) -> win32more.Windows.UI.Xaml.BrushTransition: ...
    @winrt_mixinmethod
    def put_BackgroundTransition(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter5, value: win32more.Windows.UI.Xaml.BrushTransition) -> Void: ...
    @winrt_mixinmethod
    def get_BackgroundSizing(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter5) -> win32more.Windows.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_mixinmethod
    def put_BackgroundSizing(self: win32more.Windows.UI.Xaml.Controls.IContentPresenter5, value: win32more.Windows.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_mixinmethod
    def OnContentTemplateChanged(self: win32more.Windows.UI.Xaml.Controls.IContentPresenterOverrides, oldContentTemplate: win32more.Windows.UI.Xaml.DataTemplate, newContentTemplate: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def OnContentTemplateSelectorChanged(self: win32more.Windows.UI.Xaml.Controls.IContentPresenterOverrides, oldContentTemplateSelector: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector, newContentTemplateSelector: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_classmethod
    def get_BackgroundSizingProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextWrappingProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxLinesProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LineStackingStrategyProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LineHeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderThicknessProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CornerRadiusProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalContentAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalContentAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextScaleFactorEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OpticalMarginAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextLineBoundsProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentTemplateSelectorProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentTransitionsProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontSizeProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontFamilyProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontWeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStretchProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CharacterSpacingProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Background = property(get_Background, put_Background)
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BackgroundTransition = property(get_BackgroundTransition, put_BackgroundTransition)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    Content = property(get_Content, put_Content)
    ContentTemplate = property(get_ContentTemplate, put_ContentTemplate)
    ContentTemplateSelector = property(get_ContentTemplateSelector, put_ContentTemplateSelector)
    ContentTransitions = property(get_ContentTransitions, put_ContentTransitions)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
    HorizontalContentAlignment = property(get_HorizontalContentAlignment, put_HorizontalContentAlignment)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    LineHeight = property(get_LineHeight, put_LineHeight)
    LineStackingStrategy = property(get_LineStackingStrategy, put_LineStackingStrategy)
    MaxLines = property(get_MaxLines, put_MaxLines)
    OpticalMarginAlignment = property(get_OpticalMarginAlignment, put_OpticalMarginAlignment)
    Padding = property(get_Padding, put_Padding)
    TextLineBounds = property(get_TextLineBounds, put_TextLineBounds)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    VerticalContentAlignment = property(get_VerticalContentAlignment, put_VerticalContentAlignment)
    _ContentPresenter_Meta_.BackgroundProperty = property(get_BackgroundProperty, None)
    _ContentPresenter_Meta_.BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    _ContentPresenter_Meta_.BorderBrushProperty = property(get_BorderBrushProperty, None)
    _ContentPresenter_Meta_.BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    _ContentPresenter_Meta_.CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    _ContentPresenter_Meta_.ContentProperty = property(get_ContentProperty, None)
    _ContentPresenter_Meta_.ContentTemplateProperty = property(get_ContentTemplateProperty, None)
    _ContentPresenter_Meta_.ContentTemplateSelectorProperty = property(get_ContentTemplateSelectorProperty, None)
    _ContentPresenter_Meta_.ContentTransitionsProperty = property(get_ContentTransitionsProperty, None)
    _ContentPresenter_Meta_.CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    _ContentPresenter_Meta_.FontFamilyProperty = property(get_FontFamilyProperty, None)
    _ContentPresenter_Meta_.FontSizeProperty = property(get_FontSizeProperty, None)
    _ContentPresenter_Meta_.FontStretchProperty = property(get_FontStretchProperty, None)
    _ContentPresenter_Meta_.FontStyleProperty = property(get_FontStyleProperty, None)
    _ContentPresenter_Meta_.FontWeightProperty = property(get_FontWeightProperty, None)
    _ContentPresenter_Meta_.ForegroundProperty = property(get_ForegroundProperty, None)
    _ContentPresenter_Meta_.HorizontalContentAlignmentProperty = property(get_HorizontalContentAlignmentProperty, None)
    _ContentPresenter_Meta_.IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    _ContentPresenter_Meta_.LineHeightProperty = property(get_LineHeightProperty, None)
    _ContentPresenter_Meta_.LineStackingStrategyProperty = property(get_LineStackingStrategyProperty, None)
    _ContentPresenter_Meta_.MaxLinesProperty = property(get_MaxLinesProperty, None)
    _ContentPresenter_Meta_.OpticalMarginAlignmentProperty = property(get_OpticalMarginAlignmentProperty, None)
    _ContentPresenter_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    _ContentPresenter_Meta_.TextLineBoundsProperty = property(get_TextLineBoundsProperty, None)
    _ContentPresenter_Meta_.TextWrappingProperty = property(get_TextWrappingProperty, None)
    _ContentPresenter_Meta_.VerticalContentAlignmentProperty = property(get_VerticalContentAlignmentProperty, None)
class ContextMenuEventArgs(ComPtr):
    extends: win32more.Windows.UI.Xaml.RoutedEventArgs
    default_interface: win32more.Windows.UI.Xaml.Controls.IContextMenuEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.ContextMenuEventArgs'
    @winrt_mixinmethod
    def get_Handled(self: win32more.Windows.UI.Xaml.Controls.IContextMenuEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Windows.UI.Xaml.Controls.IContextMenuEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CursorLeft(self: win32more.Windows.UI.Xaml.Controls.IContextMenuEventArgs) -> Double: ...
    @winrt_mixinmethod
    def get_CursorTop(self: win32more.Windows.UI.Xaml.Controls.IContextMenuEventArgs) -> Double: ...
    CursorLeft = property(get_CursorLeft, None)
    CursorTop = property(get_CursorTop, None)
    Handled = property(get_Handled, put_Handled)
class ContextMenuOpeningEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{df945151-745c-4446-b2fc-216d765847a0}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Controls.ContextMenuEventArgs) -> Void: ...
class _Control_Meta_(ComPtr.__class__):
    pass
class Control(ComPtr, metaclass=_Control_Meta_):
    extends: win32more.Windows.UI.Xaml.FrameworkElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IControl
    _classid_ = 'Windows.UI.Xaml.Controls.Control'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.Control.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IControlFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Control: ...
    @winrt_mixinmethod
    def get_FontSize(self: win32more.Windows.UI.Xaml.Controls.IControl) -> Double: ...
    @winrt_mixinmethod
    def put_FontSize(self: win32more.Windows.UI.Xaml.Controls.IControl, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FontFamily(self: win32more.Windows.UI.Xaml.Controls.IControl) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_FontFamily(self: win32more.Windows.UI.Xaml.Controls.IControl, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_FontWeight(self: win32more.Windows.UI.Xaml.Controls.IControl) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_FontWeight(self: win32more.Windows.UI.Xaml.Controls.IControl, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_FontStyle(self: win32more.Windows.UI.Xaml.Controls.IControl) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_FontStyle(self: win32more.Windows.UI.Xaml.Controls.IControl, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_FontStretch(self: win32more.Windows.UI.Xaml.Controls.IControl) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_mixinmethod
    def put_FontStretch(self: win32more.Windows.UI.Xaml.Controls.IControl, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_mixinmethod
    def get_CharacterSpacing(self: win32more.Windows.UI.Xaml.Controls.IControl) -> Int32: ...
    @winrt_mixinmethod
    def put_CharacterSpacing(self: win32more.Windows.UI.Xaml.Controls.IControl, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_Foreground(self: win32more.Windows.UI.Xaml.Controls.IControl) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Foreground(self: win32more.Windows.UI.Xaml.Controls.IControl, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_IsTabStop(self: win32more.Windows.UI.Xaml.Controls.IControl) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTabStop(self: win32more.Windows.UI.Xaml.Controls.IControl, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsEnabled(self: win32more.Windows.UI.Xaml.Controls.IControl) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsEnabled(self: win32more.Windows.UI.Xaml.Controls.IControl, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TabIndex(self: win32more.Windows.UI.Xaml.Controls.IControl) -> Int32: ...
    @winrt_mixinmethod
    def put_TabIndex(self: win32more.Windows.UI.Xaml.Controls.IControl, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_TabNavigation(self: win32more.Windows.UI.Xaml.Controls.IControl) -> win32more.Windows.UI.Xaml.Input.KeyboardNavigationMode: ...
    @winrt_mixinmethod
    def put_TabNavigation(self: win32more.Windows.UI.Xaml.Controls.IControl, value: win32more.Windows.UI.Xaml.Input.KeyboardNavigationMode) -> Void: ...
    @winrt_mixinmethod
    def get_Template(self: win32more.Windows.UI.Xaml.Controls.IControl) -> win32more.Windows.UI.Xaml.Controls.ControlTemplate: ...
    @winrt_mixinmethod
    def put_Template(self: win32more.Windows.UI.Xaml.Controls.IControl, value: win32more.Windows.UI.Xaml.Controls.ControlTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Windows.UI.Xaml.Controls.IControl) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Windows.UI.Xaml.Controls.IControl, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalContentAlignment(self: win32more.Windows.UI.Xaml.Controls.IControl) -> win32more.Windows.UI.Xaml.HorizontalAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalContentAlignment(self: win32more.Windows.UI.Xaml.Controls.IControl, value: win32more.Windows.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalContentAlignment(self: win32more.Windows.UI.Xaml.Controls.IControl) -> win32more.Windows.UI.Xaml.VerticalAlignment: ...
    @winrt_mixinmethod
    def put_VerticalContentAlignment(self: win32more.Windows.UI.Xaml.Controls.IControl, value: win32more.Windows.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_Background(self: win32more.Windows.UI.Xaml.Controls.IControl) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Background(self: win32more.Windows.UI.Xaml.Controls.IControl, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BorderThickness(self: win32more.Windows.UI.Xaml.Controls.IControl) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_BorderThickness(self: win32more.Windows.UI.Xaml.Controls.IControl, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_BorderBrush(self: win32more.Windows.UI.Xaml.Controls.IControl) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BorderBrush(self: win32more.Windows.UI.Xaml.Controls.IControl, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_FocusState(self: win32more.Windows.UI.Xaml.Controls.IControl) -> win32more.Windows.UI.Xaml.FocusState: ...
    @winrt_mixinmethod
    def add_IsEnabledChanged(self: win32more.Windows.UI.Xaml.Controls.IControl, handler: win32more.Windows.UI.Xaml.DependencyPropertyChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_IsEnabledChanged(self: win32more.Windows.UI.Xaml.Controls.IControl, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ApplyTemplate(self: win32more.Windows.UI.Xaml.Controls.IControl) -> Boolean: ...
    @winrt_mixinmethod
    def Focus(self: win32more.Windows.UI.Xaml.Controls.IControl, value: win32more.Windows.UI.Xaml.FocusState) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsTextScaleFactorEnabled(self: win32more.Windows.UI.Xaml.Controls.IControl2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextScaleFactorEnabled(self: win32more.Windows.UI.Xaml.Controls.IControl2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_UseSystemFocusVisuals(self: win32more.Windows.UI.Xaml.Controls.IControl3) -> Boolean: ...
    @winrt_mixinmethod
    def put_UseSystemFocusVisuals(self: win32more.Windows.UI.Xaml.Controls.IControl3, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsFocusEngagementEnabled(self: win32more.Windows.UI.Xaml.Controls.IControl4) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFocusEngagementEnabled(self: win32more.Windows.UI.Xaml.Controls.IControl4, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsFocusEngaged(self: win32more.Windows.UI.Xaml.Controls.IControl4) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFocusEngaged(self: win32more.Windows.UI.Xaml.Controls.IControl4, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_RequiresPointer(self: win32more.Windows.UI.Xaml.Controls.IControl4) -> win32more.Windows.UI.Xaml.Controls.RequiresPointer: ...
    @winrt_mixinmethod
    def put_RequiresPointer(self: win32more.Windows.UI.Xaml.Controls.IControl4, value: win32more.Windows.UI.Xaml.Controls.RequiresPointer) -> Void: ...
    @winrt_mixinmethod
    def get_XYFocusLeft(self: win32more.Windows.UI.Xaml.Controls.IControl4) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def put_XYFocusLeft(self: win32more.Windows.UI.Xaml.Controls.IControl4, value: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_mixinmethod
    def get_XYFocusRight(self: win32more.Windows.UI.Xaml.Controls.IControl4) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def put_XYFocusRight(self: win32more.Windows.UI.Xaml.Controls.IControl4, value: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_mixinmethod
    def get_XYFocusUp(self: win32more.Windows.UI.Xaml.Controls.IControl4) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def put_XYFocusUp(self: win32more.Windows.UI.Xaml.Controls.IControl4, value: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_mixinmethod
    def get_XYFocusDown(self: win32more.Windows.UI.Xaml.Controls.IControl4) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def put_XYFocusDown(self: win32more.Windows.UI.Xaml.Controls.IControl4, value: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_mixinmethod
    def get_ElementSoundMode(self: win32more.Windows.UI.Xaml.Controls.IControl4) -> win32more.Windows.UI.Xaml.ElementSoundMode: ...
    @winrt_mixinmethod
    def put_ElementSoundMode(self: win32more.Windows.UI.Xaml.Controls.IControl4, value: win32more.Windows.UI.Xaml.ElementSoundMode) -> Void: ...
    @winrt_mixinmethod
    def add_FocusEngaged(self: win32more.Windows.UI.Xaml.Controls.IControl4, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.Control, win32more.Windows.UI.Xaml.Controls.FocusEngagedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FocusEngaged(self: win32more.Windows.UI.Xaml.Controls.IControl4, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_FocusDisengaged(self: win32more.Windows.UI.Xaml.Controls.IControl4, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.Control, win32more.Windows.UI.Xaml.Controls.FocusDisengagedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FocusDisengaged(self: win32more.Windows.UI.Xaml.Controls.IControl4, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def RemoveFocusEngagement(self: win32more.Windows.UI.Xaml.Controls.IControl4) -> Void: ...
    @winrt_mixinmethod
    def get_DefaultStyleResourceUri(self: win32more.Windows.UI.Xaml.Controls.IControl5) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_DefaultStyleResourceUri(self: win32more.Windows.UI.Xaml.Controls.IControl5, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_BackgroundSizing(self: win32more.Windows.UI.Xaml.Controls.IControl7) -> win32more.Windows.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_mixinmethod
    def put_BackgroundSizing(self: win32more.Windows.UI.Xaml.Controls.IControl7, value: win32more.Windows.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_mixinmethod
    def get_CornerRadius(self: win32more.Windows.UI.Xaml.Controls.IControl7) -> win32more.Windows.UI.Xaml.CornerRadius: ...
    @winrt_mixinmethod
    def put_CornerRadius(self: win32more.Windows.UI.Xaml.Controls.IControl7, value: win32more.Windows.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_mixinmethod
    def get_DefaultStyleKey(self: win32more.Windows.UI.Xaml.Controls.IControlProtected) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_DefaultStyleKey(self: win32more.Windows.UI.Xaml.Controls.IControlProtected, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def GetTemplateChild(self: win32more.Windows.UI.Xaml.Controls.IControlProtected, childName: WinRT_String) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def OnPointerEntered(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPointerPressed(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPointerMoved(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPointerReleased(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPointerExited(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPointerCaptureLost(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPointerCanceled(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPointerWheelChanged(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnTapped(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.TappedRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnDoubleTapped(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.DoubleTappedRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnHolding(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.HoldingRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnRightTapped(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.RightTappedRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnManipulationStarting(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.ManipulationStartingRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnManipulationInertiaStarting(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnManipulationStarted(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.ManipulationStartedRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnManipulationDelta(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnManipulationCompleted(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnKeyUp(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.KeyRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnKeyDown(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.Input.KeyRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnGotFocus(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.RoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnLostFocus(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.RoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnDragEnter(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.DragEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnDragLeave(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.DragEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnDragOver(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.DragEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnDrop(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides, e: win32more.Windows.UI.Xaml.DragEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPreviewKeyDown(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides6, e: win32more.Windows.UI.Xaml.Input.KeyRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPreviewKeyUp(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides6, e: win32more.Windows.UI.Xaml.Input.KeyRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnCharacterReceived(self: win32more.Windows.UI.Xaml.Controls.IControlOverrides6, e: win32more.Windows.UI.Xaml.Input.CharacterReceivedRoutedEventArgs) -> Void: ...
    @winrt_classmethod
    def get_BackgroundSizingProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics7) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CornerRadiusProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics7) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DefaultStyleResourceUriProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTemplateKeyTipTargetProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsTemplateKeyTipTarget(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics5, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsTemplateKeyTipTarget(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics5, element: win32more.Windows.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsFocusEngagementEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsFocusEngagedProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RequiresPointerProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_XYFocusLeftProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_XYFocusRightProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_XYFocusUpProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_XYFocusDownProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ElementSoundModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_UseSystemFocusVisualsProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTemplateFocusTargetProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsTemplateFocusTarget(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics3, element: win32more.Windows.UI.Xaml.FrameworkElement) -> Boolean: ...
    @winrt_classmethod
    def SetIsTemplateFocusTarget(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics3, element: win32more.Windows.UI.Xaml.FrameworkElement, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsTextScaleFactorEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontSizeProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontFamilyProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontWeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStretchProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CharacterSpacingProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTabStopProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TabIndexProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TabNavigationProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalContentAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalContentAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderThicknessProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DefaultStyleKeyProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FocusStateProperty(cls: win32more.Windows.UI.Xaml.Controls.IControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Background = property(get_Background, put_Background)
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    DefaultStyleKey = property(get_DefaultStyleKey, put_DefaultStyleKey)
    DefaultStyleResourceUri = property(get_DefaultStyleResourceUri, put_DefaultStyleResourceUri)
    ElementSoundMode = property(get_ElementSoundMode, put_ElementSoundMode)
    FocusState = property(get_FocusState, None)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
    HorizontalContentAlignment = property(get_HorizontalContentAlignment, put_HorizontalContentAlignment)
    IsEnabled = property(get_IsEnabled, put_IsEnabled)
    IsFocusEngaged = property(get_IsFocusEngaged, put_IsFocusEngaged)
    IsFocusEngagementEnabled = property(get_IsFocusEngagementEnabled, put_IsFocusEngagementEnabled)
    IsTabStop = property(get_IsTabStop, put_IsTabStop)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    Padding = property(get_Padding, put_Padding)
    RequiresPointer = property(get_RequiresPointer, put_RequiresPointer)
    TabIndex = property(get_TabIndex, put_TabIndex)
    TabNavigation = property(get_TabNavigation, put_TabNavigation)
    Template = property(get_Template, put_Template)
    UseSystemFocusVisuals = property(get_UseSystemFocusVisuals, put_UseSystemFocusVisuals)
    VerticalContentAlignment = property(get_VerticalContentAlignment, put_VerticalContentAlignment)
    XYFocusDown = property(get_XYFocusDown, put_XYFocusDown)
    XYFocusLeft = property(get_XYFocusLeft, put_XYFocusLeft)
    XYFocusRight = property(get_XYFocusRight, put_XYFocusRight)
    XYFocusUp = property(get_XYFocusUp, put_XYFocusUp)
    _Control_Meta_.BackgroundProperty = property(get_BackgroundProperty, None)
    _Control_Meta_.BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    _Control_Meta_.BorderBrushProperty = property(get_BorderBrushProperty, None)
    _Control_Meta_.BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    _Control_Meta_.CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    _Control_Meta_.CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    _Control_Meta_.DefaultStyleKeyProperty = property(get_DefaultStyleKeyProperty, None)
    _Control_Meta_.DefaultStyleResourceUriProperty = property(get_DefaultStyleResourceUriProperty, None)
    _Control_Meta_.ElementSoundModeProperty = property(get_ElementSoundModeProperty, None)
    _Control_Meta_.FocusStateProperty = property(get_FocusStateProperty, None)
    _Control_Meta_.FontFamilyProperty = property(get_FontFamilyProperty, None)
    _Control_Meta_.FontSizeProperty = property(get_FontSizeProperty, None)
    _Control_Meta_.FontStretchProperty = property(get_FontStretchProperty, None)
    _Control_Meta_.FontStyleProperty = property(get_FontStyleProperty, None)
    _Control_Meta_.FontWeightProperty = property(get_FontWeightProperty, None)
    _Control_Meta_.ForegroundProperty = property(get_ForegroundProperty, None)
    _Control_Meta_.HorizontalContentAlignmentProperty = property(get_HorizontalContentAlignmentProperty, None)
    _Control_Meta_.IsEnabledProperty = property(get_IsEnabledProperty, None)
    _Control_Meta_.IsFocusEngagedProperty = property(get_IsFocusEngagedProperty, None)
    _Control_Meta_.IsFocusEngagementEnabledProperty = property(get_IsFocusEngagementEnabledProperty, None)
    _Control_Meta_.IsTabStopProperty = property(get_IsTabStopProperty, None)
    _Control_Meta_.IsTemplateFocusTargetProperty = property(get_IsTemplateFocusTargetProperty, None)
    _Control_Meta_.IsTemplateKeyTipTargetProperty = property(get_IsTemplateKeyTipTargetProperty, None)
    _Control_Meta_.IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    _Control_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    _Control_Meta_.RequiresPointerProperty = property(get_RequiresPointerProperty, None)
    _Control_Meta_.TabIndexProperty = property(get_TabIndexProperty, None)
    _Control_Meta_.TabNavigationProperty = property(get_TabNavigationProperty, None)
    _Control_Meta_.TemplateProperty = property(get_TemplateProperty, None)
    _Control_Meta_.UseSystemFocusVisualsProperty = property(get_UseSystemFocusVisualsProperty, None)
    _Control_Meta_.VerticalContentAlignmentProperty = property(get_VerticalContentAlignmentProperty, None)
    _Control_Meta_.XYFocusDownProperty = property(get_XYFocusDownProperty, None)
    _Control_Meta_.XYFocusLeftProperty = property(get_XYFocusLeftProperty, None)
    _Control_Meta_.XYFocusRightProperty = property(get_XYFocusRightProperty, None)
    _Control_Meta_.XYFocusUpProperty = property(get_XYFocusUpProperty, None)
    IsEnabledChanged = event()
    FocusEngaged = event()
    FocusDisengaged = event()
class ControlTemplate(ComPtr):
    extends: win32more.Windows.UI.Xaml.FrameworkTemplate
    default_interface: win32more.Windows.UI.Xaml.Controls.IControlTemplate
    _classid_ = 'Windows.UI.Xaml.Controls.ControlTemplate'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ControlTemplate.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.ControlTemplate: ...
    @winrt_mixinmethod
    def get_TargetType(self: win32more.Windows.UI.Xaml.Controls.IControlTemplate) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_mixinmethod
    def put_TargetType(self: win32more.Windows.UI.Xaml.Controls.IControlTemplate, value: win32more.Windows.UI.Xaml.Interop.TypeName) -> Void: ...
    TargetType = property(get_TargetType, put_TargetType)
class DataTemplateSelector(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IDataTemplateSelector
    _classid_ = 'Windows.UI.Xaml.Controls.DataTemplateSelector'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.DataTemplateSelector.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IDataTemplateSelectorFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_mixinmethod
    def SelectTemplate(self: win32more.Windows.UI.Xaml.Controls.IDataTemplateSelector, item: win32more.Windows.Win32.System.WinRT.IInspectable, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def SelectTemplateForItem(self: win32more.Windows.UI.Xaml.Controls.IDataTemplateSelector2, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def SelectTemplateCore(self: win32more.Windows.UI.Xaml.Controls.IDataTemplateSelectorOverrides, item: win32more.Windows.Win32.System.WinRT.IInspectable, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def SelectTemplateForItemCore(self: win32more.Windows.UI.Xaml.Controls.IDataTemplateSelectorOverrides2, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def GetElement(self: win32more.Windows.UI.Xaml.IElementFactory, args: win32more.Windows.UI.Xaml.ElementFactoryGetArgs) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def RecycleElement(self: win32more.Windows.UI.Xaml.IElementFactory, args: win32more.Windows.UI.Xaml.ElementFactoryRecycleArgs) -> Void: ...
class DatePickedEventArgs(ComPtr):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Controls.IDatePickedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.DatePickedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.DatePickedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.DatePickedEventArgs: ...
    @winrt_mixinmethod
    def get_OldDate(self: win32more.Windows.UI.Xaml.Controls.IDatePickedEventArgs) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def get_NewDate(self: win32more.Windows.UI.Xaml.Controls.IDatePickedEventArgs) -> win32more.Windows.Foundation.DateTime: ...
    NewDate = property(get_NewDate, None)
    OldDate = property(get_OldDate, None)
class _DatePicker_Meta_(ComPtr.__class__):
    pass
class DatePicker(ComPtr, metaclass=_DatePicker_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IDatePicker
    _classid_ = 'Windows.UI.Xaml.Controls.DatePicker'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.DatePicker.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.DatePicker: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Windows.UI.Xaml.Controls.IDatePicker) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Windows.UI.Xaml.Controls.IDatePicker, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IDatePicker) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IDatePicker, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarIdentifier(self: win32more.Windows.UI.Xaml.Controls.IDatePicker) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_CalendarIdentifier(self: win32more.Windows.UI.Xaml.Controls.IDatePicker, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Date(self: win32more.Windows.UI.Xaml.Controls.IDatePicker) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_Date(self: win32more.Windows.UI.Xaml.Controls.IDatePicker, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_DayVisible(self: win32more.Windows.UI.Xaml.Controls.IDatePicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_DayVisible(self: win32more.Windows.UI.Xaml.Controls.IDatePicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MonthVisible(self: win32more.Windows.UI.Xaml.Controls.IDatePicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_MonthVisible(self: win32more.Windows.UI.Xaml.Controls.IDatePicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_YearVisible(self: win32more.Windows.UI.Xaml.Controls.IDatePicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_YearVisible(self: win32more.Windows.UI.Xaml.Controls.IDatePicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_DayFormat(self: win32more.Windows.UI.Xaml.Controls.IDatePicker) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DayFormat(self: win32more.Windows.UI.Xaml.Controls.IDatePicker, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_MonthFormat(self: win32more.Windows.UI.Xaml.Controls.IDatePicker) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_MonthFormat(self: win32more.Windows.UI.Xaml.Controls.IDatePicker, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_YearFormat(self: win32more.Windows.UI.Xaml.Controls.IDatePicker) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_YearFormat(self: win32more.Windows.UI.Xaml.Controls.IDatePicker, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_MinYear(self: win32more.Windows.UI.Xaml.Controls.IDatePicker) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_MinYear(self: win32more.Windows.UI.Xaml.Controls.IDatePicker, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_MaxYear(self: win32more.Windows.UI.Xaml.Controls.IDatePicker) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_MaxYear(self: win32more.Windows.UI.Xaml.Controls.IDatePicker, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Windows.UI.Xaml.Controls.IDatePicker) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Windows.UI.Xaml.Controls.IDatePicker, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def add_DateChanged(self: win32more.Windows.UI.Xaml.Controls.IDatePicker, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.UI.Xaml.Controls.DatePickerValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DateChanged(self: win32more.Windows.UI.Xaml.Controls.IDatePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_LightDismissOverlayMode(self: win32more.Windows.UI.Xaml.Controls.IDatePicker2) -> win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_mixinmethod
    def put_LightDismissOverlayMode(self: win32more.Windows.UI.Xaml.Controls.IDatePicker2, value: win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedDate(self: win32more.Windows.UI.Xaml.Controls.IDatePicker3) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def put_SelectedDate(self: win32more.Windows.UI.Xaml.Controls.IDatePicker3, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_mixinmethod
    def add_SelectedDateChanged(self: win32more.Windows.UI.Xaml.Controls.IDatePicker3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.DatePicker, win32more.Windows.UI.Xaml.Controls.DatePickerSelectedValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectedDateChanged(self: win32more.Windows.UI.Xaml.Controls.IDatePicker3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_SelectedDateProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LightDismissOverlayModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarIdentifierProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DateProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_YearVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayFormatProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthFormatProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_YearFormatProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinYearProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxYearProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CalendarIdentifier = property(get_CalendarIdentifier, put_CalendarIdentifier)
    Date = property(get_Date, put_Date)
    DayFormat = property(get_DayFormat, put_DayFormat)
    DayVisible = property(get_DayVisible, put_DayVisible)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    MaxYear = property(get_MaxYear, put_MaxYear)
    MinYear = property(get_MinYear, put_MinYear)
    MonthFormat = property(get_MonthFormat, put_MonthFormat)
    MonthVisible = property(get_MonthVisible, put_MonthVisible)
    Orientation = property(get_Orientation, put_Orientation)
    SelectedDate = property(get_SelectedDate, put_SelectedDate)
    YearFormat = property(get_YearFormat, put_YearFormat)
    YearVisible = property(get_YearVisible, put_YearVisible)
    _DatePicker_Meta_.CalendarIdentifierProperty = property(get_CalendarIdentifierProperty, None)
    _DatePicker_Meta_.DateProperty = property(get_DateProperty, None)
    _DatePicker_Meta_.DayFormatProperty = property(get_DayFormatProperty, None)
    _DatePicker_Meta_.DayVisibleProperty = property(get_DayVisibleProperty, None)
    _DatePicker_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _DatePicker_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _DatePicker_Meta_.LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    _DatePicker_Meta_.MaxYearProperty = property(get_MaxYearProperty, None)
    _DatePicker_Meta_.MinYearProperty = property(get_MinYearProperty, None)
    _DatePicker_Meta_.MonthFormatProperty = property(get_MonthFormatProperty, None)
    _DatePicker_Meta_.MonthVisibleProperty = property(get_MonthVisibleProperty, None)
    _DatePicker_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _DatePicker_Meta_.SelectedDateProperty = property(get_SelectedDateProperty, None)
    _DatePicker_Meta_.YearFormatProperty = property(get_YearFormatProperty, None)
    _DatePicker_Meta_.YearVisibleProperty = property(get_YearVisibleProperty, None)
    DateChanged = event()
    SelectedDateChanged = event()
class _DatePickerFlyout_Meta_(ComPtr.__class__):
    pass
class DatePickerFlyout(ComPtr, metaclass=_DatePickerFlyout_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.PickerFlyoutBase
    default_interface: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout
    _classid_ = 'Windows.UI.Xaml.Controls.DatePickerFlyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.DatePickerFlyout.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.DatePickerFlyout: ...
    @winrt_mixinmethod
    def get_CalendarIdentifier(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_CalendarIdentifier(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Date(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_Date(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_DayVisible(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout) -> Boolean: ...
    @winrt_mixinmethod
    def put_DayVisible(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MonthVisible(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout) -> Boolean: ...
    @winrt_mixinmethod
    def put_MonthVisible(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_YearVisible(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout) -> Boolean: ...
    @winrt_mixinmethod
    def put_YearVisible(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MinYear(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_MinYear(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_MaxYear(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_MaxYear(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def add_DatePicked(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.DatePickerFlyout, win32more.Windows.UI.Xaml.Controls.DatePickedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DatePicked(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ShowAtAsync(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout, target: win32more.Windows.UI.Xaml.FrameworkElement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]]: ...
    @winrt_mixinmethod
    def get_DayFormat(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DayFormat(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_MonthFormat(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_MonthFormat(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_YearFormat(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_YearFormat(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyout2, value: WinRT_String) -> Void: ...
    @winrt_classmethod
    def get_DayFormatProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthFormatProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_YearFormatProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarIdentifierProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DateProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_YearVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinYearProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxYearProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CalendarIdentifier = property(get_CalendarIdentifier, put_CalendarIdentifier)
    Date = property(get_Date, put_Date)
    DayFormat = property(get_DayFormat, put_DayFormat)
    DayVisible = property(get_DayVisible, put_DayVisible)
    MaxYear = property(get_MaxYear, put_MaxYear)
    MinYear = property(get_MinYear, put_MinYear)
    MonthFormat = property(get_MonthFormat, put_MonthFormat)
    MonthVisible = property(get_MonthVisible, put_MonthVisible)
    YearFormat = property(get_YearFormat, put_YearFormat)
    YearVisible = property(get_YearVisible, put_YearVisible)
    _DatePickerFlyout_Meta_.CalendarIdentifierProperty = property(get_CalendarIdentifierProperty, None)
    _DatePickerFlyout_Meta_.DateProperty = property(get_DateProperty, None)
    _DatePickerFlyout_Meta_.DayFormatProperty = property(get_DayFormatProperty, None)
    _DatePickerFlyout_Meta_.DayVisibleProperty = property(get_DayVisibleProperty, None)
    _DatePickerFlyout_Meta_.MaxYearProperty = property(get_MaxYearProperty, None)
    _DatePickerFlyout_Meta_.MinYearProperty = property(get_MinYearProperty, None)
    _DatePickerFlyout_Meta_.MonthFormatProperty = property(get_MonthFormatProperty, None)
    _DatePickerFlyout_Meta_.MonthVisibleProperty = property(get_MonthVisibleProperty, None)
    _DatePickerFlyout_Meta_.YearFormatProperty = property(get_YearFormatProperty, None)
    _DatePickerFlyout_Meta_.YearVisibleProperty = property(get_YearVisibleProperty, None)
    DatePicked = event()
class _DatePickerFlyoutItem_Meta_(ComPtr.__class__):
    pass
class DatePickerFlyoutItem(ComPtr, metaclass=_DatePickerFlyoutItem_Meta_):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutItem
    _classid_ = 'Windows.UI.Xaml.Controls.DatePickerFlyoutItem'
    @winrt_mixinmethod
    def get_PrimaryText(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PrimaryText(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutItem, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SecondaryText(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SecondaryText(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutItem, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def GetCustomProperty(self: win32more.Windows.UI.Xaml.Data.ICustomPropertyProvider, name: WinRT_String) -> win32more.Windows.UI.Xaml.Data.ICustomProperty: ...
    @winrt_mixinmethod
    def GetIndexedProperty(self: win32more.Windows.UI.Xaml.Data.ICustomPropertyProvider, name: WinRT_String, type: win32more.Windows.UI.Xaml.Interop.TypeName) -> win32more.Windows.UI.Xaml.Data.ICustomProperty: ...
    @winrt_mixinmethod
    def GetStringRepresentation(self: win32more.Windows.UI.Xaml.Data.ICustomPropertyProvider) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Type(self: win32more.Windows.UI.Xaml.Data.ICustomPropertyProvider) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_classmethod
    def get_PrimaryTextProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SecondaryTextProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    PrimaryText = property(get_PrimaryText, put_PrimaryText)
    SecondaryText = property(get_SecondaryText, put_SecondaryText)
    Type = property(get_Type, None)
    _DatePickerFlyoutItem_Meta_.PrimaryTextProperty = property(get_PrimaryTextProperty, None)
    _DatePickerFlyoutItem_Meta_.SecondaryTextProperty = property(get_SecondaryTextProperty, None)
class _DatePickerFlyoutPresenter_Meta_(ComPtr.__class__):
    pass
class DatePickerFlyoutPresenter(ComPtr, metaclass=_DatePickerFlyoutPresenter_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutPresenter
    _classid_ = 'Windows.UI.Xaml.Controls.DatePickerFlyoutPresenter'
    @winrt_mixinmethod
    def get_IsDefaultShadowEnabled(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutPresenter2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDefaultShadowEnabled(self: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutPresenter2, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsDefaultShadowEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IDatePickerFlyoutPresenterStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsDefaultShadowEnabled = property(get_IsDefaultShadowEnabled, put_IsDefaultShadowEnabled)
    _DatePickerFlyoutPresenter_Meta_.IsDefaultShadowEnabledProperty = property(get_IsDefaultShadowEnabledProperty, None)
class DatePickerSelectedValueChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IDatePickerSelectedValueChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.DatePickerSelectedValueChangedEventArgs'
    @winrt_mixinmethod
    def get_OldDate(self: win32more.Windows.UI.Xaml.Controls.IDatePickerSelectedValueChangedEventArgs) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def get_NewDate(self: win32more.Windows.UI.Xaml.Controls.IDatePickerSelectedValueChangedEventArgs) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    NewDate = property(get_NewDate, None)
    OldDate = property(get_OldDate, None)
class DatePickerValueChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IDatePickerValueChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.DatePickerValueChangedEventArgs'
    @winrt_mixinmethod
    def get_OldDate(self: win32more.Windows.UI.Xaml.Controls.IDatePickerValueChangedEventArgs) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def get_NewDate(self: win32more.Windows.UI.Xaml.Controls.IDatePickerValueChangedEventArgs) -> win32more.Windows.Foundation.DateTime: ...
    NewDate = property(get_NewDate, None)
    OldDate = property(get_OldDate, None)
class DisabledFormattingAccelerators(Enum, UInt32):
    None_ = 0
    Bold = 1
    Italic = 2
    Underline = 4
    All = 4294967295
class DragItemsCompletedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IDragItemsCompletedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.DragItemsCompletedEventArgs'
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.UI.Xaml.Controls.IDragItemsCompletedEventArgs) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def get_DropResult(self: win32more.Windows.UI.Xaml.Controls.IDragItemsCompletedEventArgs) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation: ...
    DropResult = property(get_DropResult, None)
    Items = property(get_Items, None)
class DragItemsStartingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IDragItemsStartingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.DragItemsStartingEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.DragItemsStartingEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.DragItemsStartingEventArgs: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Windows.UI.Xaml.Controls.IDragItemsStartingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Windows.UI.Xaml.Controls.IDragItemsStartingEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.UI.Xaml.Controls.IDragItemsStartingEventArgs) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Windows.UI.Xaml.Controls.IDragItemsStartingEventArgs) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackage: ...
    Cancel = property(get_Cancel, put_Cancel)
    Data = property(get_Data, None)
    Items = property(get_Items, None)
class DragItemsStartingEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3aaeab4c-14cb-4434-becc-88a8585c2f89}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Controls.DragItemsStartingEventArgs) -> Void: ...
class DropDownButton(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.Button
    default_interface: win32more.Windows.UI.Xaml.Controls.IDropDownButton
    _classid_ = 'Windows.UI.Xaml.Controls.DropDownButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.DropDownButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IDropDownButtonFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.DropDownButton: ...
class DropDownButtonAutomationPeer(ComPtr):
    extends: win32more.Windows.UI.Xaml.Automation.Peers.ButtonAutomationPeer
    default_interface: win32more.Windows.UI.Xaml.Controls.IDropDownButtonAutomationPeer
    _classid_ = 'Windows.UI.Xaml.Controls.DropDownButtonAutomationPeer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.DropDownButtonAutomationPeer.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IDropDownButtonAutomationPeerFactory, owner: win32more.Windows.UI.Xaml.Controls.DropDownButton, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.DropDownButtonAutomationPeer: ...
    @winrt_mixinmethod
    def get_ExpandCollapseState(self: win32more.Windows.UI.Xaml.Automation.Provider.IExpandCollapseProvider) -> win32more.Windows.UI.Xaml.Automation.ExpandCollapseState: ...
    @winrt_mixinmethod
    def Collapse(self: win32more.Windows.UI.Xaml.Automation.Provider.IExpandCollapseProvider) -> Void: ...
    @winrt_mixinmethod
    def Expand(self: win32more.Windows.UI.Xaml.Automation.Provider.IExpandCollapseProvider) -> Void: ...
    ExpandCollapseState = property(get_ExpandCollapseState, None)
class DynamicOverflowItemsChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IDynamicOverflowItemsChangingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.DynamicOverflowItemsChangingEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.DynamicOverflowItemsChangingEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.DynamicOverflowItemsChangingEventArgs: ...
    @winrt_mixinmethod
    def get_Action(self: win32more.Windows.UI.Xaml.Controls.IDynamicOverflowItemsChangingEventArgs) -> win32more.Windows.UI.Xaml.Controls.CommandBarDynamicOverflowAction: ...
    Action = property(get_Action, None)
class _FlipView_Meta_(ComPtr.__class__):
    pass
class FlipView(ComPtr, metaclass=_FlipView_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.Selector
    default_interface: win32more.Windows.UI.Xaml.Controls.IFlipView
    _classid_ = 'Windows.UI.Xaml.Controls.FlipView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.FlipView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IFlipViewFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.FlipView: ...
    @winrt_mixinmethod
    def get_UseTouchAnimationsForAllNavigation(self: win32more.Windows.UI.Xaml.Controls.IFlipView2) -> Boolean: ...
    @winrt_mixinmethod
    def put_UseTouchAnimationsForAllNavigation(self: win32more.Windows.UI.Xaml.Controls.IFlipView2, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_UseTouchAnimationsForAllNavigationProperty(cls: win32more.Windows.UI.Xaml.Controls.IFlipViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    UseTouchAnimationsForAllNavigation = property(get_UseTouchAnimationsForAllNavigation, put_UseTouchAnimationsForAllNavigation)
    _FlipView_Meta_.UseTouchAnimationsForAllNavigationProperty = property(get_UseTouchAnimationsForAllNavigationProperty, None)
class FlipViewItem(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.SelectorItem
    default_interface: win32more.Windows.UI.Xaml.Controls.IFlipViewItem
    _classid_ = 'Windows.UI.Xaml.Controls.FlipViewItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.FlipViewItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IFlipViewItemFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.FlipViewItem: ...
class _Flyout_Meta_(ComPtr.__class__):
    pass
class Flyout(ComPtr, metaclass=_Flyout_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase
    default_interface: win32more.Windows.UI.Xaml.Controls.IFlyout
    _classid_ = 'Windows.UI.Xaml.Controls.Flyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.Flyout.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IFlyoutFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Flyout: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Windows.UI.Xaml.Controls.IFlyout) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Windows.UI.Xaml.Controls.IFlyout, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_FlyoutPresenterStyle(self: win32more.Windows.UI.Xaml.Controls.IFlyout) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_FlyoutPresenterStyle(self: win32more.Windows.UI.Xaml.Controls.IFlyout, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Windows.UI.Xaml.Controls.IFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FlyoutPresenterStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.IFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Content = property(get_Content, put_Content)
    FlyoutPresenterStyle = property(get_FlyoutPresenterStyle, put_FlyoutPresenterStyle)
    _Flyout_Meta_.ContentProperty = property(get_ContentProperty, None)
    _Flyout_Meta_.FlyoutPresenterStyleProperty = property(get_FlyoutPresenterStyleProperty, None)
class _FlyoutPresenter_Meta_(ComPtr.__class__):
    pass
class FlyoutPresenter(ComPtr, metaclass=_FlyoutPresenter_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Windows.UI.Xaml.Controls.IFlyoutPresenter
    _classid_ = 'Windows.UI.Xaml.Controls.FlyoutPresenter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.FlyoutPresenter.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IFlyoutPresenterFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.FlyoutPresenter: ...
    @winrt_mixinmethod
    def get_IsDefaultShadowEnabled(self: win32more.Windows.UI.Xaml.Controls.IFlyoutPresenter2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDefaultShadowEnabled(self: win32more.Windows.UI.Xaml.Controls.IFlyoutPresenter2, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsDefaultShadowEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IFlyoutPresenterStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsDefaultShadowEnabled = property(get_IsDefaultShadowEnabled, put_IsDefaultShadowEnabled)
    _FlyoutPresenter_Meta_.IsDefaultShadowEnabledProperty = property(get_IsDefaultShadowEnabledProperty, None)
class FocusDisengagedEventArgs(ComPtr):
    extends: win32more.Windows.UI.Xaml.RoutedEventArgs
    default_interface: win32more.Windows.UI.Xaml.Controls.IFocusDisengagedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.FocusDisengagedEventArgs'
class FocusEngagedEventArgs(ComPtr):
    extends: win32more.Windows.UI.Xaml.RoutedEventArgs
    default_interface: win32more.Windows.UI.Xaml.Controls.IFocusEngagedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.FocusEngagedEventArgs'
    @winrt_mixinmethod
    def get_Handled(self: win32more.Windows.UI.Xaml.Controls.IFocusEngagedEventArgs2) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Windows.UI.Xaml.Controls.IFocusEngagedEventArgs2, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class _FontIcon_Meta_(ComPtr.__class__):
    pass
class FontIcon(ComPtr, metaclass=_FontIcon_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.IconElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IFontIcon
    _classid_ = 'Windows.UI.Xaml.Controls.FontIcon'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.FontIcon.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IFontIconFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.FontIcon: ...
    @winrt_mixinmethod
    def get_Glyph(self: win32more.Windows.UI.Xaml.Controls.IFontIcon) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Glyph(self: win32more.Windows.UI.Xaml.Controls.IFontIcon, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_FontSize(self: win32more.Windows.UI.Xaml.Controls.IFontIcon) -> Double: ...
    @winrt_mixinmethod
    def put_FontSize(self: win32more.Windows.UI.Xaml.Controls.IFontIcon, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FontFamily(self: win32more.Windows.UI.Xaml.Controls.IFontIcon) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_FontFamily(self: win32more.Windows.UI.Xaml.Controls.IFontIcon, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_FontWeight(self: win32more.Windows.UI.Xaml.Controls.IFontIcon) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_FontWeight(self: win32more.Windows.UI.Xaml.Controls.IFontIcon, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_FontStyle(self: win32more.Windows.UI.Xaml.Controls.IFontIcon) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_FontStyle(self: win32more.Windows.UI.Xaml.Controls.IFontIcon, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextScaleFactorEnabled(self: win32more.Windows.UI.Xaml.Controls.IFontIcon2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextScaleFactorEnabled(self: win32more.Windows.UI.Xaml.Controls.IFontIcon2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MirroredWhenRightToLeft(self: win32more.Windows.UI.Xaml.Controls.IFontIcon3) -> Boolean: ...
    @winrt_mixinmethod
    def put_MirroredWhenRightToLeft(self: win32more.Windows.UI.Xaml.Controls.IFontIcon3, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_MirroredWhenRightToLeftProperty(cls: win32more.Windows.UI.Xaml.Controls.IFontIconStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextScaleFactorEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IFontIconStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GlyphProperty(cls: win32more.Windows.UI.Xaml.Controls.IFontIconStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontSizeProperty(cls: win32more.Windows.UI.Xaml.Controls.IFontIconStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontFamilyProperty(cls: win32more.Windows.UI.Xaml.Controls.IFontIconStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontWeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IFontIconStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.IFontIconStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Glyph = property(get_Glyph, put_Glyph)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    MirroredWhenRightToLeft = property(get_MirroredWhenRightToLeft, put_MirroredWhenRightToLeft)
    _FontIcon_Meta_.FontFamilyProperty = property(get_FontFamilyProperty, None)
    _FontIcon_Meta_.FontSizeProperty = property(get_FontSizeProperty, None)
    _FontIcon_Meta_.FontStyleProperty = property(get_FontStyleProperty, None)
    _FontIcon_Meta_.FontWeightProperty = property(get_FontWeightProperty, None)
    _FontIcon_Meta_.GlyphProperty = property(get_GlyphProperty, None)
    _FontIcon_Meta_.IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    _FontIcon_Meta_.MirroredWhenRightToLeftProperty = property(get_MirroredWhenRightToLeftProperty, None)
class _FontIconSource_Meta_(ComPtr.__class__):
    pass
class FontIconSource(ComPtr, metaclass=_FontIconSource_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.IconSource
    default_interface: win32more.Windows.UI.Xaml.Controls.IFontIconSource
    _classid_ = 'Windows.UI.Xaml.Controls.FontIconSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.FontIconSource.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IFontIconSourceFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.FontIconSource: ...
    @winrt_mixinmethod
    def get_Glyph(self: win32more.Windows.UI.Xaml.Controls.IFontIconSource) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Glyph(self: win32more.Windows.UI.Xaml.Controls.IFontIconSource, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_FontSize(self: win32more.Windows.UI.Xaml.Controls.IFontIconSource) -> Double: ...
    @winrt_mixinmethod
    def put_FontSize(self: win32more.Windows.UI.Xaml.Controls.IFontIconSource, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FontFamily(self: win32more.Windows.UI.Xaml.Controls.IFontIconSource) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_FontFamily(self: win32more.Windows.UI.Xaml.Controls.IFontIconSource, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_FontWeight(self: win32more.Windows.UI.Xaml.Controls.IFontIconSource) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_FontWeight(self: win32more.Windows.UI.Xaml.Controls.IFontIconSource, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_FontStyle(self: win32more.Windows.UI.Xaml.Controls.IFontIconSource) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_FontStyle(self: win32more.Windows.UI.Xaml.Controls.IFontIconSource, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextScaleFactorEnabled(self: win32more.Windows.UI.Xaml.Controls.IFontIconSource) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextScaleFactorEnabled(self: win32more.Windows.UI.Xaml.Controls.IFontIconSource, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MirroredWhenRightToLeft(self: win32more.Windows.UI.Xaml.Controls.IFontIconSource) -> Boolean: ...
    @winrt_mixinmethod
    def put_MirroredWhenRightToLeft(self: win32more.Windows.UI.Xaml.Controls.IFontIconSource, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_GlyphProperty(cls: win32more.Windows.UI.Xaml.Controls.IFontIconSourceStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontSizeProperty(cls: win32more.Windows.UI.Xaml.Controls.IFontIconSourceStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontFamilyProperty(cls: win32more.Windows.UI.Xaml.Controls.IFontIconSourceStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontWeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IFontIconSourceStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.IFontIconSourceStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextScaleFactorEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IFontIconSourceStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MirroredWhenRightToLeftProperty(cls: win32more.Windows.UI.Xaml.Controls.IFontIconSourceStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Glyph = property(get_Glyph, put_Glyph)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    MirroredWhenRightToLeft = property(get_MirroredWhenRightToLeft, put_MirroredWhenRightToLeft)
    _FontIconSource_Meta_.FontFamilyProperty = property(get_FontFamilyProperty, None)
    _FontIconSource_Meta_.FontSizeProperty = property(get_FontSizeProperty, None)
    _FontIconSource_Meta_.FontStyleProperty = property(get_FontStyleProperty, None)
    _FontIconSource_Meta_.FontWeightProperty = property(get_FontWeightProperty, None)
    _FontIconSource_Meta_.GlyphProperty = property(get_GlyphProperty, None)
    _FontIconSource_Meta_.IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    _FontIconSource_Meta_.MirroredWhenRightToLeftProperty = property(get_MirroredWhenRightToLeftProperty, None)
class _Frame_Meta_(ComPtr.__class__):
    pass
class Frame(ComPtr, metaclass=_Frame_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Windows.UI.Xaml.Controls.IFrame
    _classid_ = 'Windows.UI.Xaml.Controls.Frame'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.Frame.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IFrameFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Frame: ...
    @winrt_mixinmethod
    def get_CacheSize(self: win32more.Windows.UI.Xaml.Controls.IFrame) -> Int32: ...
    @winrt_mixinmethod
    def put_CacheSize(self: win32more.Windows.UI.Xaml.Controls.IFrame, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_CanGoBack(self: win32more.Windows.UI.Xaml.Controls.IFrame) -> Boolean: ...
    @winrt_mixinmethod
    def get_CanGoForward(self: win32more.Windows.UI.Xaml.Controls.IFrame) -> Boolean: ...
    @winrt_mixinmethod
    def get_CurrentSourcePageType(self: win32more.Windows.UI.Xaml.Controls.IFrame) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_mixinmethod
    def get_SourcePageType(self: win32more.Windows.UI.Xaml.Controls.IFrame) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_mixinmethod
    def put_SourcePageType(self: win32more.Windows.UI.Xaml.Controls.IFrame, value: win32more.Windows.UI.Xaml.Interop.TypeName) -> Void: ...
    @winrt_mixinmethod
    def get_BackStackDepth(self: win32more.Windows.UI.Xaml.Controls.IFrame) -> Int32: ...
    @winrt_mixinmethod
    def add_Navigated(self: win32more.Windows.UI.Xaml.Controls.IFrame, handler: win32more.Windows.UI.Xaml.Navigation.NavigatedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Navigated(self: win32more.Windows.UI.Xaml.Controls.IFrame, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Navigating(self: win32more.Windows.UI.Xaml.Controls.IFrame, handler: win32more.Windows.UI.Xaml.Navigation.NavigatingCancelEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Navigating(self: win32more.Windows.UI.Xaml.Controls.IFrame, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_NavigationFailed(self: win32more.Windows.UI.Xaml.Controls.IFrame, handler: win32more.Windows.UI.Xaml.Navigation.NavigationFailedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_NavigationFailed(self: win32more.Windows.UI.Xaml.Controls.IFrame, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_NavigationStopped(self: win32more.Windows.UI.Xaml.Controls.IFrame, handler: win32more.Windows.UI.Xaml.Navigation.NavigationStoppedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_NavigationStopped(self: win32more.Windows.UI.Xaml.Controls.IFrame, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_overload
    @winrt_mixinmethod
    def GoBack(self: win32more.Windows.UI.Xaml.Controls.IFrame) -> Void: ...
    @winrt_mixinmethod
    def GoForward(self: win32more.Windows.UI.Xaml.Controls.IFrame) -> Void: ...
    @winrt_overload
    @winrt_mixinmethod
    def Navigate(self: win32more.Windows.UI.Xaml.Controls.IFrame, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def GetNavigationState(self: win32more.Windows.UI.Xaml.Controls.IFrame) -> WinRT_String: ...
    @winrt_mixinmethod
    def SetNavigationState(self: win32more.Windows.UI.Xaml.Controls.IFrame, navigationState: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_BackStack(self: win32more.Windows.UI.Xaml.Controls.IFrame2) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Navigation.PageStackEntry]: ...
    @winrt_mixinmethod
    def get_ForwardStack(self: win32more.Windows.UI.Xaml.Controls.IFrame2) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Navigation.PageStackEntry]: ...
    @Navigate.register
    @winrt_mixinmethod
    def Navigate(self: win32more.Windows.UI.Xaml.Controls.IFrame2, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: win32more.Windows.Win32.System.WinRT.IInspectable, infoOverride: win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo) -> Boolean: ...
    @GoBack.register
    @winrt_mixinmethod
    def GoBack(self: win32more.Windows.UI.Xaml.Controls.IFrame3, transitionInfoOverride: win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo) -> Void: ...
    @winrt_mixinmethod
    def SetNavigationStateWithNavigationControl(self: win32more.Windows.UI.Xaml.Controls.IFrame4, navigationState: WinRT_String, suppressNavigate: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsNavigationStackEnabled(self: win32more.Windows.UI.Xaml.Controls.IFrame5) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsNavigationStackEnabled(self: win32more.Windows.UI.Xaml.Controls.IFrame5, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def NavigateToType(self: win32more.Windows.UI.Xaml.Controls.IFrame5, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: win32more.Windows.Win32.System.WinRT.IInspectable, navigationOptions: win32more.Windows.UI.Xaml.Navigation.FrameNavigationOptions) -> Boolean: ...
    @Navigate.register
    @winrt_mixinmethod
    def Navigate(self: win32more.Windows.UI.Xaml.Controls.INavigate, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName) -> Boolean: ...
    @winrt_classmethod
    def get_IsNavigationStackEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IFrameStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackStackProperty(cls: win32more.Windows.UI.Xaml.Controls.IFrameStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ForwardStackProperty(cls: win32more.Windows.UI.Xaml.Controls.IFrameStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CacheSizeProperty(cls: win32more.Windows.UI.Xaml.Controls.IFrameStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanGoBackProperty(cls: win32more.Windows.UI.Xaml.Controls.IFrameStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanGoForwardProperty(cls: win32more.Windows.UI.Xaml.Controls.IFrameStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CurrentSourcePageTypeProperty(cls: win32more.Windows.UI.Xaml.Controls.IFrameStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SourcePageTypeProperty(cls: win32more.Windows.UI.Xaml.Controls.IFrameStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackStackDepthProperty(cls: win32more.Windows.UI.Xaml.Controls.IFrameStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BackStack = property(get_BackStack, None)
    BackStackDepth = property(get_BackStackDepth, None)
    CacheSize = property(get_CacheSize, put_CacheSize)
    CanGoBack = property(get_CanGoBack, None)
    CanGoForward = property(get_CanGoForward, None)
    CurrentSourcePageType = property(get_CurrentSourcePageType, None)
    ForwardStack = property(get_ForwardStack, None)
    IsNavigationStackEnabled = property(get_IsNavigationStackEnabled, put_IsNavigationStackEnabled)
    SourcePageType = property(get_SourcePageType, put_SourcePageType)
    _Frame_Meta_.BackStackDepthProperty = property(get_BackStackDepthProperty, None)
    _Frame_Meta_.BackStackProperty = property(get_BackStackProperty, None)
    _Frame_Meta_.CacheSizeProperty = property(get_CacheSizeProperty, None)
    _Frame_Meta_.CanGoBackProperty = property(get_CanGoBackProperty, None)
    _Frame_Meta_.CanGoForwardProperty = property(get_CanGoForwardProperty, None)
    _Frame_Meta_.CurrentSourcePageTypeProperty = property(get_CurrentSourcePageTypeProperty, None)
    _Frame_Meta_.ForwardStackProperty = property(get_ForwardStackProperty, None)
    _Frame_Meta_.IsNavigationStackEnabledProperty = property(get_IsNavigationStackEnabledProperty, None)
    _Frame_Meta_.SourcePageTypeProperty = property(get_SourcePageTypeProperty, None)
    Navigated = event()
    Navigating = event()
    NavigationFailed = event()
    NavigationStopped = event()
class _Grid_Meta_(ComPtr.__class__):
    pass
class Grid(ComPtr, metaclass=_Grid_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Panel
    default_interface: win32more.Windows.UI.Xaml.Controls.IGrid
    _classid_ = 'Windows.UI.Xaml.Controls.Grid'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.Grid.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IGridFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Grid: ...
    @winrt_mixinmethod
    def get_RowDefinitions(self: win32more.Windows.UI.Xaml.Controls.IGrid) -> win32more.Windows.UI.Xaml.Controls.RowDefinitionCollection: ...
    @winrt_mixinmethod
    def get_ColumnDefinitions(self: win32more.Windows.UI.Xaml.Controls.IGrid) -> win32more.Windows.UI.Xaml.Controls.ColumnDefinitionCollection: ...
    @winrt_mixinmethod
    def get_BorderBrush(self: win32more.Windows.UI.Xaml.Controls.IGrid2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BorderBrush(self: win32more.Windows.UI.Xaml.Controls.IGrid2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BorderThickness(self: win32more.Windows.UI.Xaml.Controls.IGrid2) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_BorderThickness(self: win32more.Windows.UI.Xaml.Controls.IGrid2, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_CornerRadius(self: win32more.Windows.UI.Xaml.Controls.IGrid2) -> win32more.Windows.UI.Xaml.CornerRadius: ...
    @winrt_mixinmethod
    def put_CornerRadius(self: win32more.Windows.UI.Xaml.Controls.IGrid2, value: win32more.Windows.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Windows.UI.Xaml.Controls.IGrid2) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Windows.UI.Xaml.Controls.IGrid2, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_RowSpacing(self: win32more.Windows.UI.Xaml.Controls.IGrid3) -> Double: ...
    @winrt_mixinmethod
    def put_RowSpacing(self: win32more.Windows.UI.Xaml.Controls.IGrid3, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ColumnSpacing(self: win32more.Windows.UI.Xaml.Controls.IGrid3) -> Double: ...
    @winrt_mixinmethod
    def put_ColumnSpacing(self: win32more.Windows.UI.Xaml.Controls.IGrid3, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_BackgroundSizing(self: win32more.Windows.UI.Xaml.Controls.IGrid4) -> win32more.Windows.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_mixinmethod
    def put_BackgroundSizing(self: win32more.Windows.UI.Xaml.Controls.IGrid4, value: win32more.Windows.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_classmethod
    def get_BackgroundSizingProperty(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RowSpacingProperty(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ColumnSpacingProperty(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderThicknessProperty(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CornerRadiusProperty(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RowProperty(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetRow(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics, element: win32more.Windows.UI.Xaml.FrameworkElement) -> Int32: ...
    @winrt_classmethod
    def SetRow(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics, element: win32more.Windows.UI.Xaml.FrameworkElement, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_ColumnProperty(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetColumn(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics, element: win32more.Windows.UI.Xaml.FrameworkElement) -> Int32: ...
    @winrt_classmethod
    def SetColumn(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics, element: win32more.Windows.UI.Xaml.FrameworkElement, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_RowSpanProperty(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetRowSpan(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics, element: win32more.Windows.UI.Xaml.FrameworkElement) -> Int32: ...
    @winrt_classmethod
    def SetRowSpan(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics, element: win32more.Windows.UI.Xaml.FrameworkElement, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_ColumnSpanProperty(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetColumnSpan(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics, element: win32more.Windows.UI.Xaml.FrameworkElement) -> Int32: ...
    @winrt_classmethod
    def SetColumnSpan(cls: win32more.Windows.UI.Xaml.Controls.IGridStatics, element: win32more.Windows.UI.Xaml.FrameworkElement, value: Int32) -> Void: ...
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    ColumnDefinitions = property(get_ColumnDefinitions, None)
    ColumnSpacing = property(get_ColumnSpacing, put_ColumnSpacing)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    Padding = property(get_Padding, put_Padding)
    RowDefinitions = property(get_RowDefinitions, None)
    RowSpacing = property(get_RowSpacing, put_RowSpacing)
    _Grid_Meta_.BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    _Grid_Meta_.BorderBrushProperty = property(get_BorderBrushProperty, None)
    _Grid_Meta_.BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    _Grid_Meta_.ColumnProperty = property(get_ColumnProperty, None)
    _Grid_Meta_.ColumnSpacingProperty = property(get_ColumnSpacingProperty, None)
    _Grid_Meta_.ColumnSpanProperty = property(get_ColumnSpanProperty, None)
    _Grid_Meta_.CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    _Grid_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    _Grid_Meta_.RowProperty = property(get_RowProperty, None)
    _Grid_Meta_.RowSpacingProperty = property(get_RowSpacingProperty, None)
    _Grid_Meta_.RowSpanProperty = property(get_RowSpanProperty, None)
class GridView(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.ListViewBase
    default_interface: win32more.Windows.UI.Xaml.Controls.IGridView
    _classid_ = 'Windows.UI.Xaml.Controls.GridView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.GridView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IGridViewFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.GridView: ...
class GridViewHeaderItem(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.ListViewBaseHeaderItem
    default_interface: win32more.Windows.UI.Xaml.Controls.IGridViewHeaderItem
    _classid_ = 'Windows.UI.Xaml.Controls.GridViewHeaderItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.GridViewHeaderItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IGridViewHeaderItemFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.GridViewHeaderItem: ...
class GridViewItem(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.SelectorItem
    default_interface: win32more.Windows.UI.Xaml.Controls.IGridViewItem
    _classid_ = 'Windows.UI.Xaml.Controls.GridViewItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.GridViewItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IGridViewItemFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.GridViewItem: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Windows.UI.Xaml.Controls.IGridViewItem) -> win32more.Windows.UI.Xaml.Controls.Primitives.GridViewItemTemplateSettings: ...
    TemplateSettings = property(get_TemplateSettings, None)
class GroupItem(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Windows.UI.Xaml.Controls.IGroupItem
    _classid_ = 'Windows.UI.Xaml.Controls.GroupItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.GroupItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IGroupItemFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.GroupItem: ...
class GroupStyle(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IGroupStyle
    _classid_ = 'Windows.UI.Xaml.Controls.GroupStyle'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.GroupStyle.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IGroupStyleFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.GroupStyle: ...
    @winrt_mixinmethod
    def get_Panel(self: win32more.Windows.UI.Xaml.Controls.IGroupStyle) -> win32more.Windows.UI.Xaml.Controls.ItemsPanelTemplate: ...
    @winrt_mixinmethod
    def put_Panel(self: win32more.Windows.UI.Xaml.Controls.IGroupStyle, value: win32more.Windows.UI.Xaml.Controls.ItemsPanelTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_ContainerStyle(self: win32more.Windows.UI.Xaml.Controls.IGroupStyle) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_ContainerStyle(self: win32more.Windows.UI.Xaml.Controls.IGroupStyle, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_ContainerStyleSelector(self: win32more.Windows.UI.Xaml.Controls.IGroupStyle) -> win32more.Windows.UI.Xaml.Controls.StyleSelector: ...
    @winrt_mixinmethod
    def put_ContainerStyleSelector(self: win32more.Windows.UI.Xaml.Controls.IGroupStyle, value: win32more.Windows.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IGroupStyle) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IGroupStyle, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplateSelector(self: win32more.Windows.UI.Xaml.Controls.IGroupStyle) -> win32more.Windows.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_mixinmethod
    def put_HeaderTemplateSelector(self: win32more.Windows.UI.Xaml.Controls.IGroupStyle, value: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_mixinmethod
    def get_HidesIfEmpty(self: win32more.Windows.UI.Xaml.Controls.IGroupStyle) -> Boolean: ...
    @winrt_mixinmethod
    def put_HidesIfEmpty(self: win32more.Windows.UI.Xaml.Controls.IGroupStyle, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderContainerStyle(self: win32more.Windows.UI.Xaml.Controls.IGroupStyle2) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_HeaderContainerStyle(self: win32more.Windows.UI.Xaml.Controls.IGroupStyle2, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def add_PropertyChanged(self: win32more.Windows.UI.Xaml.Data.INotifyPropertyChanged, handler: win32more.Windows.UI.Xaml.Data.PropertyChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PropertyChanged(self: win32more.Windows.UI.Xaml.Data.INotifyPropertyChanged, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ContainerStyle = property(get_ContainerStyle, put_ContainerStyle)
    ContainerStyleSelector = property(get_ContainerStyleSelector, put_ContainerStyleSelector)
    HeaderContainerStyle = property(get_HeaderContainerStyle, put_HeaderContainerStyle)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HeaderTemplateSelector = property(get_HeaderTemplateSelector, put_HeaderTemplateSelector)
    HidesIfEmpty = property(get_HidesIfEmpty, put_HidesIfEmpty)
    Panel = property(get_Panel, put_Panel)
    PropertyChanged = event()
class GroupStyleSelector(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IGroupStyleSelector
    _classid_ = 'Windows.UI.Xaml.Controls.GroupStyleSelector'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.GroupStyleSelector.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IGroupStyleSelectorFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.GroupStyleSelector: ...
    @winrt_mixinmethod
    def SelectGroupStyle(self: win32more.Windows.UI.Xaml.Controls.IGroupStyleSelector, group: win32more.Windows.Win32.System.WinRT.IInspectable, level: UInt32) -> win32more.Windows.UI.Xaml.Controls.GroupStyle: ...
    @winrt_mixinmethod
    def SelectGroupStyleCore(self: win32more.Windows.UI.Xaml.Controls.IGroupStyleSelectorOverrides, group: win32more.Windows.Win32.System.WinRT.IInspectable, level: UInt32) -> win32more.Windows.UI.Xaml.Controls.GroupStyle: ...
class HandwritingPanelClosedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IHandwritingPanelClosedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.HandwritingPanelClosedEventArgs'
class HandwritingPanelOpenedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IHandwritingPanelOpenedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.HandwritingPanelOpenedEventArgs'
class HandwritingPanelPlacementAlignment(Enum, Int32):
    Auto = 0
    TopLeft = 1
    TopRight = 2
    BottomLeft = 3
    BottomRight = 4
class _HandwritingView_Meta_(ComPtr.__class__):
    pass
class HandwritingView(ComPtr, metaclass=_HandwritingView_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IHandwritingView
    _classid_ = 'Windows.UI.Xaml.Controls.HandwritingView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.HandwritingView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IHandwritingViewFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.HandwritingView: ...
    @winrt_mixinmethod
    def get_PlacementTarget(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_PlacementTarget(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_PlacementAlignment(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView) -> win32more.Windows.UI.Xaml.Controls.HandwritingPanelPlacementAlignment: ...
    @winrt_mixinmethod
    def put_PlacementAlignment(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView, value: win32more.Windows.UI.Xaml.Controls.HandwritingPanelPlacementAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_IsOpen(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView) -> Boolean: ...
    @winrt_mixinmethod
    def get_AreCandidatesEnabled(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView) -> Boolean: ...
    @winrt_mixinmethod
    def put_AreCandidatesEnabled(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_Opened(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.HandwritingView, win32more.Windows.UI.Xaml.Controls.HandwritingPanelOpenedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Opened(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.HandwritingView, win32more.Windows.UI.Xaml.Controls.HandwritingPanelClosedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def TryClose(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView) -> Boolean: ...
    @winrt_mixinmethod
    def TryOpen(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsSwitchToKeyboardEnabled(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSwitchToKeyboardEnabled(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsCommandBarOpen(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCommandBarOpen(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_InputDeviceTypes(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView2) -> win32more.Windows.UI.Core.CoreInputDeviceTypes: ...
    @winrt_mixinmethod
    def put_InputDeviceTypes(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView2, value: win32more.Windows.UI.Core.CoreInputDeviceTypes) -> Void: ...
    @winrt_mixinmethod
    def add_CandidatesChanged(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.HandwritingView, win32more.Windows.UI.Xaml.Controls.HandwritingViewCandidatesChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CandidatesChanged(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextSubmitted(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.HandwritingView, win32more.Windows.UI.Xaml.Controls.HandwritingViewTextSubmittedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextSubmitted(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetCandidates(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView2, candidatesSessionId: UInt32) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def SelectCandidate(self: win32more.Windows.UI.Xaml.Controls.IHandwritingView2, candidatesSessionId: UInt32, selectedCandidateIndex: UInt32) -> Void: ...
    @winrt_classmethod
    def get_IsSwitchToKeyboardEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IHandwritingViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsCommandBarOpenProperty(cls: win32more.Windows.UI.Xaml.Controls.IHandwritingViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlacementTargetProperty(cls: win32more.Windows.UI.Xaml.Controls.IHandwritingViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlacementAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IHandwritingViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsOpenProperty(cls: win32more.Windows.UI.Xaml.Controls.IHandwritingViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AreCandidatesEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IHandwritingViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AreCandidatesEnabled = property(get_AreCandidatesEnabled, put_AreCandidatesEnabled)
    InputDeviceTypes = property(get_InputDeviceTypes, put_InputDeviceTypes)
    IsCommandBarOpen = property(get_IsCommandBarOpen, put_IsCommandBarOpen)
    IsOpen = property(get_IsOpen, None)
    IsSwitchToKeyboardEnabled = property(get_IsSwitchToKeyboardEnabled, put_IsSwitchToKeyboardEnabled)
    PlacementAlignment = property(get_PlacementAlignment, put_PlacementAlignment)
    PlacementTarget = property(get_PlacementTarget, put_PlacementTarget)
    _HandwritingView_Meta_.AreCandidatesEnabledProperty = property(get_AreCandidatesEnabledProperty, None)
    _HandwritingView_Meta_.IsCommandBarOpenProperty = property(get_IsCommandBarOpenProperty, None)
    _HandwritingView_Meta_.IsOpenProperty = property(get_IsOpenProperty, None)
    _HandwritingView_Meta_.IsSwitchToKeyboardEnabledProperty = property(get_IsSwitchToKeyboardEnabledProperty, None)
    _HandwritingView_Meta_.PlacementAlignmentProperty = property(get_PlacementAlignmentProperty, None)
    _HandwritingView_Meta_.PlacementTargetProperty = property(get_PlacementTargetProperty, None)
    Opened = event()
    Closed = event()
    CandidatesChanged = event()
    TextSubmitted = event()
class HandwritingViewCandidatesChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IHandwritingViewCandidatesChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.HandwritingViewCandidatesChangedEventArgs'
    @winrt_mixinmethod
    def get_CandidatesSessionId(self: win32more.Windows.UI.Xaml.Controls.IHandwritingViewCandidatesChangedEventArgs) -> UInt32: ...
    CandidatesSessionId = property(get_CandidatesSessionId, None)
class HandwritingViewTextSubmittedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IHandwritingViewTextSubmittedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.HandwritingViewTextSubmittedEventArgs'
class _Hub_Meta_(ComPtr.__class__):
    pass
class Hub(ComPtr, metaclass=_Hub_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IHub
    _classid_ = 'Windows.UI.Xaml.Controls.Hub'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.Hub.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IHubFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Hub: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Windows.UI.Xaml.Controls.IHub) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Windows.UI.Xaml.Controls.IHub, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IHub) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IHub, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Windows.UI.Xaml.Controls.IHub) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Windows.UI.Xaml.Controls.IHub, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_DefaultSectionIndex(self: win32more.Windows.UI.Xaml.Controls.IHub) -> Int32: ...
    @winrt_mixinmethod
    def put_DefaultSectionIndex(self: win32more.Windows.UI.Xaml.Controls.IHub, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_Sections(self: win32more.Windows.UI.Xaml.Controls.IHub) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection]: ...
    @winrt_mixinmethod
    def get_SectionsInView(self: win32more.Windows.UI.Xaml.Controls.IHub) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection]: ...
    @winrt_mixinmethod
    def get_SectionHeaders(self: win32more.Windows.UI.Xaml.Controls.IHub) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def add_SectionHeaderClick(self: win32more.Windows.UI.Xaml.Controls.IHub, handler: win32more.Windows.UI.Xaml.Controls.HubSectionHeaderClickEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SectionHeaderClick(self: win32more.Windows.UI.Xaml.Controls.IHub, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SectionsInViewChanged(self: win32more.Windows.UI.Xaml.Controls.IHub, handler: win32more.Windows.UI.Xaml.Controls.SectionsInViewChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SectionsInViewChanged(self: win32more.Windows.UI.Xaml.Controls.IHub, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ScrollToSection(self: win32more.Windows.UI.Xaml.Controls.IHub, section: win32more.Windows.UI.Xaml.Controls.HubSection) -> Void: ...
    @winrt_mixinmethod
    def get_SemanticZoomOwner(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation) -> win32more.Windows.UI.Xaml.Controls.SemanticZoom: ...
    @winrt_mixinmethod
    def put_SemanticZoomOwner(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation, value: win32more.Windows.UI.Xaml.Controls.SemanticZoom) -> Void: ...
    @winrt_mixinmethod
    def get_IsActiveView(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsActiveView(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsZoomedInView(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZoomedInView(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def InitializeViewChange(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation) -> Void: ...
    @winrt_mixinmethod
    def CompleteViewChange(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation) -> Void: ...
    @winrt_mixinmethod
    def MakeVisible(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation, item: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def StartViewChangeFrom(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation, source: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def StartViewChangeTo(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation, source: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def CompleteViewChangeFrom(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation, source: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def CompleteViewChangeTo(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation, source: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.IHubStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IHubStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Windows.UI.Xaml.Controls.IHubStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DefaultSectionIndexProperty(cls: win32more.Windows.UI.Xaml.Controls.IHubStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SemanticZoomOwnerProperty(cls: win32more.Windows.UI.Xaml.Controls.IHubStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsActiveViewProperty(cls: win32more.Windows.UI.Xaml.Controls.IHubStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsZoomedInViewProperty(cls: win32more.Windows.UI.Xaml.Controls.IHubStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DefaultSectionIndex = property(get_DefaultSectionIndex, put_DefaultSectionIndex)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsActiveView = property(get_IsActiveView, put_IsActiveView)
    IsZoomedInView = property(get_IsZoomedInView, put_IsZoomedInView)
    Orientation = property(get_Orientation, put_Orientation)
    SectionHeaders = property(get_SectionHeaders, None)
    Sections = property(get_Sections, None)
    SectionsInView = property(get_SectionsInView, None)
    SemanticZoomOwner = property(get_SemanticZoomOwner, put_SemanticZoomOwner)
    _Hub_Meta_.DefaultSectionIndexProperty = property(get_DefaultSectionIndexProperty, None)
    _Hub_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _Hub_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _Hub_Meta_.IsActiveViewProperty = property(get_IsActiveViewProperty, None)
    _Hub_Meta_.IsZoomedInViewProperty = property(get_IsZoomedInViewProperty, None)
    _Hub_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _Hub_Meta_.SemanticZoomOwnerProperty = property(get_SemanticZoomOwnerProperty, None)
    SectionHeaderClick = event()
    SectionsInViewChanged = event()
class _HubSection_Meta_(ComPtr.__class__):
    pass
class HubSection(ComPtr, metaclass=_HubSection_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IHubSection
    _classid_ = 'Windows.UI.Xaml.Controls.HubSection'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.HubSection.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IHubSectionFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.HubSection: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Windows.UI.Xaml.Controls.IHubSection) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Windows.UI.Xaml.Controls.IHubSection, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IHubSection) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IHubSection, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_ContentTemplate(self: win32more.Windows.UI.Xaml.Controls.IHubSection) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_ContentTemplate(self: win32more.Windows.UI.Xaml.Controls.IHubSection, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_IsHeaderInteractive(self: win32more.Windows.UI.Xaml.Controls.IHubSection) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsHeaderInteractive(self: win32more.Windows.UI.Xaml.Controls.IHubSection, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.IHubSectionStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IHubSectionStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IHubSectionStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsHeaderInteractiveProperty(cls: win32more.Windows.UI.Xaml.Controls.IHubSectionStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ContentTemplate = property(get_ContentTemplate, put_ContentTemplate)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsHeaderInteractive = property(get_IsHeaderInteractive, put_IsHeaderInteractive)
    _HubSection_Meta_.ContentTemplateProperty = property(get_ContentTemplateProperty, None)
    _HubSection_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _HubSection_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _HubSection_Meta_.IsHeaderInteractiveProperty = property(get_IsHeaderInteractiveProperty, None)
class HubSectionCollection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[win32more.Windows.UI.Xaml.Controls.HubSection]]
    default_interface: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection]
    _classid_ = 'Windows.UI.Xaml.Controls.HubSectionCollection'
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection], index: UInt32) -> win32more.Windows.UI.Xaml.Controls.HubSection: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection]) -> UInt32: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection]) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.UI.Xaml.Controls.HubSection]: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection], value: win32more.Windows.UI.Xaml.Controls.HubSection, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def SetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection], index: UInt32, value: win32more.Windows.UI.Xaml.Controls.HubSection) -> Void: ...
    @winrt_mixinmethod
    def InsertAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection], index: UInt32, value: win32more.Windows.UI.Xaml.Controls.HubSection) -> Void: ...
    @winrt_mixinmethod
    def RemoveAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection], index: UInt32) -> Void: ...
    @winrt_mixinmethod
    def Append(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection], value: win32more.Windows.UI.Xaml.Controls.HubSection) -> Void: ...
    @winrt_mixinmethod
    def RemoveAtEnd(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection]) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection]) -> Void: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection], startIndex: UInt32, items: FillArray[win32more.Windows.UI.Xaml.Controls.HubSection]) -> UInt32: ...
    @winrt_mixinmethod
    def ReplaceAll(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection], items: PassArray[win32more.Windows.UI.Xaml.Controls.HubSection]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.UI.Xaml.Controls.HubSection]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.UI.Xaml.Controls.HubSection]: ...
    Size = property(get_Size, None)
class HubSectionHeaderClickEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IHubSectionHeaderClickEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.HubSectionHeaderClickEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.HubSectionHeaderClickEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.HubSectionHeaderClickEventArgs: ...
    @winrt_mixinmethod
    def get_Section(self: win32more.Windows.UI.Xaml.Controls.IHubSectionHeaderClickEventArgs) -> win32more.Windows.UI.Xaml.Controls.HubSection: ...
    Section = property(get_Section, None)
class HubSectionHeaderClickEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{afe17b9b-9c63-4583-88e4-c59019b7f49d}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Controls.HubSectionHeaderClickEventArgs) -> Void: ...
class _HyperlinkButton_Meta_(ComPtr.__class__):
    pass
class HyperlinkButton(ComPtr, metaclass=_HyperlinkButton_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.ButtonBase
    default_interface: win32more.Windows.UI.Xaml.Controls.IHyperlinkButton
    _classid_ = 'Windows.UI.Xaml.Controls.HyperlinkButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.HyperlinkButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IHyperlinkButtonFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.HyperlinkButton: ...
    @winrt_mixinmethod
    def get_NavigateUri(self: win32more.Windows.UI.Xaml.Controls.IHyperlinkButton) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_NavigateUri(self: win32more.Windows.UI.Xaml.Controls.IHyperlinkButton, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_classmethod
    def get_NavigateUriProperty(cls: win32more.Windows.UI.Xaml.Controls.IHyperlinkButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    NavigateUri = property(get_NavigateUri, put_NavigateUri)
    _HyperlinkButton_Meta_.NavigateUriProperty = property(get_NavigateUriProperty, None)
class IAnchorRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAnchorRequestedEventArgs'
    _iid_ = Guid('{5175f55d-4785-5a72-b462-eb11e9bdf897}')
    @winrt_commethod(6)
    def get_Anchor(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Anchor(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_AnchorCandidates(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.UIElement]: ...
    Anchor = property(get_Anchor, put_Anchor)
    AnchorCandidates = property(get_AnchorCandidates, None)
class IAppBar(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBar'
    _iid_ = Guid('{7b0fc253-86a5-4b43-9872-0b8a6234b74b}')
    @winrt_commethod(6)
    def get_IsOpen(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsOpen(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsSticky(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsSticky(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def add_Opened(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_Opened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def add_Closed(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_Closed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    IsOpen = property(get_IsOpen, put_IsOpen)
    IsSticky = property(get_IsSticky, put_IsSticky)
    Opened = event()
    Closed = event()
class IAppBar2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBar2'
    _iid_ = Guid('{c3ab17b3-7ad7-4676-9910-7fe3f0e8e993}')
    @winrt_commethod(6)
    def get_ClosedDisplayMode(self) -> win32more.Windows.UI.Xaml.Controls.AppBarClosedDisplayMode: ...
    @winrt_commethod(7)
    def put_ClosedDisplayMode(self, value: win32more.Windows.UI.Xaml.Controls.AppBarClosedDisplayMode) -> Void: ...
    ClosedDisplayMode = property(get_ClosedDisplayMode, put_ClosedDisplayMode)
class IAppBar3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBar3'
    _iid_ = Guid('{982b001f-752e-4e7a-b055-54802c9ea749}')
    @winrt_commethod(6)
    def get_TemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.AppBarTemplateSettings: ...
    @winrt_commethod(7)
    def add_Opening(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_Opening(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(9)
    def add_Closing(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_Closing(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    TemplateSettings = property(get_TemplateSettings, None)
    Opening = event()
    Closing = event()
class IAppBar4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBar4'
    _iid_ = Guid('{94ebc8cd-0a64-4da3-bf43-f13100a46605}')
    @winrt_commethod(6)
    def get_LightDismissOverlayMode(self) -> win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_commethod(7)
    def put_LightDismissOverlayMode(self, value: win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
class IAppBarButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarButton'
    _iid_ = Guid('{4459a451-69e8-440c-9896-4bb4f5f642d1}')
    @winrt_commethod(6)
    def get_Label(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Label(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Icon(self) -> win32more.Windows.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(9)
    def put_Icon(self, value: win32more.Windows.UI.Xaml.Controls.IconElement) -> Void: ...
    Icon = property(get_Icon, put_Icon)
    Label = property(get_Label, put_Label)
class IAppBarButton3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarButton3'
    _iid_ = Guid('{0b282150-198b-4e84-8f1c-9f6a8ba267a7}')
    @winrt_commethod(6)
    def get_LabelPosition(self) -> win32more.Windows.UI.Xaml.Controls.CommandBarLabelPosition: ...
    @winrt_commethod(7)
    def put_LabelPosition(self, value: win32more.Windows.UI.Xaml.Controls.CommandBarLabelPosition) -> Void: ...
    LabelPosition = property(get_LabelPosition, put_LabelPosition)
class IAppBarButton4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarButton4'
    _iid_ = Guid('{958fce6b-fd08-4414-8458-9d40866dc84e}')
    @winrt_commethod(6)
    def get_KeyboardAcceleratorTextOverride(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_KeyboardAcceleratorTextOverride(self, value: WinRT_String) -> Void: ...
    KeyboardAcceleratorTextOverride = property(get_KeyboardAcceleratorTextOverride, put_KeyboardAcceleratorTextOverride)
class IAppBarButton5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarButton5'
    _iid_ = Guid('{4096fc7f-1aec-4b0f-a031-ca8c4e06d2ed}')
    @winrt_commethod(6)
    def get_TemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.AppBarButtonTemplateSettings: ...
    TemplateSettings = property(get_TemplateSettings, None)
class IAppBarButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarButtonFactory'
    _iid_ = Guid('{bdbb1bb6-cb2e-4276-abd6-7935130510e0}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.AppBarButton: ...
class IAppBarButtonStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarButtonStatics'
    _iid_ = Guid('{7ccd13e6-5301-407f-874e-dc9160aa07af}')
    @winrt_commethod(6)
    def get_LabelProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IconProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsCompactProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IconProperty = property(get_IconProperty, None)
    IsCompactProperty = property(get_IsCompactProperty, None)
    LabelProperty = property(get_LabelProperty, None)
class IAppBarButtonStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarButtonStatics3'
    _iid_ = Guid('{4d7bf314-2ede-4328-8906-752a1f27cdfa}')
    @winrt_commethod(6)
    def get_LabelPositionProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsInOverflowProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DynamicOverflowOrderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DynamicOverflowOrderProperty = property(get_DynamicOverflowOrderProperty, None)
    IsInOverflowProperty = property(get_IsInOverflowProperty, None)
    LabelPositionProperty = property(get_LabelPositionProperty, None)
class IAppBarButtonStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarButtonStatics4'
    _iid_ = Guid('{1c0ae26a-c755-4fe6-a3b6-0e3394e952c0}')
    @winrt_commethod(6)
    def get_KeyboardAcceleratorTextOverrideProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    KeyboardAcceleratorTextOverrideProperty = property(get_KeyboardAcceleratorTextOverrideProperty, None)
class IAppBarElementContainer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarElementContainer'
    _iid_ = Guid('{1d5ba067-a990-5dab-a9c3-e6be56642a1a}')
class IAppBarElementContainerFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarElementContainerFactory'
    _iid_ = Guid('{b506530e-8897-5d6f-a43e-f0586338d282}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.AppBarElementContainer: ...
class IAppBarElementContainerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarElementContainerStatics'
    _iid_ = Guid('{ebbef840-c745-5a6f-8671-9a41eb2196e7}')
    @winrt_commethod(6)
    def get_IsCompactProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsInOverflowProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DynamicOverflowOrderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DynamicOverflowOrderProperty = property(get_DynamicOverflowOrderProperty, None)
    IsCompactProperty = property(get_IsCompactProperty, None)
    IsInOverflowProperty = property(get_IsInOverflowProperty, None)
class IAppBarFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarFactory'
    _iid_ = Guid('{614708d1-8e65-43cb-92d7-8eee17515f8d}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.AppBar: ...
class IAppBarOverrides(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarOverrides'
    _iid_ = Guid('{f003e4e2-7b0f-4f4a-970d-ae8a0eaa9b70}')
    @winrt_commethod(6)
    def OnClosed(self, e: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(7)
    def OnOpened(self, e: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
class IAppBarOverrides3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarOverrides3'
    _iid_ = Guid('{412bbbc8-51d0-4b49-ab62-a3dd6bdcb298}')
    @winrt_commethod(6)
    def OnClosing(self, e: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(7)
    def OnOpening(self, e: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
class IAppBarSeparator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarSeparator'
    _iid_ = Guid('{1b0795a1-1bc1-4d53-95ea-fb0a2cccc905}')
class IAppBarSeparatorFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarSeparatorFactory'
    _iid_ = Guid('{05da25cd-f407-48de-8b50-ff87d1e2818f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.AppBarSeparator: ...
class IAppBarSeparatorStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarSeparatorStatics'
    _iid_ = Guid('{37f23484-5b35-4663-a75d-f2d50cb9c619}')
    @winrt_commethod(6)
    def get_IsCompactProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsCompactProperty = property(get_IsCompactProperty, None)
class IAppBarSeparatorStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarSeparatorStatics3'
    _iid_ = Guid('{36c753f9-7373-4e5e-9ba4-c3622a003c4e}')
    @winrt_commethod(6)
    def get_IsInOverflowProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_DynamicOverflowOrderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DynamicOverflowOrderProperty = property(get_DynamicOverflowOrderProperty, None)
    IsInOverflowProperty = property(get_IsInOverflowProperty, None)
class IAppBarStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarStatics'
    _iid_ = Guid('{79bb7e8d-dca9-4b5f-a448-37b13238ed76}')
    @winrt_commethod(6)
    def get_IsOpenProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsStickyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsOpenProperty = property(get_IsOpenProperty, None)
    IsStickyProperty = property(get_IsStickyProperty, None)
class IAppBarStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarStatics2'
    _iid_ = Guid('{222355e9-0384-49de-8738-dfc9d409ac5d}')
    @winrt_commethod(6)
    def get_ClosedDisplayModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ClosedDisplayModeProperty = property(get_ClosedDisplayModeProperty, None)
class IAppBarStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarStatics4'
    _iid_ = Guid('{ba02082e-1165-4451-94b3-eb3ac73e4196}')
    @winrt_commethod(6)
    def get_LightDismissOverlayModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
class IAppBarToggleButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarToggleButton'
    _iid_ = Guid('{2e914438-fd53-4b8d-858b-3644269f8e4d}')
    @winrt_commethod(6)
    def get_Label(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Label(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Icon(self) -> win32more.Windows.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(9)
    def put_Icon(self, value: win32more.Windows.UI.Xaml.Controls.IconElement) -> Void: ...
    Icon = property(get_Icon, put_Icon)
    Label = property(get_Label, put_Label)
class IAppBarToggleButton3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarToggleButton3'
    _iid_ = Guid('{ef9a85e5-16ff-4d72-b9e8-9b861eaf84a8}')
    @winrt_commethod(6)
    def get_LabelPosition(self) -> win32more.Windows.UI.Xaml.Controls.CommandBarLabelPosition: ...
    @winrt_commethod(7)
    def put_LabelPosition(self, value: win32more.Windows.UI.Xaml.Controls.CommandBarLabelPosition) -> Void: ...
    LabelPosition = property(get_LabelPosition, put_LabelPosition)
class IAppBarToggleButton4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarToggleButton4'
    _iid_ = Guid('{b86b736e-3eaf-4751-a897-00029f1f6aca}')
    @winrt_commethod(6)
    def get_KeyboardAcceleratorTextOverride(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_KeyboardAcceleratorTextOverride(self, value: WinRT_String) -> Void: ...
    KeyboardAcceleratorTextOverride = property(get_KeyboardAcceleratorTextOverride, put_KeyboardAcceleratorTextOverride)
class IAppBarToggleButton5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarToggleButton5'
    _iid_ = Guid('{9dca3357-c130-4fb6-a1e2-d2b348fe43be}')
    @winrt_commethod(6)
    def get_TemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.AppBarToggleButtonTemplateSettings: ...
    TemplateSettings = property(get_TemplateSettings, None)
class IAppBarToggleButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarToggleButtonFactory'
    _iid_ = Guid('{028aa7d4-8f54-45a6-9f90-13605656d793}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.AppBarToggleButton: ...
class IAppBarToggleButtonStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarToggleButtonStatics'
    _iid_ = Guid('{fe5aaf96-7929-4da1-aa67-cddf73a3e4b5}')
    @winrt_commethod(6)
    def get_LabelProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IconProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsCompactProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IconProperty = property(get_IconProperty, None)
    IsCompactProperty = property(get_IsCompactProperty, None)
    LabelProperty = property(get_LabelProperty, None)
class IAppBarToggleButtonStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarToggleButtonStatics3'
    _iid_ = Guid('{bd4c65bf-2edd-44d1-acd5-35c00e2f21bc}')
    @winrt_commethod(6)
    def get_LabelPositionProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsInOverflowProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DynamicOverflowOrderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DynamicOverflowOrderProperty = property(get_DynamicOverflowOrderProperty, None)
    IsInOverflowProperty = property(get_IsInOverflowProperty, None)
    LabelPositionProperty = property(get_LabelPositionProperty, None)
class IAppBarToggleButtonStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAppBarToggleButtonStatics4'
    _iid_ = Guid('{a478b984-e916-4137-bdbd-95bd46ff3ce6}')
    @winrt_commethod(6)
    def get_KeyboardAcceleratorTextOverrideProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    KeyboardAcceleratorTextOverrideProperty = property(get_KeyboardAcceleratorTextOverrideProperty, None)
class IAutoSuggestBox(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAutoSuggestBox'
    _iid_ = Guid('{103e9b13-3400-4a16-90b9-6912bf06974f}')
    @winrt_commethod(6)
    def get_MaxSuggestionListHeight(self) -> Double: ...
    @winrt_commethod(7)
    def put_MaxSuggestionListHeight(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_IsSuggestionListOpen(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsSuggestionListOpen(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_TextMemberPath(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_TextMemberPath(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_Text(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_UpdateTextOnSelect(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_UpdateTextOnSelect(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_PlaceholderText(self) -> WinRT_String: ...
    @winrt_commethod(17)
    def put_PlaceholderText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(18)
    def get_Header(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(19)
    def put_Header(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(20)
    def get_AutoMaximizeSuggestionArea(self) -> Boolean: ...
    @winrt_commethod(21)
    def put_AutoMaximizeSuggestionArea(self, value: Boolean) -> Void: ...
    @winrt_commethod(22)
    def get_TextBoxStyle(self) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_commethod(23)
    def put_TextBoxStyle(self, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(24)
    def add_SuggestionChosen(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.AutoSuggestBox, win32more.Windows.UI.Xaml.Controls.AutoSuggestBoxSuggestionChosenEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(25)
    def remove_SuggestionChosen(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(26)
    def add_TextChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.AutoSuggestBox, win32more.Windows.UI.Xaml.Controls.AutoSuggestBoxTextChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(27)
    def remove_TextChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AutoMaximizeSuggestionArea = property(get_AutoMaximizeSuggestionArea, put_AutoMaximizeSuggestionArea)
    Header = property(get_Header, put_Header)
    IsSuggestionListOpen = property(get_IsSuggestionListOpen, put_IsSuggestionListOpen)
    MaxSuggestionListHeight = property(get_MaxSuggestionListHeight, put_MaxSuggestionListHeight)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    Text = property(get_Text, put_Text)
    TextBoxStyle = property(get_TextBoxStyle, put_TextBoxStyle)
    TextMemberPath = property(get_TextMemberPath, put_TextMemberPath)
    UpdateTextOnSelect = property(get_UpdateTextOnSelect, put_UpdateTextOnSelect)
    SuggestionChosen = event()
    TextChanged = event()
class IAutoSuggestBox2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAutoSuggestBox2'
    _iid_ = Guid('{aa87ddde-e679-45b2-a7c9-9aedc39db886}')
    @winrt_commethod(6)
    def get_QueryIcon(self) -> win32more.Windows.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(7)
    def put_QueryIcon(self, value: win32more.Windows.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_commethod(8)
    def add_QuerySubmitted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.AutoSuggestBox, win32more.Windows.UI.Xaml.Controls.AutoSuggestBoxQuerySubmittedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_QuerySubmitted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    QueryIcon = property(get_QueryIcon, put_QueryIcon)
    QuerySubmitted = event()
class IAutoSuggestBox3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAutoSuggestBox3'
    _iid_ = Guid('{9bbbfcef-f32d-402e-9009-05bdbaf6336e}')
    @winrt_commethod(6)
    def get_LightDismissOverlayMode(self) -> win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_commethod(7)
    def put_LightDismissOverlayMode(self, value: win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
class IAutoSuggestBox4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAutoSuggestBox4'
    _iid_ = Guid('{c22df897-a3e8-5051-b3cc-b5f0f5262950}')
    @winrt_commethod(6)
    def get_Description(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Description(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    Description = property(get_Description, put_Description)
class IAutoSuggestBoxQuerySubmittedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAutoSuggestBoxQuerySubmittedEventArgs'
    _iid_ = Guid('{78dcb116-818a-4cb5-bca7-382ce6ddc90d}')
    @winrt_commethod(6)
    def get_QueryText(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_ChosenSuggestion(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    ChosenSuggestion = property(get_ChosenSuggestion, None)
    QueryText = property(get_QueryText, None)
class IAutoSuggestBoxStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAutoSuggestBoxStatics'
    _iid_ = Guid('{ee22c7f4-c15d-4ff3-8a94-f50dfdfbe89a}')
    @winrt_commethod(6)
    def get_MaxSuggestionListHeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsSuggestionListOpenProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_TextMemberPathProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_TextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_UpdateTextOnSelectProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_PlaceholderTextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_HeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_AutoMaximizeSuggestionAreaProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_TextBoxStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AutoMaximizeSuggestionAreaProperty = property(get_AutoMaximizeSuggestionAreaProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    IsSuggestionListOpenProperty = property(get_IsSuggestionListOpenProperty, None)
    MaxSuggestionListHeightProperty = property(get_MaxSuggestionListHeightProperty, None)
    PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    TextBoxStyleProperty = property(get_TextBoxStyleProperty, None)
    TextMemberPathProperty = property(get_TextMemberPathProperty, None)
    TextProperty = property(get_TextProperty, None)
    UpdateTextOnSelectProperty = property(get_UpdateTextOnSelectProperty, None)
class IAutoSuggestBoxStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAutoSuggestBoxStatics2'
    _iid_ = Guid('{1cd297a8-8e6a-41ef-a95d-7157dc0c7106}')
    @winrt_commethod(6)
    def get_QueryIconProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    QueryIconProperty = property(get_QueryIconProperty, None)
class IAutoSuggestBoxStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAutoSuggestBoxStatics3'
    _iid_ = Guid('{2cead2dd-c4d5-4ab2-8a13-afddcf067c86}')
    @winrt_commethod(6)
    def get_LightDismissOverlayModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
class IAutoSuggestBoxStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAutoSuggestBoxStatics4'
    _iid_ = Guid('{d63efaae-b9df-58d8-a00a-dbfe9ffdedd0}')
    @winrt_commethod(6)
    def get_DescriptionProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DescriptionProperty = property(get_DescriptionProperty, None)
class IAutoSuggestBoxSuggestionChosenEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAutoSuggestBoxSuggestionChosenEventArgs'
    _iid_ = Guid('{396f7254-1ed5-4bc5-a060-655530bca6ba}')
    @winrt_commethod(6)
    def get_SelectedItem(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    SelectedItem = property(get_SelectedItem, None)
class IAutoSuggestBoxTextChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAutoSuggestBoxTextChangedEventArgs'
    _iid_ = Guid('{3a6f7254-1ed5-4bc5-a060-655530bca6ba}')
    @winrt_commethod(6)
    def get_Reason(self) -> win32more.Windows.UI.Xaml.Controls.AutoSuggestionBoxTextChangeReason: ...
    @winrt_commethod(7)
    def put_Reason(self, value: win32more.Windows.UI.Xaml.Controls.AutoSuggestionBoxTextChangeReason) -> Void: ...
    @winrt_commethod(8)
    def CheckCurrent(self) -> Boolean: ...
    Reason = property(get_Reason, put_Reason)
class IAutoSuggestBoxTextChangedEventArgsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IAutoSuggestBoxTextChangedEventArgsStatics'
    _iid_ = Guid('{fef7772b-9f45-44db-8c27-bda3f933e7b5}')
    @winrt_commethod(6)
    def get_ReasonProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ReasonProperty = property(get_ReasonProperty, None)
class IBackClickEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IBackClickEventArgs'
    _iid_ = Guid('{2ae6146c-477e-48c9-8830-2c464b7c7104}')
    @winrt_commethod(6)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Handled(self, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class IBitmapIcon(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IBitmapIcon'
    _iid_ = Guid('{e8fe17cb-35f7-40f3-a185-48b397b73e68}')
    @winrt_commethod(6)
    def get_UriSource(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def put_UriSource(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    UriSource = property(get_UriSource, put_UriSource)
class IBitmapIcon2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IBitmapIcon2'
    _iid_ = Guid('{0624a20a-9dd1-4201-bb20-42863da15658}')
    @winrt_commethod(6)
    def get_ShowAsMonochrome(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_ShowAsMonochrome(self, value: Boolean) -> Void: ...
    ShowAsMonochrome = property(get_ShowAsMonochrome, put_ShowAsMonochrome)
class IBitmapIconFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IBitmapIconFactory'
    _iid_ = Guid('{46d64b1d-7a49-4f66-9729-2848c788e402}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.BitmapIcon: ...
class IBitmapIconSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IBitmapIconSource'
    _iid_ = Guid('{c8e33dc7-d4ae-4a87-947f-ac4d0bcf5af4}')
    @winrt_commethod(6)
    def get_UriSource(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def put_UriSource(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(8)
    def get_ShowAsMonochrome(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_ShowAsMonochrome(self, value: Boolean) -> Void: ...
    ShowAsMonochrome = property(get_ShowAsMonochrome, put_ShowAsMonochrome)
    UriSource = property(get_UriSource, put_UriSource)
class IBitmapIconSourceFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IBitmapIconSourceFactory'
    _iid_ = Guid('{6509e5c6-44b6-4cd1-86cd-c3189b12c43c}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.BitmapIconSource: ...
class IBitmapIconSourceStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IBitmapIconSourceStatics'
    _iid_ = Guid('{5a105887-e494-4d2b-8528-39472296133f}')
    @winrt_commethod(6)
    def get_UriSourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ShowAsMonochromeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ShowAsMonochromeProperty = property(get_ShowAsMonochromeProperty, None)
    UriSourceProperty = property(get_UriSourceProperty, None)
class IBitmapIconStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IBitmapIconStatics'
    _iid_ = Guid('{e072d117-e4e7-4e0c-9470-53ff1ce84f67}')
    @winrt_commethod(6)
    def get_UriSourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    UriSourceProperty = property(get_UriSourceProperty, None)
class IBitmapIconStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IBitmapIconStatics2'
    _iid_ = Guid('{9745026b-b742-4a89-a5d7-a0e5fb809af1}')
    @winrt_commethod(6)
    def get_ShowAsMonochromeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ShowAsMonochromeProperty = property(get_ShowAsMonochromeProperty, None)
class IBorder(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IBorder'
    _iid_ = Guid('{797c4539-45bd-4633-a044-bfb02ef5170f}')
    @winrt_commethod(6)
    def get_BorderBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(7)
    def put_BorderBrush(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(8)
    def get_BorderThickness(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(9)
    def put_BorderThickness(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(10)
    def get_Background(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(11)
    def put_Background(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(12)
    def get_CornerRadius(self) -> win32more.Windows.UI.Xaml.CornerRadius: ...
    @winrt_commethod(13)
    def put_CornerRadius(self, value: win32more.Windows.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_commethod(14)
    def get_Padding(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(15)
    def put_Padding(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(16)
    def get_Child(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(17)
    def put_Child(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(18)
    def get_ChildTransitions(self) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(19)
    def put_ChildTransitions(self, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    Background = property(get_Background, put_Background)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    Child = property(get_Child, put_Child)
    ChildTransitions = property(get_ChildTransitions, put_ChildTransitions)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    Padding = property(get_Padding, put_Padding)
class IBorder2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IBorder2'
    _iid_ = Guid('{a1efbd9d-cb8b-56b5-878d-3a7f43bc9730}')
    @winrt_commethod(6)
    def get_BackgroundSizing(self) -> win32more.Windows.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_commethod(7)
    def put_BackgroundSizing(self, value: win32more.Windows.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_commethod(8)
    def get_BackgroundTransition(self) -> win32more.Windows.UI.Xaml.BrushTransition: ...
    @winrt_commethod(9)
    def put_BackgroundTransition(self, value: win32more.Windows.UI.Xaml.BrushTransition) -> Void: ...
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BackgroundTransition = property(get_BackgroundTransition, put_BackgroundTransition)
class IBorderStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IBorderStatics'
    _iid_ = Guid('{b81d1639-e911-4fd7-a4c4-b9c7f008b7fc}')
    @winrt_commethod(6)
    def get_BorderBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_BorderThicknessProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_BackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_CornerRadiusProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_PaddingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_ChildTransitionsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BackgroundProperty = property(get_BackgroundProperty, None)
    BorderBrushProperty = property(get_BorderBrushProperty, None)
    BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    ChildTransitionsProperty = property(get_ChildTransitionsProperty, None)
    CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
class IBorderStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IBorderStatics2'
    _iid_ = Guid('{a26d4476-803f-5040-a0f3-e66db3733166}')
    @winrt_commethod(6)
    def get_BackgroundSizingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
class IButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IButton'
    _iid_ = Guid('{280335ae-5570-46c7-8e0b-602be71229a2}')
class IButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IButtonFactory'
    _iid_ = Guid('{80a13c19-843a-451c-8cf5-44c701b0e216}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Button: ...
class IButtonStaticsWithFlyout(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IButtonStaticsWithFlyout'
    _iid_ = Guid('{90143898-a16c-4759-b2f0-a5f7e625169e}')
    @winrt_commethod(6)
    def get_FlyoutProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    FlyoutProperty = property(get_FlyoutProperty, None)
class IButtonWithFlyout(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IButtonWithFlyout'
    _iid_ = Guid('{09108f87-df6c-4180-9b3a-e60845825811}')
    @winrt_commethod(6)
    def get_Flyout(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(7)
    def put_Flyout(self, value: win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    Flyout = property(get_Flyout, put_Flyout)
class ICalendarDatePicker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarDatePicker'
    _iid_ = Guid('{63c9c16f-668c-4491-9444-d45d8bf4fa29}')
    @winrt_commethod(6)
    def get_Date(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(7)
    def put_Date(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_commethod(8)
    def get_IsCalendarOpen(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsCalendarOpen(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_DateFormat(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_DateFormat(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_PlaceholderText(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_PlaceholderText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_Header(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(15)
    def put_Header(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(16)
    def get_HeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(17)
    def put_HeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(18)
    def get_CalendarViewStyle(self) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_commethod(19)
    def put_CalendarViewStyle(self, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(20)
    def get_MinDate(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(21)
    def put_MinDate(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(22)
    def get_MaxDate(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(23)
    def put_MaxDate(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(24)
    def get_IsTodayHighlighted(self) -> Boolean: ...
    @winrt_commethod(25)
    def put_IsTodayHighlighted(self, value: Boolean) -> Void: ...
    @winrt_commethod(26)
    def get_DisplayMode(self) -> win32more.Windows.UI.Xaml.Controls.CalendarViewDisplayMode: ...
    @winrt_commethod(27)
    def put_DisplayMode(self, value: win32more.Windows.UI.Xaml.Controls.CalendarViewDisplayMode) -> Void: ...
    @winrt_commethod(28)
    def get_FirstDayOfWeek(self) -> win32more.Windows.Globalization.DayOfWeek: ...
    @winrt_commethod(29)
    def put_FirstDayOfWeek(self, value: win32more.Windows.Globalization.DayOfWeek) -> Void: ...
    @winrt_commethod(30)
    def get_DayOfWeekFormat(self) -> WinRT_String: ...
    @winrt_commethod(31)
    def put_DayOfWeekFormat(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(32)
    def get_CalendarIdentifier(self) -> WinRT_String: ...
    @winrt_commethod(33)
    def put_CalendarIdentifier(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(34)
    def get_IsOutOfScopeEnabled(self) -> Boolean: ...
    @winrt_commethod(35)
    def put_IsOutOfScopeEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(36)
    def get_IsGroupLabelVisible(self) -> Boolean: ...
    @winrt_commethod(37)
    def put_IsGroupLabelVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(38)
    def add_CalendarViewDayItemChanging(self, handler: win32more.Windows.UI.Xaml.Controls.CalendarViewDayItemChangingEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(39)
    def remove_CalendarViewDayItemChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(40)
    def add_DateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.CalendarDatePicker, win32more.Windows.UI.Xaml.Controls.CalendarDatePickerDateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(41)
    def remove_DateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(42)
    def add_Opened(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(43)
    def remove_Opened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(44)
    def add_Closed(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(45)
    def remove_Closed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(46)
    def SetDisplayDate(self, date: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(47)
    def SetYearDecadeDisplayDimensions(self, columns: Int32, rows: Int32) -> Void: ...
    CalendarIdentifier = property(get_CalendarIdentifier, put_CalendarIdentifier)
    CalendarViewStyle = property(get_CalendarViewStyle, put_CalendarViewStyle)
    Date = property(get_Date, put_Date)
    DateFormat = property(get_DateFormat, put_DateFormat)
    DayOfWeekFormat = property(get_DayOfWeekFormat, put_DayOfWeekFormat)
    DisplayMode = property(get_DisplayMode, put_DisplayMode)
    FirstDayOfWeek = property(get_FirstDayOfWeek, put_FirstDayOfWeek)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsCalendarOpen = property(get_IsCalendarOpen, put_IsCalendarOpen)
    IsGroupLabelVisible = property(get_IsGroupLabelVisible, put_IsGroupLabelVisible)
    IsOutOfScopeEnabled = property(get_IsOutOfScopeEnabled, put_IsOutOfScopeEnabled)
    IsTodayHighlighted = property(get_IsTodayHighlighted, put_IsTodayHighlighted)
    MaxDate = property(get_MaxDate, put_MaxDate)
    MinDate = property(get_MinDate, put_MinDate)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    CalendarViewDayItemChanging = event()
    DateChanged = event()
    Opened = event()
    Closed = event()
class ICalendarDatePicker2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarDatePicker2'
    _iid_ = Guid('{b216c159-2411-4a60-a7aa-27416b49481e}')
    @winrt_commethod(6)
    def get_LightDismissOverlayMode(self) -> win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_commethod(7)
    def put_LightDismissOverlayMode(self, value: win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
class ICalendarDatePicker3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarDatePicker3'
    _iid_ = Guid('{645856c0-db7b-5e75-85e9-f623e3457ea6}')
    @winrt_commethod(6)
    def get_Description(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Description(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    Description = property(get_Description, put_Description)
class ICalendarDatePickerDateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarDatePickerDateChangedEventArgs'
    _iid_ = Guid('{60d90db2-5010-46ba-842d-a4152c6504e7}')
    @winrt_commethod(6)
    def get_NewDate(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(7)
    def get_OldDate(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    NewDate = property(get_NewDate, None)
    OldDate = property(get_OldDate, None)
class ICalendarDatePickerFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarDatePickerFactory'
    _iid_ = Guid('{107aad5d-38be-42af-a957-fc86a5cf1e9a}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.CalendarDatePicker: ...
class ICalendarDatePickerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarDatePickerStatics'
    _iid_ = Guid('{39a3d291-afab-4b94-8395-ba7b874e3c8c}')
    @winrt_commethod(6)
    def get_DateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsCalendarOpenProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DateFormatProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PlaceholderTextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_HeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_HeaderTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_CalendarViewStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_MinDateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_MaxDateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_IsTodayHighlightedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_DisplayModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_FirstDayOfWeekProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_DayOfWeekFormatProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_CalendarIdentifierProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_IsOutOfScopeEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_IsGroupLabelVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CalendarIdentifierProperty = property(get_CalendarIdentifierProperty, None)
    CalendarViewStyleProperty = property(get_CalendarViewStyleProperty, None)
    DateFormatProperty = property(get_DateFormatProperty, None)
    DateProperty = property(get_DateProperty, None)
    DayOfWeekFormatProperty = property(get_DayOfWeekFormatProperty, None)
    DisplayModeProperty = property(get_DisplayModeProperty, None)
    FirstDayOfWeekProperty = property(get_FirstDayOfWeekProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IsCalendarOpenProperty = property(get_IsCalendarOpenProperty, None)
    IsGroupLabelVisibleProperty = property(get_IsGroupLabelVisibleProperty, None)
    IsOutOfScopeEnabledProperty = property(get_IsOutOfScopeEnabledProperty, None)
    IsTodayHighlightedProperty = property(get_IsTodayHighlightedProperty, None)
    MaxDateProperty = property(get_MaxDateProperty, None)
    MinDateProperty = property(get_MinDateProperty, None)
    PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
class ICalendarDatePickerStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarDatePickerStatics2'
    _iid_ = Guid('{30206b58-a2f6-4a00-8d13-33c46b6b8e0d}')
    @winrt_commethod(6)
    def get_LightDismissOverlayModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
class ICalendarDatePickerStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarDatePickerStatics3'
    _iid_ = Guid('{b188741d-cf69-568c-9707-baaaec2b64db}')
    @winrt_commethod(6)
    def get_DescriptionProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DescriptionProperty = property(get_DescriptionProperty, None)
class ICalendarView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarView'
    _iid_ = Guid('{cd639203-dfb5-4312-ac07-c0391824607b}')
    @winrt_commethod(6)
    def get_CalendarIdentifier(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_CalendarIdentifier(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_DayOfWeekFormat(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_DayOfWeekFormat(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_IsGroupLabelVisible(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsGroupLabelVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_DisplayMode(self) -> win32more.Windows.UI.Xaml.Controls.CalendarViewDisplayMode: ...
    @winrt_commethod(13)
    def put_DisplayMode(self, value: win32more.Windows.UI.Xaml.Controls.CalendarViewDisplayMode) -> Void: ...
    @winrt_commethod(14)
    def get_FirstDayOfWeek(self) -> win32more.Windows.Globalization.DayOfWeek: ...
    @winrt_commethod(15)
    def put_FirstDayOfWeek(self, value: win32more.Windows.Globalization.DayOfWeek) -> Void: ...
    @winrt_commethod(16)
    def get_IsOutOfScopeEnabled(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsOutOfScopeEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_IsTodayHighlighted(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_IsTodayHighlighted(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_MaxDate(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(21)
    def put_MaxDate(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(22)
    def get_MinDate(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(23)
    def put_MinDate(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(24)
    def get_NumberOfWeeksInView(self) -> Int32: ...
    @winrt_commethod(25)
    def put_NumberOfWeeksInView(self, value: Int32) -> Void: ...
    @winrt_commethod(26)
    def get_SelectedDates(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(27)
    def get_SelectionMode(self) -> win32more.Windows.UI.Xaml.Controls.CalendarViewSelectionMode: ...
    @winrt_commethod(28)
    def put_SelectionMode(self, value: win32more.Windows.UI.Xaml.Controls.CalendarViewSelectionMode) -> Void: ...
    @winrt_commethod(29)
    def get_TemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.CalendarViewTemplateSettings: ...
    @winrt_commethod(30)
    def get_FocusBorderBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(31)
    def put_FocusBorderBrush(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(32)
    def get_SelectedHoverBorderBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(33)
    def put_SelectedHoverBorderBrush(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(34)
    def get_SelectedPressedBorderBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(35)
    def put_SelectedPressedBorderBrush(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(36)
    def get_SelectedBorderBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(37)
    def put_SelectedBorderBrush(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(38)
    def get_HoverBorderBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(39)
    def put_HoverBorderBrush(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(40)
    def get_PressedBorderBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(41)
    def put_PressedBorderBrush(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(42)
    def get_CalendarItemBorderBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(43)
    def put_CalendarItemBorderBrush(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(44)
    def get_OutOfScopeBackground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(45)
    def put_OutOfScopeBackground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(46)
    def get_CalendarItemBackground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(47)
    def put_CalendarItemBackground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(48)
    def get_PressedForeground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(49)
    def put_PressedForeground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(50)
    def get_TodayForeground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(51)
    def put_TodayForeground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(52)
    def get_BlackoutForeground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(53)
    def put_BlackoutForeground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(54)
    def get_SelectedForeground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(55)
    def put_SelectedForeground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(56)
    def get_OutOfScopeForeground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(57)
    def put_OutOfScopeForeground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(58)
    def get_CalendarItemForeground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(59)
    def put_CalendarItemForeground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(60)
    def get_DayItemFontFamily(self) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(61)
    def put_DayItemFontFamily(self, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(62)
    def get_DayItemFontSize(self) -> Double: ...
    @winrt_commethod(63)
    def put_DayItemFontSize(self, value: Double) -> Void: ...
    @winrt_commethod(64)
    def get_DayItemFontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(65)
    def put_DayItemFontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(66)
    def get_DayItemFontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(67)
    def put_DayItemFontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(68)
    def get_TodayFontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(69)
    def put_TodayFontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(70)
    def get_FirstOfMonthLabelFontFamily(self) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(71)
    def put_FirstOfMonthLabelFontFamily(self, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(72)
    def get_FirstOfMonthLabelFontSize(self) -> Double: ...
    @winrt_commethod(73)
    def put_FirstOfMonthLabelFontSize(self, value: Double) -> Void: ...
    @winrt_commethod(74)
    def get_FirstOfMonthLabelFontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(75)
    def put_FirstOfMonthLabelFontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(76)
    def get_FirstOfMonthLabelFontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(77)
    def put_FirstOfMonthLabelFontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(78)
    def get_MonthYearItemFontFamily(self) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(79)
    def put_MonthYearItemFontFamily(self, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(80)
    def get_MonthYearItemFontSize(self) -> Double: ...
    @winrt_commethod(81)
    def put_MonthYearItemFontSize(self, value: Double) -> Void: ...
    @winrt_commethod(82)
    def get_MonthYearItemFontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(83)
    def put_MonthYearItemFontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(84)
    def get_MonthYearItemFontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(85)
    def put_MonthYearItemFontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(86)
    def get_FirstOfYearDecadeLabelFontFamily(self) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(87)
    def put_FirstOfYearDecadeLabelFontFamily(self, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(88)
    def get_FirstOfYearDecadeLabelFontSize(self) -> Double: ...
    @winrt_commethod(89)
    def put_FirstOfYearDecadeLabelFontSize(self, value: Double) -> Void: ...
    @winrt_commethod(90)
    def get_FirstOfYearDecadeLabelFontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(91)
    def put_FirstOfYearDecadeLabelFontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(92)
    def get_FirstOfYearDecadeLabelFontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(93)
    def put_FirstOfYearDecadeLabelFontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(94)
    def get_HorizontalDayItemAlignment(self) -> win32more.Windows.UI.Xaml.HorizontalAlignment: ...
    @winrt_commethod(95)
    def put_HorizontalDayItemAlignment(self, value: win32more.Windows.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_commethod(96)
    def get_VerticalDayItemAlignment(self) -> win32more.Windows.UI.Xaml.VerticalAlignment: ...
    @winrt_commethod(97)
    def put_VerticalDayItemAlignment(self, value: win32more.Windows.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_commethod(98)
    def get_HorizontalFirstOfMonthLabelAlignment(self) -> win32more.Windows.UI.Xaml.HorizontalAlignment: ...
    @winrt_commethod(99)
    def put_HorizontalFirstOfMonthLabelAlignment(self, value: win32more.Windows.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_commethod(100)
    def get_VerticalFirstOfMonthLabelAlignment(self) -> win32more.Windows.UI.Xaml.VerticalAlignment: ...
    @winrt_commethod(101)
    def put_VerticalFirstOfMonthLabelAlignment(self, value: win32more.Windows.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_commethod(102)
    def get_CalendarItemBorderThickness(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(103)
    def put_CalendarItemBorderThickness(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(104)
    def get_CalendarViewDayItemStyle(self) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_commethod(105)
    def put_CalendarViewDayItemStyle(self, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(106)
    def add_CalendarViewDayItemChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.CalendarView, win32more.Windows.UI.Xaml.Controls.CalendarViewDayItemChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(107)
    def remove_CalendarViewDayItemChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(108)
    def add_SelectedDatesChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.CalendarView, win32more.Windows.UI.Xaml.Controls.CalendarViewSelectedDatesChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(109)
    def remove_SelectedDatesChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(110)
    def SetDisplayDate(self, date: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(111)
    def SetYearDecadeDisplayDimensions(self, columns: Int32, rows: Int32) -> Void: ...
    BlackoutForeground = property(get_BlackoutForeground, put_BlackoutForeground)
    CalendarIdentifier = property(get_CalendarIdentifier, put_CalendarIdentifier)
    CalendarItemBackground = property(get_CalendarItemBackground, put_CalendarItemBackground)
    CalendarItemBorderBrush = property(get_CalendarItemBorderBrush, put_CalendarItemBorderBrush)
    CalendarItemBorderThickness = property(get_CalendarItemBorderThickness, put_CalendarItemBorderThickness)
    CalendarItemForeground = property(get_CalendarItemForeground, put_CalendarItemForeground)
    CalendarViewDayItemStyle = property(get_CalendarViewDayItemStyle, put_CalendarViewDayItemStyle)
    DayItemFontFamily = property(get_DayItemFontFamily, put_DayItemFontFamily)
    DayItemFontSize = property(get_DayItemFontSize, put_DayItemFontSize)
    DayItemFontStyle = property(get_DayItemFontStyle, put_DayItemFontStyle)
    DayItemFontWeight = property(get_DayItemFontWeight, put_DayItemFontWeight)
    DayOfWeekFormat = property(get_DayOfWeekFormat, put_DayOfWeekFormat)
    DisplayMode = property(get_DisplayMode, put_DisplayMode)
    FirstDayOfWeek = property(get_FirstDayOfWeek, put_FirstDayOfWeek)
    FirstOfMonthLabelFontFamily = property(get_FirstOfMonthLabelFontFamily, put_FirstOfMonthLabelFontFamily)
    FirstOfMonthLabelFontSize = property(get_FirstOfMonthLabelFontSize, put_FirstOfMonthLabelFontSize)
    FirstOfMonthLabelFontStyle = property(get_FirstOfMonthLabelFontStyle, put_FirstOfMonthLabelFontStyle)
    FirstOfMonthLabelFontWeight = property(get_FirstOfMonthLabelFontWeight, put_FirstOfMonthLabelFontWeight)
    FirstOfYearDecadeLabelFontFamily = property(get_FirstOfYearDecadeLabelFontFamily, put_FirstOfYearDecadeLabelFontFamily)
    FirstOfYearDecadeLabelFontSize = property(get_FirstOfYearDecadeLabelFontSize, put_FirstOfYearDecadeLabelFontSize)
    FirstOfYearDecadeLabelFontStyle = property(get_FirstOfYearDecadeLabelFontStyle, put_FirstOfYearDecadeLabelFontStyle)
    FirstOfYearDecadeLabelFontWeight = property(get_FirstOfYearDecadeLabelFontWeight, put_FirstOfYearDecadeLabelFontWeight)
    FocusBorderBrush = property(get_FocusBorderBrush, put_FocusBorderBrush)
    HorizontalDayItemAlignment = property(get_HorizontalDayItemAlignment, put_HorizontalDayItemAlignment)
    HorizontalFirstOfMonthLabelAlignment = property(get_HorizontalFirstOfMonthLabelAlignment, put_HorizontalFirstOfMonthLabelAlignment)
    HoverBorderBrush = property(get_HoverBorderBrush, put_HoverBorderBrush)
    IsGroupLabelVisible = property(get_IsGroupLabelVisible, put_IsGroupLabelVisible)
    IsOutOfScopeEnabled = property(get_IsOutOfScopeEnabled, put_IsOutOfScopeEnabled)
    IsTodayHighlighted = property(get_IsTodayHighlighted, put_IsTodayHighlighted)
    MaxDate = property(get_MaxDate, put_MaxDate)
    MinDate = property(get_MinDate, put_MinDate)
    MonthYearItemFontFamily = property(get_MonthYearItemFontFamily, put_MonthYearItemFontFamily)
    MonthYearItemFontSize = property(get_MonthYearItemFontSize, put_MonthYearItemFontSize)
    MonthYearItemFontStyle = property(get_MonthYearItemFontStyle, put_MonthYearItemFontStyle)
    MonthYearItemFontWeight = property(get_MonthYearItemFontWeight, put_MonthYearItemFontWeight)
    NumberOfWeeksInView = property(get_NumberOfWeeksInView, put_NumberOfWeeksInView)
    OutOfScopeBackground = property(get_OutOfScopeBackground, put_OutOfScopeBackground)
    OutOfScopeForeground = property(get_OutOfScopeForeground, put_OutOfScopeForeground)
    PressedBorderBrush = property(get_PressedBorderBrush, put_PressedBorderBrush)
    PressedForeground = property(get_PressedForeground, put_PressedForeground)
    SelectedBorderBrush = property(get_SelectedBorderBrush, put_SelectedBorderBrush)
    SelectedDates = property(get_SelectedDates, None)
    SelectedForeground = property(get_SelectedForeground, put_SelectedForeground)
    SelectedHoverBorderBrush = property(get_SelectedHoverBorderBrush, put_SelectedHoverBorderBrush)
    SelectedPressedBorderBrush = property(get_SelectedPressedBorderBrush, put_SelectedPressedBorderBrush)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    TemplateSettings = property(get_TemplateSettings, None)
    TodayFontWeight = property(get_TodayFontWeight, put_TodayFontWeight)
    TodayForeground = property(get_TodayForeground, put_TodayForeground)
    VerticalDayItemAlignment = property(get_VerticalDayItemAlignment, put_VerticalDayItemAlignment)
    VerticalFirstOfMonthLabelAlignment = property(get_VerticalFirstOfMonthLabelAlignment, put_VerticalFirstOfMonthLabelAlignment)
    CalendarViewDayItemChanging = event()
    SelectedDatesChanged = event()
class ICalendarView2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarView2'
    _iid_ = Guid('{f55ab64a-5504-5d9e-9d20-2ffdb88fc56b}')
    @winrt_commethod(6)
    def get_SelectedDisabledBorderBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(7)
    def put_SelectedDisabledBorderBrush(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(8)
    def get_TodaySelectedInnerBorderBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(9)
    def put_TodaySelectedInnerBorderBrush(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(10)
    def get_BlackoutStrikethroughBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(11)
    def put_BlackoutStrikethroughBrush(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(12)
    def get_BlackoutBackground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(13)
    def put_BlackoutBackground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(14)
    def get_CalendarItemHoverBackground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(15)
    def put_CalendarItemHoverBackground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(16)
    def get_CalendarItemPressedBackground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(17)
    def put_CalendarItemPressedBackground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(18)
    def get_CalendarItemDisabledBackground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(19)
    def put_CalendarItemDisabledBackground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(20)
    def get_TodayBackground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(21)
    def put_TodayBackground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(22)
    def get_TodayBlackoutBackground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(23)
    def put_TodayBlackoutBackground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(24)
    def get_TodayHoverBackground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(25)
    def put_TodayHoverBackground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(26)
    def get_TodayPressedBackground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(27)
    def put_TodayPressedBackground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(28)
    def get_TodayDisabledBackground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(29)
    def put_TodayDisabledBackground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(30)
    def get_TodayBlackoutForeground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(31)
    def put_TodayBlackoutForeground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(32)
    def get_SelectedHoverForeground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(33)
    def put_SelectedHoverForeground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(34)
    def get_SelectedPressedForeground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(35)
    def put_SelectedPressedForeground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(36)
    def get_SelectedDisabledForeground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(37)
    def put_SelectedDisabledForeground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(38)
    def get_OutOfScopeHoverForeground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(39)
    def put_OutOfScopeHoverForeground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(40)
    def get_OutOfScopePressedForeground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(41)
    def put_OutOfScopePressedForeground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(42)
    def get_DisabledForeground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(43)
    def put_DisabledForeground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(44)
    def get_DayItemMargin(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(45)
    def put_DayItemMargin(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(46)
    def get_MonthYearItemMargin(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(47)
    def put_MonthYearItemMargin(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(48)
    def get_FirstOfMonthLabelMargin(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(49)
    def put_FirstOfMonthLabelMargin(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(50)
    def get_FirstOfYearDecadeLabelMargin(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(51)
    def put_FirstOfYearDecadeLabelMargin(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(52)
    def get_CalendarItemCornerRadius(self) -> win32more.Windows.UI.Xaml.CornerRadius: ...
    @winrt_commethod(53)
    def put_CalendarItemCornerRadius(self, value: win32more.Windows.UI.Xaml.CornerRadius) -> Void: ...
    BlackoutBackground = property(get_BlackoutBackground, put_BlackoutBackground)
    BlackoutStrikethroughBrush = property(get_BlackoutStrikethroughBrush, put_BlackoutStrikethroughBrush)
    CalendarItemCornerRadius = property(get_CalendarItemCornerRadius, put_CalendarItemCornerRadius)
    CalendarItemDisabledBackground = property(get_CalendarItemDisabledBackground, put_CalendarItemDisabledBackground)
    CalendarItemHoverBackground = property(get_CalendarItemHoverBackground, put_CalendarItemHoverBackground)
    CalendarItemPressedBackground = property(get_CalendarItemPressedBackground, put_CalendarItemPressedBackground)
    DayItemMargin = property(get_DayItemMargin, put_DayItemMargin)
    DisabledForeground = property(get_DisabledForeground, put_DisabledForeground)
    FirstOfMonthLabelMargin = property(get_FirstOfMonthLabelMargin, put_FirstOfMonthLabelMargin)
    FirstOfYearDecadeLabelMargin = property(get_FirstOfYearDecadeLabelMargin, put_FirstOfYearDecadeLabelMargin)
    MonthYearItemMargin = property(get_MonthYearItemMargin, put_MonthYearItemMargin)
    OutOfScopeHoverForeground = property(get_OutOfScopeHoverForeground, put_OutOfScopeHoverForeground)
    OutOfScopePressedForeground = property(get_OutOfScopePressedForeground, put_OutOfScopePressedForeground)
    SelectedDisabledBorderBrush = property(get_SelectedDisabledBorderBrush, put_SelectedDisabledBorderBrush)
    SelectedDisabledForeground = property(get_SelectedDisabledForeground, put_SelectedDisabledForeground)
    SelectedHoverForeground = property(get_SelectedHoverForeground, put_SelectedHoverForeground)
    SelectedPressedForeground = property(get_SelectedPressedForeground, put_SelectedPressedForeground)
    TodayBackground = property(get_TodayBackground, put_TodayBackground)
    TodayBlackoutBackground = property(get_TodayBlackoutBackground, put_TodayBlackoutBackground)
    TodayBlackoutForeground = property(get_TodayBlackoutForeground, put_TodayBlackoutForeground)
    TodayDisabledBackground = property(get_TodayDisabledBackground, put_TodayDisabledBackground)
    TodayHoverBackground = property(get_TodayHoverBackground, put_TodayHoverBackground)
    TodayPressedBackground = property(get_TodayPressedBackground, put_TodayPressedBackground)
    TodaySelectedInnerBorderBrush = property(get_TodaySelectedInnerBorderBrush, put_TodaySelectedInnerBorderBrush)
class ICalendarViewDayItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarViewDayItem'
    _iid_ = Guid('{0fdb2dc5-32c1-4b8f-befc-017b555b32d2}')
    @winrt_commethod(6)
    def get_IsBlackout(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsBlackout(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Date(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(9)
    def SetDensityColors(self, colors: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.UI.Color]) -> Void: ...
    Date = property(get_Date, None)
    IsBlackout = property(get_IsBlackout, put_IsBlackout)
class ICalendarViewDayItemChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarViewDayItemChangingEventArgs'
    _iid_ = Guid('{73146666-1fb1-44f9-b7ad-4de859ecc565}')
    @winrt_commethod(6)
    def get_InRecycleQueue(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_Item(self) -> win32more.Windows.UI.Xaml.Controls.CalendarViewDayItem: ...
    @winrt_commethod(8)
    def get_Phase(self) -> UInt32: ...
    @winrt_commethod(9)
    def RegisterUpdateCallback(self, callback: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.CalendarView, win32more.Windows.UI.Xaml.Controls.CalendarViewDayItemChangingEventArgs]) -> Void: ...
    @winrt_commethod(10)
    def RegisterUpdateCallbackWithPhase(self, callbackPhase: UInt32, callback: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.CalendarView, win32more.Windows.UI.Xaml.Controls.CalendarViewDayItemChangingEventArgs]) -> Void: ...
    InRecycleQueue = property(get_InRecycleQueue, None)
    Item = property(get_Item, None)
    Phase = property(get_Phase, None)
class ICalendarViewDayItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarViewDayItemFactory'
    _iid_ = Guid('{62112bdc-1d2f-4e44-9baf-1665749521f2}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.CalendarViewDayItem: ...
class ICalendarViewDayItemStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarViewDayItemStatics'
    _iid_ = Guid('{c3a1dbbf-bd88-488b-b916-d00d69b1735a}')
    @winrt_commethod(6)
    def get_IsBlackoutProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_DateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DateProperty = property(get_DateProperty, None)
    IsBlackoutProperty = property(get_IsBlackoutProperty, None)
class ICalendarViewFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarViewFactory'
    _iid_ = Guid('{3d8f82e3-6cc6-423e-8d7c-7014d954ddef}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.CalendarView: ...
class ICalendarViewSelectedDatesChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarViewSelectedDatesChangedEventArgs'
    _iid_ = Guid('{ee6069f6-13ef-4896-8ffc-5302b1b17539}')
    @winrt_commethod(6)
    def get_AddedDates(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(7)
    def get_RemovedDates(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Foundation.DateTime]: ...
    AddedDates = property(get_AddedDates, None)
    RemovedDates = property(get_RemovedDates, None)
class ICalendarViewStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarViewStatics'
    _iid_ = Guid('{7260f1c4-2f5d-41bd-99bb-4571b20b79a8}')
    @winrt_commethod(6)
    def get_CalendarIdentifierProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_DayOfWeekFormatProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsGroupLabelVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_DisplayModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FirstDayOfWeekProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsOutOfScopeEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IsTodayHighlightedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_MaxDateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_MinDateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_NumberOfWeeksInViewProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_SelectedDatesProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_SelectionModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_TemplateSettingsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_FocusBorderBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_SelectedHoverBorderBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_SelectedPressedBorderBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_SelectedBorderBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_HoverBorderBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_PressedBorderBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_CalendarItemBorderBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def get_OutOfScopeBackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(27)
    def get_CalendarItemBackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(28)
    def get_PressedForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(29)
    def get_TodayForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(30)
    def get_BlackoutForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(31)
    def get_SelectedForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(32)
    def get_OutOfScopeForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(33)
    def get_CalendarItemForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(34)
    def get_DayItemFontFamilyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(35)
    def get_DayItemFontSizeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(36)
    def get_DayItemFontStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(37)
    def get_DayItemFontWeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(38)
    def get_TodayFontWeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(39)
    def get_FirstOfMonthLabelFontFamilyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(40)
    def get_FirstOfMonthLabelFontSizeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(41)
    def get_FirstOfMonthLabelFontStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(42)
    def get_FirstOfMonthLabelFontWeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(43)
    def get_MonthYearItemFontFamilyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(44)
    def get_MonthYearItemFontSizeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(45)
    def get_MonthYearItemFontStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(46)
    def get_MonthYearItemFontWeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(47)
    def get_FirstOfYearDecadeLabelFontFamilyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(48)
    def get_FirstOfYearDecadeLabelFontSizeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(49)
    def get_FirstOfYearDecadeLabelFontStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(50)
    def get_FirstOfYearDecadeLabelFontWeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(51)
    def get_HorizontalDayItemAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(52)
    def get_VerticalDayItemAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(53)
    def get_HorizontalFirstOfMonthLabelAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(54)
    def get_VerticalFirstOfMonthLabelAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(55)
    def get_CalendarItemBorderThicknessProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(56)
    def get_CalendarViewDayItemStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BlackoutForegroundProperty = property(get_BlackoutForegroundProperty, None)
    CalendarIdentifierProperty = property(get_CalendarIdentifierProperty, None)
    CalendarItemBackgroundProperty = property(get_CalendarItemBackgroundProperty, None)
    CalendarItemBorderBrushProperty = property(get_CalendarItemBorderBrushProperty, None)
    CalendarItemBorderThicknessProperty = property(get_CalendarItemBorderThicknessProperty, None)
    CalendarItemForegroundProperty = property(get_CalendarItemForegroundProperty, None)
    CalendarViewDayItemStyleProperty = property(get_CalendarViewDayItemStyleProperty, None)
    DayItemFontFamilyProperty = property(get_DayItemFontFamilyProperty, None)
    DayItemFontSizeProperty = property(get_DayItemFontSizeProperty, None)
    DayItemFontStyleProperty = property(get_DayItemFontStyleProperty, None)
    DayItemFontWeightProperty = property(get_DayItemFontWeightProperty, None)
    DayOfWeekFormatProperty = property(get_DayOfWeekFormatProperty, None)
    DisplayModeProperty = property(get_DisplayModeProperty, None)
    FirstDayOfWeekProperty = property(get_FirstDayOfWeekProperty, None)
    FirstOfMonthLabelFontFamilyProperty = property(get_FirstOfMonthLabelFontFamilyProperty, None)
    FirstOfMonthLabelFontSizeProperty = property(get_FirstOfMonthLabelFontSizeProperty, None)
    FirstOfMonthLabelFontStyleProperty = property(get_FirstOfMonthLabelFontStyleProperty, None)
    FirstOfMonthLabelFontWeightProperty = property(get_FirstOfMonthLabelFontWeightProperty, None)
    FirstOfYearDecadeLabelFontFamilyProperty = property(get_FirstOfYearDecadeLabelFontFamilyProperty, None)
    FirstOfYearDecadeLabelFontSizeProperty = property(get_FirstOfYearDecadeLabelFontSizeProperty, None)
    FirstOfYearDecadeLabelFontStyleProperty = property(get_FirstOfYearDecadeLabelFontStyleProperty, None)
    FirstOfYearDecadeLabelFontWeightProperty = property(get_FirstOfYearDecadeLabelFontWeightProperty, None)
    FocusBorderBrushProperty = property(get_FocusBorderBrushProperty, None)
    HorizontalDayItemAlignmentProperty = property(get_HorizontalDayItemAlignmentProperty, None)
    HorizontalFirstOfMonthLabelAlignmentProperty = property(get_HorizontalFirstOfMonthLabelAlignmentProperty, None)
    HoverBorderBrushProperty = property(get_HoverBorderBrushProperty, None)
    IsGroupLabelVisibleProperty = property(get_IsGroupLabelVisibleProperty, None)
    IsOutOfScopeEnabledProperty = property(get_IsOutOfScopeEnabledProperty, None)
    IsTodayHighlightedProperty = property(get_IsTodayHighlightedProperty, None)
    MaxDateProperty = property(get_MaxDateProperty, None)
    MinDateProperty = property(get_MinDateProperty, None)
    MonthYearItemFontFamilyProperty = property(get_MonthYearItemFontFamilyProperty, None)
    MonthYearItemFontSizeProperty = property(get_MonthYearItemFontSizeProperty, None)
    MonthYearItemFontStyleProperty = property(get_MonthYearItemFontStyleProperty, None)
    MonthYearItemFontWeightProperty = property(get_MonthYearItemFontWeightProperty, None)
    NumberOfWeeksInViewProperty = property(get_NumberOfWeeksInViewProperty, None)
    OutOfScopeBackgroundProperty = property(get_OutOfScopeBackgroundProperty, None)
    OutOfScopeForegroundProperty = property(get_OutOfScopeForegroundProperty, None)
    PressedBorderBrushProperty = property(get_PressedBorderBrushProperty, None)
    PressedForegroundProperty = property(get_PressedForegroundProperty, None)
    SelectedBorderBrushProperty = property(get_SelectedBorderBrushProperty, None)
    SelectedDatesProperty = property(get_SelectedDatesProperty, None)
    SelectedForegroundProperty = property(get_SelectedForegroundProperty, None)
    SelectedHoverBorderBrushProperty = property(get_SelectedHoverBorderBrushProperty, None)
    SelectedPressedBorderBrushProperty = property(get_SelectedPressedBorderBrushProperty, None)
    SelectionModeProperty = property(get_SelectionModeProperty, None)
    TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
    TodayFontWeightProperty = property(get_TodayFontWeightProperty, None)
    TodayForegroundProperty = property(get_TodayForegroundProperty, None)
    VerticalDayItemAlignmentProperty = property(get_VerticalDayItemAlignmentProperty, None)
    VerticalFirstOfMonthLabelAlignmentProperty = property(get_VerticalFirstOfMonthLabelAlignmentProperty, None)
class ICalendarViewStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICalendarViewStatics2'
    _iid_ = Guid('{f29e5024-b8fb-50c8-8a38-d443abb37009}')
    @winrt_commethod(6)
    def get_SelectedDisabledBorderBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TodaySelectedInnerBorderBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_BlackoutStrikethroughBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_BlackoutBackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_CalendarItemHoverBackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_CalendarItemPressedBackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_CalendarItemDisabledBackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_TodayBackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_TodayBlackoutBackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_TodayHoverBackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_TodayPressedBackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_TodayDisabledBackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_TodayBlackoutForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_SelectedHoverForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_SelectedPressedForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_SelectedDisabledForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_OutOfScopeHoverForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_OutOfScopePressedForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_DisabledForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_DayItemMarginProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def get_MonthYearItemMarginProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(27)
    def get_FirstOfMonthLabelMarginProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(28)
    def get_FirstOfYearDecadeLabelMarginProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(29)
    def get_CalendarItemCornerRadiusProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BlackoutBackgroundProperty = property(get_BlackoutBackgroundProperty, None)
    BlackoutStrikethroughBrushProperty = property(get_BlackoutStrikethroughBrushProperty, None)
    CalendarItemCornerRadiusProperty = property(get_CalendarItemCornerRadiusProperty, None)
    CalendarItemDisabledBackgroundProperty = property(get_CalendarItemDisabledBackgroundProperty, None)
    CalendarItemHoverBackgroundProperty = property(get_CalendarItemHoverBackgroundProperty, None)
    CalendarItemPressedBackgroundProperty = property(get_CalendarItemPressedBackgroundProperty, None)
    DayItemMarginProperty = property(get_DayItemMarginProperty, None)
    DisabledForegroundProperty = property(get_DisabledForegroundProperty, None)
    FirstOfMonthLabelMarginProperty = property(get_FirstOfMonthLabelMarginProperty, None)
    FirstOfYearDecadeLabelMarginProperty = property(get_FirstOfYearDecadeLabelMarginProperty, None)
    MonthYearItemMarginProperty = property(get_MonthYearItemMarginProperty, None)
    OutOfScopeHoverForegroundProperty = property(get_OutOfScopeHoverForegroundProperty, None)
    OutOfScopePressedForegroundProperty = property(get_OutOfScopePressedForegroundProperty, None)
    SelectedDisabledBorderBrushProperty = property(get_SelectedDisabledBorderBrushProperty, None)
    SelectedDisabledForegroundProperty = property(get_SelectedDisabledForegroundProperty, None)
    SelectedHoverForegroundProperty = property(get_SelectedHoverForegroundProperty, None)
    SelectedPressedForegroundProperty = property(get_SelectedPressedForegroundProperty, None)
    TodayBackgroundProperty = property(get_TodayBackgroundProperty, None)
    TodayBlackoutBackgroundProperty = property(get_TodayBlackoutBackgroundProperty, None)
    TodayBlackoutForegroundProperty = property(get_TodayBlackoutForegroundProperty, None)
    TodayDisabledBackgroundProperty = property(get_TodayDisabledBackgroundProperty, None)
    TodayHoverBackgroundProperty = property(get_TodayHoverBackgroundProperty, None)
    TodayPressedBackgroundProperty = property(get_TodayPressedBackgroundProperty, None)
    TodaySelectedInnerBorderBrushProperty = property(get_TodaySelectedInnerBorderBrushProperty, None)
class ICandidateWindowBoundsChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICandidateWindowBoundsChangedEventArgs'
    _iid_ = Guid('{8a946458-83b0-4c32-9450-5169a5838b55}')
    @winrt_commethod(6)
    def get_Bounds(self) -> win32more.Windows.Foundation.Rect: ...
    Bounds = property(get_Bounds, None)
class ICanvas(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICanvas'
    _iid_ = Guid('{79190e19-cd38-4823-aeae-64a77132f519}')
class ICanvasFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICanvasFactory'
    _iid_ = Guid('{1b328bd1-b400-4a8e-943b-5ad2c45be0df}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Canvas: ...
class ICanvasStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICanvasStatics'
    _iid_ = Guid('{40ce5c46-2962-446f-aafb-4cdc486939c9}')
    @winrt_commethod(6)
    def get_LeftProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def GetLeft(self, element: win32more.Windows.UI.Xaml.UIElement) -> Double: ...
    @winrt_commethod(8)
    def SetLeft(self, element: win32more.Windows.UI.Xaml.UIElement, length: Double) -> Void: ...
    @winrt_commethod(9)
    def get_TopProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def GetTop(self, element: win32more.Windows.UI.Xaml.UIElement) -> Double: ...
    @winrt_commethod(11)
    def SetTop(self, element: win32more.Windows.UI.Xaml.UIElement, length: Double) -> Void: ...
    @winrt_commethod(12)
    def get_ZIndexProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def GetZIndex(self, element: win32more.Windows.UI.Xaml.UIElement) -> Int32: ...
    @winrt_commethod(14)
    def SetZIndex(self, element: win32more.Windows.UI.Xaml.UIElement, value: Int32) -> Void: ...
    LeftProperty = property(get_LeftProperty, None)
    TopProperty = property(get_TopProperty, None)
    ZIndexProperty = property(get_ZIndexProperty, None)
class ICaptureElement(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICaptureElement'
    _iid_ = Guid('{31a5c0e7-f307-4d4a-b626-e978863f5b74}')
    @winrt_commethod(6)
    def get_Source(self) -> win32more.Windows.Media.Capture.MediaCapture: ...
    @winrt_commethod(7)
    def put_Source(self, value: win32more.Windows.Media.Capture.MediaCapture) -> Void: ...
    @winrt_commethod(8)
    def get_Stretch(self) -> win32more.Windows.UI.Xaml.Media.Stretch: ...
    @winrt_commethod(9)
    def put_Stretch(self, value: win32more.Windows.UI.Xaml.Media.Stretch) -> Void: ...
    Source = property(get_Source, put_Source)
    Stretch = property(get_Stretch, put_Stretch)
class ICaptureElementStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICaptureElementStatics'
    _iid_ = Guid('{1e438ded-7da6-409e-806e-305ae4ad9b3f}')
    @winrt_commethod(6)
    def get_SourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_StretchProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SourceProperty = property(get_SourceProperty, None)
    StretchProperty = property(get_StretchProperty, None)
class ICheckBox(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICheckBox'
    _iid_ = Guid('{2294c894-7e2a-4b70-b088-8f5d814875ba}')
class ICheckBoxFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICheckBoxFactory'
    _iid_ = Guid('{4fa6aabb-3f4b-4301-be07-1172ea61eefb}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.CheckBox: ...
class IChoosingGroupHeaderContainerEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IChoosingGroupHeaderContainerEventArgs'
    _iid_ = Guid('{67db44d6-d201-4d72-beac-5e8e58afd8c7}')
    @winrt_commethod(6)
    def get_GroupHeaderContainer(self) -> win32more.Windows.UI.Xaml.Controls.ListViewBaseHeaderItem: ...
    @winrt_commethod(7)
    def put_GroupHeaderContainer(self, value: win32more.Windows.UI.Xaml.Controls.ListViewBaseHeaderItem) -> Void: ...
    @winrt_commethod(8)
    def get_GroupIndex(self) -> Int32: ...
    @winrt_commethod(9)
    def get_Group(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    Group = property(get_Group, None)
    GroupHeaderContainer = property(get_GroupHeaderContainer, put_GroupHeaderContainer)
    GroupIndex = property(get_GroupIndex, None)
class IChoosingItemContainerEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IChoosingItemContainerEventArgs'
    _iid_ = Guid('{9bb43bce-ae67-4a80-8363-e3fe1b244f2c}')
    @winrt_commethod(6)
    def get_ItemIndex(self) -> Int32: ...
    @winrt_commethod(7)
    def get_Item(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(8)
    def get_ItemContainer(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.SelectorItem: ...
    @winrt_commethod(9)
    def put_ItemContainer(self, value: win32more.Windows.UI.Xaml.Controls.Primitives.SelectorItem) -> Void: ...
    @winrt_commethod(10)
    def get_IsContainerPrepared(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsContainerPrepared(self, value: Boolean) -> Void: ...
    IsContainerPrepared = property(get_IsContainerPrepared, put_IsContainerPrepared)
    Item = property(get_Item, None)
    ItemContainer = property(get_ItemContainer, put_ItemContainer)
    ItemIndex = property(get_ItemIndex, None)
class ICleanUpVirtualizedItemEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICleanUpVirtualizedItemEventArgs'
    _iid_ = Guid('{ea05cce9-937c-4120-8406-792185784338}')
    @winrt_commethod(6)
    def get_Value(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def get_UIElement(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(8)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    UIElement = property(get_UIElement, None)
    Value = property(get_Value, None)
class IColorChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IColorChangedEventArgs'
    _iid_ = Guid('{34f7201f-aad0-4c3a-b97b-2abf36455539}')
    @winrt_commethod(6)
    def get_OldColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(7)
    def get_NewColor(self) -> win32more.Windows.UI.Color: ...
    NewColor = property(get_NewColor, None)
    OldColor = property(get_OldColor, None)
class IColorPicker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IColorPicker'
    _iid_ = Guid('{6232e371-5c64-43cb-8b35-7f82dde36740}')
    @winrt_commethod(6)
    def get_Color(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(7)
    def put_Color(self, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(8)
    def get_PreviousColor(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_commethod(9)
    def put_PreviousColor(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_commethod(10)
    def get_IsAlphaEnabled(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsAlphaEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_IsColorSpectrumVisible(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsColorSpectrumVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_IsColorPreviewVisible(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsColorPreviewVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_IsColorSliderVisible(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsColorSliderVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_IsAlphaSliderVisible(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_IsAlphaSliderVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_IsMoreButtonVisible(self) -> Boolean: ...
    @winrt_commethod(21)
    def put_IsMoreButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(22)
    def get_IsColorChannelTextInputVisible(self) -> Boolean: ...
    @winrt_commethod(23)
    def put_IsColorChannelTextInputVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(24)
    def get_IsAlphaTextInputVisible(self) -> Boolean: ...
    @winrt_commethod(25)
    def put_IsAlphaTextInputVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(26)
    def get_IsHexInputVisible(self) -> Boolean: ...
    @winrt_commethod(27)
    def put_IsHexInputVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(28)
    def get_MinHue(self) -> Int32: ...
    @winrt_commethod(29)
    def put_MinHue(self, value: Int32) -> Void: ...
    @winrt_commethod(30)
    def get_MaxHue(self) -> Int32: ...
    @winrt_commethod(31)
    def put_MaxHue(self, value: Int32) -> Void: ...
    @winrt_commethod(32)
    def get_MinSaturation(self) -> Int32: ...
    @winrt_commethod(33)
    def put_MinSaturation(self, value: Int32) -> Void: ...
    @winrt_commethod(34)
    def get_MaxSaturation(self) -> Int32: ...
    @winrt_commethod(35)
    def put_MaxSaturation(self, value: Int32) -> Void: ...
    @winrt_commethod(36)
    def get_MinValue(self) -> Int32: ...
    @winrt_commethod(37)
    def put_MinValue(self, value: Int32) -> Void: ...
    @winrt_commethod(38)
    def get_MaxValue(self) -> Int32: ...
    @winrt_commethod(39)
    def put_MaxValue(self, value: Int32) -> Void: ...
    @winrt_commethod(40)
    def get_ColorSpectrumShape(self) -> win32more.Windows.UI.Xaml.Controls.ColorSpectrumShape: ...
    @winrt_commethod(41)
    def put_ColorSpectrumShape(self, value: win32more.Windows.UI.Xaml.Controls.ColorSpectrumShape) -> Void: ...
    @winrt_commethod(42)
    def get_ColorSpectrumComponents(self) -> win32more.Windows.UI.Xaml.Controls.ColorSpectrumComponents: ...
    @winrt_commethod(43)
    def put_ColorSpectrumComponents(self, value: win32more.Windows.UI.Xaml.Controls.ColorSpectrumComponents) -> Void: ...
    @winrt_commethod(44)
    def add_ColorChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ColorPicker, win32more.Windows.UI.Xaml.Controls.ColorChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(45)
    def remove_ColorChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Color = property(get_Color, put_Color)
    ColorSpectrumComponents = property(get_ColorSpectrumComponents, put_ColorSpectrumComponents)
    ColorSpectrumShape = property(get_ColorSpectrumShape, put_ColorSpectrumShape)
    IsAlphaEnabled = property(get_IsAlphaEnabled, put_IsAlphaEnabled)
    IsAlphaSliderVisible = property(get_IsAlphaSliderVisible, put_IsAlphaSliderVisible)
    IsAlphaTextInputVisible = property(get_IsAlphaTextInputVisible, put_IsAlphaTextInputVisible)
    IsColorChannelTextInputVisible = property(get_IsColorChannelTextInputVisible, put_IsColorChannelTextInputVisible)
    IsColorPreviewVisible = property(get_IsColorPreviewVisible, put_IsColorPreviewVisible)
    IsColorSliderVisible = property(get_IsColorSliderVisible, put_IsColorSliderVisible)
    IsColorSpectrumVisible = property(get_IsColorSpectrumVisible, put_IsColorSpectrumVisible)
    IsHexInputVisible = property(get_IsHexInputVisible, put_IsHexInputVisible)
    IsMoreButtonVisible = property(get_IsMoreButtonVisible, put_IsMoreButtonVisible)
    MaxHue = property(get_MaxHue, put_MaxHue)
    MaxSaturation = property(get_MaxSaturation, put_MaxSaturation)
    MaxValue = property(get_MaxValue, put_MaxValue)
    MinHue = property(get_MinHue, put_MinHue)
    MinSaturation = property(get_MinSaturation, put_MinSaturation)
    MinValue = property(get_MinValue, put_MinValue)
    PreviousColor = property(get_PreviousColor, put_PreviousColor)
    ColorChanged = event()
class IColorPickerFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IColorPickerFactory'
    _iid_ = Guid('{abae07ff-aecf-481d-9204-201c3894cd1b}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ColorPicker: ...
class IColorPickerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IColorPickerStatics'
    _iid_ = Guid('{67ca9be7-1574-451a-b6df-fe57d9d07b46}')
    @winrt_commethod(6)
    def get_ColorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PreviousColorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsAlphaEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_IsColorSpectrumVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsColorPreviewVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsColorSliderVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IsAlphaSliderVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_IsMoreButtonVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_IsColorChannelTextInputVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_IsAlphaTextInputVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_IsHexInputVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_MinHueProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_MaxHueProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_MinSaturationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_MaxSaturationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_MinValueProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_MaxValueProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_ColorSpectrumShapeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_ColorSpectrumComponentsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ColorProperty = property(get_ColorProperty, None)
    ColorSpectrumComponentsProperty = property(get_ColorSpectrumComponentsProperty, None)
    ColorSpectrumShapeProperty = property(get_ColorSpectrumShapeProperty, None)
    IsAlphaEnabledProperty = property(get_IsAlphaEnabledProperty, None)
    IsAlphaSliderVisibleProperty = property(get_IsAlphaSliderVisibleProperty, None)
    IsAlphaTextInputVisibleProperty = property(get_IsAlphaTextInputVisibleProperty, None)
    IsColorChannelTextInputVisibleProperty = property(get_IsColorChannelTextInputVisibleProperty, None)
    IsColorPreviewVisibleProperty = property(get_IsColorPreviewVisibleProperty, None)
    IsColorSliderVisibleProperty = property(get_IsColorSliderVisibleProperty, None)
    IsColorSpectrumVisibleProperty = property(get_IsColorSpectrumVisibleProperty, None)
    IsHexInputVisibleProperty = property(get_IsHexInputVisibleProperty, None)
    IsMoreButtonVisibleProperty = property(get_IsMoreButtonVisibleProperty, None)
    MaxHueProperty = property(get_MaxHueProperty, None)
    MaxSaturationProperty = property(get_MaxSaturationProperty, None)
    MaxValueProperty = property(get_MaxValueProperty, None)
    MinHueProperty = property(get_MinHueProperty, None)
    MinSaturationProperty = property(get_MinSaturationProperty, None)
    MinValueProperty = property(get_MinValueProperty, None)
    PreviousColorProperty = property(get_PreviousColorProperty, None)
class IColumnDefinition(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IColumnDefinition'
    _iid_ = Guid('{f7f1b229-f024-467f-970a-7e705615db7b}')
    @winrt_commethod(6)
    def get_Width(self) -> win32more.Windows.UI.Xaml.GridLength: ...
    @winrt_commethod(7)
    def put_Width(self, value: win32more.Windows.UI.Xaml.GridLength) -> Void: ...
    @winrt_commethod(8)
    def get_MaxWidth(self) -> Double: ...
    @winrt_commethod(9)
    def put_MaxWidth(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_MinWidth(self) -> Double: ...
    @winrt_commethod(11)
    def put_MinWidth(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_ActualWidth(self) -> Double: ...
    ActualWidth = property(get_ActualWidth, None)
    MaxWidth = property(get_MaxWidth, put_MaxWidth)
    MinWidth = property(get_MinWidth, put_MinWidth)
    Width = property(get_Width, put_Width)
class IColumnDefinitionStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IColumnDefinitionStatics'
    _iid_ = Guid('{06b0d728-d044-40c6-942e-ae60eac74851}')
    @winrt_commethod(6)
    def get_WidthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_MaxWidthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_MinWidthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    MaxWidthProperty = property(get_MaxWidthProperty, None)
    MinWidthProperty = property(get_MinWidthProperty, None)
    WidthProperty = property(get_WidthProperty, None)
class IComboBox(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IComboBox'
    _iid_ = Guid('{b9a8d05c-ac97-47f1-a5f4-3f9f4d4b116c}')
    @winrt_commethod(6)
    def get_IsDropDownOpen(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsDropDownOpen(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsEditable(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_IsSelectionBoxHighlighted(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_MaxDropDownHeight(self) -> Double: ...
    @winrt_commethod(11)
    def put_MaxDropDownHeight(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_SelectionBoxItem(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(13)
    def get_SelectionBoxItemTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(14)
    def get_TemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.ComboBoxTemplateSettings: ...
    @winrt_commethod(15)
    def add_DropDownClosed(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(16)
    def remove_DropDownClosed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(17)
    def add_DropDownOpened(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_DropDownOpened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    IsDropDownOpen = property(get_IsDropDownOpen, put_IsDropDownOpen)
    IsEditable = property(get_IsEditable, None)
    IsSelectionBoxHighlighted = property(get_IsSelectionBoxHighlighted, None)
    MaxDropDownHeight = property(get_MaxDropDownHeight, put_MaxDropDownHeight)
    SelectionBoxItem = property(get_SelectionBoxItem, None)
    SelectionBoxItemTemplate = property(get_SelectionBoxItemTemplate, None)
    TemplateSettings = property(get_TemplateSettings, None)
    DropDownClosed = event()
    DropDownOpened = event()
class IComboBox2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IComboBox2'
    _iid_ = Guid('{ea0cbf91-ca36-4fad-972a-2e53a6718b9f}')
    @winrt_commethod(6)
    def get_Header(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_HeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_PlaceholderText(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_PlaceholderText(self, value: WinRT_String) -> Void: ...
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
class IComboBox3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IComboBox3'
    _iid_ = Guid('{52400a63-476c-4bb6-b781-019324d3fed9}')
    @winrt_commethod(6)
    def get_LightDismissOverlayMode(self) -> win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_commethod(7)
    def put_LightDismissOverlayMode(self, value: win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_commethod(8)
    def get_IsTextSearchEnabled(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsTextSearchEnabled(self, value: Boolean) -> Void: ...
    IsTextSearchEnabled = property(get_IsTextSearchEnabled, put_IsTextSearchEnabled)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
class IComboBox4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IComboBox4'
    _iid_ = Guid('{b7974f49-b05c-47f9-9aaf-d6f9187be5fd}')
    @winrt_commethod(6)
    def get_SelectionChangedTrigger(self) -> win32more.Windows.UI.Xaml.Controls.ComboBoxSelectionChangedTrigger: ...
    @winrt_commethod(7)
    def put_SelectionChangedTrigger(self, value: win32more.Windows.UI.Xaml.Controls.ComboBoxSelectionChangedTrigger) -> Void: ...
    SelectionChangedTrigger = property(get_SelectionChangedTrigger, put_SelectionChangedTrigger)
class IComboBox5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IComboBox5'
    _iid_ = Guid('{ab79d646-800a-4a28-969b-34bb8fb458cf}')
    @winrt_commethod(6)
    def get_PlaceholderForeground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(7)
    def put_PlaceholderForeground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    PlaceholderForeground = property(get_PlaceholderForeground, put_PlaceholderForeground)
class IComboBox6(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IComboBox6'
    _iid_ = Guid('{61aad6a5-81fb-5f87-bae3-369fbe2ea1f3}')
    @winrt_commethod(6)
    def put_IsEditable(self, value: Boolean) -> Void: ...
    @winrt_commethod(7)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Text(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_TextBoxStyle(self) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_commethod(10)
    def put_TextBoxStyle(self, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(11)
    def get_Description(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(12)
    def put_Description(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(13)
    def add_TextSubmitted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ComboBox, win32more.Windows.UI.Xaml.Controls.ComboBoxTextSubmittedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(14)
    def remove_TextSubmitted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Description = property(get_Description, put_Description)
    IsEditable = property(None, put_IsEditable)
    Text = property(get_Text, put_Text)
    TextBoxStyle = property(get_TextBoxStyle, put_TextBoxStyle)
    TextSubmitted = event()
class IComboBoxFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IComboBoxFactory'
    _iid_ = Guid('{ac0d0444-a65b-4abd-86df-3016049efedc}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ComboBox: ...
class IComboBoxItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IComboBoxItem'
    _iid_ = Guid('{993fd6d2-2aae-4f3b-b44d-5648f4d06114}')
class IComboBoxItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IComboBoxItemFactory'
    _iid_ = Guid('{8fffe867-d94c-4e87-8fc4-6ebcd63c5ac2}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ComboBoxItem: ...
class IComboBoxOverrides(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IComboBoxOverrides'
    _iid_ = Guid('{4f016541-bcfe-4a22-8932-c914981c2240}')
    @winrt_commethod(6)
    def OnDropDownClosed(self, e: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(7)
    def OnDropDownOpened(self, e: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
class IComboBoxStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IComboBoxStatics'
    _iid_ = Guid('{3e14c9b1-d15b-4dc9-8110-cf3a117b96e7}')
    @winrt_commethod(6)
    def get_IsDropDownOpenProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_MaxDropDownHeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsDropDownOpenProperty = property(get_IsDropDownOpenProperty, None)
    MaxDropDownHeightProperty = property(get_MaxDropDownHeightProperty, None)
class IComboBoxStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IComboBoxStatics2'
    _iid_ = Guid('{93988a11-402c-4b13-96d1-7220266b9220}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PlaceholderTextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
class IComboBoxStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IComboBoxStatics3'
    _iid_ = Guid('{949e140f-ce7f-4e41-bdc5-d1d3388ad0a6}')
    @winrt_commethod(6)
    def get_LightDismissOverlayModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsTextSearchEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsTextSearchEnabledProperty = property(get_IsTextSearchEnabledProperty, None)
    LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
class IComboBoxStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IComboBoxStatics4'
    _iid_ = Guid('{d9f58358-f7b0-46ce-8061-ad83ec2f2dd4}')
    @winrt_commethod(6)
    def get_SelectionChangedTriggerProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SelectionChangedTriggerProperty = property(get_SelectionChangedTriggerProperty, None)
class IComboBoxStatics5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IComboBoxStatics5'
    _iid_ = Guid('{b802cef1-a264-444a-9a61-aa8867b7a63c}')
    @winrt_commethod(6)
    def get_PlaceholderForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    PlaceholderForegroundProperty = property(get_PlaceholderForegroundProperty, None)
class IComboBoxStatics6(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IComboBoxStatics6'
    _iid_ = Guid('{516c88e0-ec6b-54ac-8c57-5ec080ee05c8}')
    @winrt_commethod(6)
    def get_IsEditableProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_TextBoxStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_DescriptionProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DescriptionProperty = property(get_DescriptionProperty, None)
    IsEditableProperty = property(get_IsEditableProperty, None)
    TextBoxStyleProperty = property(get_TextBoxStyleProperty, None)
    TextProperty = property(get_TextProperty, None)
class IComboBoxTextSubmittedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IComboBoxTextSubmittedEventArgs'
    _iid_ = Guid('{cb698cbb-6879-558e-af82-df1d08f62afa}')
    @winrt_commethod(6)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_Handled(self, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
    Text = property(get_Text, None)
class ICommandBar(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICommandBar'
    _iid_ = Guid('{98bc4280-4a3d-4cee-bd07-22ce94c5af76}')
    @winrt_commethod(6)
    def get_PrimaryCommands(self) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Windows.UI.Xaml.Controls.ICommandBarElement]: ...
    @winrt_commethod(7)
    def get_SecondaryCommands(self) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Windows.UI.Xaml.Controls.ICommandBarElement]: ...
    PrimaryCommands = property(get_PrimaryCommands, None)
    SecondaryCommands = property(get_SecondaryCommands, None)
class ICommandBar2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICommandBar2'
    _iid_ = Guid('{57662f58-5b32-475d-be64-4ca36e7b97d4}')
    @winrt_commethod(6)
    def get_CommandBarOverflowPresenterStyle(self) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_commethod(7)
    def put_CommandBarOverflowPresenterStyle(self, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(8)
    def get_CommandBarTemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.CommandBarTemplateSettings: ...
    CommandBarOverflowPresenterStyle = property(get_CommandBarOverflowPresenterStyle, put_CommandBarOverflowPresenterStyle)
    CommandBarTemplateSettings = property(get_CommandBarTemplateSettings, None)
class ICommandBar3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICommandBar3'
    _iid_ = Guid('{40ebbc23-2a79-48b3-9a67-649b852d8589}')
    @winrt_commethod(6)
    def get_DefaultLabelPosition(self) -> win32more.Windows.UI.Xaml.Controls.CommandBarDefaultLabelPosition: ...
    @winrt_commethod(7)
    def put_DefaultLabelPosition(self, value: win32more.Windows.UI.Xaml.Controls.CommandBarDefaultLabelPosition) -> Void: ...
    @winrt_commethod(8)
    def get_OverflowButtonVisibility(self) -> win32more.Windows.UI.Xaml.Controls.CommandBarOverflowButtonVisibility: ...
    @winrt_commethod(9)
    def put_OverflowButtonVisibility(self, value: win32more.Windows.UI.Xaml.Controls.CommandBarOverflowButtonVisibility) -> Void: ...
    @winrt_commethod(10)
    def get_IsDynamicOverflowEnabled(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsDynamicOverflowEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def add_DynamicOverflowItemsChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.CommandBar, win32more.Windows.UI.Xaml.Controls.DynamicOverflowItemsChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_DynamicOverflowItemsChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    DefaultLabelPosition = property(get_DefaultLabelPosition, put_DefaultLabelPosition)
    IsDynamicOverflowEnabled = property(get_IsDynamicOverflowEnabled, put_IsDynamicOverflowEnabled)
    OverflowButtonVisibility = property(get_OverflowButtonVisibility, put_OverflowButtonVisibility)
    DynamicOverflowItemsChanging = event()
class ICommandBarElement(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICommandBarElement'
    _iid_ = Guid('{67918e1b-f2d5-44d1-8b84-92b87f80a350}')
    @winrt_commethod(6)
    def get_IsCompact(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsCompact(self, value: Boolean) -> Void: ...
    IsCompact = property(get_IsCompact, put_IsCompact)
class ICommandBarElement2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICommandBarElement2'
    _iid_ = Guid('{a9bf1236-4402-4688-b987-9d2b9b7bf2bd}')
    @winrt_commethod(6)
    def get_IsInOverflow(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_DynamicOverflowOrder(self) -> Int32: ...
    @winrt_commethod(8)
    def put_DynamicOverflowOrder(self, value: Int32) -> Void: ...
    DynamicOverflowOrder = property(get_DynamicOverflowOrder, put_DynamicOverflowOrder)
    IsInOverflow = property(get_IsInOverflow, None)
class ICommandBarFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICommandBarFactory'
    _iid_ = Guid('{67bdeb44-20e1-4177-ad44-f617b374e8e8}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.CommandBar: ...
class ICommandBarFlyout(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICommandBarFlyout'
    _iid_ = Guid('{fecd2c4d-f16a-58cd-8aca-db0f046f25c3}')
    @winrt_commethod(6)
    def get_PrimaryCommands(self) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Windows.UI.Xaml.Controls.ICommandBarElement]: ...
    @winrt_commethod(7)
    def get_SecondaryCommands(self) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Windows.UI.Xaml.Controls.ICommandBarElement]: ...
    PrimaryCommands = property(get_PrimaryCommands, None)
    SecondaryCommands = property(get_SecondaryCommands, None)
class ICommandBarFlyoutFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICommandBarFlyoutFactory'
    _iid_ = Guid('{dd6441b3-6df1-593d-b80c-daf5c1daee41}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.CommandBarFlyout: ...
class ICommandBarOverflowPresenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICommandBarOverflowPresenter'
    _iid_ = Guid('{6e7a9427-58ef-4366-a017-18c193d56b14}')
class ICommandBarOverflowPresenterFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICommandBarOverflowPresenterFactory'
    _iid_ = Guid('{8323f774-5aaa-4049-b78f-218c6a19c37e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.CommandBarOverflowPresenter: ...
class ICommandBarStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICommandBarStatics'
    _iid_ = Guid('{5bd981ea-e278-409c-b522-f946ca253b44}')
    @winrt_commethod(6)
    def get_PrimaryCommandsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_SecondaryCommandsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    PrimaryCommandsProperty = property(get_PrimaryCommandsProperty, None)
    SecondaryCommandsProperty = property(get_SecondaryCommandsProperty, None)
class ICommandBarStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICommandBarStatics2'
    _iid_ = Guid('{3d9ec8e3-51a9-4e34-956c-7081d06f26f8}')
    @winrt_commethod(6)
    def get_CommandBarOverflowPresenterStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CommandBarOverflowPresenterStyleProperty = property(get_CommandBarOverflowPresenterStyleProperty, None)
class ICommandBarStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ICommandBarStatics3'
    _iid_ = Guid('{b45a24a4-8af1-4843-b319-e03fc45ab726}')
    @winrt_commethod(6)
    def get_DefaultLabelPositionProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_OverflowButtonVisibilityProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsDynamicOverflowEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DefaultLabelPositionProperty = property(get_DefaultLabelPositionProperty, None)
    IsDynamicOverflowEnabledProperty = property(get_IsDynamicOverflowEnabledProperty, None)
    OverflowButtonVisibilityProperty = property(get_OverflowButtonVisibilityProperty, None)
class IContainerContentChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContainerContentChangingEventArgs'
    _iid_ = Guid('{07deeaa7-018f-4dda-b399-fd4e13a31bea}')
    @winrt_commethod(6)
    def get_ItemContainer(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.SelectorItem: ...
    @winrt_commethod(7)
    def get_InRecycleQueue(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_ItemIndex(self) -> Int32: ...
    @winrt_commethod(9)
    def get_Item(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(10)
    def get_Phase(self) -> UInt32: ...
    @winrt_commethod(11)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(12)
    def put_Handled(self, value: Boolean) -> Void: ...
    @winrt_commethod(13)
    def RegisterUpdateCallback(self, callback: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ListViewBase, win32more.Windows.UI.Xaml.Controls.ContainerContentChangingEventArgs]) -> Void: ...
    @winrt_commethod(14)
    def RegisterUpdateCallbackWithPhase(self, callbackPhase: UInt32, callback: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ListViewBase, win32more.Windows.UI.Xaml.Controls.ContainerContentChangingEventArgs]) -> Void: ...
    Handled = property(get_Handled, put_Handled)
    InRecycleQueue = property(get_InRecycleQueue, None)
    Item = property(get_Item, None)
    ItemContainer = property(get_ItemContainer, None)
    ItemIndex = property(get_ItemIndex, None)
    Phase = property(get_Phase, None)
class IContentControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentControl'
    _iid_ = Guid('{a26dd1dc-cd44-435c-be94-01d6241c231c}')
    @winrt_commethod(6)
    def get_Content(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Content(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_ContentTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_ContentTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_ContentTemplateSelector(self) -> win32more.Windows.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_commethod(11)
    def put_ContentTemplateSelector(self, value: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_commethod(12)
    def get_ContentTransitions(self) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(13)
    def put_ContentTransitions(self, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    Content = property(get_Content, put_Content)
    ContentTemplate = property(get_ContentTemplate, put_ContentTemplate)
    ContentTemplateSelector = property(get_ContentTemplateSelector, put_ContentTemplateSelector)
    ContentTransitions = property(get_ContentTransitions, put_ContentTransitions)
class IContentControl2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentControl2'
    _iid_ = Guid('{652c208c-8ccf-4399-bd3e-5a015aa1bc03}')
    @winrt_commethod(6)
    def get_ContentTemplateRoot(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    ContentTemplateRoot = property(get_ContentTemplateRoot, None)
class IContentControlFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentControlFactory'
    _iid_ = Guid('{ab017b19-196e-4ed5-a27f-55c58fb1673f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ContentControl: ...
class IContentControlOverrides(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentControlOverrides'
    _iid_ = Guid('{5f4c0b10-e38e-4b5d-be1a-5ed04246a635}')
    @winrt_commethod(6)
    def OnContentChanged(self, oldContent: win32more.Windows.Win32.System.WinRT.IInspectable, newContent: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(7)
    def OnContentTemplateChanged(self, oldContentTemplate: win32more.Windows.UI.Xaml.DataTemplate, newContentTemplate: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(8)
    def OnContentTemplateSelectorChanged(self, oldContentTemplateSelector: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector, newContentTemplateSelector: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
class IContentControlStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentControlStatics'
    _iid_ = Guid('{116982a4-5cf5-4c05-a53f-15e4876c85ec}')
    @winrt_commethod(6)
    def get_ContentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ContentTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ContentTemplateSelectorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_ContentTransitionsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ContentProperty = property(get_ContentProperty, None)
    ContentTemplateProperty = property(get_ContentTemplateProperty, None)
    ContentTemplateSelectorProperty = property(get_ContentTemplateSelectorProperty, None)
    ContentTransitionsProperty = property(get_ContentTransitionsProperty, None)
class IContentDialog(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentDialog'
    _iid_ = Guid('{38dc4404-d24e-40d8-9415-349464c1afdc}')
    @winrt_commethod(6)
    def get_Title(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Title(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_TitleTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_TitleTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_FullSizeDesired(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_FullSizeDesired(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_PrimaryButtonText(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_PrimaryButtonText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_SecondaryButtonText(self) -> WinRT_String: ...
    @winrt_commethod(15)
    def put_SecondaryButtonText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(16)
    def get_PrimaryButtonCommand(self) -> win32more.Windows.UI.Xaml.Input.ICommand: ...
    @winrt_commethod(17)
    def put_PrimaryButtonCommand(self, value: win32more.Windows.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_commethod(18)
    def get_SecondaryButtonCommand(self) -> win32more.Windows.UI.Xaml.Input.ICommand: ...
    @winrt_commethod(19)
    def put_SecondaryButtonCommand(self, value: win32more.Windows.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_commethod(20)
    def get_PrimaryButtonCommandParameter(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(21)
    def put_PrimaryButtonCommandParameter(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(22)
    def get_SecondaryButtonCommandParameter(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(23)
    def put_SecondaryButtonCommandParameter(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(24)
    def get_IsPrimaryButtonEnabled(self) -> Boolean: ...
    @winrt_commethod(25)
    def put_IsPrimaryButtonEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(26)
    def get_IsSecondaryButtonEnabled(self) -> Boolean: ...
    @winrt_commethod(27)
    def put_IsSecondaryButtonEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(28)
    def add_Closing(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ContentDialog, win32more.Windows.UI.Xaml.Controls.ContentDialogClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(29)
    def remove_Closing(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(30)
    def add_Closed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ContentDialog, win32more.Windows.UI.Xaml.Controls.ContentDialogClosedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(31)
    def remove_Closed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(32)
    def add_Opened(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ContentDialog, win32more.Windows.UI.Xaml.Controls.ContentDialogOpenedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(33)
    def remove_Opened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(34)
    def add_PrimaryButtonClick(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ContentDialog, win32more.Windows.UI.Xaml.Controls.ContentDialogButtonClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(35)
    def remove_PrimaryButtonClick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(36)
    def add_SecondaryButtonClick(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ContentDialog, win32more.Windows.UI.Xaml.Controls.ContentDialogButtonClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(37)
    def remove_SecondaryButtonClick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(38)
    def Hide(self) -> Void: ...
    @winrt_commethod(39)
    def ShowAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.UI.Xaml.Controls.ContentDialogResult]: ...
    FullSizeDesired = property(get_FullSizeDesired, put_FullSizeDesired)
    IsPrimaryButtonEnabled = property(get_IsPrimaryButtonEnabled, put_IsPrimaryButtonEnabled)
    IsSecondaryButtonEnabled = property(get_IsSecondaryButtonEnabled, put_IsSecondaryButtonEnabled)
    PrimaryButtonCommand = property(get_PrimaryButtonCommand, put_PrimaryButtonCommand)
    PrimaryButtonCommandParameter = property(get_PrimaryButtonCommandParameter, put_PrimaryButtonCommandParameter)
    PrimaryButtonText = property(get_PrimaryButtonText, put_PrimaryButtonText)
    SecondaryButtonCommand = property(get_SecondaryButtonCommand, put_SecondaryButtonCommand)
    SecondaryButtonCommandParameter = property(get_SecondaryButtonCommandParameter, put_SecondaryButtonCommandParameter)
    SecondaryButtonText = property(get_SecondaryButtonText, put_SecondaryButtonText)
    Title = property(get_Title, put_Title)
    TitleTemplate = property(get_TitleTemplate, put_TitleTemplate)
    Closing = event()
    Closed = event()
    Opened = event()
    PrimaryButtonClick = event()
    SecondaryButtonClick = event()
class IContentDialog2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentDialog2'
    _iid_ = Guid('{2f93eb45-ee43-4303-9b38-3fe1a111ecbf}')
    @winrt_commethod(6)
    def get_CloseButtonText(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_CloseButtonText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_CloseButtonCommand(self) -> win32more.Windows.UI.Xaml.Input.ICommand: ...
    @winrt_commethod(9)
    def put_CloseButtonCommand(self, value: win32more.Windows.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_commethod(10)
    def get_CloseButtonCommandParameter(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(11)
    def put_CloseButtonCommandParameter(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(12)
    def get_PrimaryButtonStyle(self) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_commethod(13)
    def put_PrimaryButtonStyle(self, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(14)
    def get_SecondaryButtonStyle(self) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_commethod(15)
    def put_SecondaryButtonStyle(self, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(16)
    def get_CloseButtonStyle(self) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_commethod(17)
    def put_CloseButtonStyle(self, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(18)
    def get_DefaultButton(self) -> win32more.Windows.UI.Xaml.Controls.ContentDialogButton: ...
    @winrt_commethod(19)
    def put_DefaultButton(self, value: win32more.Windows.UI.Xaml.Controls.ContentDialogButton) -> Void: ...
    @winrt_commethod(20)
    def add_CloseButtonClick(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ContentDialog, win32more.Windows.UI.Xaml.Controls.ContentDialogButtonClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_CloseButtonClick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CloseButtonCommand = property(get_CloseButtonCommand, put_CloseButtonCommand)
    CloseButtonCommandParameter = property(get_CloseButtonCommandParameter, put_CloseButtonCommandParameter)
    CloseButtonStyle = property(get_CloseButtonStyle, put_CloseButtonStyle)
    CloseButtonText = property(get_CloseButtonText, put_CloseButtonText)
    DefaultButton = property(get_DefaultButton, put_DefaultButton)
    PrimaryButtonStyle = property(get_PrimaryButtonStyle, put_PrimaryButtonStyle)
    SecondaryButtonStyle = property(get_SecondaryButtonStyle, put_SecondaryButtonStyle)
    CloseButtonClick = event()
class IContentDialog3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentDialog3'
    _iid_ = Guid('{9d9a089e-f954-4ede-b07f-6b069a9c0180}')
    @winrt_commethod(6)
    def ShowAsyncWithPlacement(self, placement: win32more.Windows.UI.Xaml.Controls.ContentDialogPlacement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.UI.Xaml.Controls.ContentDialogResult]: ...
class IContentDialogButtonClickDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentDialogButtonClickDeferral'
    _iid_ = Guid('{bd0d3637-19ce-4946-8e77-bd03fe8ebe03}')
    @winrt_commethod(6)
    def Complete(self) -> Void: ...
class IContentDialogButtonClickEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentDialogButtonClickEventArgs'
    _iid_ = Guid('{5f34c205-8afa-4cf2-8ca0-264d73bed63d}')
    @winrt_commethod(6)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Cancel(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def GetDeferral(self) -> win32more.Windows.UI.Xaml.Controls.ContentDialogButtonClickDeferral: ...
    Cancel = property(get_Cancel, put_Cancel)
class IContentDialogClosedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentDialogClosedEventArgs'
    _iid_ = Guid('{905522ef-2cba-4af8-b666-cc36c22732fb}')
    @winrt_commethod(6)
    def get_Result(self) -> win32more.Windows.UI.Xaml.Controls.ContentDialogResult: ...
    Result = property(get_Result, None)
class IContentDialogClosingDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentDialogClosingDeferral'
    _iid_ = Guid('{215d4d11-7e30-4cb9-a710-5a4f9cca8b42}')
    @winrt_commethod(6)
    def Complete(self) -> Void: ...
class IContentDialogClosingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentDialogClosingEventArgs'
    _iid_ = Guid('{db3c1c34-3bbf-47d4-be4f-c9ec115918b9}')
    @winrt_commethod(6)
    def get_Result(self) -> win32more.Windows.UI.Xaml.Controls.ContentDialogResult: ...
    @winrt_commethod(7)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_Cancel(self, value: Boolean) -> Void: ...
    @winrt_commethod(9)
    def GetDeferral(self) -> win32more.Windows.UI.Xaml.Controls.ContentDialogClosingDeferral: ...
    Cancel = property(get_Cancel, put_Cancel)
    Result = property(get_Result, None)
class IContentDialogFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentDialogFactory'
    _iid_ = Guid('{05557178-9d8e-4315-b37d-680c14012c35}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ContentDialog: ...
class IContentDialogOpenedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentDialogOpenedEventArgs'
    _iid_ = Guid('{0966b315-5f59-4999-9e3e-374c0f174b04}')
class IContentDialogStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentDialogStatics'
    _iid_ = Guid('{23ab47a6-508a-4f33-b786-f2fa96d869af}')
    @winrt_commethod(6)
    def get_TitleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TitleTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_FullSizeDesiredProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PrimaryButtonTextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_SecondaryButtonTextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_PrimaryButtonCommandProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_SecondaryButtonCommandProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_PrimaryButtonCommandParameterProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_SecondaryButtonCommandParameterProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_IsPrimaryButtonEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_IsSecondaryButtonEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    FullSizeDesiredProperty = property(get_FullSizeDesiredProperty, None)
    IsPrimaryButtonEnabledProperty = property(get_IsPrimaryButtonEnabledProperty, None)
    IsSecondaryButtonEnabledProperty = property(get_IsSecondaryButtonEnabledProperty, None)
    PrimaryButtonCommandParameterProperty = property(get_PrimaryButtonCommandParameterProperty, None)
    PrimaryButtonCommandProperty = property(get_PrimaryButtonCommandProperty, None)
    PrimaryButtonTextProperty = property(get_PrimaryButtonTextProperty, None)
    SecondaryButtonCommandParameterProperty = property(get_SecondaryButtonCommandParameterProperty, None)
    SecondaryButtonCommandProperty = property(get_SecondaryButtonCommandProperty, None)
    SecondaryButtonTextProperty = property(get_SecondaryButtonTextProperty, None)
    TitleProperty = property(get_TitleProperty, None)
    TitleTemplateProperty = property(get_TitleTemplateProperty, None)
class IContentDialogStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentDialogStatics2'
    _iid_ = Guid('{329825b2-8fb0-4125-bb07-e79a5a03819f}')
    @winrt_commethod(6)
    def get_CloseButtonTextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CloseButtonCommandProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CloseButtonCommandParameterProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PrimaryButtonStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_SecondaryButtonStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_CloseButtonStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_DefaultButtonProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CloseButtonCommandParameterProperty = property(get_CloseButtonCommandParameterProperty, None)
    CloseButtonCommandProperty = property(get_CloseButtonCommandProperty, None)
    CloseButtonStyleProperty = property(get_CloseButtonStyleProperty, None)
    CloseButtonTextProperty = property(get_CloseButtonTextProperty, None)
    DefaultButtonProperty = property(get_DefaultButtonProperty, None)
    PrimaryButtonStyleProperty = property(get_PrimaryButtonStyleProperty, None)
    SecondaryButtonStyleProperty = property(get_SecondaryButtonStyleProperty, None)
class IContentLinkChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentLinkChangedEventArgs'
    _iid_ = Guid('{64f3f1de-89fb-4b77-8b9b-191b6d19290a}')
    @winrt_commethod(6)
    def get_ChangeKind(self) -> win32more.Windows.UI.Xaml.Controls.ContentLinkChangeKind: ...
    @winrt_commethod(7)
    def get_ContentLinkInfo(self) -> win32more.Windows.UI.Text.ContentLinkInfo: ...
    @winrt_commethod(8)
    def get_TextRange(self) -> win32more.Windows.UI.Xaml.Documents.TextRange: ...
    ChangeKind = property(get_ChangeKind, None)
    ContentLinkInfo = property(get_ContentLinkInfo, None)
    TextRange = property(get_TextRange, None)
class IContentPresenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentPresenter'
    _iid_ = Guid('{79fde5b4-cd37-491c-8845-daf472defff6}')
    @winrt_commethod(6)
    def get_Content(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Content(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_ContentTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_ContentTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_ContentTemplateSelector(self) -> win32more.Windows.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_commethod(11)
    def put_ContentTemplateSelector(self, value: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_commethod(12)
    def get_ContentTransitions(self) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(13)
    def put_ContentTransitions(self, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_commethod(14)
    def get_FontSize(self) -> Double: ...
    @winrt_commethod(15)
    def put_FontSize(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_FontFamily(self) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(17)
    def put_FontFamily(self, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(18)
    def get_FontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(19)
    def put_FontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(20)
    def get_FontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(21)
    def put_FontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(22)
    def get_FontStretch(self) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_commethod(23)
    def put_FontStretch(self, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_commethod(24)
    def get_CharacterSpacing(self) -> Int32: ...
    @winrt_commethod(25)
    def put_CharacterSpacing(self, value: Int32) -> Void: ...
    @winrt_commethod(26)
    def get_Foreground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(27)
    def put_Foreground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    Content = property(get_Content, put_Content)
    ContentTemplate = property(get_ContentTemplate, put_ContentTemplate)
    ContentTemplateSelector = property(get_ContentTemplateSelector, put_ContentTemplateSelector)
    ContentTransitions = property(get_ContentTransitions, put_ContentTransitions)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
class IContentPresenter2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentPresenter2'
    _iid_ = Guid('{5138e958-335d-4210-8bbb-0aa2b4b5c29e}')
    @winrt_commethod(6)
    def get_OpticalMarginAlignment(self) -> win32more.Windows.UI.Xaml.OpticalMarginAlignment: ...
    @winrt_commethod(7)
    def put_OpticalMarginAlignment(self, value: win32more.Windows.UI.Xaml.OpticalMarginAlignment) -> Void: ...
    @winrt_commethod(8)
    def get_TextLineBounds(self) -> win32more.Windows.UI.Xaml.TextLineBounds: ...
    @winrt_commethod(9)
    def put_TextLineBounds(self, value: win32more.Windows.UI.Xaml.TextLineBounds) -> Void: ...
    OpticalMarginAlignment = property(get_OpticalMarginAlignment, put_OpticalMarginAlignment)
    TextLineBounds = property(get_TextLineBounds, put_TextLineBounds)
class IContentPresenter3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentPresenter3'
    _iid_ = Guid('{b038876a-9c4d-4402-ac56-a223487dc6c8}')
    @winrt_commethod(6)
    def get_IsTextScaleFactorEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsTextScaleFactorEnabled(self, value: Boolean) -> Void: ...
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
class IContentPresenter4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentPresenter4'
    _iid_ = Guid('{997b1b17-3bf8-432b-8fd9-68c7bab21f9d}')
    @winrt_commethod(6)
    def get_TextWrapping(self) -> win32more.Windows.UI.Xaml.TextWrapping: ...
    @winrt_commethod(7)
    def put_TextWrapping(self, value: win32more.Windows.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_commethod(8)
    def get_MaxLines(self) -> Int32: ...
    @winrt_commethod(9)
    def put_MaxLines(self, value: Int32) -> Void: ...
    @winrt_commethod(10)
    def get_LineStackingStrategy(self) -> win32more.Windows.UI.Xaml.LineStackingStrategy: ...
    @winrt_commethod(11)
    def put_LineStackingStrategy(self, value: win32more.Windows.UI.Xaml.LineStackingStrategy) -> Void: ...
    @winrt_commethod(12)
    def get_LineHeight(self) -> Double: ...
    @winrt_commethod(13)
    def put_LineHeight(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_BorderBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(15)
    def put_BorderBrush(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(16)
    def get_BorderThickness(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(17)
    def put_BorderThickness(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(18)
    def get_CornerRadius(self) -> win32more.Windows.UI.Xaml.CornerRadius: ...
    @winrt_commethod(19)
    def put_CornerRadius(self, value: win32more.Windows.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_commethod(20)
    def get_Padding(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(21)
    def put_Padding(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(22)
    def get_Background(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(23)
    def put_Background(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(24)
    def get_HorizontalContentAlignment(self) -> win32more.Windows.UI.Xaml.HorizontalAlignment: ...
    @winrt_commethod(25)
    def put_HorizontalContentAlignment(self, value: win32more.Windows.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_commethod(26)
    def get_VerticalContentAlignment(self) -> win32more.Windows.UI.Xaml.VerticalAlignment: ...
    @winrt_commethod(27)
    def put_VerticalContentAlignment(self, value: win32more.Windows.UI.Xaml.VerticalAlignment) -> Void: ...
    Background = property(get_Background, put_Background)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    HorizontalContentAlignment = property(get_HorizontalContentAlignment, put_HorizontalContentAlignment)
    LineHeight = property(get_LineHeight, put_LineHeight)
    LineStackingStrategy = property(get_LineStackingStrategy, put_LineStackingStrategy)
    MaxLines = property(get_MaxLines, put_MaxLines)
    Padding = property(get_Padding, put_Padding)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    VerticalContentAlignment = property(get_VerticalContentAlignment, put_VerticalContentAlignment)
class IContentPresenter5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentPresenter5'
    _iid_ = Guid('{d248970c-b785-5e7f-9c11-8a6cd3d5929b}')
    @winrt_commethod(6)
    def get_BackgroundTransition(self) -> win32more.Windows.UI.Xaml.BrushTransition: ...
    @winrt_commethod(7)
    def put_BackgroundTransition(self, value: win32more.Windows.UI.Xaml.BrushTransition) -> Void: ...
    @winrt_commethod(8)
    def get_BackgroundSizing(self) -> win32more.Windows.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_commethod(9)
    def put_BackgroundSizing(self, value: win32more.Windows.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BackgroundTransition = property(get_BackgroundTransition, put_BackgroundTransition)
class IContentPresenterFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentPresenterFactory'
    _iid_ = Guid('{3339d4f7-4815-44c4-9f76-68c83880ef10}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ContentPresenter: ...
class IContentPresenterOverrides(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentPresenterOverrides'
    _iid_ = Guid('{a76339ed-32ff-438b-aad5-1d68fae93426}')
    @winrt_commethod(6)
    def OnContentTemplateChanged(self, oldContentTemplate: win32more.Windows.UI.Xaml.DataTemplate, newContentTemplate: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(7)
    def OnContentTemplateSelectorChanged(self, oldContentTemplateSelector: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector, newContentTemplateSelector: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
class IContentPresenterStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentPresenterStatics'
    _iid_ = Guid('{18c2893b-da2e-4426-b85a-2c7e2171bedf}')
    @winrt_commethod(6)
    def get_ContentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ContentTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ContentTemplateSelectorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_ContentTransitionsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FontSizeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_FontFamilyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_FontWeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_FontStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_FontStretchProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_CharacterSpacingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_ForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    ContentProperty = property(get_ContentProperty, None)
    ContentTemplateProperty = property(get_ContentTemplateProperty, None)
    ContentTemplateSelectorProperty = property(get_ContentTemplateSelectorProperty, None)
    ContentTransitionsProperty = property(get_ContentTransitionsProperty, None)
    FontFamilyProperty = property(get_FontFamilyProperty, None)
    FontSizeProperty = property(get_FontSizeProperty, None)
    FontStretchProperty = property(get_FontStretchProperty, None)
    FontStyleProperty = property(get_FontStyleProperty, None)
    FontWeightProperty = property(get_FontWeightProperty, None)
    ForegroundProperty = property(get_ForegroundProperty, None)
class IContentPresenterStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentPresenterStatics2'
    _iid_ = Guid('{c7d89dd9-06e6-46be-a8a0-9c117d3024a3}')
    @winrt_commethod(6)
    def get_OpticalMarginAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TextLineBoundsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    OpticalMarginAlignmentProperty = property(get_OpticalMarginAlignmentProperty, None)
    TextLineBoundsProperty = property(get_TextLineBoundsProperty, None)
class IContentPresenterStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentPresenterStatics3'
    _iid_ = Guid('{cbe6cf5b-38b1-4d5d-b098-bc94b35c8ddf}')
    @winrt_commethod(6)
    def get_IsTextScaleFactorEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
class IContentPresenterStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentPresenterStatics4'
    _iid_ = Guid('{ff8be292-af28-47eb-a5c3-dc44ced40fd2}')
    @winrt_commethod(6)
    def get_TextWrappingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_MaxLinesProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_LineStackingStrategyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_LineHeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_BorderBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_BorderThicknessProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_CornerRadiusProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_PaddingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_BackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_HorizontalContentAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_VerticalContentAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BackgroundProperty = property(get_BackgroundProperty, None)
    BorderBrushProperty = property(get_BorderBrushProperty, None)
    BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    HorizontalContentAlignmentProperty = property(get_HorizontalContentAlignmentProperty, None)
    LineHeightProperty = property(get_LineHeightProperty, None)
    LineStackingStrategyProperty = property(get_LineStackingStrategyProperty, None)
    MaxLinesProperty = property(get_MaxLinesProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
    TextWrappingProperty = property(get_TextWrappingProperty, None)
    VerticalContentAlignmentProperty = property(get_VerticalContentAlignmentProperty, None)
class IContentPresenterStatics5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContentPresenterStatics5'
    _iid_ = Guid('{169e700f-e8e6-5f6a-b97e-7ef8f7006f49}')
    @winrt_commethod(6)
    def get_BackgroundSizingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
class IContextMenuEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IContextMenuEventArgs'
    _iid_ = Guid('{1f7df263-c14b-4528-b6f0-637999d83cc6}')
    @winrt_commethod(6)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Handled(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_CursorLeft(self) -> Double: ...
    @winrt_commethod(9)
    def get_CursorTop(self) -> Double: ...
    CursorLeft = property(get_CursorLeft, None)
    CursorTop = property(get_CursorTop, None)
    Handled = property(get_Handled, put_Handled)
class IControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IControl'
    _iid_ = Guid('{a8912263-2951-4f58-a9c5-5a134eaa7f07}')
    @winrt_commethod(6)
    def get_FontSize(self) -> Double: ...
    @winrt_commethod(7)
    def put_FontSize(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_FontFamily(self) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(9)
    def put_FontFamily(self, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(10)
    def get_FontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(11)
    def put_FontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(12)
    def get_FontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(13)
    def put_FontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(14)
    def get_FontStretch(self) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_commethod(15)
    def put_FontStretch(self, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_commethod(16)
    def get_CharacterSpacing(self) -> Int32: ...
    @winrt_commethod(17)
    def put_CharacterSpacing(self, value: Int32) -> Void: ...
    @winrt_commethod(18)
    def get_Foreground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(19)
    def put_Foreground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(20)
    def get_IsTabStop(self) -> Boolean: ...
    @winrt_commethod(21)
    def put_IsTabStop(self, value: Boolean) -> Void: ...
    @winrt_commethod(22)
    def get_IsEnabled(self) -> Boolean: ...
    @winrt_commethod(23)
    def put_IsEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(24)
    def get_TabIndex(self) -> Int32: ...
    @winrt_commethod(25)
    def put_TabIndex(self, value: Int32) -> Void: ...
    @winrt_commethod(26)
    def get_TabNavigation(self) -> win32more.Windows.UI.Xaml.Input.KeyboardNavigationMode: ...
    @winrt_commethod(27)
    def put_TabNavigation(self, value: win32more.Windows.UI.Xaml.Input.KeyboardNavigationMode) -> Void: ...
    @winrt_commethod(28)
    def get_Template(self) -> win32more.Windows.UI.Xaml.Controls.ControlTemplate: ...
    @winrt_commethod(29)
    def put_Template(self, value: win32more.Windows.UI.Xaml.Controls.ControlTemplate) -> Void: ...
    @winrt_commethod(30)
    def get_Padding(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(31)
    def put_Padding(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(32)
    def get_HorizontalContentAlignment(self) -> win32more.Windows.UI.Xaml.HorizontalAlignment: ...
    @winrt_commethod(33)
    def put_HorizontalContentAlignment(self, value: win32more.Windows.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_commethod(34)
    def get_VerticalContentAlignment(self) -> win32more.Windows.UI.Xaml.VerticalAlignment: ...
    @winrt_commethod(35)
    def put_VerticalContentAlignment(self, value: win32more.Windows.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_commethod(36)
    def get_Background(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(37)
    def put_Background(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(38)
    def get_BorderThickness(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(39)
    def put_BorderThickness(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(40)
    def get_BorderBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(41)
    def put_BorderBrush(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(42)
    def get_FocusState(self) -> win32more.Windows.UI.Xaml.FocusState: ...
    @winrt_commethod(43)
    def add_IsEnabledChanged(self, handler: win32more.Windows.UI.Xaml.DependencyPropertyChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(44)
    def remove_IsEnabledChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(45)
    def ApplyTemplate(self) -> Boolean: ...
    @winrt_commethod(46)
    def Focus(self, value: win32more.Windows.UI.Xaml.FocusState) -> Boolean: ...
    Background = property(get_Background, put_Background)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    FocusState = property(get_FocusState, None)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
    HorizontalContentAlignment = property(get_HorizontalContentAlignment, put_HorizontalContentAlignment)
    IsEnabled = property(get_IsEnabled, put_IsEnabled)
    IsTabStop = property(get_IsTabStop, put_IsTabStop)
    Padding = property(get_Padding, put_Padding)
    TabIndex = property(get_TabIndex, put_TabIndex)
    TabNavigation = property(get_TabNavigation, put_TabNavigation)
    Template = property(get_Template, put_Template)
    VerticalContentAlignment = property(get_VerticalContentAlignment, put_VerticalContentAlignment)
    IsEnabledChanged = event()
class IControl2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IControl2'
    _iid_ = Guid('{43e0fe10-14ec-427e-8c57-dee60df60aa8}')
    @winrt_commethod(6)
    def get_IsTextScaleFactorEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsTextScaleFactorEnabled(self, value: Boolean) -> Void: ...
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
class IControl3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IControl3'
    _iid_ = Guid('{077b29e4-dade-4f55-9b96-09e21b28eb1c}')
    @winrt_commethod(6)
    def get_UseSystemFocusVisuals(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_UseSystemFocusVisuals(self, value: Boolean) -> Void: ...
    UseSystemFocusVisuals = property(get_UseSystemFocusVisuals, put_UseSystemFocusVisuals)
class IControl4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IControl4'
    _iid_ = Guid('{0e18aeee-5f2e-44ea-8513-d3875c0a7513}')
    @winrt_commethod(6)
    def get_IsFocusEngagementEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsFocusEngagementEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsFocusEngaged(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsFocusEngaged(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_RequiresPointer(self) -> win32more.Windows.UI.Xaml.Controls.RequiresPointer: ...
    @winrt_commethod(11)
    def put_RequiresPointer(self, value: win32more.Windows.UI.Xaml.Controls.RequiresPointer) -> Void: ...
    @winrt_commethod(12)
    def get_XYFocusLeft(self) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_commethod(13)
    def put_XYFocusLeft(self, value: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_commethod(14)
    def get_XYFocusRight(self) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_commethod(15)
    def put_XYFocusRight(self, value: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_commethod(16)
    def get_XYFocusUp(self) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_commethod(17)
    def put_XYFocusUp(self, value: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_commethod(18)
    def get_XYFocusDown(self) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_commethod(19)
    def put_XYFocusDown(self, value: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_commethod(20)
    def get_ElementSoundMode(self) -> win32more.Windows.UI.Xaml.ElementSoundMode: ...
    @winrt_commethod(21)
    def put_ElementSoundMode(self, value: win32more.Windows.UI.Xaml.ElementSoundMode) -> Void: ...
    @winrt_commethod(22)
    def add_FocusEngaged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.Control, win32more.Windows.UI.Xaml.Controls.FocusEngagedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(23)
    def remove_FocusEngaged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(24)
    def add_FocusDisengaged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.Control, win32more.Windows.UI.Xaml.Controls.FocusDisengagedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(25)
    def remove_FocusDisengaged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(26)
    def RemoveFocusEngagement(self) -> Void: ...
    ElementSoundMode = property(get_ElementSoundMode, put_ElementSoundMode)
    IsFocusEngaged = property(get_IsFocusEngaged, put_IsFocusEngaged)
    IsFocusEngagementEnabled = property(get_IsFocusEngagementEnabled, put_IsFocusEngagementEnabled)
    RequiresPointer = property(get_RequiresPointer, put_RequiresPointer)
    XYFocusDown = property(get_XYFocusDown, put_XYFocusDown)
    XYFocusLeft = property(get_XYFocusLeft, put_XYFocusLeft)
    XYFocusRight = property(get_XYFocusRight, put_XYFocusRight)
    XYFocusUp = property(get_XYFocusUp, put_XYFocusUp)
    FocusEngaged = event()
    FocusDisengaged = event()
class IControl5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IControl5'
    _iid_ = Guid('{5ebb51d5-9e58-49b7-bc2d-0155ff118664}')
    @winrt_commethod(6)
    def get_DefaultStyleResourceUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def put_DefaultStyleResourceUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    DefaultStyleResourceUri = property(get_DefaultStyleResourceUri, put_DefaultStyleResourceUri)
class IControl7(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IControl7'
    _iid_ = Guid('{3550dbe1-e561-5934-a3ef-7db8bf6e3b45}')
    @winrt_commethod(6)
    def get_BackgroundSizing(self) -> win32more.Windows.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_commethod(7)
    def put_BackgroundSizing(self, value: win32more.Windows.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_commethod(8)
    def get_CornerRadius(self) -> win32more.Windows.UI.Xaml.CornerRadius: ...
    @winrt_commethod(9)
    def put_CornerRadius(self, value: win32more.Windows.UI.Xaml.CornerRadius) -> Void: ...
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
class IControlFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IControlFactory'
    _iid_ = Guid('{b12b1d5a-6419-4e16-b212-a45336b75778}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Control: ...
class IControlOverrides(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IControlOverrides'
    _iid_ = Guid('{a09691df-9824-41fe-b530-b0d8990e64c1}')
    @winrt_commethod(6)
    def OnPointerEntered(self, e: win32more.Windows.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_commethod(7)
    def OnPointerPressed(self, e: win32more.Windows.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_commethod(8)
    def OnPointerMoved(self, e: win32more.Windows.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_commethod(9)
    def OnPointerReleased(self, e: win32more.Windows.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_commethod(10)
    def OnPointerExited(self, e: win32more.Windows.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_commethod(11)
    def OnPointerCaptureLost(self, e: win32more.Windows.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_commethod(12)
    def OnPointerCanceled(self, e: win32more.Windows.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_commethod(13)
    def OnPointerWheelChanged(self, e: win32more.Windows.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_commethod(14)
    def OnTapped(self, e: win32more.Windows.UI.Xaml.Input.TappedRoutedEventArgs) -> Void: ...
    @winrt_commethod(15)
    def OnDoubleTapped(self, e: win32more.Windows.UI.Xaml.Input.DoubleTappedRoutedEventArgs) -> Void: ...
    @winrt_commethod(16)
    def OnHolding(self, e: win32more.Windows.UI.Xaml.Input.HoldingRoutedEventArgs) -> Void: ...
    @winrt_commethod(17)
    def OnRightTapped(self, e: win32more.Windows.UI.Xaml.Input.RightTappedRoutedEventArgs) -> Void: ...
    @winrt_commethod(18)
    def OnManipulationStarting(self, e: win32more.Windows.UI.Xaml.Input.ManipulationStartingRoutedEventArgs) -> Void: ...
    @winrt_commethod(19)
    def OnManipulationInertiaStarting(self, e: win32more.Windows.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs) -> Void: ...
    @winrt_commethod(20)
    def OnManipulationStarted(self, e: win32more.Windows.UI.Xaml.Input.ManipulationStartedRoutedEventArgs) -> Void: ...
    @winrt_commethod(21)
    def OnManipulationDelta(self, e: win32more.Windows.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs) -> Void: ...
    @winrt_commethod(22)
    def OnManipulationCompleted(self, e: win32more.Windows.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs) -> Void: ...
    @winrt_commethod(23)
    def OnKeyUp(self, e: win32more.Windows.UI.Xaml.Input.KeyRoutedEventArgs) -> Void: ...
    @winrt_commethod(24)
    def OnKeyDown(self, e: win32more.Windows.UI.Xaml.Input.KeyRoutedEventArgs) -> Void: ...
    @winrt_commethod(25)
    def OnGotFocus(self, e: win32more.Windows.UI.Xaml.RoutedEventArgs) -> Void: ...
    @winrt_commethod(26)
    def OnLostFocus(self, e: win32more.Windows.UI.Xaml.RoutedEventArgs) -> Void: ...
    @winrt_commethod(27)
    def OnDragEnter(self, e: win32more.Windows.UI.Xaml.DragEventArgs) -> Void: ...
    @winrt_commethod(28)
    def OnDragLeave(self, e: win32more.Windows.UI.Xaml.DragEventArgs) -> Void: ...
    @winrt_commethod(29)
    def OnDragOver(self, e: win32more.Windows.UI.Xaml.DragEventArgs) -> Void: ...
    @winrt_commethod(30)
    def OnDrop(self, e: win32more.Windows.UI.Xaml.DragEventArgs) -> Void: ...
class IControlOverrides6(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IControlOverrides6'
    _iid_ = Guid('{e194c96a-d8cc-4339-a0e1-2e9c420879ec}')
    @winrt_commethod(6)
    def OnPreviewKeyDown(self, e: win32more.Windows.UI.Xaml.Input.KeyRoutedEventArgs) -> Void: ...
    @winrt_commethod(7)
    def OnPreviewKeyUp(self, e: win32more.Windows.UI.Xaml.Input.KeyRoutedEventArgs) -> Void: ...
    @winrt_commethod(8)
    def OnCharacterReceived(self, e: win32more.Windows.UI.Xaml.Input.CharacterReceivedRoutedEventArgs) -> Void: ...
class IControlProtected(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IControlProtected'
    _iid_ = Guid('{1791587a-2a7c-4981-a2d8-ab99fffc65b9}')
    @winrt_commethod(6)
    def get_DefaultStyleKey(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_DefaultStyleKey(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def GetTemplateChild(self, childName: WinRT_String) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    DefaultStyleKey = property(get_DefaultStyleKey, put_DefaultStyleKey)
class IControlStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IControlStatics'
    _iid_ = Guid('{473b305b-877d-4c35-8fca-46a05f96607a}')
    @winrt_commethod(6)
    def get_FontSizeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_FontFamilyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_FontWeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_FontStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FontStretchProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_CharacterSpacingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_IsTabStopProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_IsEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_TabIndexProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_TabNavigationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_TemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_PaddingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_HorizontalContentAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_VerticalContentAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_BackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_BorderThicknessProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_BorderBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_DefaultStyleKeyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_FocusStateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BackgroundProperty = property(get_BackgroundProperty, None)
    BorderBrushProperty = property(get_BorderBrushProperty, None)
    BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    DefaultStyleKeyProperty = property(get_DefaultStyleKeyProperty, None)
    FocusStateProperty = property(get_FocusStateProperty, None)
    FontFamilyProperty = property(get_FontFamilyProperty, None)
    FontSizeProperty = property(get_FontSizeProperty, None)
    FontStretchProperty = property(get_FontStretchProperty, None)
    FontStyleProperty = property(get_FontStyleProperty, None)
    FontWeightProperty = property(get_FontWeightProperty, None)
    ForegroundProperty = property(get_ForegroundProperty, None)
    HorizontalContentAlignmentProperty = property(get_HorizontalContentAlignmentProperty, None)
    IsEnabledProperty = property(get_IsEnabledProperty, None)
    IsTabStopProperty = property(get_IsTabStopProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
    TabIndexProperty = property(get_TabIndexProperty, None)
    TabNavigationProperty = property(get_TabNavigationProperty, None)
    TemplateProperty = property(get_TemplateProperty, None)
    VerticalContentAlignmentProperty = property(get_VerticalContentAlignmentProperty, None)
class IControlStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IControlStatics2'
    _iid_ = Guid('{32233e36-ab74-4a25-a556-45293135b2c5}')
    @winrt_commethod(6)
    def get_IsTextScaleFactorEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
class IControlStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IControlStatics3'
    _iid_ = Guid('{aad15e61-e4b9-4d72-b653-934149aa5003}')
    @winrt_commethod(6)
    def get_UseSystemFocusVisualsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsTemplateFocusTargetProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def GetIsTemplateFocusTarget(self, element: win32more.Windows.UI.Xaml.FrameworkElement) -> Boolean: ...
    @winrt_commethod(9)
    def SetIsTemplateFocusTarget(self, element: win32more.Windows.UI.Xaml.FrameworkElement, value: Boolean) -> Void: ...
    IsTemplateFocusTargetProperty = property(get_IsTemplateFocusTargetProperty, None)
    UseSystemFocusVisualsProperty = property(get_UseSystemFocusVisualsProperty, None)
class IControlStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IControlStatics4'
    _iid_ = Guid('{59fda728-c05a-4ec2-8a4b-06ad69b66e15}')
    @winrt_commethod(6)
    def get_IsFocusEngagementEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsFocusEngagedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_RequiresPointerProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_XYFocusLeftProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_XYFocusRightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_XYFocusUpProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_XYFocusDownProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_ElementSoundModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ElementSoundModeProperty = property(get_ElementSoundModeProperty, None)
    IsFocusEngagedProperty = property(get_IsFocusEngagedProperty, None)
    IsFocusEngagementEnabledProperty = property(get_IsFocusEngagementEnabledProperty, None)
    RequiresPointerProperty = property(get_RequiresPointerProperty, None)
    XYFocusDownProperty = property(get_XYFocusDownProperty, None)
    XYFocusLeftProperty = property(get_XYFocusLeftProperty, None)
    XYFocusRightProperty = property(get_XYFocusRightProperty, None)
    XYFocusUpProperty = property(get_XYFocusUpProperty, None)
class IControlStatics5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IControlStatics5'
    _iid_ = Guid('{f635b5a3-ef8e-404f-877b-5580473710a6}')
    @winrt_commethod(6)
    def get_DefaultStyleResourceUriProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsTemplateKeyTipTargetProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def GetIsTemplateKeyTipTarget(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(9)
    def SetIsTemplateKeyTipTarget(self, element: win32more.Windows.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    DefaultStyleResourceUriProperty = property(get_DefaultStyleResourceUriProperty, None)
    IsTemplateKeyTipTargetProperty = property(get_IsTemplateKeyTipTargetProperty, None)
class IControlStatics7(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IControlStatics7'
    _iid_ = Guid('{aee1ca45-c910-5dab-a266-fdf50c0bedd2}')
    @winrt_commethod(6)
    def get_BackgroundSizingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CornerRadiusProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    CornerRadiusProperty = property(get_CornerRadiusProperty, None)
class IControlTemplate(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IControlTemplate'
    _iid_ = Guid('{efd2418e-41e0-48bb-8b82-91eda1ba3fe2}')
    @winrt_commethod(6)
    def get_TargetType(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_commethod(7)
    def put_TargetType(self, value: win32more.Windows.UI.Xaml.Interop.TypeName) -> Void: ...
    TargetType = property(get_TargetType, put_TargetType)
class IDataTemplateSelector(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDataTemplateSelector'
    _iid_ = Guid('{a907d496-46a0-4cd7-8dbe-f9a581df60b1}')
    @winrt_commethod(6)
    def SelectTemplate(self, item: win32more.Windows.Win32.System.WinRT.IInspectable, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.DataTemplate: ...
class IDataTemplateSelector2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDataTemplateSelector2'
    _iid_ = Guid('{3792bc47-8c4b-4257-a5ae-cc3f8ed786eb}')
    @winrt_commethod(6)
    def SelectTemplateForItem(self, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.UI.Xaml.DataTemplate: ...
class IDataTemplateSelectorFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDataTemplateSelectorFactory'
    _iid_ = Guid('{511baad0-210a-457d-9521-433d2b11b7d2}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.DataTemplateSelector: ...
class IDataTemplateSelectorOverrides(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDataTemplateSelectorOverrides'
    _iid_ = Guid('{2d162925-5966-4bfa-8638-4d345689f6cf}')
    @winrt_commethod(6)
    def SelectTemplateCore(self, item: win32more.Windows.Win32.System.WinRT.IInspectable, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.DataTemplate: ...
class IDataTemplateSelectorOverrides2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDataTemplateSelectorOverrides2'
    _iid_ = Guid('{6c3fb5fc-8e84-4c91-ac15-04a1d885500f}')
    @winrt_commethod(6)
    def SelectTemplateForItemCore(self, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.UI.Xaml.DataTemplate: ...
class IDatePickedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePickedEventArgs'
    _iid_ = Guid('{a1527b12-59c1-4521-b28c-b176675e7c5a}')
    @winrt_commethod(6)
    def get_OldDate(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(7)
    def get_NewDate(self) -> win32more.Windows.Foundation.DateTime: ...
    NewDate = property(get_NewDate, None)
    OldDate = property(get_OldDate, None)
class IDatePicker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePicker'
    _iid_ = Guid('{06da3946-08b8-4103-8b8a-093efd6a7657}')
    @winrt_commethod(6)
    def get_Header(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_HeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_CalendarIdentifier(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_CalendarIdentifier(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_Date(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(13)
    def put_Date(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(14)
    def get_DayVisible(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_DayVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_MonthVisible(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_MonthVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_YearVisible(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_YearVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_DayFormat(self) -> WinRT_String: ...
    @winrt_commethod(21)
    def put_DayFormat(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(22)
    def get_MonthFormat(self) -> WinRT_String: ...
    @winrt_commethod(23)
    def put_MonthFormat(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(24)
    def get_YearFormat(self) -> WinRT_String: ...
    @winrt_commethod(25)
    def put_YearFormat(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(26)
    def get_MinYear(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(27)
    def put_MinYear(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(28)
    def get_MaxYear(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(29)
    def put_MaxYear(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(30)
    def get_Orientation(self) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(31)
    def put_Orientation(self, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(32)
    def add_DateChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.UI.Xaml.Controls.DatePickerValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(33)
    def remove_DateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CalendarIdentifier = property(get_CalendarIdentifier, put_CalendarIdentifier)
    Date = property(get_Date, put_Date)
    DayFormat = property(get_DayFormat, put_DayFormat)
    DayVisible = property(get_DayVisible, put_DayVisible)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    MaxYear = property(get_MaxYear, put_MaxYear)
    MinYear = property(get_MinYear, put_MinYear)
    MonthFormat = property(get_MonthFormat, put_MonthFormat)
    MonthVisible = property(get_MonthVisible, put_MonthVisible)
    Orientation = property(get_Orientation, put_Orientation)
    YearFormat = property(get_YearFormat, put_YearFormat)
    YearVisible = property(get_YearVisible, put_YearVisible)
    DateChanged = event()
class IDatePicker2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePicker2'
    _iid_ = Guid('{bb28b475-2c1f-4340-9e30-948f99c9e57a}')
    @winrt_commethod(6)
    def get_LightDismissOverlayMode(self) -> win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_commethod(7)
    def put_LightDismissOverlayMode(self, value: win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
class IDatePicker3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePicker3'
    _iid_ = Guid('{7da12a3b-a764-5ae1-abae-6affc1428e1e}')
    @winrt_commethod(6)
    def get_SelectedDate(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(7)
    def put_SelectedDate(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_commethod(8)
    def add_SelectedDateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.DatePicker, win32more.Windows.UI.Xaml.Controls.DatePickerSelectedValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_SelectedDateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    SelectedDate = property(get_SelectedDate, put_SelectedDate)
    SelectedDateChanged = event()
class IDatePickerFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePickerFactory'
    _iid_ = Guid('{eec3ca84-9896-4a7d-bb35-6fb21eaeca11}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.DatePicker: ...
class IDatePickerFlyout(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePickerFlyout'
    _iid_ = Guid('{fbf33b1a-a3a4-4df8-9228-23a5ac27df4e}')
    @winrt_commethod(6)
    def get_CalendarIdentifier(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_CalendarIdentifier(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Date(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(9)
    def put_Date(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(10)
    def get_DayVisible(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_DayVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_MonthVisible(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_MonthVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_YearVisible(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_YearVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_MinYear(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(17)
    def put_MinYear(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(18)
    def get_MaxYear(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(19)
    def put_MaxYear(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(20)
    def add_DatePicked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.DatePickerFlyout, win32more.Windows.UI.Xaml.Controls.DatePickedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_DatePicked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(22)
    def ShowAtAsync(self, target: win32more.Windows.UI.Xaml.FrameworkElement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]]: ...
    CalendarIdentifier = property(get_CalendarIdentifier, put_CalendarIdentifier)
    Date = property(get_Date, put_Date)
    DayVisible = property(get_DayVisible, put_DayVisible)
    MaxYear = property(get_MaxYear, put_MaxYear)
    MinYear = property(get_MinYear, put_MinYear)
    MonthVisible = property(get_MonthVisible, put_MonthVisible)
    YearVisible = property(get_YearVisible, put_YearVisible)
    DatePicked = event()
class IDatePickerFlyout2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePickerFlyout2'
    _iid_ = Guid('{cfb18dbb-9931-4119-8bda-54a86fdfac84}')
    @winrt_commethod(6)
    def get_DayFormat(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_DayFormat(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_MonthFormat(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_MonthFormat(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_YearFormat(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_YearFormat(self, value: WinRT_String) -> Void: ...
    DayFormat = property(get_DayFormat, put_DayFormat)
    MonthFormat = property(get_MonthFormat, put_MonthFormat)
    YearFormat = property(get_YearFormat, put_YearFormat)
class IDatePickerFlyoutItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePickerFlyoutItem'
    _iid_ = Guid('{9d9bc289-00d2-4aac-9c85-d74f06367887}')
    @winrt_commethod(6)
    def get_PrimaryText(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_PrimaryText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_SecondaryText(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_SecondaryText(self, value: WinRT_String) -> Void: ...
    PrimaryText = property(get_PrimaryText, put_PrimaryText)
    SecondaryText = property(get_SecondaryText, put_SecondaryText)
class IDatePickerFlyoutItemStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePickerFlyoutItemStatics'
    _iid_ = Guid('{aa9c91da-07f6-4cdf-89b4-dda3bdb0ea6b}')
    @winrt_commethod(6)
    def get_PrimaryTextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_SecondaryTextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    PrimaryTextProperty = property(get_PrimaryTextProperty, None)
    SecondaryTextProperty = property(get_SecondaryTextProperty, None)
class IDatePickerFlyoutPresenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePickerFlyoutPresenter'
    _iid_ = Guid('{7c62f70e-2ddc-4381-832f-54cbdfaa849a}')
class IDatePickerFlyoutPresenter2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePickerFlyoutPresenter2'
    _iid_ = Guid('{c5b2578f-96d8-55cc-97ee-3f88fc85e479}')
    @winrt_commethod(6)
    def get_IsDefaultShadowEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsDefaultShadowEnabled(self, value: Boolean) -> Void: ...
    IsDefaultShadowEnabled = property(get_IsDefaultShadowEnabled, put_IsDefaultShadowEnabled)
class IDatePickerFlyoutPresenterStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePickerFlyoutPresenterStatics2'
    _iid_ = Guid('{4dc0c49e-1f8e-5966-bbdb-215750c73aba}')
    @winrt_commethod(6)
    def get_IsDefaultShadowEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsDefaultShadowEnabledProperty = property(get_IsDefaultShadowEnabledProperty, None)
class IDatePickerFlyoutStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePickerFlyoutStatics'
    _iid_ = Guid('{cd570377-5845-4c12-8c10-592d9fcc7cd9}')
    @winrt_commethod(6)
    def get_CalendarIdentifierProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_DateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DayVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_MonthVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_YearVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_MinYearProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_MaxYearProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CalendarIdentifierProperty = property(get_CalendarIdentifierProperty, None)
    DateProperty = property(get_DateProperty, None)
    DayVisibleProperty = property(get_DayVisibleProperty, None)
    MaxYearProperty = property(get_MaxYearProperty, None)
    MinYearProperty = property(get_MinYearProperty, None)
    MonthVisibleProperty = property(get_MonthVisibleProperty, None)
    YearVisibleProperty = property(get_YearVisibleProperty, None)
class IDatePickerFlyoutStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePickerFlyoutStatics2'
    _iid_ = Guid('{afd3e569-81e6-4b54-84a9-68079b73e34e}')
    @winrt_commethod(6)
    def get_DayFormatProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_MonthFormatProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_YearFormatProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DayFormatProperty = property(get_DayFormatProperty, None)
    MonthFormatProperty = property(get_MonthFormatProperty, None)
    YearFormatProperty = property(get_YearFormatProperty, None)
class IDatePickerSelectedValueChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePickerSelectedValueChangedEventArgs'
    _iid_ = Guid('{564dceed-744a-5c3a-9bd2-4dcd9919a7b7}')
    @winrt_commethod(6)
    def get_OldDate(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(7)
    def get_NewDate(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    NewDate = property(get_NewDate, None)
    OldDate = property(get_OldDate, None)
class IDatePickerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePickerStatics'
    _iid_ = Guid('{182e7c69-2116-4c67-b513-713364831d79}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CalendarIdentifierProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_DateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_DayVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_MonthVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_YearVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_DayFormatProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_MonthFormatProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_YearFormatProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_MinYearProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_MaxYearProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_OrientationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CalendarIdentifierProperty = property(get_CalendarIdentifierProperty, None)
    DateProperty = property(get_DateProperty, None)
    DayFormatProperty = property(get_DayFormatProperty, None)
    DayVisibleProperty = property(get_DayVisibleProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    MaxYearProperty = property(get_MaxYearProperty, None)
    MinYearProperty = property(get_MinYearProperty, None)
    MonthFormatProperty = property(get_MonthFormatProperty, None)
    MonthVisibleProperty = property(get_MonthVisibleProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
    YearFormatProperty = property(get_YearFormatProperty, None)
    YearVisibleProperty = property(get_YearVisibleProperty, None)
class IDatePickerStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePickerStatics2'
    _iid_ = Guid('{f1076df6-fba6-4550-8b88-a6420847f60d}')
    @winrt_commethod(6)
    def get_LightDismissOverlayModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
class IDatePickerStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePickerStatics3'
    _iid_ = Guid('{a9f80afe-a30a-5f26-a446-fec2075d4a0e}')
    @winrt_commethod(6)
    def get_SelectedDateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SelectedDateProperty = property(get_SelectedDateProperty, None)
class IDatePickerValueChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDatePickerValueChangedEventArgs'
    _iid_ = Guid('{1ae661b2-b1b4-4273-96e0-19daff187446}')
    @winrt_commethod(6)
    def get_OldDate(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(7)
    def get_NewDate(self) -> win32more.Windows.Foundation.DateTime: ...
    NewDate = property(get_NewDate, None)
    OldDate = property(get_OldDate, None)
class IDragItemsCompletedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDragItemsCompletedEventArgs'
    _iid_ = Guid('{af05f22f-9e78-4b21-9a8e-41c2d1367a2a}')
    @winrt_commethod(6)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_commethod(7)
    def get_DropResult(self) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation: ...
    DropResult = property(get_DropResult, None)
    Items = property(get_Items, None)
class IDragItemsStartingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDragItemsStartingEventArgs'
    _iid_ = Guid('{71cf215c-daed-4783-aa11-dc574d2713e9}')
    @winrt_commethod(6)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Cancel(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_commethod(9)
    def get_Data(self) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackage: ...
    Cancel = property(get_Cancel, put_Cancel)
    Data = property(get_Data, None)
    Items = property(get_Items, None)
class IDropDownButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDropDownButton'
    _iid_ = Guid('{671f74e6-2a27-5fa8-b0a2-79b2e71ebd87}')
class IDropDownButtonAutomationPeer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDropDownButtonAutomationPeer'
    _iid_ = Guid('{72f294f1-bff6-5d07-9db4-54134506bc80}')
class IDropDownButtonAutomationPeerFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDropDownButtonAutomationPeerFactory'
    _iid_ = Guid('{b8c449b2-6354-5c0c-9e95-e0c99a293a44}')
    @winrt_commethod(6)
    def CreateInstance(self, owner: win32more.Windows.UI.Xaml.Controls.DropDownButton, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.DropDownButtonAutomationPeer: ...
class IDropDownButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDropDownButtonFactory'
    _iid_ = Guid('{0d9f8ab5-e70d-52bd-9ca0-36ceecaa642a}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.DropDownButton: ...
class IDynamicOverflowItemsChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IDynamicOverflowItemsChangingEventArgs'
    _iid_ = Guid('{c93c736f-6f6e-4e43-90d9-9b46a0d88b9f}')
    @winrt_commethod(6)
    def get_Action(self) -> win32more.Windows.UI.Xaml.Controls.CommandBarDynamicOverflowAction: ...
    Action = property(get_Action, None)
class IFlipView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFlipView'
    _iid_ = Guid('{a1582f68-3d7d-4d3b-b71d-488eed1e3493}')
class IFlipView2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFlipView2'
    _iid_ = Guid('{c4fea4fd-7af3-4952-9fd9-9e0987fc4f29}')
    @winrt_commethod(6)
    def get_UseTouchAnimationsForAllNavigation(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_UseTouchAnimationsForAllNavigation(self, value: Boolean) -> Void: ...
    UseTouchAnimationsForAllNavigation = property(get_UseTouchAnimationsForAllNavigation, put_UseTouchAnimationsForAllNavigation)
class IFlipViewFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFlipViewFactory'
    _iid_ = Guid('{f1dea9be-9ae8-4d4b-ab43-16d31e05f4f3}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.FlipView: ...
class IFlipViewItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFlipViewItem'
    _iid_ = Guid('{56196565-ce2b-4bda-a36b-82a2b8b0d4c0}')
class IFlipViewItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFlipViewItemFactory'
    _iid_ = Guid('{f21d91fe-22a0-4412-a853-9d6a6e8f2aaf}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.FlipViewItem: ...
class IFlipViewStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFlipViewStatics2'
    _iid_ = Guid('{70e3d93f-4308-4ba2-bbce-e2cb0ed34476}')
    @winrt_commethod(6)
    def get_UseTouchAnimationsForAllNavigationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    UseTouchAnimationsForAllNavigationProperty = property(get_UseTouchAnimationsForAllNavigationProperty, None)
class IFlyout(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFlyout'
    _iid_ = Guid('{6584ebdf-cbc7-4e19-843a-a14f24a793ea}')
    @winrt_commethod(6)
    def get_Content(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Content(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_FlyoutPresenterStyle(self) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_commethod(9)
    def put_FlyoutPresenterStyle(self, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    Content = property(get_Content, put_Content)
    FlyoutPresenterStyle = property(get_FlyoutPresenterStyle, put_FlyoutPresenterStyle)
class IFlyoutFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFlyoutFactory'
    _iid_ = Guid('{4bed4933-008e-4b03-a385-79fe5266ddba}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Flyout: ...
class IFlyoutPresenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFlyoutPresenter'
    _iid_ = Guid('{827d5b79-e37b-46a5-8d44-63a11a580e83}')
class IFlyoutPresenter2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFlyoutPresenter2'
    _iid_ = Guid('{4f857e92-36b4-5048-9051-a992b43e8a1d}')
    @winrt_commethod(6)
    def get_IsDefaultShadowEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsDefaultShadowEnabled(self, value: Boolean) -> Void: ...
    IsDefaultShadowEnabled = property(get_IsDefaultShadowEnabled, put_IsDefaultShadowEnabled)
class IFlyoutPresenterFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFlyoutPresenterFactory'
    _iid_ = Guid('{ee4d668f-da76-469a-acd7-3060e613ade7}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.FlyoutPresenter: ...
class IFlyoutPresenterStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFlyoutPresenterStatics2'
    _iid_ = Guid('{1492ae4b-2727-5e8e-9105-6d7a2b1185b2}')
    @winrt_commethod(6)
    def get_IsDefaultShadowEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsDefaultShadowEnabledProperty = property(get_IsDefaultShadowEnabledProperty, None)
class IFlyoutStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFlyoutStatics'
    _iid_ = Guid('{61364e0b-db75-47e1-b2c3-5b901c3d74b6}')
    @winrt_commethod(6)
    def get_ContentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_FlyoutPresenterStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ContentProperty = property(get_ContentProperty, None)
    FlyoutPresenterStyleProperty = property(get_FlyoutPresenterStyleProperty, None)
class IFocusDisengagedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFocusDisengagedEventArgs'
    _iid_ = Guid('{5e14280f-953e-4cf8-b9ea-c530a1ce02ad}')
class IFocusEngagedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFocusEngagedEventArgs'
    _iid_ = Guid('{a69fc352-da66-404c-823f-5358594e70bb}')
class IFocusEngagedEventArgs2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFocusEngagedEventArgs2'
    _iid_ = Guid('{4a59e0f4-87c0-4ccd-93c4-a3a01ce39265}')
    @winrt_commethod(6)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Handled(self, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class IFontIcon(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFontIcon'
    _iid_ = Guid('{d4d61391-39ac-4950-9166-3606c264418b}')
    @winrt_commethod(6)
    def get_Glyph(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Glyph(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_FontSize(self) -> Double: ...
    @winrt_commethod(9)
    def put_FontSize(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_FontFamily(self) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(11)
    def put_FontFamily(self, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(12)
    def get_FontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(13)
    def put_FontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(14)
    def get_FontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(15)
    def put_FontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Glyph = property(get_Glyph, put_Glyph)
class IFontIcon2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFontIcon2'
    _iid_ = Guid('{f6ebd84d-37e8-46ee-a574-41ad550482e0}')
    @winrt_commethod(6)
    def get_IsTextScaleFactorEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsTextScaleFactorEnabled(self, value: Boolean) -> Void: ...
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
class IFontIcon3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFontIcon3'
    _iid_ = Guid('{6155d919-1c6c-4950-8794-231ef0914d94}')
    @winrt_commethod(6)
    def get_MirroredWhenRightToLeft(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_MirroredWhenRightToLeft(self, value: Boolean) -> Void: ...
    MirroredWhenRightToLeft = property(get_MirroredWhenRightToLeft, put_MirroredWhenRightToLeft)
class IFontIconFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFontIconFactory'
    _iid_ = Guid('{1c781b6b-37bf-4ddc-a1a8-1b77db3cf0ea}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.FontIcon: ...
class IFontIconSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFontIconSource'
    _iid_ = Guid('{2211ac9a-74e3-43ed-b61c-21afc7df4d10}')
    @winrt_commethod(6)
    def get_Glyph(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Glyph(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_FontSize(self) -> Double: ...
    @winrt_commethod(9)
    def put_FontSize(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_FontFamily(self) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(11)
    def put_FontFamily(self, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(12)
    def get_FontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(13)
    def put_FontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(14)
    def get_FontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(15)
    def put_FontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(16)
    def get_IsTextScaleFactorEnabled(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsTextScaleFactorEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_MirroredWhenRightToLeft(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_MirroredWhenRightToLeft(self, value: Boolean) -> Void: ...
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Glyph = property(get_Glyph, put_Glyph)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    MirroredWhenRightToLeft = property(get_MirroredWhenRightToLeft, put_MirroredWhenRightToLeft)
class IFontIconSourceFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFontIconSourceFactory'
    _iid_ = Guid('{8bdcf6bd-fc06-42b8-b30b-7505082ac38f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.FontIconSource: ...
class IFontIconSourceStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFontIconSourceStatics'
    _iid_ = Guid('{8c0e422f-8269-43b1-b95a-ef070e86770d}')
    @winrt_commethod(6)
    def get_GlyphProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_FontSizeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_FontFamilyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_FontWeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FontStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsTextScaleFactorEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_MirroredWhenRightToLeftProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    FontFamilyProperty = property(get_FontFamilyProperty, None)
    FontSizeProperty = property(get_FontSizeProperty, None)
    FontStyleProperty = property(get_FontStyleProperty, None)
    FontWeightProperty = property(get_FontWeightProperty, None)
    GlyphProperty = property(get_GlyphProperty, None)
    IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    MirroredWhenRightToLeftProperty = property(get_MirroredWhenRightToLeftProperty, None)
class IFontIconStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFontIconStatics'
    _iid_ = Guid('{b3be7bf6-1467-4086-bbcb-4e21d97a7b4d}')
    @winrt_commethod(6)
    def get_GlyphProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_FontSizeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_FontFamilyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_FontWeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FontStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    FontFamilyProperty = property(get_FontFamilyProperty, None)
    FontSizeProperty = property(get_FontSizeProperty, None)
    FontStyleProperty = property(get_FontStyleProperty, None)
    FontWeightProperty = property(get_FontWeightProperty, None)
    GlyphProperty = property(get_GlyphProperty, None)
class IFontIconStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFontIconStatics2'
    _iid_ = Guid('{e6080672-08f8-43d3-8790-4604290cbebd}')
    @winrt_commethod(6)
    def get_IsTextScaleFactorEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
class IFontIconStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFontIconStatics3'
    _iid_ = Guid('{a4528b17-b084-4bd5-aab4-feae9d3b5d26}')
    @winrt_commethod(6)
    def get_MirroredWhenRightToLeftProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    MirroredWhenRightToLeftProperty = property(get_MirroredWhenRightToLeftProperty, None)
class IFrame(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFrame'
    _iid_ = Guid('{68ea500b-3fe9-4735-b6a0-e7601933b089}')
    @winrt_commethod(6)
    def get_CacheSize(self) -> Int32: ...
    @winrt_commethod(7)
    def put_CacheSize(self, value: Int32) -> Void: ...
    @winrt_commethod(8)
    def get_CanGoBack(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_CanGoForward(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_CurrentSourcePageType(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_commethod(11)
    def get_SourcePageType(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_commethod(12)
    def put_SourcePageType(self, value: win32more.Windows.UI.Xaml.Interop.TypeName) -> Void: ...
    @winrt_commethod(13)
    def get_BackStackDepth(self) -> Int32: ...
    @winrt_commethod(14)
    def add_Navigated(self, handler: win32more.Windows.UI.Xaml.Navigation.NavigatedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_Navigated(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def add_Navigating(self, handler: win32more.Windows.UI.Xaml.Navigation.NavigatingCancelEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_Navigating(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def add_NavigationFailed(self, handler: win32more.Windows.UI.Xaml.Navigation.NavigationFailedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_NavigationFailed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(20)
    def add_NavigationStopped(self, handler: win32more.Windows.UI.Xaml.Navigation.NavigationStoppedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_NavigationStopped(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(22)
    def GoBack(self) -> Void: ...
    @winrt_commethod(23)
    def GoForward(self) -> Void: ...
    @winrt_commethod(24)
    def Navigate(self, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_commethod(25)
    def GetNavigationState(self) -> WinRT_String: ...
    @winrt_commethod(26)
    def SetNavigationState(self, navigationState: WinRT_String) -> Void: ...
    BackStackDepth = property(get_BackStackDepth, None)
    CacheSize = property(get_CacheSize, put_CacheSize)
    CanGoBack = property(get_CanGoBack, None)
    CanGoForward = property(get_CanGoForward, None)
    CurrentSourcePageType = property(get_CurrentSourcePageType, None)
    SourcePageType = property(get_SourcePageType, put_SourcePageType)
    Navigated = event()
    Navigating = event()
    NavigationFailed = event()
    NavigationStopped = event()
class IFrame2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFrame2'
    _iid_ = Guid('{3f367f87-9f5a-4b04-b818-b554c069597a}')
    @winrt_commethod(6)
    def get_BackStack(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Navigation.PageStackEntry]: ...
    @winrt_commethod(7)
    def get_ForwardStack(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Navigation.PageStackEntry]: ...
    @winrt_commethod(8)
    def Navigate(self, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: win32more.Windows.Win32.System.WinRT.IInspectable, infoOverride: win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo) -> Boolean: ...
    BackStack = property(get_BackStack, None)
    ForwardStack = property(get_ForwardStack, None)
class IFrame3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFrame3'
    _iid_ = Guid('{648a2b4d-53ca-4b5a-aa8e-3cc7440f4a67}')
    @winrt_commethod(6)
    def GoBack(self, transitionInfoOverride: win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo) -> Void: ...
class IFrame4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFrame4'
    _iid_ = Guid('{9b17c21a-bd2b-4a00-99eb-946be9618084}')
    @winrt_commethod(6)
    def SetNavigationStateWithNavigationControl(self, navigationState: WinRT_String, suppressNavigate: Boolean) -> Void: ...
class IFrame5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFrame5'
    _iid_ = Guid('{453fb92e-82b5-5f93-92ab-15341806c9da}')
    @winrt_commethod(6)
    def get_IsNavigationStackEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsNavigationStackEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def NavigateToType(self, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: win32more.Windows.Win32.System.WinRT.IInspectable, navigationOptions: win32more.Windows.UI.Xaml.Navigation.FrameNavigationOptions) -> Boolean: ...
    IsNavigationStackEnabled = property(get_IsNavigationStackEnabled, put_IsNavigationStackEnabled)
class IFrameFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFrameFactory'
    _iid_ = Guid('{02ee93d4-448e-469e-9799-0a8a1f70f171}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Frame: ...
class IFrameStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFrameStatics'
    _iid_ = Guid('{d5acf0e9-d967-471b-8459-c8af4341511b}')
    @winrt_commethod(6)
    def get_CacheSizeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CanGoBackProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CanGoForwardProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_CurrentSourcePageTypeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_SourcePageTypeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_BackStackDepthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BackStackDepthProperty = property(get_BackStackDepthProperty, None)
    CacheSizeProperty = property(get_CacheSizeProperty, None)
    CanGoBackProperty = property(get_CanGoBackProperty, None)
    CanGoForwardProperty = property(get_CanGoForwardProperty, None)
    CurrentSourcePageTypeProperty = property(get_CurrentSourcePageTypeProperty, None)
    SourcePageTypeProperty = property(get_SourcePageTypeProperty, None)
class IFrameStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFrameStatics2'
    _iid_ = Guid('{e4b5cdfe-42f0-4462-a1c1-5d259dd82a03}')
    @winrt_commethod(6)
    def get_BackStackProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ForwardStackProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BackStackProperty = property(get_BackStackProperty, None)
    ForwardStackProperty = property(get_ForwardStackProperty, None)
class IFrameStatics5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IFrameStatics5'
    _iid_ = Guid('{53c89b25-f0e0-58f1-a06d-441075914ff8}')
    @winrt_commethod(6)
    def get_IsNavigationStackEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsNavigationStackEnabledProperty = property(get_IsNavigationStackEnabledProperty, None)
class IGrid(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGrid'
    _iid_ = Guid('{fd104460-2e15-4ba3-8b8f-fa693a4161e9}')
    @winrt_commethod(6)
    def get_RowDefinitions(self) -> win32more.Windows.UI.Xaml.Controls.RowDefinitionCollection: ...
    @winrt_commethod(7)
    def get_ColumnDefinitions(self) -> win32more.Windows.UI.Xaml.Controls.ColumnDefinitionCollection: ...
    ColumnDefinitions = property(get_ColumnDefinitions, None)
    RowDefinitions = property(get_RowDefinitions, None)
class IGrid2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGrid2'
    _iid_ = Guid('{f76efa41-380e-45db-be87-9e1326ba4b57}')
    @winrt_commethod(6)
    def get_BorderBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(7)
    def put_BorderBrush(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(8)
    def get_BorderThickness(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(9)
    def put_BorderThickness(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(10)
    def get_CornerRadius(self) -> win32more.Windows.UI.Xaml.CornerRadius: ...
    @winrt_commethod(11)
    def put_CornerRadius(self, value: win32more.Windows.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_commethod(12)
    def get_Padding(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(13)
    def put_Padding(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    Padding = property(get_Padding, put_Padding)
class IGrid3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGrid3'
    _iid_ = Guid('{12dfc5fc-2342-4dd2-9e7d-2090a171d1ef}')
    @winrt_commethod(6)
    def get_RowSpacing(self) -> Double: ...
    @winrt_commethod(7)
    def put_RowSpacing(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_ColumnSpacing(self) -> Double: ...
    @winrt_commethod(9)
    def put_ColumnSpacing(self, value: Double) -> Void: ...
    ColumnSpacing = property(get_ColumnSpacing, put_ColumnSpacing)
    RowSpacing = property(get_RowSpacing, put_RowSpacing)
class IGrid4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGrid4'
    _iid_ = Guid('{ed02d274-81f1-5ac2-a0c3-bbdaf5a3ffee}')
    @winrt_commethod(6)
    def get_BackgroundSizing(self) -> win32more.Windows.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_commethod(7)
    def put_BackgroundSizing(self, value: win32more.Windows.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
class IGridFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGridFactory'
    _iid_ = Guid('{ae814041-c531-43b4-bf99-12f506f7b01c}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Grid: ...
class IGridStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGridStatics'
    _iid_ = Guid('{64fe2e9f-f951-42b6-a9ce-bb179af11595}')
    @winrt_commethod(6)
    def get_RowProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def GetRow(self, element: win32more.Windows.UI.Xaml.FrameworkElement) -> Int32: ...
    @winrt_commethod(8)
    def SetRow(self, element: win32more.Windows.UI.Xaml.FrameworkElement, value: Int32) -> Void: ...
    @winrt_commethod(9)
    def get_ColumnProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def GetColumn(self, element: win32more.Windows.UI.Xaml.FrameworkElement) -> Int32: ...
    @winrt_commethod(11)
    def SetColumn(self, element: win32more.Windows.UI.Xaml.FrameworkElement, value: Int32) -> Void: ...
    @winrt_commethod(12)
    def get_RowSpanProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def GetRowSpan(self, element: win32more.Windows.UI.Xaml.FrameworkElement) -> Int32: ...
    @winrt_commethod(14)
    def SetRowSpan(self, element: win32more.Windows.UI.Xaml.FrameworkElement, value: Int32) -> Void: ...
    @winrt_commethod(15)
    def get_ColumnSpanProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def GetColumnSpan(self, element: win32more.Windows.UI.Xaml.FrameworkElement) -> Int32: ...
    @winrt_commethod(17)
    def SetColumnSpan(self, element: win32more.Windows.UI.Xaml.FrameworkElement, value: Int32) -> Void: ...
    ColumnProperty = property(get_ColumnProperty, None)
    ColumnSpanProperty = property(get_ColumnSpanProperty, None)
    RowProperty = property(get_RowProperty, None)
    RowSpanProperty = property(get_RowSpanProperty, None)
class IGridStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGridStatics2'
    _iid_ = Guid('{2d666658-58b6-4a1b-841b-875ba93b5d6a}')
    @winrt_commethod(6)
    def get_BorderBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_BorderThicknessProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CornerRadiusProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PaddingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BorderBrushProperty = property(get_BorderBrushProperty, None)
    BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
class IGridStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGridStatics3'
    _iid_ = Guid('{c3fba437-5a0c-407a-9621-79545386d811}')
    @winrt_commethod(6)
    def get_RowSpacingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ColumnSpacingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ColumnSpacingProperty = property(get_ColumnSpacingProperty, None)
    RowSpacingProperty = property(get_RowSpacingProperty, None)
class IGridStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGridStatics4'
    _iid_ = Guid('{691af349-1f63-57aa-8726-9cdcc1b14c02}')
    @winrt_commethod(6)
    def get_BackgroundSizingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
class IGridView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGridView'
    _iid_ = Guid('{026ae934-b67e-4d80-8f72-8aa64b4d827b}')
class IGridViewFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGridViewFactory'
    _iid_ = Guid('{d9bcca89-09f9-4c6e-a83e-f199146f0e7d}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.GridView: ...
class IGridViewHeaderItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGridViewHeaderItem'
    _iid_ = Guid('{72d75d7e-5dc3-4ffc-9b1c-939b5c37161c}')
class IGridViewHeaderItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGridViewHeaderItemFactory'
    _iid_ = Guid('{36e0c96e-b56a-4b3b-8bac-7aef5e6f9945}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.GridViewHeaderItem: ...
class IGridViewItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGridViewItem'
    _iid_ = Guid('{7d9901f1-e7c1-4e83-b470-c9d6d7bda9f5}')
    @winrt_commethod(6)
    def get_TemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.GridViewItemTemplateSettings: ...
    TemplateSettings = property(get_TemplateSettings, None)
class IGridViewItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGridViewItemFactory'
    _iid_ = Guid('{229b00af-3fa6-43e9-979d-07ea0d6280dc}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.GridViewItem: ...
class IGroupItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGroupItem'
    _iid_ = Guid('{4ae8d5d1-7228-4a16-a61f-88c0e8f45c76}')
class IGroupItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGroupItemFactory'
    _iid_ = Guid('{d9a1d53e-b1e0-4319-9808-7a9e887e13b0}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.GroupItem: ...
class IGroupStyle(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGroupStyle'
    _iid_ = Guid('{71ca300b-b89e-4184-b0df-a9e95447de8d}')
    @winrt_commethod(6)
    def get_Panel(self) -> win32more.Windows.UI.Xaml.Controls.ItemsPanelTemplate: ...
    @winrt_commethod(7)
    def put_Panel(self, value: win32more.Windows.UI.Xaml.Controls.ItemsPanelTemplate) -> Void: ...
    @winrt_commethod(8)
    def get_ContainerStyle(self) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_commethod(9)
    def put_ContainerStyle(self, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(10)
    def get_ContainerStyleSelector(self) -> win32more.Windows.UI.Xaml.Controls.StyleSelector: ...
    @winrt_commethod(11)
    def put_ContainerStyleSelector(self, value: win32more.Windows.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_commethod(12)
    def get_HeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(13)
    def put_HeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(14)
    def get_HeaderTemplateSelector(self) -> win32more.Windows.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_commethod(15)
    def put_HeaderTemplateSelector(self, value: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_commethod(16)
    def get_HidesIfEmpty(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_HidesIfEmpty(self, value: Boolean) -> Void: ...
    ContainerStyle = property(get_ContainerStyle, put_ContainerStyle)
    ContainerStyleSelector = property(get_ContainerStyleSelector, put_ContainerStyleSelector)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HeaderTemplateSelector = property(get_HeaderTemplateSelector, put_HeaderTemplateSelector)
    HidesIfEmpty = property(get_HidesIfEmpty, put_HidesIfEmpty)
    Panel = property(get_Panel, put_Panel)
class IGroupStyle2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGroupStyle2'
    _iid_ = Guid('{69f90679-3a11-4fe7-b4df-2a0139d4018b}')
    @winrt_commethod(6)
    def get_HeaderContainerStyle(self) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_commethod(7)
    def put_HeaderContainerStyle(self, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    HeaderContainerStyle = property(get_HeaderContainerStyle, put_HeaderContainerStyle)
class IGroupStyleFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGroupStyleFactory'
    _iid_ = Guid('{56ff664f-e2d7-4f49-803d-c727cdf9372d}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.GroupStyle: ...
class IGroupStyleSelector(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGroupStyleSelector'
    _iid_ = Guid('{6dda119e-9a74-478f-a339-5bb52de6c51e}')
    @winrt_commethod(6)
    def SelectGroupStyle(self, group: win32more.Windows.Win32.System.WinRT.IInspectable, level: UInt32) -> win32more.Windows.UI.Xaml.Controls.GroupStyle: ...
class IGroupStyleSelectorFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGroupStyleSelectorFactory'
    _iid_ = Guid('{bf570d33-b2f6-481f-a450-c80c291fb22d}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.GroupStyleSelector: ...
class IGroupStyleSelectorOverrides(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IGroupStyleSelectorOverrides'
    _iid_ = Guid('{f691cab2-77ad-4d3d-a51c-8ef9c3836456}')
    @winrt_commethod(6)
    def SelectGroupStyleCore(self, group: win32more.Windows.Win32.System.WinRT.IInspectable, level: UInt32) -> win32more.Windows.UI.Xaml.Controls.GroupStyle: ...
class IHandwritingPanelClosedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHandwritingPanelClosedEventArgs'
    _iid_ = Guid('{4fb91c73-192d-4dd2-a1a2-80ed01125876}')
class IHandwritingPanelOpenedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHandwritingPanelOpenedEventArgs'
    _iid_ = Guid('{fc15b16d-9f15-47b0-b97a-94a68cc61345}')
class IHandwritingView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHandwritingView'
    _iid_ = Guid('{c44204a7-31e0-44bc-a38b-4bee64ecd99f}')
    @winrt_commethod(6)
    def get_PlacementTarget(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_PlacementTarget(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_PlacementAlignment(self) -> win32more.Windows.UI.Xaml.Controls.HandwritingPanelPlacementAlignment: ...
    @winrt_commethod(9)
    def put_PlacementAlignment(self, value: win32more.Windows.UI.Xaml.Controls.HandwritingPanelPlacementAlignment) -> Void: ...
    @winrt_commethod(10)
    def get_IsOpen(self) -> Boolean: ...
    @winrt_commethod(11)
    def get_AreCandidatesEnabled(self) -> Boolean: ...
    @winrt_commethod(12)
    def put_AreCandidatesEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(13)
    def add_Opened(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.HandwritingView, win32more.Windows.UI.Xaml.Controls.HandwritingPanelOpenedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(14)
    def remove_Opened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(15)
    def add_Closed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.HandwritingView, win32more.Windows.UI.Xaml.Controls.HandwritingPanelClosedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(16)
    def remove_Closed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(17)
    def TryClose(self) -> Boolean: ...
    @winrt_commethod(18)
    def TryOpen(self) -> Boolean: ...
    AreCandidatesEnabled = property(get_AreCandidatesEnabled, put_AreCandidatesEnabled)
    IsOpen = property(get_IsOpen, None)
    PlacementAlignment = property(get_PlacementAlignment, put_PlacementAlignment)
    PlacementTarget = property(get_PlacementTarget, put_PlacementTarget)
    Opened = event()
    Closed = event()
class IHandwritingView2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHandwritingView2'
    _iid_ = Guid('{4bcf991b-0de1-5c9e-8970-37b9878fe171}')
    @winrt_commethod(6)
    def get_IsSwitchToKeyboardEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsSwitchToKeyboardEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsCommandBarOpen(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsCommandBarOpen(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_InputDeviceTypes(self) -> win32more.Windows.UI.Core.CoreInputDeviceTypes: ...
    @winrt_commethod(11)
    def put_InputDeviceTypes(self, value: win32more.Windows.UI.Core.CoreInputDeviceTypes) -> Void: ...
    @winrt_commethod(12)
    def add_CandidatesChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.HandwritingView, win32more.Windows.UI.Xaml.Controls.HandwritingViewCandidatesChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_CandidatesChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_TextSubmitted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.HandwritingView, win32more.Windows.UI.Xaml.Controls.HandwritingViewTextSubmittedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_TextSubmitted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def GetCandidates(self, candidatesSessionId: UInt32) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(17)
    def SelectCandidate(self, candidatesSessionId: UInt32, selectedCandidateIndex: UInt32) -> Void: ...
    InputDeviceTypes = property(get_InputDeviceTypes, put_InputDeviceTypes)
    IsCommandBarOpen = property(get_IsCommandBarOpen, put_IsCommandBarOpen)
    IsSwitchToKeyboardEnabled = property(get_IsSwitchToKeyboardEnabled, put_IsSwitchToKeyboardEnabled)
    CandidatesChanged = event()
    TextSubmitted = event()
class IHandwritingViewCandidatesChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHandwritingViewCandidatesChangedEventArgs'
    _iid_ = Guid('{6f5f63d8-56b1-56c5-a416-c19c16bf7884}')
    @winrt_commethod(6)
    def get_CandidatesSessionId(self) -> UInt32: ...
    CandidatesSessionId = property(get_CandidatesSessionId, None)
class IHandwritingViewFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHandwritingViewFactory'
    _iid_ = Guid('{e00c873f-0012-475c-890c-97ae308642de}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.HandwritingView: ...
class IHandwritingViewStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHandwritingViewStatics'
    _iid_ = Guid('{bb7ceed0-cc5f-4004-b8c8-142e195f0618}')
    @winrt_commethod(6)
    def get_PlacementTargetProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PlacementAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsOpenProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_AreCandidatesEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AreCandidatesEnabledProperty = property(get_AreCandidatesEnabledProperty, None)
    IsOpenProperty = property(get_IsOpenProperty, None)
    PlacementAlignmentProperty = property(get_PlacementAlignmentProperty, None)
    PlacementTargetProperty = property(get_PlacementTargetProperty, None)
class IHandwritingViewStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHandwritingViewStatics2'
    _iid_ = Guid('{2cd052e4-d703-5183-a1be-7e285df978d9}')
    @winrt_commethod(6)
    def get_IsSwitchToKeyboardEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsCommandBarOpenProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsCommandBarOpenProperty = property(get_IsCommandBarOpenProperty, None)
    IsSwitchToKeyboardEnabledProperty = property(get_IsSwitchToKeyboardEnabledProperty, None)
class IHandwritingViewTextSubmittedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHandwritingViewTextSubmittedEventArgs'
    _iid_ = Guid('{55ac0f47-f5e4-55da-b8a3-d418b7564291}')
class IHub(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHub'
    _iid_ = Guid('{ae692e82-7314-4f51-ab11-2af1ed4a19f8}')
    @winrt_commethod(6)
    def get_Header(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_HeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_Orientation(self) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(11)
    def put_Orientation(self, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(12)
    def get_DefaultSectionIndex(self) -> Int32: ...
    @winrt_commethod(13)
    def put_DefaultSectionIndex(self, value: Int32) -> Void: ...
    @winrt_commethod(14)
    def get_Sections(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection]: ...
    @winrt_commethod(15)
    def get_SectionsInView(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection]: ...
    @winrt_commethod(16)
    def get_SectionHeaders(self) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_commethod(17)
    def add_SectionHeaderClick(self, handler: win32more.Windows.UI.Xaml.Controls.HubSectionHeaderClickEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_SectionHeaderClick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(19)
    def add_SectionsInViewChanged(self, handler: win32more.Windows.UI.Xaml.Controls.SectionsInViewChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(20)
    def remove_SectionsInViewChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(21)
    def ScrollToSection(self, section: win32more.Windows.UI.Xaml.Controls.HubSection) -> Void: ...
    DefaultSectionIndex = property(get_DefaultSectionIndex, put_DefaultSectionIndex)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    Orientation = property(get_Orientation, put_Orientation)
    SectionHeaders = property(get_SectionHeaders, None)
    Sections = property(get_Sections, None)
    SectionsInView = property(get_SectionsInView, None)
    SectionHeaderClick = event()
    SectionsInViewChanged = event()
class IHubFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHubFactory'
    _iid_ = Guid('{dca6b2ba-c6f5-4961-9953-c51873db5424}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Hub: ...
class IHubSection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHubSection'
    _iid_ = Guid('{a4e66cb7-7fdd-4fe0-ab49-c246639dccf9}')
    @winrt_commethod(6)
    def get_Header(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_HeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_ContentTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(11)
    def put_ContentTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(12)
    def get_IsHeaderInteractive(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsHeaderInteractive(self, value: Boolean) -> Void: ...
    ContentTemplate = property(get_ContentTemplate, put_ContentTemplate)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsHeaderInteractive = property(get_IsHeaderInteractive, put_IsHeaderInteractive)
class IHubSectionFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHubSectionFactory'
    _iid_ = Guid('{fff55fa2-ece4-4bba-aa3b-9804aef47883}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.HubSection: ...
class IHubSectionHeaderClickEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHubSectionHeaderClickEventArgs'
    _iid_ = Guid('{e1c5ef04-1edd-4112-aeeb-996c96400698}')
    @winrt_commethod(6)
    def get_Section(self) -> win32more.Windows.UI.Xaml.Controls.HubSection: ...
    Section = property(get_Section, None)
class IHubSectionStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHubSectionStatics'
    _iid_ = Guid('{12d2d85a-ea27-42d1-998b-61e52aed842b}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ContentTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_IsHeaderInteractiveProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ContentTemplateProperty = property(get_ContentTemplateProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IsHeaderInteractiveProperty = property(get_IsHeaderInteractiveProperty, None)
class IHubStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHubStatics'
    _iid_ = Guid('{0e6fa034-ad3c-4f32-b701-e24fab562028}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_OrientationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_DefaultSectionIndexProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_SemanticZoomOwnerProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsActiveViewProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IsZoomedInViewProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DefaultSectionIndexProperty = property(get_DefaultSectionIndexProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IsActiveViewProperty = property(get_IsActiveViewProperty, None)
    IsZoomedInViewProperty = property(get_IsZoomedInViewProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
    SemanticZoomOwnerProperty = property(get_SemanticZoomOwnerProperty, None)
class IHyperlinkButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHyperlinkButton'
    _iid_ = Guid('{ccebaca3-3b5c-4f4c-9bfd-86887bc79772}')
    @winrt_commethod(6)
    def get_NavigateUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def put_NavigateUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    NavigateUri = property(get_NavigateUri, put_NavigateUri)
class IHyperlinkButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHyperlinkButtonFactory'
    _iid_ = Guid('{43521bad-4e97-4da9-a64d-935dfd8cedf2}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.HyperlinkButton: ...
class IHyperlinkButtonStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IHyperlinkButtonStatics'
    _iid_ = Guid('{fbaeb5c7-cdb7-4263-b7d6-3c0d2904ed98}')
    @winrt_commethod(6)
    def get_NavigateUriProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    NavigateUriProperty = property(get_NavigateUriProperty, None)
class IIconElement(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IIconElement'
    _iid_ = Guid('{9af0803b-d04c-467a-bbd5-9b81f02d9a56}')
    @winrt_commethod(6)
    def get_Foreground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(7)
    def put_Foreground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    Foreground = property(get_Foreground, put_Foreground)
class IIconElementFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IIconElementFactory'
    _iid_ = Guid('{cf37a562-0424-43c7-8bea-720fba973ef1}')
class IIconElementStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IIconElementStatics'
    _iid_ = Guid('{be19a623-77cf-472f-82ea-047801d12012}')
    @winrt_commethod(6)
    def get_ForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ForegroundProperty = property(get_ForegroundProperty, None)
class IIconSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IIconSource'
    _iid_ = Guid('{92ec8d55-45eb-47a4-863c-91b224044f9b}')
    @winrt_commethod(6)
    def get_Foreground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(7)
    def put_Foreground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    Foreground = property(get_Foreground, put_Foreground)
class IIconSourceElement(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IIconSourceElement'
    _iid_ = Guid('{d7a64502-ddda-55cd-b4c9-e79abc8b0ea4}')
    @winrt_commethod(6)
    def get_IconSource(self) -> win32more.Windows.UI.Xaml.Controls.IconSource: ...
    @winrt_commethod(7)
    def put_IconSource(self, value: win32more.Windows.UI.Xaml.Controls.IconSource) -> Void: ...
    IconSource = property(get_IconSource, put_IconSource)
class IIconSourceElementFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IIconSourceElementFactory'
    _iid_ = Guid('{26b59fab-2092-5b95-b59e-f27f210689e7}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.IconSourceElement: ...
class IIconSourceElementStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IIconSourceElementStatics'
    _iid_ = Guid('{f37cfd45-f3d8-50ff-a1b8-0fba4ae61d79}')
    @winrt_commethod(6)
    def get_IconSourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IconSourceProperty = property(get_IconSourceProperty, None)
class IIconSourceFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IIconSourceFactory'
    _iid_ = Guid('{4d117cf1-1fd6-49d7-b483-02ec3de997d6}')
class IIconSourceStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IIconSourceStatics'
    _iid_ = Guid('{1d389dbe-1cd3-4f4f-83b0-55dc6387685b}')
    @winrt_commethod(6)
    def get_ForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ForegroundProperty = property(get_ForegroundProperty, None)
class IImage(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IImage'
    _iid_ = Guid('{495b7402-9af3-4e50-aa90-03388f3086d2}')
    @winrt_commethod(6)
    def get_Source(self) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(7)
    def put_Source(self, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(8)
    def get_Stretch(self) -> win32more.Windows.UI.Xaml.Media.Stretch: ...
    @winrt_commethod(9)
    def put_Stretch(self, value: win32more.Windows.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_commethod(10)
    def get_NineGrid(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(11)
    def put_NineGrid(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(12)
    def get_PlayToSource(self) -> win32more.Windows.Media.PlayTo.PlayToSource: ...
    @winrt_commethod(13)
    def add_ImageFailed(self, handler: win32more.Windows.UI.Xaml.ExceptionRoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(14)
    def remove_ImageFailed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(15)
    def add_ImageOpened(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(16)
    def remove_ImageOpened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    NineGrid = property(get_NineGrid, put_NineGrid)
    PlayToSource = property(get_PlayToSource, None)
    Source = property(get_Source, put_Source)
    Stretch = property(get_Stretch, put_Stretch)
    ImageFailed = event()
    ImageOpened = event()
class IImage2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IImage2'
    _iid_ = Guid('{f445119e-881f-48bb-873a-64417ca4f002}')
    @winrt_commethod(6)
    def GetAsCastingSource(self) -> win32more.Windows.Media.Casting.CastingSource: ...
class IImage3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IImage3'
    _iid_ = Guid('{06ebe792-47c2-4d92-a488-8cd685d06aca}')
    @winrt_commethod(6)
    def GetAlphaMask(self) -> win32more.Windows.UI.Composition.CompositionBrush: ...
class IImageStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IImageStatics'
    _iid_ = Guid('{89903772-c336-43d1-9d51-c3bbd5d5d691}')
    @winrt_commethod(6)
    def get_SourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_StretchProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_NineGridProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PlayToSourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    NineGridProperty = property(get_NineGridProperty, None)
    PlayToSourceProperty = property(get_PlayToSourceProperty, None)
    SourceProperty = property(get_SourceProperty, None)
    StretchProperty = property(get_StretchProperty, None)
class IInkCanvas(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkCanvas'
    _iid_ = Guid('{29443c28-8e48-4fc8-a473-35b0ba12acea}')
    @winrt_commethod(6)
    def get_InkPresenter(self) -> win32more.Windows.UI.Input.Inking.InkPresenter: ...
    InkPresenter = property(get_InkPresenter, None)
class IInkCanvasFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkCanvasFactory'
    _iid_ = Guid('{924ac2de-ab04-48f0-9653-e0f2da4dbf1a}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkCanvas: ...
class IInkToolbar(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbar'
    _iid_ = Guid('{3ddd0cca-51f0-486f-a03e-4ee13dc12bcb}')
    @winrt_commethod(6)
    def get_InitialControls(self) -> win32more.Windows.UI.Xaml.Controls.InkToolbarInitialControls: ...
    @winrt_commethod(7)
    def put_InitialControls(self, value: win32more.Windows.UI.Xaml.Controls.InkToolbarInitialControls) -> Void: ...
    @winrt_commethod(8)
    def get_Children(self) -> win32more.Windows.UI.Xaml.DependencyObjectCollection: ...
    @winrt_commethod(9)
    def get_ActiveTool(self) -> win32more.Windows.UI.Xaml.Controls.InkToolbarToolButton: ...
    @winrt_commethod(10)
    def put_ActiveTool(self, value: win32more.Windows.UI.Xaml.Controls.InkToolbarToolButton) -> Void: ...
    @winrt_commethod(11)
    def get_InkDrawingAttributes(self) -> win32more.Windows.UI.Input.Inking.InkDrawingAttributes: ...
    @winrt_commethod(12)
    def get_IsRulerButtonChecked(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsRulerButtonChecked(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_TargetInkCanvas(self) -> win32more.Windows.UI.Xaml.Controls.InkCanvas: ...
    @winrt_commethod(15)
    def put_TargetInkCanvas(self, value: win32more.Windows.UI.Xaml.Controls.InkCanvas) -> Void: ...
    @winrt_commethod(16)
    def add_ActiveToolChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.InkToolbar, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_ActiveToolChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def add_InkDrawingAttributesChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.InkToolbar, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_InkDrawingAttributesChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(20)
    def add_EraseAllClicked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.InkToolbar, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_EraseAllClicked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(22)
    def add_IsRulerButtonCheckedChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.InkToolbar, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(23)
    def remove_IsRulerButtonCheckedChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(24)
    def GetToolButton(self, tool: win32more.Windows.UI.Xaml.Controls.InkToolbarTool) -> win32more.Windows.UI.Xaml.Controls.InkToolbarToolButton: ...
    @winrt_commethod(25)
    def GetToggleButton(self, tool: win32more.Windows.UI.Xaml.Controls.InkToolbarToggle) -> win32more.Windows.UI.Xaml.Controls.InkToolbarToggleButton: ...
    ActiveTool = property(get_ActiveTool, put_ActiveTool)
    Children = property(get_Children, None)
    InitialControls = property(get_InitialControls, put_InitialControls)
    InkDrawingAttributes = property(get_InkDrawingAttributes, None)
    IsRulerButtonChecked = property(get_IsRulerButtonChecked, put_IsRulerButtonChecked)
    TargetInkCanvas = property(get_TargetInkCanvas, put_TargetInkCanvas)
    ActiveToolChanged = event()
    InkDrawingAttributesChanged = event()
    EraseAllClicked = event()
    IsRulerButtonCheckedChanged = event()
class IInkToolbar2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbar2'
    _iid_ = Guid('{86f0c111-b484-454a-ae78-1d25a33d1c67}')
    @winrt_commethod(6)
    def get_IsStencilButtonChecked(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsStencilButtonChecked(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_ButtonFlyoutPlacement(self) -> win32more.Windows.UI.Xaml.Controls.InkToolbarButtonFlyoutPlacement: ...
    @winrt_commethod(9)
    def put_ButtonFlyoutPlacement(self, value: win32more.Windows.UI.Xaml.Controls.InkToolbarButtonFlyoutPlacement) -> Void: ...
    @winrt_commethod(10)
    def get_Orientation(self) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(11)
    def put_Orientation(self, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(12)
    def add_IsStencilButtonCheckedChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.InkToolbar, win32more.Windows.UI.Xaml.Controls.InkToolbarIsStencilButtonCheckedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_IsStencilButtonCheckedChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def GetMenuButton(self, menu: win32more.Windows.UI.Xaml.Controls.InkToolbarMenuKind) -> win32more.Windows.UI.Xaml.Controls.InkToolbarMenuButton: ...
    ButtonFlyoutPlacement = property(get_ButtonFlyoutPlacement, put_ButtonFlyoutPlacement)
    IsStencilButtonChecked = property(get_IsStencilButtonChecked, put_IsStencilButtonChecked)
    Orientation = property(get_Orientation, put_Orientation)
    IsStencilButtonCheckedChanged = event()
class IInkToolbar3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbar3'
    _iid_ = Guid('{a8a6def0-7aa8-5326-b7c4-88ae25013362}')
    @winrt_commethod(6)
    def get_TargetInkPresenter(self) -> win32more.Windows.UI.Input.Inking.InkPresenter: ...
    @winrt_commethod(7)
    def put_TargetInkPresenter(self, value: win32more.Windows.UI.Input.Inking.InkPresenter) -> Void: ...
    TargetInkPresenter = property(get_TargetInkPresenter, put_TargetInkPresenter)
class IInkToolbarBallpointPenButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarBallpointPenButton'
    _iid_ = Guid('{158329f8-1e99-3acc-910f-9da2d872ae12}')
class IInkToolbarBallpointPenButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarBallpointPenButtonFactory'
    _iid_ = Guid('{2f0bd3e4-d754-4255-8ec4-00cd101296ab}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarBallpointPenButton: ...
class IInkToolbarCustomPen(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarCustomPen'
    _iid_ = Guid('{4082207b-2f3d-4e6a-8c27-fe61ef7e70eb}')
    @winrt_commethod(6)
    def CreateInkDrawingAttributes(self, brush: win32more.Windows.UI.Xaml.Media.Brush, strokeWidth: Double) -> win32more.Windows.UI.Input.Inking.InkDrawingAttributes: ...
class IInkToolbarCustomPenButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarCustomPenButton'
    _iid_ = Guid('{46024401-2b2a-4f3c-a53c-1a045a408efa}')
    @winrt_commethod(6)
    def get_CustomPen(self) -> win32more.Windows.UI.Xaml.Controls.InkToolbarCustomPen: ...
    @winrt_commethod(7)
    def put_CustomPen(self, value: win32more.Windows.UI.Xaml.Controls.InkToolbarCustomPen) -> Void: ...
    @winrt_commethod(8)
    def get_ConfigurationContent(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(9)
    def put_ConfigurationContent(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    ConfigurationContent = property(get_ConfigurationContent, put_ConfigurationContent)
    CustomPen = property(get_CustomPen, put_CustomPen)
class IInkToolbarCustomPenButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarCustomPenButtonFactory'
    _iid_ = Guid('{0f2ef0ba-c8b9-4c36-8987-94d3dafede18}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarCustomPenButton: ...
class IInkToolbarCustomPenButtonStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarCustomPenButtonStatics'
    _iid_ = Guid('{373c25f4-e555-4e85-a80d-da6b8433dbde}')
    @winrt_commethod(6)
    def get_CustomPenProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ConfigurationContentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ConfigurationContentProperty = property(get_ConfigurationContentProperty, None)
    CustomPenProperty = property(get_CustomPenProperty, None)
class IInkToolbarCustomPenFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarCustomPenFactory'
    _iid_ = Guid('{d214d636-f1aa-4f48-bf2c-a926caae4c60}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarCustomPen: ...
class IInkToolbarCustomPenOverrides(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarCustomPenOverrides'
    _iid_ = Guid('{9d22eb6c-1255-4256-b6bd-82c2fd273488}')
    @winrt_commethod(6)
    def CreateInkDrawingAttributesCore(self, brush: win32more.Windows.UI.Xaml.Media.Brush, strokeWidth: Double) -> win32more.Windows.UI.Input.Inking.InkDrawingAttributes: ...
class IInkToolbarCustomToggleButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarCustomToggleButton'
    _iid_ = Guid('{550c4d84-4f54-4fbe-b12b-e0a50aab0d05}')
class IInkToolbarCustomToggleButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarCustomToggleButtonFactory'
    _iid_ = Guid('{4a00374d-4cd2-4ed9-863e-83b8cf3fd2af}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarCustomToggleButton: ...
class IInkToolbarCustomToolButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarCustomToolButton'
    _iid_ = Guid('{9f98acd7-c605-4105-be10-3943a7c0da3c}')
    @winrt_commethod(6)
    def get_ConfigurationContent(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_ConfigurationContent(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    ConfigurationContent = property(get_ConfigurationContent, put_ConfigurationContent)
class IInkToolbarCustomToolButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarCustomToolButtonFactory'
    _iid_ = Guid('{c295fe4e-30eb-4130-a6b6-8c85d8e26e89}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarCustomToolButton: ...
class IInkToolbarCustomToolButtonStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarCustomToolButtonStatics'
    _iid_ = Guid('{11fe4cb9-bbac-4314-9344-92c6693ddeaf}')
    @winrt_commethod(6)
    def get_ConfigurationContentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ConfigurationContentProperty = property(get_ConfigurationContentProperty, None)
class IInkToolbarEraserButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarEraserButton'
    _iid_ = Guid('{4cbdb92e-5f5e-4b35-a41c-16ffb0283bc0}')
class IInkToolbarEraserButton2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarEraserButton2'
    _iid_ = Guid('{e7a59257-5ae8-436d-b2e2-93c200900ca0}')
    @winrt_commethod(6)
    def get_IsClearAllVisible(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsClearAllVisible(self, value: Boolean) -> Void: ...
    IsClearAllVisible = property(get_IsClearAllVisible, put_IsClearAllVisible)
class IInkToolbarEraserButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarEraserButtonFactory'
    _iid_ = Guid('{fd40611d-d1ba-4d67-af00-148036ad492c}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarEraserButton: ...
class IInkToolbarEraserButtonStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarEraserButtonStatics2'
    _iid_ = Guid('{038a1736-c5cd-4311-83f4-38cbf07c2066}')
    @winrt_commethod(6)
    def get_IsClearAllVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsClearAllVisibleProperty = property(get_IsClearAllVisibleProperty, None)
class IInkToolbarFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarFactory'
    _iid_ = Guid('{3947aa99-36b1-4374-ab5c-98bf07a4320b}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbar: ...
class IInkToolbarFlyoutItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarFlyoutItem'
    _iid_ = Guid('{92b68786-37ee-4915-9e89-e187564a889a}')
    @winrt_commethod(6)
    def get_Kind(self) -> win32more.Windows.UI.Xaml.Controls.InkToolbarFlyoutItemKind: ...
    @winrt_commethod(7)
    def put_Kind(self, value: win32more.Windows.UI.Xaml.Controls.InkToolbarFlyoutItemKind) -> Void: ...
    @winrt_commethod(8)
    def get_IsChecked(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsChecked(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def add_Checked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.InkToolbarFlyoutItem, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_Checked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def add_Unchecked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.InkToolbarFlyoutItem, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_Unchecked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    IsChecked = property(get_IsChecked, put_IsChecked)
    Kind = property(get_Kind, put_Kind)
    Checked = event()
    Unchecked = event()
class IInkToolbarFlyoutItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarFlyoutItemFactory'
    _iid_ = Guid('{352e7b93-803b-4f0e-8c72-9dfc0329329f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarFlyoutItem: ...
class IInkToolbarFlyoutItemStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarFlyoutItemStatics'
    _iid_ = Guid('{1fe54b64-4063-4a5f-b89c-9f58935ee379}')
    @winrt_commethod(6)
    def get_KindProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsCheckedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsCheckedProperty = property(get_IsCheckedProperty, None)
    KindProperty = property(get_KindProperty, None)
class IInkToolbarHighlighterButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarHighlighterButton'
    _iid_ = Guid('{0b3cc15b-7abf-487e-acc1-5b5048fee6d2}')
class IInkToolbarHighlighterButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarHighlighterButtonFactory'
    _iid_ = Guid('{7c334add-42ca-4943-94a4-23b5a6e55cf1}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarHighlighterButton: ...
class IInkToolbarIsStencilButtonCheckedChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarIsStencilButtonCheckedChangedEventArgs'
    _iid_ = Guid('{026edd26-d32b-4e28-a033-d5097662b292}')
    @winrt_commethod(6)
    def get_StencilButton(self) -> win32more.Windows.UI.Xaml.Controls.InkToolbarStencilButton: ...
    @winrt_commethod(7)
    def get_StencilKind(self) -> win32more.Windows.UI.Xaml.Controls.InkToolbarStencilKind: ...
    StencilButton = property(get_StencilButton, None)
    StencilKind = property(get_StencilKind, None)
class IInkToolbarMenuButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarMenuButton'
    _iid_ = Guid('{860ecae5-7633-4ea1-a209-50392d1aebd1}')
    @winrt_commethod(6)
    def get_MenuKind(self) -> win32more.Windows.UI.Xaml.Controls.InkToolbarMenuKind: ...
    @winrt_commethod(7)
    def get_IsExtensionGlyphShown(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_IsExtensionGlyphShown(self, value: Boolean) -> Void: ...
    IsExtensionGlyphShown = property(get_IsExtensionGlyphShown, put_IsExtensionGlyphShown)
    MenuKind = property(get_MenuKind, None)
class IInkToolbarMenuButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarMenuButtonFactory'
    _iid_ = Guid('{7a463a9d-5dc7-44a7-afd0-2b685cb9a96c}')
class IInkToolbarMenuButtonStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarMenuButtonStatics'
    _iid_ = Guid('{f03b17a6-b8b0-4a87-a961-37cd05d83137}')
    @winrt_commethod(6)
    def get_IsExtensionGlyphShownProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsExtensionGlyphShownProperty = property(get_IsExtensionGlyphShownProperty, None)
class IInkToolbarPenButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarPenButton'
    _iid_ = Guid('{e0b80c21-b032-40ee-a2b9-507f6ccb827b}')
    @winrt_commethod(6)
    def get_Palette(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Media.Brush]: ...
    @winrt_commethod(7)
    def put_Palette(self, value: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Media.Brush]) -> Void: ...
    @winrt_commethod(8)
    def get_MinStrokeWidth(self) -> Double: ...
    @winrt_commethod(9)
    def put_MinStrokeWidth(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_MaxStrokeWidth(self) -> Double: ...
    @winrt_commethod(11)
    def put_MaxStrokeWidth(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_SelectedBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(13)
    def get_SelectedBrushIndex(self) -> Int32: ...
    @winrt_commethod(14)
    def put_SelectedBrushIndex(self, value: Int32) -> Void: ...
    @winrt_commethod(15)
    def get_SelectedStrokeWidth(self) -> Double: ...
    @winrt_commethod(16)
    def put_SelectedStrokeWidth(self, value: Double) -> Void: ...
    MaxStrokeWidth = property(get_MaxStrokeWidth, put_MaxStrokeWidth)
    MinStrokeWidth = property(get_MinStrokeWidth, put_MinStrokeWidth)
    Palette = property(get_Palette, put_Palette)
    SelectedBrush = property(get_SelectedBrush, None)
    SelectedBrushIndex = property(get_SelectedBrushIndex, put_SelectedBrushIndex)
    SelectedStrokeWidth = property(get_SelectedStrokeWidth, put_SelectedStrokeWidth)
class IInkToolbarPenButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarPenButtonFactory'
    _iid_ = Guid('{b1463d21-59cb-4a83-92e1-692842797b2e}')
class IInkToolbarPenButtonStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarPenButtonStatics'
    _iid_ = Guid('{b922ce42-09f0-453d-8026-44daf2753f65}')
    @winrt_commethod(6)
    def get_PaletteProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_MinStrokeWidthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_MaxStrokeWidthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_SelectedBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_SelectedBrushIndexProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_SelectedStrokeWidthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    MaxStrokeWidthProperty = property(get_MaxStrokeWidthProperty, None)
    MinStrokeWidthProperty = property(get_MinStrokeWidthProperty, None)
    PaletteProperty = property(get_PaletteProperty, None)
    SelectedBrushIndexProperty = property(get_SelectedBrushIndexProperty, None)
    SelectedBrushProperty = property(get_SelectedBrushProperty, None)
    SelectedStrokeWidthProperty = property(get_SelectedStrokeWidthProperty, None)
class IInkToolbarPenConfigurationControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarPenConfigurationControl'
    _iid_ = Guid('{601ae5f6-28a5-44cc-89a6-380e91a572dd}')
    @winrt_commethod(6)
    def get_PenButton(self) -> win32more.Windows.UI.Xaml.Controls.InkToolbarPenButton: ...
    PenButton = property(get_PenButton, None)
class IInkToolbarPenConfigurationControlFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarPenConfigurationControlFactory'
    _iid_ = Guid('{67f065ee-f5e7-46eb-9187-8d3ca3af891b}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarPenConfigurationControl: ...
class IInkToolbarPenConfigurationControlStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarPenConfigurationControlStatics'
    _iid_ = Guid('{48a61bef-19ce-41bb-abe0-7c8726fae75e}')
    @winrt_commethod(6)
    def get_PenButtonProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    PenButtonProperty = property(get_PenButtonProperty, None)
class IInkToolbarPencilButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarPencilButton'
    _iid_ = Guid('{5b112832-1984-4148-9f25-382b35db087f}')
class IInkToolbarPencilButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarPencilButtonFactory'
    _iid_ = Guid('{db66d85f-cfd6-495f-93ab-b8566af9f8af}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarPencilButton: ...
class IInkToolbarRulerButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarRulerButton'
    _iid_ = Guid('{4a992832-1984-4148-9f25-382b35db087f}')
    @winrt_commethod(6)
    def get_Ruler(self) -> win32more.Windows.UI.Input.Inking.InkPresenterRuler: ...
    Ruler = property(get_Ruler, None)
class IInkToolbarRulerButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarRulerButtonFactory'
    _iid_ = Guid('{bb26d85f-cfd6-495f-93ab-b8566af9f8af}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarRulerButton: ...
class IInkToolbarRulerButtonStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarRulerButtonStatics'
    _iid_ = Guid('{bae75f65-be30-4bee-964b-ff9e498fee37}')
    @winrt_commethod(6)
    def get_RulerProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    RulerProperty = property(get_RulerProperty, None)
class IInkToolbarStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarStatics'
    _iid_ = Guid('{a3b493bb-cb4f-4e6b-a33d-f11e7a295efa}')
    @winrt_commethod(6)
    def get_InitialControlsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ChildrenProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ActiveToolProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_InkDrawingAttributesProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsRulerButtonCheckedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_TargetInkCanvasProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ActiveToolProperty = property(get_ActiveToolProperty, None)
    ChildrenProperty = property(get_ChildrenProperty, None)
    InitialControlsProperty = property(get_InitialControlsProperty, None)
    InkDrawingAttributesProperty = property(get_InkDrawingAttributesProperty, None)
    IsRulerButtonCheckedProperty = property(get_IsRulerButtonCheckedProperty, None)
    TargetInkCanvasProperty = property(get_TargetInkCanvasProperty, None)
class IInkToolbarStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarStatics2'
    _iid_ = Guid('{aac1f8f2-2c1f-4e9c-b3f3-31ff22b51c7a}')
    @winrt_commethod(6)
    def get_IsStencilButtonCheckedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ButtonFlyoutPlacementProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_OrientationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ButtonFlyoutPlacementProperty = property(get_ButtonFlyoutPlacementProperty, None)
    IsStencilButtonCheckedProperty = property(get_IsStencilButtonCheckedProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
class IInkToolbarStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarStatics3'
    _iid_ = Guid('{a0ee663d-b63f-516e-a0a4-0704c4544d62}')
    @winrt_commethod(6)
    def get_TargetInkPresenterProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    TargetInkPresenterProperty = property(get_TargetInkPresenterProperty, None)
class IInkToolbarStencilButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarStencilButton'
    _iid_ = Guid('{306a2616-5b40-4bf3-92b7-f1df936aeff5}')
    @winrt_commethod(6)
    def get_Ruler(self) -> win32more.Windows.UI.Input.Inking.InkPresenterRuler: ...
    @winrt_commethod(7)
    def get_Protractor(self) -> win32more.Windows.UI.Input.Inking.InkPresenterProtractor: ...
    @winrt_commethod(8)
    def get_SelectedStencil(self) -> win32more.Windows.UI.Xaml.Controls.InkToolbarStencilKind: ...
    @winrt_commethod(9)
    def put_SelectedStencil(self, value: win32more.Windows.UI.Xaml.Controls.InkToolbarStencilKind) -> Void: ...
    @winrt_commethod(10)
    def get_IsRulerItemVisible(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsRulerItemVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_IsProtractorItemVisible(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsProtractorItemVisible(self, value: Boolean) -> Void: ...
    IsProtractorItemVisible = property(get_IsProtractorItemVisible, put_IsProtractorItemVisible)
    IsRulerItemVisible = property(get_IsRulerItemVisible, put_IsRulerItemVisible)
    Protractor = property(get_Protractor, None)
    Ruler = property(get_Ruler, None)
    SelectedStencil = property(get_SelectedStencil, put_SelectedStencil)
class IInkToolbarStencilButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarStencilButtonFactory'
    _iid_ = Guid('{a20701d1-8a70-4d77-89d4-1730a3a58edf}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarStencilButton: ...
class IInkToolbarStencilButtonStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarStencilButtonStatics'
    _iid_ = Guid('{4748c07f-63e4-420d-939a-6b7243e9d124}')
    @winrt_commethod(6)
    def get_RulerProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ProtractorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_SelectedStencilProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_IsRulerItemVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsProtractorItemVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsProtractorItemVisibleProperty = property(get_IsProtractorItemVisibleProperty, None)
    IsRulerItemVisibleProperty = property(get_IsRulerItemVisibleProperty, None)
    ProtractorProperty = property(get_ProtractorProperty, None)
    RulerProperty = property(get_RulerProperty, None)
    SelectedStencilProperty = property(get_SelectedStencilProperty, None)
class IInkToolbarToggleButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarToggleButton'
    _iid_ = Guid('{b4a278fa-f5f0-4b1f-beb0-0b8a29905a4a}')
    @winrt_commethod(6)
    def get_ToggleKind(self) -> win32more.Windows.UI.Xaml.Controls.InkToolbarToggle: ...
    ToggleKind = property(get_ToggleKind, None)
class IInkToolbarToggleButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarToggleButtonFactory'
    _iid_ = Guid('{b2f90710-e5a1-4365-9d1a-e5b7ad8b9668}')
class IInkToolbarToolButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarToolButton'
    _iid_ = Guid('{5c5af41e-ccb7-4458-8064-a9849d31561b}')
    @winrt_commethod(6)
    def get_ToolKind(self) -> win32more.Windows.UI.Xaml.Controls.InkToolbarTool: ...
    @winrt_commethod(7)
    def get_IsExtensionGlyphShown(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_IsExtensionGlyphShown(self, value: Boolean) -> Void: ...
    IsExtensionGlyphShown = property(get_IsExtensionGlyphShown, put_IsExtensionGlyphShown)
    ToolKind = property(get_ToolKind, None)
class IInkToolbarToolButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarToolButtonFactory'
    _iid_ = Guid('{6293bf4b-89fe-4ed0-a1a6-88d3eba917b2}')
class IInkToolbarToolButtonStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInkToolbarToolButtonStatics'
    _iid_ = Guid('{9e097d18-d136-4ef6-b0fd-1a78c2884a01}')
    @winrt_commethod(6)
    def get_IsExtensionGlyphShownProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsExtensionGlyphShownProperty = property(get_IsExtensionGlyphShownProperty, None)
class IInsertionPanel(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IInsertionPanel'
    _iid_ = Guid('{6b8de08f-6527-4d39-bcbf-58b01da923d7}')
    @winrt_commethod(6)
    def GetInsertionIndexes(self, position: win32more.Windows.Foundation.Point, first: POINTER(Int32), second: POINTER(Int32)) -> Void: ...
class IIsTextTrimmedChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IIsTextTrimmedChangedEventArgs'
    _iid_ = Guid('{16f597cd-ebff-4fb4-8714-26147418b945}')
class IItemClickEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemClickEventArgs'
    _iid_ = Guid('{9c314242-f29a-494d-a3a5-d4c7b2a46852}')
    @winrt_commethod(6)
    def get_ClickedItem(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    ClickedItem = property(get_ClickedItem, None)
class IItemContainerGenerator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemContainerGenerator'
    _iid_ = Guid('{40765f00-83f0-4d7f-b1b8-f19de4f1d5da}')
    @winrt_commethod(6)
    def add_ItemsChanged(self, handler: win32more.Windows.UI.Xaml.Controls.Primitives.ItemsChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_ItemsChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def ItemFromContainer(self, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(9)
    def ContainerFromItem(self, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_commethod(10)
    def IndexFromContainer(self, container: win32more.Windows.UI.Xaml.DependencyObject) -> Int32: ...
    @winrt_commethod(11)
    def ContainerFromIndex(self, index: Int32) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_commethod(12)
    def GetItemContainerGeneratorForPanel(self, panel: win32more.Windows.UI.Xaml.Controls.Panel) -> win32more.Windows.UI.Xaml.Controls.ItemContainerGenerator: ...
    @winrt_commethod(13)
    def StartAt(self, position: win32more.Windows.UI.Xaml.Controls.Primitives.GeneratorPosition, direction: win32more.Windows.UI.Xaml.Controls.Primitives.GeneratorDirection, allowStartAtRealizedItem: Boolean) -> Void: ...
    @winrt_commethod(14)
    def Stop(self) -> Void: ...
    @winrt_commethod(15)
    def GenerateNext(self, isNewlyRealized: POINTER(Boolean)) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_commethod(16)
    def PrepareItemContainer(self, container: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_commethod(17)
    def RemoveAll(self) -> Void: ...
    @winrt_commethod(18)
    def Remove(self, position: win32more.Windows.UI.Xaml.Controls.Primitives.GeneratorPosition, count: Int32) -> Void: ...
    @winrt_commethod(19)
    def GeneratorPositionFromIndex(self, itemIndex: Int32) -> win32more.Windows.UI.Xaml.Controls.Primitives.GeneratorPosition: ...
    @winrt_commethod(20)
    def IndexFromGeneratorPosition(self, position: win32more.Windows.UI.Xaml.Controls.Primitives.GeneratorPosition) -> Int32: ...
    @winrt_commethod(21)
    def Recycle(self, position: win32more.Windows.UI.Xaml.Controls.Primitives.GeneratorPosition, count: Int32) -> Void: ...
    ItemsChanged = event()
class IItemContainerMapping(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemContainerMapping'
    _iid_ = Guid('{53c9f23a-f25d-446a-99b8-c7aeb839050f}')
    @winrt_commethod(6)
    def ItemFromContainer(self, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def ContainerFromItem(self, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_commethod(8)
    def IndexFromContainer(self, container: win32more.Windows.UI.Xaml.DependencyObject) -> Int32: ...
    @winrt_commethod(9)
    def ContainerFromIndex(self, index: Int32) -> win32more.Windows.UI.Xaml.DependencyObject: ...
class IItemsControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsControl'
    _iid_ = Guid('{f4a91dd8-d979-4381-8652-bda0342a765e}')
    @winrt_commethod(6)
    def get_ItemsSource(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_ItemsSource(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_Items(self) -> win32more.Windows.UI.Xaml.Controls.ItemCollection: ...
    @winrt_commethod(9)
    def get_ItemTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(10)
    def put_ItemTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(11)
    def get_ItemTemplateSelector(self) -> win32more.Windows.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_commethod(12)
    def put_ItemTemplateSelector(self, value: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_commethod(13)
    def get_ItemsPanel(self) -> win32more.Windows.UI.Xaml.Controls.ItemsPanelTemplate: ...
    @winrt_commethod(14)
    def put_ItemsPanel(self, value: win32more.Windows.UI.Xaml.Controls.ItemsPanelTemplate) -> Void: ...
    @winrt_commethod(15)
    def get_DisplayMemberPath(self) -> WinRT_String: ...
    @winrt_commethod(16)
    def put_DisplayMemberPath(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(17)
    def get_ItemContainerStyle(self) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_commethod(18)
    def put_ItemContainerStyle(self, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(19)
    def get_ItemContainerStyleSelector(self) -> win32more.Windows.UI.Xaml.Controls.StyleSelector: ...
    @winrt_commethod(20)
    def put_ItemContainerStyleSelector(self, value: win32more.Windows.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_commethod(21)
    def get_ItemContainerGenerator(self) -> win32more.Windows.UI.Xaml.Controls.ItemContainerGenerator: ...
    @winrt_commethod(22)
    def get_ItemContainerTransitions(self) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(23)
    def put_ItemContainerTransitions(self, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_commethod(24)
    def get_GroupStyle(self) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Windows.UI.Xaml.Controls.GroupStyle]: ...
    @winrt_commethod(25)
    def get_GroupStyleSelector(self) -> win32more.Windows.UI.Xaml.Controls.GroupStyleSelector: ...
    @winrt_commethod(26)
    def put_GroupStyleSelector(self, value: win32more.Windows.UI.Xaml.Controls.GroupStyleSelector) -> Void: ...
    @winrt_commethod(27)
    def get_IsGrouping(self) -> Boolean: ...
    DisplayMemberPath = property(get_DisplayMemberPath, put_DisplayMemberPath)
    GroupStyle = property(get_GroupStyle, None)
    GroupStyleSelector = property(get_GroupStyleSelector, put_GroupStyleSelector)
    IsGrouping = property(get_IsGrouping, None)
    ItemContainerGenerator = property(get_ItemContainerGenerator, None)
    ItemContainerStyle = property(get_ItemContainerStyle, put_ItemContainerStyle)
    ItemContainerStyleSelector = property(get_ItemContainerStyleSelector, put_ItemContainerStyleSelector)
    ItemContainerTransitions = property(get_ItemContainerTransitions, put_ItemContainerTransitions)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemTemplateSelector = property(get_ItemTemplateSelector, put_ItemTemplateSelector)
    Items = property(get_Items, None)
    ItemsPanel = property(get_ItemsPanel, put_ItemsPanel)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
class IItemsControl2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsControl2'
    _iid_ = Guid('{754c3266-0529-45e3-8748-bf747d158357}')
    @winrt_commethod(6)
    def get_ItemsPanelRoot(self) -> win32more.Windows.UI.Xaml.Controls.Panel: ...
    ItemsPanelRoot = property(get_ItemsPanelRoot, None)
class IItemsControl3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsControl3'
    _iid_ = Guid('{502b7489-aee4-4de3-a2ab-195ac20c4212}')
    @winrt_commethod(6)
    def GroupHeaderContainerFromItemContainer(self, itemContainer: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.DependencyObject: ...
class IItemsControlFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsControlFactory'
    _iid_ = Guid('{f7bbc359-f8fd-471c-bcb2-2c74be8ebf8c}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ItemsControl: ...
class IItemsControlOverrides(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsControlOverrides'
    _iid_ = Guid('{c79bb41b-a084-4301-a496-72971f364ed1}')
    @winrt_commethod(6)
    def IsItemItsOwnContainerOverride(self, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_commethod(7)
    def GetContainerForItemOverride(self) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_commethod(8)
    def ClearContainerForItemOverride(self, element: win32more.Windows.UI.Xaml.DependencyObject, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(9)
    def PrepareContainerForItemOverride(self, element: win32more.Windows.UI.Xaml.DependencyObject, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(10)
    def OnItemsChanged(self, e: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(11)
    def OnItemContainerStyleChanged(self, oldItemContainerStyle: win32more.Windows.UI.Xaml.Style, newItemContainerStyle: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(12)
    def OnItemContainerStyleSelectorChanged(self, oldItemContainerStyleSelector: win32more.Windows.UI.Xaml.Controls.StyleSelector, newItemContainerStyleSelector: win32more.Windows.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_commethod(13)
    def OnItemTemplateChanged(self, oldItemTemplate: win32more.Windows.UI.Xaml.DataTemplate, newItemTemplate: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(14)
    def OnItemTemplateSelectorChanged(self, oldItemTemplateSelector: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector, newItemTemplateSelector: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_commethod(15)
    def OnGroupStyleSelectorChanged(self, oldGroupStyleSelector: win32more.Windows.UI.Xaml.Controls.GroupStyleSelector, newGroupStyleSelector: win32more.Windows.UI.Xaml.Controls.GroupStyleSelector) -> Void: ...
class IItemsControlStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsControlStatics'
    _iid_ = Guid('{37dabd89-dcfb-45b8-9afe-874df097905e}')
    @winrt_commethod(6)
    def get_ItemsSourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ItemTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ItemTemplateSelectorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_ItemsPanelProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_DisplayMemberPathProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_ItemContainerStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ItemContainerStyleSelectorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_ItemContainerTransitionsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_GroupStyleSelectorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_IsGroupingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def GetItemsOwner(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.ItemsControl: ...
    @winrt_commethod(17)
    def ItemsControlFromItemContainer(self, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.ItemsControl: ...
    DisplayMemberPathProperty = property(get_DisplayMemberPathProperty, None)
    GroupStyleSelectorProperty = property(get_GroupStyleSelectorProperty, None)
    IsGroupingProperty = property(get_IsGroupingProperty, None)
    ItemContainerStyleProperty = property(get_ItemContainerStyleProperty, None)
    ItemContainerStyleSelectorProperty = property(get_ItemContainerStyleSelectorProperty, None)
    ItemContainerTransitionsProperty = property(get_ItemContainerTransitionsProperty, None)
    ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    ItemTemplateSelectorProperty = property(get_ItemTemplateSelectorProperty, None)
    ItemsPanelProperty = property(get_ItemsPanelProperty, None)
    ItemsSourceProperty = property(get_ItemsSourceProperty, None)
class IItemsPanelTemplate(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsPanelTemplate'
    _iid_ = Guid('{14ead768-34b2-4b97-bf3c-e8d73230a2aa}')
class IItemsPickedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsPickedEventArgs'
    _iid_ = Guid('{f95b9aac-a621-488e-9156-8ee31165be04}')
    @winrt_commethod(6)
    def get_AddedItems(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_commethod(7)
    def get_RemovedItems(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    AddedItems = property(get_AddedItems, None)
    RemovedItems = property(get_RemovedItems, None)
class IItemsPresenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsPresenter'
    _iid_ = Guid('{c271569b-6dca-4e2b-8e14-c55136b02a71}')
    @winrt_commethod(6)
    def get_Header(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_HeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_HeaderTransitions(self) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(11)
    def put_HeaderTransitions(self, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_commethod(12)
    def get_Padding(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(13)
    def put_Padding(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HeaderTransitions = property(get_HeaderTransitions, put_HeaderTransitions)
    Padding = property(get_Padding, put_Padding)
class IItemsPresenter2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsPresenter2'
    _iid_ = Guid('{5c04aa33-1df3-4731-a4c9-da818378d63d}')
    @winrt_commethod(6)
    def get_Footer(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Footer(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_FooterTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_FooterTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_FooterTransitions(self) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(11)
    def put_FooterTransitions(self, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    Footer = property(get_Footer, put_Footer)
    FooterTemplate = property(get_FooterTemplate, put_FooterTemplate)
    FooterTransitions = property(get_FooterTransitions, put_FooterTransitions)
class IItemsPresenterStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsPresenterStatics'
    _iid_ = Guid('{18de66cd-4a6c-4b2e-aa86-cb126c9a2920}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_HeaderTransitionsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PaddingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    HeaderTransitionsProperty = property(get_HeaderTransitionsProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
class IItemsPresenterStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsPresenterStatics2'
    _iid_ = Guid('{8971632e-7867-4d66-9630-29f1c5f7403f}')
    @winrt_commethod(6)
    def get_FooterProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_FooterTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_FooterTransitionsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    FooterProperty = property(get_FooterProperty, None)
    FooterTemplateProperty = property(get_FooterTemplateProperty, None)
    FooterTransitionsProperty = property(get_FooterTransitionsProperty, None)
class IItemsStackPanel(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsStackPanel'
    _iid_ = Guid('{df7ab79d-7ad5-4b58-9363-919af90226e6}')
    @winrt_commethod(6)
    def get_GroupPadding(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(7)
    def put_GroupPadding(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(8)
    def get_Orientation(self) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(9)
    def put_Orientation(self, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(10)
    def get_FirstCacheIndex(self) -> Int32: ...
    @winrt_commethod(11)
    def get_FirstVisibleIndex(self) -> Int32: ...
    @winrt_commethod(12)
    def get_LastVisibleIndex(self) -> Int32: ...
    @winrt_commethod(13)
    def get_LastCacheIndex(self) -> Int32: ...
    @winrt_commethod(14)
    def get_ScrollingDirection(self) -> win32more.Windows.UI.Xaml.Controls.PanelScrollingDirection: ...
    @winrt_commethod(15)
    def get_GroupHeaderPlacement(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.GroupHeaderPlacement: ...
    @winrt_commethod(16)
    def put_GroupHeaderPlacement(self, value: win32more.Windows.UI.Xaml.Controls.Primitives.GroupHeaderPlacement) -> Void: ...
    @winrt_commethod(17)
    def get_ItemsUpdatingScrollMode(self) -> win32more.Windows.UI.Xaml.Controls.ItemsUpdatingScrollMode: ...
    @winrt_commethod(18)
    def put_ItemsUpdatingScrollMode(self, value: win32more.Windows.UI.Xaml.Controls.ItemsUpdatingScrollMode) -> Void: ...
    @winrt_commethod(19)
    def get_CacheLength(self) -> Double: ...
    @winrt_commethod(20)
    def put_CacheLength(self, value: Double) -> Void: ...
    CacheLength = property(get_CacheLength, put_CacheLength)
    FirstCacheIndex = property(get_FirstCacheIndex, None)
    FirstVisibleIndex = property(get_FirstVisibleIndex, None)
    GroupHeaderPlacement = property(get_GroupHeaderPlacement, put_GroupHeaderPlacement)
    GroupPadding = property(get_GroupPadding, put_GroupPadding)
    ItemsUpdatingScrollMode = property(get_ItemsUpdatingScrollMode, put_ItemsUpdatingScrollMode)
    LastCacheIndex = property(get_LastCacheIndex, None)
    LastVisibleIndex = property(get_LastVisibleIndex, None)
    Orientation = property(get_Orientation, put_Orientation)
    ScrollingDirection = property(get_ScrollingDirection, None)
class IItemsStackPanel2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsStackPanel2'
    _iid_ = Guid('{eeeecdb0-00b4-4534-937b-56318b293e92}')
    @winrt_commethod(6)
    def get_AreStickyGroupHeadersEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_AreStickyGroupHeadersEnabled(self, value: Boolean) -> Void: ...
    AreStickyGroupHeadersEnabled = property(get_AreStickyGroupHeadersEnabled, put_AreStickyGroupHeadersEnabled)
class IItemsStackPanelStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsStackPanelStatics'
    _iid_ = Guid('{ca25d63f-044f-4b6b-b315-0b60e0b4f87d}')
    @winrt_commethod(6)
    def get_GroupPaddingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_OrientationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_GroupHeaderPlacementProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_CacheLengthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CacheLengthProperty = property(get_CacheLengthProperty, None)
    GroupHeaderPlacementProperty = property(get_GroupHeaderPlacementProperty, None)
    GroupPaddingProperty = property(get_GroupPaddingProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
class IItemsStackPanelStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsStackPanelStatics2'
    _iid_ = Guid('{3972eb2c-384a-48bf-adfd-772e2572c504}')
    @winrt_commethod(6)
    def get_AreStickyGroupHeadersEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AreStickyGroupHeadersEnabledProperty = property(get_AreStickyGroupHeadersEnabledProperty, None)
class IItemsWrapGrid(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsWrapGrid'
    _iid_ = Guid('{ddfe6b5f-ba88-4a7d-8a5b-e58caf0f4e2d}')
    @winrt_commethod(6)
    def get_GroupPadding(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(7)
    def put_GroupPadding(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(8)
    def get_Orientation(self) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(9)
    def put_Orientation(self, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(10)
    def get_MaximumRowsOrColumns(self) -> Int32: ...
    @winrt_commethod(11)
    def put_MaximumRowsOrColumns(self, value: Int32) -> Void: ...
    @winrt_commethod(12)
    def get_ItemWidth(self) -> Double: ...
    @winrt_commethod(13)
    def put_ItemWidth(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_ItemHeight(self) -> Double: ...
    @winrt_commethod(15)
    def put_ItemHeight(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_FirstCacheIndex(self) -> Int32: ...
    @winrt_commethod(17)
    def get_FirstVisibleIndex(self) -> Int32: ...
    @winrt_commethod(18)
    def get_LastVisibleIndex(self) -> Int32: ...
    @winrt_commethod(19)
    def get_LastCacheIndex(self) -> Int32: ...
    @winrt_commethod(20)
    def get_ScrollingDirection(self) -> win32more.Windows.UI.Xaml.Controls.PanelScrollingDirection: ...
    @winrt_commethod(21)
    def get_GroupHeaderPlacement(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.GroupHeaderPlacement: ...
    @winrt_commethod(22)
    def put_GroupHeaderPlacement(self, value: win32more.Windows.UI.Xaml.Controls.Primitives.GroupHeaderPlacement) -> Void: ...
    @winrt_commethod(23)
    def get_CacheLength(self) -> Double: ...
    @winrt_commethod(24)
    def put_CacheLength(self, value: Double) -> Void: ...
    CacheLength = property(get_CacheLength, put_CacheLength)
    FirstCacheIndex = property(get_FirstCacheIndex, None)
    FirstVisibleIndex = property(get_FirstVisibleIndex, None)
    GroupHeaderPlacement = property(get_GroupHeaderPlacement, put_GroupHeaderPlacement)
    GroupPadding = property(get_GroupPadding, put_GroupPadding)
    ItemHeight = property(get_ItemHeight, put_ItemHeight)
    ItemWidth = property(get_ItemWidth, put_ItemWidth)
    LastCacheIndex = property(get_LastCacheIndex, None)
    LastVisibleIndex = property(get_LastVisibleIndex, None)
    MaximumRowsOrColumns = property(get_MaximumRowsOrColumns, put_MaximumRowsOrColumns)
    Orientation = property(get_Orientation, put_Orientation)
    ScrollingDirection = property(get_ScrollingDirection, None)
class IItemsWrapGrid2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsWrapGrid2'
    _iid_ = Guid('{80c21c0f-63ec-4258-bd61-d4a6956c864a}')
    @winrt_commethod(6)
    def get_AreStickyGroupHeadersEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_AreStickyGroupHeadersEnabled(self, value: Boolean) -> Void: ...
    AreStickyGroupHeadersEnabled = property(get_AreStickyGroupHeadersEnabled, put_AreStickyGroupHeadersEnabled)
class IItemsWrapGridStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsWrapGridStatics'
    _iid_ = Guid('{4ec5427d-24a0-449a-b763-3077ba0f2dd5}')
    @winrt_commethod(6)
    def get_GroupPaddingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_OrientationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_MaximumRowsOrColumnsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_ItemWidthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_ItemHeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_GroupHeaderPlacementProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_CacheLengthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CacheLengthProperty = property(get_CacheLengthProperty, None)
    GroupHeaderPlacementProperty = property(get_GroupHeaderPlacementProperty, None)
    GroupPaddingProperty = property(get_GroupPaddingProperty, None)
    ItemHeightProperty = property(get_ItemHeightProperty, None)
    ItemWidthProperty = property(get_ItemWidthProperty, None)
    MaximumRowsOrColumnsProperty = property(get_MaximumRowsOrColumnsProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
class IItemsWrapGridStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IItemsWrapGridStatics2'
    _iid_ = Guid('{2e27d3f7-feaa-478d-bfd1-29338adc5a03}')
    @winrt_commethod(6)
    def get_AreStickyGroupHeadersEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AreStickyGroupHeadersEnabledProperty = property(get_AreStickyGroupHeadersEnabledProperty, None)
class IListBox(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListBox'
    _iid_ = Guid('{e9f3b9ff-8e91-4ecf-a707-c927f694f881}')
    @winrt_commethod(6)
    def get_SelectedItems(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_commethod(7)
    def get_SelectionMode(self) -> win32more.Windows.UI.Xaml.Controls.SelectionMode: ...
    @winrt_commethod(8)
    def put_SelectionMode(self, value: win32more.Windows.UI.Xaml.Controls.SelectionMode) -> Void: ...
    @winrt_commethod(9)
    def ScrollIntoView(self, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(10)
    def SelectAll(self) -> Void: ...
    SelectedItems = property(get_SelectedItems, None)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
class IListBox2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListBox2'
    _iid_ = Guid('{70572aba-8ad1-4085-9350-deee359294e3}')
    @winrt_commethod(6)
    def get_SingleSelectionFollowsFocus(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_SingleSelectionFollowsFocus(self, value: Boolean) -> Void: ...
    SingleSelectionFollowsFocus = property(get_SingleSelectionFollowsFocus, put_SingleSelectionFollowsFocus)
class IListBoxFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListBoxFactory'
    _iid_ = Guid('{60cdfda2-2f44-444b-9c94-b8c9fda46f59}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ListBox: ...
class IListBoxItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListBoxItem'
    _iid_ = Guid('{43c13323-6edf-4e4b-b6b2-3a93eec41d95}')
class IListBoxItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListBoxItemFactory'
    _iid_ = Guid('{4398b8d4-a3de-402c-b23d-190384b27ca8}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ListBoxItem: ...
class IListBoxStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListBoxStatics'
    _iid_ = Guid('{6d3f7f73-706a-4e53-a9aa-c9a53c9cdd70}')
    @winrt_commethod(6)
    def get_SelectionModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SelectionModeProperty = property(get_SelectionModeProperty, None)
class IListBoxStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListBoxStatics2'
    _iid_ = Guid('{0089adeb-b709-4c8d-b1ed-4a7d97ee7716}')
    @winrt_commethod(6)
    def get_SingleSelectionFollowsFocusProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SingleSelectionFollowsFocusProperty = property(get_SingleSelectionFollowsFocusProperty, None)
class IListPickerFlyout(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListPickerFlyout'
    _iid_ = Guid('{0f0cb9d7-e5f3-45e6-9063-ff7bbb193c47}')
    @winrt_commethod(6)
    def get_ItemsSource(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_ItemsSource(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_ItemTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_ItemTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_DisplayMemberPath(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_DisplayMemberPath(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_SelectionMode(self) -> win32more.Windows.UI.Xaml.Controls.ListPickerFlyoutSelectionMode: ...
    @winrt_commethod(13)
    def put_SelectionMode(self, value: win32more.Windows.UI.Xaml.Controls.ListPickerFlyoutSelectionMode) -> Void: ...
    @winrt_commethod(14)
    def get_SelectedIndex(self) -> Int32: ...
    @winrt_commethod(15)
    def put_SelectedIndex(self, value: Int32) -> Void: ...
    @winrt_commethod(16)
    def get_SelectedItem(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(17)
    def put_SelectedItem(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(18)
    def get_SelectedValue(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(19)
    def put_SelectedValue(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(20)
    def get_SelectedValuePath(self) -> WinRT_String: ...
    @winrt_commethod(21)
    def put_SelectedValuePath(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(22)
    def get_SelectedItems(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_commethod(23)
    def add_ItemsPicked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ListPickerFlyout, win32more.Windows.UI.Xaml.Controls.ItemsPickedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(24)
    def remove_ItemsPicked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(25)
    def ShowAtAsync(self, target: win32more.Windows.UI.Xaml.FrameworkElement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]]: ...
    DisplayMemberPath = property(get_DisplayMemberPath, put_DisplayMemberPath)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    SelectedIndex = property(get_SelectedIndex, put_SelectedIndex)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    SelectedItems = property(get_SelectedItems, None)
    SelectedValue = property(get_SelectedValue, put_SelectedValue)
    SelectedValuePath = property(get_SelectedValuePath, put_SelectedValuePath)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    ItemsPicked = event()
class IListPickerFlyoutPresenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListPickerFlyoutPresenter'
    _iid_ = Guid('{68155fb3-883e-417a-80d0-e2fd88410084}')
class IListPickerFlyoutStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListPickerFlyoutStatics'
    _iid_ = Guid('{fee25b97-8b96-4602-81d2-82fd8e0f7ea8}')
    @winrt_commethod(6)
    def get_ItemsSourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ItemTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DisplayMemberPathProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_SelectionModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_SelectedIndexProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_SelectedItemProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_SelectedValueProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_SelectedValuePathProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DisplayMemberPathProperty = property(get_DisplayMemberPathProperty, None)
    ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    ItemsSourceProperty = property(get_ItemsSourceProperty, None)
    SelectedIndexProperty = property(get_SelectedIndexProperty, None)
    SelectedItemProperty = property(get_SelectedItemProperty, None)
    SelectedValuePathProperty = property(get_SelectedValuePathProperty, None)
    SelectedValueProperty = property(get_SelectedValueProperty, None)
    SelectionModeProperty = property(get_SelectionModeProperty, None)
class IListView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListView'
    _iid_ = Guid('{f6ce8c6d-fe96-41ad-a64a-c2b81c4af7f8}')
class IListViewBase(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewBase'
    _iid_ = Guid('{3d0813ba-6890-4537-bfe5-796d9458edd6}')
    @winrt_commethod(6)
    def get_SelectedItems(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_commethod(7)
    def get_SelectionMode(self) -> win32more.Windows.UI.Xaml.Controls.ListViewSelectionMode: ...
    @winrt_commethod(8)
    def put_SelectionMode(self, value: win32more.Windows.UI.Xaml.Controls.ListViewSelectionMode) -> Void: ...
    @winrt_commethod(9)
    def get_IsSwipeEnabled(self) -> Boolean: ...
    @winrt_commethod(10)
    def put_IsSwipeEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(11)
    def get_CanDragItems(self) -> Boolean: ...
    @winrt_commethod(12)
    def put_CanDragItems(self, value: Boolean) -> Void: ...
    @winrt_commethod(13)
    def get_CanReorderItems(self) -> Boolean: ...
    @winrt_commethod(14)
    def put_CanReorderItems(self, value: Boolean) -> Void: ...
    @winrt_commethod(15)
    def get_IsItemClickEnabled(self) -> Boolean: ...
    @winrt_commethod(16)
    def put_IsItemClickEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(17)
    def get_DataFetchSize(self) -> Double: ...
    @winrt_commethod(18)
    def put_DataFetchSize(self, value: Double) -> Void: ...
    @winrt_commethod(19)
    def get_IncrementalLoadingThreshold(self) -> Double: ...
    @winrt_commethod(20)
    def put_IncrementalLoadingThreshold(self, value: Double) -> Void: ...
    @winrt_commethod(21)
    def get_IncrementalLoadingTrigger(self) -> win32more.Windows.UI.Xaml.Controls.IncrementalLoadingTrigger: ...
    @winrt_commethod(22)
    def put_IncrementalLoadingTrigger(self, value: win32more.Windows.UI.Xaml.Controls.IncrementalLoadingTrigger) -> Void: ...
    @winrt_commethod(23)
    def add_ItemClick(self, handler: win32more.Windows.UI.Xaml.Controls.ItemClickEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(24)
    def remove_ItemClick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(25)
    def add_DragItemsStarting(self, handler: win32more.Windows.UI.Xaml.Controls.DragItemsStartingEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(26)
    def remove_DragItemsStarting(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(27)
    def ScrollIntoView(self, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(28)
    def SelectAll(self) -> Void: ...
    @winrt_commethod(29)
    def LoadMoreItemsAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.UI.Xaml.Data.LoadMoreItemsResult]: ...
    @winrt_commethod(30)
    def ScrollIntoViewWithAlignment(self, item: win32more.Windows.Win32.System.WinRT.IInspectable, alignment: win32more.Windows.UI.Xaml.Controls.ScrollIntoViewAlignment) -> Void: ...
    @winrt_commethod(31)
    def get_Header(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(32)
    def put_Header(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(33)
    def get_HeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(34)
    def put_HeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(35)
    def get_HeaderTransitions(self) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(36)
    def put_HeaderTransitions(self, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    CanDragItems = property(get_CanDragItems, put_CanDragItems)
    CanReorderItems = property(get_CanReorderItems, put_CanReorderItems)
    DataFetchSize = property(get_DataFetchSize, put_DataFetchSize)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HeaderTransitions = property(get_HeaderTransitions, put_HeaderTransitions)
    IncrementalLoadingThreshold = property(get_IncrementalLoadingThreshold, put_IncrementalLoadingThreshold)
    IncrementalLoadingTrigger = property(get_IncrementalLoadingTrigger, put_IncrementalLoadingTrigger)
    IsItemClickEnabled = property(get_IsItemClickEnabled, put_IsItemClickEnabled)
    IsSwipeEnabled = property(get_IsSwipeEnabled, put_IsSwipeEnabled)
    SelectedItems = property(get_SelectedItems, None)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    ItemClick = event()
    DragItemsStarting = event()
class IListViewBase2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewBase2'
    _iid_ = Guid('{d1c2a4f7-78a3-4491-86e0-2ddebc007ac5}')
    @winrt_commethod(6)
    def get_ShowsScrollingPlaceholders(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_ShowsScrollingPlaceholders(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def add_ContainerContentChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ListViewBase, win32more.Windows.UI.Xaml.Controls.ContainerContentChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_ContainerContentChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def SetDesiredContainerUpdateDuration(self, duration: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(11)
    def get_Footer(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(12)
    def put_Footer(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(13)
    def get_FooterTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(14)
    def put_FooterTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(15)
    def get_FooterTransitions(self) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(16)
    def put_FooterTransitions(self, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    Footer = property(get_Footer, put_Footer)
    FooterTemplate = property(get_FooterTemplate, put_FooterTemplate)
    FooterTransitions = property(get_FooterTransitions, put_FooterTransitions)
    ShowsScrollingPlaceholders = property(get_ShowsScrollingPlaceholders, put_ShowsScrollingPlaceholders)
    ContainerContentChanging = event()
class IListViewBase3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewBase3'
    _iid_ = Guid('{b364c035-0a13-406f-a3fb-f30e7ddca94c}')
    @winrt_commethod(6)
    def get_ReorderMode(self) -> win32more.Windows.UI.Xaml.Controls.ListViewReorderMode: ...
    @winrt_commethod(7)
    def put_ReorderMode(self, value: win32more.Windows.UI.Xaml.Controls.ListViewReorderMode) -> Void: ...
    ReorderMode = property(get_ReorderMode, put_ReorderMode)
class IListViewBase4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewBase4'
    _iid_ = Guid('{18b7792b-11dc-4eb6-a7bc-741adb3eeb79}')
    @winrt_commethod(6)
    def get_SelectedRanges(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.UI.Xaml.Data.ItemIndexRange]: ...
    @winrt_commethod(7)
    def get_IsMultiSelectCheckBoxEnabled(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_IsMultiSelectCheckBoxEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(9)
    def add_DragItemsCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ListViewBase, win32more.Windows.UI.Xaml.Controls.DragItemsCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_DragItemsCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(11)
    def add_ChoosingItemContainer(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ListViewBase, win32more.Windows.UI.Xaml.Controls.ChoosingItemContainerEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_ChoosingItemContainer(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(13)
    def add_ChoosingGroupHeaderContainer(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ListViewBase, win32more.Windows.UI.Xaml.Controls.ChoosingGroupHeaderContainerEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(14)
    def remove_ChoosingGroupHeaderContainer(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(15)
    def SelectRange(self, itemIndexRange: win32more.Windows.UI.Xaml.Data.ItemIndexRange) -> Void: ...
    @winrt_commethod(16)
    def DeselectRange(self, itemIndexRange: win32more.Windows.UI.Xaml.Data.ItemIndexRange) -> Void: ...
    IsMultiSelectCheckBoxEnabled = property(get_IsMultiSelectCheckBoxEnabled, put_IsMultiSelectCheckBoxEnabled)
    SelectedRanges = property(get_SelectedRanges, None)
    DragItemsCompleted = event()
    ChoosingItemContainer = event()
    ChoosingGroupHeaderContainer = event()
class IListViewBase5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewBase5'
    _iid_ = Guid('{1a9c6e99-1719-4b80-b335-628331a07019}')
    @winrt_commethod(6)
    def get_SingleSelectionFollowsFocus(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_SingleSelectionFollowsFocus(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def IsDragSource(self) -> Boolean: ...
    SingleSelectionFollowsFocus = property(get_SingleSelectionFollowsFocus, put_SingleSelectionFollowsFocus)
class IListViewBase6(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewBase6'
    _iid_ = Guid('{f8a42637-965b-483b-94e5-e5c9fef0e352}')
    @winrt_commethod(6)
    def TryStartConnectedAnimationAsync(self, animation: win32more.Windows.UI.Xaml.Media.Animation.ConnectedAnimation, item: win32more.Windows.Win32.System.WinRT.IInspectable, elementName: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_commethod(7)
    def PrepareConnectedAnimation(self, key: WinRT_String, item: win32more.Windows.Win32.System.WinRT.IInspectable, elementName: WinRT_String) -> win32more.Windows.UI.Xaml.Media.Animation.ConnectedAnimation: ...
class IListViewBaseFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewBaseFactory'
    _iid_ = Guid('{e67e6c7f-150f-46d0-a6ac-c5002bd9ca53}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ListViewBase: ...
class IListViewBaseHeaderItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewBaseHeaderItem'
    _iid_ = Guid('{6d0ded27-0d19-4091-8917-ce7c85c1e630}')
class IListViewBaseHeaderItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewBaseHeaderItemFactory'
    _iid_ = Guid('{3872a6a1-ea19-455f-9df7-147cc41d329c}')
class IListViewBaseStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewBaseStatics'
    _iid_ = Guid('{8532b8f7-3e16-455b-89a8-c1346223f6d3}')
    @winrt_commethod(6)
    def get_SelectionModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsSwipeEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CanDragItemsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_CanReorderItemsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsItemClickEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_DataFetchSizeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IncrementalLoadingThresholdProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_IncrementalLoadingTriggerProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_SemanticZoomOwnerProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_IsActiveViewProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_IsZoomedInViewProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_HeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_HeaderTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_HeaderTransitionsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CanDragItemsProperty = property(get_CanDragItemsProperty, None)
    CanReorderItemsProperty = property(get_CanReorderItemsProperty, None)
    DataFetchSizeProperty = property(get_DataFetchSizeProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    HeaderTransitionsProperty = property(get_HeaderTransitionsProperty, None)
    IncrementalLoadingThresholdProperty = property(get_IncrementalLoadingThresholdProperty, None)
    IncrementalLoadingTriggerProperty = property(get_IncrementalLoadingTriggerProperty, None)
    IsActiveViewProperty = property(get_IsActiveViewProperty, None)
    IsItemClickEnabledProperty = property(get_IsItemClickEnabledProperty, None)
    IsSwipeEnabledProperty = property(get_IsSwipeEnabledProperty, None)
    IsZoomedInViewProperty = property(get_IsZoomedInViewProperty, None)
    SelectionModeProperty = property(get_SelectionModeProperty, None)
    SemanticZoomOwnerProperty = property(get_SemanticZoomOwnerProperty, None)
class IListViewBaseStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewBaseStatics2'
    _iid_ = Guid('{821c00c8-78cc-411f-9f2e-a55758227f3e}')
    @winrt_commethod(6)
    def get_ShowsScrollingPlaceholdersProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_FooterProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_FooterTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_FooterTransitionsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    FooterProperty = property(get_FooterProperty, None)
    FooterTemplateProperty = property(get_FooterTemplateProperty, None)
    FooterTransitionsProperty = property(get_FooterTransitionsProperty, None)
    ShowsScrollingPlaceholdersProperty = property(get_ShowsScrollingPlaceholdersProperty, None)
class IListViewBaseStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewBaseStatics3'
    _iid_ = Guid('{3b539091-31c6-4d0c-90af-5dc1d6ae9c05}')
    @winrt_commethod(6)
    def get_ReorderModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ReorderModeProperty = property(get_ReorderModeProperty, None)
class IListViewBaseStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewBaseStatics4'
    _iid_ = Guid('{ad13258b-fbd0-4f18-8bf8-9b8613951c22}')
    @winrt_commethod(6)
    def get_IsMultiSelectCheckBoxEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsMultiSelectCheckBoxEnabledProperty = property(get_IsMultiSelectCheckBoxEnabledProperty, None)
class IListViewBaseStatics5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewBaseStatics5'
    _iid_ = Guid('{40346fcf-0476-4259-895f-a6569738620f}')
    @winrt_commethod(6)
    def get_SingleSelectionFollowsFocusProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SingleSelectionFollowsFocusProperty = property(get_SingleSelectionFollowsFocusProperty, None)
class IListViewFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewFactory'
    _iid_ = Guid('{bdff696d-3f22-41f9-97a6-883134a76113}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ListView: ...
class IListViewHeaderItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewHeaderItem'
    _iid_ = Guid('{1b61baeb-e196-4b3b-a5f9-1ed636f3f79b}')
class IListViewHeaderItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewHeaderItemFactory'
    _iid_ = Guid('{68d2c96a-96b0-4f08-a7a5-f1086720a0fa}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ListViewHeaderItem: ...
class IListViewItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewItem'
    _iid_ = Guid('{b7bb4305-3dd9-43de-a8c0-c472f085bc11}')
    @winrt_commethod(6)
    def get_TemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.ListViewItemTemplateSettings: ...
    TemplateSettings = property(get_TemplateSettings, None)
class IListViewItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewItemFactory'
    _iid_ = Guid('{f431073d-9cac-42a2-82df-0f4490bc4e2e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ListViewItem: ...
class IListViewPersistenceHelper(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewPersistenceHelper'
    _iid_ = Guid('{05bde8a6-2191-4b4b-8c22-9b25676e806e}')
class IListViewPersistenceHelperStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IListViewPersistenceHelperStatics'
    _iid_ = Guid('{6d0c2b08-bb9b-44f9-8063-5c3f9c21884b}')
    @winrt_commethod(6)
    def GetRelativeScrollPosition(self, listViewBase: win32more.Windows.UI.Xaml.Controls.ListViewBase, itemToKeyHandler: win32more.Windows.UI.Xaml.Controls.ListViewItemToKeyHandler) -> WinRT_String: ...
    @winrt_commethod(7)
    def SetRelativeScrollPositionAsync(self, listViewBase: win32more.Windows.UI.Xaml.Controls.ListViewBase, relativeScrollPosition: WinRT_String, keyToItemHandler: win32more.Windows.UI.Xaml.Controls.ListViewKeyToItemHandler) -> win32more.Windows.Foundation.IAsyncAction: ...
class IMediaElement(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaElement'
    _iid_ = Guid('{a38ed2cf-13de-4299-ade2-ae18f74ed353}')
    @winrt_commethod(6)
    def get_PosterSource(self) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(7)
    def put_PosterSource(self, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(8)
    def get_Source(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(9)
    def put_Source(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(10)
    def get_IsMuted(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsMuted(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_IsAudioOnly(self) -> Boolean: ...
    @winrt_commethod(13)
    def get_AutoPlay(self) -> Boolean: ...
    @winrt_commethod(14)
    def put_AutoPlay(self, value: Boolean) -> Void: ...
    @winrt_commethod(15)
    def get_Volume(self) -> Double: ...
    @winrt_commethod(16)
    def put_Volume(self, value: Double) -> Void: ...
    @winrt_commethod(17)
    def get_Balance(self) -> Double: ...
    @winrt_commethod(18)
    def put_Balance(self, value: Double) -> Void: ...
    @winrt_commethod(19)
    def get_NaturalVideoHeight(self) -> Int32: ...
    @winrt_commethod(20)
    def get_NaturalVideoWidth(self) -> Int32: ...
    @winrt_commethod(21)
    def get_NaturalDuration(self) -> win32more.Windows.UI.Xaml.Duration: ...
    @winrt_commethod(22)
    def get_Position(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(23)
    def put_Position(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(24)
    def get_DownloadProgress(self) -> Double: ...
    @winrt_commethod(25)
    def get_BufferingProgress(self) -> Double: ...
    @winrt_commethod(26)
    def get_DownloadProgressOffset(self) -> Double: ...
    @winrt_commethod(27)
    def get_CurrentState(self) -> win32more.Windows.UI.Xaml.Media.MediaElementState: ...
    @winrt_commethod(28)
    def get_Markers(self) -> win32more.Windows.UI.Xaml.Media.TimelineMarkerCollection: ...
    @winrt_commethod(29)
    def get_CanSeek(self) -> Boolean: ...
    @winrt_commethod(30)
    def get_CanPause(self) -> Boolean: ...
    @winrt_commethod(31)
    def get_AudioStreamCount(self) -> Int32: ...
    @winrt_commethod(32)
    def get_AudioStreamIndex(self) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_commethod(33)
    def put_AudioStreamIndex(self, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    @winrt_commethod(34)
    def get_PlaybackRate(self) -> Double: ...
    @winrt_commethod(35)
    def put_PlaybackRate(self, value: Double) -> Void: ...
    @winrt_commethod(36)
    def get_IsLooping(self) -> Boolean: ...
    @winrt_commethod(37)
    def put_IsLooping(self, value: Boolean) -> Void: ...
    @winrt_commethod(38)
    def get_PlayToSource(self) -> win32more.Windows.Media.PlayTo.PlayToSource: ...
    @winrt_commethod(39)
    def get_DefaultPlaybackRate(self) -> Double: ...
    @winrt_commethod(40)
    def put_DefaultPlaybackRate(self, value: Double) -> Void: ...
    @winrt_commethod(41)
    def get_AspectRatioWidth(self) -> Int32: ...
    @winrt_commethod(42)
    def get_AspectRatioHeight(self) -> Int32: ...
    @winrt_commethod(43)
    def get_RealTimePlayback(self) -> Boolean: ...
    @winrt_commethod(44)
    def put_RealTimePlayback(self, value: Boolean) -> Void: ...
    @winrt_commethod(45)
    def get_AudioCategory(self) -> win32more.Windows.UI.Xaml.Media.AudioCategory: ...
    @winrt_commethod(46)
    def put_AudioCategory(self, value: win32more.Windows.UI.Xaml.Media.AudioCategory) -> Void: ...
    @winrt_commethod(47)
    def get_AudioDeviceType(self) -> win32more.Windows.UI.Xaml.Media.AudioDeviceType: ...
    @winrt_commethod(48)
    def put_AudioDeviceType(self, value: win32more.Windows.UI.Xaml.Media.AudioDeviceType) -> Void: ...
    @winrt_commethod(49)
    def get_ProtectionManager(self) -> win32more.Windows.Media.Protection.MediaProtectionManager: ...
    @winrt_commethod(50)
    def put_ProtectionManager(self, value: win32more.Windows.Media.Protection.MediaProtectionManager) -> Void: ...
    @winrt_commethod(51)
    def get_Stereo3DVideoPackingMode(self) -> win32more.Windows.UI.Xaml.Media.Stereo3DVideoPackingMode: ...
    @winrt_commethod(52)
    def put_Stereo3DVideoPackingMode(self, value: win32more.Windows.UI.Xaml.Media.Stereo3DVideoPackingMode) -> Void: ...
    @winrt_commethod(53)
    def get_Stereo3DVideoRenderMode(self) -> win32more.Windows.UI.Xaml.Media.Stereo3DVideoRenderMode: ...
    @winrt_commethod(54)
    def put_Stereo3DVideoRenderMode(self, value: win32more.Windows.UI.Xaml.Media.Stereo3DVideoRenderMode) -> Void: ...
    @winrt_commethod(55)
    def get_IsStereo3DVideo(self) -> Boolean: ...
    @winrt_commethod(56)
    def add_MediaOpened(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(57)
    def remove_MediaOpened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(58)
    def add_MediaEnded(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(59)
    def remove_MediaEnded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(60)
    def add_MediaFailed(self, handler: win32more.Windows.UI.Xaml.ExceptionRoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(61)
    def remove_MediaFailed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(62)
    def add_DownloadProgressChanged(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(63)
    def remove_DownloadProgressChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(64)
    def add_BufferingProgressChanged(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(65)
    def remove_BufferingProgressChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(66)
    def add_CurrentStateChanged(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(67)
    def remove_CurrentStateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(68)
    def add_MarkerReached(self, handler: win32more.Windows.UI.Xaml.Media.TimelineMarkerRoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(69)
    def remove_MarkerReached(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(70)
    def add_RateChanged(self, handler: win32more.Windows.UI.Xaml.Media.RateChangedRoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(71)
    def remove_RateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(72)
    def add_VolumeChanged(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(73)
    def remove_VolumeChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(74)
    def add_SeekCompleted(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(75)
    def remove_SeekCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(76)
    def Stop(self) -> Void: ...
    @winrt_commethod(77)
    def Play(self) -> Void: ...
    @winrt_commethod(78)
    def Pause(self) -> Void: ...
    @winrt_commethod(79)
    def CanPlayType(self, type: WinRT_String) -> win32more.Windows.UI.Xaml.Media.MediaCanPlayResponse: ...
    @winrt_commethod(80)
    def SetSource(self, stream: win32more.Windows.Storage.Streams.IRandomAccessStream, mimeType: WinRT_String) -> Void: ...
    @winrt_commethod(81)
    def GetAudioStreamLanguage(self, index: win32more.Windows.Foundation.IReference[Int32]) -> WinRT_String: ...
    @winrt_commethod(82)
    def AddAudioEffect(self, effectID: WinRT_String, effectOptional: Boolean, effectConfiguration: win32more.Windows.Foundation.Collections.IPropertySet) -> Void: ...
    @winrt_commethod(83)
    def AddVideoEffect(self, effectID: WinRT_String, effectOptional: Boolean, effectConfiguration: win32more.Windows.Foundation.Collections.IPropertySet) -> Void: ...
    @winrt_commethod(84)
    def RemoveAllEffects(self) -> Void: ...
    @winrt_commethod(85)
    def get_ActualStereo3DVideoPackingMode(self) -> win32more.Windows.UI.Xaml.Media.Stereo3DVideoPackingMode: ...
    ActualStereo3DVideoPackingMode = property(get_ActualStereo3DVideoPackingMode, None)
    AspectRatioHeight = property(get_AspectRatioHeight, None)
    AspectRatioWidth = property(get_AspectRatioWidth, None)
    AudioCategory = property(get_AudioCategory, put_AudioCategory)
    AudioDeviceType = property(get_AudioDeviceType, put_AudioDeviceType)
    AudioStreamCount = property(get_AudioStreamCount, None)
    AudioStreamIndex = property(get_AudioStreamIndex, put_AudioStreamIndex)
    AutoPlay = property(get_AutoPlay, put_AutoPlay)
    Balance = property(get_Balance, put_Balance)
    BufferingProgress = property(get_BufferingProgress, None)
    CanPause = property(get_CanPause, None)
    CanSeek = property(get_CanSeek, None)
    CurrentState = property(get_CurrentState, None)
    DefaultPlaybackRate = property(get_DefaultPlaybackRate, put_DefaultPlaybackRate)
    DownloadProgress = property(get_DownloadProgress, None)
    DownloadProgressOffset = property(get_DownloadProgressOffset, None)
    IsAudioOnly = property(get_IsAudioOnly, None)
    IsLooping = property(get_IsLooping, put_IsLooping)
    IsMuted = property(get_IsMuted, put_IsMuted)
    IsStereo3DVideo = property(get_IsStereo3DVideo, None)
    Markers = property(get_Markers, None)
    NaturalDuration = property(get_NaturalDuration, None)
    NaturalVideoHeight = property(get_NaturalVideoHeight, None)
    NaturalVideoWidth = property(get_NaturalVideoWidth, None)
    PlayToSource = property(get_PlayToSource, None)
    PlaybackRate = property(get_PlaybackRate, put_PlaybackRate)
    Position = property(get_Position, put_Position)
    PosterSource = property(get_PosterSource, put_PosterSource)
    ProtectionManager = property(get_ProtectionManager, put_ProtectionManager)
    RealTimePlayback = property(get_RealTimePlayback, put_RealTimePlayback)
    Source = property(get_Source, put_Source)
    Stereo3DVideoPackingMode = property(get_Stereo3DVideoPackingMode, put_Stereo3DVideoPackingMode)
    Stereo3DVideoRenderMode = property(get_Stereo3DVideoRenderMode, put_Stereo3DVideoRenderMode)
    Volume = property(get_Volume, put_Volume)
    MediaOpened = event()
    MediaEnded = event()
    MediaFailed = event()
    DownloadProgressChanged = event()
    BufferingProgressChanged = event()
    CurrentStateChanged = event()
    MarkerReached = event()
    RateChanged = event()
    VolumeChanged = event()
    SeekCompleted = event()
class IMediaElement2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaElement2'
    _iid_ = Guid('{fd53da65-b186-4654-bfdb-180ed26cad07}')
    @winrt_commethod(6)
    def get_AreTransportControlsEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_AreTransportControlsEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Stretch(self) -> win32more.Windows.UI.Xaml.Media.Stretch: ...
    @winrt_commethod(9)
    def put_Stretch(self, value: win32more.Windows.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_commethod(10)
    def get_IsFullWindow(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsFullWindow(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def SetMediaStreamSource(self, source: win32more.Windows.Media.Core.IMediaSource) -> Void: ...
    @winrt_commethod(13)
    def get_PlayToPreferredSourceUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(14)
    def put_PlayToPreferredSourceUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    AreTransportControlsEnabled = property(get_AreTransportControlsEnabled, put_AreTransportControlsEnabled)
    IsFullWindow = property(get_IsFullWindow, put_IsFullWindow)
    PlayToPreferredSourceUri = property(get_PlayToPreferredSourceUri, put_PlayToPreferredSourceUri)
    Stretch = property(get_Stretch, put_Stretch)
class IMediaElement3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaElement3'
    _iid_ = Guid('{479f6f13-0fdb-4ed8-928a-4d39169c3cd2}')
    @winrt_commethod(6)
    def get_TransportControls(self) -> win32more.Windows.UI.Xaml.Controls.MediaTransportControls: ...
    @winrt_commethod(7)
    def put_TransportControls(self, value: win32more.Windows.UI.Xaml.Controls.MediaTransportControls) -> Void: ...
    @winrt_commethod(8)
    def add_PartialMediaFailureDetected(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.MediaElement, win32more.Windows.UI.Xaml.Media.PartialMediaFailureDetectedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_PartialMediaFailureDetected(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def SetPlaybackSource(self, source: win32more.Windows.Media.Playback.IMediaPlaybackSource) -> Void: ...
    @winrt_commethod(11)
    def GetAsCastingSource(self) -> win32more.Windows.Media.Casting.CastingSource: ...
    TransportControls = property(get_TransportControls, put_TransportControls)
    PartialMediaFailureDetected = event()
class IMediaElementStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaElementStatics'
    _iid_ = Guid('{dccd2cb9-7568-4682-a72a-8ddf2a2665ca}')
    @winrt_commethod(6)
    def get_PosterSourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_SourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsMutedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_IsAudioOnlyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_AutoPlayProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_VolumeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_BalanceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_NaturalVideoHeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_NaturalVideoWidthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_NaturalDurationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_PositionProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_DownloadProgressProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_BufferingProgressProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_DownloadProgressOffsetProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_CurrentStateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_CanSeekProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_CanPauseProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_AudioStreamCountProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_AudioStreamIndexProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_PlaybackRateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def get_IsLoopingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(27)
    def get_PlayToSourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(28)
    def get_DefaultPlaybackRateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(29)
    def get_AspectRatioWidthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(30)
    def get_AspectRatioHeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(31)
    def get_RealTimePlaybackProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(32)
    def get_AudioCategoryProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(33)
    def get_AudioDeviceTypeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(34)
    def get_ProtectionManagerProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(35)
    def get_Stereo3DVideoPackingModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(36)
    def get_Stereo3DVideoRenderModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(37)
    def get_IsStereo3DVideoProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(38)
    def get_ActualStereo3DVideoPackingModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ActualStereo3DVideoPackingModeProperty = property(get_ActualStereo3DVideoPackingModeProperty, None)
    AspectRatioHeightProperty = property(get_AspectRatioHeightProperty, None)
    AspectRatioWidthProperty = property(get_AspectRatioWidthProperty, None)
    AudioCategoryProperty = property(get_AudioCategoryProperty, None)
    AudioDeviceTypeProperty = property(get_AudioDeviceTypeProperty, None)
    AudioStreamCountProperty = property(get_AudioStreamCountProperty, None)
    AudioStreamIndexProperty = property(get_AudioStreamIndexProperty, None)
    AutoPlayProperty = property(get_AutoPlayProperty, None)
    BalanceProperty = property(get_BalanceProperty, None)
    BufferingProgressProperty = property(get_BufferingProgressProperty, None)
    CanPauseProperty = property(get_CanPauseProperty, None)
    CanSeekProperty = property(get_CanSeekProperty, None)
    CurrentStateProperty = property(get_CurrentStateProperty, None)
    DefaultPlaybackRateProperty = property(get_DefaultPlaybackRateProperty, None)
    DownloadProgressOffsetProperty = property(get_DownloadProgressOffsetProperty, None)
    DownloadProgressProperty = property(get_DownloadProgressProperty, None)
    IsAudioOnlyProperty = property(get_IsAudioOnlyProperty, None)
    IsLoopingProperty = property(get_IsLoopingProperty, None)
    IsMutedProperty = property(get_IsMutedProperty, None)
    IsStereo3DVideoProperty = property(get_IsStereo3DVideoProperty, None)
    NaturalDurationProperty = property(get_NaturalDurationProperty, None)
    NaturalVideoHeightProperty = property(get_NaturalVideoHeightProperty, None)
    NaturalVideoWidthProperty = property(get_NaturalVideoWidthProperty, None)
    PlayToSourceProperty = property(get_PlayToSourceProperty, None)
    PlaybackRateProperty = property(get_PlaybackRateProperty, None)
    PositionProperty = property(get_PositionProperty, None)
    PosterSourceProperty = property(get_PosterSourceProperty, None)
    ProtectionManagerProperty = property(get_ProtectionManagerProperty, None)
    RealTimePlaybackProperty = property(get_RealTimePlaybackProperty, None)
    SourceProperty = property(get_SourceProperty, None)
    Stereo3DVideoPackingModeProperty = property(get_Stereo3DVideoPackingModeProperty, None)
    Stereo3DVideoRenderModeProperty = property(get_Stereo3DVideoRenderModeProperty, None)
    VolumeProperty = property(get_VolumeProperty, None)
class IMediaElementStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaElementStatics2'
    _iid_ = Guid('{9ee7f826-f154-4dc6-8014-a6eba987f847}')
    @winrt_commethod(6)
    def get_AreTransportControlsEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_StretchProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsFullWindowProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PlayToPreferredSourceUriProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AreTransportControlsEnabledProperty = property(get_AreTransportControlsEnabledProperty, None)
    IsFullWindowProperty = property(get_IsFullWindowProperty, None)
    PlayToPreferredSourceUriProperty = property(get_PlayToPreferredSourceUriProperty, None)
    StretchProperty = property(get_StretchProperty, None)
class IMediaPlayerElement(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaPlayerElement'
    _iid_ = Guid('{3b4ca526-2e25-4598-bc71-d491f8e8de39}')
    @winrt_commethod(6)
    def get_Source(self) -> win32more.Windows.Media.Playback.IMediaPlaybackSource: ...
    @winrt_commethod(7)
    def put_Source(self, value: win32more.Windows.Media.Playback.IMediaPlaybackSource) -> Void: ...
    @winrt_commethod(8)
    def get_TransportControls(self) -> win32more.Windows.UI.Xaml.Controls.MediaTransportControls: ...
    @winrt_commethod(9)
    def put_TransportControls(self, value: win32more.Windows.UI.Xaml.Controls.MediaTransportControls) -> Void: ...
    @winrt_commethod(10)
    def get_AreTransportControlsEnabled(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_AreTransportControlsEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_PosterSource(self) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(13)
    def put_PosterSource(self, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(14)
    def get_Stretch(self) -> win32more.Windows.UI.Xaml.Media.Stretch: ...
    @winrt_commethod(15)
    def put_Stretch(self, value: win32more.Windows.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_commethod(16)
    def get_AutoPlay(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_AutoPlay(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_IsFullWindow(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_IsFullWindow(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_MediaPlayer(self) -> win32more.Windows.Media.Playback.MediaPlayer: ...
    @winrt_commethod(21)
    def SetMediaPlayer(self, mediaPlayer: win32more.Windows.Media.Playback.MediaPlayer) -> Void: ...
    AreTransportControlsEnabled = property(get_AreTransportControlsEnabled, put_AreTransportControlsEnabled)
    AutoPlay = property(get_AutoPlay, put_AutoPlay)
    IsFullWindow = property(get_IsFullWindow, put_IsFullWindow)
    MediaPlayer = property(get_MediaPlayer, None)
    PosterSource = property(get_PosterSource, put_PosterSource)
    Source = property(get_Source, put_Source)
    Stretch = property(get_Stretch, put_Stretch)
    TransportControls = property(get_TransportControls, put_TransportControls)
class IMediaPlayerElementFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaPlayerElementFactory'
    _iid_ = Guid('{77e525c3-eb17-4b8d-889d-1ea8abdbd4ef}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MediaPlayerElement: ...
class IMediaPlayerElementStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaPlayerElementStatics'
    _iid_ = Guid('{1e7c4020-ac57-42dd-ad1c-3ebc2d7f08ba}')
    @winrt_commethod(6)
    def get_SourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_AreTransportControlsEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PosterSourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_StretchProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_AutoPlayProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsFullWindowProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_MediaPlayerProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AreTransportControlsEnabledProperty = property(get_AreTransportControlsEnabledProperty, None)
    AutoPlayProperty = property(get_AutoPlayProperty, None)
    IsFullWindowProperty = property(get_IsFullWindowProperty, None)
    MediaPlayerProperty = property(get_MediaPlayerProperty, None)
    PosterSourceProperty = property(get_PosterSourceProperty, None)
    SourceProperty = property(get_SourceProperty, None)
    StretchProperty = property(get_StretchProperty, None)
class IMediaPlayerPresenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaPlayerPresenter'
    _iid_ = Guid('{77a92326-0c5b-41fc-bf49-15f6c3524b6b}')
    @winrt_commethod(6)
    def get_MediaPlayer(self) -> win32more.Windows.Media.Playback.MediaPlayer: ...
    @winrt_commethod(7)
    def put_MediaPlayer(self, value: win32more.Windows.Media.Playback.MediaPlayer) -> Void: ...
    @winrt_commethod(8)
    def get_Stretch(self) -> win32more.Windows.UI.Xaml.Media.Stretch: ...
    @winrt_commethod(9)
    def put_Stretch(self, value: win32more.Windows.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_commethod(10)
    def get_IsFullWindow(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsFullWindow(self, value: Boolean) -> Void: ...
    IsFullWindow = property(get_IsFullWindow, put_IsFullWindow)
    MediaPlayer = property(get_MediaPlayer, put_MediaPlayer)
    Stretch = property(get_Stretch, put_Stretch)
class IMediaPlayerPresenterFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaPlayerPresenterFactory'
    _iid_ = Guid('{e6766fb7-d96f-4b95-b33c-59e81cb1e9ba}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MediaPlayerPresenter: ...
class IMediaPlayerPresenterStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaPlayerPresenterStatics'
    _iid_ = Guid('{84d774fe-ead4-4957-b42b-223158ca0de7}')
    @winrt_commethod(6)
    def get_MediaPlayerProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_StretchProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsFullWindowProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsFullWindowProperty = property(get_IsFullWindowProperty, None)
    MediaPlayerProperty = property(get_MediaPlayerProperty, None)
    StretchProperty = property(get_StretchProperty, None)
class IMediaTransportControls(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaTransportControls'
    _iid_ = Guid('{d6f69e7d-0825-49a9-9fce-5586d8694f0c}')
    @winrt_commethod(6)
    def get_IsFullWindowButtonVisible(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsFullWindowButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsFullWindowEnabled(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsFullWindowEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_IsZoomButtonVisible(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsZoomButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_IsZoomEnabled(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsZoomEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_IsFastForwardButtonVisible(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsFastForwardButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_IsFastForwardEnabled(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsFastForwardEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_IsFastRewindButtonVisible(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_IsFastRewindButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_IsFastRewindEnabled(self) -> Boolean: ...
    @winrt_commethod(21)
    def put_IsFastRewindEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(22)
    def get_IsStopButtonVisible(self) -> Boolean: ...
    @winrt_commethod(23)
    def put_IsStopButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(24)
    def get_IsStopEnabled(self) -> Boolean: ...
    @winrt_commethod(25)
    def put_IsStopEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(26)
    def get_IsVolumeButtonVisible(self) -> Boolean: ...
    @winrt_commethod(27)
    def put_IsVolumeButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(28)
    def get_IsVolumeEnabled(self) -> Boolean: ...
    @winrt_commethod(29)
    def put_IsVolumeEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(30)
    def get_IsPlaybackRateButtonVisible(self) -> Boolean: ...
    @winrt_commethod(31)
    def put_IsPlaybackRateButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(32)
    def get_IsPlaybackRateEnabled(self) -> Boolean: ...
    @winrt_commethod(33)
    def put_IsPlaybackRateEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(34)
    def get_IsSeekBarVisible(self) -> Boolean: ...
    @winrt_commethod(35)
    def put_IsSeekBarVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(36)
    def get_IsSeekEnabled(self) -> Boolean: ...
    @winrt_commethod(37)
    def put_IsSeekEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(38)
    def get_IsCompact(self) -> Boolean: ...
    @winrt_commethod(39)
    def put_IsCompact(self, value: Boolean) -> Void: ...
    IsCompact = property(get_IsCompact, put_IsCompact)
    IsFastForwardButtonVisible = property(get_IsFastForwardButtonVisible, put_IsFastForwardButtonVisible)
    IsFastForwardEnabled = property(get_IsFastForwardEnabled, put_IsFastForwardEnabled)
    IsFastRewindButtonVisible = property(get_IsFastRewindButtonVisible, put_IsFastRewindButtonVisible)
    IsFastRewindEnabled = property(get_IsFastRewindEnabled, put_IsFastRewindEnabled)
    IsFullWindowButtonVisible = property(get_IsFullWindowButtonVisible, put_IsFullWindowButtonVisible)
    IsFullWindowEnabled = property(get_IsFullWindowEnabled, put_IsFullWindowEnabled)
    IsPlaybackRateButtonVisible = property(get_IsPlaybackRateButtonVisible, put_IsPlaybackRateButtonVisible)
    IsPlaybackRateEnabled = property(get_IsPlaybackRateEnabled, put_IsPlaybackRateEnabled)
    IsSeekBarVisible = property(get_IsSeekBarVisible, put_IsSeekBarVisible)
    IsSeekEnabled = property(get_IsSeekEnabled, put_IsSeekEnabled)
    IsStopButtonVisible = property(get_IsStopButtonVisible, put_IsStopButtonVisible)
    IsStopEnabled = property(get_IsStopEnabled, put_IsStopEnabled)
    IsVolumeButtonVisible = property(get_IsVolumeButtonVisible, put_IsVolumeButtonVisible)
    IsVolumeEnabled = property(get_IsVolumeEnabled, put_IsVolumeEnabled)
    IsZoomButtonVisible = property(get_IsZoomButtonVisible, put_IsZoomButtonVisible)
    IsZoomEnabled = property(get_IsZoomEnabled, put_IsZoomEnabled)
class IMediaTransportControls2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaTransportControls2'
    _iid_ = Guid('{2b89efec-1bea-451e-8bcd-cfe2d9423262}')
    @winrt_commethod(6)
    def get_IsSkipForwardButtonVisible(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsSkipForwardButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsSkipForwardEnabled(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsSkipForwardEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_IsSkipBackwardButtonVisible(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsSkipBackwardButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_IsSkipBackwardEnabled(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsSkipBackwardEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_IsNextTrackButtonVisible(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsNextTrackButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_IsPreviousTrackButtonVisible(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsPreviousTrackButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_FastPlayFallbackBehaviour(self) -> win32more.Windows.UI.Xaml.Media.FastPlayFallbackBehaviour: ...
    @winrt_commethod(19)
    def put_FastPlayFallbackBehaviour(self, value: win32more.Windows.UI.Xaml.Media.FastPlayFallbackBehaviour) -> Void: ...
    @winrt_commethod(20)
    def add_ThumbnailRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.MediaTransportControls, win32more.Windows.UI.Xaml.Media.MediaTransportControlsThumbnailRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_ThumbnailRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    FastPlayFallbackBehaviour = property(get_FastPlayFallbackBehaviour, put_FastPlayFallbackBehaviour)
    IsNextTrackButtonVisible = property(get_IsNextTrackButtonVisible, put_IsNextTrackButtonVisible)
    IsPreviousTrackButtonVisible = property(get_IsPreviousTrackButtonVisible, put_IsPreviousTrackButtonVisible)
    IsSkipBackwardButtonVisible = property(get_IsSkipBackwardButtonVisible, put_IsSkipBackwardButtonVisible)
    IsSkipBackwardEnabled = property(get_IsSkipBackwardEnabled, put_IsSkipBackwardEnabled)
    IsSkipForwardButtonVisible = property(get_IsSkipForwardButtonVisible, put_IsSkipForwardButtonVisible)
    IsSkipForwardEnabled = property(get_IsSkipForwardEnabled, put_IsSkipForwardEnabled)
    ThumbnailRequested = event()
class IMediaTransportControls3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaTransportControls3'
    _iid_ = Guid('{5086430e-0940-11e7-93ae-92361f002671}')
    @winrt_commethod(6)
    def get_ShowAndHideAutomatically(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_ShowAndHideAutomatically(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsRepeatEnabled(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsRepeatEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_IsRepeatButtonVisible(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsRepeatButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def Show(self) -> Void: ...
    @winrt_commethod(13)
    def Hide(self) -> Void: ...
    IsRepeatButtonVisible = property(get_IsRepeatButtonVisible, put_IsRepeatButtonVisible)
    IsRepeatEnabled = property(get_IsRepeatEnabled, put_IsRepeatEnabled)
    ShowAndHideAutomatically = property(get_ShowAndHideAutomatically, put_ShowAndHideAutomatically)
class IMediaTransportControls4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaTransportControls4'
    _iid_ = Guid('{0fb17c58-9f23-11e7-abc4-cec278b6b50a}')
    @winrt_commethod(6)
    def get_IsCompactOverlayButtonVisible(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsCompactOverlayButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsCompactOverlayEnabled(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsCompactOverlayEnabled(self, value: Boolean) -> Void: ...
    IsCompactOverlayButtonVisible = property(get_IsCompactOverlayButtonVisible, put_IsCompactOverlayButtonVisible)
    IsCompactOverlayEnabled = property(get_IsCompactOverlayEnabled, put_IsCompactOverlayEnabled)
class IMediaTransportControlsFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaTransportControlsFactory'
    _iid_ = Guid('{1da2015a-a8e4-4c1b-88c9-0b183ecc62e3}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MediaTransportControls: ...
class IMediaTransportControlsHelper(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaTransportControlsHelper'
    _iid_ = Guid('{3d41d509-ff44-4420-807e-8f7a2e2c4251}')
class IMediaTransportControlsHelperStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaTransportControlsHelperStatics'
    _iid_ = Guid('{5a772047-a9a1-4625-9270-7f49875d4394}')
    @winrt_commethod(6)
    def get_DropoutOrderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def GetDropoutOrder(self, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_commethod(8)
    def SetDropoutOrder(self, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    DropoutOrderProperty = property(get_DropoutOrderProperty, None)
class IMediaTransportControlsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaTransportControlsStatics'
    _iid_ = Guid('{590ea907-d2ef-4c1a-9429-b4b15d64fd56}')
    @winrt_commethod(6)
    def get_IsFullWindowButtonVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsFullWindowEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsZoomButtonVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_IsZoomEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsFastForwardButtonVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsFastForwardEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IsFastRewindButtonVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_IsFastRewindEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_IsStopButtonVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_IsStopEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_IsVolumeButtonVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_IsVolumeEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_IsPlaybackRateButtonVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_IsPlaybackRateEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_IsSeekBarVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_IsSeekEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_IsCompactProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsCompactProperty = property(get_IsCompactProperty, None)
    IsFastForwardButtonVisibleProperty = property(get_IsFastForwardButtonVisibleProperty, None)
    IsFastForwardEnabledProperty = property(get_IsFastForwardEnabledProperty, None)
    IsFastRewindButtonVisibleProperty = property(get_IsFastRewindButtonVisibleProperty, None)
    IsFastRewindEnabledProperty = property(get_IsFastRewindEnabledProperty, None)
    IsFullWindowButtonVisibleProperty = property(get_IsFullWindowButtonVisibleProperty, None)
    IsFullWindowEnabledProperty = property(get_IsFullWindowEnabledProperty, None)
    IsPlaybackRateButtonVisibleProperty = property(get_IsPlaybackRateButtonVisibleProperty, None)
    IsPlaybackRateEnabledProperty = property(get_IsPlaybackRateEnabledProperty, None)
    IsSeekBarVisibleProperty = property(get_IsSeekBarVisibleProperty, None)
    IsSeekEnabledProperty = property(get_IsSeekEnabledProperty, None)
    IsStopButtonVisibleProperty = property(get_IsStopButtonVisibleProperty, None)
    IsStopEnabledProperty = property(get_IsStopEnabledProperty, None)
    IsVolumeButtonVisibleProperty = property(get_IsVolumeButtonVisibleProperty, None)
    IsVolumeEnabledProperty = property(get_IsVolumeEnabledProperty, None)
    IsZoomButtonVisibleProperty = property(get_IsZoomButtonVisibleProperty, None)
    IsZoomEnabledProperty = property(get_IsZoomEnabledProperty, None)
class IMediaTransportControlsStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaTransportControlsStatics2'
    _iid_ = Guid('{1728cfdc-561f-4386-a7f8-090d95f68d96}')
    @winrt_commethod(6)
    def get_IsSkipForwardButtonVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsSkipForwardEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsSkipBackwardButtonVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_IsSkipBackwardEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsNextTrackButtonVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsPreviousTrackButtonVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_FastPlayFallbackBehaviourProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    FastPlayFallbackBehaviourProperty = property(get_FastPlayFallbackBehaviourProperty, None)
    IsNextTrackButtonVisibleProperty = property(get_IsNextTrackButtonVisibleProperty, None)
    IsPreviousTrackButtonVisibleProperty = property(get_IsPreviousTrackButtonVisibleProperty, None)
    IsSkipBackwardButtonVisibleProperty = property(get_IsSkipBackwardButtonVisibleProperty, None)
    IsSkipBackwardEnabledProperty = property(get_IsSkipBackwardEnabledProperty, None)
    IsSkipForwardButtonVisibleProperty = property(get_IsSkipForwardButtonVisibleProperty, None)
    IsSkipForwardEnabledProperty = property(get_IsSkipForwardEnabledProperty, None)
class IMediaTransportControlsStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaTransportControlsStatics3'
    _iid_ = Guid('{5fe05542-0940-11e7-93ae-92361f002671}')
    @winrt_commethod(6)
    def get_ShowAndHideAutomaticallyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsRepeatEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsRepeatButtonVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsRepeatButtonVisibleProperty = property(get_IsRepeatButtonVisibleProperty, None)
    IsRepeatEnabledProperty = property(get_IsRepeatEnabledProperty, None)
    ShowAndHideAutomaticallyProperty = property(get_ShowAndHideAutomaticallyProperty, None)
class IMediaTransportControlsStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMediaTransportControlsStatics4'
    _iid_ = Guid('{0fb18144-9f23-11e7-abc4-cec278b6b50a}')
    @winrt_commethod(6)
    def get_IsCompactOverlayButtonVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsCompactOverlayEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsCompactOverlayButtonVisibleProperty = property(get_IsCompactOverlayButtonVisibleProperty, None)
    IsCompactOverlayEnabledProperty = property(get_IsCompactOverlayEnabledProperty, None)
class IMenuBar(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuBar'
    _iid_ = Guid('{c8f67b0c-0e76-5af2-bade-785049c80a41}')
    @winrt_commethod(6)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.MenuBarItem]: ...
    Items = property(get_Items, None)
class IMenuBarFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuBarFactory'
    _iid_ = Guid('{dc619e50-72ba-513f-80aa-ddd093825dde}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MenuBar: ...
class IMenuBarItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuBarItem'
    _iid_ = Guid('{bf643b4c-8125-5b53-a454-06e896a5acee}')
    @winrt_commethod(6)
    def get_Title(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Title(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.MenuFlyoutItemBase]: ...
    Items = property(get_Items, None)
    Title = property(get_Title, put_Title)
class IMenuBarItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuBarItemFactory'
    _iid_ = Guid('{ecf86f62-c394-50e2-a568-17af8cf26874}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MenuBarItem: ...
class IMenuBarItemFlyout(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuBarItemFlyout'
    _iid_ = Guid('{ed00d2d8-b686-55fe-8dbb-f04a640e42ef}')
class IMenuBarItemFlyoutFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuBarItemFlyoutFactory'
    _iid_ = Guid('{1d24f9bd-bd19-5d95-b573-711f649fcbe9}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MenuBarItemFlyout: ...
class IMenuBarItemStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuBarItemStatics'
    _iid_ = Guid('{60a9e3fb-b405-50d0-bb78-d396a34da267}')
    @winrt_commethod(6)
    def get_TitleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ItemsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ItemsProperty = property(get_ItemsProperty, None)
    TitleProperty = property(get_TitleProperty, None)
class IMenuBarStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuBarStatics'
    _iid_ = Guid('{bed31c25-7db8-51cc-9706-1d79327daf93}')
    @winrt_commethod(6)
    def get_ItemsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ItemsProperty = property(get_ItemsProperty, None)
class IMenuFlyout(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyout'
    _iid_ = Guid('{ad3210f1-985b-4171-bbba-67bcc729649b}')
    @winrt_commethod(6)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.MenuFlyoutItemBase]: ...
    @winrt_commethod(7)
    def get_MenuFlyoutPresenterStyle(self) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_commethod(8)
    def put_MenuFlyoutPresenterStyle(self, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    Items = property(get_Items, None)
    MenuFlyoutPresenterStyle = property(get_MenuFlyoutPresenterStyle, put_MenuFlyoutPresenterStyle)
class IMenuFlyout2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyout2'
    _iid_ = Guid('{507c7bad-d9d1-4c05-9d4b-cda8de9ab242}')
    @winrt_commethod(6)
    def ShowAt(self, targetElement: win32more.Windows.UI.Xaml.UIElement, point: win32more.Windows.Foundation.Point) -> Void: ...
class IMenuFlyoutFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutFactory'
    _iid_ = Guid('{644533ab-bbb9-499b-9ff3-30d40e2c56d8}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MenuFlyout: ...
class IMenuFlyoutItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutItem'
    _iid_ = Guid('{160775cf-b598-44af-a488-c3ce2af6d3f0}')
    @winrt_commethod(6)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Text(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Command(self) -> win32more.Windows.UI.Xaml.Input.ICommand: ...
    @winrt_commethod(9)
    def put_Command(self, value: win32more.Windows.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_commethod(10)
    def get_CommandParameter(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(11)
    def put_CommandParameter(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(12)
    def add_Click(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_Click(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Command = property(get_Command, put_Command)
    CommandParameter = property(get_CommandParameter, put_CommandParameter)
    Text = property(get_Text, put_Text)
    Click = event()
class IMenuFlyoutItem2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutItem2'
    _iid_ = Guid('{0ae266eb-028c-4423-a8e3-989fd9dd7126}')
    @winrt_commethod(6)
    def get_Icon(self) -> win32more.Windows.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(7)
    def put_Icon(self, value: win32more.Windows.UI.Xaml.Controls.IconElement) -> Void: ...
    Icon = property(get_Icon, put_Icon)
class IMenuFlyoutItem3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutItem3'
    _iid_ = Guid('{9727b2e3-b2b6-49dc-8c22-e0138b941559}')
    @winrt_commethod(6)
    def get_KeyboardAcceleratorTextOverride(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_KeyboardAcceleratorTextOverride(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_TemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.MenuFlyoutItemTemplateSettings: ...
    KeyboardAcceleratorTextOverride = property(get_KeyboardAcceleratorTextOverride, put_KeyboardAcceleratorTextOverride)
    TemplateSettings = property(get_TemplateSettings, None)
class IMenuFlyoutItemBase(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutItemBase'
    _iid_ = Guid('{f9b56047-8da6-4730-9208-144125c6b396}')
class IMenuFlyoutItemBaseFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutItemBaseFactory'
    _iid_ = Guid('{83e6dbad-fc67-41d5-8797-60acd1ceb1d9}')
class IMenuFlyoutItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutItemFactory'
    _iid_ = Guid('{c5aa39e2-44f3-455e-9c5b-62bb6afce3ad}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MenuFlyoutItem: ...
class IMenuFlyoutItemStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutItemStatics'
    _iid_ = Guid('{4950b424-a43a-41f7-aa3a-9ce9619747d5}')
    @winrt_commethod(6)
    def get_TextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CommandProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CommandParameterProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CommandParameterProperty = property(get_CommandParameterProperty, None)
    CommandProperty = property(get_CommandProperty, None)
    TextProperty = property(get_TextProperty, None)
class IMenuFlyoutItemStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutItemStatics2'
    _iid_ = Guid('{aca4f564-1790-4601-916e-5ae1f01f4bd6}')
    @winrt_commethod(6)
    def get_IconProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IconProperty = property(get_IconProperty, None)
class IMenuFlyoutItemStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutItemStatics3'
    _iid_ = Guid('{d83fd7c3-0aeb-4ef3-8270-8b9b95f2b298}')
    @winrt_commethod(6)
    def get_KeyboardAcceleratorTextOverrideProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    KeyboardAcceleratorTextOverrideProperty = property(get_KeyboardAcceleratorTextOverrideProperty, None)
class IMenuFlyoutPresenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutPresenter'
    _iid_ = Guid('{906e0304-254e-413f-b219-c7b97f003752}')
class IMenuFlyoutPresenter2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutPresenter2'
    _iid_ = Guid('{895894df-5a9f-4a1f-85ec-6f3c1b6dcb89}')
    @winrt_commethod(6)
    def get_TemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.MenuFlyoutPresenterTemplateSettings: ...
    TemplateSettings = property(get_TemplateSettings, None)
class IMenuFlyoutPresenter3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutPresenter3'
    _iid_ = Guid('{6afd4e16-aee0-584a-9849-edaa323a484f}')
    @winrt_commethod(6)
    def get_IsDefaultShadowEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsDefaultShadowEnabled(self, value: Boolean) -> Void: ...
    IsDefaultShadowEnabled = property(get_IsDefaultShadowEnabled, put_IsDefaultShadowEnabled)
class IMenuFlyoutPresenterFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutPresenterFactory'
    _iid_ = Guid('{b88b5091-101c-41f8-aac1-1b105c14fb99}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MenuFlyoutPresenter: ...
class IMenuFlyoutPresenterStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutPresenterStatics3'
    _iid_ = Guid('{3772a818-825a-520c-80ae-4d39a2d59ab5}')
    @winrt_commethod(6)
    def get_IsDefaultShadowEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsDefaultShadowEnabledProperty = property(get_IsDefaultShadowEnabledProperty, None)
class IMenuFlyoutSeparator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutSeparator'
    _iid_ = Guid('{71fa2b7d-0b51-4950-a1a4-bbc42eac4c12}')
class IMenuFlyoutSeparatorFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutSeparatorFactory'
    _iid_ = Guid('{c159dcc8-b437-44e0-b24b-5720aea1dbac}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MenuFlyoutSeparator: ...
class IMenuFlyoutStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutStatics'
    _iid_ = Guid('{3dbefba1-9522-4045-9e58-c99b13aab9b9}')
    @winrt_commethod(6)
    def get_MenuFlyoutPresenterStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    MenuFlyoutPresenterStyleProperty = property(get_MenuFlyoutPresenterStyleProperty, None)
class IMenuFlyoutSubItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutSubItem'
    _iid_ = Guid('{e5386550-fe2c-43e2-a73f-62168f619973}')
    @winrt_commethod(6)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.MenuFlyoutItemBase]: ...
    @winrt_commethod(7)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Text(self, value: WinRT_String) -> Void: ...
    Items = property(get_Items, None)
    Text = property(get_Text, put_Text)
class IMenuFlyoutSubItem2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutSubItem2'
    _iid_ = Guid('{ac935626-190a-4de2-8d71-7cc4747da580}')
    @winrt_commethod(6)
    def get_Icon(self) -> win32more.Windows.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(7)
    def put_Icon(self, value: win32more.Windows.UI.Xaml.Controls.IconElement) -> Void: ...
    Icon = property(get_Icon, put_Icon)
class IMenuFlyoutSubItemStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutSubItemStatics'
    _iid_ = Guid('{ddb27a36-1874-4aef-837d-6fec9da4e681}')
    @winrt_commethod(6)
    def get_TextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    TextProperty = property(get_TextProperty, None)
class IMenuFlyoutSubItemStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IMenuFlyoutSubItemStatics2'
    _iid_ = Guid('{ac14d09b-3e93-4785-94ef-fdb23baba965}')
    @winrt_commethod(6)
    def get_IconProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IconProperty = property(get_IconProperty, None)
class INavigate(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigate'
    _iid_ = Guid('{bf2195a9-f4ea-4336-977c-f8fcf78b0d9e}')
    @winrt_commethod(6)
    def Navigate(self, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName) -> Boolean: ...
class INavigationView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationView'
    _iid_ = Guid('{f209ce15-391a-42ca-9fc6-f79da65aca32}')
    @winrt_commethod(6)
    def get_IsPaneOpen(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsPaneOpen(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_CompactModeThresholdWidth(self) -> Double: ...
    @winrt_commethod(9)
    def put_CompactModeThresholdWidth(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_ExpandedModeThresholdWidth(self) -> Double: ...
    @winrt_commethod(11)
    def put_ExpandedModeThresholdWidth(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_PaneFooter(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(13)
    def put_PaneFooter(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(14)
    def get_Header(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(15)
    def put_Header(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(16)
    def get_HeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(17)
    def put_HeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(18)
    def get_DisplayMode(self) -> win32more.Windows.UI.Xaml.Controls.NavigationViewDisplayMode: ...
    @winrt_commethod(19)
    def get_IsSettingsVisible(self) -> Boolean: ...
    @winrt_commethod(20)
    def put_IsSettingsVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(21)
    def get_IsPaneToggleButtonVisible(self) -> Boolean: ...
    @winrt_commethod(22)
    def put_IsPaneToggleButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(23)
    def get_AlwaysShowHeader(self) -> Boolean: ...
    @winrt_commethod(24)
    def put_AlwaysShowHeader(self, value: Boolean) -> Void: ...
    @winrt_commethod(25)
    def get_CompactPaneLength(self) -> Double: ...
    @winrt_commethod(26)
    def put_CompactPaneLength(self, value: Double) -> Void: ...
    @winrt_commethod(27)
    def get_OpenPaneLength(self) -> Double: ...
    @winrt_commethod(28)
    def put_OpenPaneLength(self, value: Double) -> Void: ...
    @winrt_commethod(29)
    def get_PaneToggleButtonStyle(self) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_commethod(30)
    def put_PaneToggleButtonStyle(self, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(31)
    def get_SelectedItem(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(32)
    def put_SelectedItem(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(33)
    def get_MenuItems(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_commethod(34)
    def get_MenuItemsSource(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(35)
    def put_MenuItemsSource(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(36)
    def get_SettingsItem(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(37)
    def get_AutoSuggestBox(self) -> win32more.Windows.UI.Xaml.Controls.AutoSuggestBox: ...
    @winrt_commethod(38)
    def put_AutoSuggestBox(self, value: win32more.Windows.UI.Xaml.Controls.AutoSuggestBox) -> Void: ...
    @winrt_commethod(39)
    def get_MenuItemTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(40)
    def put_MenuItemTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(41)
    def get_MenuItemTemplateSelector(self) -> win32more.Windows.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_commethod(42)
    def put_MenuItemTemplateSelector(self, value: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_commethod(43)
    def get_MenuItemContainerStyle(self) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_commethod(44)
    def put_MenuItemContainerStyle(self, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(45)
    def get_MenuItemContainerStyleSelector(self) -> win32more.Windows.UI.Xaml.Controls.StyleSelector: ...
    @winrt_commethod(46)
    def put_MenuItemContainerStyleSelector(self, value: win32more.Windows.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_commethod(47)
    def MenuItemFromContainer(self, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(48)
    def ContainerFromMenuItem(self, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_commethod(49)
    def add_SelectionChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.NavigationView, win32more.Windows.UI.Xaml.Controls.NavigationViewSelectionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(50)
    def remove_SelectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(51)
    def add_ItemInvoked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.NavigationView, win32more.Windows.UI.Xaml.Controls.NavigationViewItemInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(52)
    def remove_ItemInvoked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(53)
    def add_DisplayModeChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.NavigationView, win32more.Windows.UI.Xaml.Controls.NavigationViewDisplayModeChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(54)
    def remove_DisplayModeChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AlwaysShowHeader = property(get_AlwaysShowHeader, put_AlwaysShowHeader)
    AutoSuggestBox = property(get_AutoSuggestBox, put_AutoSuggestBox)
    CompactModeThresholdWidth = property(get_CompactModeThresholdWidth, put_CompactModeThresholdWidth)
    CompactPaneLength = property(get_CompactPaneLength, put_CompactPaneLength)
    DisplayMode = property(get_DisplayMode, None)
    ExpandedModeThresholdWidth = property(get_ExpandedModeThresholdWidth, put_ExpandedModeThresholdWidth)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsPaneOpen = property(get_IsPaneOpen, put_IsPaneOpen)
    IsPaneToggleButtonVisible = property(get_IsPaneToggleButtonVisible, put_IsPaneToggleButtonVisible)
    IsSettingsVisible = property(get_IsSettingsVisible, put_IsSettingsVisible)
    MenuItemContainerStyle = property(get_MenuItemContainerStyle, put_MenuItemContainerStyle)
    MenuItemContainerStyleSelector = property(get_MenuItemContainerStyleSelector, put_MenuItemContainerStyleSelector)
    MenuItemTemplate = property(get_MenuItemTemplate, put_MenuItemTemplate)
    MenuItemTemplateSelector = property(get_MenuItemTemplateSelector, put_MenuItemTemplateSelector)
    MenuItems = property(get_MenuItems, None)
    MenuItemsSource = property(get_MenuItemsSource, put_MenuItemsSource)
    OpenPaneLength = property(get_OpenPaneLength, put_OpenPaneLength)
    PaneFooter = property(get_PaneFooter, put_PaneFooter)
    PaneToggleButtonStyle = property(get_PaneToggleButtonStyle, put_PaneToggleButtonStyle)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    SettingsItem = property(get_SettingsItem, None)
    SelectionChanged = event()
    ItemInvoked = event()
    DisplayModeChanged = event()
class INavigationView2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationView2'
    _iid_ = Guid('{2be49737-7c13-4c44-86c3-8b25e697a80e}')
    @winrt_commethod(6)
    def get_IsBackButtonVisible(self) -> win32more.Windows.UI.Xaml.Controls.NavigationViewBackButtonVisible: ...
    @winrt_commethod(7)
    def put_IsBackButtonVisible(self, value: win32more.Windows.UI.Xaml.Controls.NavigationViewBackButtonVisible) -> Void: ...
    @winrt_commethod(8)
    def get_IsBackEnabled(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsBackEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_PaneTitle(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_PaneTitle(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def add_BackRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.NavigationView, win32more.Windows.UI.Xaml.Controls.NavigationViewBackRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_BackRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_PaneClosed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.NavigationView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_PaneClosed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def add_PaneClosing(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.NavigationView, win32more.Windows.UI.Xaml.Controls.NavigationViewPaneClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_PaneClosing(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def add_PaneOpened(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.NavigationView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_PaneOpened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(20)
    def add_PaneOpening(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.NavigationView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_PaneOpening(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    IsBackButtonVisible = property(get_IsBackButtonVisible, put_IsBackButtonVisible)
    IsBackEnabled = property(get_IsBackEnabled, put_IsBackEnabled)
    PaneTitle = property(get_PaneTitle, put_PaneTitle)
    BackRequested = event()
    PaneClosed = event()
    PaneClosing = event()
    PaneOpened = event()
    PaneOpening = event()
class INavigationView3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationView3'
    _iid_ = Guid('{8fdfab66-9bbc-5fa3-9043-a02bb4f8ef37}')
    @winrt_commethod(6)
    def get_PaneDisplayMode(self) -> win32more.Windows.UI.Xaml.Controls.NavigationViewPaneDisplayMode: ...
    @winrt_commethod(7)
    def put_PaneDisplayMode(self, value: win32more.Windows.UI.Xaml.Controls.NavigationViewPaneDisplayMode) -> Void: ...
    @winrt_commethod(8)
    def get_PaneHeader(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(9)
    def put_PaneHeader(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(10)
    def get_PaneCustomContent(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(11)
    def put_PaneCustomContent(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(12)
    def get_ContentOverlay(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(13)
    def put_ContentOverlay(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(14)
    def get_IsPaneVisible(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsPaneVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_SelectionFollowsFocus(self) -> win32more.Windows.UI.Xaml.Controls.NavigationViewSelectionFollowsFocus: ...
    @winrt_commethod(17)
    def put_SelectionFollowsFocus(self, value: win32more.Windows.UI.Xaml.Controls.NavigationViewSelectionFollowsFocus) -> Void: ...
    @winrt_commethod(18)
    def get_TemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.NavigationViewTemplateSettings: ...
    @winrt_commethod(19)
    def get_ShoulderNavigationEnabled(self) -> win32more.Windows.UI.Xaml.Controls.NavigationViewShoulderNavigationEnabled: ...
    @winrt_commethod(20)
    def put_ShoulderNavigationEnabled(self, value: win32more.Windows.UI.Xaml.Controls.NavigationViewShoulderNavigationEnabled) -> Void: ...
    @winrt_commethod(21)
    def get_OverflowLabelMode(self) -> win32more.Windows.UI.Xaml.Controls.NavigationViewOverflowLabelMode: ...
    @winrt_commethod(22)
    def put_OverflowLabelMode(self, value: win32more.Windows.UI.Xaml.Controls.NavigationViewOverflowLabelMode) -> Void: ...
    ContentOverlay = property(get_ContentOverlay, put_ContentOverlay)
    IsPaneVisible = property(get_IsPaneVisible, put_IsPaneVisible)
    OverflowLabelMode = property(get_OverflowLabelMode, put_OverflowLabelMode)
    PaneCustomContent = property(get_PaneCustomContent, put_PaneCustomContent)
    PaneDisplayMode = property(get_PaneDisplayMode, put_PaneDisplayMode)
    PaneHeader = property(get_PaneHeader, put_PaneHeader)
    SelectionFollowsFocus = property(get_SelectionFollowsFocus, put_SelectionFollowsFocus)
    ShoulderNavigationEnabled = property(get_ShoulderNavigationEnabled, put_ShoulderNavigationEnabled)
    TemplateSettings = property(get_TemplateSettings, None)
class INavigationViewBackRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewBackRequestedEventArgs'
    _iid_ = Guid('{446700e1-9a9d-4500-a71d-25c15809b879}')
class INavigationViewDisplayModeChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewDisplayModeChangedEventArgs'
    _iid_ = Guid('{b7c1ad35-5544-40c1-9b33-acfe1d6c8094}')
    @winrt_commethod(6)
    def get_DisplayMode(self) -> win32more.Windows.UI.Xaml.Controls.NavigationViewDisplayMode: ...
    DisplayMode = property(get_DisplayMode, None)
class INavigationViewFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewFactory'
    _iid_ = Guid('{e50687c1-b7c2-4975-ad7a-5f4fe6a514c9}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.NavigationView: ...
class INavigationViewItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewItem'
    _iid_ = Guid('{8614be0f-b7b6-4851-960a-f5e3f69f624a}')
    @winrt_commethod(6)
    def get_Icon(self) -> win32more.Windows.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(7)
    def put_Icon(self, value: win32more.Windows.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_commethod(8)
    def get_CompactPaneLength(self) -> Double: ...
    CompactPaneLength = property(get_CompactPaneLength, None)
    Icon = property(get_Icon, put_Icon)
class INavigationViewItem2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewItem2'
    _iid_ = Guid('{ee488ef9-ea9c-5e04-b26c-83bf9655342f}')
    @winrt_commethod(6)
    def get_SelectsOnInvoked(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_SelectsOnInvoked(self, value: Boolean) -> Void: ...
    SelectsOnInvoked = property(get_SelectsOnInvoked, put_SelectsOnInvoked)
class INavigationViewItemBase(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewItemBase'
    _iid_ = Guid('{edf04eb1-37d1-471f-8570-3829ee5b2bc6}')
class INavigationViewItemBaseFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewItemBaseFactory'
    _iid_ = Guid('{eb014cef-7890-4ebb-8245-02e8510f321d}')
class INavigationViewItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewItemFactory'
    _iid_ = Guid('{973bdb4a-7e08-4f76-923c-f12bd685e86e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.NavigationViewItem: ...
class INavigationViewItemHeader(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewItemHeader'
    _iid_ = Guid('{e21df22c-da4a-4e74-9ffc-b163bd7adacd}')
class INavigationViewItemHeaderFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewItemHeaderFactory'
    _iid_ = Guid('{f3105988-7768-45d3-8bb0-6ded9e43a98b}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.NavigationViewItemHeader: ...
class INavigationViewItemInvokedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewItemInvokedEventArgs'
    _iid_ = Guid('{29496822-55d2-49fa-964b-f1dbafef85c4}')
    @winrt_commethod(6)
    def get_InvokedItem(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def get_IsSettingsInvoked(self) -> Boolean: ...
    InvokedItem = property(get_InvokedItem, None)
    IsSettingsInvoked = property(get_IsSettingsInvoked, None)
class INavigationViewItemInvokedEventArgs2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewItemInvokedEventArgs2'
    _iid_ = Guid('{b568f2dd-515e-5770-a466-bd5f43fb6442}')
    @winrt_commethod(6)
    def get_InvokedItemContainer(self) -> win32more.Windows.UI.Xaml.Controls.NavigationViewItemBase: ...
    @winrt_commethod(7)
    def get_RecommendedNavigationTransitionInfo(self) -> win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    InvokedItemContainer = property(get_InvokedItemContainer, None)
    RecommendedNavigationTransitionInfo = property(get_RecommendedNavigationTransitionInfo, None)
class INavigationViewItemSeparator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewItemSeparator'
    _iid_ = Guid('{de62c951-bb9b-471e-83e3-af4791e7096a}')
class INavigationViewItemSeparatorFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewItemSeparatorFactory'
    _iid_ = Guid('{71cf3a66-db86-49e0-8154-5fd356aedec0}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.NavigationViewItemSeparator: ...
class INavigationViewItemStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewItemStatics'
    _iid_ = Guid('{803c0081-fda5-4b90-aace-3f2306dbe5c4}')
    @winrt_commethod(6)
    def get_IconProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CompactPaneLengthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CompactPaneLengthProperty = property(get_CompactPaneLengthProperty, None)
    IconProperty = property(get_IconProperty, None)
class INavigationViewItemStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewItemStatics2'
    _iid_ = Guid('{f4f2f77c-54b4-541d-b747-3a96e9ff3d55}')
    @winrt_commethod(6)
    def get_SelectsOnInvokedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SelectsOnInvokedProperty = property(get_SelectsOnInvokedProperty, None)
class INavigationViewList(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewList'
    _iid_ = Guid('{4f726f85-5ce0-48cd-8ef2-1a29458a3404}')
class INavigationViewListFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewListFactory'
    _iid_ = Guid('{faee9541-c3bf-47bf-b904-6155f4df6b4f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.NavigationViewList: ...
class INavigationViewPaneClosingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewPaneClosingEventArgs'
    _iid_ = Guid('{955575ba-75f5-432d-b49b-60e47552d5ee}')
    @winrt_commethod(6)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
class INavigationViewSelectionChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewSelectionChangedEventArgs'
    _iid_ = Guid('{5aa509a0-3a5e-4f54-896c-98b85f819508}')
    @winrt_commethod(6)
    def get_SelectedItem(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def get_IsSettingsSelected(self) -> Boolean: ...
    IsSettingsSelected = property(get_IsSettingsSelected, None)
    SelectedItem = property(get_SelectedItem, None)
class INavigationViewSelectionChangedEventArgs2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewSelectionChangedEventArgs2'
    _iid_ = Guid('{fd5af806-d10a-5e8b-973f-3b8fda944625}')
    @winrt_commethod(6)
    def get_SelectedItemContainer(self) -> win32more.Windows.UI.Xaml.Controls.NavigationViewItemBase: ...
    @winrt_commethod(7)
    def get_RecommendedNavigationTransitionInfo(self) -> win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    RecommendedNavigationTransitionInfo = property(get_RecommendedNavigationTransitionInfo, None)
    SelectedItemContainer = property(get_SelectedItemContainer, None)
class INavigationViewStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewStatics'
    _iid_ = Guid('{363a86c7-72da-4420-b871-15d9d0d45756}')
    @winrt_commethod(6)
    def get_IsPaneOpenProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CompactModeThresholdWidthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ExpandedModeThresholdWidthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PaneFooterProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_HeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_HeaderTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_DisplayModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_IsSettingsVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_IsPaneToggleButtonVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_AlwaysShowHeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_CompactPaneLengthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_OpenPaneLengthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_PaneToggleButtonStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_MenuItemsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_MenuItemsSourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_SelectedItemProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_SettingsItemProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_AutoSuggestBoxProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_MenuItemTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_MenuItemTemplateSelectorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def get_MenuItemContainerStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(27)
    def get_MenuItemContainerStyleSelectorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AlwaysShowHeaderProperty = property(get_AlwaysShowHeaderProperty, None)
    AutoSuggestBoxProperty = property(get_AutoSuggestBoxProperty, None)
    CompactModeThresholdWidthProperty = property(get_CompactModeThresholdWidthProperty, None)
    CompactPaneLengthProperty = property(get_CompactPaneLengthProperty, None)
    DisplayModeProperty = property(get_DisplayModeProperty, None)
    ExpandedModeThresholdWidthProperty = property(get_ExpandedModeThresholdWidthProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IsPaneOpenProperty = property(get_IsPaneOpenProperty, None)
    IsPaneToggleButtonVisibleProperty = property(get_IsPaneToggleButtonVisibleProperty, None)
    IsSettingsVisibleProperty = property(get_IsSettingsVisibleProperty, None)
    MenuItemContainerStyleProperty = property(get_MenuItemContainerStyleProperty, None)
    MenuItemContainerStyleSelectorProperty = property(get_MenuItemContainerStyleSelectorProperty, None)
    MenuItemTemplateProperty = property(get_MenuItemTemplateProperty, None)
    MenuItemTemplateSelectorProperty = property(get_MenuItemTemplateSelectorProperty, None)
    MenuItemsProperty = property(get_MenuItemsProperty, None)
    MenuItemsSourceProperty = property(get_MenuItemsSourceProperty, None)
    OpenPaneLengthProperty = property(get_OpenPaneLengthProperty, None)
    PaneFooterProperty = property(get_PaneFooterProperty, None)
    PaneToggleButtonStyleProperty = property(get_PaneToggleButtonStyleProperty, None)
    SelectedItemProperty = property(get_SelectedItemProperty, None)
    SettingsItemProperty = property(get_SettingsItemProperty, None)
class INavigationViewStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewStatics2'
    _iid_ = Guid('{8cc50d74-1a42-4852-ab5a-6dc82f28a4ba}')
    @winrt_commethod(6)
    def get_IsBackButtonVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsBackEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PaneTitleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsBackButtonVisibleProperty = property(get_IsBackButtonVisibleProperty, None)
    IsBackEnabledProperty = property(get_IsBackEnabledProperty, None)
    PaneTitleProperty = property(get_PaneTitleProperty, None)
class INavigationViewStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewStatics3'
    _iid_ = Guid('{9b6b69b7-f746-5550-91e1-ee0c9a85c05e}')
    @winrt_commethod(6)
    def get_PaneDisplayModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PaneHeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PaneCustomContentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_ContentOverlayProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsPaneVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_SelectionFollowsFocusProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_TemplateSettingsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_ShoulderNavigationEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_OverflowLabelModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ContentOverlayProperty = property(get_ContentOverlayProperty, None)
    IsPaneVisibleProperty = property(get_IsPaneVisibleProperty, None)
    OverflowLabelModeProperty = property(get_OverflowLabelModeProperty, None)
    PaneCustomContentProperty = property(get_PaneCustomContentProperty, None)
    PaneDisplayModeProperty = property(get_PaneDisplayModeProperty, None)
    PaneHeaderProperty = property(get_PaneHeaderProperty, None)
    SelectionFollowsFocusProperty = property(get_SelectionFollowsFocusProperty, None)
    ShoulderNavigationEnabledProperty = property(get_ShoulderNavigationEnabledProperty, None)
    TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
class INavigationViewTemplateSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewTemplateSettings'
    _iid_ = Guid('{2956cbc4-0528-55d5-b2d1-eae807aea6da}')
    @winrt_commethod(6)
    def get_TopPadding(self) -> Double: ...
    @winrt_commethod(7)
    def get_OverflowButtonVisibility(self) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_commethod(8)
    def get_PaneToggleButtonVisibility(self) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_commethod(9)
    def get_BackButtonVisibility(self) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_commethod(10)
    def get_TopPaneVisibility(self) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_commethod(11)
    def get_LeftPaneVisibility(self) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_commethod(12)
    def get_SingleSelectionFollowsFocus(self) -> Boolean: ...
    BackButtonVisibility = property(get_BackButtonVisibility, None)
    LeftPaneVisibility = property(get_LeftPaneVisibility, None)
    OverflowButtonVisibility = property(get_OverflowButtonVisibility, None)
    PaneToggleButtonVisibility = property(get_PaneToggleButtonVisibility, None)
    SingleSelectionFollowsFocus = property(get_SingleSelectionFollowsFocus, None)
    TopPadding = property(get_TopPadding, None)
    TopPaneVisibility = property(get_TopPaneVisibility, None)
class INavigationViewTemplateSettingsFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewTemplateSettingsFactory'
    _iid_ = Guid('{28a6a351-64bc-5b60-8f74-e9ee908a240e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.NavigationViewTemplateSettings: ...
class INavigationViewTemplateSettingsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics'
    _iid_ = Guid('{2c885e59-f7b9-5078-aeb6-8d7a03c05d02}')
    @winrt_commethod(6)
    def get_TopPaddingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_OverflowButtonVisibilityProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PaneToggleButtonVisibilityProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_BackButtonVisibilityProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_TopPaneVisibilityProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_LeftPaneVisibilityProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_SingleSelectionFollowsFocusProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BackButtonVisibilityProperty = property(get_BackButtonVisibilityProperty, None)
    LeftPaneVisibilityProperty = property(get_LeftPaneVisibilityProperty, None)
    OverflowButtonVisibilityProperty = property(get_OverflowButtonVisibilityProperty, None)
    PaneToggleButtonVisibilityProperty = property(get_PaneToggleButtonVisibilityProperty, None)
    SingleSelectionFollowsFocusProperty = property(get_SingleSelectionFollowsFocusProperty, None)
    TopPaddingProperty = property(get_TopPaddingProperty, None)
    TopPaneVisibilityProperty = property(get_TopPaneVisibilityProperty, None)
class INotifyEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INotifyEventArgs'
    _iid_ = Guid('{af0e05f7-c4b7-44c5-b09d-5cb7052b3a97}')
    @winrt_commethod(6)
    def get_Value(self) -> WinRT_String: ...
    Value = property(get_Value, None)
class INotifyEventArgs2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.INotifyEventArgs2'
    _iid_ = Guid('{0d140f56-1dce-4fcd-85bc-5a5572273b9c}')
    @winrt_commethod(6)
    def get_CallingUri(self) -> win32more.Windows.Foundation.Uri: ...
    CallingUri = property(get_CallingUri, None)
class IPage(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPage'
    _iid_ = Guid('{c4b27075-e641-453e-824d-012fc7cf95cf}')
    @winrt_commethod(6)
    def get_Frame(self) -> win32more.Windows.UI.Xaml.Controls.Frame: ...
    @winrt_commethod(7)
    def get_NavigationCacheMode(self) -> win32more.Windows.UI.Xaml.Navigation.NavigationCacheMode: ...
    @winrt_commethod(8)
    def put_NavigationCacheMode(self, value: win32more.Windows.UI.Xaml.Navigation.NavigationCacheMode) -> Void: ...
    @winrt_commethod(9)
    def get_TopAppBar(self) -> win32more.Windows.UI.Xaml.Controls.AppBar: ...
    @winrt_commethod(10)
    def put_TopAppBar(self, value: win32more.Windows.UI.Xaml.Controls.AppBar) -> Void: ...
    @winrt_commethod(11)
    def get_BottomAppBar(self) -> win32more.Windows.UI.Xaml.Controls.AppBar: ...
    @winrt_commethod(12)
    def put_BottomAppBar(self, value: win32more.Windows.UI.Xaml.Controls.AppBar) -> Void: ...
    BottomAppBar = property(get_BottomAppBar, put_BottomAppBar)
    Frame = property(get_Frame, None)
    NavigationCacheMode = property(get_NavigationCacheMode, put_NavigationCacheMode)
    TopAppBar = property(get_TopAppBar, put_TopAppBar)
class IPageFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPageFactory'
    _iid_ = Guid('{dfa149ac-1849-445e-937c-40a9590cc076}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Page: ...
class IPageOverrides(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPageOverrides'
    _iid_ = Guid('{230b9cb8-3419-4306-aabe-4a8e680d3627}')
    @winrt_commethod(6)
    def OnNavigatedFrom(self, e: win32more.Windows.UI.Xaml.Navigation.NavigationEventArgs) -> Void: ...
    @winrt_commethod(7)
    def OnNavigatedTo(self, e: win32more.Windows.UI.Xaml.Navigation.NavigationEventArgs) -> Void: ...
    @winrt_commethod(8)
    def OnNavigatingFrom(self, e: win32more.Windows.UI.Xaml.Navigation.NavigatingCancelEventArgs) -> Void: ...
class IPageStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPageStatics'
    _iid_ = Guid('{376dde71-f725-46dd-8d80-eeeaf7da74e5}')
    @winrt_commethod(6)
    def get_FrameProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TopAppBarProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_BottomAppBarProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BottomAppBarProperty = property(get_BottomAppBarProperty, None)
    FrameProperty = property(get_FrameProperty, None)
    TopAppBarProperty = property(get_TopAppBarProperty, None)
class IPanel(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPanel'
    _iid_ = Guid('{a50a4bbd-8361-469c-90da-e9a40c7474df}')
    @winrt_commethod(6)
    def get_Children(self) -> win32more.Windows.UI.Xaml.Controls.UIElementCollection: ...
    @winrt_commethod(7)
    def get_Background(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(8)
    def put_Background(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(9)
    def get_IsItemsHost(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_ChildrenTransitions(self) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(11)
    def put_ChildrenTransitions(self, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    Background = property(get_Background, put_Background)
    Children = property(get_Children, None)
    ChildrenTransitions = property(get_ChildrenTransitions, put_ChildrenTransitions)
    IsItemsHost = property(get_IsItemsHost, None)
class IPanel2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPanel2'
    _iid_ = Guid('{709133c7-38f3-5083-a4bb-06a548a1d231}')
    @winrt_commethod(6)
    def get_BackgroundTransition(self) -> win32more.Windows.UI.Xaml.BrushTransition: ...
    @winrt_commethod(7)
    def put_BackgroundTransition(self, value: win32more.Windows.UI.Xaml.BrushTransition) -> Void: ...
    BackgroundTransition = property(get_BackgroundTransition, put_BackgroundTransition)
class IPanelFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPanelFactory'
    _iid_ = Guid('{eee68111-c7cc-433f-95cd-d630c34302dd}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Panel: ...
class IPanelStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPanelStatics'
    _iid_ = Guid('{f23d6b5d-8330-47a6-a046-25f509b25232}')
    @winrt_commethod(6)
    def get_BackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsItemsHostProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ChildrenTransitionsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BackgroundProperty = property(get_BackgroundProperty, None)
    ChildrenTransitionsProperty = property(get_ChildrenTransitionsProperty, None)
    IsItemsHostProperty = property(get_IsItemsHostProperty, None)
class IParallaxView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IParallaxView'
    _iid_ = Guid('{6b84fcd4-4083-5b4b-bc40-d9204e19b41a}')
    @winrt_commethod(6)
    def get_Child(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Child(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_HorizontalShift(self) -> Double: ...
    @winrt_commethod(9)
    def put_HorizontalShift(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_HorizontalSourceEndOffset(self) -> Double: ...
    @winrt_commethod(11)
    def put_HorizontalSourceEndOffset(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_HorizontalSourceOffsetKind(self) -> win32more.Windows.UI.Xaml.Controls.ParallaxSourceOffsetKind: ...
    @winrt_commethod(13)
    def put_HorizontalSourceOffsetKind(self, value: win32more.Windows.UI.Xaml.Controls.ParallaxSourceOffsetKind) -> Void: ...
    @winrt_commethod(14)
    def get_HorizontalSourceStartOffset(self) -> Double: ...
    @winrt_commethod(15)
    def put_HorizontalSourceStartOffset(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_IsHorizontalShiftClamped(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsHorizontalShiftClamped(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_IsVerticalShiftClamped(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_IsVerticalShiftClamped(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_MaxHorizontalShiftRatio(self) -> Double: ...
    @winrt_commethod(21)
    def put_MaxHorizontalShiftRatio(self, value: Double) -> Void: ...
    @winrt_commethod(22)
    def get_MaxVerticalShiftRatio(self) -> Double: ...
    @winrt_commethod(23)
    def put_MaxVerticalShiftRatio(self, value: Double) -> Void: ...
    @winrt_commethod(24)
    def get_Source(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(25)
    def put_Source(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(26)
    def get_VerticalShift(self) -> Double: ...
    @winrt_commethod(27)
    def put_VerticalShift(self, value: Double) -> Void: ...
    @winrt_commethod(28)
    def get_VerticalSourceEndOffset(self) -> Double: ...
    @winrt_commethod(29)
    def put_VerticalSourceEndOffset(self, value: Double) -> Void: ...
    @winrt_commethod(30)
    def get_VerticalSourceOffsetKind(self) -> win32more.Windows.UI.Xaml.Controls.ParallaxSourceOffsetKind: ...
    @winrt_commethod(31)
    def put_VerticalSourceOffsetKind(self, value: win32more.Windows.UI.Xaml.Controls.ParallaxSourceOffsetKind) -> Void: ...
    @winrt_commethod(32)
    def get_VerticalSourceStartOffset(self) -> Double: ...
    @winrt_commethod(33)
    def put_VerticalSourceStartOffset(self, value: Double) -> Void: ...
    @winrt_commethod(34)
    def RefreshAutomaticHorizontalOffsets(self) -> Void: ...
    @winrt_commethod(35)
    def RefreshAutomaticVerticalOffsets(self) -> Void: ...
    Child = property(get_Child, put_Child)
    HorizontalShift = property(get_HorizontalShift, put_HorizontalShift)
    HorizontalSourceEndOffset = property(get_HorizontalSourceEndOffset, put_HorizontalSourceEndOffset)
    HorizontalSourceOffsetKind = property(get_HorizontalSourceOffsetKind, put_HorizontalSourceOffsetKind)
    HorizontalSourceStartOffset = property(get_HorizontalSourceStartOffset, put_HorizontalSourceStartOffset)
    IsHorizontalShiftClamped = property(get_IsHorizontalShiftClamped, put_IsHorizontalShiftClamped)
    IsVerticalShiftClamped = property(get_IsVerticalShiftClamped, put_IsVerticalShiftClamped)
    MaxHorizontalShiftRatio = property(get_MaxHorizontalShiftRatio, put_MaxHorizontalShiftRatio)
    MaxVerticalShiftRatio = property(get_MaxVerticalShiftRatio, put_MaxVerticalShiftRatio)
    Source = property(get_Source, put_Source)
    VerticalShift = property(get_VerticalShift, put_VerticalShift)
    VerticalSourceEndOffset = property(get_VerticalSourceEndOffset, put_VerticalSourceEndOffset)
    VerticalSourceOffsetKind = property(get_VerticalSourceOffsetKind, put_VerticalSourceOffsetKind)
    VerticalSourceStartOffset = property(get_VerticalSourceStartOffset, put_VerticalSourceStartOffset)
class IParallaxViewFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IParallaxViewFactory'
    _iid_ = Guid('{e4eb9642-3e8e-5a26-94f2-9121d121b916}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ParallaxView: ...
class IParallaxViewStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IParallaxViewStatics'
    _iid_ = Guid('{8836e49c-0e0e-57d8-9395-f0a9a0d1bb28}')
    @winrt_commethod(6)
    def get_ChildProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HorizontalSourceEndOffsetProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_HorizontalSourceOffsetKindProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_HorizontalSourceStartOffsetProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_MaxHorizontalShiftRatioProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_HorizontalShiftProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IsHorizontalShiftClampedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_IsVerticalShiftClampedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_SourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_VerticalSourceEndOffsetProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_VerticalSourceOffsetKindProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_VerticalSourceStartOffsetProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_MaxVerticalShiftRatioProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_VerticalShiftProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ChildProperty = property(get_ChildProperty, None)
    HorizontalShiftProperty = property(get_HorizontalShiftProperty, None)
    HorizontalSourceEndOffsetProperty = property(get_HorizontalSourceEndOffsetProperty, None)
    HorizontalSourceOffsetKindProperty = property(get_HorizontalSourceOffsetKindProperty, None)
    HorizontalSourceStartOffsetProperty = property(get_HorizontalSourceStartOffsetProperty, None)
    IsHorizontalShiftClampedProperty = property(get_IsHorizontalShiftClampedProperty, None)
    IsVerticalShiftClampedProperty = property(get_IsVerticalShiftClampedProperty, None)
    MaxHorizontalShiftRatioProperty = property(get_MaxHorizontalShiftRatioProperty, None)
    MaxVerticalShiftRatioProperty = property(get_MaxVerticalShiftRatioProperty, None)
    SourceProperty = property(get_SourceProperty, None)
    VerticalShiftProperty = property(get_VerticalShiftProperty, None)
    VerticalSourceEndOffsetProperty = property(get_VerticalSourceEndOffsetProperty, None)
    VerticalSourceOffsetKindProperty = property(get_VerticalSourceOffsetKindProperty, None)
    VerticalSourceStartOffsetProperty = property(get_VerticalSourceStartOffsetProperty, None)
class IPasswordBox(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPasswordBox'
    _iid_ = Guid('{02b9aa11-0b47-4e7d-ad91-3a4168ed230d}')
    @winrt_commethod(6)
    def get_Password(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Password(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_PasswordChar(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_PasswordChar(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_IsPasswordRevealButtonEnabled(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsPasswordRevealButtonEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_MaxLength(self) -> Int32: ...
    @winrt_commethod(13)
    def put_MaxLength(self, value: Int32) -> Void: ...
    @winrt_commethod(14)
    def add_PasswordChanged(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_PasswordChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def add_ContextMenuOpening(self, handler: win32more.Windows.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_ContextMenuOpening(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def SelectAll(self) -> Void: ...
    IsPasswordRevealButtonEnabled = property(get_IsPasswordRevealButtonEnabled, put_IsPasswordRevealButtonEnabled)
    MaxLength = property(get_MaxLength, put_MaxLength)
    Password = property(get_Password, put_Password)
    PasswordChar = property(get_PasswordChar, put_PasswordChar)
    PasswordChanged = event()
    ContextMenuOpening = event()
class IPasswordBox2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPasswordBox2'
    _iid_ = Guid('{5ed738df-212f-4aeb-b5b8-2c219aec3c0c}')
    @winrt_commethod(6)
    def get_Header(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_HeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_PlaceholderText(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_PlaceholderText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_SelectionHighlightColor(self) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_commethod(13)
    def put_SelectionHighlightColor(self, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_commethod(14)
    def get_PreventKeyboardDisplayOnProgrammaticFocus(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_PreventKeyboardDisplayOnProgrammaticFocus(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def add_Paste(self, handler: win32more.Windows.UI.Xaml.Controls.TextControlPasteEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_Paste(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    PreventKeyboardDisplayOnProgrammaticFocus = property(get_PreventKeyboardDisplayOnProgrammaticFocus, put_PreventKeyboardDisplayOnProgrammaticFocus)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    Paste = event()
class IPasswordBox3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPasswordBox3'
    _iid_ = Guid('{6024d9d1-56b7-41f0-9558-3934c14244d6}')
    @winrt_commethod(6)
    def get_PasswordRevealMode(self) -> win32more.Windows.UI.Xaml.Controls.PasswordRevealMode: ...
    @winrt_commethod(7)
    def put_PasswordRevealMode(self, value: win32more.Windows.UI.Xaml.Controls.PasswordRevealMode) -> Void: ...
    @winrt_commethod(8)
    def get_TextReadingOrder(self) -> win32more.Windows.UI.Xaml.TextReadingOrder: ...
    @winrt_commethod(9)
    def put_TextReadingOrder(self, value: win32more.Windows.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_commethod(10)
    def get_InputScope(self) -> win32more.Windows.UI.Xaml.Input.InputScope: ...
    @winrt_commethod(11)
    def put_InputScope(self, value: win32more.Windows.UI.Xaml.Input.InputScope) -> Void: ...
    InputScope = property(get_InputScope, put_InputScope)
    PasswordRevealMode = property(get_PasswordRevealMode, put_PasswordRevealMode)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
class IPasswordBox4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPasswordBox4'
    _iid_ = Guid('{569f4343-8e6c-44bf-808d-0e03964ed32f}')
    @winrt_commethod(6)
    def add_PasswordChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.PasswordBox, win32more.Windows.UI.Xaml.Controls.PasswordBoxPasswordChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_PasswordChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    PasswordChanging = event()
class IPasswordBox5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPasswordBox5'
    _iid_ = Guid('{f96c2753-e1d4-5142-86c2-7318bfbbc705}')
    @winrt_commethod(6)
    def get_CanPasteClipboardContent(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_SelectionFlyout(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(8)
    def put_SelectionFlyout(self, value: win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(10)
    def put_Description(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(11)
    def PasteFromClipboard(self) -> Void: ...
    CanPasteClipboardContent = property(get_CanPasteClipboardContent, None)
    Description = property(get_Description, put_Description)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
class IPasswordBoxPasswordChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPasswordBoxPasswordChangingEventArgs'
    _iid_ = Guid('{142eda22-3552-4ab8-81a6-a48620ee9c53}')
    @winrt_commethod(6)
    def get_IsContentChanging(self) -> Boolean: ...
    IsContentChanging = property(get_IsContentChanging, None)
class IPasswordBoxStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPasswordBoxStatics'
    _iid_ = Guid('{5ee67563-2d74-4ace-bd79-fcab61a7d77b}')
    @winrt_commethod(6)
    def get_PasswordProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PasswordCharProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsPasswordRevealButtonEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_MaxLengthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsPasswordRevealButtonEnabledProperty = property(get_IsPasswordRevealButtonEnabledProperty, None)
    MaxLengthProperty = property(get_MaxLengthProperty, None)
    PasswordCharProperty = property(get_PasswordCharProperty, None)
    PasswordProperty = property(get_PasswordProperty, None)
class IPasswordBoxStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPasswordBoxStatics2'
    _iid_ = Guid('{fc57935f-98fa-4066-b785-fa725ecde232}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PlaceholderTextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_SelectionHighlightColorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_PreventKeyboardDisplayOnProgrammaticFocusProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    PreventKeyboardDisplayOnProgrammaticFocusProperty = property(get_PreventKeyboardDisplayOnProgrammaticFocusProperty, None)
    SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
class IPasswordBoxStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPasswordBoxStatics3'
    _iid_ = Guid('{a2cdd319-ad6a-4352-b590-f696ffcb8e3f}')
    @winrt_commethod(6)
    def get_PasswordRevealModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TextReadingOrderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_InputScopeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    InputScopeProperty = property(get_InputScopeProperty, None)
    PasswordRevealModeProperty = property(get_PasswordRevealModeProperty, None)
    TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
class IPasswordBoxStatics5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPasswordBoxStatics5'
    _iid_ = Guid('{4bdac1ac-6b42-55f3-bfa4-65c7235078d6}')
    @winrt_commethod(6)
    def get_CanPasteClipboardContentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_SelectionFlyoutProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DescriptionProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CanPasteClipboardContentProperty = property(get_CanPasteClipboardContentProperty, None)
    DescriptionProperty = property(get_DescriptionProperty, None)
    SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
class IPathIcon(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPathIcon'
    _iid_ = Guid('{214c62db-c366-4a0e-b9ad-dcf168d7ec0c}')
    @winrt_commethod(6)
    def get_Data(self) -> win32more.Windows.UI.Xaml.Media.Geometry: ...
    @winrt_commethod(7)
    def put_Data(self, value: win32more.Windows.UI.Xaml.Media.Geometry) -> Void: ...
    Data = property(get_Data, put_Data)
class IPathIconFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPathIconFactory'
    _iid_ = Guid('{af9d9652-9c5d-4a37-9e1a-044abeef792b}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.PathIcon: ...
class IPathIconSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPathIconSource'
    _iid_ = Guid('{1f47010e-b305-4863-8b7a-15d08d633c7a}')
    @winrt_commethod(6)
    def get_Data(self) -> win32more.Windows.UI.Xaml.Media.Geometry: ...
    @winrt_commethod(7)
    def put_Data(self, value: win32more.Windows.UI.Xaml.Media.Geometry) -> Void: ...
    Data = property(get_Data, put_Data)
class IPathIconSourceFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPathIconSourceFactory'
    _iid_ = Guid('{8f7f85b9-5247-4f3b-833f-e384bf7e9c84}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.PathIconSource: ...
class IPathIconSourceStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPathIconSourceStatics'
    _iid_ = Guid('{df7027d5-3682-43ff-80f0-afa256b2fdc3}')
    @winrt_commethod(6)
    def get_DataProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DataProperty = property(get_DataProperty, None)
class IPathIconStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPathIconStatics'
    _iid_ = Guid('{77b75db8-fb15-491a-b6e3-7dbba911bafe}')
    @winrt_commethod(6)
    def get_DataProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DataProperty = property(get_DataProperty, None)
class IPersonPicture(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPersonPicture'
    _iid_ = Guid('{6c230b6d-0d75-4059-91bc-7b174d1d7315}')
    @winrt_commethod(6)
    def get_BadgeNumber(self) -> Int32: ...
    @winrt_commethod(7)
    def put_BadgeNumber(self, value: Int32) -> Void: ...
    @winrt_commethod(8)
    def get_BadgeGlyph(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_BadgeGlyph(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_BadgeImageSource(self) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(11)
    def put_BadgeImageSource(self, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(12)
    def get_BadgeText(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_BadgeText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_IsGroup(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsGroup(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_Contact(self) -> win32more.Windows.ApplicationModel.Contacts.Contact: ...
    @winrt_commethod(17)
    def put_Contact(self, value: win32more.Windows.ApplicationModel.Contacts.Contact) -> Void: ...
    @winrt_commethod(18)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(19)
    def put_DisplayName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(20)
    def get_Initials(self) -> WinRT_String: ...
    @winrt_commethod(21)
    def put_Initials(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(22)
    def get_PreferSmallImage(self) -> Boolean: ...
    @winrt_commethod(23)
    def put_PreferSmallImage(self, value: Boolean) -> Void: ...
    @winrt_commethod(24)
    def get_ProfilePicture(self) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(25)
    def put_ProfilePicture(self, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    BadgeGlyph = property(get_BadgeGlyph, put_BadgeGlyph)
    BadgeImageSource = property(get_BadgeImageSource, put_BadgeImageSource)
    BadgeNumber = property(get_BadgeNumber, put_BadgeNumber)
    BadgeText = property(get_BadgeText, put_BadgeText)
    Contact = property(get_Contact, put_Contact)
    DisplayName = property(get_DisplayName, put_DisplayName)
    Initials = property(get_Initials, put_Initials)
    IsGroup = property(get_IsGroup, put_IsGroup)
    PreferSmallImage = property(get_PreferSmallImage, put_PreferSmallImage)
    ProfilePicture = property(get_ProfilePicture, put_ProfilePicture)
class IPersonPictureFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPersonPictureFactory'
    _iid_ = Guid('{4f18330d-0416-4b92-bfd3-bf5780b46ab2}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.PersonPicture: ...
class IPersonPictureStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPersonPictureStatics'
    _iid_ = Guid('{dbec0982-3c10-4639-9614-aa5b7cdc32ca}')
    @winrt_commethod(6)
    def get_BadgeNumberProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_BadgeGlyphProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_BadgeImageSourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_BadgeTextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsGroupProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_ContactProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_DisplayNameProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_InitialsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_PreferSmallImageProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_ProfilePictureProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BadgeGlyphProperty = property(get_BadgeGlyphProperty, None)
    BadgeImageSourceProperty = property(get_BadgeImageSourceProperty, None)
    BadgeNumberProperty = property(get_BadgeNumberProperty, None)
    BadgeTextProperty = property(get_BadgeTextProperty, None)
    ContactProperty = property(get_ContactProperty, None)
    DisplayNameProperty = property(get_DisplayNameProperty, None)
    InitialsProperty = property(get_InitialsProperty, None)
    IsGroupProperty = property(get_IsGroupProperty, None)
    PreferSmallImageProperty = property(get_PreferSmallImageProperty, None)
    ProfilePictureProperty = property(get_ProfilePictureProperty, None)
class IPickerConfirmedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPickerConfirmedEventArgs'
    _iid_ = Guid('{447a9b51-1e23-4779-992b-986849713941}')
class IPickerFlyout(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPickerFlyout'
    _iid_ = Guid('{a336ffdb-08d9-43e6-944e-f2e5c7cee630}')
    @winrt_commethod(6)
    def get_Content(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Content(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_ConfirmationButtonsVisible(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_ConfirmationButtonsVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def add_Confirmed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.PickerFlyout, win32more.Windows.UI.Xaml.Controls.PickerConfirmedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_Confirmed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def ShowAtAsync(self, target: win32more.Windows.UI.Xaml.FrameworkElement) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    ConfirmationButtonsVisible = property(get_ConfirmationButtonsVisible, put_ConfirmationButtonsVisible)
    Content = property(get_Content, put_Content)
    Confirmed = event()
class IPickerFlyoutPresenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPickerFlyoutPresenter'
    _iid_ = Guid('{5884c978-6b27-4b38-a9ae-677c2994652e}')
class IPickerFlyoutStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPickerFlyoutStatics'
    _iid_ = Guid('{af18a436-f38a-4abd-b933-6286c115b07f}')
    @winrt_commethod(6)
    def get_ContentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ConfirmationButtonsVisibleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ConfirmationButtonsVisibleProperty = property(get_ConfirmationButtonsVisibleProperty, None)
    ContentProperty = property(get_ContentProperty, None)
class IPivot(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPivot'
    _iid_ = Guid('{103e9b13-3400-4a16-90b9-6912bf06974e}')
    @winrt_commethod(6)
    def get_Title(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Title(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_TitleTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_TitleTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_HeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(11)
    def put_HeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(12)
    def get_SelectedIndex(self) -> Int32: ...
    @winrt_commethod(13)
    def put_SelectedIndex(self, value: Int32) -> Void: ...
    @winrt_commethod(14)
    def get_SelectedItem(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(15)
    def put_SelectedItem(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(16)
    def get_IsLocked(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsLocked(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def add_SelectionChanged(self, handler: win32more.Windows.UI.Xaml.Controls.SelectionChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_SelectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(20)
    def add_PivotItemLoading(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.Pivot, win32more.Windows.UI.Xaml.Controls.PivotItemEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_PivotItemLoading(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(22)
    def add_PivotItemLoaded(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.Pivot, win32more.Windows.UI.Xaml.Controls.PivotItemEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(23)
    def remove_PivotItemLoaded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(24)
    def add_PivotItemUnloading(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.Pivot, win32more.Windows.UI.Xaml.Controls.PivotItemEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(25)
    def remove_PivotItemUnloading(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(26)
    def add_PivotItemUnloaded(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.Pivot, win32more.Windows.UI.Xaml.Controls.PivotItemEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(27)
    def remove_PivotItemUnloaded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsLocked = property(get_IsLocked, put_IsLocked)
    SelectedIndex = property(get_SelectedIndex, put_SelectedIndex)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    Title = property(get_Title, put_Title)
    TitleTemplate = property(get_TitleTemplate, put_TitleTemplate)
    SelectionChanged = event()
    PivotItemLoading = event()
    PivotItemLoaded = event()
    PivotItemUnloading = event()
    PivotItemUnloaded = event()
class IPivot2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPivot2'
    _iid_ = Guid('{8b8a8660-1a55-411c-a82d-18991c3f0d6f}')
    @winrt_commethod(6)
    def get_LeftHeader(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_LeftHeader(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_LeftHeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_LeftHeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_RightHeader(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(11)
    def put_RightHeader(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(12)
    def get_RightHeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(13)
    def put_RightHeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    LeftHeader = property(get_LeftHeader, put_LeftHeader)
    LeftHeaderTemplate = property(get_LeftHeaderTemplate, put_LeftHeaderTemplate)
    RightHeader = property(get_RightHeader, put_RightHeader)
    RightHeaderTemplate = property(get_RightHeaderTemplate, put_RightHeaderTemplate)
class IPivot3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPivot3'
    _iid_ = Guid('{95bcbf96-f0da-4089-8c65-e8b81354c766}')
    @winrt_commethod(6)
    def get_HeaderFocusVisualPlacement(self) -> win32more.Windows.UI.Xaml.Controls.PivotHeaderFocusVisualPlacement: ...
    @winrt_commethod(7)
    def put_HeaderFocusVisualPlacement(self, value: win32more.Windows.UI.Xaml.Controls.PivotHeaderFocusVisualPlacement) -> Void: ...
    @winrt_commethod(8)
    def get_IsHeaderItemsCarouselEnabled(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsHeaderItemsCarouselEnabled(self, value: Boolean) -> Void: ...
    HeaderFocusVisualPlacement = property(get_HeaderFocusVisualPlacement, put_HeaderFocusVisualPlacement)
    IsHeaderItemsCarouselEnabled = property(get_IsHeaderItemsCarouselEnabled, put_IsHeaderItemsCarouselEnabled)
class IPivotFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPivotFactory'
    _iid_ = Guid('{1b0a818e-2529-4762-ba44-9abc68c3ceca}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Pivot: ...
class IPivotItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPivotItem'
    _iid_ = Guid('{a4764371-a502-47a3-915e-4aa096daf87f}')
    @winrt_commethod(6)
    def get_Header(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    Header = property(get_Header, put_Header)
class IPivotItemEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPivotItemEventArgs'
    _iid_ = Guid('{1a6f7254-1ed5-4bc5-a060-655530bca6ba}')
    @winrt_commethod(6)
    def get_Item(self) -> win32more.Windows.UI.Xaml.Controls.PivotItem: ...
    @winrt_commethod(7)
    def put_Item(self, value: win32more.Windows.UI.Xaml.Controls.PivotItem) -> Void: ...
    Item = property(get_Item, put_Item)
class IPivotItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPivotItemFactory'
    _iid_ = Guid('{0dced981-636e-4a34-8a3f-8ee018639285}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.PivotItem: ...
class IPivotItemStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPivotItemStatics'
    _iid_ = Guid('{e147ad0c-488b-4a6e-becd-a5dbd9941754}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HeaderProperty = property(get_HeaderProperty, None)
class IPivotStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPivotStatics'
    _iid_ = Guid('{ee22c7f4-c15d-4ff3-8a94-f50dfdfbe899}')
    @winrt_commethod(6)
    def get_TitleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TitleTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_HeaderTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_SelectedIndexProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_SelectedItemProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsLockedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_SlideInAnimationGroupProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def GetSlideInAnimationGroup(self, element: win32more.Windows.UI.Xaml.FrameworkElement) -> win32more.Windows.UI.Xaml.Controls.PivotSlideInAnimationGroup: ...
    @winrt_commethod(14)
    def SetSlideInAnimationGroup(self, element: win32more.Windows.UI.Xaml.FrameworkElement, value: win32more.Windows.UI.Xaml.Controls.PivotSlideInAnimationGroup) -> Void: ...
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IsLockedProperty = property(get_IsLockedProperty, None)
    SelectedIndexProperty = property(get_SelectedIndexProperty, None)
    SelectedItemProperty = property(get_SelectedItemProperty, None)
    SlideInAnimationGroupProperty = property(get_SlideInAnimationGroupProperty, None)
    TitleProperty = property(get_TitleProperty, None)
    TitleTemplateProperty = property(get_TitleTemplateProperty, None)
class IPivotStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPivotStatics2'
    _iid_ = Guid('{d7518add-be75-4023-8deb-c6513c3192a3}')
    @winrt_commethod(6)
    def get_LeftHeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_LeftHeaderTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_RightHeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_RightHeaderTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    LeftHeaderProperty = property(get_LeftHeaderProperty, None)
    LeftHeaderTemplateProperty = property(get_LeftHeaderTemplateProperty, None)
    RightHeaderProperty = property(get_RightHeaderProperty, None)
    RightHeaderTemplateProperty = property(get_RightHeaderTemplateProperty, None)
class IPivotStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IPivotStatics3'
    _iid_ = Guid('{78b6274e-6616-4600-a039-922a5d09330b}')
    @winrt_commethod(6)
    def get_HeaderFocusVisualPlacementProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsHeaderItemsCarouselEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HeaderFocusVisualPlacementProperty = property(get_HeaderFocusVisualPlacementProperty, None)
    IsHeaderItemsCarouselEnabledProperty = property(get_IsHeaderItemsCarouselEnabledProperty, None)
class IProgressBar(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IProgressBar'
    _iid_ = Guid('{ae752c89-0067-4963-bf4c-29db0c4a507e}')
    @winrt_commethod(6)
    def get_IsIndeterminate(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsIndeterminate(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_ShowError(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_ShowError(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_ShowPaused(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_ShowPaused(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_TemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.ProgressBarTemplateSettings: ...
    IsIndeterminate = property(get_IsIndeterminate, put_IsIndeterminate)
    ShowError = property(get_ShowError, put_ShowError)
    ShowPaused = property(get_ShowPaused, put_ShowPaused)
    TemplateSettings = property(get_TemplateSettings, None)
class IProgressBarFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IProgressBarFactory'
    _iid_ = Guid('{da9a8c11-1591-400b-a993-0f1c5cc12f3b}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ProgressBar: ...
class IProgressBarStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IProgressBarStatics'
    _iid_ = Guid('{7a129fda-5837-4e26-b3b4-e1c092cebbec}')
    @winrt_commethod(6)
    def get_IsIndeterminateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ShowErrorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ShowPausedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsIndeterminateProperty = property(get_IsIndeterminateProperty, None)
    ShowErrorProperty = property(get_ShowErrorProperty, None)
    ShowPausedProperty = property(get_ShowPausedProperty, None)
class IProgressRing(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IProgressRing'
    _iid_ = Guid('{6da5e49e-6e9d-425c-bd7c-02173e39763f}')
    @winrt_commethod(6)
    def get_IsActive(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsActive(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_TemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.ProgressRingTemplateSettings: ...
    IsActive = property(get_IsActive, put_IsActive)
    TemplateSettings = property(get_TemplateSettings, None)
class IProgressRingStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IProgressRingStatics'
    _iid_ = Guid('{e8b62507-4e2c-47d5-a54a-c6c48a5e6989}')
    @winrt_commethod(6)
    def get_IsActiveProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsActiveProperty = property(get_IsActiveProperty, None)
class IRadioButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRadioButton'
    _iid_ = Guid('{325c44e0-9a03-4bf3-abd6-6fbb46c9a486}')
    @winrt_commethod(6)
    def get_GroupName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_GroupName(self, value: WinRT_String) -> Void: ...
    GroupName = property(get_GroupName, put_GroupName)
class IRadioButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRadioButtonFactory'
    _iid_ = Guid('{f1d04933-34e1-4a5c-b2ae-ca3b1c0b20de}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RadioButton: ...
class IRadioButtonStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRadioButtonStatics'
    _iid_ = Guid('{6b149293-f50f-4bd8-b0ac-5c162f33a208}')
    @winrt_commethod(6)
    def get_GroupNameProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    GroupNameProperty = property(get_GroupNameProperty, None)
class IRatingControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRatingControl'
    _iid_ = Guid('{a7d91ca7-e5cf-4963-a24e-9673fe5ffdd5}')
    @winrt_commethod(6)
    def get_Caption(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Caption(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_InitialSetValue(self) -> Int32: ...
    @winrt_commethod(9)
    def put_InitialSetValue(self, value: Int32) -> Void: ...
    @winrt_commethod(10)
    def get_IsClearEnabled(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsClearEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_IsReadOnly(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsReadOnly(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_MaxRating(self) -> Int32: ...
    @winrt_commethod(15)
    def put_MaxRating(self, value: Int32) -> Void: ...
    @winrt_commethod(16)
    def get_PlaceholderValue(self) -> Double: ...
    @winrt_commethod(17)
    def put_PlaceholderValue(self, value: Double) -> Void: ...
    @winrt_commethod(18)
    def get_ItemInfo(self) -> win32more.Windows.UI.Xaml.Controls.RatingItemInfo: ...
    @winrt_commethod(19)
    def put_ItemInfo(self, value: win32more.Windows.UI.Xaml.Controls.RatingItemInfo) -> Void: ...
    @winrt_commethod(20)
    def get_Value(self) -> Double: ...
    @winrt_commethod(21)
    def put_Value(self, value: Double) -> Void: ...
    @winrt_commethod(22)
    def add_ValueChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RatingControl, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(23)
    def remove_ValueChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Caption = property(get_Caption, put_Caption)
    InitialSetValue = property(get_InitialSetValue, put_InitialSetValue)
    IsClearEnabled = property(get_IsClearEnabled, put_IsClearEnabled)
    IsReadOnly = property(get_IsReadOnly, put_IsReadOnly)
    ItemInfo = property(get_ItemInfo, put_ItemInfo)
    MaxRating = property(get_MaxRating, put_MaxRating)
    PlaceholderValue = property(get_PlaceholderValue, put_PlaceholderValue)
    Value = property(get_Value, put_Value)
    ValueChanged = event()
class IRatingControlFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRatingControlFactory'
    _iid_ = Guid('{18d81716-c542-4ccb-b347-5e62c5db782e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RatingControl: ...
class IRatingControlStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRatingControlStatics'
    _iid_ = Guid('{d062d399-ad85-4c1c-b2c4-35dd4432275e}')
    @winrt_commethod(6)
    def get_CaptionProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_InitialSetValueProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsClearEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_IsReadOnlyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_MaxRatingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_PlaceholderValueProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ItemInfoProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_ValueProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CaptionProperty = property(get_CaptionProperty, None)
    InitialSetValueProperty = property(get_InitialSetValueProperty, None)
    IsClearEnabledProperty = property(get_IsClearEnabledProperty, None)
    IsReadOnlyProperty = property(get_IsReadOnlyProperty, None)
    ItemInfoProperty = property(get_ItemInfoProperty, None)
    MaxRatingProperty = property(get_MaxRatingProperty, None)
    PlaceholderValueProperty = property(get_PlaceholderValueProperty, None)
    ValueProperty = property(get_ValueProperty, None)
class IRatingItemFontInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRatingItemFontInfo'
    _iid_ = Guid('{054723e9-7989-4d5c-9d01-a7eb876f1071}')
    @winrt_commethod(6)
    def get_DisabledGlyph(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_DisabledGlyph(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Glyph(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_Glyph(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_PointerOverGlyph(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_PointerOverGlyph(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_PointerOverPlaceholderGlyph(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_PointerOverPlaceholderGlyph(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_PlaceholderGlyph(self) -> WinRT_String: ...
    @winrt_commethod(15)
    def put_PlaceholderGlyph(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(16)
    def get_UnsetGlyph(self) -> WinRT_String: ...
    @winrt_commethod(17)
    def put_UnsetGlyph(self, value: WinRT_String) -> Void: ...
    DisabledGlyph = property(get_DisabledGlyph, put_DisabledGlyph)
    Glyph = property(get_Glyph, put_Glyph)
    PlaceholderGlyph = property(get_PlaceholderGlyph, put_PlaceholderGlyph)
    PointerOverGlyph = property(get_PointerOverGlyph, put_PointerOverGlyph)
    PointerOverPlaceholderGlyph = property(get_PointerOverPlaceholderGlyph, put_PointerOverPlaceholderGlyph)
    UnsetGlyph = property(get_UnsetGlyph, put_UnsetGlyph)
class IRatingItemFontInfoFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRatingItemFontInfoFactory'
    _iid_ = Guid('{9603fe56-9e9f-40b5-bae1-4481bb73bcd3}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RatingItemFontInfo: ...
class IRatingItemFontInfoStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRatingItemFontInfoStatics'
    _iid_ = Guid('{fb214f01-6434-4eeb-82ff-7ce5d40bf510}')
    @winrt_commethod(6)
    def get_DisabledGlyphProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_GlyphProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PlaceholderGlyphProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PointerOverGlyphProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_PointerOverPlaceholderGlyphProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_UnsetGlyphProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DisabledGlyphProperty = property(get_DisabledGlyphProperty, None)
    GlyphProperty = property(get_GlyphProperty, None)
    PlaceholderGlyphProperty = property(get_PlaceholderGlyphProperty, None)
    PointerOverGlyphProperty = property(get_PointerOverGlyphProperty, None)
    PointerOverPlaceholderGlyphProperty = property(get_PointerOverPlaceholderGlyphProperty, None)
    UnsetGlyphProperty = property(get_UnsetGlyphProperty, None)
class IRatingItemImageInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRatingItemImageInfo'
    _iid_ = Guid('{25240e8c-e0d2-490e-b8f8-96c8ee0512b9}')
    @winrt_commethod(6)
    def get_DisabledImage(self) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(7)
    def put_DisabledImage(self, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(8)
    def get_Image(self) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(9)
    def put_Image(self, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(10)
    def get_PlaceholderImage(self) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(11)
    def put_PlaceholderImage(self, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(12)
    def get_PointerOverImage(self) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(13)
    def put_PointerOverImage(self, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(14)
    def get_PointerOverPlaceholderImage(self) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(15)
    def put_PointerOverPlaceholderImage(self, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(16)
    def get_UnsetImage(self) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(17)
    def put_UnsetImage(self, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    DisabledImage = property(get_DisabledImage, put_DisabledImage)
    Image = property(get_Image, put_Image)
    PlaceholderImage = property(get_PlaceholderImage, put_PlaceholderImage)
    PointerOverImage = property(get_PointerOverImage, put_PointerOverImage)
    PointerOverPlaceholderImage = property(get_PointerOverPlaceholderImage, put_PointerOverPlaceholderImage)
    UnsetImage = property(get_UnsetImage, put_UnsetImage)
class IRatingItemImageInfoFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRatingItemImageInfoFactory'
    _iid_ = Guid('{269e03f2-da79-4787-9f4a-24a6fa56cde2}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RatingItemImageInfo: ...
class IRatingItemImageInfoStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRatingItemImageInfoStatics'
    _iid_ = Guid('{8438486b-4b1c-4123-ba0b-73484d68c338}')
    @winrt_commethod(6)
    def get_DisabledImageProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ImageProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PlaceholderImageProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PointerOverImageProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_PointerOverPlaceholderImageProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_UnsetImageProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DisabledImageProperty = property(get_DisabledImageProperty, None)
    ImageProperty = property(get_ImageProperty, None)
    PlaceholderImageProperty = property(get_PlaceholderImageProperty, None)
    PointerOverImageProperty = property(get_PointerOverImageProperty, None)
    PointerOverPlaceholderImageProperty = property(get_PointerOverPlaceholderImageProperty, None)
    UnsetImageProperty = property(get_UnsetImageProperty, None)
class IRatingItemInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRatingItemInfo'
    _iid_ = Guid('{9ccbe6a2-591e-47a0-a318-6a1f7947da2d}')
class IRatingItemInfoFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRatingItemInfoFactory'
    _iid_ = Guid('{b0fd43d6-cfec-43c8-9ac5-0b0d5e25d862}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RatingItemInfo: ...
class IRefreshContainer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRefreshContainer'
    _iid_ = Guid('{535dc413-b1d5-43c1-b057-8658ce1e0ba2}')
    @winrt_commethod(6)
    def get_Visualizer(self) -> win32more.Windows.UI.Xaml.Controls.RefreshVisualizer: ...
    @winrt_commethod(7)
    def put_Visualizer(self, value: win32more.Windows.UI.Xaml.Controls.RefreshVisualizer) -> Void: ...
    @winrt_commethod(8)
    def get_PullDirection(self) -> win32more.Windows.UI.Xaml.Controls.RefreshPullDirection: ...
    @winrt_commethod(9)
    def put_PullDirection(self, value: win32more.Windows.UI.Xaml.Controls.RefreshPullDirection) -> Void: ...
    @winrt_commethod(10)
    def add_RefreshRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RefreshContainer, win32more.Windows.UI.Xaml.Controls.RefreshRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_RefreshRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def RequestRefresh(self) -> Void: ...
    PullDirection = property(get_PullDirection, put_PullDirection)
    Visualizer = property(get_Visualizer, put_Visualizer)
    RefreshRequested = event()
class IRefreshContainerFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRefreshContainerFactory'
    _iid_ = Guid('{0a04777f-089e-4239-baeb-c4641484c37e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RefreshContainer: ...
class IRefreshContainerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRefreshContainerStatics'
    _iid_ = Guid('{a20af5a5-7015-475d-9de3-81a0479dda38}')
    @winrt_commethod(6)
    def get_VisualizerProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PullDirectionProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    PullDirectionProperty = property(get_PullDirectionProperty, None)
    VisualizerProperty = property(get_VisualizerProperty, None)
class IRefreshInteractionRatioChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRefreshInteractionRatioChangedEventArgs'
    _iid_ = Guid('{d7e47820-dc47-4b8e-bb27-7f0a83f29a07}')
    @winrt_commethod(6)
    def get_InteractionRatio(self) -> Double: ...
    InteractionRatio = property(get_InteractionRatio, None)
class IRefreshRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRefreshRequestedEventArgs'
    _iid_ = Guid('{1b089f43-cfcf-4ac6-b31f-8dab6eefdd93}')
    @winrt_commethod(6)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
class IRefreshStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRefreshStateChangedEventArgs'
    _iid_ = Guid('{bb6c901e-21fe-4109-af80-73ec661b678a}')
    @winrt_commethod(6)
    def get_OldState(self) -> win32more.Windows.UI.Xaml.Controls.RefreshVisualizerState: ...
    @winrt_commethod(7)
    def get_NewState(self) -> win32more.Windows.UI.Xaml.Controls.RefreshVisualizerState: ...
    NewState = property(get_NewState, None)
    OldState = property(get_OldState, None)
class IRefreshVisualizer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRefreshVisualizer'
    _iid_ = Guid('{c0e30122-f3eb-4baa-a11f-c3f87342cbf4}')
    @winrt_commethod(6)
    def RequestRefresh(self) -> Void: ...
    @winrt_commethod(7)
    def get_Orientation(self) -> win32more.Windows.UI.Xaml.Controls.RefreshVisualizerOrientation: ...
    @winrt_commethod(8)
    def put_Orientation(self, value: win32more.Windows.UI.Xaml.Controls.RefreshVisualizerOrientation) -> Void: ...
    @winrt_commethod(9)
    def get_Content(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(10)
    def put_Content(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(11)
    def get_State(self) -> win32more.Windows.UI.Xaml.Controls.RefreshVisualizerState: ...
    @winrt_commethod(12)
    def add_RefreshRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RefreshVisualizer, win32more.Windows.UI.Xaml.Controls.RefreshRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_RefreshRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_RefreshStateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RefreshVisualizer, win32more.Windows.UI.Xaml.Controls.RefreshStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_RefreshStateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Content = property(get_Content, put_Content)
    Orientation = property(get_Orientation, put_Orientation)
    State = property(get_State, None)
    RefreshRequested = event()
    RefreshStateChanged = event()
class IRefreshVisualizerFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRefreshVisualizerFactory'
    _iid_ = Guid('{6f5c6132-6e09-4c10-824a-127d36672715}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RefreshVisualizer: ...
class IRefreshVisualizerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRefreshVisualizerStatics'
    _iid_ = Guid('{afea56af-362a-4015-b155-733a1f869831}')
    @winrt_commethod(6)
    def get_InfoProviderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_OrientationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ContentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_StateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ContentProperty = property(get_ContentProperty, None)
    InfoProviderProperty = property(get_InfoProviderProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
    StateProperty = property(get_StateProperty, None)
class IRelativePanel(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRelativePanel'
    _iid_ = Guid('{2eabfaeb-b35a-4035-acea-3c4a3730683f}')
    @winrt_commethod(6)
    def get_BorderBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(7)
    def put_BorderBrush(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(8)
    def get_BorderThickness(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(9)
    def put_BorderThickness(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(10)
    def get_CornerRadius(self) -> win32more.Windows.UI.Xaml.CornerRadius: ...
    @winrt_commethod(11)
    def put_CornerRadius(self, value: win32more.Windows.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_commethod(12)
    def get_Padding(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(13)
    def put_Padding(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    Padding = property(get_Padding, put_Padding)
class IRelativePanel2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRelativePanel2'
    _iid_ = Guid('{c09bd88c-1e82-53b3-8c01-7d0432f5f7db}')
    @winrt_commethod(6)
    def get_BackgroundSizing(self) -> win32more.Windows.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_commethod(7)
    def put_BackgroundSizing(self, value: win32more.Windows.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
class IRelativePanelFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRelativePanelFactory'
    _iid_ = Guid('{8460193c-361b-44ba-a17e-b84c9dcdc772}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RelativePanel: ...
class IRelativePanelStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRelativePanelStatics'
    _iid_ = Guid('{15903c27-f18c-4c35-8e19-6a7459d907b6}')
    @winrt_commethod(6)
    def get_LeftOfProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def GetLeftOf(self, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(8)
    def SetLeftOf(self, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(9)
    def get_AboveProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def GetAbove(self, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(11)
    def SetAbove(self, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(12)
    def get_RightOfProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def GetRightOf(self, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(14)
    def SetRightOf(self, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(15)
    def get_BelowProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def GetBelow(self, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(17)
    def SetBelow(self, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(18)
    def get_AlignHorizontalCenterWithProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def GetAlignHorizontalCenterWith(self, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(20)
    def SetAlignHorizontalCenterWith(self, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(21)
    def get_AlignVerticalCenterWithProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def GetAlignVerticalCenterWith(self, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(23)
    def SetAlignVerticalCenterWith(self, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(24)
    def get_AlignLeftWithProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def GetAlignLeftWith(self, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(26)
    def SetAlignLeftWith(self, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(27)
    def get_AlignTopWithProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(28)
    def GetAlignTopWith(self, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(29)
    def SetAlignTopWith(self, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(30)
    def get_AlignRightWithProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(31)
    def GetAlignRightWith(self, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(32)
    def SetAlignRightWith(self, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(33)
    def get_AlignBottomWithProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(34)
    def GetAlignBottomWith(self, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(35)
    def SetAlignBottomWith(self, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(36)
    def get_AlignLeftWithPanelProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(37)
    def GetAlignLeftWithPanel(self, element: win32more.Windows.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_commethod(38)
    def SetAlignLeftWithPanel(self, element: win32more.Windows.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_commethod(39)
    def get_AlignTopWithPanelProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(40)
    def GetAlignTopWithPanel(self, element: win32more.Windows.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_commethod(41)
    def SetAlignTopWithPanel(self, element: win32more.Windows.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_commethod(42)
    def get_AlignRightWithPanelProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(43)
    def GetAlignRightWithPanel(self, element: win32more.Windows.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_commethod(44)
    def SetAlignRightWithPanel(self, element: win32more.Windows.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_commethod(45)
    def get_AlignBottomWithPanelProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(46)
    def GetAlignBottomWithPanel(self, element: win32more.Windows.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_commethod(47)
    def SetAlignBottomWithPanel(self, element: win32more.Windows.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_commethod(48)
    def get_AlignHorizontalCenterWithPanelProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(49)
    def GetAlignHorizontalCenterWithPanel(self, element: win32more.Windows.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_commethod(50)
    def SetAlignHorizontalCenterWithPanel(self, element: win32more.Windows.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_commethod(51)
    def get_AlignVerticalCenterWithPanelProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(52)
    def GetAlignVerticalCenterWithPanel(self, element: win32more.Windows.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_commethod(53)
    def SetAlignVerticalCenterWithPanel(self, element: win32more.Windows.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_commethod(54)
    def get_BorderBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(55)
    def get_BorderThicknessProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(56)
    def get_CornerRadiusProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(57)
    def get_PaddingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AboveProperty = property(get_AboveProperty, None)
    AlignBottomWithPanelProperty = property(get_AlignBottomWithPanelProperty, None)
    AlignBottomWithProperty = property(get_AlignBottomWithProperty, None)
    AlignHorizontalCenterWithPanelProperty = property(get_AlignHorizontalCenterWithPanelProperty, None)
    AlignHorizontalCenterWithProperty = property(get_AlignHorizontalCenterWithProperty, None)
    AlignLeftWithPanelProperty = property(get_AlignLeftWithPanelProperty, None)
    AlignLeftWithProperty = property(get_AlignLeftWithProperty, None)
    AlignRightWithPanelProperty = property(get_AlignRightWithPanelProperty, None)
    AlignRightWithProperty = property(get_AlignRightWithProperty, None)
    AlignTopWithPanelProperty = property(get_AlignTopWithPanelProperty, None)
    AlignTopWithProperty = property(get_AlignTopWithProperty, None)
    AlignVerticalCenterWithPanelProperty = property(get_AlignVerticalCenterWithPanelProperty, None)
    AlignVerticalCenterWithProperty = property(get_AlignVerticalCenterWithProperty, None)
    BelowProperty = property(get_BelowProperty, None)
    BorderBrushProperty = property(get_BorderBrushProperty, None)
    BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    LeftOfProperty = property(get_LeftOfProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
    RightOfProperty = property(get_RightOfProperty, None)
class IRelativePanelStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRelativePanelStatics2'
    _iid_ = Guid('{8d6b3444-5fbc-5d8b-8b46-22176f21fa8e}')
    @winrt_commethod(6)
    def get_BackgroundSizingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
class IRichEditBox(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBox'
    _iid_ = Guid('{90a57a40-80b6-4fce-b1ec-e3c616284b6a}')
    @winrt_commethod(6)
    def get_IsReadOnly(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsReadOnly(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_AcceptsReturn(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_AcceptsReturn(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_TextAlignment(self) -> win32more.Windows.UI.Xaml.TextAlignment: ...
    @winrt_commethod(11)
    def put_TextAlignment(self, value: win32more.Windows.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(12)
    def get_TextWrapping(self) -> win32more.Windows.UI.Xaml.TextWrapping: ...
    @winrt_commethod(13)
    def put_TextWrapping(self, value: win32more.Windows.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_commethod(14)
    def get_IsSpellCheckEnabled(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsSpellCheckEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_IsTextPredictionEnabled(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsTextPredictionEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_Document(self) -> win32more.Windows.UI.Text.ITextDocument: ...
    @winrt_commethod(19)
    def get_InputScope(self) -> win32more.Windows.UI.Xaml.Input.InputScope: ...
    @winrt_commethod(20)
    def put_InputScope(self, value: win32more.Windows.UI.Xaml.Input.InputScope) -> Void: ...
    @winrt_commethod(21)
    def add_TextChanged(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(22)
    def remove_TextChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(23)
    def add_SelectionChanged(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(24)
    def remove_SelectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(25)
    def add_ContextMenuOpening(self, handler: win32more.Windows.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(26)
    def remove_ContextMenuOpening(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AcceptsReturn = property(get_AcceptsReturn, put_AcceptsReturn)
    Document = property(get_Document, None)
    InputScope = property(get_InputScope, put_InputScope)
    IsReadOnly = property(get_IsReadOnly, put_IsReadOnly)
    IsSpellCheckEnabled = property(get_IsSpellCheckEnabled, put_IsSpellCheckEnabled)
    IsTextPredictionEnabled = property(get_IsTextPredictionEnabled, put_IsTextPredictionEnabled)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    TextChanged = event()
    SelectionChanged = event()
    ContextMenuOpening = event()
class IRichEditBox2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBox2'
    _iid_ = Guid('{bbea6ead-e805-47a4-bbe7-47e59b8f74a7}')
    @winrt_commethod(6)
    def get_Header(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_HeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_PlaceholderText(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_PlaceholderText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_SelectionHighlightColor(self) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_commethod(13)
    def put_SelectionHighlightColor(self, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_commethod(14)
    def get_PreventKeyboardDisplayOnProgrammaticFocus(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_PreventKeyboardDisplayOnProgrammaticFocus(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_IsColorFontEnabled(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsColorFontEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def add_Paste(self, handler: win32more.Windows.UI.Xaml.Controls.TextControlPasteEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_Paste(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    PreventKeyboardDisplayOnProgrammaticFocus = property(get_PreventKeyboardDisplayOnProgrammaticFocus, put_PreventKeyboardDisplayOnProgrammaticFocus)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    Paste = event()
class IRichEditBox3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBox3'
    _iid_ = Guid('{6b17a462-fbb6-4fff-9991-9399cb9c0b90}')
    @winrt_commethod(6)
    def add_TextCompositionStarted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.TextCompositionStartedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_TextCompositionStarted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_TextCompositionChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.TextCompositionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_TextCompositionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def add_TextCompositionEnded(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.TextCompositionEndedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_TextCompositionEnded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def get_TextReadingOrder(self) -> win32more.Windows.UI.Xaml.TextReadingOrder: ...
    @winrt_commethod(13)
    def put_TextReadingOrder(self, value: win32more.Windows.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_commethod(14)
    def get_DesiredCandidateWindowAlignment(self) -> win32more.Windows.UI.Xaml.Controls.CandidateWindowAlignment: ...
    @winrt_commethod(15)
    def put_DesiredCandidateWindowAlignment(self, value: win32more.Windows.UI.Xaml.Controls.CandidateWindowAlignment) -> Void: ...
    @winrt_commethod(16)
    def add_CandidateWindowBoundsChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.CandidateWindowBoundsChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_CandidateWindowBoundsChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def add_TextChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.RichEditBoxTextChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_TextChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    DesiredCandidateWindowAlignment = property(get_DesiredCandidateWindowAlignment, put_DesiredCandidateWindowAlignment)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    TextCompositionStarted = event()
    TextCompositionChanged = event()
    TextCompositionEnded = event()
    CandidateWindowBoundsChanged = event()
    TextChanging = event()
class IRichEditBox4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBox4'
    _iid_ = Guid('{5caa8d35-c838-4bad-a07c-204183bb751f}')
    @winrt_commethod(6)
    def GetLinguisticAlternativesAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    @winrt_commethod(7)
    def get_ClipboardCopyFormat(self) -> win32more.Windows.UI.Xaml.Controls.RichEditClipboardFormat: ...
    @winrt_commethod(8)
    def put_ClipboardCopyFormat(self, value: win32more.Windows.UI.Xaml.Controls.RichEditClipboardFormat) -> Void: ...
    ClipboardCopyFormat = property(get_ClipboardCopyFormat, put_ClipboardCopyFormat)
class IRichEditBox5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBox5'
    _iid_ = Guid('{a66d9cea-6391-4f3b-9fd3-1fd01f49f327}')
    @winrt_commethod(6)
    def get_SelectionHighlightColorWhenNotFocused(self) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_commethod(7)
    def put_SelectionHighlightColorWhenNotFocused(self, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_commethod(8)
    def get_MaxLength(self) -> Int32: ...
    @winrt_commethod(9)
    def put_MaxLength(self, value: Int32) -> Void: ...
    MaxLength = property(get_MaxLength, put_MaxLength)
    SelectionHighlightColorWhenNotFocused = property(get_SelectionHighlightColorWhenNotFocused, put_SelectionHighlightColorWhenNotFocused)
class IRichEditBox6(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBox6'
    _iid_ = Guid('{0c89d500-e8d8-4eae-8804-33649205d7d2}')
    @winrt_commethod(6)
    def get_HorizontalTextAlignment(self) -> win32more.Windows.UI.Xaml.TextAlignment: ...
    @winrt_commethod(7)
    def put_HorizontalTextAlignment(self, value: win32more.Windows.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(8)
    def get_CharacterCasing(self) -> win32more.Windows.UI.Xaml.Controls.CharacterCasing: ...
    @winrt_commethod(9)
    def put_CharacterCasing(self, value: win32more.Windows.UI.Xaml.Controls.CharacterCasing) -> Void: ...
    @winrt_commethod(10)
    def get_DisabledFormattingAccelerators(self) -> win32more.Windows.UI.Xaml.Controls.DisabledFormattingAccelerators: ...
    @winrt_commethod(11)
    def put_DisabledFormattingAccelerators(self, value: win32more.Windows.UI.Xaml.Controls.DisabledFormattingAccelerators) -> Void: ...
    @winrt_commethod(12)
    def add_CopyingToClipboard(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.TextControlCopyingToClipboardEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_CopyingToClipboard(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_CuttingToClipboard(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.TextControlCuttingToClipboardEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_CuttingToClipboard(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CharacterCasing = property(get_CharacterCasing, put_CharacterCasing)
    DisabledFormattingAccelerators = property(get_DisabledFormattingAccelerators, put_DisabledFormattingAccelerators)
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    CopyingToClipboard = event()
    CuttingToClipboard = event()
class IRichEditBox7(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBox7'
    _iid_ = Guid('{980c93ea-241f-4f6a-a539-9d185c8cf18a}')
    @winrt_commethod(6)
    def get_ContentLinkForegroundColor(self) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_commethod(7)
    def put_ContentLinkForegroundColor(self, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_commethod(8)
    def get_ContentLinkBackgroundColor(self) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_commethod(9)
    def put_ContentLinkBackgroundColor(self, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_commethod(10)
    def get_ContentLinkProviders(self) -> win32more.Windows.UI.Xaml.Documents.ContentLinkProviderCollection: ...
    @winrt_commethod(11)
    def put_ContentLinkProviders(self, value: win32more.Windows.UI.Xaml.Documents.ContentLinkProviderCollection) -> Void: ...
    @winrt_commethod(12)
    def get_HandwritingView(self) -> win32more.Windows.UI.Xaml.Controls.HandwritingView: ...
    @winrt_commethod(13)
    def put_HandwritingView(self, value: win32more.Windows.UI.Xaml.Controls.HandwritingView) -> Void: ...
    @winrt_commethod(14)
    def get_IsHandwritingViewEnabled(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsHandwritingViewEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def add_ContentLinkChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.ContentLinkChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_ContentLinkChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def add_ContentLinkInvoked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Documents.ContentLinkInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_ContentLinkInvoked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ContentLinkBackgroundColor = property(get_ContentLinkBackgroundColor, put_ContentLinkBackgroundColor)
    ContentLinkForegroundColor = property(get_ContentLinkForegroundColor, put_ContentLinkForegroundColor)
    ContentLinkProviders = property(get_ContentLinkProviders, put_ContentLinkProviders)
    HandwritingView = property(get_HandwritingView, put_HandwritingView)
    IsHandwritingViewEnabled = property(get_IsHandwritingViewEnabled, put_IsHandwritingViewEnabled)
    ContentLinkChanged = event()
    ContentLinkInvoked = event()
class IRichEditBox8(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBox8'
    _iid_ = Guid('{a098e0b8-18e2-513e-9d8d-4e9703410c03}')
    @winrt_commethod(6)
    def get_TextDocument(self) -> win32more.Windows.UI.Text.RichEditTextDocument: ...
    @winrt_commethod(7)
    def get_SelectionFlyout(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(8)
    def put_SelectionFlyout(self, value: win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_commethod(9)
    def get_ProofingMenuFlyout(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(10)
    def get_Description(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(11)
    def put_Description(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(12)
    def add_SelectionChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.RichEditBoxSelectionChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_SelectionChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Description = property(get_Description, put_Description)
    ProofingMenuFlyout = property(get_ProofingMenuFlyout, None)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    TextDocument = property(get_TextDocument, None)
    SelectionChanging = event()
class IRichEditBoxFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBoxFactory'
    _iid_ = Guid('{61a1df62-2806-41ed-88ed-ae21f47ab422}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RichEditBox: ...
class IRichEditBoxSelectionChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBoxSelectionChangingEventArgs'
    _iid_ = Guid('{90e0035c-e8b8-5c33-9896-4e989d65829c}')
    @winrt_commethod(6)
    def get_SelectionStart(self) -> Int32: ...
    @winrt_commethod(7)
    def get_SelectionLength(self) -> Int32: ...
    @winrt_commethod(8)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    SelectionLength = property(get_SelectionLength, None)
    SelectionStart = property(get_SelectionStart, None)
class IRichEditBoxStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBoxStatics'
    _iid_ = Guid('{f5e03a74-88ea-479b-9a05-37089ff30ede}')
    @winrt_commethod(6)
    def get_IsReadOnlyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_AcceptsReturnProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_TextAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_TextWrappingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsSpellCheckEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsTextPredictionEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_InputScopeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AcceptsReturnProperty = property(get_AcceptsReturnProperty, None)
    InputScopeProperty = property(get_InputScopeProperty, None)
    IsReadOnlyProperty = property(get_IsReadOnlyProperty, None)
    IsSpellCheckEnabledProperty = property(get_IsSpellCheckEnabledProperty, None)
    IsTextPredictionEnabledProperty = property(get_IsTextPredictionEnabledProperty, None)
    TextAlignmentProperty = property(get_TextAlignmentProperty, None)
    TextWrappingProperty = property(get_TextWrappingProperty, None)
class IRichEditBoxStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBoxStatics2'
    _iid_ = Guid('{e3eb26de-2748-420b-b1fc-ce95b6e85eec}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PlaceholderTextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_SelectionHighlightColorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_PreventKeyboardDisplayOnProgrammaticFocusProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsColorFontEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    PreventKeyboardDisplayOnProgrammaticFocusProperty = property(get_PreventKeyboardDisplayOnProgrammaticFocusProperty, None)
    SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
class IRichEditBoxStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBoxStatics3'
    _iid_ = Guid('{6d17eec5-1fb3-4c8b-aa23-f5e15d6ab64e}')
    @winrt_commethod(6)
    def get_DesiredCandidateWindowAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TextReadingOrderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DesiredCandidateWindowAlignmentProperty = property(get_DesiredCandidateWindowAlignmentProperty, None)
    TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
class IRichEditBoxStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBoxStatics4'
    _iid_ = Guid('{f5d54fd7-7796-42a5-a5e5-2cd211ee8176}')
    @winrt_commethod(6)
    def get_ClipboardCopyFormatProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ClipboardCopyFormatProperty = property(get_ClipboardCopyFormatProperty, None)
class IRichEditBoxStatics5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBoxStatics5'
    _iid_ = Guid('{4b5c4568-43d5-43e6-bbb9-cb4e6250f45a}')
    @winrt_commethod(6)
    def get_SelectionHighlightColorWhenNotFocusedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_MaxLengthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    MaxLengthProperty = property(get_MaxLengthProperty, None)
    SelectionHighlightColorWhenNotFocusedProperty = property(get_SelectionHighlightColorWhenNotFocusedProperty, None)
class IRichEditBoxStatics6(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBoxStatics6'
    _iid_ = Guid('{fe40e287-82ed-4f7e-92ba-66f67bc1ff44}')
    @winrt_commethod(6)
    def get_HorizontalTextAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CharacterCasingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DisabledFormattingAcceleratorsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CharacterCasingProperty = property(get_CharacterCasingProperty, None)
    DisabledFormattingAcceleratorsProperty = property(get_DisabledFormattingAcceleratorsProperty, None)
    HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
class IRichEditBoxStatics7(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBoxStatics7'
    _iid_ = Guid('{59fa898f-f861-43da-a7ce-4b9c21d835f9}')
    @winrt_commethod(6)
    def get_ContentLinkForegroundColorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ContentLinkBackgroundColorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ContentLinkProvidersProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_HandwritingViewProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsHandwritingViewEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ContentLinkBackgroundColorProperty = property(get_ContentLinkBackgroundColorProperty, None)
    ContentLinkForegroundColorProperty = property(get_ContentLinkForegroundColorProperty, None)
    ContentLinkProvidersProperty = property(get_ContentLinkProvidersProperty, None)
    HandwritingViewProperty = property(get_HandwritingViewProperty, None)
    IsHandwritingViewEnabledProperty = property(get_IsHandwritingViewEnabledProperty, None)
class IRichEditBoxStatics8(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBoxStatics8'
    _iid_ = Guid('{58045172-106b-56a9-a8e4-4b74bf347d4e}')
    @winrt_commethod(6)
    def get_SelectionFlyoutProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ProofingMenuFlyoutProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DescriptionProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DescriptionProperty = property(get_DescriptionProperty, None)
    ProofingMenuFlyoutProperty = property(get_ProofingMenuFlyoutProperty, None)
    SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
class IRichEditBoxTextChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBoxTextChangingEventArgs'
    _iid_ = Guid('{54065018-2813-4922-9f8e-b6bbafd995d8}')
class IRichEditBoxTextChangingEventArgs2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichEditBoxTextChangingEventArgs2'
    _iid_ = Guid('{395b0db5-636e-413e-9eb4-fc22ebfa3628}')
    @winrt_commethod(6)
    def get_IsContentChanging(self) -> Boolean: ...
    IsContentChanging = property(get_IsContentChanging, None)
class IRichTextBlock(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlock'
    _iid_ = Guid('{e5fff9e2-b968-49e7-97d4-8cca2ac3ae7c}')
    @winrt_commethod(6)
    def get_FontSize(self) -> Double: ...
    @winrt_commethod(7)
    def put_FontSize(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_FontFamily(self) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(9)
    def put_FontFamily(self, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(10)
    def get_FontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(11)
    def put_FontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(12)
    def get_FontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(13)
    def put_FontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(14)
    def get_FontStretch(self) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_commethod(15)
    def put_FontStretch(self, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_commethod(16)
    def get_Foreground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(17)
    def put_Foreground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(18)
    def get_TextWrapping(self) -> win32more.Windows.UI.Xaml.TextWrapping: ...
    @winrt_commethod(19)
    def put_TextWrapping(self, value: win32more.Windows.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_commethod(20)
    def get_TextTrimming(self) -> win32more.Windows.UI.Xaml.TextTrimming: ...
    @winrt_commethod(21)
    def put_TextTrimming(self, value: win32more.Windows.UI.Xaml.TextTrimming) -> Void: ...
    @winrt_commethod(22)
    def get_TextAlignment(self) -> win32more.Windows.UI.Xaml.TextAlignment: ...
    @winrt_commethod(23)
    def put_TextAlignment(self, value: win32more.Windows.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(24)
    def get_Blocks(self) -> win32more.Windows.UI.Xaml.Documents.BlockCollection: ...
    @winrt_commethod(25)
    def get_Padding(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(26)
    def put_Padding(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(27)
    def get_LineHeight(self) -> Double: ...
    @winrt_commethod(28)
    def put_LineHeight(self, value: Double) -> Void: ...
    @winrt_commethod(29)
    def get_LineStackingStrategy(self) -> win32more.Windows.UI.Xaml.LineStackingStrategy: ...
    @winrt_commethod(30)
    def put_LineStackingStrategy(self, value: win32more.Windows.UI.Xaml.LineStackingStrategy) -> Void: ...
    @winrt_commethod(31)
    def get_CharacterSpacing(self) -> Int32: ...
    @winrt_commethod(32)
    def put_CharacterSpacing(self, value: Int32) -> Void: ...
    @winrt_commethod(33)
    def get_OverflowContentTarget(self) -> win32more.Windows.UI.Xaml.Controls.RichTextBlockOverflow: ...
    @winrt_commethod(34)
    def put_OverflowContentTarget(self, value: win32more.Windows.UI.Xaml.Controls.RichTextBlockOverflow) -> Void: ...
    @winrt_commethod(35)
    def get_IsTextSelectionEnabled(self) -> Boolean: ...
    @winrt_commethod(36)
    def put_IsTextSelectionEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(37)
    def get_HasOverflowContent(self) -> Boolean: ...
    @winrt_commethod(38)
    def get_SelectedText(self) -> WinRT_String: ...
    @winrt_commethod(39)
    def get_ContentStart(self) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(40)
    def get_ContentEnd(self) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(41)
    def get_SelectionStart(self) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(42)
    def get_SelectionEnd(self) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(43)
    def get_BaselineOffset(self) -> Double: ...
    @winrt_commethod(44)
    def add_SelectionChanged(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(45)
    def remove_SelectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(46)
    def add_ContextMenuOpening(self, handler: win32more.Windows.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(47)
    def remove_ContextMenuOpening(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(48)
    def SelectAll(self) -> Void: ...
    @winrt_commethod(49)
    def Select(self, start: win32more.Windows.UI.Xaml.Documents.TextPointer, end: win32more.Windows.UI.Xaml.Documents.TextPointer) -> Void: ...
    @winrt_commethod(50)
    def GetPositionFromPoint(self, point: win32more.Windows.Foundation.Point) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(51)
    def Focus(self, value: win32more.Windows.UI.Xaml.FocusState) -> Boolean: ...
    @winrt_commethod(52)
    def get_TextIndent(self) -> Double: ...
    @winrt_commethod(53)
    def put_TextIndent(self, value: Double) -> Void: ...
    BaselineOffset = property(get_BaselineOffset, None)
    Blocks = property(get_Blocks, None)
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    ContentEnd = property(get_ContentEnd, None)
    ContentStart = property(get_ContentStart, None)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
    HasOverflowContent = property(get_HasOverflowContent, None)
    IsTextSelectionEnabled = property(get_IsTextSelectionEnabled, put_IsTextSelectionEnabled)
    LineHeight = property(get_LineHeight, put_LineHeight)
    LineStackingStrategy = property(get_LineStackingStrategy, put_LineStackingStrategy)
    OverflowContentTarget = property(get_OverflowContentTarget, put_OverflowContentTarget)
    Padding = property(get_Padding, put_Padding)
    SelectedText = property(get_SelectedText, None)
    SelectionEnd = property(get_SelectionEnd, None)
    SelectionStart = property(get_SelectionStart, None)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
    TextIndent = property(get_TextIndent, put_TextIndent)
    TextTrimming = property(get_TextTrimming, put_TextTrimming)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    SelectionChanged = event()
    ContextMenuOpening = event()
class IRichTextBlock2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlock2'
    _iid_ = Guid('{3f209013-03e7-4508-964a-91aedab3d11e}')
    @winrt_commethod(6)
    def get_MaxLines(self) -> Int32: ...
    @winrt_commethod(7)
    def put_MaxLines(self, value: Int32) -> Void: ...
    @winrt_commethod(8)
    def get_TextLineBounds(self) -> win32more.Windows.UI.Xaml.TextLineBounds: ...
    @winrt_commethod(9)
    def put_TextLineBounds(self, value: win32more.Windows.UI.Xaml.TextLineBounds) -> Void: ...
    @winrt_commethod(10)
    def get_SelectionHighlightColor(self) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_commethod(11)
    def put_SelectionHighlightColor(self, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_commethod(12)
    def get_OpticalMarginAlignment(self) -> win32more.Windows.UI.Xaml.OpticalMarginAlignment: ...
    @winrt_commethod(13)
    def put_OpticalMarginAlignment(self, value: win32more.Windows.UI.Xaml.OpticalMarginAlignment) -> Void: ...
    @winrt_commethod(14)
    def get_IsColorFontEnabled(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsColorFontEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_TextReadingOrder(self) -> win32more.Windows.UI.Xaml.TextReadingOrder: ...
    @winrt_commethod(17)
    def put_TextReadingOrder(self, value: win32more.Windows.UI.Xaml.TextReadingOrder) -> Void: ...
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    MaxLines = property(get_MaxLines, put_MaxLines)
    OpticalMarginAlignment = property(get_OpticalMarginAlignment, put_OpticalMarginAlignment)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    TextLineBounds = property(get_TextLineBounds, put_TextLineBounds)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
class IRichTextBlock3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlock3'
    _iid_ = Guid('{7d39ae83-8918-4613-b007-7c898ba2950e}')
    @winrt_commethod(6)
    def get_IsTextScaleFactorEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsTextScaleFactorEnabled(self, value: Boolean) -> Void: ...
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
class IRichTextBlock4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlock4'
    _iid_ = Guid('{3577c1ea-24fd-4f50-bbe4-3fb654ea58c5}')
    @winrt_commethod(6)
    def get_TextDecorations(self) -> win32more.Windows.UI.Text.TextDecorations: ...
    @winrt_commethod(7)
    def put_TextDecorations(self, value: win32more.Windows.UI.Text.TextDecorations) -> Void: ...
    TextDecorations = property(get_TextDecorations, put_TextDecorations)
class IRichTextBlock5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlock5'
    _iid_ = Guid('{9c7dc0c6-7a9f-45b6-8818-822c549ba094}')
    @winrt_commethod(6)
    def get_IsTextTrimmed(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_HorizontalTextAlignment(self) -> win32more.Windows.UI.Xaml.TextAlignment: ...
    @winrt_commethod(8)
    def put_HorizontalTextAlignment(self, value: win32more.Windows.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(9)
    def get_TextHighlighters(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Documents.TextHighlighter]: ...
    @winrt_commethod(10)
    def add_IsTextTrimmedChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichTextBlock, win32more.Windows.UI.Xaml.Controls.IsTextTrimmedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_IsTextTrimmedChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    IsTextTrimmed = property(get_IsTextTrimmed, None)
    TextHighlighters = property(get_TextHighlighters, None)
    IsTextTrimmedChanged = event()
class IRichTextBlock6(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlock6'
    _iid_ = Guid('{ae9010cd-e899-526e-927e-88e0eed693c8}')
    @winrt_commethod(6)
    def get_SelectionFlyout(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(7)
    def put_SelectionFlyout(self, value: win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_commethod(8)
    def CopySelectionToClipboard(self) -> Void: ...
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
class IRichTextBlockOverflow(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlockOverflow'
    _iid_ = Guid('{4f93749b-dac3-4a42-9cbb-99f0de37c071}')
    @winrt_commethod(6)
    def get_OverflowContentTarget(self) -> win32more.Windows.UI.Xaml.Controls.RichTextBlockOverflow: ...
    @winrt_commethod(7)
    def put_OverflowContentTarget(self, value: win32more.Windows.UI.Xaml.Controls.RichTextBlockOverflow) -> Void: ...
    @winrt_commethod(8)
    def get_Padding(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(9)
    def put_Padding(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(10)
    def get_ContentSource(self) -> win32more.Windows.UI.Xaml.Controls.RichTextBlock: ...
    @winrt_commethod(11)
    def get_HasOverflowContent(self) -> Boolean: ...
    @winrt_commethod(12)
    def get_ContentStart(self) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(13)
    def get_ContentEnd(self) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(14)
    def get_BaselineOffset(self) -> Double: ...
    @winrt_commethod(15)
    def GetPositionFromPoint(self, point: win32more.Windows.Foundation.Point) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(16)
    def Focus(self, value: win32more.Windows.UI.Xaml.FocusState) -> Boolean: ...
    BaselineOffset = property(get_BaselineOffset, None)
    ContentEnd = property(get_ContentEnd, None)
    ContentSource = property(get_ContentSource, None)
    ContentStart = property(get_ContentStart, None)
    HasOverflowContent = property(get_HasOverflowContent, None)
    OverflowContentTarget = property(get_OverflowContentTarget, put_OverflowContentTarget)
    Padding = property(get_Padding, put_Padding)
class IRichTextBlockOverflow2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlockOverflow2'
    _iid_ = Guid('{8742624e-a882-4826-b929-4d5c3905b9a1}')
    @winrt_commethod(6)
    def get_MaxLines(self) -> Int32: ...
    @winrt_commethod(7)
    def put_MaxLines(self, value: Int32) -> Void: ...
    MaxLines = property(get_MaxLines, put_MaxLines)
class IRichTextBlockOverflow3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlockOverflow3'
    _iid_ = Guid('{7f69587b-5c7f-4b5f-bdbc-fb95c90e10de}')
    @winrt_commethod(6)
    def get_IsTextTrimmed(self) -> Boolean: ...
    @winrt_commethod(7)
    def add_IsTextTrimmedChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichTextBlockOverflow, win32more.Windows.UI.Xaml.Controls.IsTextTrimmedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_IsTextTrimmedChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    IsTextTrimmed = property(get_IsTextTrimmed, None)
    IsTextTrimmedChanged = event()
class IRichTextBlockOverflowStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlockOverflowStatics'
    _iid_ = Guid('{041ac2f7-4f2b-43c3-a122-3fea9ca9dc87}')
    @winrt_commethod(6)
    def get_OverflowContentTargetProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PaddingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_HasOverflowContentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HasOverflowContentProperty = property(get_HasOverflowContentProperty, None)
    OverflowContentTargetProperty = property(get_OverflowContentTargetProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
class IRichTextBlockOverflowStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlockOverflowStatics2'
    _iid_ = Guid('{b5ebed4c-f8c4-4a3a-907f-e53e78279fa3}')
    @winrt_commethod(6)
    def get_MaxLinesProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    MaxLinesProperty = property(get_MaxLinesProperty, None)
class IRichTextBlockOverflowStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlockOverflowStatics3'
    _iid_ = Guid('{d1d4a705-eb0b-4ecb-b9b7-e65d03087c8e}')
    @winrt_commethod(6)
    def get_IsTextTrimmedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsTextTrimmedProperty = property(get_IsTextTrimmedProperty, None)
class IRichTextBlockStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlockStatics'
    _iid_ = Guid('{492d883c-adea-433c-be1c-208a164262be}')
    @winrt_commethod(6)
    def get_FontSizeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_FontFamilyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_FontWeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_FontStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FontStretchProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_ForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_TextWrappingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_TextTrimmingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_TextAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_PaddingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_LineHeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_LineStackingStrategyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_CharacterSpacingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_OverflowContentTargetProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_IsTextSelectionEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_HasOverflowContentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_SelectedTextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_TextIndentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    FontFamilyProperty = property(get_FontFamilyProperty, None)
    FontSizeProperty = property(get_FontSizeProperty, None)
    FontStretchProperty = property(get_FontStretchProperty, None)
    FontStyleProperty = property(get_FontStyleProperty, None)
    FontWeightProperty = property(get_FontWeightProperty, None)
    ForegroundProperty = property(get_ForegroundProperty, None)
    HasOverflowContentProperty = property(get_HasOverflowContentProperty, None)
    IsTextSelectionEnabledProperty = property(get_IsTextSelectionEnabledProperty, None)
    LineHeightProperty = property(get_LineHeightProperty, None)
    LineStackingStrategyProperty = property(get_LineStackingStrategyProperty, None)
    OverflowContentTargetProperty = property(get_OverflowContentTargetProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
    SelectedTextProperty = property(get_SelectedTextProperty, None)
    TextAlignmentProperty = property(get_TextAlignmentProperty, None)
    TextIndentProperty = property(get_TextIndentProperty, None)
    TextTrimmingProperty = property(get_TextTrimmingProperty, None)
    TextWrappingProperty = property(get_TextWrappingProperty, None)
class IRichTextBlockStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlockStatics2'
    _iid_ = Guid('{0d6131e1-af29-48ce-8aaf-74ecc28bfbb0}')
    @winrt_commethod(6)
    def get_MaxLinesProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TextLineBoundsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_SelectionHighlightColorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_OpticalMarginAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsColorFontEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_TextReadingOrderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    MaxLinesProperty = property(get_MaxLinesProperty, None)
    OpticalMarginAlignmentProperty = property(get_OpticalMarginAlignmentProperty, None)
    SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    TextLineBoundsProperty = property(get_TextLineBoundsProperty, None)
    TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
class IRichTextBlockStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlockStatics3'
    _iid_ = Guid('{073f7ef4-ca2b-4b49-a59a-31d8fa743332}')
    @winrt_commethod(6)
    def get_IsTextScaleFactorEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
class IRichTextBlockStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlockStatics4'
    _iid_ = Guid('{80155bc4-6d96-4b08-ad57-13db0f046412}')
    @winrt_commethod(6)
    def get_TextDecorationsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    TextDecorationsProperty = property(get_TextDecorationsProperty, None)
class IRichTextBlockStatics5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlockStatics5'
    _iid_ = Guid('{ac9283a1-4f25-4280-8868-3eeee82821e8}')
    @winrt_commethod(6)
    def get_IsTextTrimmedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HorizontalTextAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
    IsTextTrimmedProperty = property(get_IsTextTrimmedProperty, None)
class IRichTextBlockStatics6(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRichTextBlockStatics6'
    _iid_ = Guid('{073057e7-91c5-5857-be7c-e72621239786}')
    @winrt_commethod(6)
    def get_SelectionFlyoutProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
class IRowDefinition(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRowDefinition'
    _iid_ = Guid('{4abae829-d80c-4a5e-a48c-f8b3d3b6533d}')
    @winrt_commethod(6)
    def get_Height(self) -> win32more.Windows.UI.Xaml.GridLength: ...
    @winrt_commethod(7)
    def put_Height(self, value: win32more.Windows.UI.Xaml.GridLength) -> Void: ...
    @winrt_commethod(8)
    def get_MaxHeight(self) -> Double: ...
    @winrt_commethod(9)
    def put_MaxHeight(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_MinHeight(self) -> Double: ...
    @winrt_commethod(11)
    def put_MinHeight(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_ActualHeight(self) -> Double: ...
    ActualHeight = property(get_ActualHeight, None)
    Height = property(get_Height, put_Height)
    MaxHeight = property(get_MaxHeight, put_MaxHeight)
    MinHeight = property(get_MinHeight, put_MinHeight)
class IRowDefinitionStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IRowDefinitionStatics'
    _iid_ = Guid('{5adf3fe5-2056-4724-94d6-e4812b022ec8}')
    @winrt_commethod(6)
    def get_HeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_MaxHeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_MinHeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HeightProperty = property(get_HeightProperty, None)
    MaxHeightProperty = property(get_MaxHeightProperty, None)
    MinHeightProperty = property(get_MinHeightProperty, None)
class IScrollAnchorProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IScrollAnchorProvider'
    _iid_ = Guid('{6ae99a0f-478c-5440-b2c6-ead4378ef8e4}')
    @winrt_commethod(6)
    def get_CurrentAnchor(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def RegisterAnchorCandidate(self, element: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def UnregisterAnchorCandidate(self, element: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    CurrentAnchor = property(get_CurrentAnchor, None)
class IScrollContentPresenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IScrollContentPresenter'
    _iid_ = Guid('{5712ee2b-0eeb-46d3-aa31-5f6801b8de20}')
    @winrt_commethod(6)
    def get_CanVerticallyScroll(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_CanVerticallyScroll(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_CanHorizontallyScroll(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_CanHorizontallyScroll(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_ExtentWidth(self) -> Double: ...
    @winrt_commethod(11)
    def get_ExtentHeight(self) -> Double: ...
    @winrt_commethod(12)
    def get_ViewportWidth(self) -> Double: ...
    @winrt_commethod(13)
    def get_ViewportHeight(self) -> Double: ...
    @winrt_commethod(14)
    def get_HorizontalOffset(self) -> Double: ...
    @winrt_commethod(15)
    def get_VerticalOffset(self) -> Double: ...
    @winrt_commethod(16)
    def get_ScrollOwner(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(17)
    def put_ScrollOwner(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(18)
    def LineUp(self) -> Void: ...
    @winrt_commethod(19)
    def LineDown(self) -> Void: ...
    @winrt_commethod(20)
    def LineLeft(self) -> Void: ...
    @winrt_commethod(21)
    def LineRight(self) -> Void: ...
    @winrt_commethod(22)
    def PageUp(self) -> Void: ...
    @winrt_commethod(23)
    def PageDown(self) -> Void: ...
    @winrt_commethod(24)
    def PageLeft(self) -> Void: ...
    @winrt_commethod(25)
    def PageRight(self) -> Void: ...
    @winrt_commethod(26)
    def MouseWheelUp(self) -> Void: ...
    @winrt_commethod(27)
    def MouseWheelDown(self) -> Void: ...
    @winrt_commethod(28)
    def MouseWheelLeft(self) -> Void: ...
    @winrt_commethod(29)
    def MouseWheelRight(self) -> Void: ...
    @winrt_commethod(30)
    def SetHorizontalOffset(self, offset: Double) -> Void: ...
    @winrt_commethod(31)
    def SetVerticalOffset(self, offset: Double) -> Void: ...
    @winrt_commethod(32)
    def MakeVisible(self, visual: win32more.Windows.UI.Xaml.UIElement, rectangle: win32more.Windows.Foundation.Rect) -> win32more.Windows.Foundation.Rect: ...
    CanHorizontallyScroll = property(get_CanHorizontallyScroll, put_CanHorizontallyScroll)
    CanVerticallyScroll = property(get_CanVerticallyScroll, put_CanVerticallyScroll)
    ExtentHeight = property(get_ExtentHeight, None)
    ExtentWidth = property(get_ExtentWidth, None)
    HorizontalOffset = property(get_HorizontalOffset, None)
    ScrollOwner = property(get_ScrollOwner, put_ScrollOwner)
    VerticalOffset = property(get_VerticalOffset, None)
    ViewportHeight = property(get_ViewportHeight, None)
    ViewportWidth = property(get_ViewportWidth, None)
class IScrollContentPresenter2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IScrollContentPresenter2'
    _iid_ = Guid('{5f9f2737-2318-5999-8a62-c3ed3c0e98b6}')
    @winrt_commethod(6)
    def get_CanContentRenderOutsideBounds(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_CanContentRenderOutsideBounds(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_SizesContentToTemplatedParent(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_SizesContentToTemplatedParent(self, value: Boolean) -> Void: ...
    CanContentRenderOutsideBounds = property(get_CanContentRenderOutsideBounds, put_CanContentRenderOutsideBounds)
    SizesContentToTemplatedParent = property(get_SizesContentToTemplatedParent, put_SizesContentToTemplatedParent)
class IScrollContentPresenterStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IScrollContentPresenterStatics2'
    _iid_ = Guid('{e172ff1a-c676-524b-8f20-96152149d05e}')
    @winrt_commethod(6)
    def get_CanContentRenderOutsideBoundsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_SizesContentToTemplatedParentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CanContentRenderOutsideBoundsProperty = property(get_CanContentRenderOutsideBoundsProperty, None)
    SizesContentToTemplatedParentProperty = property(get_SizesContentToTemplatedParentProperty, None)
class IScrollViewer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IScrollViewer'
    _iid_ = Guid('{64e9be00-4dc1-493d-abe7-cbd3c577490d}')
    @winrt_commethod(6)
    def get_HorizontalScrollBarVisibility(self) -> win32more.Windows.UI.Xaml.Controls.ScrollBarVisibility: ...
    @winrt_commethod(7)
    def put_HorizontalScrollBarVisibility(self, value: win32more.Windows.UI.Xaml.Controls.ScrollBarVisibility) -> Void: ...
    @winrt_commethod(8)
    def get_VerticalScrollBarVisibility(self) -> win32more.Windows.UI.Xaml.Controls.ScrollBarVisibility: ...
    @winrt_commethod(9)
    def put_VerticalScrollBarVisibility(self, value: win32more.Windows.UI.Xaml.Controls.ScrollBarVisibility) -> Void: ...
    @winrt_commethod(10)
    def get_IsHorizontalRailEnabled(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsHorizontalRailEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_IsVerticalRailEnabled(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsVerticalRailEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_IsHorizontalScrollChainingEnabled(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsHorizontalScrollChainingEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_IsVerticalScrollChainingEnabled(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsVerticalScrollChainingEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_IsZoomChainingEnabled(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_IsZoomChainingEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_IsScrollInertiaEnabled(self) -> Boolean: ...
    @winrt_commethod(21)
    def put_IsScrollInertiaEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(22)
    def get_IsZoomInertiaEnabled(self) -> Boolean: ...
    @winrt_commethod(23)
    def put_IsZoomInertiaEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(24)
    def get_HorizontalScrollMode(self) -> win32more.Windows.UI.Xaml.Controls.ScrollMode: ...
    @winrt_commethod(25)
    def put_HorizontalScrollMode(self, value: win32more.Windows.UI.Xaml.Controls.ScrollMode) -> Void: ...
    @winrt_commethod(26)
    def get_VerticalScrollMode(self) -> win32more.Windows.UI.Xaml.Controls.ScrollMode: ...
    @winrt_commethod(27)
    def put_VerticalScrollMode(self, value: win32more.Windows.UI.Xaml.Controls.ScrollMode) -> Void: ...
    @winrt_commethod(28)
    def get_ZoomMode(self) -> win32more.Windows.UI.Xaml.Controls.ZoomMode: ...
    @winrt_commethod(29)
    def put_ZoomMode(self, value: win32more.Windows.UI.Xaml.Controls.ZoomMode) -> Void: ...
    @winrt_commethod(30)
    def get_HorizontalSnapPointsAlignment(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.SnapPointsAlignment: ...
    @winrt_commethod(31)
    def put_HorizontalSnapPointsAlignment(self, value: win32more.Windows.UI.Xaml.Controls.Primitives.SnapPointsAlignment) -> Void: ...
    @winrt_commethod(32)
    def get_VerticalSnapPointsAlignment(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.SnapPointsAlignment: ...
    @winrt_commethod(33)
    def put_VerticalSnapPointsAlignment(self, value: win32more.Windows.UI.Xaml.Controls.Primitives.SnapPointsAlignment) -> Void: ...
    @winrt_commethod(34)
    def get_HorizontalSnapPointsType(self) -> win32more.Windows.UI.Xaml.Controls.SnapPointsType: ...
    @winrt_commethod(35)
    def put_HorizontalSnapPointsType(self, value: win32more.Windows.UI.Xaml.Controls.SnapPointsType) -> Void: ...
    @winrt_commethod(36)
    def get_VerticalSnapPointsType(self) -> win32more.Windows.UI.Xaml.Controls.SnapPointsType: ...
    @winrt_commethod(37)
    def put_VerticalSnapPointsType(self, value: win32more.Windows.UI.Xaml.Controls.SnapPointsType) -> Void: ...
    @winrt_commethod(38)
    def get_ZoomSnapPointsType(self) -> win32more.Windows.UI.Xaml.Controls.SnapPointsType: ...
    @winrt_commethod(39)
    def put_ZoomSnapPointsType(self, value: win32more.Windows.UI.Xaml.Controls.SnapPointsType) -> Void: ...
    @winrt_commethod(40)
    def get_HorizontalOffset(self) -> Double: ...
    @winrt_commethod(41)
    def get_ViewportWidth(self) -> Double: ...
    @winrt_commethod(42)
    def get_ScrollableWidth(self) -> Double: ...
    @winrt_commethod(43)
    def get_ComputedHorizontalScrollBarVisibility(self) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_commethod(44)
    def get_ExtentWidth(self) -> Double: ...
    @winrt_commethod(45)
    def get_VerticalOffset(self) -> Double: ...
    @winrt_commethod(46)
    def get_ViewportHeight(self) -> Double: ...
    @winrt_commethod(47)
    def get_ScrollableHeight(self) -> Double: ...
    @winrt_commethod(48)
    def get_ComputedVerticalScrollBarVisibility(self) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_commethod(49)
    def get_ExtentHeight(self) -> Double: ...
    @winrt_commethod(50)
    def get_MinZoomFactor(self) -> Single: ...
    @winrt_commethod(51)
    def put_MinZoomFactor(self, value: Single) -> Void: ...
    @winrt_commethod(52)
    def get_MaxZoomFactor(self) -> Single: ...
    @winrt_commethod(53)
    def put_MaxZoomFactor(self, value: Single) -> Void: ...
    @winrt_commethod(54)
    def get_ZoomFactor(self) -> Single: ...
    @winrt_commethod(55)
    def get_ZoomSnapPoints(self) -> win32more.Windows.Foundation.Collections.IVector[Single]: ...
    @winrt_commethod(56)
    def add_ViewChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.UI.Xaml.Controls.ScrollViewerViewChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(57)
    def remove_ViewChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(58)
    def ScrollToHorizontalOffset(self, offset: Double) -> Void: ...
    @winrt_commethod(59)
    def ScrollToVerticalOffset(self, offset: Double) -> Void: ...
    @winrt_commethod(60)
    def ZoomToFactor(self, factor: Single) -> Void: ...
    @winrt_commethod(61)
    def InvalidateScrollInfo(self) -> Void: ...
    @winrt_commethod(62)
    def get_IsDeferredScrollingEnabled(self) -> Boolean: ...
    @winrt_commethod(63)
    def put_IsDeferredScrollingEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(64)
    def get_BringIntoViewOnFocusChange(self) -> Boolean: ...
    @winrt_commethod(65)
    def put_BringIntoViewOnFocusChange(self, value: Boolean) -> Void: ...
    BringIntoViewOnFocusChange = property(get_BringIntoViewOnFocusChange, put_BringIntoViewOnFocusChange)
    ComputedHorizontalScrollBarVisibility = property(get_ComputedHorizontalScrollBarVisibility, None)
    ComputedVerticalScrollBarVisibility = property(get_ComputedVerticalScrollBarVisibility, None)
    ExtentHeight = property(get_ExtentHeight, None)
    ExtentWidth = property(get_ExtentWidth, None)
    HorizontalOffset = property(get_HorizontalOffset, None)
    HorizontalScrollBarVisibility = property(get_HorizontalScrollBarVisibility, put_HorizontalScrollBarVisibility)
    HorizontalScrollMode = property(get_HorizontalScrollMode, put_HorizontalScrollMode)
    HorizontalSnapPointsAlignment = property(get_HorizontalSnapPointsAlignment, put_HorizontalSnapPointsAlignment)
    HorizontalSnapPointsType = property(get_HorizontalSnapPointsType, put_HorizontalSnapPointsType)
    IsDeferredScrollingEnabled = property(get_IsDeferredScrollingEnabled, put_IsDeferredScrollingEnabled)
    IsHorizontalRailEnabled = property(get_IsHorizontalRailEnabled, put_IsHorizontalRailEnabled)
    IsHorizontalScrollChainingEnabled = property(get_IsHorizontalScrollChainingEnabled, put_IsHorizontalScrollChainingEnabled)
    IsScrollInertiaEnabled = property(get_IsScrollInertiaEnabled, put_IsScrollInertiaEnabled)
    IsVerticalRailEnabled = property(get_IsVerticalRailEnabled, put_IsVerticalRailEnabled)
    IsVerticalScrollChainingEnabled = property(get_IsVerticalScrollChainingEnabled, put_IsVerticalScrollChainingEnabled)
    IsZoomChainingEnabled = property(get_IsZoomChainingEnabled, put_IsZoomChainingEnabled)
    IsZoomInertiaEnabled = property(get_IsZoomInertiaEnabled, put_IsZoomInertiaEnabled)
    MaxZoomFactor = property(get_MaxZoomFactor, put_MaxZoomFactor)
    MinZoomFactor = property(get_MinZoomFactor, put_MinZoomFactor)
    ScrollableHeight = property(get_ScrollableHeight, None)
    ScrollableWidth = property(get_ScrollableWidth, None)
    VerticalOffset = property(get_VerticalOffset, None)
    VerticalScrollBarVisibility = property(get_VerticalScrollBarVisibility, put_VerticalScrollBarVisibility)
    VerticalScrollMode = property(get_VerticalScrollMode, put_VerticalScrollMode)
    VerticalSnapPointsAlignment = property(get_VerticalSnapPointsAlignment, put_VerticalSnapPointsAlignment)
    VerticalSnapPointsType = property(get_VerticalSnapPointsType, put_VerticalSnapPointsType)
    ViewportHeight = property(get_ViewportHeight, None)
    ViewportWidth = property(get_ViewportWidth, None)
    ZoomFactor = property(get_ZoomFactor, None)
    ZoomMode = property(get_ZoomMode, put_ZoomMode)
    ZoomSnapPoints = property(get_ZoomSnapPoints, None)
    ZoomSnapPointsType = property(get_ZoomSnapPointsType, put_ZoomSnapPointsType)
    ViewChanged = event()
class IScrollViewer2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IScrollViewer2'
    _iid_ = Guid('{64e9be10-4dd1-494d-abf7-cbd3c577491d}')
    @winrt_commethod(6)
    def get_TopLeftHeader(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_TopLeftHeader(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_LeftHeader(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(9)
    def put_LeftHeader(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(10)
    def get_TopHeader(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(11)
    def put_TopHeader(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(12)
    def add_ViewChanging(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.UI.Xaml.Controls.ScrollViewerViewChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_ViewChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def ChangeView(self, horizontalOffset: win32more.Windows.Foundation.IReference[Double], verticalOffset: win32more.Windows.Foundation.IReference[Double], zoomFactor: win32more.Windows.Foundation.IReference[Single]) -> Boolean: ...
    @winrt_commethod(15)
    def ChangeViewWithOptionalAnimation(self, horizontalOffset: win32more.Windows.Foundation.IReference[Double], verticalOffset: win32more.Windows.Foundation.IReference[Double], zoomFactor: win32more.Windows.Foundation.IReference[Single], disableAnimation: Boolean) -> Boolean: ...
    LeftHeader = property(get_LeftHeader, put_LeftHeader)
    TopHeader = property(get_TopHeader, put_TopHeader)
    TopLeftHeader = property(get_TopLeftHeader, put_TopLeftHeader)
    ViewChanging = event()
class IScrollViewer3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IScrollViewer3'
    _iid_ = Guid('{74e9be21-5de2-595e-bc08-dbd3c577492c}')
    @winrt_commethod(6)
    def add_DirectManipulationStarted(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_DirectManipulationStarted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_DirectManipulationCompleted(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_DirectManipulationCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    DirectManipulationStarted = event()
    DirectManipulationCompleted = event()
class IScrollViewer4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IScrollViewer4'
    _iid_ = Guid('{786fb0c4-50a9-5a45-8a92-7bf372e19098}')
    @winrt_commethod(6)
    def get_ReduceViewportForCoreInputViewOcclusions(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_ReduceViewportForCoreInputViewOcclusions(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_HorizontalAnchorRatio(self) -> Double: ...
    @winrt_commethod(9)
    def put_HorizontalAnchorRatio(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_VerticalAnchorRatio(self) -> Double: ...
    @winrt_commethod(11)
    def put_VerticalAnchorRatio(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_CanContentRenderOutsideBounds(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_CanContentRenderOutsideBounds(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def add_AnchorRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ScrollViewer, win32more.Windows.UI.Xaml.Controls.AnchorRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_AnchorRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CanContentRenderOutsideBounds = property(get_CanContentRenderOutsideBounds, put_CanContentRenderOutsideBounds)
    HorizontalAnchorRatio = property(get_HorizontalAnchorRatio, put_HorizontalAnchorRatio)
    ReduceViewportForCoreInputViewOcclusions = property(get_ReduceViewportForCoreInputViewOcclusions, put_ReduceViewportForCoreInputViewOcclusions)
    VerticalAnchorRatio = property(get_VerticalAnchorRatio, put_VerticalAnchorRatio)
    AnchorRequested = event()
class IScrollViewerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IScrollViewerStatics'
    _iid_ = Guid('{33d1299d-8d6e-4290-bf22-905cccd04d31}')
    @winrt_commethod(6)
    def get_HorizontalSnapPointsAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_VerticalSnapPointsAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_HorizontalSnapPointsTypeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_VerticalSnapPointsTypeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_ZoomSnapPointsTypeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_HorizontalOffsetProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ViewportWidthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_ScrollableWidthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_ComputedHorizontalScrollBarVisibilityProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_ExtentWidthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_VerticalOffsetProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_ViewportHeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_ScrollableHeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_ComputedVerticalScrollBarVisibilityProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_ExtentHeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_MinZoomFactorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_MaxZoomFactorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_ZoomFactorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_ZoomSnapPointsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_HorizontalScrollBarVisibilityProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def GetHorizontalScrollBarVisibility(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.ScrollBarVisibility: ...
    @winrt_commethod(27)
    def SetHorizontalScrollBarVisibility(self, element: win32more.Windows.UI.Xaml.DependencyObject, horizontalScrollBarVisibility: win32more.Windows.UI.Xaml.Controls.ScrollBarVisibility) -> Void: ...
    @winrt_commethod(28)
    def get_VerticalScrollBarVisibilityProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(29)
    def GetVerticalScrollBarVisibility(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.ScrollBarVisibility: ...
    @winrt_commethod(30)
    def SetVerticalScrollBarVisibility(self, element: win32more.Windows.UI.Xaml.DependencyObject, verticalScrollBarVisibility: win32more.Windows.UI.Xaml.Controls.ScrollBarVisibility) -> Void: ...
    @winrt_commethod(31)
    def get_IsHorizontalRailEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(32)
    def GetIsHorizontalRailEnabled(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(33)
    def SetIsHorizontalRailEnabled(self, element: win32more.Windows.UI.Xaml.DependencyObject, isHorizontalRailEnabled: Boolean) -> Void: ...
    @winrt_commethod(34)
    def get_IsVerticalRailEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(35)
    def GetIsVerticalRailEnabled(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(36)
    def SetIsVerticalRailEnabled(self, element: win32more.Windows.UI.Xaml.DependencyObject, isVerticalRailEnabled: Boolean) -> Void: ...
    @winrt_commethod(37)
    def get_IsHorizontalScrollChainingEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(38)
    def GetIsHorizontalScrollChainingEnabled(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(39)
    def SetIsHorizontalScrollChainingEnabled(self, element: win32more.Windows.UI.Xaml.DependencyObject, isHorizontalScrollChainingEnabled: Boolean) -> Void: ...
    @winrt_commethod(40)
    def get_IsVerticalScrollChainingEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(41)
    def GetIsVerticalScrollChainingEnabled(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(42)
    def SetIsVerticalScrollChainingEnabled(self, element: win32more.Windows.UI.Xaml.DependencyObject, isVerticalScrollChainingEnabled: Boolean) -> Void: ...
    @winrt_commethod(43)
    def get_IsZoomChainingEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(44)
    def GetIsZoomChainingEnabled(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(45)
    def SetIsZoomChainingEnabled(self, element: win32more.Windows.UI.Xaml.DependencyObject, isZoomChainingEnabled: Boolean) -> Void: ...
    @winrt_commethod(46)
    def get_IsScrollInertiaEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(47)
    def GetIsScrollInertiaEnabled(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(48)
    def SetIsScrollInertiaEnabled(self, element: win32more.Windows.UI.Xaml.DependencyObject, isScrollInertiaEnabled: Boolean) -> Void: ...
    @winrt_commethod(49)
    def get_IsZoomInertiaEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(50)
    def GetIsZoomInertiaEnabled(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(51)
    def SetIsZoomInertiaEnabled(self, element: win32more.Windows.UI.Xaml.DependencyObject, isZoomInertiaEnabled: Boolean) -> Void: ...
    @winrt_commethod(52)
    def get_HorizontalScrollModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(53)
    def GetHorizontalScrollMode(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.ScrollMode: ...
    @winrt_commethod(54)
    def SetHorizontalScrollMode(self, element: win32more.Windows.UI.Xaml.DependencyObject, horizontalScrollMode: win32more.Windows.UI.Xaml.Controls.ScrollMode) -> Void: ...
    @winrt_commethod(55)
    def get_VerticalScrollModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(56)
    def GetVerticalScrollMode(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.ScrollMode: ...
    @winrt_commethod(57)
    def SetVerticalScrollMode(self, element: win32more.Windows.UI.Xaml.DependencyObject, verticalScrollMode: win32more.Windows.UI.Xaml.Controls.ScrollMode) -> Void: ...
    @winrt_commethod(58)
    def get_ZoomModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(59)
    def GetZoomMode(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.ZoomMode: ...
    @winrt_commethod(60)
    def SetZoomMode(self, element: win32more.Windows.UI.Xaml.DependencyObject, zoomMode: win32more.Windows.UI.Xaml.Controls.ZoomMode) -> Void: ...
    @winrt_commethod(61)
    def get_IsDeferredScrollingEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(62)
    def GetIsDeferredScrollingEnabled(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(63)
    def SetIsDeferredScrollingEnabled(self, element: win32more.Windows.UI.Xaml.DependencyObject, isDeferredScrollingEnabled: Boolean) -> Void: ...
    @winrt_commethod(64)
    def get_BringIntoViewOnFocusChangeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(65)
    def GetBringIntoViewOnFocusChange(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(66)
    def SetBringIntoViewOnFocusChange(self, element: win32more.Windows.UI.Xaml.DependencyObject, bringIntoViewOnFocusChange: Boolean) -> Void: ...
    BringIntoViewOnFocusChangeProperty = property(get_BringIntoViewOnFocusChangeProperty, None)
    ComputedHorizontalScrollBarVisibilityProperty = property(get_ComputedHorizontalScrollBarVisibilityProperty, None)
    ComputedVerticalScrollBarVisibilityProperty = property(get_ComputedVerticalScrollBarVisibilityProperty, None)
    ExtentHeightProperty = property(get_ExtentHeightProperty, None)
    ExtentWidthProperty = property(get_ExtentWidthProperty, None)
    HorizontalOffsetProperty = property(get_HorizontalOffsetProperty, None)
    HorizontalScrollBarVisibilityProperty = property(get_HorizontalScrollBarVisibilityProperty, None)
    HorizontalScrollModeProperty = property(get_HorizontalScrollModeProperty, None)
    HorizontalSnapPointsAlignmentProperty = property(get_HorizontalSnapPointsAlignmentProperty, None)
    HorizontalSnapPointsTypeProperty = property(get_HorizontalSnapPointsTypeProperty, None)
    IsDeferredScrollingEnabledProperty = property(get_IsDeferredScrollingEnabledProperty, None)
    IsHorizontalRailEnabledProperty = property(get_IsHorizontalRailEnabledProperty, None)
    IsHorizontalScrollChainingEnabledProperty = property(get_IsHorizontalScrollChainingEnabledProperty, None)
    IsScrollInertiaEnabledProperty = property(get_IsScrollInertiaEnabledProperty, None)
    IsVerticalRailEnabledProperty = property(get_IsVerticalRailEnabledProperty, None)
    IsVerticalScrollChainingEnabledProperty = property(get_IsVerticalScrollChainingEnabledProperty, None)
    IsZoomChainingEnabledProperty = property(get_IsZoomChainingEnabledProperty, None)
    IsZoomInertiaEnabledProperty = property(get_IsZoomInertiaEnabledProperty, None)
    MaxZoomFactorProperty = property(get_MaxZoomFactorProperty, None)
    MinZoomFactorProperty = property(get_MinZoomFactorProperty, None)
    ScrollableHeightProperty = property(get_ScrollableHeightProperty, None)
    ScrollableWidthProperty = property(get_ScrollableWidthProperty, None)
    VerticalOffsetProperty = property(get_VerticalOffsetProperty, None)
    VerticalScrollBarVisibilityProperty = property(get_VerticalScrollBarVisibilityProperty, None)
    VerticalScrollModeProperty = property(get_VerticalScrollModeProperty, None)
    VerticalSnapPointsAlignmentProperty = property(get_VerticalSnapPointsAlignmentProperty, None)
    VerticalSnapPointsTypeProperty = property(get_VerticalSnapPointsTypeProperty, None)
    ViewportHeightProperty = property(get_ViewportHeightProperty, None)
    ViewportWidthProperty = property(get_ViewportWidthProperty, None)
    ZoomFactorProperty = property(get_ZoomFactorProperty, None)
    ZoomModeProperty = property(get_ZoomModeProperty, None)
    ZoomSnapPointsProperty = property(get_ZoomSnapPointsProperty, None)
    ZoomSnapPointsTypeProperty = property(get_ZoomSnapPointsTypeProperty, None)
class IScrollViewerStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IScrollViewerStatics2'
    _iid_ = Guid('{33d129ad-8d7e-42a0-bf32-905cccd04d41}')
    @winrt_commethod(6)
    def get_TopLeftHeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_LeftHeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_TopHeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    LeftHeaderProperty = property(get_LeftHeaderProperty, None)
    TopHeaderProperty = property(get_TopHeaderProperty, None)
    TopLeftHeaderProperty = property(get_TopLeftHeaderProperty, None)
class IScrollViewerStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IScrollViewerStatics4'
    _iid_ = Guid('{220cf7cc-4f46-59f1-af9b-67fa8eb33d01}')
    @winrt_commethod(6)
    def get_ReduceViewportForCoreInputViewOcclusionsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HorizontalAnchorRatioProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_VerticalAnchorRatioProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_CanContentRenderOutsideBoundsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def GetCanContentRenderOutsideBounds(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(11)
    def SetCanContentRenderOutsideBounds(self, element: win32more.Windows.UI.Xaml.DependencyObject, canContentRenderOutsideBounds: Boolean) -> Void: ...
    CanContentRenderOutsideBoundsProperty = property(get_CanContentRenderOutsideBoundsProperty, None)
    HorizontalAnchorRatioProperty = property(get_HorizontalAnchorRatioProperty, None)
    ReduceViewportForCoreInputViewOcclusionsProperty = property(get_ReduceViewportForCoreInputViewOcclusionsProperty, None)
    VerticalAnchorRatioProperty = property(get_VerticalAnchorRatioProperty, None)
class IScrollViewerView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IScrollViewerView'
    _iid_ = Guid('{64e9be01-4dc2-493e-abe8-cbd3c577490e}')
    @winrt_commethod(6)
    def get_HorizontalOffset(self) -> Double: ...
    @winrt_commethod(7)
    def get_VerticalOffset(self) -> Double: ...
    @winrt_commethod(8)
    def get_ZoomFactor(self) -> Single: ...
    HorizontalOffset = property(get_HorizontalOffset, None)
    VerticalOffset = property(get_VerticalOffset, None)
    ZoomFactor = property(get_ZoomFactor, None)
class IScrollViewerViewChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IScrollViewerViewChangedEventArgs'
    _iid_ = Guid('{4dd04f7e-7a11-4b2e-9933-577df39252b6}')
    @winrt_commethod(6)
    def get_IsIntermediate(self) -> Boolean: ...
    IsIntermediate = property(get_IsIntermediate, None)
class IScrollViewerViewChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IScrollViewerViewChangingEventArgs'
    _iid_ = Guid('{4dd04f7f-7a11-4b2e-9933-577df39252b6}')
    @winrt_commethod(6)
    def get_NextView(self) -> win32more.Windows.UI.Xaml.Controls.ScrollViewerView: ...
    @winrt_commethod(7)
    def get_FinalView(self) -> win32more.Windows.UI.Xaml.Controls.ScrollViewerView: ...
    @winrt_commethod(8)
    def get_IsInertial(self) -> Boolean: ...
    FinalView = property(get_FinalView, None)
    IsInertial = property(get_IsInertial, None)
    NextView = property(get_NextView, None)
class ISearchBox(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISearchBox'
    _iid_ = Guid('{f89ecc5a-99ba-4bd4-966c-f11fa443d13c}')
    @winrt_commethod(6)
    def get_SearchHistoryEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_SearchHistoryEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_SearchHistoryContext(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_SearchHistoryContext(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_PlaceholderText(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_PlaceholderText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_QueryText(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_QueryText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_FocusOnKeyboardInput(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_FocusOnKeyboardInput(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_ChooseSuggestionOnEnter(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_ChooseSuggestionOnEnter(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def add_QueryChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SearchBox, win32more.Windows.UI.Xaml.Controls.SearchBoxQueryChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_QueryChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(20)
    def add_SuggestionsRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SearchBox, win32more.Windows.UI.Xaml.Controls.SearchBoxSuggestionsRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_SuggestionsRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(22)
    def add_QuerySubmitted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SearchBox, win32more.Windows.UI.Xaml.Controls.SearchBoxQuerySubmittedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(23)
    def remove_QuerySubmitted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(24)
    def add_ResultSuggestionChosen(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SearchBox, win32more.Windows.UI.Xaml.Controls.SearchBoxResultSuggestionChosenEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(25)
    def remove_ResultSuggestionChosen(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(26)
    def add_PrepareForFocusOnKeyboardInput(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SearchBox, win32more.Windows.UI.Xaml.RoutedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(27)
    def remove_PrepareForFocusOnKeyboardInput(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(28)
    def SetLocalContentSuggestionSettings(self, settings: win32more.Windows.ApplicationModel.Search.LocalContentSuggestionSettings) -> Void: ...
    ChooseSuggestionOnEnter = property(get_ChooseSuggestionOnEnter, put_ChooseSuggestionOnEnter)
    FocusOnKeyboardInput = property(get_FocusOnKeyboardInput, put_FocusOnKeyboardInput)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    QueryText = property(get_QueryText, put_QueryText)
    SearchHistoryContext = property(get_SearchHistoryContext, put_SearchHistoryContext)
    SearchHistoryEnabled = property(get_SearchHistoryEnabled, put_SearchHistoryEnabled)
    QueryChanged = event()
    SuggestionsRequested = event()
    QuerySubmitted = event()
    ResultSuggestionChosen = event()
    PrepareForFocusOnKeyboardInput = event()
class ISearchBoxFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISearchBoxFactory'
    _iid_ = Guid('{cd743f6d-8685-46b4-9ddd-202f6941b701}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SearchBox: ...
class ISearchBoxQueryChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISearchBoxQueryChangedEventArgs'
    _iid_ = Guid('{a9a70f8f-0cb0-4bd2-9998-2fb57ad5e731}')
    @winrt_commethod(6)
    def get_QueryText(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Language(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_LinguisticDetails(self) -> win32more.Windows.ApplicationModel.Search.SearchQueryLinguisticDetails: ...
    Language = property(get_Language, None)
    LinguisticDetails = property(get_LinguisticDetails, None)
    QueryText = property(get_QueryText, None)
class ISearchBoxQuerySubmittedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISearchBoxQuerySubmittedEventArgs'
    _iid_ = Guid('{126e90fd-3c4e-4ccb-9aef-4705d19fe548}')
    @winrt_commethod(6)
    def get_QueryText(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Language(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_LinguisticDetails(self) -> win32more.Windows.ApplicationModel.Search.SearchQueryLinguisticDetails: ...
    @winrt_commethod(9)
    def get_KeyModifiers(self) -> win32more.Windows.System.VirtualKeyModifiers: ...
    KeyModifiers = property(get_KeyModifiers, None)
    Language = property(get_Language, None)
    LinguisticDetails = property(get_LinguisticDetails, None)
    QueryText = property(get_QueryText, None)
class ISearchBoxResultSuggestionChosenEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISearchBoxResultSuggestionChosenEventArgs'
    _iid_ = Guid('{18918c23-e4c3-4662-a03b-d054ffd0f905}')
    @winrt_commethod(6)
    def get_Tag(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_KeyModifiers(self) -> win32more.Windows.System.VirtualKeyModifiers: ...
    KeyModifiers = property(get_KeyModifiers, None)
    Tag = property(get_Tag, None)
class ISearchBoxStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISearchBoxStatics'
    _iid_ = Guid('{b123634f-6871-48cd-92df-4cff22459082}')
    @winrt_commethod(6)
    def get_SearchHistoryEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_SearchHistoryContextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PlaceholderTextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_QueryTextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FocusOnKeyboardInputProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_ChooseSuggestionOnEnterProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ChooseSuggestionOnEnterProperty = property(get_ChooseSuggestionOnEnterProperty, None)
    FocusOnKeyboardInputProperty = property(get_FocusOnKeyboardInputProperty, None)
    PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    QueryTextProperty = property(get_QueryTextProperty, None)
    SearchHistoryContextProperty = property(get_SearchHistoryContextProperty, None)
    SearchHistoryEnabledProperty = property(get_SearchHistoryEnabledProperty, None)
class ISearchBoxSuggestionsRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISearchBoxSuggestionsRequestedEventArgs'
    _iid_ = Guid('{da15170e-e566-48cb-bd11-fe4b0f30a44d}')
    @winrt_commethod(6)
    def get_QueryText(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Language(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_LinguisticDetails(self) -> win32more.Windows.ApplicationModel.Search.SearchQueryLinguisticDetails: ...
    @winrt_commethod(9)
    def get_Request(self) -> win32more.Windows.ApplicationModel.Search.SearchSuggestionsRequest: ...
    Language = property(get_Language, None)
    LinguisticDetails = property(get_LinguisticDetails, None)
    QueryText = property(get_QueryText, None)
    Request = property(get_Request, None)
class ISectionsInViewChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISectionsInViewChangedEventArgs'
    _iid_ = Guid('{dd49ee6b-d165-430f-a37d-b807064f85e1}')
    @winrt_commethod(6)
    def get_AddedSections(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection]: ...
    @winrt_commethod(7)
    def get_RemovedSections(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection]: ...
    AddedSections = property(get_AddedSections, None)
    RemovedSections = property(get_RemovedSections, None)
class ISectionsInViewChangedEventArgsFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISectionsInViewChangedEventArgsFactory'
    _iid_ = Guid('{557f5244-92f8-4150-b730-e6346e8f50d1}')
class ISelectionChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISelectionChangedEventArgs'
    _iid_ = Guid('{c972d2dc-b609-4758-851e-a799c21de97d}')
    @winrt_commethod(6)
    def get_AddedItems(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_commethod(7)
    def get_RemovedItems(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    AddedItems = property(get_AddedItems, None)
    RemovedItems = property(get_RemovedItems, None)
class ISelectionChangedEventArgsFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISelectionChangedEventArgsFactory'
    _iid_ = Guid('{11a8b6b5-2830-4517-84cd-5524c8b88b45}')
    @winrt_commethod(6)
    def CreateInstanceWithRemovedItemsAndAddedItems(self, removedItems: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable], addedItems: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable], baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SelectionChangedEventArgs: ...
class ISemanticZoom(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISemanticZoom'
    _iid_ = Guid('{019fff21-ece6-4fbc-bf40-8938d4813e27}')
    @winrt_commethod(6)
    def get_ZoomedInView(self) -> win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation: ...
    @winrt_commethod(7)
    def put_ZoomedInView(self, value: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation) -> Void: ...
    @winrt_commethod(8)
    def get_ZoomedOutView(self) -> win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation: ...
    @winrt_commethod(9)
    def put_ZoomedOutView(self, value: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation) -> Void: ...
    @winrt_commethod(10)
    def get_IsZoomedInViewActive(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsZoomedInViewActive(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_CanChangeViews(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_CanChangeViews(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def add_ViewChangeStarted(self, handler: win32more.Windows.UI.Xaml.Controls.SemanticZoomViewChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_ViewChangeStarted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def add_ViewChangeCompleted(self, handler: win32more.Windows.UI.Xaml.Controls.SemanticZoomViewChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_ViewChangeCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def ToggleActiveView(self) -> Void: ...
    @winrt_commethod(19)
    def get_IsZoomOutButtonEnabled(self) -> Boolean: ...
    @winrt_commethod(20)
    def put_IsZoomOutButtonEnabled(self, value: Boolean) -> Void: ...
    CanChangeViews = property(get_CanChangeViews, put_CanChangeViews)
    IsZoomOutButtonEnabled = property(get_IsZoomOutButtonEnabled, put_IsZoomOutButtonEnabled)
    IsZoomedInViewActive = property(get_IsZoomedInViewActive, put_IsZoomedInViewActive)
    ZoomedInView = property(get_ZoomedInView, put_ZoomedInView)
    ZoomedOutView = property(get_ZoomedOutView, put_ZoomedOutView)
    ViewChangeStarted = event()
    ViewChangeCompleted = event()
class ISemanticZoomInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISemanticZoomInformation'
    _iid_ = Guid('{a76a3b63-229b-4dc5-aa11-9d922fbf8a98}')
    @winrt_commethod(6)
    def get_SemanticZoomOwner(self) -> win32more.Windows.UI.Xaml.Controls.SemanticZoom: ...
    @winrt_commethod(7)
    def put_SemanticZoomOwner(self, value: win32more.Windows.UI.Xaml.Controls.SemanticZoom) -> Void: ...
    @winrt_commethod(8)
    def get_IsActiveView(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsActiveView(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_IsZoomedInView(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsZoomedInView(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def InitializeViewChange(self) -> Void: ...
    @winrt_commethod(13)
    def CompleteViewChange(self) -> Void: ...
    @winrt_commethod(14)
    def MakeVisible(self, item: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_commethod(15)
    def StartViewChangeFrom(self, source: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_commethod(16)
    def StartViewChangeTo(self, source: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_commethod(17)
    def CompleteViewChangeFrom(self, source: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_commethod(18)
    def CompleteViewChangeTo(self, source: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    IsActiveView = property(get_IsActiveView, put_IsActiveView)
    IsZoomedInView = property(get_IsZoomedInView, put_IsZoomedInView)
    SemanticZoomOwner = property(get_SemanticZoomOwner, put_SemanticZoomOwner)
class ISemanticZoomLocation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISemanticZoomLocation'
    _iid_ = Guid('{42011736-e3c2-496b-bc4e-d750d4375b9a}')
    @winrt_commethod(6)
    def get_Item(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Item(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_Bounds(self) -> win32more.Windows.Foundation.Rect: ...
    @winrt_commethod(9)
    def put_Bounds(self, value: win32more.Windows.Foundation.Rect) -> Void: ...
    Bounds = property(get_Bounds, put_Bounds)
    Item = property(get_Item, put_Item)
class ISemanticZoomStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISemanticZoomStatics'
    _iid_ = Guid('{8ef17ef2-9898-4666-b285-3ed38a07910e}')
    @winrt_commethod(6)
    def get_ZoomedInViewProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ZoomedOutViewProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsZoomedInViewActiveProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_CanChangeViewsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsZoomOutButtonEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CanChangeViewsProperty = property(get_CanChangeViewsProperty, None)
    IsZoomOutButtonEnabledProperty = property(get_IsZoomOutButtonEnabledProperty, None)
    IsZoomedInViewActiveProperty = property(get_IsZoomedInViewActiveProperty, None)
    ZoomedInViewProperty = property(get_ZoomedInViewProperty, None)
    ZoomedOutViewProperty = property(get_ZoomedOutViewProperty, None)
class ISemanticZoomViewChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISemanticZoomViewChangedEventArgs'
    _iid_ = Guid('{47dfc068-b569-4b19-842d-8e6cf90989af}')
    @winrt_commethod(6)
    def get_IsSourceZoomedInView(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsSourceZoomedInView(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_SourceItem(self) -> win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation: ...
    @winrt_commethod(9)
    def put_SourceItem(self, value: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_commethod(10)
    def get_DestinationItem(self) -> win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation: ...
    @winrt_commethod(11)
    def put_DestinationItem(self, value: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    DestinationItem = property(get_DestinationItem, put_DestinationItem)
    IsSourceZoomedInView = property(get_IsSourceZoomedInView, put_IsSourceZoomedInView)
    SourceItem = property(get_SourceItem, put_SourceItem)
class ISettingsFlyout(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISettingsFlyout'
    _iid_ = Guid('{830ba82b-c55b-4e32-a51c-5791e024c8af}')
    @winrt_commethod(6)
    def get_Title(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Title(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderBackground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(9)
    def put_HeaderBackground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(10)
    def get_HeaderForeground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(11)
    def put_HeaderForeground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(12)
    def get_IconSource(self) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(13)
    def put_IconSource(self, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(14)
    def get_TemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.SettingsFlyoutTemplateSettings: ...
    @winrt_commethod(15)
    def add_BackClick(self, handler: win32more.Windows.UI.Xaml.Controls.BackClickEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(16)
    def remove_BackClick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(17)
    def Show(self) -> Void: ...
    @winrt_commethod(18)
    def ShowIndependent(self) -> Void: ...
    @winrt_commethod(19)
    def Hide(self) -> Void: ...
    HeaderBackground = property(get_HeaderBackground, put_HeaderBackground)
    HeaderForeground = property(get_HeaderForeground, put_HeaderForeground)
    IconSource = property(get_IconSource, put_IconSource)
    TemplateSettings = property(get_TemplateSettings, None)
    Title = property(get_Title, put_Title)
    BackClick = event()
class ISettingsFlyoutFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISettingsFlyoutFactory'
    _iid_ = Guid('{480c7011-57aa-4db6-b6fd-ec676f6d414e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SettingsFlyout: ...
class ISettingsFlyoutStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISettingsFlyoutStatics'
    _iid_ = Guid('{d0e3b535-9157-4be4-a42a-f591698846ac}')
    @winrt_commethod(6)
    def get_TitleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderBackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_HeaderForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_IconSourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HeaderBackgroundProperty = property(get_HeaderBackgroundProperty, None)
    HeaderForegroundProperty = property(get_HeaderForegroundProperty, None)
    IconSourceProperty = property(get_IconSourceProperty, None)
    TitleProperty = property(get_TitleProperty, None)
class ISlider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISlider'
    _iid_ = Guid('{89572027-4c48-4700-8076-497ba73d9c18}')
    @winrt_commethod(6)
    def get_IntermediateValue(self) -> Double: ...
    @winrt_commethod(7)
    def put_IntermediateValue(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_StepFrequency(self) -> Double: ...
    @winrt_commethod(9)
    def put_StepFrequency(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_SnapsTo(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.SliderSnapsTo: ...
    @winrt_commethod(11)
    def put_SnapsTo(self, value: win32more.Windows.UI.Xaml.Controls.Primitives.SliderSnapsTo) -> Void: ...
    @winrt_commethod(12)
    def get_TickFrequency(self) -> Double: ...
    @winrt_commethod(13)
    def put_TickFrequency(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_TickPlacement(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.TickPlacement: ...
    @winrt_commethod(15)
    def put_TickPlacement(self, value: win32more.Windows.UI.Xaml.Controls.Primitives.TickPlacement) -> Void: ...
    @winrt_commethod(16)
    def get_Orientation(self) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(17)
    def put_Orientation(self, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(18)
    def get_IsDirectionReversed(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_IsDirectionReversed(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_IsThumbToolTipEnabled(self) -> Boolean: ...
    @winrt_commethod(21)
    def put_IsThumbToolTipEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(22)
    def get_ThumbToolTipValueConverter(self) -> win32more.Windows.UI.Xaml.Data.IValueConverter: ...
    @winrt_commethod(23)
    def put_ThumbToolTipValueConverter(self, value: win32more.Windows.UI.Xaml.Data.IValueConverter) -> Void: ...
    IntermediateValue = property(get_IntermediateValue, put_IntermediateValue)
    IsDirectionReversed = property(get_IsDirectionReversed, put_IsDirectionReversed)
    IsThumbToolTipEnabled = property(get_IsThumbToolTipEnabled, put_IsThumbToolTipEnabled)
    Orientation = property(get_Orientation, put_Orientation)
    SnapsTo = property(get_SnapsTo, put_SnapsTo)
    StepFrequency = property(get_StepFrequency, put_StepFrequency)
    ThumbToolTipValueConverter = property(get_ThumbToolTipValueConverter, put_ThumbToolTipValueConverter)
    TickFrequency = property(get_TickFrequency, put_TickFrequency)
    TickPlacement = property(get_TickPlacement, put_TickPlacement)
class ISlider2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISlider2'
    _iid_ = Guid('{40a3c50e-87d6-4d2f-b1cf-b279cc996f26}')
    @winrt_commethod(6)
    def get_Header(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_HeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
class ISliderFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISliderFactory'
    _iid_ = Guid('{03a67b37-c7bf-437c-848f-8cb5b753eab4}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Slider: ...
class ISliderStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISliderStatics'
    _iid_ = Guid('{8a4363d7-7fdf-4d30-98fe-ce78c05b31cf}')
    @winrt_commethod(6)
    def get_IntermediateValueProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_StepFrequencyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_SnapsToProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_TickFrequencyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_TickPlacementProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_OrientationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IsDirectionReversedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_IsThumbToolTipEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_ThumbToolTipValueConverterProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IntermediateValueProperty = property(get_IntermediateValueProperty, None)
    IsDirectionReversedProperty = property(get_IsDirectionReversedProperty, None)
    IsThumbToolTipEnabledProperty = property(get_IsThumbToolTipEnabledProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
    SnapsToProperty = property(get_SnapsToProperty, None)
    StepFrequencyProperty = property(get_StepFrequencyProperty, None)
    ThumbToolTipValueConverterProperty = property(get_ThumbToolTipValueConverterProperty, None)
    TickFrequencyProperty = property(get_TickFrequencyProperty, None)
    TickPlacementProperty = property(get_TickPlacementProperty, None)
class ISliderStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISliderStatics2'
    _iid_ = Guid('{00e7935d-79a5-4759-96a6-29e0a94add33}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
class ISplitButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISplitButton'
    _iid_ = Guid('{58bbb066-c2ea-5499-8150-40faa75f6bb5}')
    @winrt_commethod(6)
    def get_Flyout(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(7)
    def put_Flyout(self, value: win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_commethod(8)
    def get_Command(self) -> win32more.Windows.UI.Xaml.Input.ICommand: ...
    @winrt_commethod(9)
    def put_Command(self, value: win32more.Windows.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_commethod(10)
    def get_CommandParameter(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(11)
    def put_CommandParameter(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(12)
    def add_Click(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SplitButton, win32more.Windows.UI.Xaml.Controls.SplitButtonClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_Click(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Command = property(get_Command, put_Command)
    CommandParameter = property(get_CommandParameter, put_CommandParameter)
    Flyout = property(get_Flyout, put_Flyout)
    Click = event()
class ISplitButtonAutomationPeer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISplitButtonAutomationPeer'
    _iid_ = Guid('{c46a58b8-3828-5c36-aa13-f79f02c12f34}')
class ISplitButtonAutomationPeerFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISplitButtonAutomationPeerFactory'
    _iid_ = Guid('{d63a2534-77dc-5361-8422-4ad8750f45f4}')
    @winrt_commethod(6)
    def CreateInstance(self, owner: win32more.Windows.UI.Xaml.Controls.SplitButton, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SplitButtonAutomationPeer: ...
class ISplitButtonClickEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISplitButtonClickEventArgs'
    _iid_ = Guid('{c227c2ca-26f4-5960-98d5-919149d1b525}')
class ISplitButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISplitButtonFactory'
    _iid_ = Guid('{3201c32f-4d55-589d-97dd-617fa3642137}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SplitButton: ...
class ISplitButtonStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISplitButtonStatics'
    _iid_ = Guid('{8df07a81-0b1f-5ea9-be42-152ab9a4bc5e}')
    @winrt_commethod(6)
    def get_FlyoutProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CommandProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CommandParameterProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CommandParameterProperty = property(get_CommandParameterProperty, None)
    CommandProperty = property(get_CommandProperty, None)
    FlyoutProperty = property(get_FlyoutProperty, None)
class ISplitView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISplitView'
    _iid_ = Guid('{97222f31-3844-429e-939c-1673155322a1}')
    @winrt_commethod(6)
    def get_Content(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Content(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_Pane(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(9)
    def put_Pane(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(10)
    def get_IsPaneOpen(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsPaneOpen(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_OpenPaneLength(self) -> Double: ...
    @winrt_commethod(13)
    def put_OpenPaneLength(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_CompactPaneLength(self) -> Double: ...
    @winrt_commethod(15)
    def put_CompactPaneLength(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_PanePlacement(self) -> win32more.Windows.UI.Xaml.Controls.SplitViewPanePlacement: ...
    @winrt_commethod(17)
    def put_PanePlacement(self, value: win32more.Windows.UI.Xaml.Controls.SplitViewPanePlacement) -> Void: ...
    @winrt_commethod(18)
    def get_DisplayMode(self) -> win32more.Windows.UI.Xaml.Controls.SplitViewDisplayMode: ...
    @winrt_commethod(19)
    def put_DisplayMode(self, value: win32more.Windows.UI.Xaml.Controls.SplitViewDisplayMode) -> Void: ...
    @winrt_commethod(20)
    def get_TemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.SplitViewTemplateSettings: ...
    @winrt_commethod(21)
    def get_PaneBackground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(22)
    def put_PaneBackground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(23)
    def add_PaneClosing(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SplitView, win32more.Windows.UI.Xaml.Controls.SplitViewPaneClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(24)
    def remove_PaneClosing(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(25)
    def add_PaneClosed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SplitView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(26)
    def remove_PaneClosed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CompactPaneLength = property(get_CompactPaneLength, put_CompactPaneLength)
    Content = property(get_Content, put_Content)
    DisplayMode = property(get_DisplayMode, put_DisplayMode)
    IsPaneOpen = property(get_IsPaneOpen, put_IsPaneOpen)
    OpenPaneLength = property(get_OpenPaneLength, put_OpenPaneLength)
    Pane = property(get_Pane, put_Pane)
    PaneBackground = property(get_PaneBackground, put_PaneBackground)
    PanePlacement = property(get_PanePlacement, put_PanePlacement)
    TemplateSettings = property(get_TemplateSettings, None)
    PaneClosing = event()
    PaneClosed = event()
class ISplitView2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISplitView2'
    _iid_ = Guid('{5ea7dc10-cc83-409a-82f9-3e91d6d7084f}')
    @winrt_commethod(6)
    def get_LightDismissOverlayMode(self) -> win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_commethod(7)
    def put_LightDismissOverlayMode(self, value: win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
class ISplitView3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISplitView3'
    _iid_ = Guid('{0ea12d8d-1171-407b-96d3-5e1b470c3ec5}')
    @winrt_commethod(6)
    def add_PaneOpening(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SplitView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_PaneOpening(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_PaneOpened(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SplitView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_PaneOpened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    PaneOpening = event()
    PaneOpened = event()
class ISplitViewFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISplitViewFactory'
    _iid_ = Guid('{f101773a-084e-4fb9-8442-63221b44533f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SplitView: ...
class ISplitViewPaneClosingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISplitViewPaneClosingEventArgs'
    _iid_ = Guid('{93cf494e-7a95-44d8-9562-1b348248da9f}')
    @winrt_commethod(6)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
class ISplitViewStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISplitViewStatics'
    _iid_ = Guid('{859b4f6f-44ab-4e4b-91c1-17b7056d9b5f}')
    @winrt_commethod(6)
    def get_ContentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PaneProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsPaneOpenProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_OpenPaneLengthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_CompactPaneLengthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_PanePlacementProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_DisplayModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_TemplateSettingsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_PaneBackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CompactPaneLengthProperty = property(get_CompactPaneLengthProperty, None)
    ContentProperty = property(get_ContentProperty, None)
    DisplayModeProperty = property(get_DisplayModeProperty, None)
    IsPaneOpenProperty = property(get_IsPaneOpenProperty, None)
    OpenPaneLengthProperty = property(get_OpenPaneLengthProperty, None)
    PaneBackgroundProperty = property(get_PaneBackgroundProperty, None)
    PanePlacementProperty = property(get_PanePlacementProperty, None)
    PaneProperty = property(get_PaneProperty, None)
    TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
class ISplitViewStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISplitViewStatics2'
    _iid_ = Guid('{14b7cd7a-dfbc-422c-80a9-585871297113}')
    @winrt_commethod(6)
    def get_LightDismissOverlayModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
class IStackPanel(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IStackPanel'
    _iid_ = Guid('{b8ae8fe2-d641-4fd7-80b4-7439207d2798}')
    @winrt_commethod(6)
    def get_AreScrollSnapPointsRegular(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_AreScrollSnapPointsRegular(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Orientation(self) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(9)
    def put_Orientation(self, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    AreScrollSnapPointsRegular = property(get_AreScrollSnapPointsRegular, put_AreScrollSnapPointsRegular)
    Orientation = property(get_Orientation, put_Orientation)
class IStackPanel2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IStackPanel2'
    _iid_ = Guid('{36f23359-040e-48f7-9a98-f2664591959c}')
    @winrt_commethod(6)
    def get_BorderBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(7)
    def put_BorderBrush(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(8)
    def get_BorderThickness(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(9)
    def put_BorderThickness(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(10)
    def get_CornerRadius(self) -> win32more.Windows.UI.Xaml.CornerRadius: ...
    @winrt_commethod(11)
    def put_CornerRadius(self, value: win32more.Windows.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_commethod(12)
    def get_Padding(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(13)
    def put_Padding(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    Padding = property(get_Padding, put_Padding)
class IStackPanel4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IStackPanel4'
    _iid_ = Guid('{43ebf7f6-3196-412e-8a95-add002ff43f0}')
    @winrt_commethod(6)
    def get_Spacing(self) -> Double: ...
    @winrt_commethod(7)
    def put_Spacing(self, value: Double) -> Void: ...
    Spacing = property(get_Spacing, put_Spacing)
class IStackPanel5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IStackPanel5'
    _iid_ = Guid('{f73e3117-61a8-5a01-865e-88511c04a992}')
    @winrt_commethod(6)
    def get_BackgroundSizing(self) -> win32more.Windows.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_commethod(7)
    def put_BackgroundSizing(self, value: win32more.Windows.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
class IStackPanelFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IStackPanelFactory'
    _iid_ = Guid('{63d8248a-8b34-445a-808f-b6ecd62a27d9}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.StackPanel: ...
class IStackPanelStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IStackPanelStatics'
    _iid_ = Guid('{f0d0cd93-4dbc-48a7-9914-954924657771}')
    @winrt_commethod(6)
    def get_AreScrollSnapPointsRegularProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_OrientationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AreScrollSnapPointsRegularProperty = property(get_AreScrollSnapPointsRegularProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
class IStackPanelStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IStackPanelStatics2'
    _iid_ = Guid('{d97e6257-080d-412e-a91a-ce6e5d02aad3}')
    @winrt_commethod(6)
    def get_BorderBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_BorderThicknessProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CornerRadiusProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PaddingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BorderBrushProperty = property(get_BorderBrushProperty, None)
    BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
class IStackPanelStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IStackPanelStatics4'
    _iid_ = Guid('{279cdd71-067b-459f-815f-ecd85c5e4843}')
    @winrt_commethod(6)
    def get_SpacingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SpacingProperty = property(get_SpacingProperty, None)
class IStackPanelStatics5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IStackPanelStatics5'
    _iid_ = Guid('{87287490-bff2-5347-8787-fb5aec942878}')
    @winrt_commethod(6)
    def get_BackgroundSizingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
class IStyleSelector(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IStyleSelector'
    _iid_ = Guid('{d1113f67-d8c1-4ae4-98f0-d8504502f08b}')
    @winrt_commethod(6)
    def SelectStyle(self, item: win32more.Windows.Win32.System.WinRT.IInspectable, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Style: ...
class IStyleSelectorFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IStyleSelectorFactory'
    _iid_ = Guid('{9e942ae7-3761-447f-8f97-29e39d5eb310}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.StyleSelector: ...
class IStyleSelectorOverrides(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IStyleSelectorOverrides'
    _iid_ = Guid('{08add66d-0e2e-43a0-aeca-8faa94b9d017}')
    @winrt_commethod(6)
    def SelectStyleCore(self, item: win32more.Windows.Win32.System.WinRT.IInspectable, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Style: ...
class ISwapChainBackgroundPanel(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISwapChainBackgroundPanel'
    _iid_ = Guid('{1c59db48-8233-4c0c-bcf5-02a5fb35ae00}')
class ISwapChainBackgroundPanel2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISwapChainBackgroundPanel2'
    _iid_ = Guid('{21e672f2-2592-4c38-870f-28fbcf52c095}')
    @winrt_commethod(6)
    def CreateCoreIndependentInputSource(self, deviceTypes: win32more.Windows.UI.Core.CoreInputDeviceTypes) -> win32more.Windows.UI.Core.CoreIndependentInputSource: ...
class ISwapChainBackgroundPanelFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISwapChainBackgroundPanelFactory'
    _iid_ = Guid('{198289d4-c89b-49b2-896c-5917bf8adcae}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SwapChainBackgroundPanel: ...
class ISwapChainPanel(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISwapChainPanel'
    _iid_ = Guid('{c589644f-eba8-427a-b75a-9f1f93a11ae9}')
    @winrt_commethod(6)
    def get_CompositionScaleX(self) -> Single: ...
    @winrt_commethod(7)
    def get_CompositionScaleY(self) -> Single: ...
    @winrt_commethod(8)
    def add_CompositionScaleChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SwapChainPanel, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_CompositionScaleChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def CreateCoreIndependentInputSource(self, deviceTypes: win32more.Windows.UI.Core.CoreInputDeviceTypes) -> win32more.Windows.UI.Core.CoreIndependentInputSource: ...
    CompositionScaleX = property(get_CompositionScaleX, None)
    CompositionScaleY = property(get_CompositionScaleY, None)
    CompositionScaleChanged = event()
class ISwapChainPanelFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISwapChainPanelFactory'
    _iid_ = Guid('{f38f8d7f-1a48-49cb-86d2-10eaaaf6fd70}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SwapChainPanel: ...
class ISwapChainPanelStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISwapChainPanelStatics'
    _iid_ = Guid('{f89c0297-eea8-498c-99c4-257e3660df7e}')
    @winrt_commethod(6)
    def get_CompositionScaleXProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CompositionScaleYProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CompositionScaleXProperty = property(get_CompositionScaleXProperty, None)
    CompositionScaleYProperty = property(get_CompositionScaleYProperty, None)
class ISwipeControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISwipeControl'
    _iid_ = Guid('{9ee3d96f-6704-4823-aa15-1c143bc53cf7}')
    @winrt_commethod(6)
    def get_LeftItems(self) -> win32more.Windows.UI.Xaml.Controls.SwipeItems: ...
    @winrt_commethod(7)
    def put_LeftItems(self, value: win32more.Windows.UI.Xaml.Controls.SwipeItems) -> Void: ...
    @winrt_commethod(8)
    def get_RightItems(self) -> win32more.Windows.UI.Xaml.Controls.SwipeItems: ...
    @winrt_commethod(9)
    def put_RightItems(self, value: win32more.Windows.UI.Xaml.Controls.SwipeItems) -> Void: ...
    @winrt_commethod(10)
    def get_TopItems(self) -> win32more.Windows.UI.Xaml.Controls.SwipeItems: ...
    @winrt_commethod(11)
    def put_TopItems(self, value: win32more.Windows.UI.Xaml.Controls.SwipeItems) -> Void: ...
    @winrt_commethod(12)
    def get_BottomItems(self) -> win32more.Windows.UI.Xaml.Controls.SwipeItems: ...
    @winrt_commethod(13)
    def put_BottomItems(self, value: win32more.Windows.UI.Xaml.Controls.SwipeItems) -> Void: ...
    @winrt_commethod(14)
    def Close(self) -> Void: ...
    BottomItems = property(get_BottomItems, put_BottomItems)
    LeftItems = property(get_LeftItems, put_LeftItems)
    RightItems = property(get_RightItems, put_RightItems)
    TopItems = property(get_TopItems, put_TopItems)
class ISwipeControlFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISwipeControlFactory'
    _iid_ = Guid('{c0aaa3ae-d141-4e12-a728-5f95b507e7ab}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SwipeControl: ...
class ISwipeControlStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISwipeControlStatics'
    _iid_ = Guid('{e57ae83c-2216-4717-9ef6-4662334c6501}')
    @winrt_commethod(6)
    def get_LeftItemsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_RightItemsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_TopItemsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_BottomItemsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BottomItemsProperty = property(get_BottomItemsProperty, None)
    LeftItemsProperty = property(get_LeftItemsProperty, None)
    RightItemsProperty = property(get_RightItemsProperty, None)
    TopItemsProperty = property(get_TopItemsProperty, None)
class ISwipeItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISwipeItem'
    _iid_ = Guid('{836edadc-45c8-4a00-90a0-7107fa894a1b}')
    @winrt_commethod(6)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Text(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_IconSource(self) -> win32more.Windows.UI.Xaml.Controls.IconSource: ...
    @winrt_commethod(9)
    def put_IconSource(self, value: win32more.Windows.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_commethod(10)
    def get_Background(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(11)
    def put_Background(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(12)
    def get_Foreground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(13)
    def put_Foreground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(14)
    def get_Command(self) -> win32more.Windows.UI.Xaml.Input.ICommand: ...
    @winrt_commethod(15)
    def put_Command(self, value: win32more.Windows.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_commethod(16)
    def get_CommandParameter(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(17)
    def put_CommandParameter(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(18)
    def get_BehaviorOnInvoked(self) -> win32more.Windows.UI.Xaml.Controls.SwipeBehaviorOnInvoked: ...
    @winrt_commethod(19)
    def put_BehaviorOnInvoked(self, value: win32more.Windows.UI.Xaml.Controls.SwipeBehaviorOnInvoked) -> Void: ...
    @winrt_commethod(20)
    def add_Invoked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SwipeItem, win32more.Windows.UI.Xaml.Controls.SwipeItemInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_Invoked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Background = property(get_Background, put_Background)
    BehaviorOnInvoked = property(get_BehaviorOnInvoked, put_BehaviorOnInvoked)
    Command = property(get_Command, put_Command)
    CommandParameter = property(get_CommandParameter, put_CommandParameter)
    Foreground = property(get_Foreground, put_Foreground)
    IconSource = property(get_IconSource, put_IconSource)
    Text = property(get_Text, put_Text)
    Invoked = event()
class ISwipeItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISwipeItemFactory'
    _iid_ = Guid('{844bd61a-1716-4097-bba2-7526da22de39}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SwipeItem: ...
class ISwipeItemInvokedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISwipeItemInvokedEventArgs'
    _iid_ = Guid('{c5b025f5-cb32-4733-8011-5d0d37f4550a}')
    @winrt_commethod(6)
    def get_SwipeControl(self) -> win32more.Windows.UI.Xaml.Controls.SwipeControl: ...
    SwipeControl = property(get_SwipeControl, None)
class ISwipeItemStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISwipeItemStatics'
    _iid_ = Guid('{d0b44e96-2766-4d93-b5db-f5e1be832c2d}')
    @winrt_commethod(6)
    def get_IconSourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_BackgroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_ForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_CommandProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_CommandParameterProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_BehaviorOnInvokedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BackgroundProperty = property(get_BackgroundProperty, None)
    BehaviorOnInvokedProperty = property(get_BehaviorOnInvokedProperty, None)
    CommandParameterProperty = property(get_CommandParameterProperty, None)
    CommandProperty = property(get_CommandProperty, None)
    ForegroundProperty = property(get_ForegroundProperty, None)
    IconSourceProperty = property(get_IconSourceProperty, None)
    TextProperty = property(get_TextProperty, None)
class ISwipeItems(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISwipeItems'
    _iid_ = Guid('{b01726ff-969a-40d0-9f04-76084ce6d7b7}')
    @winrt_commethod(6)
    def get_Mode(self) -> win32more.Windows.UI.Xaml.Controls.SwipeMode: ...
    @winrt_commethod(7)
    def put_Mode(self, value: win32more.Windows.UI.Xaml.Controls.SwipeMode) -> Void: ...
    Mode = property(get_Mode, put_Mode)
class ISwipeItemsFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISwipeItemsFactory'
    _iid_ = Guid('{47c460ee-d5aa-445f-b31e-50c076c011b9}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SwipeItems: ...
class ISwipeItemsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISwipeItemsStatics'
    _iid_ = Guid('{376250df-48db-43e3-b0e9-089e5da9a114}')
    @winrt_commethod(6)
    def get_ModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ModeProperty = property(get_ModeProperty, None)
class ISymbolIcon(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISymbolIcon'
    _iid_ = Guid('{7a4774c9-a6a3-4b30-8ff1-9081d70e9a5c}')
    @winrt_commethod(6)
    def get_Symbol(self) -> win32more.Windows.UI.Xaml.Controls.Symbol: ...
    @winrt_commethod(7)
    def put_Symbol(self, value: win32more.Windows.UI.Xaml.Controls.Symbol) -> Void: ...
    Symbol = property(get_Symbol, put_Symbol)
class ISymbolIconFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISymbolIconFactory'
    _iid_ = Guid('{c7252b88-e76c-4b44-8a05-046b9dc772b8}')
    @winrt_commethod(6)
    def CreateInstanceWithSymbol(self, symbol: win32more.Windows.UI.Xaml.Controls.Symbol) -> win32more.Windows.UI.Xaml.Controls.SymbolIcon: ...
class ISymbolIconSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISymbolIconSource'
    _iid_ = Guid('{625d95a2-b6b1-408a-b289-eab2ecba62d8}')
    @winrt_commethod(6)
    def get_Symbol(self) -> win32more.Windows.UI.Xaml.Controls.Symbol: ...
    @winrt_commethod(7)
    def put_Symbol(self, value: win32more.Windows.UI.Xaml.Controls.Symbol) -> Void: ...
    Symbol = property(get_Symbol, put_Symbol)
class ISymbolIconSourceFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISymbolIconSourceFactory'
    _iid_ = Guid('{a526aab0-4130-4907-b049-21f9240c7a40}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SymbolIconSource: ...
class ISymbolIconSourceStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISymbolIconSourceStatics'
    _iid_ = Guid('{8bc49738-d94e-4148-8d64-1adf0f23f25f}')
    @winrt_commethod(6)
    def get_SymbolProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SymbolProperty = property(get_SymbolProperty, None)
class ISymbolIconStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ISymbolIconStatics'
    _iid_ = Guid('{8624fbdf-952c-4f76-b03f-30833be99572}')
    @winrt_commethod(6)
    def get_SymbolProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SymbolProperty = property(get_SymbolProperty, None)
class ITextBlock(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBlock'
    _iid_ = Guid('{ae2d9271-3b4a-45fc-8468-f7949548f4d5}')
    @winrt_commethod(6)
    def get_FontSize(self) -> Double: ...
    @winrt_commethod(7)
    def put_FontSize(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_FontFamily(self) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(9)
    def put_FontFamily(self, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(10)
    def get_FontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(11)
    def put_FontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(12)
    def get_FontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(13)
    def put_FontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(14)
    def get_FontStretch(self) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_commethod(15)
    def put_FontStretch(self, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_commethod(16)
    def get_CharacterSpacing(self) -> Int32: ...
    @winrt_commethod(17)
    def put_CharacterSpacing(self, value: Int32) -> Void: ...
    @winrt_commethod(18)
    def get_Foreground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(19)
    def put_Foreground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(20)
    def get_TextWrapping(self) -> win32more.Windows.UI.Xaml.TextWrapping: ...
    @winrt_commethod(21)
    def put_TextWrapping(self, value: win32more.Windows.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_commethod(22)
    def get_TextTrimming(self) -> win32more.Windows.UI.Xaml.TextTrimming: ...
    @winrt_commethod(23)
    def put_TextTrimming(self, value: win32more.Windows.UI.Xaml.TextTrimming) -> Void: ...
    @winrt_commethod(24)
    def get_TextAlignment(self) -> win32more.Windows.UI.Xaml.TextAlignment: ...
    @winrt_commethod(25)
    def put_TextAlignment(self, value: win32more.Windows.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(26)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(27)
    def put_Text(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(28)
    def get_Inlines(self) -> win32more.Windows.UI.Xaml.Documents.InlineCollection: ...
    @winrt_commethod(29)
    def get_Padding(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(30)
    def put_Padding(self, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(31)
    def get_LineHeight(self) -> Double: ...
    @winrt_commethod(32)
    def put_LineHeight(self, value: Double) -> Void: ...
    @winrt_commethod(33)
    def get_LineStackingStrategy(self) -> win32more.Windows.UI.Xaml.LineStackingStrategy: ...
    @winrt_commethod(34)
    def put_LineStackingStrategy(self, value: win32more.Windows.UI.Xaml.LineStackingStrategy) -> Void: ...
    @winrt_commethod(35)
    def get_IsTextSelectionEnabled(self) -> Boolean: ...
    @winrt_commethod(36)
    def put_IsTextSelectionEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(37)
    def get_SelectedText(self) -> WinRT_String: ...
    @winrt_commethod(38)
    def get_ContentStart(self) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(39)
    def get_ContentEnd(self) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(40)
    def get_SelectionStart(self) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(41)
    def get_SelectionEnd(self) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(42)
    def get_BaselineOffset(self) -> Double: ...
    @winrt_commethod(43)
    def add_SelectionChanged(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(44)
    def remove_SelectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(45)
    def add_ContextMenuOpening(self, handler: win32more.Windows.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(46)
    def remove_ContextMenuOpening(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(47)
    def SelectAll(self) -> Void: ...
    @winrt_commethod(48)
    def Select(self, start: win32more.Windows.UI.Xaml.Documents.TextPointer, end: win32more.Windows.UI.Xaml.Documents.TextPointer) -> Void: ...
    @winrt_commethod(49)
    def Focus(self, value: win32more.Windows.UI.Xaml.FocusState) -> Boolean: ...
    BaselineOffset = property(get_BaselineOffset, None)
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    ContentEnd = property(get_ContentEnd, None)
    ContentStart = property(get_ContentStart, None)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
    Inlines = property(get_Inlines, None)
    IsTextSelectionEnabled = property(get_IsTextSelectionEnabled, put_IsTextSelectionEnabled)
    LineHeight = property(get_LineHeight, put_LineHeight)
    LineStackingStrategy = property(get_LineStackingStrategy, put_LineStackingStrategy)
    Padding = property(get_Padding, put_Padding)
    SelectedText = property(get_SelectedText, None)
    SelectionEnd = property(get_SelectionEnd, None)
    SelectionStart = property(get_SelectionStart, None)
    Text = property(get_Text, put_Text)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
    TextTrimming = property(get_TextTrimming, put_TextTrimming)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    SelectionChanged = event()
    ContextMenuOpening = event()
class ITextBlock2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBlock2'
    _iid_ = Guid('{45206a4c-0a4e-4fbf-aee9-335d5a205f6e}')
    @winrt_commethod(6)
    def get_SelectionHighlightColor(self) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_commethod(7)
    def put_SelectionHighlightColor(self, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_commethod(8)
    def get_MaxLines(self) -> Int32: ...
    @winrt_commethod(9)
    def put_MaxLines(self, value: Int32) -> Void: ...
    @winrt_commethod(10)
    def get_TextLineBounds(self) -> win32more.Windows.UI.Xaml.TextLineBounds: ...
    @winrt_commethod(11)
    def put_TextLineBounds(self, value: win32more.Windows.UI.Xaml.TextLineBounds) -> Void: ...
    @winrt_commethod(12)
    def get_OpticalMarginAlignment(self) -> win32more.Windows.UI.Xaml.OpticalMarginAlignment: ...
    @winrt_commethod(13)
    def put_OpticalMarginAlignment(self, value: win32more.Windows.UI.Xaml.OpticalMarginAlignment) -> Void: ...
    @winrt_commethod(14)
    def get_IsColorFontEnabled(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsColorFontEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_TextReadingOrder(self) -> win32more.Windows.UI.Xaml.TextReadingOrder: ...
    @winrt_commethod(17)
    def put_TextReadingOrder(self, value: win32more.Windows.UI.Xaml.TextReadingOrder) -> Void: ...
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    MaxLines = property(get_MaxLines, put_MaxLines)
    OpticalMarginAlignment = property(get_OpticalMarginAlignment, put_OpticalMarginAlignment)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    TextLineBounds = property(get_TextLineBounds, put_TextLineBounds)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
class ITextBlock3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBlock3'
    _iid_ = Guid('{b651dd5a-424b-48c3-9b67-486f4e139899}')
    @winrt_commethod(6)
    def get_IsTextScaleFactorEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsTextScaleFactorEnabled(self, value: Boolean) -> Void: ...
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
class ITextBlock4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBlock4'
    _iid_ = Guid('{b014f270-9808-4adc-b452-60cda54100c1}')
    @winrt_commethod(6)
    def GetAlphaMask(self) -> win32more.Windows.UI.Composition.CompositionBrush: ...
class ITextBlock5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBlock5'
    _iid_ = Guid('{624a2d38-edbd-4a5a-b678-e49f1e07afbd}')
    @winrt_commethod(6)
    def get_TextDecorations(self) -> win32more.Windows.UI.Text.TextDecorations: ...
    @winrt_commethod(7)
    def put_TextDecorations(self, value: win32more.Windows.UI.Text.TextDecorations) -> Void: ...
    TextDecorations = property(get_TextDecorations, put_TextDecorations)
class ITextBlock6(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBlock6'
    _iid_ = Guid('{31816cd9-0404-410f-91ec-33b0a0bb92b2}')
    @winrt_commethod(6)
    def get_IsTextTrimmed(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_HorizontalTextAlignment(self) -> win32more.Windows.UI.Xaml.TextAlignment: ...
    @winrt_commethod(8)
    def put_HorizontalTextAlignment(self, value: win32more.Windows.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(9)
    def get_TextHighlighters(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Documents.TextHighlighter]: ...
    @winrt_commethod(10)
    def add_IsTextTrimmedChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBlock, win32more.Windows.UI.Xaml.Controls.IsTextTrimmedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_IsTextTrimmedChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    IsTextTrimmed = property(get_IsTextTrimmed, None)
    TextHighlighters = property(get_TextHighlighters, None)
    IsTextTrimmedChanged = event()
class ITextBlock7(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBlock7'
    _iid_ = Guid('{dfe20a4e-8be7-5e33-9f37-72416875b121}')
    @winrt_commethod(6)
    def get_SelectionFlyout(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(7)
    def put_SelectionFlyout(self, value: win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_commethod(8)
    def CopySelectionToClipboard(self) -> Void: ...
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
class ITextBlockStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBlockStatics'
    _iid_ = Guid('{193ec042-a847-4552-b4e8-db36655b840a}')
    @winrt_commethod(6)
    def get_FontSizeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_FontFamilyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_FontWeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_FontStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FontStretchProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_CharacterSpacingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_TextWrappingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_TextTrimmingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_TextAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_TextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_PaddingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_LineHeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_LineStackingStrategyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_IsTextSelectionEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_SelectedTextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    FontFamilyProperty = property(get_FontFamilyProperty, None)
    FontSizeProperty = property(get_FontSizeProperty, None)
    FontStretchProperty = property(get_FontStretchProperty, None)
    FontStyleProperty = property(get_FontStyleProperty, None)
    FontWeightProperty = property(get_FontWeightProperty, None)
    ForegroundProperty = property(get_ForegroundProperty, None)
    IsTextSelectionEnabledProperty = property(get_IsTextSelectionEnabledProperty, None)
    LineHeightProperty = property(get_LineHeightProperty, None)
    LineStackingStrategyProperty = property(get_LineStackingStrategyProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
    SelectedTextProperty = property(get_SelectedTextProperty, None)
    TextAlignmentProperty = property(get_TextAlignmentProperty, None)
    TextProperty = property(get_TextProperty, None)
    TextTrimmingProperty = property(get_TextTrimmingProperty, None)
    TextWrappingProperty = property(get_TextWrappingProperty, None)
class ITextBlockStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBlockStatics2'
    _iid_ = Guid('{88100b1b-ff24-4b93-a0e6-f029c94871f1}')
    @winrt_commethod(6)
    def get_SelectionHighlightColorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_MaxLinesProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_TextLineBoundsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_OpticalMarginAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsColorFontEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_TextReadingOrderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    MaxLinesProperty = property(get_MaxLinesProperty, None)
    OpticalMarginAlignmentProperty = property(get_OpticalMarginAlignmentProperty, None)
    SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    TextLineBoundsProperty = property(get_TextLineBoundsProperty, None)
    TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
class ITextBlockStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBlockStatics3'
    _iid_ = Guid('{8d16b9eb-20a1-4eab-bbf2-1d6bdcbcd705}')
    @winrt_commethod(6)
    def get_IsTextScaleFactorEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
class ITextBlockStatics5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBlockStatics5'
    _iid_ = Guid('{8e4d9c70-0d4e-48df-ae7f-bb7a9af6852e}')
    @winrt_commethod(6)
    def get_TextDecorationsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    TextDecorationsProperty = property(get_TextDecorationsProperty, None)
class ITextBlockStatics6(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBlockStatics6'
    _iid_ = Guid('{3d1013a9-f9a6-43a2-99d3-573b89a83ca3}')
    @winrt_commethod(6)
    def get_IsTextTrimmedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HorizontalTextAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
    IsTextTrimmedProperty = property(get_IsTextTrimmedProperty, None)
class ITextBlockStatics7(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBlockStatics7'
    _iid_ = Guid('{cfd57e3b-0256-585d-8b3f-feafb69d3320}')
    @winrt_commethod(6)
    def get_SelectionFlyoutProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
class ITextBox(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBox'
    _iid_ = Guid('{e48f5a8b-1dff-4352-a1f4-e516514ec882}')
    @winrt_commethod(6)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Text(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_SelectedText(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_SelectedText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_SelectionLength(self) -> Int32: ...
    @winrt_commethod(11)
    def put_SelectionLength(self, value: Int32) -> Void: ...
    @winrt_commethod(12)
    def get_SelectionStart(self) -> Int32: ...
    @winrt_commethod(13)
    def put_SelectionStart(self, value: Int32) -> Void: ...
    @winrt_commethod(14)
    def get_MaxLength(self) -> Int32: ...
    @winrt_commethod(15)
    def put_MaxLength(self, value: Int32) -> Void: ...
    @winrt_commethod(16)
    def get_IsReadOnly(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsReadOnly(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_AcceptsReturn(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_AcceptsReturn(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_TextAlignment(self) -> win32more.Windows.UI.Xaml.TextAlignment: ...
    @winrt_commethod(21)
    def put_TextAlignment(self, value: win32more.Windows.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(22)
    def get_TextWrapping(self) -> win32more.Windows.UI.Xaml.TextWrapping: ...
    @winrt_commethod(23)
    def put_TextWrapping(self, value: win32more.Windows.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_commethod(24)
    def get_IsSpellCheckEnabled(self) -> Boolean: ...
    @winrt_commethod(25)
    def put_IsSpellCheckEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(26)
    def get_IsTextPredictionEnabled(self) -> Boolean: ...
    @winrt_commethod(27)
    def put_IsTextPredictionEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(28)
    def get_InputScope(self) -> win32more.Windows.UI.Xaml.Input.InputScope: ...
    @winrt_commethod(29)
    def put_InputScope(self, value: win32more.Windows.UI.Xaml.Input.InputScope) -> Void: ...
    @winrt_commethod(30)
    def add_TextChanged(self, handler: win32more.Windows.UI.Xaml.Controls.TextChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(31)
    def remove_TextChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(32)
    def add_SelectionChanged(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(33)
    def remove_SelectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(34)
    def add_ContextMenuOpening(self, handler: win32more.Windows.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(35)
    def remove_ContextMenuOpening(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(36)
    def Select(self, start: Int32, length: Int32) -> Void: ...
    @winrt_commethod(37)
    def SelectAll(self) -> Void: ...
    @winrt_commethod(38)
    def GetRectFromCharacterIndex(self, charIndex: Int32, trailingEdge: Boolean) -> win32more.Windows.Foundation.Rect: ...
    AcceptsReturn = property(get_AcceptsReturn, put_AcceptsReturn)
    InputScope = property(get_InputScope, put_InputScope)
    IsReadOnly = property(get_IsReadOnly, put_IsReadOnly)
    IsSpellCheckEnabled = property(get_IsSpellCheckEnabled, put_IsSpellCheckEnabled)
    IsTextPredictionEnabled = property(get_IsTextPredictionEnabled, put_IsTextPredictionEnabled)
    MaxLength = property(get_MaxLength, put_MaxLength)
    SelectedText = property(get_SelectedText, put_SelectedText)
    SelectionLength = property(get_SelectionLength, put_SelectionLength)
    SelectionStart = property(get_SelectionStart, put_SelectionStart)
    Text = property(get_Text, put_Text)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    TextChanged = event()
    SelectionChanged = event()
    ContextMenuOpening = event()
class ITextBox2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBox2'
    _iid_ = Guid('{f7168c00-1432-462a-9405-38f385bfc37c}')
    @winrt_commethod(6)
    def get_Header(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_HeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_PlaceholderText(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_PlaceholderText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_SelectionHighlightColor(self) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_commethod(13)
    def put_SelectionHighlightColor(self, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_commethod(14)
    def get_PreventKeyboardDisplayOnProgrammaticFocus(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_PreventKeyboardDisplayOnProgrammaticFocus(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_IsColorFontEnabled(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsColorFontEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def add_Paste(self, handler: win32more.Windows.UI.Xaml.Controls.TextControlPasteEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_Paste(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    PreventKeyboardDisplayOnProgrammaticFocus = property(get_PreventKeyboardDisplayOnProgrammaticFocus, put_PreventKeyboardDisplayOnProgrammaticFocus)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    Paste = event()
class ITextBox3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBox3'
    _iid_ = Guid('{7df18c3c-2826-425e-9a94-00b7f73f3756}')
    @winrt_commethod(6)
    def add_TextCompositionStarted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.TextCompositionStartedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_TextCompositionStarted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_TextCompositionChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.TextCompositionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_TextCompositionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def add_TextCompositionEnded(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.TextCompositionEndedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_TextCompositionEnded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def get_TextReadingOrder(self) -> win32more.Windows.UI.Xaml.TextReadingOrder: ...
    @winrt_commethod(13)
    def put_TextReadingOrder(self, value: win32more.Windows.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_commethod(14)
    def get_DesiredCandidateWindowAlignment(self) -> win32more.Windows.UI.Xaml.Controls.CandidateWindowAlignment: ...
    @winrt_commethod(15)
    def put_DesiredCandidateWindowAlignment(self, value: win32more.Windows.UI.Xaml.Controls.CandidateWindowAlignment) -> Void: ...
    @winrt_commethod(16)
    def add_CandidateWindowBoundsChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.CandidateWindowBoundsChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_CandidateWindowBoundsChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def add_TextChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.TextBoxTextChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_TextChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    DesiredCandidateWindowAlignment = property(get_DesiredCandidateWindowAlignment, put_DesiredCandidateWindowAlignment)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    TextCompositionStarted = event()
    TextCompositionChanged = event()
    TextCompositionEnded = event()
    CandidateWindowBoundsChanged = event()
    TextChanging = event()
class ITextBox4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBox4'
    _iid_ = Guid('{b5f1a675-cce1-45af-aef9-c4787bbb5e30}')
    @winrt_commethod(6)
    def GetLinguisticAlternativesAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
class ITextBox5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBox5'
    _iid_ = Guid('{35f9cfc1-4176-44f4-b756-e9ccc4399805}')
    @winrt_commethod(6)
    def get_SelectionHighlightColorWhenNotFocused(self) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_commethod(7)
    def put_SelectionHighlightColorWhenNotFocused(self, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    SelectionHighlightColorWhenNotFocused = property(get_SelectionHighlightColorWhenNotFocused, put_SelectionHighlightColorWhenNotFocused)
class ITextBox6(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBox6'
    _iid_ = Guid('{41ff2d07-5085-4e52-a51c-f94b06cd558b}')
    @winrt_commethod(6)
    def get_HorizontalTextAlignment(self) -> win32more.Windows.UI.Xaml.TextAlignment: ...
    @winrt_commethod(7)
    def put_HorizontalTextAlignment(self, value: win32more.Windows.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(8)
    def get_CharacterCasing(self) -> win32more.Windows.UI.Xaml.Controls.CharacterCasing: ...
    @winrt_commethod(9)
    def put_CharacterCasing(self, value: win32more.Windows.UI.Xaml.Controls.CharacterCasing) -> Void: ...
    @winrt_commethod(10)
    def get_PlaceholderForeground(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(11)
    def put_PlaceholderForeground(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(12)
    def add_CopyingToClipboard(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.TextControlCopyingToClipboardEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_CopyingToClipboard(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_CuttingToClipboard(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.TextControlCuttingToClipboardEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_CuttingToClipboard(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def add_BeforeTextChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.TextBoxBeforeTextChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_BeforeTextChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CharacterCasing = property(get_CharacterCasing, put_CharacterCasing)
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    PlaceholderForeground = property(get_PlaceholderForeground, put_PlaceholderForeground)
    CopyingToClipboard = event()
    CuttingToClipboard = event()
    BeforeTextChanging = event()
class ITextBox7(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBox7'
    _iid_ = Guid('{da4911f9-ffe1-4c6a-ac6d-1b4a174ccf80}')
    @winrt_commethod(6)
    def get_HandwritingView(self) -> win32more.Windows.UI.Xaml.Controls.HandwritingView: ...
    @winrt_commethod(7)
    def put_HandwritingView(self, value: win32more.Windows.UI.Xaml.Controls.HandwritingView) -> Void: ...
    @winrt_commethod(8)
    def get_IsHandwritingViewEnabled(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsHandwritingViewEnabled(self, value: Boolean) -> Void: ...
    HandwritingView = property(get_HandwritingView, put_HandwritingView)
    IsHandwritingViewEnabled = property(get_IsHandwritingViewEnabled, put_IsHandwritingViewEnabled)
class ITextBox8(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBox8'
    _iid_ = Guid('{1eb6d027-0317-5c37-8aea-f747ae7f0463}')
    @winrt_commethod(6)
    def get_CanPasteClipboardContent(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_CanUndo(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_CanRedo(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_SelectionFlyout(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(10)
    def put_SelectionFlyout(self, value: win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_commethod(11)
    def get_ProofingMenuFlyout(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(12)
    def get_Description(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(13)
    def put_Description(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(14)
    def add_SelectionChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.TextBoxSelectionChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_SelectionChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def Undo(self) -> Void: ...
    @winrt_commethod(17)
    def Redo(self) -> Void: ...
    @winrt_commethod(18)
    def PasteFromClipboard(self) -> Void: ...
    @winrt_commethod(19)
    def CopySelectionToClipboard(self) -> Void: ...
    @winrt_commethod(20)
    def CutSelectionToClipboard(self) -> Void: ...
    @winrt_commethod(21)
    def ClearUndoRedoHistory(self) -> Void: ...
    CanPasteClipboardContent = property(get_CanPasteClipboardContent, None)
    CanRedo = property(get_CanRedo, None)
    CanUndo = property(get_CanUndo, None)
    Description = property(get_Description, put_Description)
    ProofingMenuFlyout = property(get_ProofingMenuFlyout, None)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionChanging = event()
class ITextBoxBeforeTextChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBoxBeforeTextChangingEventArgs'
    _iid_ = Guid('{a5541db3-7784-4258-aa83-e4bedd727467}')
    @winrt_commethod(6)
    def get_NewText(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    NewText = property(get_NewText, None)
class ITextBoxFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBoxFactory'
    _iid_ = Guid('{710e4278-8529-47d3-8d8e-307e34cff081}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TextBox: ...
class ITextBoxSelectionChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBoxSelectionChangingEventArgs'
    _iid_ = Guid('{847a24dd-9abe-52df-a80a-0cce4b496632}')
    @winrt_commethod(6)
    def get_SelectionStart(self) -> Int32: ...
    @winrt_commethod(7)
    def get_SelectionLength(self) -> Int32: ...
    @winrt_commethod(8)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    SelectionLength = property(get_SelectionLength, None)
    SelectionStart = property(get_SelectionStart, None)
class ITextBoxStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBoxStatics'
    _iid_ = Guid('{7e37f4fb-a4bc-4625-8838-8eb2a9091283}')
    @winrt_commethod(6)
    def get_TextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_MaxLengthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsReadOnlyProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_AcceptsReturnProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_TextAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_TextWrappingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IsSpellCheckEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_IsTextPredictionEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_InputScopeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AcceptsReturnProperty = property(get_AcceptsReturnProperty, None)
    InputScopeProperty = property(get_InputScopeProperty, None)
    IsReadOnlyProperty = property(get_IsReadOnlyProperty, None)
    IsSpellCheckEnabledProperty = property(get_IsSpellCheckEnabledProperty, None)
    IsTextPredictionEnabledProperty = property(get_IsTextPredictionEnabledProperty, None)
    MaxLengthProperty = property(get_MaxLengthProperty, None)
    TextAlignmentProperty = property(get_TextAlignmentProperty, None)
    TextProperty = property(get_TextProperty, None)
    TextWrappingProperty = property(get_TextWrappingProperty, None)
class ITextBoxStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBoxStatics2'
    _iid_ = Guid('{7592f37d-4e76-4ee4-8e0f-7d6e1a23326b}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PlaceholderTextProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_SelectionHighlightColorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_PreventKeyboardDisplayOnProgrammaticFocusProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsColorFontEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    PreventKeyboardDisplayOnProgrammaticFocusProperty = property(get_PreventKeyboardDisplayOnProgrammaticFocusProperty, None)
    SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
class ITextBoxStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBoxStatics3'
    _iid_ = Guid('{0e1005c0-10b5-40f6-92c2-ce134b0d3457}')
    @winrt_commethod(6)
    def get_DesiredCandidateWindowAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TextReadingOrderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DesiredCandidateWindowAlignmentProperty = property(get_DesiredCandidateWindowAlignmentProperty, None)
    TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
class ITextBoxStatics5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBoxStatics5'
    _iid_ = Guid('{07d04b45-1b2f-4627-82fd-683f197e5a75}')
    @winrt_commethod(6)
    def get_SelectionHighlightColorWhenNotFocusedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SelectionHighlightColorWhenNotFocusedProperty = property(get_SelectionHighlightColorWhenNotFocusedProperty, None)
class ITextBoxStatics6(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBoxStatics6'
    _iid_ = Guid('{dc0d97e7-1cb7-433e-aa4f-9c64c98cdee5}')
    @winrt_commethod(6)
    def get_HorizontalTextAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CharacterCasingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PlaceholderForegroundProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CharacterCasingProperty = property(get_CharacterCasingProperty, None)
    HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
    PlaceholderForegroundProperty = property(get_PlaceholderForegroundProperty, None)
class ITextBoxStatics7(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBoxStatics7'
    _iid_ = Guid('{cd6c6f47-147e-46f8-a4e8-749c49847a3e}')
    @winrt_commethod(6)
    def get_HandwritingViewProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsHandwritingViewEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HandwritingViewProperty = property(get_HandwritingViewProperty, None)
    IsHandwritingViewEnabledProperty = property(get_IsHandwritingViewEnabledProperty, None)
class ITextBoxStatics8(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBoxStatics8'
    _iid_ = Guid('{7f93d7c4-7d88-5f4d-8955-a5ad3848bcb6}')
    @winrt_commethod(6)
    def get_CanPasteClipboardContentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CanUndoProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CanRedoProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_SelectionFlyoutProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_ProofingMenuFlyoutProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_DescriptionProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CanPasteClipboardContentProperty = property(get_CanPasteClipboardContentProperty, None)
    CanRedoProperty = property(get_CanRedoProperty, None)
    CanUndoProperty = property(get_CanUndoProperty, None)
    DescriptionProperty = property(get_DescriptionProperty, None)
    ProofingMenuFlyoutProperty = property(get_ProofingMenuFlyoutProperty, None)
    SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
class ITextBoxTextChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBoxTextChangingEventArgs'
    _iid_ = Guid('{4e6a4b75-43dd-4e33-acbe-2d8796a17927}')
class ITextBoxTextChangingEventArgs2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextBoxTextChangingEventArgs2'
    _iid_ = Guid('{c0723d44-53a6-415f-a981-50dfaf1becbe}')
    @winrt_commethod(6)
    def get_IsContentChanging(self) -> Boolean: ...
    IsContentChanging = property(get_IsContentChanging, None)
class ITextChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextChangedEventArgs'
    _iid_ = Guid('{4dd04f7d-7a11-4b2e-9933-577df39252b6}')
class ITextCommandBarFlyout(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextCommandBarFlyout'
    _iid_ = Guid('{90384f66-cd3d-5325-8f40-59b076463c40}')
class ITextCommandBarFlyoutFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextCommandBarFlyoutFactory'
    _iid_ = Guid('{1b5918d8-b006-5ecd-ab72-6fdb48abc1f4}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TextCommandBarFlyout: ...
class ITextCompositionChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextCompositionChangedEventArgs'
    _iid_ = Guid('{b9c7e0f2-50b7-441d-990c-68553e2e056b}')
    @winrt_commethod(6)
    def get_StartIndex(self) -> Int32: ...
    @winrt_commethod(7)
    def get_Length(self) -> Int32: ...
    Length = property(get_Length, None)
    StartIndex = property(get_StartIndex, None)
class ITextCompositionEndedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextCompositionEndedEventArgs'
    _iid_ = Guid('{46e34db2-77c0-4015-8eb4-92eefdfc5914}')
    @winrt_commethod(6)
    def get_StartIndex(self) -> Int32: ...
    @winrt_commethod(7)
    def get_Length(self) -> Int32: ...
    Length = property(get_Length, None)
    StartIndex = property(get_StartIndex, None)
class ITextCompositionStartedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextCompositionStartedEventArgs'
    _iid_ = Guid('{df22abb2-10cf-491e-91e8-d3cd72d8a0d3}')
    @winrt_commethod(6)
    def get_StartIndex(self) -> Int32: ...
    @winrt_commethod(7)
    def get_Length(self) -> Int32: ...
    Length = property(get_Length, None)
    StartIndex = property(get_StartIndex, None)
class ITextControlCopyingToClipboardEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextControlCopyingToClipboardEventArgs'
    _iid_ = Guid('{e405ef19-d0df-43da-ace6-16f9113868c3}')
    @winrt_commethod(6)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Handled(self, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class ITextControlCuttingToClipboardEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextControlCuttingToClipboardEventArgs'
    _iid_ = Guid('{5f894995-a58d-4cf3-b589-b5e500e06475}')
    @winrt_commethod(6)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Handled(self, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class ITextControlPasteEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITextControlPasteEventArgs'
    _iid_ = Guid('{4bd1d625-221a-477e-bb2c-ad0c1ed125e7}')
    @winrt_commethod(6)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Handled(self, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class ITimePickedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITimePickedEventArgs'
    _iid_ = Guid('{8ad3ff21-5f66-4785-b999-24fef39fb6db}')
    @winrt_commethod(6)
    def get_OldTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def get_NewTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    NewTime = property(get_NewTime, None)
    OldTime = property(get_OldTime, None)
class ITimePicker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITimePicker'
    _iid_ = Guid('{e39099f2-3aff-4792-909e-2d9941ec0357}')
    @winrt_commethod(6)
    def get_Header(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_HeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_ClockIdentifier(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_ClockIdentifier(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_MinuteIncrement(self) -> Int32: ...
    @winrt_commethod(13)
    def put_MinuteIncrement(self, value: Int32) -> Void: ...
    @winrt_commethod(14)
    def get_Time(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(15)
    def put_Time(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(16)
    def add_TimeChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.UI.Xaml.Controls.TimePickerValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_TimeChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ClockIdentifier = property(get_ClockIdentifier, put_ClockIdentifier)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    MinuteIncrement = property(get_MinuteIncrement, put_MinuteIncrement)
    Time = property(get_Time, put_Time)
    TimeChanged = event()
class ITimePicker2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITimePicker2'
    _iid_ = Guid('{0ff0798c-f922-419f-8b3d-23ee7586d48e}')
    @winrt_commethod(6)
    def get_LightDismissOverlayMode(self) -> win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_commethod(7)
    def put_LightDismissOverlayMode(self, value: win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
class ITimePicker3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITimePicker3'
    _iid_ = Guid('{fa6e4f91-ac32-59a4-94da-8b3d64289ed6}')
    @winrt_commethod(6)
    def get_SelectedTime(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    @winrt_commethod(7)
    def put_SelectedTime(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]) -> Void: ...
    @winrt_commethod(8)
    def add_SelectedTimeChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TimePicker, win32more.Windows.UI.Xaml.Controls.TimePickerSelectedValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_SelectedTimeChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    SelectedTime = property(get_SelectedTime, put_SelectedTime)
    SelectedTimeChanged = event()
class ITimePickerFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITimePickerFactory'
    _iid_ = Guid('{553fe413-6cd7-46a9-a97b-a18bdc4b4ca3}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TimePicker: ...
class ITimePickerFlyout(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITimePickerFlyout'
    _iid_ = Guid('{bb739d75-e836-439e-86d5-506d2d18e404}')
    @winrt_commethod(6)
    def get_ClockIdentifier(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_ClockIdentifier(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Time(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(9)
    def put_Time(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(10)
    def get_MinuteIncrement(self) -> Int32: ...
    @winrt_commethod(11)
    def put_MinuteIncrement(self, value: Int32) -> Void: ...
    @winrt_commethod(12)
    def add_TimePicked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TimePickerFlyout, win32more.Windows.UI.Xaml.Controls.TimePickedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_TimePicked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def ShowAtAsync(self, target: win32more.Windows.UI.Xaml.FrameworkElement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]]: ...
    ClockIdentifier = property(get_ClockIdentifier, put_ClockIdentifier)
    MinuteIncrement = property(get_MinuteIncrement, put_MinuteIncrement)
    Time = property(get_Time, put_Time)
    TimePicked = event()
class ITimePickerFlyoutPresenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITimePickerFlyoutPresenter'
    _iid_ = Guid('{c5320638-7a18-40ed-9fd0-4c852c09b24e}')
class ITimePickerFlyoutPresenter2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITimePickerFlyoutPresenter2'
    _iid_ = Guid('{a13b5b68-7ee9-59f7-aad6-6532a8a8c3bf}')
    @winrt_commethod(6)
    def get_IsDefaultShadowEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsDefaultShadowEnabled(self, value: Boolean) -> Void: ...
    IsDefaultShadowEnabled = property(get_IsDefaultShadowEnabled, put_IsDefaultShadowEnabled)
class ITimePickerFlyoutPresenterStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITimePickerFlyoutPresenterStatics2'
    _iid_ = Guid('{aa5f0ddc-f2bb-53f2-a54d-b34acccf51e4}')
    @winrt_commethod(6)
    def get_IsDefaultShadowEnabledProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsDefaultShadowEnabledProperty = property(get_IsDefaultShadowEnabledProperty, None)
class ITimePickerFlyoutStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITimePickerFlyoutStatics'
    _iid_ = Guid('{3f6728ce-2169-4003-b4a8-8de7035a0ad6}')
    @winrt_commethod(6)
    def get_ClockIdentifierProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TimeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_MinuteIncrementProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ClockIdentifierProperty = property(get_ClockIdentifierProperty, None)
    MinuteIncrementProperty = property(get_MinuteIncrementProperty, None)
    TimeProperty = property(get_TimeProperty, None)
class ITimePickerSelectedValueChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITimePickerSelectedValueChangedEventArgs'
    _iid_ = Guid('{6e20fb35-3b9b-5bb6-9888-266524db181e}')
    @winrt_commethod(6)
    def get_OldTime(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    @winrt_commethod(7)
    def get_NewTime(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    NewTime = property(get_NewTime, None)
    OldTime = property(get_OldTime, None)
class ITimePickerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITimePickerStatics'
    _iid_ = Guid('{fa71dfb1-233e-4f31-b8be-a6ea670c25cd}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ClockIdentifierProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_MinuteIncrementProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_TimeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ClockIdentifierProperty = property(get_ClockIdentifierProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    MinuteIncrementProperty = property(get_MinuteIncrementProperty, None)
    TimeProperty = property(get_TimeProperty, None)
class ITimePickerStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITimePickerStatics2'
    _iid_ = Guid('{36d8abcd-4e10-451a-b93b-1a731ea7ee3f}')
    @winrt_commethod(6)
    def get_LightDismissOverlayModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
class ITimePickerStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITimePickerStatics3'
    _iid_ = Guid('{cfef1763-ba87-54d8-82d4-7c6b9734dc9d}')
    @winrt_commethod(6)
    def get_SelectedTimeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SelectedTimeProperty = property(get_SelectedTimeProperty, None)
class ITimePickerValueChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITimePickerValueChangedEventArgs'
    _iid_ = Guid('{2f4edb8d-b995-4e31-8ba9-c4dcdeb21ca3}')
    @winrt_commethod(6)
    def get_OldTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def get_NewTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    NewTime = property(get_NewTime, None)
    OldTime = property(get_OldTime, None)
class IToggleMenuFlyoutItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToggleMenuFlyoutItem'
    _iid_ = Guid('{49841edd-88e9-4663-a701-cd4fd25e398f}')
    @winrt_commethod(6)
    def get_IsChecked(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsChecked(self, value: Boolean) -> Void: ...
    IsChecked = property(get_IsChecked, put_IsChecked)
class IToggleMenuFlyoutItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToggleMenuFlyoutItemFactory'
    _iid_ = Guid('{a151966f-3bf7-46b6-b61c-9b2c1ba68843}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ToggleMenuFlyoutItem: ...
class IToggleMenuFlyoutItemStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToggleMenuFlyoutItemStatics'
    _iid_ = Guid('{16c724fb-6c1a-4852-9258-08c038367907}')
    @winrt_commethod(6)
    def get_IsCheckedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsCheckedProperty = property(get_IsCheckedProperty, None)
class IToggleSplitButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToggleSplitButton'
    _iid_ = Guid('{28981b31-8e78-570c-bebb-685814485ae9}')
    @winrt_commethod(6)
    def get_IsChecked(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsChecked(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def add_IsCheckedChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ToggleSplitButton, win32more.Windows.UI.Xaml.Controls.ToggleSplitButtonIsCheckedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_IsCheckedChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    IsChecked = property(get_IsChecked, put_IsChecked)
    IsCheckedChanged = event()
class IToggleSplitButtonAutomationPeer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToggleSplitButtonAutomationPeer'
    _iid_ = Guid('{538e61de-7d46-5da7-94ab-acede6a12b9e}')
class IToggleSplitButtonAutomationPeerFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToggleSplitButtonAutomationPeerFactory'
    _iid_ = Guid('{9829b0a0-5a30-5eed-a3a3-1472c53b0a66}')
    @winrt_commethod(6)
    def CreateInstance(self, owner: win32more.Windows.UI.Xaml.Controls.ToggleSplitButton, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ToggleSplitButtonAutomationPeer: ...
class IToggleSplitButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToggleSplitButtonFactory'
    _iid_ = Guid('{3fcf073b-e57c-573d-af38-d1b2ad387951}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ToggleSplitButton: ...
class IToggleSplitButtonIsCheckedChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToggleSplitButtonIsCheckedChangedEventArgs'
    _iid_ = Guid('{2138f0cf-5fcd-5dbb-99ae-359483070f6b}')
class IToggleSwitch(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToggleSwitch'
    _iid_ = Guid('{331d8f00-c5f9-46a5-b6c8-ede539304567}')
    @winrt_commethod(6)
    def get_IsOn(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsOn(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Header(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(9)
    def put_Header(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(10)
    def get_HeaderTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(11)
    def put_HeaderTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(12)
    def get_OnContent(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(13)
    def put_OnContent(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(14)
    def get_OnContentTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(15)
    def put_OnContentTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(16)
    def get_OffContent(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(17)
    def put_OffContent(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(18)
    def get_OffContentTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(19)
    def put_OffContentTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(20)
    def get_TemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.ToggleSwitchTemplateSettings: ...
    @winrt_commethod(21)
    def add_Toggled(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(22)
    def remove_Toggled(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsOn = property(get_IsOn, put_IsOn)
    OffContent = property(get_OffContent, put_OffContent)
    OffContentTemplate = property(get_OffContentTemplate, put_OffContentTemplate)
    OnContent = property(get_OnContent, put_OnContent)
    OnContentTemplate = property(get_OnContentTemplate, put_OnContentTemplate)
    TemplateSettings = property(get_TemplateSettings, None)
    Toggled = event()
class IToggleSwitchOverrides(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToggleSwitchOverrides'
    _iid_ = Guid('{bfd07f53-f8ca-4e47-949e-9e80429b3d16}')
    @winrt_commethod(6)
    def OnToggled(self) -> Void: ...
    @winrt_commethod(7)
    def OnOnContentChanged(self, oldContent: win32more.Windows.Win32.System.WinRT.IInspectable, newContent: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def OnOffContentChanged(self, oldContent: win32more.Windows.Win32.System.WinRT.IInspectable, newContent: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(9)
    def OnHeaderChanged(self, oldContent: win32more.Windows.Win32.System.WinRT.IInspectable, newContent: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
class IToggleSwitchStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToggleSwitchStatics'
    _iid_ = Guid('{1d37147f-97df-4226-92ca-ddf453d7fd5a}')
    @winrt_commethod(6)
    def get_IsOnProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_HeaderTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_OnContentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_OnContentTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_OffContentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_OffContentTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IsOnProperty = property(get_IsOnProperty, None)
    OffContentProperty = property(get_OffContentProperty, None)
    OffContentTemplateProperty = property(get_OffContentTemplateProperty, None)
    OnContentProperty = property(get_OnContentProperty, None)
    OnContentTemplateProperty = property(get_OnContentTemplateProperty, None)
class IToolTip(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToolTip'
    _iid_ = Guid('{7de5d75f-4415-429f-b523-699bdb8c30db}')
    @winrt_commethod(6)
    def get_HorizontalOffset(self) -> Double: ...
    @winrt_commethod(7)
    def put_HorizontalOffset(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_IsOpen(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsOpen(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_Placement(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.PlacementMode: ...
    @winrt_commethod(11)
    def put_Placement(self, value: win32more.Windows.UI.Xaml.Controls.Primitives.PlacementMode) -> Void: ...
    @winrt_commethod(12)
    def get_PlacementTarget(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(13)
    def put_PlacementTarget(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(14)
    def get_VerticalOffset(self) -> Double: ...
    @winrt_commethod(15)
    def put_VerticalOffset(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_TemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.Primitives.ToolTipTemplateSettings: ...
    @winrt_commethod(17)
    def add_Closed(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_Closed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(19)
    def add_Opened(self, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(20)
    def remove_Opened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    HorizontalOffset = property(get_HorizontalOffset, put_HorizontalOffset)
    IsOpen = property(get_IsOpen, put_IsOpen)
    Placement = property(get_Placement, put_Placement)
    PlacementTarget = property(get_PlacementTarget, put_PlacementTarget)
    TemplateSettings = property(get_TemplateSettings, None)
    VerticalOffset = property(get_VerticalOffset, put_VerticalOffset)
    Closed = event()
    Opened = event()
class IToolTip2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToolTip2'
    _iid_ = Guid('{2b1ade26-299a-5d54-800b-3bea123b4c20}')
    @winrt_commethod(6)
    def get_PlacementRect(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Rect]: ...
    @winrt_commethod(7)
    def put_PlacementRect(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Rect]) -> Void: ...
    PlacementRect = property(get_PlacementRect, put_PlacementRect)
class IToolTipFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToolTipFactory'
    _iid_ = Guid('{89839403-b538-49e3-a430-3ac037dc6fe0}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ToolTip: ...
class IToolTipService(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToolTipService'
    _iid_ = Guid('{03a55f87-bfcc-4a1e-8fea-98f610832cea}')
class IToolTipServiceStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToolTipServiceStatics'
    _iid_ = Guid('{86e649f8-e245-48aa-a8c8-d1073ed76319}')
    @winrt_commethod(6)
    def get_PlacementProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def GetPlacement(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.Primitives.PlacementMode: ...
    @winrt_commethod(8)
    def SetPlacement(self, element: win32more.Windows.UI.Xaml.DependencyObject, value: win32more.Windows.UI.Xaml.Controls.Primitives.PlacementMode) -> Void: ...
    @winrt_commethod(9)
    def get_PlacementTargetProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def GetPlacementTarget(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(11)
    def SetPlacementTarget(self, element: win32more.Windows.UI.Xaml.DependencyObject, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(12)
    def get_ToolTipProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def GetToolTip(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(14)
    def SetToolTip(self, element: win32more.Windows.UI.Xaml.DependencyObject, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    PlacementProperty = property(get_PlacementProperty, None)
    PlacementTargetProperty = property(get_PlacementTargetProperty, None)
    ToolTipProperty = property(get_ToolTipProperty, None)
class IToolTipStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToolTipStatics'
    _iid_ = Guid('{f00285b8-4ba9-4f4f-86a7-86003813ceb3}')
    @winrt_commethod(6)
    def get_HorizontalOffsetProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsOpenProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PlacementProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PlacementTargetProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_VerticalOffsetProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HorizontalOffsetProperty = property(get_HorizontalOffsetProperty, None)
    IsOpenProperty = property(get_IsOpenProperty, None)
    PlacementProperty = property(get_PlacementProperty, None)
    PlacementTargetProperty = property(get_PlacementTargetProperty, None)
    VerticalOffsetProperty = property(get_VerticalOffsetProperty, None)
class IToolTipStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IToolTipStatics2'
    _iid_ = Guid('{6845e646-9c7f-5011-8a78-7da9d87eb3b6}')
    @winrt_commethod(6)
    def get_PlacementRectProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    PlacementRectProperty = property(get_PlacementRectProperty, None)
class ITreeView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeView'
    _iid_ = Guid('{9353cc5c-dd6e-453c-aedd-0c3ac993978b}')
    @winrt_commethod(6)
    def get_RootNodes(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.TreeViewNode]: ...
    @winrt_commethod(7)
    def get_SelectionMode(self) -> win32more.Windows.UI.Xaml.Controls.TreeViewSelectionMode: ...
    @winrt_commethod(8)
    def put_SelectionMode(self, value: win32more.Windows.UI.Xaml.Controls.TreeViewSelectionMode) -> Void: ...
    @winrt_commethod(9)
    def get_SelectedNodes(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.TreeViewNode]: ...
    @winrt_commethod(10)
    def Expand(self, value: win32more.Windows.UI.Xaml.Controls.TreeViewNode) -> Void: ...
    @winrt_commethod(11)
    def Collapse(self, value: win32more.Windows.UI.Xaml.Controls.TreeViewNode) -> Void: ...
    @winrt_commethod(12)
    def SelectAll(self) -> Void: ...
    @winrt_commethod(13)
    def add_ItemInvoked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TreeView, win32more.Windows.UI.Xaml.Controls.TreeViewItemInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(14)
    def remove_ItemInvoked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(15)
    def add_Expanding(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TreeView, win32more.Windows.UI.Xaml.Controls.TreeViewExpandingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(16)
    def remove_Expanding(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(17)
    def add_Collapsed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TreeView, win32more.Windows.UI.Xaml.Controls.TreeViewCollapsedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_Collapsed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    RootNodes = property(get_RootNodes, None)
    SelectedNodes = property(get_SelectedNodes, None)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    ItemInvoked = event()
    Expanding = event()
    Collapsed = event()
class ITreeView2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeView2'
    _iid_ = Guid('{4f33a2e6-2f29-55d3-a1ab-1f4a863bf960}')
    @winrt_commethod(6)
    def NodeFromContainer(self, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.TreeViewNode: ...
    @winrt_commethod(7)
    def ContainerFromNode(self, node: win32more.Windows.UI.Xaml.Controls.TreeViewNode) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_commethod(8)
    def ItemFromContainer(self, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(9)
    def ContainerFromItem(self, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_commethod(10)
    def get_CanDragItems(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_CanDragItems(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_CanReorderItems(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_CanReorderItems(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_ItemTemplate(self) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_commethod(15)
    def put_ItemTemplate(self, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(16)
    def get_ItemTemplateSelector(self) -> win32more.Windows.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_commethod(17)
    def put_ItemTemplateSelector(self, value: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_commethod(18)
    def get_ItemContainerStyle(self) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_commethod(19)
    def put_ItemContainerStyle(self, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(20)
    def get_ItemContainerStyleSelector(self) -> win32more.Windows.UI.Xaml.Controls.StyleSelector: ...
    @winrt_commethod(21)
    def put_ItemContainerStyleSelector(self, value: win32more.Windows.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_commethod(22)
    def get_ItemContainerTransitions(self) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(23)
    def put_ItemContainerTransitions(self, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_commethod(24)
    def get_ItemsSource(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(25)
    def put_ItemsSource(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(26)
    def add_DragItemsStarting(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TreeView, win32more.Windows.UI.Xaml.Controls.TreeViewDragItemsStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(27)
    def remove_DragItemsStarting(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(28)
    def add_DragItemsCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TreeView, win32more.Windows.UI.Xaml.Controls.TreeViewDragItemsCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(29)
    def remove_DragItemsCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CanDragItems = property(get_CanDragItems, put_CanDragItems)
    CanReorderItems = property(get_CanReorderItems, put_CanReorderItems)
    ItemContainerStyle = property(get_ItemContainerStyle, put_ItemContainerStyle)
    ItemContainerStyleSelector = property(get_ItemContainerStyleSelector, put_ItemContainerStyleSelector)
    ItemContainerTransitions = property(get_ItemContainerTransitions, put_ItemContainerTransitions)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemTemplateSelector = property(get_ItemTemplateSelector, put_ItemTemplateSelector)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    DragItemsStarting = event()
    DragItemsCompleted = event()
class ITreeViewCollapsedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewCollapsedEventArgs'
    _iid_ = Guid('{391db3b0-1e58-4539-9e93-387978f46cce}')
    @winrt_commethod(6)
    def get_Node(self) -> win32more.Windows.UI.Xaml.Controls.TreeViewNode: ...
    Node = property(get_Node, None)
class ITreeViewCollapsedEventArgs2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewCollapsedEventArgs2'
    _iid_ = Guid('{747b2f4f-7b25-56aa-8300-78d83b7ab2db}')
    @winrt_commethod(6)
    def get_Item(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    Item = property(get_Item, None)
class ITreeViewDragItemsCompletedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewDragItemsCompletedEventArgs'
    _iid_ = Guid('{3ca8632c-4311-574e-8ab4-3b7aa5de7a88}')
    @winrt_commethod(6)
    def get_DropResult(self) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation: ...
    @winrt_commethod(7)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    DropResult = property(get_DropResult, None)
    Items = property(get_Items, None)
class ITreeViewDragItemsStartingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewDragItemsStartingEventArgs'
    _iid_ = Guid('{7bdb7ec4-e125-5773-9a3f-6695233d6250}')
    @winrt_commethod(6)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Cancel(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Data(self) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackage: ...
    @winrt_commethod(9)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    Cancel = property(get_Cancel, put_Cancel)
    Data = property(get_Data, None)
    Items = property(get_Items, None)
class ITreeViewExpandingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewExpandingEventArgs'
    _iid_ = Guid('{c5e1fa63-4154-49d2-a21f-c34176605e3a}')
    @winrt_commethod(6)
    def get_Node(self) -> win32more.Windows.UI.Xaml.Controls.TreeViewNode: ...
    Node = property(get_Node, None)
class ITreeViewExpandingEventArgs2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewExpandingEventArgs2'
    _iid_ = Guid('{a12f54c3-87b9-5623-9c74-e6dd443cde18}')
    @winrt_commethod(6)
    def get_Item(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    Item = property(get_Item, None)
class ITreeViewFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewFactory'
    _iid_ = Guid('{cc5267c3-6c69-49ce-b445-753acee7948b}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TreeView: ...
class ITreeViewItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewItem'
    _iid_ = Guid('{4e05d3e6-6167-44e7-9c74-291ddd6df6eb}')
    @winrt_commethod(6)
    def get_GlyphOpacity(self) -> Double: ...
    @winrt_commethod(7)
    def put_GlyphOpacity(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_GlyphBrush(self) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_commethod(9)
    def put_GlyphBrush(self, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(10)
    def get_ExpandedGlyph(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_ExpandedGlyph(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_CollapsedGlyph(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_CollapsedGlyph(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_GlyphSize(self) -> Double: ...
    @winrt_commethod(15)
    def put_GlyphSize(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_IsExpanded(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsExpanded(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_TreeViewItemTemplateSettings(self) -> win32more.Windows.UI.Xaml.Controls.TreeViewItemTemplateSettings: ...
    CollapsedGlyph = property(get_CollapsedGlyph, put_CollapsedGlyph)
    ExpandedGlyph = property(get_ExpandedGlyph, put_ExpandedGlyph)
    GlyphBrush = property(get_GlyphBrush, put_GlyphBrush)
    GlyphOpacity = property(get_GlyphOpacity, put_GlyphOpacity)
    GlyphSize = property(get_GlyphSize, put_GlyphSize)
    IsExpanded = property(get_IsExpanded, put_IsExpanded)
    TreeViewItemTemplateSettings = property(get_TreeViewItemTemplateSettings, None)
class ITreeViewItem2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewItem2'
    _iid_ = Guid('{007baf7f-0493-51b4-879c-458024b34149}')
    @winrt_commethod(6)
    def get_HasUnrealizedChildren(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_HasUnrealizedChildren(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_ItemsSource(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(9)
    def put_ItemsSource(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    HasUnrealizedChildren = property(get_HasUnrealizedChildren, put_HasUnrealizedChildren)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
class ITreeViewItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewItemFactory'
    _iid_ = Guid('{4ea32731-568d-4d0d-adfd-3d8dc5aa5d88}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TreeViewItem: ...
class ITreeViewItemInvokedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewItemInvokedEventArgs'
    _iid_ = Guid('{472ab521-0242-4290-9363-ab4fe704527f}')
    @winrt_commethod(6)
    def get_InvokedItem(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Handled(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Handled(self) -> Boolean: ...
    Handled = property(get_Handled, put_Handled)
    InvokedItem = property(get_InvokedItem, None)
class ITreeViewItemStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewItemStatics'
    _iid_ = Guid('{436795be-7396-46dc-a264-21c56581c5e5}')
    @winrt_commethod(6)
    def get_GlyphOpacityProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_GlyphBrushProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ExpandedGlyphProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_CollapsedGlyphProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_GlyphSizeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsExpandedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_TreeViewItemTemplateSettingsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CollapsedGlyphProperty = property(get_CollapsedGlyphProperty, None)
    ExpandedGlyphProperty = property(get_ExpandedGlyphProperty, None)
    GlyphBrushProperty = property(get_GlyphBrushProperty, None)
    GlyphOpacityProperty = property(get_GlyphOpacityProperty, None)
    GlyphSizeProperty = property(get_GlyphSizeProperty, None)
    IsExpandedProperty = property(get_IsExpandedProperty, None)
    TreeViewItemTemplateSettingsProperty = property(get_TreeViewItemTemplateSettingsProperty, None)
class ITreeViewItemStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewItemStatics2'
    _iid_ = Guid('{a8af82f3-d803-5c25-b48d-ae0e73b16d8e}')
    @winrt_commethod(6)
    def get_HasUnrealizedChildrenProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ItemsSourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HasUnrealizedChildrenProperty = property(get_HasUnrealizedChildrenProperty, None)
    ItemsSourceProperty = property(get_ItemsSourceProperty, None)
class ITreeViewItemTemplateSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewItemTemplateSettings'
    _iid_ = Guid('{ec323744-de31-4936-bfc2-1cb37ba1dc08}')
    @winrt_commethod(6)
    def get_ExpandedGlyphVisibility(self) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_commethod(7)
    def get_CollapsedGlyphVisibility(self) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_commethod(8)
    def get_Indentation(self) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_commethod(9)
    def get_DragItemsCount(self) -> Int32: ...
    CollapsedGlyphVisibility = property(get_CollapsedGlyphVisibility, None)
    DragItemsCount = property(get_DragItemsCount, None)
    ExpandedGlyphVisibility = property(get_ExpandedGlyphVisibility, None)
    Indentation = property(get_Indentation, None)
class ITreeViewItemTemplateSettingsFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewItemTemplateSettingsFactory'
    _iid_ = Guid('{11a1953b-31b7-4f40-8633-02fc614b518c}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TreeViewItemTemplateSettings: ...
class ITreeViewItemTemplateSettingsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewItemTemplateSettingsStatics'
    _iid_ = Guid('{55c720a8-70ed-4c21-93f4-2d79c1a4a5f7}')
    @winrt_commethod(6)
    def get_ExpandedGlyphVisibilityProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CollapsedGlyphVisibilityProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IndentationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_DragItemsCountProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CollapsedGlyphVisibilityProperty = property(get_CollapsedGlyphVisibilityProperty, None)
    DragItemsCountProperty = property(get_DragItemsCountProperty, None)
    ExpandedGlyphVisibilityProperty = property(get_ExpandedGlyphVisibilityProperty, None)
    IndentationProperty = property(get_IndentationProperty, None)
class ITreeViewList(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewList'
    _iid_ = Guid('{0f00a54e-099a-47a5-a942-94692b01f452}')
class ITreeViewListFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewListFactory'
    _iid_ = Guid('{288f6232-41d2-46f7-b1f5-691c625264b7}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TreeViewList: ...
class ITreeViewNode(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewNode'
    _iid_ = Guid('{c04c8ed3-9af2-4e75-a329-7497a110e7a8}')
    @winrt_commethod(6)
    def get_Content(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Content(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_Parent(self) -> win32more.Windows.UI.Xaml.Controls.TreeViewNode: ...
    @winrt_commethod(9)
    def get_IsExpanded(self) -> Boolean: ...
    @winrt_commethod(10)
    def put_IsExpanded(self, value: Boolean) -> Void: ...
    @winrt_commethod(11)
    def get_HasChildren(self) -> Boolean: ...
    @winrt_commethod(12)
    def get_Depth(self) -> Int32: ...
    @winrt_commethod(13)
    def get_HasUnrealizedChildren(self) -> Boolean: ...
    @winrt_commethod(14)
    def put_HasUnrealizedChildren(self, value: Boolean) -> Void: ...
    @winrt_commethod(15)
    def get_Children(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.TreeViewNode]: ...
    Children = property(get_Children, None)
    Content = property(get_Content, put_Content)
    Depth = property(get_Depth, None)
    HasChildren = property(get_HasChildren, None)
    HasUnrealizedChildren = property(get_HasUnrealizedChildren, put_HasUnrealizedChildren)
    IsExpanded = property(get_IsExpanded, put_IsExpanded)
    Parent = property(get_Parent, None)
class ITreeViewNodeFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewNodeFactory'
    _iid_ = Guid('{6ec62d90-aa19-414a-8a45-0a5589a836f7}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TreeViewNode: ...
class ITreeViewNodeStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewNodeStatics'
    _iid_ = Guid('{5d8276fe-e1d1-4b61-9e81-c7fb189a2980}')
    @winrt_commethod(6)
    def get_ContentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_DepthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsExpandedProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_HasChildrenProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ContentProperty = property(get_ContentProperty, None)
    DepthProperty = property(get_DepthProperty, None)
    HasChildrenProperty = property(get_HasChildrenProperty, None)
    IsExpandedProperty = property(get_IsExpandedProperty, None)
class ITreeViewStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewStatics'
    _iid_ = Guid('{ef913e08-83f2-4e16-bfb1-1577b98355f5}')
    @winrt_commethod(6)
    def get_SelectionModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SelectionModeProperty = property(get_SelectionModeProperty, None)
class ITreeViewStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITreeViewStatics2'
    _iid_ = Guid('{16b1c8f9-7aa1-5e38-8218-7bba3ea417c0}')
    @winrt_commethod(6)
    def get_CanDragItemsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CanReorderItemsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ItemTemplateProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_ItemTemplateSelectorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_ItemContainerStyleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_ItemContainerStyleSelectorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ItemContainerTransitionsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_ItemsSourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CanDragItemsProperty = property(get_CanDragItemsProperty, None)
    CanReorderItemsProperty = property(get_CanReorderItemsProperty, None)
    ItemContainerStyleProperty = property(get_ItemContainerStyleProperty, None)
    ItemContainerStyleSelectorProperty = property(get_ItemContainerStyleSelectorProperty, None)
    ItemContainerTransitionsProperty = property(get_ItemContainerTransitionsProperty, None)
    ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    ItemTemplateSelectorProperty = property(get_ItemTemplateSelectorProperty, None)
    ItemsSourceProperty = property(get_ItemsSourceProperty, None)
class ITwoPaneView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITwoPaneView'
    _iid_ = Guid('{1b4d0db5-14ad-5926-bb8a-5b0a5c0085f0}')
    @winrt_commethod(6)
    def get_Pane1(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Pane1(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_Pane2(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(9)
    def put_Pane2(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(10)
    def get_Pane1Length(self) -> win32more.Windows.UI.Xaml.GridLength: ...
    @winrt_commethod(11)
    def put_Pane1Length(self, value: win32more.Windows.UI.Xaml.GridLength) -> Void: ...
    @winrt_commethod(12)
    def get_Pane2Length(self) -> win32more.Windows.UI.Xaml.GridLength: ...
    @winrt_commethod(13)
    def put_Pane2Length(self, value: win32more.Windows.UI.Xaml.GridLength) -> Void: ...
    @winrt_commethod(14)
    def get_PanePriority(self) -> win32more.Windows.UI.Xaml.Controls.TwoPaneViewPriority: ...
    @winrt_commethod(15)
    def put_PanePriority(self, value: win32more.Windows.UI.Xaml.Controls.TwoPaneViewPriority) -> Void: ...
    @winrt_commethod(16)
    def get_Mode(self) -> win32more.Windows.UI.Xaml.Controls.TwoPaneViewMode: ...
    @winrt_commethod(17)
    def get_WideModeConfiguration(self) -> win32more.Windows.UI.Xaml.Controls.TwoPaneViewWideModeConfiguration: ...
    @winrt_commethod(18)
    def put_WideModeConfiguration(self, value: win32more.Windows.UI.Xaml.Controls.TwoPaneViewWideModeConfiguration) -> Void: ...
    @winrt_commethod(19)
    def get_TallModeConfiguration(self) -> win32more.Windows.UI.Xaml.Controls.TwoPaneViewTallModeConfiguration: ...
    @winrt_commethod(20)
    def put_TallModeConfiguration(self, value: win32more.Windows.UI.Xaml.Controls.TwoPaneViewTallModeConfiguration) -> Void: ...
    @winrt_commethod(21)
    def get_MinWideModeWidth(self) -> Double: ...
    @winrt_commethod(22)
    def put_MinWideModeWidth(self, value: Double) -> Void: ...
    @winrt_commethod(23)
    def get_MinTallModeHeight(self) -> Double: ...
    @winrt_commethod(24)
    def put_MinTallModeHeight(self, value: Double) -> Void: ...
    @winrt_commethod(25)
    def add_ModeChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TwoPaneView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(26)
    def remove_ModeChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    MinTallModeHeight = property(get_MinTallModeHeight, put_MinTallModeHeight)
    MinWideModeWidth = property(get_MinWideModeWidth, put_MinWideModeWidth)
    Mode = property(get_Mode, None)
    Pane1 = property(get_Pane1, put_Pane1)
    Pane1Length = property(get_Pane1Length, put_Pane1Length)
    Pane2 = property(get_Pane2, put_Pane2)
    Pane2Length = property(get_Pane2Length, put_Pane2Length)
    PanePriority = property(get_PanePriority, put_PanePriority)
    TallModeConfiguration = property(get_TallModeConfiguration, put_TallModeConfiguration)
    WideModeConfiguration = property(get_WideModeConfiguration, put_WideModeConfiguration)
    ModeChanged = event()
class ITwoPaneViewFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITwoPaneViewFactory'
    _iid_ = Guid('{18ff792d-58b4-59ed-a051-51aceffbcca9}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TwoPaneView: ...
class ITwoPaneViewStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.ITwoPaneViewStatics'
    _iid_ = Guid('{5a35c389-85c4-55f4-abb1-97451bc32d71}')
    @winrt_commethod(6)
    def get_Pane1Property(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_Pane2Property(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_Pane1LengthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_Pane2LengthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_PanePriorityProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_ModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_WideModeConfigurationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_TallModeConfigurationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_MinWideModeWidthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_MinTallModeHeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    MinTallModeHeightProperty = property(get_MinTallModeHeightProperty, None)
    MinWideModeWidthProperty = property(get_MinWideModeWidthProperty, None)
    ModeProperty = property(get_ModeProperty, None)
    Pane1LengthProperty = property(get_Pane1LengthProperty, None)
    Pane1Property = property(get_Pane1Property, None)
    Pane2LengthProperty = property(get_Pane2LengthProperty, None)
    Pane2Property = property(get_Pane2Property, None)
    PanePriorityProperty = property(get_PanePriorityProperty, None)
    TallModeConfigurationProperty = property(get_TallModeConfigurationProperty, None)
    WideModeConfigurationProperty = property(get_WideModeConfigurationProperty, None)
class IUIElementCollection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IUIElementCollection'
    _iid_ = Guid('{d6602d54-88f6-43f6-85d8-a9d914a6dd3b}')
    @winrt_commethod(6)
    def Move(self, oldIndex: UInt32, newIndex: UInt32) -> Void: ...
class IUserControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IUserControl'
    _iid_ = Guid('{a7a69ec9-ea35-4679-bf29-f4f09286d314}')
    @winrt_commethod(6)
    def get_Content(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Content(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    Content = property(get_Content, put_Content)
class IUserControlFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IUserControlFactory'
    _iid_ = Guid('{38b1ed92-a28a-4972-93df-f4f759b8afd2}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.UserControl: ...
class IUserControlStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IUserControlStatics'
    _iid_ = Guid('{e8887976-2c5c-41cf-be6a-9e44befdf655}')
    @winrt_commethod(6)
    def get_ContentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ContentProperty = property(get_ContentProperty, None)
class IVariableSizedWrapGrid(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IVariableSizedWrapGrid'
    _iid_ = Guid('{9ca507c7-23c9-4f01-b80f-be5c21eef474}')
    @winrt_commethod(6)
    def get_ItemHeight(self) -> Double: ...
    @winrt_commethod(7)
    def put_ItemHeight(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_ItemWidth(self) -> Double: ...
    @winrt_commethod(9)
    def put_ItemWidth(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_Orientation(self) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(11)
    def put_Orientation(self, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(12)
    def get_HorizontalChildrenAlignment(self) -> win32more.Windows.UI.Xaml.HorizontalAlignment: ...
    @winrt_commethod(13)
    def put_HorizontalChildrenAlignment(self, value: win32more.Windows.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_commethod(14)
    def get_VerticalChildrenAlignment(self) -> win32more.Windows.UI.Xaml.VerticalAlignment: ...
    @winrt_commethod(15)
    def put_VerticalChildrenAlignment(self, value: win32more.Windows.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_commethod(16)
    def get_MaximumRowsOrColumns(self) -> Int32: ...
    @winrt_commethod(17)
    def put_MaximumRowsOrColumns(self, value: Int32) -> Void: ...
    HorizontalChildrenAlignment = property(get_HorizontalChildrenAlignment, put_HorizontalChildrenAlignment)
    ItemHeight = property(get_ItemHeight, put_ItemHeight)
    ItemWidth = property(get_ItemWidth, put_ItemWidth)
    MaximumRowsOrColumns = property(get_MaximumRowsOrColumns, put_MaximumRowsOrColumns)
    Orientation = property(get_Orientation, put_Orientation)
    VerticalChildrenAlignment = property(get_VerticalChildrenAlignment, put_VerticalChildrenAlignment)
class IVariableSizedWrapGridStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IVariableSizedWrapGridStatics'
    _iid_ = Guid('{fe9db859-8127-4aef-b7a2-949847486e96}')
    @winrt_commethod(6)
    def get_ItemHeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ItemWidthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_OrientationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_HorizontalChildrenAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_VerticalChildrenAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_MaximumRowsOrColumnsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_RowSpanProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def GetRowSpan(self, element: win32more.Windows.UI.Xaml.UIElement) -> Int32: ...
    @winrt_commethod(14)
    def SetRowSpan(self, element: win32more.Windows.UI.Xaml.UIElement, value: Int32) -> Void: ...
    @winrt_commethod(15)
    def get_ColumnSpanProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def GetColumnSpan(self, element: win32more.Windows.UI.Xaml.UIElement) -> Int32: ...
    @winrt_commethod(17)
    def SetColumnSpan(self, element: win32more.Windows.UI.Xaml.UIElement, value: Int32) -> Void: ...
    ColumnSpanProperty = property(get_ColumnSpanProperty, None)
    HorizontalChildrenAlignmentProperty = property(get_HorizontalChildrenAlignmentProperty, None)
    ItemHeightProperty = property(get_ItemHeightProperty, None)
    ItemWidthProperty = property(get_ItemWidthProperty, None)
    MaximumRowsOrColumnsProperty = property(get_MaximumRowsOrColumnsProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
    RowSpanProperty = property(get_RowSpanProperty, None)
    VerticalChildrenAlignmentProperty = property(get_VerticalChildrenAlignmentProperty, None)
class IViewbox(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IViewbox'
    _iid_ = Guid('{05252c58-ba9d-4809-9ec3-fa0d16710ba1}')
    @winrt_commethod(6)
    def get_Child(self) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Child(self, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_Stretch(self) -> win32more.Windows.UI.Xaml.Media.Stretch: ...
    @winrt_commethod(9)
    def put_Stretch(self, value: win32more.Windows.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_commethod(10)
    def get_StretchDirection(self) -> win32more.Windows.UI.Xaml.Controls.StretchDirection: ...
    @winrt_commethod(11)
    def put_StretchDirection(self, value: win32more.Windows.UI.Xaml.Controls.StretchDirection) -> Void: ...
    Child = property(get_Child, put_Child)
    Stretch = property(get_Stretch, put_Stretch)
    StretchDirection = property(get_StretchDirection, put_StretchDirection)
class IViewboxStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IViewboxStatics'
    _iid_ = Guid('{5cd1e72d-e8d3-4865-8f08-b6b2d689adf1}')
    @winrt_commethod(6)
    def get_StretchProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_StretchDirectionProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    StretchDirectionProperty = property(get_StretchDirectionProperty, None)
    StretchProperty = property(get_StretchProperty, None)
class IVirtualizingPanel(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IVirtualizingPanel'
    _iid_ = Guid('{38aad50c-12cf-4d1e-a884-c9df85f07cd9}')
    @winrt_commethod(6)
    def get_ItemContainerGenerator(self) -> win32more.Windows.UI.Xaml.Controls.ItemContainerGenerator: ...
    ItemContainerGenerator = property(get_ItemContainerGenerator, None)
class IVirtualizingPanelFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IVirtualizingPanelFactory'
    _iid_ = Guid('{be19f839-cbd0-43e9-a5d0-0bdba0ffbd38}')
class IVirtualizingPanelOverrides(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IVirtualizingPanelOverrides'
    _iid_ = Guid('{5ef6bd7d-677f-408d-a96c-b19507750466}')
    @winrt_commethod(6)
    def OnItemsChanged(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, args: win32more.Windows.UI.Xaml.Controls.Primitives.ItemsChangedEventArgs) -> Void: ...
    @winrt_commethod(7)
    def OnClearChildren(self) -> Void: ...
    @winrt_commethod(8)
    def BringIndexIntoView(self, index: Int32) -> Void: ...
class IVirtualizingPanelProtected(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IVirtualizingPanelProtected'
    _iid_ = Guid('{c9c9ab42-c232-479d-a7c9-5e7611196a45}')
    @winrt_commethod(6)
    def AddInternalChild(self, child: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(7)
    def InsertInternalChild(self, index: Int32, child: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def RemoveInternalChildRange(self, index: Int32, range: Int32) -> Void: ...
class IVirtualizingStackPanel(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IVirtualizingStackPanel'
    _iid_ = Guid('{7567cd9a-a3b4-4dea-bb11-549e2c2f919d}')
    @winrt_commethod(6)
    def get_AreScrollSnapPointsRegular(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_AreScrollSnapPointsRegular(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Orientation(self) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(9)
    def put_Orientation(self, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(10)
    def add_CleanUpVirtualizedItemEvent(self, handler: win32more.Windows.UI.Xaml.Controls.CleanUpVirtualizedItemEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_CleanUpVirtualizedItemEvent(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AreScrollSnapPointsRegular = property(get_AreScrollSnapPointsRegular, put_AreScrollSnapPointsRegular)
    Orientation = property(get_Orientation, put_Orientation)
    CleanUpVirtualizedItemEvent = event()
class IVirtualizingStackPanelOverrides(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IVirtualizingStackPanelOverrides'
    _iid_ = Guid('{cbe6f72c-2892-46d1-987f-58ca1081f040}')
    @winrt_commethod(6)
    def OnCleanUpVirtualizedItem(self, e: win32more.Windows.UI.Xaml.Controls.CleanUpVirtualizedItemEventArgs) -> Void: ...
class IVirtualizingStackPanelStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IVirtualizingStackPanelStatics'
    _iid_ = Guid('{8314e778-91d3-4d56-ac09-223adcd2bd3f}')
    @winrt_commethod(6)
    def get_AreScrollSnapPointsRegularProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_OrientationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_VirtualizationModeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def GetVirtualizationMode(self, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.VirtualizationMode: ...
    @winrt_commethod(10)
    def SetVirtualizationMode(self, element: win32more.Windows.UI.Xaml.DependencyObject, value: win32more.Windows.UI.Xaml.Controls.VirtualizationMode) -> Void: ...
    @winrt_commethod(11)
    def get_IsVirtualizingProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def GetIsVirtualizing(self, o: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    AreScrollSnapPointsRegularProperty = property(get_AreScrollSnapPointsRegularProperty, None)
    IsVirtualizingProperty = property(get_IsVirtualizingProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
    VirtualizationModeProperty = property(get_VirtualizationModeProperty, None)
class IWebView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebView'
    _iid_ = Guid('{5862cc46-1f7d-479b-92a6-de7858fe8d54}')
    @winrt_commethod(6)
    def get_Source(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def put_Source(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(8)
    def get_AllowedScriptNotifyUris(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Foundation.Uri]: ...
    @winrt_commethod(9)
    def put_AllowedScriptNotifyUris(self, value: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Foundation.Uri]) -> Void: ...
    @winrt_commethod(10)
    def get_DataTransferPackage(self) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackage: ...
    @winrt_commethod(11)
    def add_LoadCompleted(self, handler: win32more.Windows.UI.Xaml.Navigation.LoadCompletedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_LoadCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(13)
    def add_ScriptNotify(self, handler: win32more.Windows.UI.Xaml.Controls.NotifyEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(14)
    def remove_ScriptNotify(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(15)
    def add_NavigationFailed(self, handler: win32more.Windows.UI.Xaml.Controls.WebViewNavigationFailedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(16)
    def remove_NavigationFailed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(17)
    def InvokeScript(self, scriptName: WinRT_String, arguments: PassArray[WinRT_String]) -> WinRT_String: ...
    @winrt_commethod(18)
    def Navigate(self, source: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(19)
    def NavigateToString(self, text: WinRT_String) -> Void: ...
    AllowedScriptNotifyUris = property(get_AllowedScriptNotifyUris, put_AllowedScriptNotifyUris)
    DataTransferPackage = property(get_DataTransferPackage, None)
    Source = property(get_Source, put_Source)
    LoadCompleted = event()
    ScriptNotify = event()
    NavigationFailed = event()
class IWebView2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebView2'
    _iid_ = Guid('{d481759e-3eff-4462-823d-fd52f9ba4cc8}')
    @winrt_commethod(6)
    def get_CanGoBack(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_CanGoForward(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_DocumentTitle(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def add_NavigationStarting(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewNavigationStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_NavigationStarting(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(11)
    def add_ContentLoading(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewContentLoadingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_ContentLoading(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(13)
    def add_DOMContentLoaded(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewDOMContentLoadedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(14)
    def remove_DOMContentLoaded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(15)
    def GoForward(self) -> Void: ...
    @winrt_commethod(16)
    def GoBack(self) -> Void: ...
    @winrt_commethod(17)
    def Refresh(self) -> Void: ...
    @winrt_commethod(18)
    def Stop(self) -> Void: ...
    @winrt_commethod(19)
    def CapturePreviewToStreamAsync(self, stream: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(20)
    def InvokeScriptAsync(self, scriptName: WinRT_String, arguments: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[WinRT_String]: ...
    @winrt_commethod(21)
    def CaptureSelectedContentToDataPackageAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.DataTransfer.DataPackage]: ...
    @winrt_commethod(22)
    def NavigateToLocalStreamUri(self, source: win32more.Windows.Foundation.Uri, streamResolver: win32more.Windows.Web.IUriToStreamResolver) -> Void: ...
    @winrt_commethod(23)
    def BuildLocalStreamUri(self, contentIdentifier: WinRT_String, relativePath: WinRT_String) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(24)
    def get_DefaultBackgroundColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(25)
    def put_DefaultBackgroundColor(self, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(26)
    def add_NavigationCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewNavigationCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(27)
    def remove_NavigationCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(28)
    def add_FrameNavigationStarting(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewNavigationStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(29)
    def remove_FrameNavigationStarting(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(30)
    def add_FrameContentLoading(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewContentLoadingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(31)
    def remove_FrameContentLoading(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(32)
    def add_FrameDOMContentLoaded(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewDOMContentLoadedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(33)
    def remove_FrameDOMContentLoaded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(34)
    def add_FrameNavigationCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewNavigationCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(35)
    def remove_FrameNavigationCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(36)
    def add_LongRunningScriptDetected(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewLongRunningScriptDetectedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(37)
    def remove_LongRunningScriptDetected(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(38)
    def add_UnsafeContentWarningDisplaying(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(39)
    def remove_UnsafeContentWarningDisplaying(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(40)
    def add_UnviewableContentIdentified(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewUnviewableContentIdentifiedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(41)
    def remove_UnviewableContentIdentified(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(42)
    def NavigateWithHttpRequestMessage(self, requestMessage: win32more.Windows.Web.Http.HttpRequestMessage) -> Void: ...
    @winrt_commethod(43)
    def Focus(self, value: win32more.Windows.UI.Xaml.FocusState) -> Boolean: ...
    CanGoBack = property(get_CanGoBack, None)
    CanGoForward = property(get_CanGoForward, None)
    DefaultBackgroundColor = property(get_DefaultBackgroundColor, put_DefaultBackgroundColor)
    DocumentTitle = property(get_DocumentTitle, None)
    NavigationStarting = event()
    ContentLoading = event()
    DOMContentLoaded = event()
    NavigationCompleted = event()
    FrameNavigationStarting = event()
    FrameContentLoading = event()
    FrameDOMContentLoaded = event()
    FrameNavigationCompleted = event()
    LongRunningScriptDetected = event()
    UnsafeContentWarningDisplaying = event()
    UnviewableContentIdentified = event()
class IWebView3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebView3'
    _iid_ = Guid('{c497789b-b499-4d69-b5c2-ae9d5d6d594e}')
    @winrt_commethod(6)
    def get_ContainsFullScreenElement(self) -> Boolean: ...
    @winrt_commethod(7)
    def add_ContainsFullScreenElementChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_ContainsFullScreenElementChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ContainsFullScreenElement = property(get_ContainsFullScreenElement, None)
    ContainsFullScreenElementChanged = event()
class IWebView4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebView4'
    _iid_ = Guid('{e28243bc-67f3-462a-b4e0-3bbf6c3dab0b}')
    @winrt_commethod(6)
    def get_ExecutionMode(self) -> win32more.Windows.UI.Xaml.Controls.WebViewExecutionMode: ...
    @winrt_commethod(7)
    def get_DeferredPermissionRequests(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.WebViewDeferredPermissionRequest]: ...
    @winrt_commethod(8)
    def get_Settings(self) -> win32more.Windows.UI.Xaml.Controls.WebViewSettings: ...
    @winrt_commethod(9)
    def add_UnsupportedUriSchemeIdentified(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewUnsupportedUriSchemeIdentifiedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_UnsupportedUriSchemeIdentified(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(11)
    def add_NewWindowRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewNewWindowRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_NewWindowRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(13)
    def add_PermissionRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewPermissionRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(14)
    def remove_PermissionRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(15)
    def AddWebAllowedObject(self, name: WinRT_String, pObject: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(16)
    def DeferredPermissionRequestById(self, id: UInt32) -> win32more.Windows.UI.Xaml.Controls.WebViewDeferredPermissionRequest: ...
    DeferredPermissionRequests = property(get_DeferredPermissionRequests, None)
    ExecutionMode = property(get_ExecutionMode, None)
    Settings = property(get_Settings, None)
    UnsupportedUriSchemeIdentified = event()
    NewWindowRequested = event()
    PermissionRequested = event()
class IWebView5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebView5'
    _iid_ = Guid('{8c9884a6-2f3b-4a55-a463-8444c2095d00}')
    @winrt_commethod(6)
    def get_XYFocusLeft(self) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_commethod(7)
    def put_XYFocusLeft(self, value: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_commethod(8)
    def get_XYFocusRight(self) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_commethod(9)
    def put_XYFocusRight(self, value: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_commethod(10)
    def get_XYFocusUp(self) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_commethod(11)
    def put_XYFocusUp(self, value: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_commethod(12)
    def get_XYFocusDown(self) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_commethod(13)
    def put_XYFocusDown(self, value: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    XYFocusDown = property(get_XYFocusDown, put_XYFocusDown)
    XYFocusLeft = property(get_XYFocusLeft, put_XYFocusLeft)
    XYFocusRight = property(get_XYFocusRight, put_XYFocusRight)
    XYFocusUp = property(get_XYFocusUp, put_XYFocusUp)
class IWebView6(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebView6'
    _iid_ = Guid('{38ccd942-2536-467c-a211-af359c3b4fda}')
    @winrt_commethod(6)
    def add_SeparateProcessLost(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewSeparateProcessLostEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_SeparateProcessLost(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    SeparateProcessLost = event()
class IWebView7(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebView7'
    _iid_ = Guid('{27707c2b-042f-5353-9021-55cd06585fdf}')
    @winrt_commethod(6)
    def add_WebResourceRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewWebResourceRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_WebResourceRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    WebResourceRequested = event()
class IWebViewBrush(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewBrush'
    _iid_ = Guid('{40e86f75-0cf4-4b72-a4d6-cf5d15780116}')
    @winrt_commethod(6)
    def get_SourceName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_SourceName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def Redraw(self) -> Void: ...
    @winrt_commethod(9)
    def SetSource(self, source: win32more.Windows.UI.Xaml.Controls.WebView) -> Void: ...
    SourceName = property(get_SourceName, put_SourceName)
class IWebViewBrushStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewBrushStatics'
    _iid_ = Guid('{d74daa24-1d05-463e-b028-6baa4420e762}')
    @winrt_commethod(6)
    def get_SourceNameProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SourceNameProperty = property(get_SourceNameProperty, None)
class IWebViewContentLoadingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewContentLoadingEventArgs'
    _iid_ = Guid('{6e2980bb-98b8-413e-8129-971c6f7e4c8a}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    Uri = property(get_Uri, None)
class IWebViewDOMContentLoadedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewDOMContentLoadedEventArgs'
    _iid_ = Guid('{c47eba15-dc6b-4b36-9d80-82fb8817b988}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    Uri = property(get_Uri, None)
class IWebViewDeferredPermissionRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewDeferredPermissionRequest'
    _iid_ = Guid('{a3dcc461-7350-4d3a-8fb9-40eeec2746c2}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_PermissionType(self) -> win32more.Windows.UI.Xaml.Controls.WebViewPermissionType: ...
    @winrt_commethod(8)
    def get_Id(self) -> UInt32: ...
    @winrt_commethod(9)
    def Allow(self) -> Void: ...
    @winrt_commethod(10)
    def Deny(self) -> Void: ...
    Id = property(get_Id, None)
    PermissionType = property(get_PermissionType, None)
    Uri = property(get_Uri, None)
class IWebViewFactory4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewFactory4'
    _iid_ = Guid('{82edac58-ee6a-4c9b-a3a0-9347a7d0ef4c}')
    @winrt_commethod(6)
    def CreateInstanceWithExecutionMode(self, executionMode: win32more.Windows.UI.Xaml.Controls.WebViewExecutionMode) -> win32more.Windows.UI.Xaml.Controls.WebView: ...
class IWebViewLongRunningScriptDetectedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewLongRunningScriptDetectedEventArgs'
    _iid_ = Guid('{f3f020ab-a46c-42b0-9efe-69764d5cffa6}')
    @winrt_commethod(6)
    def get_ExecutionTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def get_StopPageScriptExecution(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_StopPageScriptExecution(self, value: Boolean) -> Void: ...
    ExecutionTime = property(get_ExecutionTime, None)
    StopPageScriptExecution = property(get_StopPageScriptExecution, put_StopPageScriptExecution)
class IWebViewNavigationCompletedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewNavigationCompletedEventArgs'
    _iid_ = Guid('{11e6f20b-eba7-44c0-889b-edeb6a064ddd}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_IsSuccess(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_WebErrorStatus(self) -> win32more.Windows.Web.WebErrorStatus: ...
    IsSuccess = property(get_IsSuccess, None)
    Uri = property(get_Uri, None)
    WebErrorStatus = property(get_WebErrorStatus, None)
class IWebViewNavigationFailedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewNavigationFailedEventArgs'
    _iid_ = Guid('{af09609a-129c-4170-9e9c-e2cdf025dca4}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_WebErrorStatus(self) -> win32more.Windows.Web.WebErrorStatus: ...
    Uri = property(get_Uri, None)
    WebErrorStatus = property(get_WebErrorStatus, None)
class IWebViewNavigationStartingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewNavigationStartingEventArgs'
    _iid_ = Guid('{94cb8668-8367-43d5-91bb-96eba37ec784}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    Uri = property(get_Uri, None)
class IWebViewNewWindowRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewNewWindowRequestedEventArgs'
    _iid_ = Guid('{470fa818-6862-44d9-b3d1-c0696373de35}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_Referrer(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(8)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_Handled(self, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
    Referrer = property(get_Referrer, None)
    Uri = property(get_Uri, None)
class IWebViewPermissionRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewPermissionRequest'
    _iid_ = Guid('{17b76332-66c4-4131-999e-df7de20a8c9c}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_PermissionType(self) -> win32more.Windows.UI.Xaml.Controls.WebViewPermissionType: ...
    @winrt_commethod(8)
    def get_Id(self) -> UInt32: ...
    @winrt_commethod(9)
    def get_State(self) -> win32more.Windows.UI.Xaml.Controls.WebViewPermissionState: ...
    @winrt_commethod(10)
    def Defer(self) -> Void: ...
    @winrt_commethod(11)
    def Allow(self) -> Void: ...
    @winrt_commethod(12)
    def Deny(self) -> Void: ...
    Id = property(get_Id, None)
    PermissionType = property(get_PermissionType, None)
    State = property(get_State, None)
    Uri = property(get_Uri, None)
class IWebViewPermissionRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewPermissionRequestedEventArgs'
    _iid_ = Guid('{dadecfd0-6e1e-473f-b0be-b02404d6a86d}')
    @winrt_commethod(6)
    def get_PermissionRequest(self) -> win32more.Windows.UI.Xaml.Controls.WebViewPermissionRequest: ...
    PermissionRequest = property(get_PermissionRequest, None)
class IWebViewSeparateProcessLostEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewSeparateProcessLostEventArgs'
    _iid_ = Guid('{a405700a-c482-40b5-aaea-e10cfa9f5abe}')
class IWebViewSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewSettings'
    _iid_ = Guid('{1d50ad4d-abf6-4785-8df3-fdebc1270301}')
    @winrt_commethod(6)
    def get_IsJavaScriptEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsJavaScriptEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsIndexedDBEnabled(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsIndexedDBEnabled(self, value: Boolean) -> Void: ...
    IsIndexedDBEnabled = property(get_IsIndexedDBEnabled, put_IsIndexedDBEnabled)
    IsJavaScriptEnabled = property(get_IsJavaScriptEnabled, put_IsJavaScriptEnabled)
class IWebViewStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewStatics'
    _iid_ = Guid('{a0b561de-5fdb-443b-b9f0-5c30f6b7a1f4}')
    @winrt_commethod(6)
    def get_AnyScriptNotifyUri(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Foundation.Uri]: ...
    @winrt_commethod(7)
    def get_SourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_AllowedScriptNotifyUrisProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_DataTransferPackageProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AllowedScriptNotifyUrisProperty = property(get_AllowedScriptNotifyUrisProperty, None)
    AnyScriptNotifyUri = property(get_AnyScriptNotifyUri, None)
    DataTransferPackageProperty = property(get_DataTransferPackageProperty, None)
    SourceProperty = property(get_SourceProperty, None)
class IWebViewStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewStatics2'
    _iid_ = Guid('{322f8780-e812-466b-9e50-8e9fec24018a}')
    @winrt_commethod(6)
    def get_CanGoBackProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CanGoForwardProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DocumentTitleProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_DefaultBackgroundColorProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CanGoBackProperty = property(get_CanGoBackProperty, None)
    CanGoForwardProperty = property(get_CanGoForwardProperty, None)
    DefaultBackgroundColorProperty = property(get_DefaultBackgroundColorProperty, None)
    DocumentTitleProperty = property(get_DocumentTitleProperty, None)
class IWebViewStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewStatics3'
    _iid_ = Guid('{129bef8a-4509-4374-b0d1-a7104d0c3a2f}')
    @winrt_commethod(6)
    def get_ContainsFullScreenElementProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ContainsFullScreenElementProperty = property(get_ContainsFullScreenElementProperty, None)
class IWebViewStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewStatics4'
    _iid_ = Guid('{44b197b0-b746-40f3-9936-4ebbff6b47b8}')
    @winrt_commethod(6)
    def get_DefaultExecutionMode(self) -> win32more.Windows.UI.Xaml.Controls.WebViewExecutionMode: ...
    @winrt_commethod(7)
    def ClearTemporaryWebDataAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    DefaultExecutionMode = property(get_DefaultExecutionMode, None)
class IWebViewStatics5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewStatics5'
    _iid_ = Guid('{08a0b8d1-508a-4db8-97ef-0fa505e19ec2}')
    @winrt_commethod(6)
    def get_XYFocusLeftProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_XYFocusRightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_XYFocusUpProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_XYFocusDownProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    XYFocusDownProperty = property(get_XYFocusDownProperty, None)
    XYFocusLeftProperty = property(get_XYFocusLeftProperty, None)
    XYFocusRightProperty = property(get_XYFocusRightProperty, None)
    XYFocusUpProperty = property(get_XYFocusUpProperty, None)
class IWebViewUnsupportedUriSchemeIdentifiedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewUnsupportedUriSchemeIdentifiedEventArgs'
    _iid_ = Guid('{b9c9e1a7-620f-4895-935d-10fbac6fd29e}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_Handled(self, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
    Uri = property(get_Uri, None)
class IWebViewUnviewableContentIdentifiedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewUnviewableContentIdentifiedEventArgs'
    _iid_ = Guid('{37bc16e1-6062-4678-b20b-6c36ac9c59ac}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_Referrer(self) -> win32more.Windows.Foundation.Uri: ...
    Referrer = property(get_Referrer, None)
    Uri = property(get_Uri, None)
class IWebViewUnviewableContentIdentifiedEventArgs2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewUnviewableContentIdentifiedEventArgs2'
    _iid_ = Guid('{9abe1154-36f0-4268-8d88-121eedf45e6a}')
    @winrt_commethod(6)
    def get_MediaType(self) -> WinRT_String: ...
    MediaType = property(get_MediaType, None)
class IWebViewWebResourceRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWebViewWebResourceRequestedEventArgs'
    _iid_ = Guid('{378d21f6-c77f-5d8b-8f30-93c99df79435}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.Web.Http.HttpRequestMessage: ...
    @winrt_commethod(7)
    def get_Response(self) -> win32more.Windows.Web.Http.HttpResponseMessage: ...
    @winrt_commethod(8)
    def put_Response(self, value: win32more.Windows.Web.Http.HttpResponseMessage) -> Void: ...
    @winrt_commethod(9)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
    Response = property(get_Response, put_Response)
class IWrapGrid(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWrapGrid'
    _iid_ = Guid('{0552178b-7567-47c2-bd5c-ad8394c828ba}')
    @winrt_commethod(6)
    def get_ItemWidth(self) -> Double: ...
    @winrt_commethod(7)
    def put_ItemWidth(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_ItemHeight(self) -> Double: ...
    @winrt_commethod(9)
    def put_ItemHeight(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_Orientation(self) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(11)
    def put_Orientation(self, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(12)
    def get_HorizontalChildrenAlignment(self) -> win32more.Windows.UI.Xaml.HorizontalAlignment: ...
    @winrt_commethod(13)
    def put_HorizontalChildrenAlignment(self, value: win32more.Windows.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_commethod(14)
    def get_VerticalChildrenAlignment(self) -> win32more.Windows.UI.Xaml.VerticalAlignment: ...
    @winrt_commethod(15)
    def put_VerticalChildrenAlignment(self, value: win32more.Windows.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_commethod(16)
    def get_MaximumRowsOrColumns(self) -> Int32: ...
    @winrt_commethod(17)
    def put_MaximumRowsOrColumns(self, value: Int32) -> Void: ...
    HorizontalChildrenAlignment = property(get_HorizontalChildrenAlignment, put_HorizontalChildrenAlignment)
    ItemHeight = property(get_ItemHeight, put_ItemHeight)
    ItemWidth = property(get_ItemWidth, put_ItemWidth)
    MaximumRowsOrColumns = property(get_MaximumRowsOrColumns, put_MaximumRowsOrColumns)
    Orientation = property(get_Orientation, put_Orientation)
    VerticalChildrenAlignment = property(get_VerticalChildrenAlignment, put_VerticalChildrenAlignment)
class IWrapGridStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Controls.IWrapGridStatics'
    _iid_ = Guid('{d04a6b97-13cb-479c-a285-e4e56846c4cb}')
    @winrt_commethod(6)
    def get_ItemWidthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ItemHeightProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_OrientationProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_HorizontalChildrenAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_VerticalChildrenAlignmentProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_MaximumRowsOrColumnsProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HorizontalChildrenAlignmentProperty = property(get_HorizontalChildrenAlignmentProperty, None)
    ItemHeightProperty = property(get_ItemHeightProperty, None)
    ItemWidthProperty = property(get_ItemWidthProperty, None)
    MaximumRowsOrColumnsProperty = property(get_MaximumRowsOrColumnsProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
    VerticalChildrenAlignmentProperty = property(get_VerticalChildrenAlignmentProperty, None)
class _IconElement_Meta_(ComPtr.__class__):
    pass
class IconElement(ComPtr, metaclass=_IconElement_Meta_):
    extends: win32more.Windows.UI.Xaml.FrameworkElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IIconElement
    _classid_ = 'Windows.UI.Xaml.Controls.IconElement'
    @winrt_mixinmethod
    def get_Foreground(self: win32more.Windows.UI.Xaml.Controls.IIconElement) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Foreground(self: win32more.Windows.UI.Xaml.Controls.IIconElement, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_classmethod
    def get_ForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.IIconElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Foreground = property(get_Foreground, put_Foreground)
    _IconElement_Meta_.ForegroundProperty = property(get_ForegroundProperty, None)
class _IconSource_Meta_(ComPtr.__class__):
    pass
class IconSource(ComPtr, metaclass=_IconSource_Meta_):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Controls.IIconSource
    _classid_ = 'Windows.UI.Xaml.Controls.IconSource'
    @winrt_mixinmethod
    def get_Foreground(self: win32more.Windows.UI.Xaml.Controls.IIconSource) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Foreground(self: win32more.Windows.UI.Xaml.Controls.IIconSource, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_classmethod
    def get_ForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.IIconSourceStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Foreground = property(get_Foreground, put_Foreground)
    _IconSource_Meta_.ForegroundProperty = property(get_ForegroundProperty, None)
class _IconSourceElement_Meta_(ComPtr.__class__):
    pass
class IconSourceElement(ComPtr, metaclass=_IconSourceElement_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.IconElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IIconSourceElement
    _classid_ = 'Windows.UI.Xaml.Controls.IconSourceElement'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.IconSourceElement.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IIconSourceElementFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.IconSourceElement: ...
    @winrt_mixinmethod
    def get_IconSource(self: win32more.Windows.UI.Xaml.Controls.IIconSourceElement) -> win32more.Windows.UI.Xaml.Controls.IconSource: ...
    @winrt_mixinmethod
    def put_IconSource(self: win32more.Windows.UI.Xaml.Controls.IIconSourceElement, value: win32more.Windows.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_classmethod
    def get_IconSourceProperty(cls: win32more.Windows.UI.Xaml.Controls.IIconSourceElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IconSource = property(get_IconSource, put_IconSource)
    _IconSourceElement_Meta_.IconSourceProperty = property(get_IconSourceProperty, None)
class _Image_Meta_(ComPtr.__class__):
    pass
class Image(ComPtr, metaclass=_Image_Meta_):
    extends: win32more.Windows.UI.Xaml.FrameworkElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IImage
    _classid_ = 'Windows.UI.Xaml.Controls.Image'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.Image.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.Image: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Windows.UI.Xaml.Controls.IImage) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Windows.UI.Xaml.Controls.IImage, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_Stretch(self: win32more.Windows.UI.Xaml.Controls.IImage) -> win32more.Windows.UI.Xaml.Media.Stretch: ...
    @winrt_mixinmethod
    def put_Stretch(self: win32more.Windows.UI.Xaml.Controls.IImage, value: win32more.Windows.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_mixinmethod
    def get_NineGrid(self: win32more.Windows.UI.Xaml.Controls.IImage) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_NineGrid(self: win32more.Windows.UI.Xaml.Controls.IImage, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_PlayToSource(self: win32more.Windows.UI.Xaml.Controls.IImage) -> win32more.Windows.Media.PlayTo.PlayToSource: ...
    @winrt_mixinmethod
    def add_ImageFailed(self: win32more.Windows.UI.Xaml.Controls.IImage, handler: win32more.Windows.UI.Xaml.ExceptionRoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ImageFailed(self: win32more.Windows.UI.Xaml.Controls.IImage, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ImageOpened(self: win32more.Windows.UI.Xaml.Controls.IImage, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ImageOpened(self: win32more.Windows.UI.Xaml.Controls.IImage, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetAsCastingSource(self: win32more.Windows.UI.Xaml.Controls.IImage2) -> win32more.Windows.Media.Casting.CastingSource: ...
    @winrt_mixinmethod
    def GetAlphaMask(self: win32more.Windows.UI.Xaml.Controls.IImage3) -> win32more.Windows.UI.Composition.CompositionBrush: ...
    @winrt_classmethod
    def get_SourceProperty(cls: win32more.Windows.UI.Xaml.Controls.IImageStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StretchProperty(cls: win32more.Windows.UI.Xaml.Controls.IImageStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_NineGridProperty(cls: win32more.Windows.UI.Xaml.Controls.IImageStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlayToSourceProperty(cls: win32more.Windows.UI.Xaml.Controls.IImageStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    NineGrid = property(get_NineGrid, put_NineGrid)
    PlayToSource = property(get_PlayToSource, None)
    Source = property(get_Source, put_Source)
    Stretch = property(get_Stretch, put_Stretch)
    _Image_Meta_.NineGridProperty = property(get_NineGridProperty, None)
    _Image_Meta_.PlayToSourceProperty = property(get_PlayToSourceProperty, None)
    _Image_Meta_.SourceProperty = property(get_SourceProperty, None)
    _Image_Meta_.StretchProperty = property(get_StretchProperty, None)
    ImageFailed = event()
    ImageOpened = event()
class IncrementalLoadingTrigger(Enum, Int32):
    None_ = 0
    Edge = 1
class InkCanvas(ComPtr):
    extends: win32more.Windows.UI.Xaml.FrameworkElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkCanvas
    _classid_ = 'Windows.UI.Xaml.Controls.InkCanvas'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.InkCanvas.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IInkCanvasFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkCanvas: ...
    @winrt_mixinmethod
    def get_InkPresenter(self: win32more.Windows.UI.Xaml.Controls.IInkCanvas) -> win32more.Windows.UI.Input.Inking.InkPresenter: ...
    InkPresenter = property(get_InkPresenter, None)
class _InkToolbar_Meta_(ComPtr.__class__):
    pass
class InkToolbar(ComPtr, metaclass=_InkToolbar_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbar
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbar'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.InkToolbar.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbar: ...
    @winrt_mixinmethod
    def get_InitialControls(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar) -> win32more.Windows.UI.Xaml.Controls.InkToolbarInitialControls: ...
    @winrt_mixinmethod
    def put_InitialControls(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar, value: win32more.Windows.UI.Xaml.Controls.InkToolbarInitialControls) -> Void: ...
    @winrt_mixinmethod
    def get_Children(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar) -> win32more.Windows.UI.Xaml.DependencyObjectCollection: ...
    @winrt_mixinmethod
    def get_ActiveTool(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar) -> win32more.Windows.UI.Xaml.Controls.InkToolbarToolButton: ...
    @winrt_mixinmethod
    def put_ActiveTool(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar, value: win32more.Windows.UI.Xaml.Controls.InkToolbarToolButton) -> Void: ...
    @winrt_mixinmethod
    def get_InkDrawingAttributes(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar) -> win32more.Windows.UI.Input.Inking.InkDrawingAttributes: ...
    @winrt_mixinmethod
    def get_IsRulerButtonChecked(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsRulerButtonChecked(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TargetInkCanvas(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar) -> win32more.Windows.UI.Xaml.Controls.InkCanvas: ...
    @winrt_mixinmethod
    def put_TargetInkCanvas(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar, value: win32more.Windows.UI.Xaml.Controls.InkCanvas) -> Void: ...
    @winrt_mixinmethod
    def add_ActiveToolChanged(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.InkToolbar, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ActiveToolChanged(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_InkDrawingAttributesChanged(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.InkToolbar, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_InkDrawingAttributesChanged(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_EraseAllClicked(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.InkToolbar, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_EraseAllClicked(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_IsRulerButtonCheckedChanged(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.InkToolbar, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_IsRulerButtonCheckedChanged(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetToolButton(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar, tool: win32more.Windows.UI.Xaml.Controls.InkToolbarTool) -> win32more.Windows.UI.Xaml.Controls.InkToolbarToolButton: ...
    @winrt_mixinmethod
    def GetToggleButton(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar, tool: win32more.Windows.UI.Xaml.Controls.InkToolbarToggle) -> win32more.Windows.UI.Xaml.Controls.InkToolbarToggleButton: ...
    @winrt_mixinmethod
    def get_IsStencilButtonChecked(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsStencilButtonChecked(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ButtonFlyoutPlacement(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar2) -> win32more.Windows.UI.Xaml.Controls.InkToolbarButtonFlyoutPlacement: ...
    @winrt_mixinmethod
    def put_ButtonFlyoutPlacement(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar2, value: win32more.Windows.UI.Xaml.Controls.InkToolbarButtonFlyoutPlacement) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar2) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar2, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def add_IsStencilButtonCheckedChanged(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.InkToolbar, win32more.Windows.UI.Xaml.Controls.InkToolbarIsStencilButtonCheckedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_IsStencilButtonCheckedChanged(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetMenuButton(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar2, menu: win32more.Windows.UI.Xaml.Controls.InkToolbarMenuKind) -> win32more.Windows.UI.Xaml.Controls.InkToolbarMenuButton: ...
    @winrt_mixinmethod
    def get_TargetInkPresenter(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar3) -> win32more.Windows.UI.Input.Inking.InkPresenter: ...
    @winrt_mixinmethod
    def put_TargetInkPresenter(self: win32more.Windows.UI.Xaml.Controls.IInkToolbar3, value: win32more.Windows.UI.Input.Inking.InkPresenter) -> Void: ...
    @winrt_classmethod
    def get_TargetInkPresenterProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsStencilButtonCheckedProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ButtonFlyoutPlacementProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_InitialControlsProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ChildrenProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ActiveToolProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_InkDrawingAttributesProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsRulerButtonCheckedProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TargetInkCanvasProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ActiveTool = property(get_ActiveTool, put_ActiveTool)
    ButtonFlyoutPlacement = property(get_ButtonFlyoutPlacement, put_ButtonFlyoutPlacement)
    Children = property(get_Children, None)
    InitialControls = property(get_InitialControls, put_InitialControls)
    InkDrawingAttributes = property(get_InkDrawingAttributes, None)
    IsRulerButtonChecked = property(get_IsRulerButtonChecked, put_IsRulerButtonChecked)
    IsStencilButtonChecked = property(get_IsStencilButtonChecked, put_IsStencilButtonChecked)
    Orientation = property(get_Orientation, put_Orientation)
    TargetInkCanvas = property(get_TargetInkCanvas, put_TargetInkCanvas)
    TargetInkPresenter = property(get_TargetInkPresenter, put_TargetInkPresenter)
    _InkToolbar_Meta_.ActiveToolProperty = property(get_ActiveToolProperty, None)
    _InkToolbar_Meta_.ButtonFlyoutPlacementProperty = property(get_ButtonFlyoutPlacementProperty, None)
    _InkToolbar_Meta_.ChildrenProperty = property(get_ChildrenProperty, None)
    _InkToolbar_Meta_.InitialControlsProperty = property(get_InitialControlsProperty, None)
    _InkToolbar_Meta_.InkDrawingAttributesProperty = property(get_InkDrawingAttributesProperty, None)
    _InkToolbar_Meta_.IsRulerButtonCheckedProperty = property(get_IsRulerButtonCheckedProperty, None)
    _InkToolbar_Meta_.IsStencilButtonCheckedProperty = property(get_IsStencilButtonCheckedProperty, None)
    _InkToolbar_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _InkToolbar_Meta_.TargetInkCanvasProperty = property(get_TargetInkCanvasProperty, None)
    _InkToolbar_Meta_.TargetInkPresenterProperty = property(get_TargetInkPresenterProperty, None)
    ActiveToolChanged = event()
    InkDrawingAttributesChanged = event()
    EraseAllClicked = event()
    IsRulerButtonCheckedChanged = event()
    IsStencilButtonCheckedChanged = event()
class InkToolbarBallpointPenButton(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.InkToolbarPenButton
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbarBallpointPenButton
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbarBallpointPenButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.InkToolbarBallpointPenButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarBallpointPenButtonFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarBallpointPenButton: ...
class InkToolbarButtonFlyoutPlacement(Enum, Int32):
    Auto = 0
    Top = 1
    Bottom = 2
    Left = 3
    Right = 4
class InkToolbarCustomPen(ComPtr):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomPen
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbarCustomPen'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.InkToolbarCustomPen.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomPenFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarCustomPen: ...
    @winrt_mixinmethod
    def CreateInkDrawingAttributes(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomPen, brush: win32more.Windows.UI.Xaml.Media.Brush, strokeWidth: Double) -> win32more.Windows.UI.Input.Inking.InkDrawingAttributes: ...
    @winrt_mixinmethod
    def CreateInkDrawingAttributesCore(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomPenOverrides, brush: win32more.Windows.UI.Xaml.Media.Brush, strokeWidth: Double) -> win32more.Windows.UI.Input.Inking.InkDrawingAttributes: ...
class _InkToolbarCustomPenButton_Meta_(ComPtr.__class__):
    pass
class InkToolbarCustomPenButton(ComPtr, metaclass=_InkToolbarCustomPenButton_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.InkToolbarPenButton
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomPenButton
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbarCustomPenButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.InkToolbarCustomPenButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomPenButtonFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarCustomPenButton: ...
    @winrt_mixinmethod
    def get_CustomPen(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomPenButton) -> win32more.Windows.UI.Xaml.Controls.InkToolbarCustomPen: ...
    @winrt_mixinmethod
    def put_CustomPen(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomPenButton, value: win32more.Windows.UI.Xaml.Controls.InkToolbarCustomPen) -> Void: ...
    @winrt_mixinmethod
    def get_ConfigurationContent(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomPenButton) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_ConfigurationContent(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomPenButton, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_classmethod
    def get_CustomPenProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomPenButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ConfigurationContentProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomPenButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ConfigurationContent = property(get_ConfigurationContent, put_ConfigurationContent)
    CustomPen = property(get_CustomPen, put_CustomPen)
    _InkToolbarCustomPenButton_Meta_.ConfigurationContentProperty = property(get_ConfigurationContentProperty, None)
    _InkToolbarCustomPenButton_Meta_.CustomPenProperty = property(get_CustomPenProperty, None)
class InkToolbarCustomToggleButton(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.InkToolbarToggleButton
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomToggleButton
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbarCustomToggleButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.InkToolbarCustomToggleButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomToggleButtonFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarCustomToggleButton: ...
class _InkToolbarCustomToolButton_Meta_(ComPtr.__class__):
    pass
class InkToolbarCustomToolButton(ComPtr, metaclass=_InkToolbarCustomToolButton_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.InkToolbarToolButton
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomToolButton
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbarCustomToolButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.InkToolbarCustomToolButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomToolButtonFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarCustomToolButton: ...
    @winrt_mixinmethod
    def get_ConfigurationContent(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomToolButton) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_ConfigurationContent(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomToolButton, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_classmethod
    def get_ConfigurationContentProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarCustomToolButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ConfigurationContent = property(get_ConfigurationContent, put_ConfigurationContent)
    _InkToolbarCustomToolButton_Meta_.ConfigurationContentProperty = property(get_ConfigurationContentProperty, None)
class _InkToolbarEraserButton_Meta_(ComPtr.__class__):
    pass
class InkToolbarEraserButton(ComPtr, metaclass=_InkToolbarEraserButton_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.InkToolbarToolButton
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbarEraserButton
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbarEraserButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.InkToolbarEraserButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarEraserButtonFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarEraserButton: ...
    @winrt_mixinmethod
    def get_IsClearAllVisible(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarEraserButton2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsClearAllVisible(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarEraserButton2, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsClearAllVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarEraserButtonStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsClearAllVisible = property(get_IsClearAllVisible, put_IsClearAllVisible)
    _InkToolbarEraserButton_Meta_.IsClearAllVisibleProperty = property(get_IsClearAllVisibleProperty, None)
class _InkToolbarFlyoutItem_Meta_(ComPtr.__class__):
    pass
class InkToolbarFlyoutItem(ComPtr, metaclass=_InkToolbarFlyoutItem_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.ButtonBase
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbarFlyoutItem
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbarFlyoutItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.InkToolbarFlyoutItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarFlyoutItemFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarFlyoutItem: ...
    @winrt_mixinmethod
    def get_Kind(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarFlyoutItem) -> win32more.Windows.UI.Xaml.Controls.InkToolbarFlyoutItemKind: ...
    @winrt_mixinmethod
    def put_Kind(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarFlyoutItem, value: win32more.Windows.UI.Xaml.Controls.InkToolbarFlyoutItemKind) -> Void: ...
    @winrt_mixinmethod
    def get_IsChecked(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarFlyoutItem) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsChecked(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarFlyoutItem, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_Checked(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarFlyoutItem, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.InkToolbarFlyoutItem, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Checked(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarFlyoutItem, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Unchecked(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarFlyoutItem, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.InkToolbarFlyoutItem, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Unchecked(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarFlyoutItem, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_KindProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarFlyoutItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsCheckedProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarFlyoutItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsChecked = property(get_IsChecked, put_IsChecked)
    Kind = property(get_Kind, put_Kind)
    _InkToolbarFlyoutItem_Meta_.IsCheckedProperty = property(get_IsCheckedProperty, None)
    _InkToolbarFlyoutItem_Meta_.KindProperty = property(get_KindProperty, None)
    Checked = event()
    Unchecked = event()
class InkToolbarFlyoutItemKind(Enum, Int32):
    Simple = 0
    Radio = 1
    Check = 2
    RadioCheck = 3
class InkToolbarHighlighterButton(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.InkToolbarPenButton
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbarHighlighterButton
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbarHighlighterButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.InkToolbarHighlighterButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarHighlighterButtonFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarHighlighterButton: ...
class InkToolbarInitialControls(Enum, Int32):
    All = 0
    None_ = 1
    PensOnly = 2
    AllExceptPens = 3
class InkToolbarIsStencilButtonCheckedChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbarIsStencilButtonCheckedChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbarIsStencilButtonCheckedChangedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.InkToolbarIsStencilButtonCheckedChangedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.InkToolbarIsStencilButtonCheckedChangedEventArgs: ...
    @winrt_mixinmethod
    def get_StencilButton(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarIsStencilButtonCheckedChangedEventArgs) -> win32more.Windows.UI.Xaml.Controls.InkToolbarStencilButton: ...
    @winrt_mixinmethod
    def get_StencilKind(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarIsStencilButtonCheckedChangedEventArgs) -> win32more.Windows.UI.Xaml.Controls.InkToolbarStencilKind: ...
    StencilButton = property(get_StencilButton, None)
    StencilKind = property(get_StencilKind, None)
class _InkToolbarMenuButton_Meta_(ComPtr.__class__):
    pass
class InkToolbarMenuButton(ComPtr, metaclass=_InkToolbarMenuButton_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.ToggleButton
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbarMenuButton
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbarMenuButton'
    @winrt_mixinmethod
    def get_MenuKind(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarMenuButton) -> win32more.Windows.UI.Xaml.Controls.InkToolbarMenuKind: ...
    @winrt_mixinmethod
    def get_IsExtensionGlyphShown(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarMenuButton) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsExtensionGlyphShown(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarMenuButton, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsExtensionGlyphShownProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarMenuButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsExtensionGlyphShown = property(get_IsExtensionGlyphShown, put_IsExtensionGlyphShown)
    MenuKind = property(get_MenuKind, None)
    _InkToolbarMenuButton_Meta_.IsExtensionGlyphShownProperty = property(get_IsExtensionGlyphShownProperty, None)
class InkToolbarMenuKind(Enum, Int32):
    Stencil = 0
class _InkToolbarPenButton_Meta_(ComPtr.__class__):
    pass
class InkToolbarPenButton(ComPtr, metaclass=_InkToolbarPenButton_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.InkToolbarToolButton
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButton
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbarPenButton'
    @winrt_mixinmethod
    def get_Palette(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButton) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Media.Brush]: ...
    @winrt_mixinmethod
    def put_Palette(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButton, value: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Media.Brush]) -> Void: ...
    @winrt_mixinmethod
    def get_MinStrokeWidth(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButton) -> Double: ...
    @winrt_mixinmethod
    def put_MinStrokeWidth(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButton, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_MaxStrokeWidth(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButton) -> Double: ...
    @winrt_mixinmethod
    def put_MaxStrokeWidth(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButton, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedBrush(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButton) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def get_SelectedBrushIndex(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButton) -> Int32: ...
    @winrt_mixinmethod
    def put_SelectedBrushIndex(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButton, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedStrokeWidth(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButton) -> Double: ...
    @winrt_mixinmethod
    def put_SelectedStrokeWidth(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButton, value: Double) -> Void: ...
    @winrt_classmethod
    def get_PaletteProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinStrokeWidthProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxStrokeWidthProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedBrushIndexProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedStrokeWidthProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    MaxStrokeWidth = property(get_MaxStrokeWidth, put_MaxStrokeWidth)
    MinStrokeWidth = property(get_MinStrokeWidth, put_MinStrokeWidth)
    Palette = property(get_Palette, put_Palette)
    SelectedBrush = property(get_SelectedBrush, None)
    SelectedBrushIndex = property(get_SelectedBrushIndex, put_SelectedBrushIndex)
    SelectedStrokeWidth = property(get_SelectedStrokeWidth, put_SelectedStrokeWidth)
    _InkToolbarPenButton_Meta_.MaxStrokeWidthProperty = property(get_MaxStrokeWidthProperty, None)
    _InkToolbarPenButton_Meta_.MinStrokeWidthProperty = property(get_MinStrokeWidthProperty, None)
    _InkToolbarPenButton_Meta_.PaletteProperty = property(get_PaletteProperty, None)
    _InkToolbarPenButton_Meta_.SelectedBrushIndexProperty = property(get_SelectedBrushIndexProperty, None)
    _InkToolbarPenButton_Meta_.SelectedBrushProperty = property(get_SelectedBrushProperty, None)
    _InkToolbarPenButton_Meta_.SelectedStrokeWidthProperty = property(get_SelectedStrokeWidthProperty, None)
class _InkToolbarPenConfigurationControl_Meta_(ComPtr.__class__):
    pass
class InkToolbarPenConfigurationControl(ComPtr, metaclass=_InkToolbarPenConfigurationControl_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenConfigurationControl
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbarPenConfigurationControl'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.InkToolbarPenConfigurationControl.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenConfigurationControlFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarPenConfigurationControl: ...
    @winrt_mixinmethod
    def get_PenButton(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenConfigurationControl) -> win32more.Windows.UI.Xaml.Controls.InkToolbarPenButton: ...
    @winrt_classmethod
    def get_PenButtonProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarPenConfigurationControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    PenButton = property(get_PenButton, None)
    _InkToolbarPenConfigurationControl_Meta_.PenButtonProperty = property(get_PenButtonProperty, None)
class InkToolbarPencilButton(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.InkToolbarPenButton
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbarPencilButton
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbarPencilButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.InkToolbarPencilButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarPencilButtonFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarPencilButton: ...
class _InkToolbarRulerButton_Meta_(ComPtr.__class__):
    pass
class InkToolbarRulerButton(ComPtr, metaclass=_InkToolbarRulerButton_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.InkToolbarToggleButton
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbarRulerButton
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbarRulerButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.InkToolbarRulerButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarRulerButtonFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarRulerButton: ...
    @winrt_mixinmethod
    def get_Ruler(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarRulerButton) -> win32more.Windows.UI.Input.Inking.InkPresenterRuler: ...
    @winrt_classmethod
    def get_RulerProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarRulerButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Ruler = property(get_Ruler, None)
    _InkToolbarRulerButton_Meta_.RulerProperty = property(get_RulerProperty, None)
class _InkToolbarStencilButton_Meta_(ComPtr.__class__):
    pass
class InkToolbarStencilButton(ComPtr, metaclass=_InkToolbarStencilButton_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.InkToolbarMenuButton
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbarStencilButton
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbarStencilButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.InkToolbarStencilButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarStencilButtonFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.InkToolbarStencilButton: ...
    @winrt_mixinmethod
    def get_Ruler(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarStencilButton) -> win32more.Windows.UI.Input.Inking.InkPresenterRuler: ...
    @winrt_mixinmethod
    def get_Protractor(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarStencilButton) -> win32more.Windows.UI.Input.Inking.InkPresenterProtractor: ...
    @winrt_mixinmethod
    def get_SelectedStencil(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarStencilButton) -> win32more.Windows.UI.Xaml.Controls.InkToolbarStencilKind: ...
    @winrt_mixinmethod
    def put_SelectedStencil(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarStencilButton, value: win32more.Windows.UI.Xaml.Controls.InkToolbarStencilKind) -> Void: ...
    @winrt_mixinmethod
    def get_IsRulerItemVisible(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarStencilButton) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsRulerItemVisible(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarStencilButton, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsProtractorItemVisible(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarStencilButton) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsProtractorItemVisible(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarStencilButton, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_RulerProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarStencilButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ProtractorProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarStencilButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedStencilProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarStencilButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsRulerItemVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarStencilButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsProtractorItemVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarStencilButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsProtractorItemVisible = property(get_IsProtractorItemVisible, put_IsProtractorItemVisible)
    IsRulerItemVisible = property(get_IsRulerItemVisible, put_IsRulerItemVisible)
    Protractor = property(get_Protractor, None)
    Ruler = property(get_Ruler, None)
    SelectedStencil = property(get_SelectedStencil, put_SelectedStencil)
    _InkToolbarStencilButton_Meta_.IsProtractorItemVisibleProperty = property(get_IsProtractorItemVisibleProperty, None)
    _InkToolbarStencilButton_Meta_.IsRulerItemVisibleProperty = property(get_IsRulerItemVisibleProperty, None)
    _InkToolbarStencilButton_Meta_.ProtractorProperty = property(get_ProtractorProperty, None)
    _InkToolbarStencilButton_Meta_.RulerProperty = property(get_RulerProperty, None)
    _InkToolbarStencilButton_Meta_.SelectedStencilProperty = property(get_SelectedStencilProperty, None)
class InkToolbarStencilKind(Enum, Int32):
    Ruler = 0
    Protractor = 1
class InkToolbarToggle(Enum, Int32):
    Ruler = 0
    Custom = 1
class InkToolbarToggleButton(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.CheckBox
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbarToggleButton
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbarToggleButton'
    @winrt_mixinmethod
    def get_ToggleKind(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarToggleButton) -> win32more.Windows.UI.Xaml.Controls.InkToolbarToggle: ...
    ToggleKind = property(get_ToggleKind, None)
class InkToolbarTool(Enum, Int32):
    BallpointPen = 0
    Pencil = 1
    Highlighter = 2
    Eraser = 3
    CustomPen = 4
    CustomTool = 5
class _InkToolbarToolButton_Meta_(ComPtr.__class__):
    pass
class InkToolbarToolButton(ComPtr, metaclass=_InkToolbarToolButton_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.RadioButton
    default_interface: win32more.Windows.UI.Xaml.Controls.IInkToolbarToolButton
    _classid_ = 'Windows.UI.Xaml.Controls.InkToolbarToolButton'
    @winrt_mixinmethod
    def get_ToolKind(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarToolButton) -> win32more.Windows.UI.Xaml.Controls.InkToolbarTool: ...
    @winrt_mixinmethod
    def get_IsExtensionGlyphShown(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarToolButton) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsExtensionGlyphShown(self: win32more.Windows.UI.Xaml.Controls.IInkToolbarToolButton, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsExtensionGlyphShownProperty(cls: win32more.Windows.UI.Xaml.Controls.IInkToolbarToolButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsExtensionGlyphShown = property(get_IsExtensionGlyphShown, put_IsExtensionGlyphShown)
    ToolKind = property(get_ToolKind, None)
    _InkToolbarToolButton_Meta_.IsExtensionGlyphShownProperty = property(get_IsExtensionGlyphShownProperty, None)
class IsTextTrimmedChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IIsTextTrimmedChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.IsTextTrimmedChangedEventArgs'
class ItemClickEventArgs(ComPtr):
    extends: win32more.Windows.UI.Xaml.RoutedEventArgs
    default_interface: win32more.Windows.UI.Xaml.Controls.IItemClickEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.ItemClickEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ItemClickEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.ItemClickEventArgs: ...
    @winrt_mixinmethod
    def get_ClickedItem(self: win32more.Windows.UI.Xaml.Controls.IItemClickEventArgs) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    ClickedItem = property(get_ClickedItem, None)
class ItemClickEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3df6d14e-e18a-4a75-9395-627c5f3cd489}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Controls.ItemClickEventArgs) -> Void: ...
class ItemCollection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[win32more.Windows.Win32.System.WinRT.IInspectable]]
    default_interface: win32more.Windows.Foundation.Collections.IObservableVector[win32more.Windows.Win32.System.WinRT.IInspectable]
    _classid_ = 'Windows.UI.Xaml.Controls.ItemCollection'
    @winrt_mixinmethod
    def add_VectorChanged(self: win32more.Windows.Foundation.Collections.IObservableVector[win32more.Windows.Win32.System.WinRT.IInspectable], vhnd: win32more.Windows.Foundation.Collections.VectorChangedEventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_VectorChanged(self: win32more.Windows.Foundation.Collections.IObservableVector[win32more.Windows.Win32.System.WinRT.IInspectable], token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable], index: UInt32) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]) -> UInt32: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable], value: win32more.Windows.Win32.System.WinRT.IInspectable, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def SetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable], index: UInt32, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def InsertAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable], index: UInt32, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def RemoveAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable], index: UInt32) -> Void: ...
    @winrt_mixinmethod
    def Append(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable], value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def RemoveAtEnd(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]) -> Void: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable], startIndex: UInt32, items: FillArray[win32more.Windows.Win32.System.WinRT.IInspectable]) -> UInt32: ...
    @winrt_mixinmethod
    def ReplaceAll(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable], items: PassArray[win32more.Windows.Win32.System.WinRT.IInspectable]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    Size = property(get_Size, None)
    VectorChanged = event()
class ItemContainerGenerator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IItemContainerGenerator
    _classid_ = 'Windows.UI.Xaml.Controls.ItemContainerGenerator'
    @winrt_mixinmethod
    def add_ItemsChanged(self: win32more.Windows.UI.Xaml.Controls.IItemContainerGenerator, handler: win32more.Windows.UI.Xaml.Controls.Primitives.ItemsChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ItemsChanged(self: win32more.Windows.UI.Xaml.Controls.IItemContainerGenerator, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ItemFromContainer(self: win32more.Windows.UI.Xaml.Controls.IItemContainerGenerator, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def ContainerFromItem(self: win32more.Windows.UI.Xaml.Controls.IItemContainerGenerator, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def IndexFromContainer(self: win32more.Windows.UI.Xaml.Controls.IItemContainerGenerator, container: win32more.Windows.UI.Xaml.DependencyObject) -> Int32: ...
    @winrt_mixinmethod
    def ContainerFromIndex(self: win32more.Windows.UI.Xaml.Controls.IItemContainerGenerator, index: Int32) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def GetItemContainerGeneratorForPanel(self: win32more.Windows.UI.Xaml.Controls.IItemContainerGenerator, panel: win32more.Windows.UI.Xaml.Controls.Panel) -> win32more.Windows.UI.Xaml.Controls.ItemContainerGenerator: ...
    @winrt_mixinmethod
    def StartAt(self: win32more.Windows.UI.Xaml.Controls.IItemContainerGenerator, position: win32more.Windows.UI.Xaml.Controls.Primitives.GeneratorPosition, direction: win32more.Windows.UI.Xaml.Controls.Primitives.GeneratorDirection, allowStartAtRealizedItem: Boolean) -> Void: ...
    @winrt_mixinmethod
    def Stop(self: win32more.Windows.UI.Xaml.Controls.IItemContainerGenerator) -> Void: ...
    @winrt_mixinmethod
    def GenerateNext(self: win32more.Windows.UI.Xaml.Controls.IItemContainerGenerator, isNewlyRealized: POINTER(Boolean)) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def PrepareItemContainer(self: win32more.Windows.UI.Xaml.Controls.IItemContainerGenerator, container: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_mixinmethod
    def RemoveAll(self: win32more.Windows.UI.Xaml.Controls.IItemContainerGenerator) -> Void: ...
    @winrt_mixinmethod
    def Remove(self: win32more.Windows.UI.Xaml.Controls.IItemContainerGenerator, position: win32more.Windows.UI.Xaml.Controls.Primitives.GeneratorPosition, count: Int32) -> Void: ...
    @winrt_mixinmethod
    def GeneratorPositionFromIndex(self: win32more.Windows.UI.Xaml.Controls.IItemContainerGenerator, itemIndex: Int32) -> win32more.Windows.UI.Xaml.Controls.Primitives.GeneratorPosition: ...
    @winrt_mixinmethod
    def IndexFromGeneratorPosition(self: win32more.Windows.UI.Xaml.Controls.IItemContainerGenerator, position: win32more.Windows.UI.Xaml.Controls.Primitives.GeneratorPosition) -> Int32: ...
    @winrt_mixinmethod
    def Recycle(self: win32more.Windows.UI.Xaml.Controls.IItemContainerGenerator, position: win32more.Windows.UI.Xaml.Controls.Primitives.GeneratorPosition, count: Int32) -> Void: ...
    ItemsChanged = event()
class _ItemsControl_Meta_(ComPtr.__class__):
    pass
class ItemsControl(ComPtr, metaclass=_ItemsControl_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IItemsControl
    _classid_ = 'Windows.UI.Xaml.Controls.ItemsControl'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ItemsControl.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IItemsControlFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ItemsControl: ...
    @winrt_mixinmethod
    def get_ItemsSource(self: win32more.Windows.UI.Xaml.Controls.IItemsControl) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_ItemsSource(self: win32more.Windows.UI.Xaml.Controls.IItemsControl, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.UI.Xaml.Controls.IItemsControl) -> win32more.Windows.UI.Xaml.Controls.ItemCollection: ...
    @winrt_mixinmethod
    def get_ItemTemplate(self: win32more.Windows.UI.Xaml.Controls.IItemsControl) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_ItemTemplate(self: win32more.Windows.UI.Xaml.Controls.IItemsControl, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_ItemTemplateSelector(self: win32more.Windows.UI.Xaml.Controls.IItemsControl) -> win32more.Windows.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_mixinmethod
    def put_ItemTemplateSelector(self: win32more.Windows.UI.Xaml.Controls.IItemsControl, value: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_mixinmethod
    def get_ItemsPanel(self: win32more.Windows.UI.Xaml.Controls.IItemsControl) -> win32more.Windows.UI.Xaml.Controls.ItemsPanelTemplate: ...
    @winrt_mixinmethod
    def put_ItemsPanel(self: win32more.Windows.UI.Xaml.Controls.IItemsControl, value: win32more.Windows.UI.Xaml.Controls.ItemsPanelTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayMemberPath(self: win32more.Windows.UI.Xaml.Controls.IItemsControl) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayMemberPath(self: win32more.Windows.UI.Xaml.Controls.IItemsControl, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ItemContainerStyle(self: win32more.Windows.UI.Xaml.Controls.IItemsControl) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_ItemContainerStyle(self: win32more.Windows.UI.Xaml.Controls.IItemsControl, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_ItemContainerStyleSelector(self: win32more.Windows.UI.Xaml.Controls.IItemsControl) -> win32more.Windows.UI.Xaml.Controls.StyleSelector: ...
    @winrt_mixinmethod
    def put_ItemContainerStyleSelector(self: win32more.Windows.UI.Xaml.Controls.IItemsControl, value: win32more.Windows.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_mixinmethod
    def get_ItemContainerGenerator(self: win32more.Windows.UI.Xaml.Controls.IItemsControl) -> win32more.Windows.UI.Xaml.Controls.ItemContainerGenerator: ...
    @winrt_mixinmethod
    def get_ItemContainerTransitions(self: win32more.Windows.UI.Xaml.Controls.IItemsControl) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_ItemContainerTransitions(self: win32more.Windows.UI.Xaml.Controls.IItemsControl, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_GroupStyle(self: win32more.Windows.UI.Xaml.Controls.IItemsControl) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Windows.UI.Xaml.Controls.GroupStyle]: ...
    @winrt_mixinmethod
    def get_GroupStyleSelector(self: win32more.Windows.UI.Xaml.Controls.IItemsControl) -> win32more.Windows.UI.Xaml.Controls.GroupStyleSelector: ...
    @winrt_mixinmethod
    def put_GroupStyleSelector(self: win32more.Windows.UI.Xaml.Controls.IItemsControl, value: win32more.Windows.UI.Xaml.Controls.GroupStyleSelector) -> Void: ...
    @winrt_mixinmethod
    def get_IsGrouping(self: win32more.Windows.UI.Xaml.Controls.IItemsControl) -> Boolean: ...
    @winrt_mixinmethod
    def get_ItemsPanelRoot(self: win32more.Windows.UI.Xaml.Controls.IItemsControl2) -> win32more.Windows.UI.Xaml.Controls.Panel: ...
    @winrt_mixinmethod
    def GroupHeaderContainerFromItemContainer(self: win32more.Windows.UI.Xaml.Controls.IItemsControl3, itemContainer: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def IsItemItsOwnContainerOverride(self: win32more.Windows.UI.Xaml.Controls.IItemsControlOverrides, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def GetContainerForItemOverride(self: win32more.Windows.UI.Xaml.Controls.IItemsControlOverrides) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def ClearContainerForItemOverride(self: win32more.Windows.UI.Xaml.Controls.IItemsControlOverrides, element: win32more.Windows.UI.Xaml.DependencyObject, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def PrepareContainerForItemOverride(self: win32more.Windows.UI.Xaml.Controls.IItemsControlOverrides, element: win32more.Windows.UI.Xaml.DependencyObject, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnItemsChanged(self: win32more.Windows.UI.Xaml.Controls.IItemsControlOverrides, e: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnItemContainerStyleChanged(self: win32more.Windows.UI.Xaml.Controls.IItemsControlOverrides, oldItemContainerStyle: win32more.Windows.UI.Xaml.Style, newItemContainerStyle: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def OnItemContainerStyleSelectorChanged(self: win32more.Windows.UI.Xaml.Controls.IItemsControlOverrides, oldItemContainerStyleSelector: win32more.Windows.UI.Xaml.Controls.StyleSelector, newItemContainerStyleSelector: win32more.Windows.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_mixinmethod
    def OnItemTemplateChanged(self: win32more.Windows.UI.Xaml.Controls.IItemsControlOverrides, oldItemTemplate: win32more.Windows.UI.Xaml.DataTemplate, newItemTemplate: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def OnItemTemplateSelectorChanged(self: win32more.Windows.UI.Xaml.Controls.IItemsControlOverrides, oldItemTemplateSelector: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector, newItemTemplateSelector: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_mixinmethod
    def OnGroupStyleSelectorChanged(self: win32more.Windows.UI.Xaml.Controls.IItemsControlOverrides, oldGroupStyleSelector: win32more.Windows.UI.Xaml.Controls.GroupStyleSelector, newGroupStyleSelector: win32more.Windows.UI.Xaml.Controls.GroupStyleSelector) -> Void: ...
    @winrt_mixinmethod
    def ItemFromContainer(self: win32more.Windows.UI.Xaml.Controls.IItemContainerMapping, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def ContainerFromItem(self: win32more.Windows.UI.Xaml.Controls.IItemContainerMapping, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def IndexFromContainer(self: win32more.Windows.UI.Xaml.Controls.IItemContainerMapping, container: win32more.Windows.UI.Xaml.DependencyObject) -> Int32: ...
    @winrt_mixinmethod
    def ContainerFromIndex(self: win32more.Windows.UI.Xaml.Controls.IItemContainerMapping, index: Int32) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_classmethod
    def get_ItemsSourceProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemTemplateSelectorProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemsPanelProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisplayMemberPathProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemContainerStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemContainerStyleSelectorProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemContainerTransitionsProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GroupStyleSelectorProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsGroupingProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetItemsOwner(cls: win32more.Windows.UI.Xaml.Controls.IItemsControlStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.ItemsControl: ...
    @winrt_classmethod
    def ItemsControlFromItemContainer(cls: win32more.Windows.UI.Xaml.Controls.IItemsControlStatics, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.ItemsControl: ...
    DisplayMemberPath = property(get_DisplayMemberPath, put_DisplayMemberPath)
    GroupStyle = property(get_GroupStyle, None)
    GroupStyleSelector = property(get_GroupStyleSelector, put_GroupStyleSelector)
    IsGrouping = property(get_IsGrouping, None)
    ItemContainerGenerator = property(get_ItemContainerGenerator, None)
    ItemContainerStyle = property(get_ItemContainerStyle, put_ItemContainerStyle)
    ItemContainerStyleSelector = property(get_ItemContainerStyleSelector, put_ItemContainerStyleSelector)
    ItemContainerTransitions = property(get_ItemContainerTransitions, put_ItemContainerTransitions)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemTemplateSelector = property(get_ItemTemplateSelector, put_ItemTemplateSelector)
    Items = property(get_Items, None)
    ItemsPanel = property(get_ItemsPanel, put_ItemsPanel)
    ItemsPanelRoot = property(get_ItemsPanelRoot, None)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    _ItemsControl_Meta_.DisplayMemberPathProperty = property(get_DisplayMemberPathProperty, None)
    _ItemsControl_Meta_.GroupStyleSelectorProperty = property(get_GroupStyleSelectorProperty, None)
    _ItemsControl_Meta_.IsGroupingProperty = property(get_IsGroupingProperty, None)
    _ItemsControl_Meta_.ItemContainerStyleProperty = property(get_ItemContainerStyleProperty, None)
    _ItemsControl_Meta_.ItemContainerStyleSelectorProperty = property(get_ItemContainerStyleSelectorProperty, None)
    _ItemsControl_Meta_.ItemContainerTransitionsProperty = property(get_ItemContainerTransitionsProperty, None)
    _ItemsControl_Meta_.ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    _ItemsControl_Meta_.ItemTemplateSelectorProperty = property(get_ItemTemplateSelectorProperty, None)
    _ItemsControl_Meta_.ItemsPanelProperty = property(get_ItemsPanelProperty, None)
    _ItemsControl_Meta_.ItemsSourceProperty = property(get_ItemsSourceProperty, None)
class ItemsPanelTemplate(ComPtr):
    extends: win32more.Windows.UI.Xaml.FrameworkTemplate
    default_interface: win32more.Windows.UI.Xaml.Controls.IItemsPanelTemplate
    _classid_ = 'Windows.UI.Xaml.Controls.ItemsPanelTemplate'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ItemsPanelTemplate.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.ItemsPanelTemplate: ...
class ItemsPickedEventArgs(ComPtr):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Controls.IItemsPickedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.ItemsPickedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ItemsPickedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.ItemsPickedEventArgs: ...
    @winrt_mixinmethod
    def get_AddedItems(self: win32more.Windows.UI.Xaml.Controls.IItemsPickedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def get_RemovedItems(self: win32more.Windows.UI.Xaml.Controls.IItemsPickedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    AddedItems = property(get_AddedItems, None)
    RemovedItems = property(get_RemovedItems, None)
class _ItemsPresenter_Meta_(ComPtr.__class__):
    pass
class ItemsPresenter(ComPtr, metaclass=_ItemsPresenter_Meta_):
    extends: win32more.Windows.UI.Xaml.FrameworkElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IItemsPresenter
    _classid_ = 'Windows.UI.Xaml.Controls.ItemsPresenter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ItemsPresenter.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.ItemsPresenter: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Windows.UI.Xaml.Controls.IItemsPresenter) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Windows.UI.Xaml.Controls.IItemsPresenter, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IItemsPresenter) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IItemsPresenter, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTransitions(self: win32more.Windows.UI.Xaml.Controls.IItemsPresenter) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_HeaderTransitions(self: win32more.Windows.UI.Xaml.Controls.IItemsPresenter, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Windows.UI.Xaml.Controls.IItemsPresenter) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Windows.UI.Xaml.Controls.IItemsPresenter, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_Footer(self: win32more.Windows.UI.Xaml.Controls.IItemsPresenter2) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Footer(self: win32more.Windows.UI.Xaml.Controls.IItemsPresenter2, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_FooterTemplate(self: win32more.Windows.UI.Xaml.Controls.IItemsPresenter2) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_FooterTemplate(self: win32more.Windows.UI.Xaml.Controls.IItemsPresenter2, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_FooterTransitions(self: win32more.Windows.UI.Xaml.Controls.IItemsPresenter2) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_FooterTransitions(self: win32more.Windows.UI.Xaml.Controls.IItemsPresenter2, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_AreHorizontalSnapPointsRegular(self: win32more.Windows.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo) -> Boolean: ...
    @winrt_mixinmethod
    def get_AreVerticalSnapPointsRegular(self: win32more.Windows.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo) -> Boolean: ...
    @winrt_mixinmethod
    def add_HorizontalSnapPointsChanged(self: win32more.Windows.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HorizontalSnapPointsChanged(self: win32more.Windows.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_VerticalSnapPointsChanged(self: win32more.Windows.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_VerticalSnapPointsChanged(self: win32more.Windows.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetIrregularSnapPoints(self: win32more.Windows.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, orientation: win32more.Windows.UI.Xaml.Controls.Orientation, alignment: win32more.Windows.UI.Xaml.Controls.Primitives.SnapPointsAlignment) -> win32more.Windows.Foundation.Collections.IVectorView[Single]: ...
    @winrt_mixinmethod
    def GetRegularSnapPoints(self: win32more.Windows.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, orientation: win32more.Windows.UI.Xaml.Controls.Orientation, alignment: win32more.Windows.UI.Xaml.Controls.Primitives.SnapPointsAlignment, offset: POINTER(Single)) -> Single: ...
    @winrt_classmethod
    def get_FooterProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsPresenterStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FooterTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsPresenterStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FooterTransitionsProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsPresenterStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTransitionsProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AreHorizontalSnapPointsRegular = property(get_AreHorizontalSnapPointsRegular, None)
    AreVerticalSnapPointsRegular = property(get_AreVerticalSnapPointsRegular, None)
    Footer = property(get_Footer, put_Footer)
    FooterTemplate = property(get_FooterTemplate, put_FooterTemplate)
    FooterTransitions = property(get_FooterTransitions, put_FooterTransitions)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HeaderTransitions = property(get_HeaderTransitions, put_HeaderTransitions)
    Padding = property(get_Padding, put_Padding)
    _ItemsPresenter_Meta_.FooterProperty = property(get_FooterProperty, None)
    _ItemsPresenter_Meta_.FooterTemplateProperty = property(get_FooterTemplateProperty, None)
    _ItemsPresenter_Meta_.FooterTransitionsProperty = property(get_FooterTransitionsProperty, None)
    _ItemsPresenter_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _ItemsPresenter_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _ItemsPresenter_Meta_.HeaderTransitionsProperty = property(get_HeaderTransitionsProperty, None)
    _ItemsPresenter_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    HorizontalSnapPointsChanged = event()
    VerticalSnapPointsChanged = event()
class _ItemsStackPanel_Meta_(ComPtr.__class__):
    pass
class ItemsStackPanel(ComPtr, metaclass=_ItemsStackPanel_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Panel
    default_interface: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel
    _classid_ = 'Windows.UI.Xaml.Controls.ItemsStackPanel'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ItemsStackPanel.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.ItemsStackPanel: ...
    @winrt_mixinmethod
    def get_GroupPadding(self: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_GroupPadding(self: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_FirstCacheIndex(self: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel) -> Int32: ...
    @winrt_mixinmethod
    def get_FirstVisibleIndex(self: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel) -> Int32: ...
    @winrt_mixinmethod
    def get_LastVisibleIndex(self: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel) -> Int32: ...
    @winrt_mixinmethod
    def get_LastCacheIndex(self: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel) -> Int32: ...
    @winrt_mixinmethod
    def get_ScrollingDirection(self: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel) -> win32more.Windows.UI.Xaml.Controls.PanelScrollingDirection: ...
    @winrt_mixinmethod
    def get_GroupHeaderPlacement(self: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel) -> win32more.Windows.UI.Xaml.Controls.Primitives.GroupHeaderPlacement: ...
    @winrt_mixinmethod
    def put_GroupHeaderPlacement(self: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel, value: win32more.Windows.UI.Xaml.Controls.Primitives.GroupHeaderPlacement) -> Void: ...
    @winrt_mixinmethod
    def get_ItemsUpdatingScrollMode(self: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel) -> win32more.Windows.UI.Xaml.Controls.ItemsUpdatingScrollMode: ...
    @winrt_mixinmethod
    def put_ItemsUpdatingScrollMode(self: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel, value: win32more.Windows.UI.Xaml.Controls.ItemsUpdatingScrollMode) -> Void: ...
    @winrt_mixinmethod
    def get_CacheLength(self: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel) -> Double: ...
    @winrt_mixinmethod
    def put_CacheLength(self: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_AreStickyGroupHeadersEnabled(self: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel2) -> Boolean: ...
    @winrt_mixinmethod
    def put_AreStickyGroupHeadersEnabled(self: win32more.Windows.UI.Xaml.Controls.IItemsStackPanel2, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_AreStickyGroupHeadersEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsStackPanelStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GroupPaddingProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsStackPanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsStackPanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GroupHeaderPlacementProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsStackPanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CacheLengthProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsStackPanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AreStickyGroupHeadersEnabled = property(get_AreStickyGroupHeadersEnabled, put_AreStickyGroupHeadersEnabled)
    CacheLength = property(get_CacheLength, put_CacheLength)
    FirstCacheIndex = property(get_FirstCacheIndex, None)
    FirstVisibleIndex = property(get_FirstVisibleIndex, None)
    GroupHeaderPlacement = property(get_GroupHeaderPlacement, put_GroupHeaderPlacement)
    GroupPadding = property(get_GroupPadding, put_GroupPadding)
    ItemsUpdatingScrollMode = property(get_ItemsUpdatingScrollMode, put_ItemsUpdatingScrollMode)
    LastCacheIndex = property(get_LastCacheIndex, None)
    LastVisibleIndex = property(get_LastVisibleIndex, None)
    Orientation = property(get_Orientation, put_Orientation)
    ScrollingDirection = property(get_ScrollingDirection, None)
    _ItemsStackPanel_Meta_.AreStickyGroupHeadersEnabledProperty = property(get_AreStickyGroupHeadersEnabledProperty, None)
    _ItemsStackPanel_Meta_.CacheLengthProperty = property(get_CacheLengthProperty, None)
    _ItemsStackPanel_Meta_.GroupHeaderPlacementProperty = property(get_GroupHeaderPlacementProperty, None)
    _ItemsStackPanel_Meta_.GroupPaddingProperty = property(get_GroupPaddingProperty, None)
    _ItemsStackPanel_Meta_.OrientationProperty = property(get_OrientationProperty, None)
class ItemsUpdatingScrollMode(Enum, Int32):
    KeepItemsInView = 0
    KeepScrollOffset = 1
    KeepLastItemInView = 2
class _ItemsWrapGrid_Meta_(ComPtr.__class__):
    pass
class ItemsWrapGrid(ComPtr, metaclass=_ItemsWrapGrid_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Panel
    default_interface: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid
    _classid_ = 'Windows.UI.Xaml.Controls.ItemsWrapGrid'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ItemsWrapGrid.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.ItemsWrapGrid: ...
    @winrt_mixinmethod
    def get_GroupPadding(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_GroupPadding(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_MaximumRowsOrColumns(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid) -> Int32: ...
    @winrt_mixinmethod
    def put_MaximumRowsOrColumns(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_ItemWidth(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid) -> Double: ...
    @winrt_mixinmethod
    def put_ItemWidth(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ItemHeight(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid) -> Double: ...
    @winrt_mixinmethod
    def put_ItemHeight(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FirstCacheIndex(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid) -> Int32: ...
    @winrt_mixinmethod
    def get_FirstVisibleIndex(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid) -> Int32: ...
    @winrt_mixinmethod
    def get_LastVisibleIndex(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid) -> Int32: ...
    @winrt_mixinmethod
    def get_LastCacheIndex(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid) -> Int32: ...
    @winrt_mixinmethod
    def get_ScrollingDirection(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid) -> win32more.Windows.UI.Xaml.Controls.PanelScrollingDirection: ...
    @winrt_mixinmethod
    def get_GroupHeaderPlacement(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid) -> win32more.Windows.UI.Xaml.Controls.Primitives.GroupHeaderPlacement: ...
    @winrt_mixinmethod
    def put_GroupHeaderPlacement(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid, value: win32more.Windows.UI.Xaml.Controls.Primitives.GroupHeaderPlacement) -> Void: ...
    @winrt_mixinmethod
    def get_CacheLength(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid) -> Double: ...
    @winrt_mixinmethod
    def put_CacheLength(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_AreStickyGroupHeadersEnabled(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid2) -> Boolean: ...
    @winrt_mixinmethod
    def put_AreStickyGroupHeadersEnabled(self: win32more.Windows.UI.Xaml.Controls.IItemsWrapGrid2, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_AreStickyGroupHeadersEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsWrapGridStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GroupPaddingProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaximumRowsOrColumnsProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemWidthProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemHeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GroupHeaderPlacementProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CacheLengthProperty(cls: win32more.Windows.UI.Xaml.Controls.IItemsWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AreStickyGroupHeadersEnabled = property(get_AreStickyGroupHeadersEnabled, put_AreStickyGroupHeadersEnabled)
    CacheLength = property(get_CacheLength, put_CacheLength)
    FirstCacheIndex = property(get_FirstCacheIndex, None)
    FirstVisibleIndex = property(get_FirstVisibleIndex, None)
    GroupHeaderPlacement = property(get_GroupHeaderPlacement, put_GroupHeaderPlacement)
    GroupPadding = property(get_GroupPadding, put_GroupPadding)
    ItemHeight = property(get_ItemHeight, put_ItemHeight)
    ItemWidth = property(get_ItemWidth, put_ItemWidth)
    LastCacheIndex = property(get_LastCacheIndex, None)
    LastVisibleIndex = property(get_LastVisibleIndex, None)
    MaximumRowsOrColumns = property(get_MaximumRowsOrColumns, put_MaximumRowsOrColumns)
    Orientation = property(get_Orientation, put_Orientation)
    ScrollingDirection = property(get_ScrollingDirection, None)
    _ItemsWrapGrid_Meta_.AreStickyGroupHeadersEnabledProperty = property(get_AreStickyGroupHeadersEnabledProperty, None)
    _ItemsWrapGrid_Meta_.CacheLengthProperty = property(get_CacheLengthProperty, None)
    _ItemsWrapGrid_Meta_.GroupHeaderPlacementProperty = property(get_GroupHeaderPlacementProperty, None)
    _ItemsWrapGrid_Meta_.GroupPaddingProperty = property(get_GroupPaddingProperty, None)
    _ItemsWrapGrid_Meta_.ItemHeightProperty = property(get_ItemHeightProperty, None)
    _ItemsWrapGrid_Meta_.ItemWidthProperty = property(get_ItemWidthProperty, None)
    _ItemsWrapGrid_Meta_.MaximumRowsOrColumnsProperty = property(get_MaximumRowsOrColumnsProperty, None)
    _ItemsWrapGrid_Meta_.OrientationProperty = property(get_OrientationProperty, None)
class LightDismissOverlayMode(Enum, Int32):
    Auto = 0
    On = 1
    Off = 2
class _ListBox_Meta_(ComPtr.__class__):
    pass
class ListBox(ComPtr, metaclass=_ListBox_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.Selector
    default_interface: win32more.Windows.UI.Xaml.Controls.IListBox
    _classid_ = 'Windows.UI.Xaml.Controls.ListBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ListBox.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IListBoxFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ListBox: ...
    @winrt_mixinmethod
    def get_SelectedItems(self: win32more.Windows.UI.Xaml.Controls.IListBox) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def get_SelectionMode(self: win32more.Windows.UI.Xaml.Controls.IListBox) -> win32more.Windows.UI.Xaml.Controls.SelectionMode: ...
    @winrt_mixinmethod
    def put_SelectionMode(self: win32more.Windows.UI.Xaml.Controls.IListBox, value: win32more.Windows.UI.Xaml.Controls.SelectionMode) -> Void: ...
    @winrt_mixinmethod
    def ScrollIntoView(self: win32more.Windows.UI.Xaml.Controls.IListBox, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def SelectAll(self: win32more.Windows.UI.Xaml.Controls.IListBox) -> Void: ...
    @winrt_mixinmethod
    def get_SingleSelectionFollowsFocus(self: win32more.Windows.UI.Xaml.Controls.IListBox2) -> Boolean: ...
    @winrt_mixinmethod
    def put_SingleSelectionFollowsFocus(self: win32more.Windows.UI.Xaml.Controls.IListBox2, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_SingleSelectionFollowsFocusProperty(cls: win32more.Windows.UI.Xaml.Controls.IListBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IListBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SelectedItems = property(get_SelectedItems, None)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    SingleSelectionFollowsFocus = property(get_SingleSelectionFollowsFocus, put_SingleSelectionFollowsFocus)
    _ListBox_Meta_.SelectionModeProperty = property(get_SelectionModeProperty, None)
    _ListBox_Meta_.SingleSelectionFollowsFocusProperty = property(get_SingleSelectionFollowsFocusProperty, None)
class ListBoxItem(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.SelectorItem
    default_interface: win32more.Windows.UI.Xaml.Controls.IListBoxItem
    _classid_ = 'Windows.UI.Xaml.Controls.ListBoxItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ListBoxItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IListBoxItemFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ListBoxItem: ...
class _ListPickerFlyout_Meta_(ComPtr.__class__):
    pass
class ListPickerFlyout(ComPtr, metaclass=_ListPickerFlyout_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.PickerFlyoutBase
    default_interface: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout
    _classid_ = 'Windows.UI.Xaml.Controls.ListPickerFlyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ListPickerFlyout.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.ListPickerFlyout: ...
    @winrt_mixinmethod
    def get_ItemsSource(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_ItemsSource(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_ItemTemplate(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_ItemTemplate(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayMemberPath(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayMemberPath(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionMode(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout) -> win32more.Windows.UI.Xaml.Controls.ListPickerFlyoutSelectionMode: ...
    @winrt_mixinmethod
    def put_SelectionMode(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout, value: win32more.Windows.UI.Xaml.Controls.ListPickerFlyoutSelectionMode) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedIndex(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout) -> Int32: ...
    @winrt_mixinmethod
    def put_SelectedIndex(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedItem(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_SelectedItem(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedValue(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_SelectedValue(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedValuePath(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SelectedValuePath(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedItems(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def add_ItemsPicked(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ListPickerFlyout, win32more.Windows.UI.Xaml.Controls.ItemsPickedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ItemsPicked(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ShowAtAsync(self: win32more.Windows.UI.Xaml.Controls.IListPickerFlyout, target: win32more.Windows.UI.Xaml.FrameworkElement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]]: ...
    @winrt_classmethod
    def get_ItemsSourceProperty(cls: win32more.Windows.UI.Xaml.Controls.IListPickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IListPickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisplayMemberPathProperty(cls: win32more.Windows.UI.Xaml.Controls.IListPickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IListPickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedIndexProperty(cls: win32more.Windows.UI.Xaml.Controls.IListPickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedItemProperty(cls: win32more.Windows.UI.Xaml.Controls.IListPickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedValueProperty(cls: win32more.Windows.UI.Xaml.Controls.IListPickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedValuePathProperty(cls: win32more.Windows.UI.Xaml.Controls.IListPickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DisplayMemberPath = property(get_DisplayMemberPath, put_DisplayMemberPath)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    SelectedIndex = property(get_SelectedIndex, put_SelectedIndex)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    SelectedItems = property(get_SelectedItems, None)
    SelectedValue = property(get_SelectedValue, put_SelectedValue)
    SelectedValuePath = property(get_SelectedValuePath, put_SelectedValuePath)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    _ListPickerFlyout_Meta_.DisplayMemberPathProperty = property(get_DisplayMemberPathProperty, None)
    _ListPickerFlyout_Meta_.ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    _ListPickerFlyout_Meta_.ItemsSourceProperty = property(get_ItemsSourceProperty, None)
    _ListPickerFlyout_Meta_.SelectedIndexProperty = property(get_SelectedIndexProperty, None)
    _ListPickerFlyout_Meta_.SelectedItemProperty = property(get_SelectedItemProperty, None)
    _ListPickerFlyout_Meta_.SelectedValuePathProperty = property(get_SelectedValuePathProperty, None)
    _ListPickerFlyout_Meta_.SelectedValueProperty = property(get_SelectedValueProperty, None)
    _ListPickerFlyout_Meta_.SelectionModeProperty = property(get_SelectionModeProperty, None)
    ItemsPicked = event()
class ListPickerFlyoutPresenter(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IListPickerFlyoutPresenter
    _classid_ = 'Windows.UI.Xaml.Controls.ListPickerFlyoutPresenter'
class ListPickerFlyoutSelectionMode(Enum, Int32):
    Single = 0
    Multiple = 1
class ListView(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.ListViewBase
    default_interface: win32more.Windows.UI.Xaml.Controls.IListView
    _classid_ = 'Windows.UI.Xaml.Controls.ListView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ListView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IListViewFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ListView: ...
class _ListViewBase_Meta_(ComPtr.__class__):
    pass
class ListViewBase(ComPtr, metaclass=_ListViewBase_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.Selector
    default_interface: win32more.Windows.UI.Xaml.Controls.IListViewBase
    _classid_ = 'Windows.UI.Xaml.Controls.ListViewBase'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ListViewBase.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ListViewBase: ...
    @winrt_mixinmethod
    def get_SelectedItems(self: win32more.Windows.UI.Xaml.Controls.IListViewBase) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def get_SelectionMode(self: win32more.Windows.UI.Xaml.Controls.IListViewBase) -> win32more.Windows.UI.Xaml.Controls.ListViewSelectionMode: ...
    @winrt_mixinmethod
    def put_SelectionMode(self: win32more.Windows.UI.Xaml.Controls.IListViewBase, value: win32more.Windows.UI.Xaml.Controls.ListViewSelectionMode) -> Void: ...
    @winrt_mixinmethod
    def get_IsSwipeEnabled(self: win32more.Windows.UI.Xaml.Controls.IListViewBase) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSwipeEnabled(self: win32more.Windows.UI.Xaml.Controls.IListViewBase, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CanDragItems(self: win32more.Windows.UI.Xaml.Controls.IListViewBase) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanDragItems(self: win32more.Windows.UI.Xaml.Controls.IListViewBase, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CanReorderItems(self: win32more.Windows.UI.Xaml.Controls.IListViewBase) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanReorderItems(self: win32more.Windows.UI.Xaml.Controls.IListViewBase, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsItemClickEnabled(self: win32more.Windows.UI.Xaml.Controls.IListViewBase) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsItemClickEnabled(self: win32more.Windows.UI.Xaml.Controls.IListViewBase, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_DataFetchSize(self: win32more.Windows.UI.Xaml.Controls.IListViewBase) -> Double: ...
    @winrt_mixinmethod
    def put_DataFetchSize(self: win32more.Windows.UI.Xaml.Controls.IListViewBase, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_IncrementalLoadingThreshold(self: win32more.Windows.UI.Xaml.Controls.IListViewBase) -> Double: ...
    @winrt_mixinmethod
    def put_IncrementalLoadingThreshold(self: win32more.Windows.UI.Xaml.Controls.IListViewBase, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_IncrementalLoadingTrigger(self: win32more.Windows.UI.Xaml.Controls.IListViewBase) -> win32more.Windows.UI.Xaml.Controls.IncrementalLoadingTrigger: ...
    @winrt_mixinmethod
    def put_IncrementalLoadingTrigger(self: win32more.Windows.UI.Xaml.Controls.IListViewBase, value: win32more.Windows.UI.Xaml.Controls.IncrementalLoadingTrigger) -> Void: ...
    @winrt_mixinmethod
    def add_ItemClick(self: win32more.Windows.UI.Xaml.Controls.IListViewBase, handler: win32more.Windows.UI.Xaml.Controls.ItemClickEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ItemClick(self: win32more.Windows.UI.Xaml.Controls.IListViewBase, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DragItemsStarting(self: win32more.Windows.UI.Xaml.Controls.IListViewBase, handler: win32more.Windows.UI.Xaml.Controls.DragItemsStartingEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DragItemsStarting(self: win32more.Windows.UI.Xaml.Controls.IListViewBase, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ScrollIntoView(self: win32more.Windows.UI.Xaml.Controls.IListViewBase, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def SelectAll(self: win32more.Windows.UI.Xaml.Controls.IListViewBase) -> Void: ...
    @winrt_mixinmethod
    def LoadMoreItemsAsync(self: win32more.Windows.UI.Xaml.Controls.IListViewBase) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.UI.Xaml.Data.LoadMoreItemsResult]: ...
    @winrt_mixinmethod
    def ScrollIntoViewWithAlignment(self: win32more.Windows.UI.Xaml.Controls.IListViewBase, item: win32more.Windows.Win32.System.WinRT.IInspectable, alignment: win32more.Windows.UI.Xaml.Controls.ScrollIntoViewAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Windows.UI.Xaml.Controls.IListViewBase) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Windows.UI.Xaml.Controls.IListViewBase, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IListViewBase) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IListViewBase, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTransitions(self: win32more.Windows.UI.Xaml.Controls.IListViewBase) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_HeaderTransitions(self: win32more.Windows.UI.Xaml.Controls.IListViewBase, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_ShowsScrollingPlaceholders(self: win32more.Windows.UI.Xaml.Controls.IListViewBase2) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShowsScrollingPlaceholders(self: win32more.Windows.UI.Xaml.Controls.IListViewBase2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_ContainerContentChanging(self: win32more.Windows.UI.Xaml.Controls.IListViewBase2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ListViewBase, win32more.Windows.UI.Xaml.Controls.ContainerContentChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContainerContentChanging(self: win32more.Windows.UI.Xaml.Controls.IListViewBase2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def SetDesiredContainerUpdateDuration(self: win32more.Windows.UI.Xaml.Controls.IListViewBase2, duration: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_Footer(self: win32more.Windows.UI.Xaml.Controls.IListViewBase2) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Footer(self: win32more.Windows.UI.Xaml.Controls.IListViewBase2, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_FooterTemplate(self: win32more.Windows.UI.Xaml.Controls.IListViewBase2) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_FooterTemplate(self: win32more.Windows.UI.Xaml.Controls.IListViewBase2, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_FooterTransitions(self: win32more.Windows.UI.Xaml.Controls.IListViewBase2) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_FooterTransitions(self: win32more.Windows.UI.Xaml.Controls.IListViewBase2, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_ReorderMode(self: win32more.Windows.UI.Xaml.Controls.IListViewBase3) -> win32more.Windows.UI.Xaml.Controls.ListViewReorderMode: ...
    @winrt_mixinmethod
    def put_ReorderMode(self: win32more.Windows.UI.Xaml.Controls.IListViewBase3, value: win32more.Windows.UI.Xaml.Controls.ListViewReorderMode) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedRanges(self: win32more.Windows.UI.Xaml.Controls.IListViewBase4) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.UI.Xaml.Data.ItemIndexRange]: ...
    @winrt_mixinmethod
    def get_IsMultiSelectCheckBoxEnabled(self: win32more.Windows.UI.Xaml.Controls.IListViewBase4) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsMultiSelectCheckBoxEnabled(self: win32more.Windows.UI.Xaml.Controls.IListViewBase4, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_DragItemsCompleted(self: win32more.Windows.UI.Xaml.Controls.IListViewBase4, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ListViewBase, win32more.Windows.UI.Xaml.Controls.DragItemsCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DragItemsCompleted(self: win32more.Windows.UI.Xaml.Controls.IListViewBase4, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ChoosingItemContainer(self: win32more.Windows.UI.Xaml.Controls.IListViewBase4, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ListViewBase, win32more.Windows.UI.Xaml.Controls.ChoosingItemContainerEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ChoosingItemContainer(self: win32more.Windows.UI.Xaml.Controls.IListViewBase4, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ChoosingGroupHeaderContainer(self: win32more.Windows.UI.Xaml.Controls.IListViewBase4, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ListViewBase, win32more.Windows.UI.Xaml.Controls.ChoosingGroupHeaderContainerEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ChoosingGroupHeaderContainer(self: win32more.Windows.UI.Xaml.Controls.IListViewBase4, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def SelectRange(self: win32more.Windows.UI.Xaml.Controls.IListViewBase4, itemIndexRange: win32more.Windows.UI.Xaml.Data.ItemIndexRange) -> Void: ...
    @winrt_mixinmethod
    def DeselectRange(self: win32more.Windows.UI.Xaml.Controls.IListViewBase4, itemIndexRange: win32more.Windows.UI.Xaml.Data.ItemIndexRange) -> Void: ...
    @winrt_mixinmethod
    def get_SingleSelectionFollowsFocus(self: win32more.Windows.UI.Xaml.Controls.IListViewBase5) -> Boolean: ...
    @winrt_mixinmethod
    def put_SingleSelectionFollowsFocus(self: win32more.Windows.UI.Xaml.Controls.IListViewBase5, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def IsDragSource(self: win32more.Windows.UI.Xaml.Controls.IListViewBase5) -> Boolean: ...
    @winrt_mixinmethod
    def TryStartConnectedAnimationAsync(self: win32more.Windows.UI.Xaml.Controls.IListViewBase6, animation: win32more.Windows.UI.Xaml.Media.Animation.ConnectedAnimation, item: win32more.Windows.Win32.System.WinRT.IInspectable, elementName: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def PrepareConnectedAnimation(self: win32more.Windows.UI.Xaml.Controls.IListViewBase6, key: WinRT_String, item: win32more.Windows.Win32.System.WinRT.IInspectable, elementName: WinRT_String) -> win32more.Windows.UI.Xaml.Media.Animation.ConnectedAnimation: ...
    @winrt_mixinmethod
    def get_SemanticZoomOwner(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation) -> win32more.Windows.UI.Xaml.Controls.SemanticZoom: ...
    @winrt_mixinmethod
    def put_SemanticZoomOwner(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation, value: win32more.Windows.UI.Xaml.Controls.SemanticZoom) -> Void: ...
    @winrt_mixinmethod
    def get_IsActiveView(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsActiveView(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsZoomedInView(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZoomedInView(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def InitializeViewChange(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation) -> Void: ...
    @winrt_mixinmethod
    def CompleteViewChange(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation) -> Void: ...
    @winrt_mixinmethod
    def MakeVisible(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation, item: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def StartViewChangeFrom(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation, source: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def StartViewChangeTo(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation, source: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def CompleteViewChangeFrom(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation, source: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def CompleteViewChangeTo(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation, source: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_classmethod
    def get_SingleSelectionFollowsFocusProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsMultiSelectCheckBoxEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ReorderModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ShowsScrollingPlaceholdersProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FooterProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FooterTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FooterTransitionsProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSwipeEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanDragItemsProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanReorderItemsProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsItemClickEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DataFetchSizeProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IncrementalLoadingThresholdProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IncrementalLoadingTriggerProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SemanticZoomOwnerProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsActiveViewProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsZoomedInViewProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTransitionsProperty(cls: win32more.Windows.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CanDragItems = property(get_CanDragItems, put_CanDragItems)
    CanReorderItems = property(get_CanReorderItems, put_CanReorderItems)
    DataFetchSize = property(get_DataFetchSize, put_DataFetchSize)
    Footer = property(get_Footer, put_Footer)
    FooterTemplate = property(get_FooterTemplate, put_FooterTemplate)
    FooterTransitions = property(get_FooterTransitions, put_FooterTransitions)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HeaderTransitions = property(get_HeaderTransitions, put_HeaderTransitions)
    IncrementalLoadingThreshold = property(get_IncrementalLoadingThreshold, put_IncrementalLoadingThreshold)
    IncrementalLoadingTrigger = property(get_IncrementalLoadingTrigger, put_IncrementalLoadingTrigger)
    IsActiveView = property(get_IsActiveView, put_IsActiveView)
    IsItemClickEnabled = property(get_IsItemClickEnabled, put_IsItemClickEnabled)
    IsMultiSelectCheckBoxEnabled = property(get_IsMultiSelectCheckBoxEnabled, put_IsMultiSelectCheckBoxEnabled)
    IsSwipeEnabled = property(get_IsSwipeEnabled, put_IsSwipeEnabled)
    IsZoomedInView = property(get_IsZoomedInView, put_IsZoomedInView)
    ReorderMode = property(get_ReorderMode, put_ReorderMode)
    SelectedItems = property(get_SelectedItems, None)
    SelectedRanges = property(get_SelectedRanges, None)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    SemanticZoomOwner = property(get_SemanticZoomOwner, put_SemanticZoomOwner)
    ShowsScrollingPlaceholders = property(get_ShowsScrollingPlaceholders, put_ShowsScrollingPlaceholders)
    SingleSelectionFollowsFocus = property(get_SingleSelectionFollowsFocus, put_SingleSelectionFollowsFocus)
    _ListViewBase_Meta_.CanDragItemsProperty = property(get_CanDragItemsProperty, None)
    _ListViewBase_Meta_.CanReorderItemsProperty = property(get_CanReorderItemsProperty, None)
    _ListViewBase_Meta_.DataFetchSizeProperty = property(get_DataFetchSizeProperty, None)
    _ListViewBase_Meta_.FooterProperty = property(get_FooterProperty, None)
    _ListViewBase_Meta_.FooterTemplateProperty = property(get_FooterTemplateProperty, None)
    _ListViewBase_Meta_.FooterTransitionsProperty = property(get_FooterTransitionsProperty, None)
    _ListViewBase_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _ListViewBase_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _ListViewBase_Meta_.HeaderTransitionsProperty = property(get_HeaderTransitionsProperty, None)
    _ListViewBase_Meta_.IncrementalLoadingThresholdProperty = property(get_IncrementalLoadingThresholdProperty, None)
    _ListViewBase_Meta_.IncrementalLoadingTriggerProperty = property(get_IncrementalLoadingTriggerProperty, None)
    _ListViewBase_Meta_.IsActiveViewProperty = property(get_IsActiveViewProperty, None)
    _ListViewBase_Meta_.IsItemClickEnabledProperty = property(get_IsItemClickEnabledProperty, None)
    _ListViewBase_Meta_.IsMultiSelectCheckBoxEnabledProperty = property(get_IsMultiSelectCheckBoxEnabledProperty, None)
    _ListViewBase_Meta_.IsSwipeEnabledProperty = property(get_IsSwipeEnabledProperty, None)
    _ListViewBase_Meta_.IsZoomedInViewProperty = property(get_IsZoomedInViewProperty, None)
    _ListViewBase_Meta_.ReorderModeProperty = property(get_ReorderModeProperty, None)
    _ListViewBase_Meta_.SelectionModeProperty = property(get_SelectionModeProperty, None)
    _ListViewBase_Meta_.SemanticZoomOwnerProperty = property(get_SemanticZoomOwnerProperty, None)
    _ListViewBase_Meta_.ShowsScrollingPlaceholdersProperty = property(get_ShowsScrollingPlaceholdersProperty, None)
    _ListViewBase_Meta_.SingleSelectionFollowsFocusProperty = property(get_SingleSelectionFollowsFocusProperty, None)
    ItemClick = event()
    DragItemsStarting = event()
    ContainerContentChanging = event()
    DragItemsCompleted = event()
    ChoosingItemContainer = event()
    ChoosingGroupHeaderContainer = event()
class ListViewBaseHeaderItem(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Windows.UI.Xaml.Controls.IListViewBaseHeaderItem
    _classid_ = 'Windows.UI.Xaml.Controls.ListViewBaseHeaderItem'
class ListViewHeaderItem(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.ListViewBaseHeaderItem
    default_interface: win32more.Windows.UI.Xaml.Controls.IListViewHeaderItem
    _classid_ = 'Windows.UI.Xaml.Controls.ListViewHeaderItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ListViewHeaderItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IListViewHeaderItemFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ListViewHeaderItem: ...
class ListViewItem(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.SelectorItem
    default_interface: win32more.Windows.UI.Xaml.Controls.IListViewItem
    _classid_ = 'Windows.UI.Xaml.Controls.ListViewItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ListViewItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IListViewItemFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ListViewItem: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Windows.UI.Xaml.Controls.IListViewItem) -> win32more.Windows.UI.Xaml.Controls.Primitives.ListViewItemTemplateSettings: ...
    TemplateSettings = property(get_TemplateSettings, None)
class ListViewItemToKeyHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6af5da76-7e8b-4a91-9a56-460cb47d523f}')
    @winrt_commethod(3)
    def Invoke(self, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> WinRT_String: ...
class ListViewKeyToItemHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{26fd5855-b530-4688-b9f0-428249178ef8}')
    @winrt_commethod(3)
    def Invoke(self, key: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
class ListViewPersistenceHelper(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IListViewPersistenceHelper
    _classid_ = 'Windows.UI.Xaml.Controls.ListViewPersistenceHelper'
    @winrt_classmethod
    def GetRelativeScrollPosition(cls: win32more.Windows.UI.Xaml.Controls.IListViewPersistenceHelperStatics, listViewBase: win32more.Windows.UI.Xaml.Controls.ListViewBase, itemToKeyHandler: win32more.Windows.UI.Xaml.Controls.ListViewItemToKeyHandler) -> WinRT_String: ...
    @winrt_classmethod
    def SetRelativeScrollPositionAsync(cls: win32more.Windows.UI.Xaml.Controls.IListViewPersistenceHelperStatics, listViewBase: win32more.Windows.UI.Xaml.Controls.ListViewBase, relativeScrollPosition: WinRT_String, keyToItemHandler: win32more.Windows.UI.Xaml.Controls.ListViewKeyToItemHandler) -> win32more.Windows.Foundation.IAsyncAction: ...
class ListViewReorderMode(Enum, Int32):
    Disabled = 0
    Enabled = 1
class ListViewSelectionMode(Enum, Int32):
    None_ = 0
    Single = 1
    Multiple = 2
    Extended = 3
class _MediaElement_Meta_(ComPtr.__class__):
    pass
class MediaElement(ComPtr, metaclass=_MediaElement_Meta_):
    extends: win32more.Windows.UI.Xaml.FrameworkElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IMediaElement
    _classid_ = 'Windows.UI.Xaml.Controls.MediaElement'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.MediaElement.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.MediaElement: ...
    @winrt_mixinmethod
    def get_PosterSource(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_PosterSource(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_IsMuted(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsMuted(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsAudioOnly(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Boolean: ...
    @winrt_mixinmethod
    def get_AutoPlay(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_AutoPlay(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Volume(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Double: ...
    @winrt_mixinmethod
    def put_Volume(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Balance(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Double: ...
    @winrt_mixinmethod
    def put_Balance(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_NaturalVideoHeight(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Int32: ...
    @winrt_mixinmethod
    def get_NaturalVideoWidth(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Int32: ...
    @winrt_mixinmethod
    def get_NaturalDuration(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> win32more.Windows.UI.Xaml.Duration: ...
    @winrt_mixinmethod
    def get_Position(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_Position(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_DownloadProgress(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Double: ...
    @winrt_mixinmethod
    def get_BufferingProgress(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Double: ...
    @winrt_mixinmethod
    def get_DownloadProgressOffset(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Double: ...
    @winrt_mixinmethod
    def get_CurrentState(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> win32more.Windows.UI.Xaml.Media.MediaElementState: ...
    @winrt_mixinmethod
    def get_Markers(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> win32more.Windows.UI.Xaml.Media.TimelineMarkerCollection: ...
    @winrt_mixinmethod
    def get_CanSeek(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Boolean: ...
    @winrt_mixinmethod
    def get_CanPause(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Boolean: ...
    @winrt_mixinmethod
    def get_AudioStreamCount(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Int32: ...
    @winrt_mixinmethod
    def get_AudioStreamIndex(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_mixinmethod
    def put_AudioStreamIndex(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    @winrt_mixinmethod
    def get_PlaybackRate(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Double: ...
    @winrt_mixinmethod
    def put_PlaybackRate(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_IsLooping(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsLooping(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_PlayToSource(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> win32more.Windows.Media.PlayTo.PlayToSource: ...
    @winrt_mixinmethod
    def get_DefaultPlaybackRate(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Double: ...
    @winrt_mixinmethod
    def put_DefaultPlaybackRate(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_AspectRatioWidth(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Int32: ...
    @winrt_mixinmethod
    def get_AspectRatioHeight(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Int32: ...
    @winrt_mixinmethod
    def get_RealTimePlayback(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_RealTimePlayback(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AudioCategory(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> win32more.Windows.UI.Xaml.Media.AudioCategory: ...
    @winrt_mixinmethod
    def put_AudioCategory(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, value: win32more.Windows.UI.Xaml.Media.AudioCategory) -> Void: ...
    @winrt_mixinmethod
    def get_AudioDeviceType(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> win32more.Windows.UI.Xaml.Media.AudioDeviceType: ...
    @winrt_mixinmethod
    def put_AudioDeviceType(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, value: win32more.Windows.UI.Xaml.Media.AudioDeviceType) -> Void: ...
    @winrt_mixinmethod
    def get_ProtectionManager(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> win32more.Windows.Media.Protection.MediaProtectionManager: ...
    @winrt_mixinmethod
    def put_ProtectionManager(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, value: win32more.Windows.Media.Protection.MediaProtectionManager) -> Void: ...
    @winrt_mixinmethod
    def get_Stereo3DVideoPackingMode(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> win32more.Windows.UI.Xaml.Media.Stereo3DVideoPackingMode: ...
    @winrt_mixinmethod
    def put_Stereo3DVideoPackingMode(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, value: win32more.Windows.UI.Xaml.Media.Stereo3DVideoPackingMode) -> Void: ...
    @winrt_mixinmethod
    def get_Stereo3DVideoRenderMode(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> win32more.Windows.UI.Xaml.Media.Stereo3DVideoRenderMode: ...
    @winrt_mixinmethod
    def put_Stereo3DVideoRenderMode(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, value: win32more.Windows.UI.Xaml.Media.Stereo3DVideoRenderMode) -> Void: ...
    @winrt_mixinmethod
    def get_IsStereo3DVideo(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Boolean: ...
    @winrt_mixinmethod
    def add_MediaOpened(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_MediaOpened(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_MediaEnded(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_MediaEnded(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_MediaFailed(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, handler: win32more.Windows.UI.Xaml.ExceptionRoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_MediaFailed(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DownloadProgressChanged(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DownloadProgressChanged(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_BufferingProgressChanged(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_BufferingProgressChanged(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CurrentStateChanged(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CurrentStateChanged(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_MarkerReached(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, handler: win32more.Windows.UI.Xaml.Media.TimelineMarkerRoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_MarkerReached(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_RateChanged(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, handler: win32more.Windows.UI.Xaml.Media.RateChangedRoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_RateChanged(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_VolumeChanged(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_VolumeChanged(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SeekCompleted(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SeekCompleted(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Stop(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Void: ...
    @winrt_mixinmethod
    def Play(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Void: ...
    @winrt_mixinmethod
    def Pause(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Void: ...
    @winrt_mixinmethod
    def CanPlayType(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, type: WinRT_String) -> win32more.Windows.UI.Xaml.Media.MediaCanPlayResponse: ...
    @winrt_mixinmethod
    def SetSource(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, stream: win32more.Windows.Storage.Streams.IRandomAccessStream, mimeType: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def GetAudioStreamLanguage(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, index: win32more.Windows.Foundation.IReference[Int32]) -> WinRT_String: ...
    @winrt_mixinmethod
    def AddAudioEffect(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, effectID: WinRT_String, effectOptional: Boolean, effectConfiguration: win32more.Windows.Foundation.Collections.IPropertySet) -> Void: ...
    @winrt_mixinmethod
    def AddVideoEffect(self: win32more.Windows.UI.Xaml.Controls.IMediaElement, effectID: WinRT_String, effectOptional: Boolean, effectConfiguration: win32more.Windows.Foundation.Collections.IPropertySet) -> Void: ...
    @winrt_mixinmethod
    def RemoveAllEffects(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> Void: ...
    @winrt_mixinmethod
    def get_ActualStereo3DVideoPackingMode(self: win32more.Windows.UI.Xaml.Controls.IMediaElement) -> win32more.Windows.UI.Xaml.Media.Stereo3DVideoPackingMode: ...
    @winrt_mixinmethod
    def get_AreTransportControlsEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaElement2) -> Boolean: ...
    @winrt_mixinmethod
    def put_AreTransportControlsEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaElement2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Stretch(self: win32more.Windows.UI.Xaml.Controls.IMediaElement2) -> win32more.Windows.UI.Xaml.Media.Stretch: ...
    @winrt_mixinmethod
    def put_Stretch(self: win32more.Windows.UI.Xaml.Controls.IMediaElement2, value: win32more.Windows.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_mixinmethod
    def get_IsFullWindow(self: win32more.Windows.UI.Xaml.Controls.IMediaElement2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFullWindow(self: win32more.Windows.UI.Xaml.Controls.IMediaElement2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def SetMediaStreamSource(self: win32more.Windows.UI.Xaml.Controls.IMediaElement2, source: win32more.Windows.Media.Core.IMediaSource) -> Void: ...
    @winrt_mixinmethod
    def get_PlayToPreferredSourceUri(self: win32more.Windows.UI.Xaml.Controls.IMediaElement2) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_PlayToPreferredSourceUri(self: win32more.Windows.UI.Xaml.Controls.IMediaElement2, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_TransportControls(self: win32more.Windows.UI.Xaml.Controls.IMediaElement3) -> win32more.Windows.UI.Xaml.Controls.MediaTransportControls: ...
    @winrt_mixinmethod
    def put_TransportControls(self: win32more.Windows.UI.Xaml.Controls.IMediaElement3, value: win32more.Windows.UI.Xaml.Controls.MediaTransportControls) -> Void: ...
    @winrt_mixinmethod
    def add_PartialMediaFailureDetected(self: win32more.Windows.UI.Xaml.Controls.IMediaElement3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.MediaElement, win32more.Windows.UI.Xaml.Media.PartialMediaFailureDetectedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PartialMediaFailureDetected(self: win32more.Windows.UI.Xaml.Controls.IMediaElement3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def SetPlaybackSource(self: win32more.Windows.UI.Xaml.Controls.IMediaElement3, source: win32more.Windows.Media.Playback.IMediaPlaybackSource) -> Void: ...
    @winrt_mixinmethod
    def GetAsCastingSource(self: win32more.Windows.UI.Xaml.Controls.IMediaElement3) -> win32more.Windows.Media.Casting.CastingSource: ...
    @winrt_classmethod
    def get_AreTransportControlsEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StretchProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsFullWindowProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlayToPreferredSourceUriProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PosterSourceProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SourceProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsMutedProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsAudioOnlyProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AutoPlayProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VolumeProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BalanceProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_NaturalVideoHeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_NaturalVideoWidthProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_NaturalDurationProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PositionProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DownloadProgressProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BufferingProgressProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DownloadProgressOffsetProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CurrentStateProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanSeekProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanPauseProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AudioStreamCountProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AudioStreamIndexProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaybackRateProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsLoopingProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlayToSourceProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DefaultPlaybackRateProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AspectRatioWidthProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AspectRatioHeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RealTimePlaybackProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AudioCategoryProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AudioDeviceTypeProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ProtectionManagerProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_Stereo3DVideoPackingModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_Stereo3DVideoRenderModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsStereo3DVideoProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ActualStereo3DVideoPackingModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ActualStereo3DVideoPackingMode = property(get_ActualStereo3DVideoPackingMode, None)
    AreTransportControlsEnabled = property(get_AreTransportControlsEnabled, put_AreTransportControlsEnabled)
    AspectRatioHeight = property(get_AspectRatioHeight, None)
    AspectRatioWidth = property(get_AspectRatioWidth, None)
    AudioCategory = property(get_AudioCategory, put_AudioCategory)
    AudioDeviceType = property(get_AudioDeviceType, put_AudioDeviceType)
    AudioStreamCount = property(get_AudioStreamCount, None)
    AudioStreamIndex = property(get_AudioStreamIndex, put_AudioStreamIndex)
    AutoPlay = property(get_AutoPlay, put_AutoPlay)
    Balance = property(get_Balance, put_Balance)
    BufferingProgress = property(get_BufferingProgress, None)
    CanPause = property(get_CanPause, None)
    CanSeek = property(get_CanSeek, None)
    CurrentState = property(get_CurrentState, None)
    DefaultPlaybackRate = property(get_DefaultPlaybackRate, put_DefaultPlaybackRate)
    DownloadProgress = property(get_DownloadProgress, None)
    DownloadProgressOffset = property(get_DownloadProgressOffset, None)
    IsAudioOnly = property(get_IsAudioOnly, None)
    IsFullWindow = property(get_IsFullWindow, put_IsFullWindow)
    IsLooping = property(get_IsLooping, put_IsLooping)
    IsMuted = property(get_IsMuted, put_IsMuted)
    IsStereo3DVideo = property(get_IsStereo3DVideo, None)
    Markers = property(get_Markers, None)
    NaturalDuration = property(get_NaturalDuration, None)
    NaturalVideoHeight = property(get_NaturalVideoHeight, None)
    NaturalVideoWidth = property(get_NaturalVideoWidth, None)
    PlayToPreferredSourceUri = property(get_PlayToPreferredSourceUri, put_PlayToPreferredSourceUri)
    PlayToSource = property(get_PlayToSource, None)
    PlaybackRate = property(get_PlaybackRate, put_PlaybackRate)
    Position = property(get_Position, put_Position)
    PosterSource = property(get_PosterSource, put_PosterSource)
    ProtectionManager = property(get_ProtectionManager, put_ProtectionManager)
    RealTimePlayback = property(get_RealTimePlayback, put_RealTimePlayback)
    Source = property(get_Source, put_Source)
    Stereo3DVideoPackingMode = property(get_Stereo3DVideoPackingMode, put_Stereo3DVideoPackingMode)
    Stereo3DVideoRenderMode = property(get_Stereo3DVideoRenderMode, put_Stereo3DVideoRenderMode)
    Stretch = property(get_Stretch, put_Stretch)
    TransportControls = property(get_TransportControls, put_TransportControls)
    Volume = property(get_Volume, put_Volume)
    _MediaElement_Meta_.ActualStereo3DVideoPackingModeProperty = property(get_ActualStereo3DVideoPackingModeProperty, None)
    _MediaElement_Meta_.AreTransportControlsEnabledProperty = property(get_AreTransportControlsEnabledProperty, None)
    _MediaElement_Meta_.AspectRatioHeightProperty = property(get_AspectRatioHeightProperty, None)
    _MediaElement_Meta_.AspectRatioWidthProperty = property(get_AspectRatioWidthProperty, None)
    _MediaElement_Meta_.AudioCategoryProperty = property(get_AudioCategoryProperty, None)
    _MediaElement_Meta_.AudioDeviceTypeProperty = property(get_AudioDeviceTypeProperty, None)
    _MediaElement_Meta_.AudioStreamCountProperty = property(get_AudioStreamCountProperty, None)
    _MediaElement_Meta_.AudioStreamIndexProperty = property(get_AudioStreamIndexProperty, None)
    _MediaElement_Meta_.AutoPlayProperty = property(get_AutoPlayProperty, None)
    _MediaElement_Meta_.BalanceProperty = property(get_BalanceProperty, None)
    _MediaElement_Meta_.BufferingProgressProperty = property(get_BufferingProgressProperty, None)
    _MediaElement_Meta_.CanPauseProperty = property(get_CanPauseProperty, None)
    _MediaElement_Meta_.CanSeekProperty = property(get_CanSeekProperty, None)
    _MediaElement_Meta_.CurrentStateProperty = property(get_CurrentStateProperty, None)
    _MediaElement_Meta_.DefaultPlaybackRateProperty = property(get_DefaultPlaybackRateProperty, None)
    _MediaElement_Meta_.DownloadProgressOffsetProperty = property(get_DownloadProgressOffsetProperty, None)
    _MediaElement_Meta_.DownloadProgressProperty = property(get_DownloadProgressProperty, None)
    _MediaElement_Meta_.IsAudioOnlyProperty = property(get_IsAudioOnlyProperty, None)
    _MediaElement_Meta_.IsFullWindowProperty = property(get_IsFullWindowProperty, None)
    _MediaElement_Meta_.IsLoopingProperty = property(get_IsLoopingProperty, None)
    _MediaElement_Meta_.IsMutedProperty = property(get_IsMutedProperty, None)
    _MediaElement_Meta_.IsStereo3DVideoProperty = property(get_IsStereo3DVideoProperty, None)
    _MediaElement_Meta_.NaturalDurationProperty = property(get_NaturalDurationProperty, None)
    _MediaElement_Meta_.NaturalVideoHeightProperty = property(get_NaturalVideoHeightProperty, None)
    _MediaElement_Meta_.NaturalVideoWidthProperty = property(get_NaturalVideoWidthProperty, None)
    _MediaElement_Meta_.PlayToPreferredSourceUriProperty = property(get_PlayToPreferredSourceUriProperty, None)
    _MediaElement_Meta_.PlayToSourceProperty = property(get_PlayToSourceProperty, None)
    _MediaElement_Meta_.PlaybackRateProperty = property(get_PlaybackRateProperty, None)
    _MediaElement_Meta_.PositionProperty = property(get_PositionProperty, None)
    _MediaElement_Meta_.PosterSourceProperty = property(get_PosterSourceProperty, None)
    _MediaElement_Meta_.ProtectionManagerProperty = property(get_ProtectionManagerProperty, None)
    _MediaElement_Meta_.RealTimePlaybackProperty = property(get_RealTimePlaybackProperty, None)
    _MediaElement_Meta_.SourceProperty = property(get_SourceProperty, None)
    _MediaElement_Meta_.Stereo3DVideoPackingModeProperty = property(get_Stereo3DVideoPackingModeProperty, None)
    _MediaElement_Meta_.Stereo3DVideoRenderModeProperty = property(get_Stereo3DVideoRenderModeProperty, None)
    _MediaElement_Meta_.StretchProperty = property(get_StretchProperty, None)
    _MediaElement_Meta_.VolumeProperty = property(get_VolumeProperty, None)
    MediaOpened = event()
    MediaEnded = event()
    MediaFailed = event()
    DownloadProgressChanged = event()
    BufferingProgressChanged = event()
    CurrentStateChanged = event()
    MarkerReached = event()
    RateChanged = event()
    VolumeChanged = event()
    SeekCompleted = event()
    PartialMediaFailureDetected = event()
class _MediaPlayerElement_Meta_(ComPtr.__class__):
    pass
class MediaPlayerElement(ComPtr, metaclass=_MediaPlayerElement_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElement
    _classid_ = 'Windows.UI.Xaml.Controls.MediaPlayerElement'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.MediaPlayerElement.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElementFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MediaPlayerElement: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElement) -> win32more.Windows.Media.Playback.IMediaPlaybackSource: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElement, value: win32more.Windows.Media.Playback.IMediaPlaybackSource) -> Void: ...
    @winrt_mixinmethod
    def get_TransportControls(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElement) -> win32more.Windows.UI.Xaml.Controls.MediaTransportControls: ...
    @winrt_mixinmethod
    def put_TransportControls(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElement, value: win32more.Windows.UI.Xaml.Controls.MediaTransportControls) -> Void: ...
    @winrt_mixinmethod
    def get_AreTransportControlsEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_AreTransportControlsEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_PosterSource(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElement) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_PosterSource(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElement, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_Stretch(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElement) -> win32more.Windows.UI.Xaml.Media.Stretch: ...
    @winrt_mixinmethod
    def put_Stretch(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElement, value: win32more.Windows.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_mixinmethod
    def get_AutoPlay(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_AutoPlay(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsFullWindow(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFullWindow(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MediaPlayer(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElement) -> win32more.Windows.Media.Playback.MediaPlayer: ...
    @winrt_mixinmethod
    def SetMediaPlayer(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElement, mediaPlayer: win32more.Windows.Media.Playback.MediaPlayer) -> Void: ...
    @winrt_classmethod
    def get_SourceProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AreTransportControlsEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PosterSourceProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StretchProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AutoPlayProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsFullWindowProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MediaPlayerProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaPlayerElementStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AreTransportControlsEnabled = property(get_AreTransportControlsEnabled, put_AreTransportControlsEnabled)
    AutoPlay = property(get_AutoPlay, put_AutoPlay)
    IsFullWindow = property(get_IsFullWindow, put_IsFullWindow)
    MediaPlayer = property(get_MediaPlayer, None)
    PosterSource = property(get_PosterSource, put_PosterSource)
    Source = property(get_Source, put_Source)
    Stretch = property(get_Stretch, put_Stretch)
    TransportControls = property(get_TransportControls, put_TransportControls)
    _MediaPlayerElement_Meta_.AreTransportControlsEnabledProperty = property(get_AreTransportControlsEnabledProperty, None)
    _MediaPlayerElement_Meta_.AutoPlayProperty = property(get_AutoPlayProperty, None)
    _MediaPlayerElement_Meta_.IsFullWindowProperty = property(get_IsFullWindowProperty, None)
    _MediaPlayerElement_Meta_.MediaPlayerProperty = property(get_MediaPlayerProperty, None)
    _MediaPlayerElement_Meta_.PosterSourceProperty = property(get_PosterSourceProperty, None)
    _MediaPlayerElement_Meta_.SourceProperty = property(get_SourceProperty, None)
    _MediaPlayerElement_Meta_.StretchProperty = property(get_StretchProperty, None)
class _MediaPlayerPresenter_Meta_(ComPtr.__class__):
    pass
class MediaPlayerPresenter(ComPtr, metaclass=_MediaPlayerPresenter_Meta_):
    extends: win32more.Windows.UI.Xaml.FrameworkElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IMediaPlayerPresenter
    _classid_ = 'Windows.UI.Xaml.Controls.MediaPlayerPresenter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.MediaPlayerPresenter.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IMediaPlayerPresenterFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MediaPlayerPresenter: ...
    @winrt_mixinmethod
    def get_MediaPlayer(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerPresenter) -> win32more.Windows.Media.Playback.MediaPlayer: ...
    @winrt_mixinmethod
    def put_MediaPlayer(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerPresenter, value: win32more.Windows.Media.Playback.MediaPlayer) -> Void: ...
    @winrt_mixinmethod
    def get_Stretch(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerPresenter) -> win32more.Windows.UI.Xaml.Media.Stretch: ...
    @winrt_mixinmethod
    def put_Stretch(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerPresenter, value: win32more.Windows.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_mixinmethod
    def get_IsFullWindow(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFullWindow(self: win32more.Windows.UI.Xaml.Controls.IMediaPlayerPresenter, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_MediaPlayerProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaPlayerPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StretchProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaPlayerPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsFullWindowProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaPlayerPresenterStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsFullWindow = property(get_IsFullWindow, put_IsFullWindow)
    MediaPlayer = property(get_MediaPlayer, put_MediaPlayer)
    Stretch = property(get_Stretch, put_Stretch)
    _MediaPlayerPresenter_Meta_.IsFullWindowProperty = property(get_IsFullWindowProperty, None)
    _MediaPlayerPresenter_Meta_.MediaPlayerProperty = property(get_MediaPlayerProperty, None)
    _MediaPlayerPresenter_Meta_.StretchProperty = property(get_StretchProperty, None)
class _MediaTransportControls_Meta_(ComPtr.__class__):
    pass
class MediaTransportControls(ComPtr, metaclass=_MediaTransportControls_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls
    _classid_ = 'Windows.UI.Xaml.Controls.MediaTransportControls'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.MediaTransportControls.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MediaTransportControls: ...
    @winrt_mixinmethod
    def get_IsFullWindowButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFullWindowButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsFullWindowEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFullWindowEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsZoomButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZoomButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsZoomEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZoomEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsFastForwardButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFastForwardButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsFastForwardEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFastForwardEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsFastRewindButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFastRewindButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsFastRewindEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFastRewindEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsStopButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsStopButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsStopEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsStopEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsVolumeButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsVolumeButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsVolumeEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsVolumeEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsPlaybackRateButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPlaybackRateButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsPlaybackRateEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPlaybackRateEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSeekBarVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSeekBarVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSeekEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSeekEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsCompact(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCompact(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSkipForwardButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSkipForwardButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSkipForwardEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSkipForwardEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSkipBackwardButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSkipBackwardButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSkipBackwardEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSkipBackwardEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsNextTrackButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsNextTrackButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsPreviousTrackButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPreviousTrackButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_FastPlayFallbackBehaviour(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls2) -> win32more.Windows.UI.Xaml.Media.FastPlayFallbackBehaviour: ...
    @winrt_mixinmethod
    def put_FastPlayFallbackBehaviour(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls2, value: win32more.Windows.UI.Xaml.Media.FastPlayFallbackBehaviour) -> Void: ...
    @winrt_mixinmethod
    def add_ThumbnailRequested(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.MediaTransportControls, win32more.Windows.UI.Xaml.Media.MediaTransportControlsThumbnailRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ThumbnailRequested(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_ShowAndHideAutomatically(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls3) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShowAndHideAutomatically(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls3, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsRepeatEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls3) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsRepeatEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls3, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsRepeatButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls3) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsRepeatButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls3, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def Show(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls3) -> Void: ...
    @winrt_mixinmethod
    def Hide(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls3) -> Void: ...
    @winrt_mixinmethod
    def get_IsCompactOverlayButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls4) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCompactOverlayButtonVisible(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls4, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsCompactOverlayEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls4) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCompactOverlayEnabled(self: win32more.Windows.UI.Xaml.Controls.IMediaTransportControls4, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsCompactOverlayButtonVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsCompactOverlayEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ShowAndHideAutomaticallyProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsRepeatEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsRepeatButtonVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSkipForwardButtonVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSkipForwardEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSkipBackwardButtonVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSkipBackwardEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsNextTrackButtonVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPreviousTrackButtonVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FastPlayFallbackBehaviourProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsFullWindowButtonVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsFullWindowEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsZoomButtonVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsZoomEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsFastForwardButtonVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsFastForwardEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsFastRewindButtonVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsFastRewindEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsStopButtonVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsStopEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsVolumeButtonVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsVolumeEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPlaybackRateButtonVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPlaybackRateEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSeekBarVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSeekEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsCompactProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    FastPlayFallbackBehaviour = property(get_FastPlayFallbackBehaviour, put_FastPlayFallbackBehaviour)
    IsCompact = property(get_IsCompact, put_IsCompact)
    IsCompactOverlayButtonVisible = property(get_IsCompactOverlayButtonVisible, put_IsCompactOverlayButtonVisible)
    IsCompactOverlayEnabled = property(get_IsCompactOverlayEnabled, put_IsCompactOverlayEnabled)
    IsFastForwardButtonVisible = property(get_IsFastForwardButtonVisible, put_IsFastForwardButtonVisible)
    IsFastForwardEnabled = property(get_IsFastForwardEnabled, put_IsFastForwardEnabled)
    IsFastRewindButtonVisible = property(get_IsFastRewindButtonVisible, put_IsFastRewindButtonVisible)
    IsFastRewindEnabled = property(get_IsFastRewindEnabled, put_IsFastRewindEnabled)
    IsFullWindowButtonVisible = property(get_IsFullWindowButtonVisible, put_IsFullWindowButtonVisible)
    IsFullWindowEnabled = property(get_IsFullWindowEnabled, put_IsFullWindowEnabled)
    IsNextTrackButtonVisible = property(get_IsNextTrackButtonVisible, put_IsNextTrackButtonVisible)
    IsPlaybackRateButtonVisible = property(get_IsPlaybackRateButtonVisible, put_IsPlaybackRateButtonVisible)
    IsPlaybackRateEnabled = property(get_IsPlaybackRateEnabled, put_IsPlaybackRateEnabled)
    IsPreviousTrackButtonVisible = property(get_IsPreviousTrackButtonVisible, put_IsPreviousTrackButtonVisible)
    IsRepeatButtonVisible = property(get_IsRepeatButtonVisible, put_IsRepeatButtonVisible)
    IsRepeatEnabled = property(get_IsRepeatEnabled, put_IsRepeatEnabled)
    IsSeekBarVisible = property(get_IsSeekBarVisible, put_IsSeekBarVisible)
    IsSeekEnabled = property(get_IsSeekEnabled, put_IsSeekEnabled)
    IsSkipBackwardButtonVisible = property(get_IsSkipBackwardButtonVisible, put_IsSkipBackwardButtonVisible)
    IsSkipBackwardEnabled = property(get_IsSkipBackwardEnabled, put_IsSkipBackwardEnabled)
    IsSkipForwardButtonVisible = property(get_IsSkipForwardButtonVisible, put_IsSkipForwardButtonVisible)
    IsSkipForwardEnabled = property(get_IsSkipForwardEnabled, put_IsSkipForwardEnabled)
    IsStopButtonVisible = property(get_IsStopButtonVisible, put_IsStopButtonVisible)
    IsStopEnabled = property(get_IsStopEnabled, put_IsStopEnabled)
    IsVolumeButtonVisible = property(get_IsVolumeButtonVisible, put_IsVolumeButtonVisible)
    IsVolumeEnabled = property(get_IsVolumeEnabled, put_IsVolumeEnabled)
    IsZoomButtonVisible = property(get_IsZoomButtonVisible, put_IsZoomButtonVisible)
    IsZoomEnabled = property(get_IsZoomEnabled, put_IsZoomEnabled)
    ShowAndHideAutomatically = property(get_ShowAndHideAutomatically, put_ShowAndHideAutomatically)
    _MediaTransportControls_Meta_.FastPlayFallbackBehaviourProperty = property(get_FastPlayFallbackBehaviourProperty, None)
    _MediaTransportControls_Meta_.IsCompactOverlayButtonVisibleProperty = property(get_IsCompactOverlayButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsCompactOverlayEnabledProperty = property(get_IsCompactOverlayEnabledProperty, None)
    _MediaTransportControls_Meta_.IsCompactProperty = property(get_IsCompactProperty, None)
    _MediaTransportControls_Meta_.IsFastForwardButtonVisibleProperty = property(get_IsFastForwardButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsFastForwardEnabledProperty = property(get_IsFastForwardEnabledProperty, None)
    _MediaTransportControls_Meta_.IsFastRewindButtonVisibleProperty = property(get_IsFastRewindButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsFastRewindEnabledProperty = property(get_IsFastRewindEnabledProperty, None)
    _MediaTransportControls_Meta_.IsFullWindowButtonVisibleProperty = property(get_IsFullWindowButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsFullWindowEnabledProperty = property(get_IsFullWindowEnabledProperty, None)
    _MediaTransportControls_Meta_.IsNextTrackButtonVisibleProperty = property(get_IsNextTrackButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsPlaybackRateButtonVisibleProperty = property(get_IsPlaybackRateButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsPlaybackRateEnabledProperty = property(get_IsPlaybackRateEnabledProperty, None)
    _MediaTransportControls_Meta_.IsPreviousTrackButtonVisibleProperty = property(get_IsPreviousTrackButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsRepeatButtonVisibleProperty = property(get_IsRepeatButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsRepeatEnabledProperty = property(get_IsRepeatEnabledProperty, None)
    _MediaTransportControls_Meta_.IsSeekBarVisibleProperty = property(get_IsSeekBarVisibleProperty, None)
    _MediaTransportControls_Meta_.IsSeekEnabledProperty = property(get_IsSeekEnabledProperty, None)
    _MediaTransportControls_Meta_.IsSkipBackwardButtonVisibleProperty = property(get_IsSkipBackwardButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsSkipBackwardEnabledProperty = property(get_IsSkipBackwardEnabledProperty, None)
    _MediaTransportControls_Meta_.IsSkipForwardButtonVisibleProperty = property(get_IsSkipForwardButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsSkipForwardEnabledProperty = property(get_IsSkipForwardEnabledProperty, None)
    _MediaTransportControls_Meta_.IsStopButtonVisibleProperty = property(get_IsStopButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsStopEnabledProperty = property(get_IsStopEnabledProperty, None)
    _MediaTransportControls_Meta_.IsVolumeButtonVisibleProperty = property(get_IsVolumeButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsVolumeEnabledProperty = property(get_IsVolumeEnabledProperty, None)
    _MediaTransportControls_Meta_.IsZoomButtonVisibleProperty = property(get_IsZoomButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsZoomEnabledProperty = property(get_IsZoomEnabledProperty, None)
    _MediaTransportControls_Meta_.ShowAndHideAutomaticallyProperty = property(get_ShowAndHideAutomaticallyProperty, None)
    ThumbnailRequested = event()
class _MediaTransportControlsHelper_Meta_(ComPtr.__class__):
    pass
class MediaTransportControlsHelper(ComPtr, metaclass=_MediaTransportControlsHelper_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsHelper
    _classid_ = 'Windows.UI.Xaml.Controls.MediaTransportControlsHelper'
    @winrt_classmethod
    def get_DropoutOrderProperty(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsHelperStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetDropoutOrder(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsHelperStatics, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_classmethod
    def SetDropoutOrder(cls: win32more.Windows.UI.Xaml.Controls.IMediaTransportControlsHelperStatics, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    _MediaTransportControlsHelper_Meta_.DropoutOrderProperty = property(get_DropoutOrderProperty, None)
class _MenuBar_Meta_(ComPtr.__class__):
    pass
class MenuBar(ComPtr, metaclass=_MenuBar_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IMenuBar
    _classid_ = 'Windows.UI.Xaml.Controls.MenuBar'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.MenuBar.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IMenuBarFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MenuBar: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.UI.Xaml.Controls.IMenuBar) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.MenuBarItem]: ...
    @winrt_classmethod
    def get_ItemsProperty(cls: win32more.Windows.UI.Xaml.Controls.IMenuBarStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Items = property(get_Items, None)
    _MenuBar_Meta_.ItemsProperty = property(get_ItemsProperty, None)
class _MenuBarItem_Meta_(ComPtr.__class__):
    pass
class MenuBarItem(ComPtr, metaclass=_MenuBarItem_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IMenuBarItem
    _classid_ = 'Windows.UI.Xaml.Controls.MenuBarItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.MenuBarItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IMenuBarItemFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MenuBarItem: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Windows.UI.Xaml.Controls.IMenuBarItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Windows.UI.Xaml.Controls.IMenuBarItem, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.UI.Xaml.Controls.IMenuBarItem) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.MenuFlyoutItemBase]: ...
    @winrt_classmethod
    def get_TitleProperty(cls: win32more.Windows.UI.Xaml.Controls.IMenuBarItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemsProperty(cls: win32more.Windows.UI.Xaml.Controls.IMenuBarItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Items = property(get_Items, None)
    Title = property(get_Title, put_Title)
    _MenuBarItem_Meta_.ItemsProperty = property(get_ItemsProperty, None)
    _MenuBarItem_Meta_.TitleProperty = property(get_TitleProperty, None)
class MenuBarItemFlyout(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.MenuFlyout
    default_interface: win32more.Windows.UI.Xaml.Controls.IMenuBarItemFlyout
    _classid_ = 'Windows.UI.Xaml.Controls.MenuBarItemFlyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.MenuBarItemFlyout.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IMenuBarItemFlyoutFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MenuBarItemFlyout: ...
class _MenuFlyout_Meta_(ComPtr.__class__):
    pass
class MenuFlyout(ComPtr, metaclass=_MenuFlyout_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase
    default_interface: win32more.Windows.UI.Xaml.Controls.IMenuFlyout
    _classid_ = 'Windows.UI.Xaml.Controls.MenuFlyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.MenuFlyout.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MenuFlyout: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyout) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.MenuFlyoutItemBase]: ...
    @winrt_mixinmethod
    def get_MenuFlyoutPresenterStyle(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyout) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_MenuFlyoutPresenterStyle(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyout, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def ShowAt(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyout2, targetElement: win32more.Windows.UI.Xaml.UIElement, point: win32more.Windows.Foundation.Point) -> Void: ...
    @winrt_classmethod
    def get_MenuFlyoutPresenterStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Items = property(get_Items, None)
    MenuFlyoutPresenterStyle = property(get_MenuFlyoutPresenterStyle, put_MenuFlyoutPresenterStyle)
    _MenuFlyout_Meta_.MenuFlyoutPresenterStyleProperty = property(get_MenuFlyoutPresenterStyleProperty, None)
class _MenuFlyoutItem_Meta_(ComPtr.__class__):
    pass
class MenuFlyoutItem(ComPtr, metaclass=_MenuFlyoutItem_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.MenuFlyoutItemBase
    default_interface: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItem
    _classid_ = 'Windows.UI.Xaml.Controls.MenuFlyoutItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.MenuFlyoutItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItemFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MenuFlyoutItem: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItem, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Command(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItem) -> win32more.Windows.UI.Xaml.Input.ICommand: ...
    @winrt_mixinmethod
    def put_Command(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItem, value: win32more.Windows.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_mixinmethod
    def get_CommandParameter(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItem) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_CommandParameter(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItem, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def add_Click(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItem, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Click(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItem, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_Icon(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItem2) -> win32more.Windows.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def put_Icon(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItem2, value: win32more.Windows.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_mixinmethod
    def get_KeyboardAcceleratorTextOverride(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItem3) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_KeyboardAcceleratorTextOverride(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItem3, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItem3) -> win32more.Windows.UI.Xaml.Controls.Primitives.MenuFlyoutItemTemplateSettings: ...
    @winrt_classmethod
    def get_KeyboardAcceleratorTextOverrideProperty(cls: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItemStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconProperty(cls: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItemStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextProperty(cls: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CommandProperty(cls: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CommandParameterProperty(cls: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Command = property(get_Command, put_Command)
    CommandParameter = property(get_CommandParameter, put_CommandParameter)
    Icon = property(get_Icon, put_Icon)
    KeyboardAcceleratorTextOverride = property(get_KeyboardAcceleratorTextOverride, put_KeyboardAcceleratorTextOverride)
    TemplateSettings = property(get_TemplateSettings, None)
    Text = property(get_Text, put_Text)
    _MenuFlyoutItem_Meta_.CommandParameterProperty = property(get_CommandParameterProperty, None)
    _MenuFlyoutItem_Meta_.CommandProperty = property(get_CommandProperty, None)
    _MenuFlyoutItem_Meta_.IconProperty = property(get_IconProperty, None)
    _MenuFlyoutItem_Meta_.KeyboardAcceleratorTextOverrideProperty = property(get_KeyboardAcceleratorTextOverrideProperty, None)
    _MenuFlyoutItem_Meta_.TextProperty = property(get_TextProperty, None)
    Click = event()
class MenuFlyoutItemBase(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutItemBase
    _classid_ = 'Windows.UI.Xaml.Controls.MenuFlyoutItemBase'
class _MenuFlyoutPresenter_Meta_(ComPtr.__class__):
    pass
class MenuFlyoutPresenter(ComPtr, metaclass=_MenuFlyoutPresenter_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ItemsControl
    default_interface: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutPresenter
    _classid_ = 'Windows.UI.Xaml.Controls.MenuFlyoutPresenter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.MenuFlyoutPresenter.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutPresenterFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MenuFlyoutPresenter: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutPresenter2) -> win32more.Windows.UI.Xaml.Controls.Primitives.MenuFlyoutPresenterTemplateSettings: ...
    @winrt_mixinmethod
    def get_IsDefaultShadowEnabled(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutPresenter3) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDefaultShadowEnabled(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutPresenter3, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsDefaultShadowEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutPresenterStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsDefaultShadowEnabled = property(get_IsDefaultShadowEnabled, put_IsDefaultShadowEnabled)
    TemplateSettings = property(get_TemplateSettings, None)
    _MenuFlyoutPresenter_Meta_.IsDefaultShadowEnabledProperty = property(get_IsDefaultShadowEnabledProperty, None)
class MenuFlyoutSeparator(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.MenuFlyoutItemBase
    default_interface: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutSeparator
    _classid_ = 'Windows.UI.Xaml.Controls.MenuFlyoutSeparator'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.MenuFlyoutSeparator.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutSeparatorFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.MenuFlyoutSeparator: ...
class _MenuFlyoutSubItem_Meta_(ComPtr.__class__):
    pass
class MenuFlyoutSubItem(ComPtr, metaclass=_MenuFlyoutSubItem_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.MenuFlyoutItemBase
    default_interface: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutSubItem
    _classid_ = 'Windows.UI.Xaml.Controls.MenuFlyoutSubItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.MenuFlyoutSubItem.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.MenuFlyoutSubItem: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutSubItem) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.MenuFlyoutItemBase]: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutSubItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutSubItem, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Icon(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutSubItem2) -> win32more.Windows.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def put_Icon(self: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutSubItem2, value: win32more.Windows.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_classmethod
    def get_IconProperty(cls: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutSubItemStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextProperty(cls: win32more.Windows.UI.Xaml.Controls.IMenuFlyoutSubItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Icon = property(get_Icon, put_Icon)
    Items = property(get_Items, None)
    Text = property(get_Text, put_Text)
    _MenuFlyoutSubItem_Meta_.IconProperty = property(get_IconProperty, None)
    _MenuFlyoutSubItem_Meta_.TextProperty = property(get_TextProperty, None)
class _NavigationView_Meta_(ComPtr.__class__):
    pass
class NavigationView(ComPtr, metaclass=_NavigationView_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Windows.UI.Xaml.Controls.INavigationView
    _classid_ = 'Windows.UI.Xaml.Controls.NavigationView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.NavigationView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.NavigationView: ...
    @winrt_mixinmethod
    def get_IsPaneOpen(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPaneOpen(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CompactModeThresholdWidth(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> Double: ...
    @winrt_mixinmethod
    def put_CompactModeThresholdWidth(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ExpandedModeThresholdWidth(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> Double: ...
    @winrt_mixinmethod
    def put_ExpandedModeThresholdWidth(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_PaneFooter(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_PaneFooter(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayMode(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> win32more.Windows.UI.Xaml.Controls.NavigationViewDisplayMode: ...
    @winrt_mixinmethod
    def get_IsSettingsVisible(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSettingsVisible(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsPaneToggleButtonVisible(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPaneToggleButtonVisible(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AlwaysShowHeader(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> Boolean: ...
    @winrt_mixinmethod
    def put_AlwaysShowHeader(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CompactPaneLength(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> Double: ...
    @winrt_mixinmethod
    def put_CompactPaneLength(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_OpenPaneLength(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> Double: ...
    @winrt_mixinmethod
    def put_OpenPaneLength(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_PaneToggleButtonStyle(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_PaneToggleButtonStyle(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedItem(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_SelectedItem(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_MenuItems(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def get_MenuItemsSource(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_MenuItemsSource(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_SettingsItem(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_AutoSuggestBox(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> win32more.Windows.UI.Xaml.Controls.AutoSuggestBox: ...
    @winrt_mixinmethod
    def put_AutoSuggestBox(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: win32more.Windows.UI.Xaml.Controls.AutoSuggestBox) -> Void: ...
    @winrt_mixinmethod
    def get_MenuItemTemplate(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_MenuItemTemplate(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_MenuItemTemplateSelector(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> win32more.Windows.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_mixinmethod
    def put_MenuItemTemplateSelector(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_mixinmethod
    def get_MenuItemContainerStyle(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_MenuItemContainerStyle(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_MenuItemContainerStyleSelector(self: win32more.Windows.UI.Xaml.Controls.INavigationView) -> win32more.Windows.UI.Xaml.Controls.StyleSelector: ...
    @winrt_mixinmethod
    def put_MenuItemContainerStyleSelector(self: win32more.Windows.UI.Xaml.Controls.INavigationView, value: win32more.Windows.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_mixinmethod
    def MenuItemFromContainer(self: win32more.Windows.UI.Xaml.Controls.INavigationView, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def ContainerFromMenuItem(self: win32more.Windows.UI.Xaml.Controls.INavigationView, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def add_SelectionChanged(self: win32more.Windows.UI.Xaml.Controls.INavigationView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.NavigationView, win32more.Windows.UI.Xaml.Controls.NavigationViewSelectionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanged(self: win32more.Windows.UI.Xaml.Controls.INavigationView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ItemInvoked(self: win32more.Windows.UI.Xaml.Controls.INavigationView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.NavigationView, win32more.Windows.UI.Xaml.Controls.NavigationViewItemInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ItemInvoked(self: win32more.Windows.UI.Xaml.Controls.INavigationView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DisplayModeChanged(self: win32more.Windows.UI.Xaml.Controls.INavigationView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.NavigationView, win32more.Windows.UI.Xaml.Controls.NavigationViewDisplayModeChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DisplayModeChanged(self: win32more.Windows.UI.Xaml.Controls.INavigationView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_IsBackButtonVisible(self: win32more.Windows.UI.Xaml.Controls.INavigationView2) -> win32more.Windows.UI.Xaml.Controls.NavigationViewBackButtonVisible: ...
    @winrt_mixinmethod
    def put_IsBackButtonVisible(self: win32more.Windows.UI.Xaml.Controls.INavigationView2, value: win32more.Windows.UI.Xaml.Controls.NavigationViewBackButtonVisible) -> Void: ...
    @winrt_mixinmethod
    def get_IsBackEnabled(self: win32more.Windows.UI.Xaml.Controls.INavigationView2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsBackEnabled(self: win32more.Windows.UI.Xaml.Controls.INavigationView2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_PaneTitle(self: win32more.Windows.UI.Xaml.Controls.INavigationView2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PaneTitle(self: win32more.Windows.UI.Xaml.Controls.INavigationView2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def add_BackRequested(self: win32more.Windows.UI.Xaml.Controls.INavigationView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.NavigationView, win32more.Windows.UI.Xaml.Controls.NavigationViewBackRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_BackRequested(self: win32more.Windows.UI.Xaml.Controls.INavigationView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PaneClosed(self: win32more.Windows.UI.Xaml.Controls.INavigationView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.NavigationView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PaneClosed(self: win32more.Windows.UI.Xaml.Controls.INavigationView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PaneClosing(self: win32more.Windows.UI.Xaml.Controls.INavigationView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.NavigationView, win32more.Windows.UI.Xaml.Controls.NavigationViewPaneClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PaneClosing(self: win32more.Windows.UI.Xaml.Controls.INavigationView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PaneOpened(self: win32more.Windows.UI.Xaml.Controls.INavigationView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.NavigationView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PaneOpened(self: win32more.Windows.UI.Xaml.Controls.INavigationView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PaneOpening(self: win32more.Windows.UI.Xaml.Controls.INavigationView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.NavigationView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PaneOpening(self: win32more.Windows.UI.Xaml.Controls.INavigationView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_PaneDisplayMode(self: win32more.Windows.UI.Xaml.Controls.INavigationView3) -> win32more.Windows.UI.Xaml.Controls.NavigationViewPaneDisplayMode: ...
    @winrt_mixinmethod
    def put_PaneDisplayMode(self: win32more.Windows.UI.Xaml.Controls.INavigationView3, value: win32more.Windows.UI.Xaml.Controls.NavigationViewPaneDisplayMode) -> Void: ...
    @winrt_mixinmethod
    def get_PaneHeader(self: win32more.Windows.UI.Xaml.Controls.INavigationView3) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_PaneHeader(self: win32more.Windows.UI.Xaml.Controls.INavigationView3, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_PaneCustomContent(self: win32more.Windows.UI.Xaml.Controls.INavigationView3) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_PaneCustomContent(self: win32more.Windows.UI.Xaml.Controls.INavigationView3, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_ContentOverlay(self: win32more.Windows.UI.Xaml.Controls.INavigationView3) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_ContentOverlay(self: win32more.Windows.UI.Xaml.Controls.INavigationView3, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_IsPaneVisible(self: win32more.Windows.UI.Xaml.Controls.INavigationView3) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPaneVisible(self: win32more.Windows.UI.Xaml.Controls.INavigationView3, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionFollowsFocus(self: win32more.Windows.UI.Xaml.Controls.INavigationView3) -> win32more.Windows.UI.Xaml.Controls.NavigationViewSelectionFollowsFocus: ...
    @winrt_mixinmethod
    def put_SelectionFollowsFocus(self: win32more.Windows.UI.Xaml.Controls.INavigationView3, value: win32more.Windows.UI.Xaml.Controls.NavigationViewSelectionFollowsFocus) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Windows.UI.Xaml.Controls.INavigationView3) -> win32more.Windows.UI.Xaml.Controls.NavigationViewTemplateSettings: ...
    @winrt_mixinmethod
    def get_ShoulderNavigationEnabled(self: win32more.Windows.UI.Xaml.Controls.INavigationView3) -> win32more.Windows.UI.Xaml.Controls.NavigationViewShoulderNavigationEnabled: ...
    @winrt_mixinmethod
    def put_ShoulderNavigationEnabled(self: win32more.Windows.UI.Xaml.Controls.INavigationView3, value: win32more.Windows.UI.Xaml.Controls.NavigationViewShoulderNavigationEnabled) -> Void: ...
    @winrt_mixinmethod
    def get_OverflowLabelMode(self: win32more.Windows.UI.Xaml.Controls.INavigationView3) -> win32more.Windows.UI.Xaml.Controls.NavigationViewOverflowLabelMode: ...
    @winrt_mixinmethod
    def put_OverflowLabelMode(self: win32more.Windows.UI.Xaml.Controls.INavigationView3, value: win32more.Windows.UI.Xaml.Controls.NavigationViewOverflowLabelMode) -> Void: ...
    @winrt_classmethod
    def get_PaneDisplayModeProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneHeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneCustomContentProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentOverlayProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPaneVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionFollowsFocusProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TemplateSettingsProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ShoulderNavigationEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OverflowLabelModeProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsBackButtonVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsBackEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneTitleProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPaneOpenProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CompactModeThresholdWidthProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ExpandedModeThresholdWidthProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneFooterProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisplayModeProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSettingsVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPaneToggleButtonVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AlwaysShowHeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CompactPaneLengthProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OpenPaneLengthProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneToggleButtonStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MenuItemsProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MenuItemsSourceProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedItemProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SettingsItemProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AutoSuggestBoxProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MenuItemTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MenuItemTemplateSelectorProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MenuItemContainerStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MenuItemContainerStyleSelectorProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AlwaysShowHeader = property(get_AlwaysShowHeader, put_AlwaysShowHeader)
    AutoSuggestBox = property(get_AutoSuggestBox, put_AutoSuggestBox)
    CompactModeThresholdWidth = property(get_CompactModeThresholdWidth, put_CompactModeThresholdWidth)
    CompactPaneLength = property(get_CompactPaneLength, put_CompactPaneLength)
    ContentOverlay = property(get_ContentOverlay, put_ContentOverlay)
    DisplayMode = property(get_DisplayMode, None)
    ExpandedModeThresholdWidth = property(get_ExpandedModeThresholdWidth, put_ExpandedModeThresholdWidth)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsBackButtonVisible = property(get_IsBackButtonVisible, put_IsBackButtonVisible)
    IsBackEnabled = property(get_IsBackEnabled, put_IsBackEnabled)
    IsPaneOpen = property(get_IsPaneOpen, put_IsPaneOpen)
    IsPaneToggleButtonVisible = property(get_IsPaneToggleButtonVisible, put_IsPaneToggleButtonVisible)
    IsPaneVisible = property(get_IsPaneVisible, put_IsPaneVisible)
    IsSettingsVisible = property(get_IsSettingsVisible, put_IsSettingsVisible)
    MenuItemContainerStyle = property(get_MenuItemContainerStyle, put_MenuItemContainerStyle)
    MenuItemContainerStyleSelector = property(get_MenuItemContainerStyleSelector, put_MenuItemContainerStyleSelector)
    MenuItemTemplate = property(get_MenuItemTemplate, put_MenuItemTemplate)
    MenuItemTemplateSelector = property(get_MenuItemTemplateSelector, put_MenuItemTemplateSelector)
    MenuItems = property(get_MenuItems, None)
    MenuItemsSource = property(get_MenuItemsSource, put_MenuItemsSource)
    OpenPaneLength = property(get_OpenPaneLength, put_OpenPaneLength)
    OverflowLabelMode = property(get_OverflowLabelMode, put_OverflowLabelMode)
    PaneCustomContent = property(get_PaneCustomContent, put_PaneCustomContent)
    PaneDisplayMode = property(get_PaneDisplayMode, put_PaneDisplayMode)
    PaneFooter = property(get_PaneFooter, put_PaneFooter)
    PaneHeader = property(get_PaneHeader, put_PaneHeader)
    PaneTitle = property(get_PaneTitle, put_PaneTitle)
    PaneToggleButtonStyle = property(get_PaneToggleButtonStyle, put_PaneToggleButtonStyle)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    SelectionFollowsFocus = property(get_SelectionFollowsFocus, put_SelectionFollowsFocus)
    SettingsItem = property(get_SettingsItem, None)
    ShoulderNavigationEnabled = property(get_ShoulderNavigationEnabled, put_ShoulderNavigationEnabled)
    TemplateSettings = property(get_TemplateSettings, None)
    _NavigationView_Meta_.AlwaysShowHeaderProperty = property(get_AlwaysShowHeaderProperty, None)
    _NavigationView_Meta_.AutoSuggestBoxProperty = property(get_AutoSuggestBoxProperty, None)
    _NavigationView_Meta_.CompactModeThresholdWidthProperty = property(get_CompactModeThresholdWidthProperty, None)
    _NavigationView_Meta_.CompactPaneLengthProperty = property(get_CompactPaneLengthProperty, None)
    _NavigationView_Meta_.ContentOverlayProperty = property(get_ContentOverlayProperty, None)
    _NavigationView_Meta_.DisplayModeProperty = property(get_DisplayModeProperty, None)
    _NavigationView_Meta_.ExpandedModeThresholdWidthProperty = property(get_ExpandedModeThresholdWidthProperty, None)
    _NavigationView_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _NavigationView_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _NavigationView_Meta_.IsBackButtonVisibleProperty = property(get_IsBackButtonVisibleProperty, None)
    _NavigationView_Meta_.IsBackEnabledProperty = property(get_IsBackEnabledProperty, None)
    _NavigationView_Meta_.IsPaneOpenProperty = property(get_IsPaneOpenProperty, None)
    _NavigationView_Meta_.IsPaneToggleButtonVisibleProperty = property(get_IsPaneToggleButtonVisibleProperty, None)
    _NavigationView_Meta_.IsPaneVisibleProperty = property(get_IsPaneVisibleProperty, None)
    _NavigationView_Meta_.IsSettingsVisibleProperty = property(get_IsSettingsVisibleProperty, None)
    _NavigationView_Meta_.MenuItemContainerStyleProperty = property(get_MenuItemContainerStyleProperty, None)
    _NavigationView_Meta_.MenuItemContainerStyleSelectorProperty = property(get_MenuItemContainerStyleSelectorProperty, None)
    _NavigationView_Meta_.MenuItemTemplateProperty = property(get_MenuItemTemplateProperty, None)
    _NavigationView_Meta_.MenuItemTemplateSelectorProperty = property(get_MenuItemTemplateSelectorProperty, None)
    _NavigationView_Meta_.MenuItemsProperty = property(get_MenuItemsProperty, None)
    _NavigationView_Meta_.MenuItemsSourceProperty = property(get_MenuItemsSourceProperty, None)
    _NavigationView_Meta_.OpenPaneLengthProperty = property(get_OpenPaneLengthProperty, None)
    _NavigationView_Meta_.OverflowLabelModeProperty = property(get_OverflowLabelModeProperty, None)
    _NavigationView_Meta_.PaneCustomContentProperty = property(get_PaneCustomContentProperty, None)
    _NavigationView_Meta_.PaneDisplayModeProperty = property(get_PaneDisplayModeProperty, None)
    _NavigationView_Meta_.PaneFooterProperty = property(get_PaneFooterProperty, None)
    _NavigationView_Meta_.PaneHeaderProperty = property(get_PaneHeaderProperty, None)
    _NavigationView_Meta_.PaneTitleProperty = property(get_PaneTitleProperty, None)
    _NavigationView_Meta_.PaneToggleButtonStyleProperty = property(get_PaneToggleButtonStyleProperty, None)
    _NavigationView_Meta_.SelectedItemProperty = property(get_SelectedItemProperty, None)
    _NavigationView_Meta_.SelectionFollowsFocusProperty = property(get_SelectionFollowsFocusProperty, None)
    _NavigationView_Meta_.SettingsItemProperty = property(get_SettingsItemProperty, None)
    _NavigationView_Meta_.ShoulderNavigationEnabledProperty = property(get_ShoulderNavigationEnabledProperty, None)
    _NavigationView_Meta_.TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
    SelectionChanged = event()
    ItemInvoked = event()
    DisplayModeChanged = event()
    BackRequested = event()
    PaneClosed = event()
    PaneClosing = event()
    PaneOpened = event()
    PaneOpening = event()
class NavigationViewBackButtonVisible(Enum, Int32):
    Collapsed = 0
    Visible = 1
    Auto = 2
class NavigationViewBackRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.INavigationViewBackRequestedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.NavigationViewBackRequestedEventArgs'
class NavigationViewDisplayMode(Enum, Int32):
    Minimal = 0
    Compact = 1
    Expanded = 2
class NavigationViewDisplayModeChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.INavigationViewDisplayModeChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.NavigationViewDisplayModeChangedEventArgs'
    @winrt_mixinmethod
    def get_DisplayMode(self: win32more.Windows.UI.Xaml.Controls.INavigationViewDisplayModeChangedEventArgs) -> win32more.Windows.UI.Xaml.Controls.NavigationViewDisplayMode: ...
    DisplayMode = property(get_DisplayMode, None)
class _NavigationViewItem_Meta_(ComPtr.__class__):
    pass
class NavigationViewItem(ComPtr, metaclass=_NavigationViewItem_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.NavigationViewItemBase
    default_interface: win32more.Windows.UI.Xaml.Controls.INavigationViewItem
    _classid_ = 'Windows.UI.Xaml.Controls.NavigationViewItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.NavigationViewItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewItemFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.NavigationViewItem: ...
    @winrt_mixinmethod
    def get_Icon(self: win32more.Windows.UI.Xaml.Controls.INavigationViewItem) -> win32more.Windows.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def put_Icon(self: win32more.Windows.UI.Xaml.Controls.INavigationViewItem, value: win32more.Windows.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_mixinmethod
    def get_CompactPaneLength(self: win32more.Windows.UI.Xaml.Controls.INavigationViewItem) -> Double: ...
    @winrt_mixinmethod
    def get_SelectsOnInvoked(self: win32more.Windows.UI.Xaml.Controls.INavigationViewItem2) -> Boolean: ...
    @winrt_mixinmethod
    def put_SelectsOnInvoked(self: win32more.Windows.UI.Xaml.Controls.INavigationViewItem2, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_SelectsOnInvokedProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewItemStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CompactPaneLengthProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CompactPaneLength = property(get_CompactPaneLength, None)
    Icon = property(get_Icon, put_Icon)
    SelectsOnInvoked = property(get_SelectsOnInvoked, put_SelectsOnInvoked)
    _NavigationViewItem_Meta_.CompactPaneLengthProperty = property(get_CompactPaneLengthProperty, None)
    _NavigationViewItem_Meta_.IconProperty = property(get_IconProperty, None)
    _NavigationViewItem_Meta_.SelectsOnInvokedProperty = property(get_SelectsOnInvokedProperty, None)
class NavigationViewItemBase(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.ListViewItem
    default_interface: win32more.Windows.UI.Xaml.Controls.INavigationViewItemBase
    _classid_ = 'Windows.UI.Xaml.Controls.NavigationViewItemBase'
class NavigationViewItemHeader(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.NavigationViewItemBase
    default_interface: win32more.Windows.UI.Xaml.Controls.INavigationViewItemHeader
    _classid_ = 'Windows.UI.Xaml.Controls.NavigationViewItemHeader'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.NavigationViewItemHeader.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewItemHeaderFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.NavigationViewItemHeader: ...
class NavigationViewItemInvokedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.INavigationViewItemInvokedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.NavigationViewItemInvokedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.NavigationViewItemInvokedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.NavigationViewItemInvokedEventArgs: ...
    @winrt_mixinmethod
    def get_InvokedItem(self: win32more.Windows.UI.Xaml.Controls.INavigationViewItemInvokedEventArgs) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_IsSettingsInvoked(self: win32more.Windows.UI.Xaml.Controls.INavigationViewItemInvokedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_InvokedItemContainer(self: win32more.Windows.UI.Xaml.Controls.INavigationViewItemInvokedEventArgs2) -> win32more.Windows.UI.Xaml.Controls.NavigationViewItemBase: ...
    @winrt_mixinmethod
    def get_RecommendedNavigationTransitionInfo(self: win32more.Windows.UI.Xaml.Controls.INavigationViewItemInvokedEventArgs2) -> win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    InvokedItem = property(get_InvokedItem, None)
    InvokedItemContainer = property(get_InvokedItemContainer, None)
    IsSettingsInvoked = property(get_IsSettingsInvoked, None)
    RecommendedNavigationTransitionInfo = property(get_RecommendedNavigationTransitionInfo, None)
class NavigationViewItemSeparator(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.NavigationViewItemBase
    default_interface: win32more.Windows.UI.Xaml.Controls.INavigationViewItemSeparator
    _classid_ = 'Windows.UI.Xaml.Controls.NavigationViewItemSeparator'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.NavigationViewItemSeparator.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewItemSeparatorFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.NavigationViewItemSeparator: ...
class NavigationViewList(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.ListView
    default_interface: win32more.Windows.UI.Xaml.Controls.INavigationViewList
    _classid_ = 'Windows.UI.Xaml.Controls.NavigationViewList'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.NavigationViewList.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewListFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.NavigationViewList: ...
class NavigationViewOverflowLabelMode(Enum, Int32):
    MoreLabel = 0
    NoLabel = 1
class NavigationViewPaneClosingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.INavigationViewPaneClosingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.NavigationViewPaneClosingEventArgs'
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Windows.UI.Xaml.Controls.INavigationViewPaneClosingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Windows.UI.Xaml.Controls.INavigationViewPaneClosingEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
class NavigationViewPaneDisplayMode(Enum, Int32):
    Auto = 0
    Left = 1
    Top = 2
    LeftCompact = 3
    LeftMinimal = 4
class NavigationViewSelectionChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.INavigationViewSelectionChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.NavigationViewSelectionChangedEventArgs'
    @winrt_mixinmethod
    def get_SelectedItem(self: win32more.Windows.UI.Xaml.Controls.INavigationViewSelectionChangedEventArgs) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_IsSettingsSelected(self: win32more.Windows.UI.Xaml.Controls.INavigationViewSelectionChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_SelectedItemContainer(self: win32more.Windows.UI.Xaml.Controls.INavigationViewSelectionChangedEventArgs2) -> win32more.Windows.UI.Xaml.Controls.NavigationViewItemBase: ...
    @winrt_mixinmethod
    def get_RecommendedNavigationTransitionInfo(self: win32more.Windows.UI.Xaml.Controls.INavigationViewSelectionChangedEventArgs2) -> win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    IsSettingsSelected = property(get_IsSettingsSelected, None)
    RecommendedNavigationTransitionInfo = property(get_RecommendedNavigationTransitionInfo, None)
    SelectedItem = property(get_SelectedItem, None)
    SelectedItemContainer = property(get_SelectedItemContainer, None)
class NavigationViewSelectionFollowsFocus(Enum, Int32):
    Disabled = 0
    Enabled = 1
class NavigationViewShoulderNavigationEnabled(Enum, Int32):
    WhenSelectionFollowsFocus = 0
    Always = 1
    Never = 2
class _NavigationViewTemplateSettings_Meta_(ComPtr.__class__):
    pass
class NavigationViewTemplateSettings(ComPtr, metaclass=_NavigationViewTemplateSettings_Meta_):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Controls.INavigationViewTemplateSettings
    _classid_ = 'Windows.UI.Xaml.Controls.NavigationViewTemplateSettings'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.NavigationViewTemplateSettings.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewTemplateSettingsFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.NavigationViewTemplateSettings: ...
    @winrt_mixinmethod
    def get_TopPadding(self: win32more.Windows.UI.Xaml.Controls.INavigationViewTemplateSettings) -> Double: ...
    @winrt_mixinmethod
    def get_OverflowButtonVisibility(self: win32more.Windows.UI.Xaml.Controls.INavigationViewTemplateSettings) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_PaneToggleButtonVisibility(self: win32more.Windows.UI.Xaml.Controls.INavigationViewTemplateSettings) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_BackButtonVisibility(self: win32more.Windows.UI.Xaml.Controls.INavigationViewTemplateSettings) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_TopPaneVisibility(self: win32more.Windows.UI.Xaml.Controls.INavigationViewTemplateSettings) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_LeftPaneVisibility(self: win32more.Windows.UI.Xaml.Controls.INavigationViewTemplateSettings) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_SingleSelectionFollowsFocus(self: win32more.Windows.UI.Xaml.Controls.INavigationViewTemplateSettings) -> Boolean: ...
    @winrt_classmethod
    def get_TopPaddingProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OverflowButtonVisibilityProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneToggleButtonVisibilityProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackButtonVisibilityProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TopPaneVisibilityProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LeftPaneVisibilityProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SingleSelectionFollowsFocusProperty(cls: win32more.Windows.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BackButtonVisibility = property(get_BackButtonVisibility, None)
    LeftPaneVisibility = property(get_LeftPaneVisibility, None)
    OverflowButtonVisibility = property(get_OverflowButtonVisibility, None)
    PaneToggleButtonVisibility = property(get_PaneToggleButtonVisibility, None)
    SingleSelectionFollowsFocus = property(get_SingleSelectionFollowsFocus, None)
    TopPadding = property(get_TopPadding, None)
    TopPaneVisibility = property(get_TopPaneVisibility, None)
    _NavigationViewTemplateSettings_Meta_.BackButtonVisibilityProperty = property(get_BackButtonVisibilityProperty, None)
    _NavigationViewTemplateSettings_Meta_.LeftPaneVisibilityProperty = property(get_LeftPaneVisibilityProperty, None)
    _NavigationViewTemplateSettings_Meta_.OverflowButtonVisibilityProperty = property(get_OverflowButtonVisibilityProperty, None)
    _NavigationViewTemplateSettings_Meta_.PaneToggleButtonVisibilityProperty = property(get_PaneToggleButtonVisibilityProperty, None)
    _NavigationViewTemplateSettings_Meta_.SingleSelectionFollowsFocusProperty = property(get_SingleSelectionFollowsFocusProperty, None)
    _NavigationViewTemplateSettings_Meta_.TopPaddingProperty = property(get_TopPaddingProperty, None)
    _NavigationViewTemplateSettings_Meta_.TopPaneVisibilityProperty = property(get_TopPaneVisibilityProperty, None)
class NotifyEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.INotifyEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.NotifyEventArgs'
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.UI.Xaml.Controls.INotifyEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_CallingUri(self: win32more.Windows.UI.Xaml.Controls.INotifyEventArgs2) -> win32more.Windows.Foundation.Uri: ...
    CallingUri = property(get_CallingUri, None)
    Value = property(get_Value, None)
class NotifyEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c2fdd1f8-7105-4a74-a109-de29dff56b98}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Controls.NotifyEventArgs) -> Void: ...
class Orientation(Enum, Int32):
    Vertical = 0
    Horizontal = 1
class _Page_Meta_(ComPtr.__class__):
    pass
class Page(ComPtr, metaclass=_Page_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.UserControl
    default_interface: win32more.Windows.UI.Xaml.Controls.IPage
    _classid_ = 'Windows.UI.Xaml.Controls.Page'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.Page.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IPageFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Page: ...
    @winrt_mixinmethod
    def get_Frame(self: win32more.Windows.UI.Xaml.Controls.IPage) -> win32more.Windows.UI.Xaml.Controls.Frame: ...
    @winrt_mixinmethod
    def get_NavigationCacheMode(self: win32more.Windows.UI.Xaml.Controls.IPage) -> win32more.Windows.UI.Xaml.Navigation.NavigationCacheMode: ...
    @winrt_mixinmethod
    def put_NavigationCacheMode(self: win32more.Windows.UI.Xaml.Controls.IPage, value: win32more.Windows.UI.Xaml.Navigation.NavigationCacheMode) -> Void: ...
    @winrt_mixinmethod
    def get_TopAppBar(self: win32more.Windows.UI.Xaml.Controls.IPage) -> win32more.Windows.UI.Xaml.Controls.AppBar: ...
    @winrt_mixinmethod
    def put_TopAppBar(self: win32more.Windows.UI.Xaml.Controls.IPage, value: win32more.Windows.UI.Xaml.Controls.AppBar) -> Void: ...
    @winrt_mixinmethod
    def get_BottomAppBar(self: win32more.Windows.UI.Xaml.Controls.IPage) -> win32more.Windows.UI.Xaml.Controls.AppBar: ...
    @winrt_mixinmethod
    def put_BottomAppBar(self: win32more.Windows.UI.Xaml.Controls.IPage, value: win32more.Windows.UI.Xaml.Controls.AppBar) -> Void: ...
    @winrt_mixinmethod
    def OnNavigatedFrom(self: win32more.Windows.UI.Xaml.Controls.IPageOverrides, e: win32more.Windows.UI.Xaml.Navigation.NavigationEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnNavigatedTo(self: win32more.Windows.UI.Xaml.Controls.IPageOverrides, e: win32more.Windows.UI.Xaml.Navigation.NavigationEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnNavigatingFrom(self: win32more.Windows.UI.Xaml.Controls.IPageOverrides, e: win32more.Windows.UI.Xaml.Navigation.NavigatingCancelEventArgs) -> Void: ...
    @winrt_classmethod
    def get_FrameProperty(cls: win32more.Windows.UI.Xaml.Controls.IPageStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TopAppBarProperty(cls: win32more.Windows.UI.Xaml.Controls.IPageStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BottomAppBarProperty(cls: win32more.Windows.UI.Xaml.Controls.IPageStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BottomAppBar = property(get_BottomAppBar, put_BottomAppBar)
    Frame = property(get_Frame, None)
    NavigationCacheMode = property(get_NavigationCacheMode, put_NavigationCacheMode)
    TopAppBar = property(get_TopAppBar, put_TopAppBar)
    _Page_Meta_.BottomAppBarProperty = property(get_BottomAppBarProperty, None)
    _Page_Meta_.FrameProperty = property(get_FrameProperty, None)
    _Page_Meta_.TopAppBarProperty = property(get_TopAppBarProperty, None)
class _Panel_Meta_(ComPtr.__class__):
    pass
class Panel(ComPtr, metaclass=_Panel_Meta_):
    extends: win32more.Windows.UI.Xaml.FrameworkElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IPanel
    _classid_ = 'Windows.UI.Xaml.Controls.Panel'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.Panel.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IPanelFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Panel: ...
    @winrt_mixinmethod
    def get_Children(self: win32more.Windows.UI.Xaml.Controls.IPanel) -> win32more.Windows.UI.Xaml.Controls.UIElementCollection: ...
    @winrt_mixinmethod
    def get_Background(self: win32more.Windows.UI.Xaml.Controls.IPanel) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Background(self: win32more.Windows.UI.Xaml.Controls.IPanel, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_IsItemsHost(self: win32more.Windows.UI.Xaml.Controls.IPanel) -> Boolean: ...
    @winrt_mixinmethod
    def get_ChildrenTransitions(self: win32more.Windows.UI.Xaml.Controls.IPanel) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_ChildrenTransitions(self: win32more.Windows.UI.Xaml.Controls.IPanel, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_BackgroundTransition(self: win32more.Windows.UI.Xaml.Controls.IPanel2) -> win32more.Windows.UI.Xaml.BrushTransition: ...
    @winrt_mixinmethod
    def put_BackgroundTransition(self: win32more.Windows.UI.Xaml.Controls.IPanel2, value: win32more.Windows.UI.Xaml.BrushTransition) -> Void: ...
    @winrt_classmethod
    def get_BackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.IPanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsItemsHostProperty(cls: win32more.Windows.UI.Xaml.Controls.IPanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ChildrenTransitionsProperty(cls: win32more.Windows.UI.Xaml.Controls.IPanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Background = property(get_Background, put_Background)
    BackgroundTransition = property(get_BackgroundTransition, put_BackgroundTransition)
    Children = property(get_Children, None)
    ChildrenTransitions = property(get_ChildrenTransitions, put_ChildrenTransitions)
    IsItemsHost = property(get_IsItemsHost, None)
    _Panel_Meta_.BackgroundProperty = property(get_BackgroundProperty, None)
    _Panel_Meta_.ChildrenTransitionsProperty = property(get_ChildrenTransitionsProperty, None)
    _Panel_Meta_.IsItemsHostProperty = property(get_IsItemsHostProperty, None)
class PanelScrollingDirection(Enum, Int32):
    None_ = 0
    Forward = 1
    Backward = 2
class ParallaxSourceOffsetKind(Enum, Int32):
    Absolute = 0
    Relative = 1
class _ParallaxView_Meta_(ComPtr.__class__):
    pass
class ParallaxView(ComPtr, metaclass=_ParallaxView_Meta_):
    extends: win32more.Windows.UI.Xaml.FrameworkElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IParallaxView
    _classid_ = 'Windows.UI.Xaml.Controls.ParallaxView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ParallaxView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IParallaxViewFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ParallaxView: ...
    @winrt_mixinmethod
    def get_Child(self: win32more.Windows.UI.Xaml.Controls.IParallaxView) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Child(self: win32more.Windows.UI.Xaml.Controls.IParallaxView, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalShift(self: win32more.Windows.UI.Xaml.Controls.IParallaxView) -> Double: ...
    @winrt_mixinmethod
    def put_HorizontalShift(self: win32more.Windows.UI.Xaml.Controls.IParallaxView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalSourceEndOffset(self: win32more.Windows.UI.Xaml.Controls.IParallaxView) -> Double: ...
    @winrt_mixinmethod
    def put_HorizontalSourceEndOffset(self: win32more.Windows.UI.Xaml.Controls.IParallaxView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalSourceOffsetKind(self: win32more.Windows.UI.Xaml.Controls.IParallaxView) -> win32more.Windows.UI.Xaml.Controls.ParallaxSourceOffsetKind: ...
    @winrt_mixinmethod
    def put_HorizontalSourceOffsetKind(self: win32more.Windows.UI.Xaml.Controls.IParallaxView, value: win32more.Windows.UI.Xaml.Controls.ParallaxSourceOffsetKind) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalSourceStartOffset(self: win32more.Windows.UI.Xaml.Controls.IParallaxView) -> Double: ...
    @winrt_mixinmethod
    def put_HorizontalSourceStartOffset(self: win32more.Windows.UI.Xaml.Controls.IParallaxView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_IsHorizontalShiftClamped(self: win32more.Windows.UI.Xaml.Controls.IParallaxView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsHorizontalShiftClamped(self: win32more.Windows.UI.Xaml.Controls.IParallaxView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsVerticalShiftClamped(self: win32more.Windows.UI.Xaml.Controls.IParallaxView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsVerticalShiftClamped(self: win32more.Windows.UI.Xaml.Controls.IParallaxView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MaxHorizontalShiftRatio(self: win32more.Windows.UI.Xaml.Controls.IParallaxView) -> Double: ...
    @winrt_mixinmethod
    def put_MaxHorizontalShiftRatio(self: win32more.Windows.UI.Xaml.Controls.IParallaxView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_MaxVerticalShiftRatio(self: win32more.Windows.UI.Xaml.Controls.IParallaxView) -> Double: ...
    @winrt_mixinmethod
    def put_MaxVerticalShiftRatio(self: win32more.Windows.UI.Xaml.Controls.IParallaxView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Windows.UI.Xaml.Controls.IParallaxView) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Windows.UI.Xaml.Controls.IParallaxView, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalShift(self: win32more.Windows.UI.Xaml.Controls.IParallaxView) -> Double: ...
    @winrt_mixinmethod
    def put_VerticalShift(self: win32more.Windows.UI.Xaml.Controls.IParallaxView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalSourceEndOffset(self: win32more.Windows.UI.Xaml.Controls.IParallaxView) -> Double: ...
    @winrt_mixinmethod
    def put_VerticalSourceEndOffset(self: win32more.Windows.UI.Xaml.Controls.IParallaxView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalSourceOffsetKind(self: win32more.Windows.UI.Xaml.Controls.IParallaxView) -> win32more.Windows.UI.Xaml.Controls.ParallaxSourceOffsetKind: ...
    @winrt_mixinmethod
    def put_VerticalSourceOffsetKind(self: win32more.Windows.UI.Xaml.Controls.IParallaxView, value: win32more.Windows.UI.Xaml.Controls.ParallaxSourceOffsetKind) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalSourceStartOffset(self: win32more.Windows.UI.Xaml.Controls.IParallaxView) -> Double: ...
    @winrt_mixinmethod
    def put_VerticalSourceStartOffset(self: win32more.Windows.UI.Xaml.Controls.IParallaxView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def RefreshAutomaticHorizontalOffsets(self: win32more.Windows.UI.Xaml.Controls.IParallaxView) -> Void: ...
    @winrt_mixinmethod
    def RefreshAutomaticVerticalOffsets(self: win32more.Windows.UI.Xaml.Controls.IParallaxView) -> Void: ...
    @winrt_classmethod
    def get_ChildProperty(cls: win32more.Windows.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalSourceEndOffsetProperty(cls: win32more.Windows.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalSourceOffsetKindProperty(cls: win32more.Windows.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalSourceStartOffsetProperty(cls: win32more.Windows.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxHorizontalShiftRatioProperty(cls: win32more.Windows.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalShiftProperty(cls: win32more.Windows.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsHorizontalShiftClampedProperty(cls: win32more.Windows.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsVerticalShiftClampedProperty(cls: win32more.Windows.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SourceProperty(cls: win32more.Windows.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalSourceEndOffsetProperty(cls: win32more.Windows.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalSourceOffsetKindProperty(cls: win32more.Windows.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalSourceStartOffsetProperty(cls: win32more.Windows.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxVerticalShiftRatioProperty(cls: win32more.Windows.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalShiftProperty(cls: win32more.Windows.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Child = property(get_Child, put_Child)
    HorizontalShift = property(get_HorizontalShift, put_HorizontalShift)
    HorizontalSourceEndOffset = property(get_HorizontalSourceEndOffset, put_HorizontalSourceEndOffset)
    HorizontalSourceOffsetKind = property(get_HorizontalSourceOffsetKind, put_HorizontalSourceOffsetKind)
    HorizontalSourceStartOffset = property(get_HorizontalSourceStartOffset, put_HorizontalSourceStartOffset)
    IsHorizontalShiftClamped = property(get_IsHorizontalShiftClamped, put_IsHorizontalShiftClamped)
    IsVerticalShiftClamped = property(get_IsVerticalShiftClamped, put_IsVerticalShiftClamped)
    MaxHorizontalShiftRatio = property(get_MaxHorizontalShiftRatio, put_MaxHorizontalShiftRatio)
    MaxVerticalShiftRatio = property(get_MaxVerticalShiftRatio, put_MaxVerticalShiftRatio)
    Source = property(get_Source, put_Source)
    VerticalShift = property(get_VerticalShift, put_VerticalShift)
    VerticalSourceEndOffset = property(get_VerticalSourceEndOffset, put_VerticalSourceEndOffset)
    VerticalSourceOffsetKind = property(get_VerticalSourceOffsetKind, put_VerticalSourceOffsetKind)
    VerticalSourceStartOffset = property(get_VerticalSourceStartOffset, put_VerticalSourceStartOffset)
    _ParallaxView_Meta_.ChildProperty = property(get_ChildProperty, None)
    _ParallaxView_Meta_.HorizontalShiftProperty = property(get_HorizontalShiftProperty, None)
    _ParallaxView_Meta_.HorizontalSourceEndOffsetProperty = property(get_HorizontalSourceEndOffsetProperty, None)
    _ParallaxView_Meta_.HorizontalSourceOffsetKindProperty = property(get_HorizontalSourceOffsetKindProperty, None)
    _ParallaxView_Meta_.HorizontalSourceStartOffsetProperty = property(get_HorizontalSourceStartOffsetProperty, None)
    _ParallaxView_Meta_.IsHorizontalShiftClampedProperty = property(get_IsHorizontalShiftClampedProperty, None)
    _ParallaxView_Meta_.IsVerticalShiftClampedProperty = property(get_IsVerticalShiftClampedProperty, None)
    _ParallaxView_Meta_.MaxHorizontalShiftRatioProperty = property(get_MaxHorizontalShiftRatioProperty, None)
    _ParallaxView_Meta_.MaxVerticalShiftRatioProperty = property(get_MaxVerticalShiftRatioProperty, None)
    _ParallaxView_Meta_.SourceProperty = property(get_SourceProperty, None)
    _ParallaxView_Meta_.VerticalShiftProperty = property(get_VerticalShiftProperty, None)
    _ParallaxView_Meta_.VerticalSourceEndOffsetProperty = property(get_VerticalSourceEndOffsetProperty, None)
    _ParallaxView_Meta_.VerticalSourceOffsetKindProperty = property(get_VerticalSourceOffsetKindProperty, None)
    _ParallaxView_Meta_.VerticalSourceStartOffsetProperty = property(get_VerticalSourceStartOffsetProperty, None)
class _PasswordBox_Meta_(ComPtr.__class__):
    pass
class PasswordBox(ComPtr, metaclass=_PasswordBox_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IPasswordBox
    _classid_ = 'Windows.UI.Xaml.Controls.PasswordBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.PasswordBox.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.PasswordBox: ...
    @winrt_mixinmethod
    def get_Password(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Password(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_PasswordChar(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PasswordChar(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IsPasswordRevealButtonEnabled(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPasswordRevealButtonEnabled(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MaxLength(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxLength(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def add_PasswordChanged(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PasswordChanged(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ContextMenuOpening(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox, handler: win32more.Windows.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContextMenuOpening(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def SelectAll(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox2) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox2, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox2) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox2, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderText(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PlaceholderText(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionHighlightColor(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox2) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_mixinmethod
    def put_SelectionHighlightColor(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox2, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_mixinmethod
    def get_PreventKeyboardDisplayOnProgrammaticFocus(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox2) -> Boolean: ...
    @winrt_mixinmethod
    def put_PreventKeyboardDisplayOnProgrammaticFocus(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_Paste(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox2, handler: win32more.Windows.UI.Xaml.Controls.TextControlPasteEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Paste(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_PasswordRevealMode(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox3) -> win32more.Windows.UI.Xaml.Controls.PasswordRevealMode: ...
    @winrt_mixinmethod
    def put_PasswordRevealMode(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox3, value: win32more.Windows.UI.Xaml.Controls.PasswordRevealMode) -> Void: ...
    @winrt_mixinmethod
    def get_TextReadingOrder(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox3) -> win32more.Windows.UI.Xaml.TextReadingOrder: ...
    @winrt_mixinmethod
    def put_TextReadingOrder(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox3, value: win32more.Windows.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_mixinmethod
    def get_InputScope(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox3) -> win32more.Windows.UI.Xaml.Input.InputScope: ...
    @winrt_mixinmethod
    def put_InputScope(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox3, value: win32more.Windows.UI.Xaml.Input.InputScope) -> Void: ...
    @winrt_mixinmethod
    def add_PasswordChanging(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox4, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.PasswordBox, win32more.Windows.UI.Xaml.Controls.PasswordBoxPasswordChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PasswordChanging(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox4, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_CanPasteClipboardContent(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox5) -> Boolean: ...
    @winrt_mixinmethod
    def get_SelectionFlyout(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox5) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def put_SelectionFlyout(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox5, value: win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox5) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox5, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def PasteFromClipboard(self: win32more.Windows.UI.Xaml.Controls.IPasswordBox5) -> Void: ...
    @winrt_classmethod
    def get_CanPasteClipboardContentProperty(cls: win32more.Windows.UI.Xaml.Controls.IPasswordBoxStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionFlyoutProperty(cls: win32more.Windows.UI.Xaml.Controls.IPasswordBoxStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DescriptionProperty(cls: win32more.Windows.UI.Xaml.Controls.IPasswordBoxStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PasswordRevealModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IPasswordBoxStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextReadingOrderProperty(cls: win32more.Windows.UI.Xaml.Controls.IPasswordBoxStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_InputScopeProperty(cls: win32more.Windows.UI.Xaml.Controls.IPasswordBoxStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.IPasswordBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IPasswordBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderTextProperty(cls: win32more.Windows.UI.Xaml.Controls.IPasswordBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionHighlightColorProperty(cls: win32more.Windows.UI.Xaml.Controls.IPasswordBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PreventKeyboardDisplayOnProgrammaticFocusProperty(cls: win32more.Windows.UI.Xaml.Controls.IPasswordBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PasswordProperty(cls: win32more.Windows.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PasswordCharProperty(cls: win32more.Windows.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPasswordRevealButtonEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxLengthProperty(cls: win32more.Windows.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CanPasteClipboardContent = property(get_CanPasteClipboardContent, None)
    Description = property(get_Description, put_Description)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    InputScope = property(get_InputScope, put_InputScope)
    IsPasswordRevealButtonEnabled = property(get_IsPasswordRevealButtonEnabled, put_IsPasswordRevealButtonEnabled)
    MaxLength = property(get_MaxLength, put_MaxLength)
    Password = property(get_Password, put_Password)
    PasswordChar = property(get_PasswordChar, put_PasswordChar)
    PasswordRevealMode = property(get_PasswordRevealMode, put_PasswordRevealMode)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    PreventKeyboardDisplayOnProgrammaticFocus = property(get_PreventKeyboardDisplayOnProgrammaticFocus, put_PreventKeyboardDisplayOnProgrammaticFocus)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    _PasswordBox_Meta_.CanPasteClipboardContentProperty = property(get_CanPasteClipboardContentProperty, None)
    _PasswordBox_Meta_.DescriptionProperty = property(get_DescriptionProperty, None)
    _PasswordBox_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _PasswordBox_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _PasswordBox_Meta_.InputScopeProperty = property(get_InputScopeProperty, None)
    _PasswordBox_Meta_.IsPasswordRevealButtonEnabledProperty = property(get_IsPasswordRevealButtonEnabledProperty, None)
    _PasswordBox_Meta_.MaxLengthProperty = property(get_MaxLengthProperty, None)
    _PasswordBox_Meta_.PasswordCharProperty = property(get_PasswordCharProperty, None)
    _PasswordBox_Meta_.PasswordProperty = property(get_PasswordProperty, None)
    _PasswordBox_Meta_.PasswordRevealModeProperty = property(get_PasswordRevealModeProperty, None)
    _PasswordBox_Meta_.PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    _PasswordBox_Meta_.PreventKeyboardDisplayOnProgrammaticFocusProperty = property(get_PreventKeyboardDisplayOnProgrammaticFocusProperty, None)
    _PasswordBox_Meta_.SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
    _PasswordBox_Meta_.SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    _PasswordBox_Meta_.TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
    PasswordChanged = event()
    ContextMenuOpening = event()
    Paste = event()
    PasswordChanging = event()
class PasswordBoxPasswordChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IPasswordBoxPasswordChangingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.PasswordBoxPasswordChangingEventArgs'
    @winrt_mixinmethod
    def get_IsContentChanging(self: win32more.Windows.UI.Xaml.Controls.IPasswordBoxPasswordChangingEventArgs) -> Boolean: ...
    IsContentChanging = property(get_IsContentChanging, None)
class PasswordRevealMode(Enum, Int32):
    Peek = 0
    Hidden = 1
    Visible = 2
class _PathIcon_Meta_(ComPtr.__class__):
    pass
class PathIcon(ComPtr, metaclass=_PathIcon_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.IconElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IPathIcon
    _classid_ = 'Windows.UI.Xaml.Controls.PathIcon'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.PathIcon.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IPathIconFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.PathIcon: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Windows.UI.Xaml.Controls.IPathIcon) -> win32more.Windows.UI.Xaml.Media.Geometry: ...
    @winrt_mixinmethod
    def put_Data(self: win32more.Windows.UI.Xaml.Controls.IPathIcon, value: win32more.Windows.UI.Xaml.Media.Geometry) -> Void: ...
    @winrt_classmethod
    def get_DataProperty(cls: win32more.Windows.UI.Xaml.Controls.IPathIconStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Data = property(get_Data, put_Data)
    _PathIcon_Meta_.DataProperty = property(get_DataProperty, None)
class _PathIconSource_Meta_(ComPtr.__class__):
    pass
class PathIconSource(ComPtr, metaclass=_PathIconSource_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.IconSource
    default_interface: win32more.Windows.UI.Xaml.Controls.IPathIconSource
    _classid_ = 'Windows.UI.Xaml.Controls.PathIconSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.PathIconSource.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IPathIconSourceFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.PathIconSource: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Windows.UI.Xaml.Controls.IPathIconSource) -> win32more.Windows.UI.Xaml.Media.Geometry: ...
    @winrt_mixinmethod
    def put_Data(self: win32more.Windows.UI.Xaml.Controls.IPathIconSource, value: win32more.Windows.UI.Xaml.Media.Geometry) -> Void: ...
    @winrt_classmethod
    def get_DataProperty(cls: win32more.Windows.UI.Xaml.Controls.IPathIconSourceStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Data = property(get_Data, put_Data)
    _PathIconSource_Meta_.DataProperty = property(get_DataProperty, None)
class _PersonPicture_Meta_(ComPtr.__class__):
    pass
class PersonPicture(ComPtr, metaclass=_PersonPicture_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IPersonPicture
    _classid_ = 'Windows.UI.Xaml.Controls.PersonPicture'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.PersonPicture.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IPersonPictureFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.PersonPicture: ...
    @winrt_mixinmethod
    def get_BadgeNumber(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture) -> Int32: ...
    @winrt_mixinmethod
    def put_BadgeNumber(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_BadgeGlyph(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_BadgeGlyph(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_BadgeImageSource(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_BadgeImageSource(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_BadgeText(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_BadgeText(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IsGroup(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsGroup(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Contact(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture) -> win32more.Windows.ApplicationModel.Contacts.Contact: ...
    @winrt_mixinmethod
    def put_Contact(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture, value: win32more.Windows.ApplicationModel.Contacts.Contact) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayName(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Initials(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Initials(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_PreferSmallImage(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture) -> Boolean: ...
    @winrt_mixinmethod
    def put_PreferSmallImage(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ProfilePicture(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_ProfilePicture(self: win32more.Windows.UI.Xaml.Controls.IPersonPicture, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_classmethod
    def get_BadgeNumberProperty(cls: win32more.Windows.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BadgeGlyphProperty(cls: win32more.Windows.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BadgeImageSourceProperty(cls: win32more.Windows.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BadgeTextProperty(cls: win32more.Windows.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsGroupProperty(cls: win32more.Windows.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContactProperty(cls: win32more.Windows.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisplayNameProperty(cls: win32more.Windows.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_InitialsProperty(cls: win32more.Windows.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PreferSmallImageProperty(cls: win32more.Windows.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ProfilePictureProperty(cls: win32more.Windows.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BadgeGlyph = property(get_BadgeGlyph, put_BadgeGlyph)
    BadgeImageSource = property(get_BadgeImageSource, put_BadgeImageSource)
    BadgeNumber = property(get_BadgeNumber, put_BadgeNumber)
    BadgeText = property(get_BadgeText, put_BadgeText)
    Contact = property(get_Contact, put_Contact)
    DisplayName = property(get_DisplayName, put_DisplayName)
    Initials = property(get_Initials, put_Initials)
    IsGroup = property(get_IsGroup, put_IsGroup)
    PreferSmallImage = property(get_PreferSmallImage, put_PreferSmallImage)
    ProfilePicture = property(get_ProfilePicture, put_ProfilePicture)
    _PersonPicture_Meta_.BadgeGlyphProperty = property(get_BadgeGlyphProperty, None)
    _PersonPicture_Meta_.BadgeImageSourceProperty = property(get_BadgeImageSourceProperty, None)
    _PersonPicture_Meta_.BadgeNumberProperty = property(get_BadgeNumberProperty, None)
    _PersonPicture_Meta_.BadgeTextProperty = property(get_BadgeTextProperty, None)
    _PersonPicture_Meta_.ContactProperty = property(get_ContactProperty, None)
    _PersonPicture_Meta_.DisplayNameProperty = property(get_DisplayNameProperty, None)
    _PersonPicture_Meta_.InitialsProperty = property(get_InitialsProperty, None)
    _PersonPicture_Meta_.IsGroupProperty = property(get_IsGroupProperty, None)
    _PersonPicture_Meta_.PreferSmallImageProperty = property(get_PreferSmallImageProperty, None)
    _PersonPicture_Meta_.ProfilePictureProperty = property(get_ProfilePictureProperty, None)
class PickerConfirmedEventArgs(ComPtr):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Controls.IPickerConfirmedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.PickerConfirmedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.PickerConfirmedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.PickerConfirmedEventArgs: ...
class _PickerFlyout_Meta_(ComPtr.__class__):
    pass
class PickerFlyout(ComPtr, metaclass=_PickerFlyout_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.PickerFlyoutBase
    default_interface: win32more.Windows.UI.Xaml.Controls.IPickerFlyout
    _classid_ = 'Windows.UI.Xaml.Controls.PickerFlyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.PickerFlyout.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.PickerFlyout: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Windows.UI.Xaml.Controls.IPickerFlyout) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Windows.UI.Xaml.Controls.IPickerFlyout, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_ConfirmationButtonsVisible(self: win32more.Windows.UI.Xaml.Controls.IPickerFlyout) -> Boolean: ...
    @winrt_mixinmethod
    def put_ConfirmationButtonsVisible(self: win32more.Windows.UI.Xaml.Controls.IPickerFlyout, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_Confirmed(self: win32more.Windows.UI.Xaml.Controls.IPickerFlyout, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.PickerFlyout, win32more.Windows.UI.Xaml.Controls.PickerConfirmedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Confirmed(self: win32more.Windows.UI.Xaml.Controls.IPickerFlyout, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ShowAtAsync(self: win32more.Windows.UI.Xaml.Controls.IPickerFlyout, target: win32more.Windows.UI.Xaml.FrameworkElement) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Windows.UI.Xaml.Controls.IPickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ConfirmationButtonsVisibleProperty(cls: win32more.Windows.UI.Xaml.Controls.IPickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ConfirmationButtonsVisible = property(get_ConfirmationButtonsVisible, put_ConfirmationButtonsVisible)
    Content = property(get_Content, put_Content)
    _PickerFlyout_Meta_.ConfirmationButtonsVisibleProperty = property(get_ConfirmationButtonsVisibleProperty, None)
    _PickerFlyout_Meta_.ContentProperty = property(get_ContentProperty, None)
    Confirmed = event()
class PickerFlyoutPresenter(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Windows.UI.Xaml.Controls.IPickerFlyoutPresenter
    _classid_ = 'Windows.UI.Xaml.Controls.PickerFlyoutPresenter'
class _Pivot_Meta_(ComPtr.__class__):
    pass
class Pivot(ComPtr, metaclass=_Pivot_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ItemsControl
    default_interface: win32more.Windows.UI.Xaml.Controls.IPivot
    _classid_ = 'Windows.UI.Xaml.Controls.Pivot'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.Pivot.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IPivotFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Pivot: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Windows.UI.Xaml.Controls.IPivot) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Windows.UI.Xaml.Controls.IPivot, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_TitleTemplate(self: win32more.Windows.UI.Xaml.Controls.IPivot) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_TitleTemplate(self: win32more.Windows.UI.Xaml.Controls.IPivot, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IPivot) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IPivot, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedIndex(self: win32more.Windows.UI.Xaml.Controls.IPivot) -> Int32: ...
    @winrt_mixinmethod
    def put_SelectedIndex(self: win32more.Windows.UI.Xaml.Controls.IPivot, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedItem(self: win32more.Windows.UI.Xaml.Controls.IPivot) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_SelectedItem(self: win32more.Windows.UI.Xaml.Controls.IPivot, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_IsLocked(self: win32more.Windows.UI.Xaml.Controls.IPivot) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsLocked(self: win32more.Windows.UI.Xaml.Controls.IPivot, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_SelectionChanged(self: win32more.Windows.UI.Xaml.Controls.IPivot, handler: win32more.Windows.UI.Xaml.Controls.SelectionChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanged(self: win32more.Windows.UI.Xaml.Controls.IPivot, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PivotItemLoading(self: win32more.Windows.UI.Xaml.Controls.IPivot, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.Pivot, win32more.Windows.UI.Xaml.Controls.PivotItemEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PivotItemLoading(self: win32more.Windows.UI.Xaml.Controls.IPivot, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PivotItemLoaded(self: win32more.Windows.UI.Xaml.Controls.IPivot, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.Pivot, win32more.Windows.UI.Xaml.Controls.PivotItemEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PivotItemLoaded(self: win32more.Windows.UI.Xaml.Controls.IPivot, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PivotItemUnloading(self: win32more.Windows.UI.Xaml.Controls.IPivot, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.Pivot, win32more.Windows.UI.Xaml.Controls.PivotItemEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PivotItemUnloading(self: win32more.Windows.UI.Xaml.Controls.IPivot, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PivotItemUnloaded(self: win32more.Windows.UI.Xaml.Controls.IPivot, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.Pivot, win32more.Windows.UI.Xaml.Controls.PivotItemEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PivotItemUnloaded(self: win32more.Windows.UI.Xaml.Controls.IPivot, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_LeftHeader(self: win32more.Windows.UI.Xaml.Controls.IPivot2) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_LeftHeader(self: win32more.Windows.UI.Xaml.Controls.IPivot2, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_LeftHeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IPivot2) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_LeftHeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IPivot2, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_RightHeader(self: win32more.Windows.UI.Xaml.Controls.IPivot2) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_RightHeader(self: win32more.Windows.UI.Xaml.Controls.IPivot2, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_RightHeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IPivot2) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_RightHeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IPivot2, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderFocusVisualPlacement(self: win32more.Windows.UI.Xaml.Controls.IPivot3) -> win32more.Windows.UI.Xaml.Controls.PivotHeaderFocusVisualPlacement: ...
    @winrt_mixinmethod
    def put_HeaderFocusVisualPlacement(self: win32more.Windows.UI.Xaml.Controls.IPivot3, value: win32more.Windows.UI.Xaml.Controls.PivotHeaderFocusVisualPlacement) -> Void: ...
    @winrt_mixinmethod
    def get_IsHeaderItemsCarouselEnabled(self: win32more.Windows.UI.Xaml.Controls.IPivot3) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsHeaderItemsCarouselEnabled(self: win32more.Windows.UI.Xaml.Controls.IPivot3, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_HeaderFocusVisualPlacementProperty(cls: win32more.Windows.UI.Xaml.Controls.IPivotStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsHeaderItemsCarouselEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IPivotStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LeftHeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.IPivotStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LeftHeaderTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IPivotStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RightHeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.IPivotStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RightHeaderTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IPivotStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TitleProperty(cls: win32more.Windows.UI.Xaml.Controls.IPivotStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TitleTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IPivotStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IPivotStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedIndexProperty(cls: win32more.Windows.UI.Xaml.Controls.IPivotStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedItemProperty(cls: win32more.Windows.UI.Xaml.Controls.IPivotStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsLockedProperty(cls: win32more.Windows.UI.Xaml.Controls.IPivotStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SlideInAnimationGroupProperty(cls: win32more.Windows.UI.Xaml.Controls.IPivotStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetSlideInAnimationGroup(cls: win32more.Windows.UI.Xaml.Controls.IPivotStatics, element: win32more.Windows.UI.Xaml.FrameworkElement) -> win32more.Windows.UI.Xaml.Controls.PivotSlideInAnimationGroup: ...
    @winrt_classmethod
    def SetSlideInAnimationGroup(cls: win32more.Windows.UI.Xaml.Controls.IPivotStatics, element: win32more.Windows.UI.Xaml.FrameworkElement, value: win32more.Windows.UI.Xaml.Controls.PivotSlideInAnimationGroup) -> Void: ...
    HeaderFocusVisualPlacement = property(get_HeaderFocusVisualPlacement, put_HeaderFocusVisualPlacement)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsHeaderItemsCarouselEnabled = property(get_IsHeaderItemsCarouselEnabled, put_IsHeaderItemsCarouselEnabled)
    IsLocked = property(get_IsLocked, put_IsLocked)
    LeftHeader = property(get_LeftHeader, put_LeftHeader)
    LeftHeaderTemplate = property(get_LeftHeaderTemplate, put_LeftHeaderTemplate)
    RightHeader = property(get_RightHeader, put_RightHeader)
    RightHeaderTemplate = property(get_RightHeaderTemplate, put_RightHeaderTemplate)
    SelectedIndex = property(get_SelectedIndex, put_SelectedIndex)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    Title = property(get_Title, put_Title)
    TitleTemplate = property(get_TitleTemplate, put_TitleTemplate)
    _Pivot_Meta_.HeaderFocusVisualPlacementProperty = property(get_HeaderFocusVisualPlacementProperty, None)
    _Pivot_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _Pivot_Meta_.IsHeaderItemsCarouselEnabledProperty = property(get_IsHeaderItemsCarouselEnabledProperty, None)
    _Pivot_Meta_.IsLockedProperty = property(get_IsLockedProperty, None)
    _Pivot_Meta_.LeftHeaderProperty = property(get_LeftHeaderProperty, None)
    _Pivot_Meta_.LeftHeaderTemplateProperty = property(get_LeftHeaderTemplateProperty, None)
    _Pivot_Meta_.RightHeaderProperty = property(get_RightHeaderProperty, None)
    _Pivot_Meta_.RightHeaderTemplateProperty = property(get_RightHeaderTemplateProperty, None)
    _Pivot_Meta_.SelectedIndexProperty = property(get_SelectedIndexProperty, None)
    _Pivot_Meta_.SelectedItemProperty = property(get_SelectedItemProperty, None)
    _Pivot_Meta_.SlideInAnimationGroupProperty = property(get_SlideInAnimationGroupProperty, None)
    _Pivot_Meta_.TitleProperty = property(get_TitleProperty, None)
    _Pivot_Meta_.TitleTemplateProperty = property(get_TitleTemplateProperty, None)
    SelectionChanged = event()
    PivotItemLoading = event()
    PivotItemLoaded = event()
    PivotItemUnloading = event()
    PivotItemUnloaded = event()
class PivotHeaderFocusVisualPlacement(Enum, Int32):
    ItemHeaders = 0
    SelectedItemHeader = 1
class _PivotItem_Meta_(ComPtr.__class__):
    pass
class PivotItem(ComPtr, metaclass=_PivotItem_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Windows.UI.Xaml.Controls.IPivotItem
    _classid_ = 'Windows.UI.Xaml.Controls.PivotItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.PivotItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IPivotItemFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.PivotItem: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Windows.UI.Xaml.Controls.IPivotItem) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Windows.UI.Xaml.Controls.IPivotItem, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.IPivotItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Header = property(get_Header, put_Header)
    _PivotItem_Meta_.HeaderProperty = property(get_HeaderProperty, None)
class PivotItemEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IPivotItemEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.PivotItemEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.PivotItemEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.PivotItemEventArgs: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Windows.UI.Xaml.Controls.IPivotItemEventArgs) -> win32more.Windows.UI.Xaml.Controls.PivotItem: ...
    @winrt_mixinmethod
    def put_Item(self: win32more.Windows.UI.Xaml.Controls.IPivotItemEventArgs, value: win32more.Windows.UI.Xaml.Controls.PivotItem) -> Void: ...
    Item = property(get_Item, put_Item)
class PivotSlideInAnimationGroup(Enum, Int32):
    Default = 0
    GroupOne = 1
    GroupTwo = 2
    GroupThree = 3
class _ProgressBar_Meta_(ComPtr.__class__):
    pass
class ProgressBar(ComPtr, metaclass=_ProgressBar_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.RangeBase
    default_interface: win32more.Windows.UI.Xaml.Controls.IProgressBar
    _classid_ = 'Windows.UI.Xaml.Controls.ProgressBar'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ProgressBar.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IProgressBarFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ProgressBar: ...
    @winrt_mixinmethod
    def get_IsIndeterminate(self: win32more.Windows.UI.Xaml.Controls.IProgressBar) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsIndeterminate(self: win32more.Windows.UI.Xaml.Controls.IProgressBar, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ShowError(self: win32more.Windows.UI.Xaml.Controls.IProgressBar) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShowError(self: win32more.Windows.UI.Xaml.Controls.IProgressBar, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ShowPaused(self: win32more.Windows.UI.Xaml.Controls.IProgressBar) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShowPaused(self: win32more.Windows.UI.Xaml.Controls.IProgressBar, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Windows.UI.Xaml.Controls.IProgressBar) -> win32more.Windows.UI.Xaml.Controls.Primitives.ProgressBarTemplateSettings: ...
    @winrt_classmethod
    def get_IsIndeterminateProperty(cls: win32more.Windows.UI.Xaml.Controls.IProgressBarStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ShowErrorProperty(cls: win32more.Windows.UI.Xaml.Controls.IProgressBarStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ShowPausedProperty(cls: win32more.Windows.UI.Xaml.Controls.IProgressBarStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsIndeterminate = property(get_IsIndeterminate, put_IsIndeterminate)
    ShowError = property(get_ShowError, put_ShowError)
    ShowPaused = property(get_ShowPaused, put_ShowPaused)
    TemplateSettings = property(get_TemplateSettings, None)
    _ProgressBar_Meta_.IsIndeterminateProperty = property(get_IsIndeterminateProperty, None)
    _ProgressBar_Meta_.ShowErrorProperty = property(get_ShowErrorProperty, None)
    _ProgressBar_Meta_.ShowPausedProperty = property(get_ShowPausedProperty, None)
class _ProgressRing_Meta_(ComPtr.__class__):
    pass
class ProgressRing(ComPtr, metaclass=_ProgressRing_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IProgressRing
    _classid_ = 'Windows.UI.Xaml.Controls.ProgressRing'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ProgressRing.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.ProgressRing: ...
    @winrt_mixinmethod
    def get_IsActive(self: win32more.Windows.UI.Xaml.Controls.IProgressRing) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsActive(self: win32more.Windows.UI.Xaml.Controls.IProgressRing, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Windows.UI.Xaml.Controls.IProgressRing) -> win32more.Windows.UI.Xaml.Controls.Primitives.ProgressRingTemplateSettings: ...
    @winrt_classmethod
    def get_IsActiveProperty(cls: win32more.Windows.UI.Xaml.Controls.IProgressRingStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsActive = property(get_IsActive, put_IsActive)
    TemplateSettings = property(get_TemplateSettings, None)
    _ProgressRing_Meta_.IsActiveProperty = property(get_IsActiveProperty, None)
class _RadioButton_Meta_(ComPtr.__class__):
    pass
class RadioButton(ComPtr, metaclass=_RadioButton_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.ToggleButton
    default_interface: win32more.Windows.UI.Xaml.Controls.IRadioButton
    _classid_ = 'Windows.UI.Xaml.Controls.RadioButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.RadioButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IRadioButtonFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RadioButton: ...
    @winrt_mixinmethod
    def get_GroupName(self: win32more.Windows.UI.Xaml.Controls.IRadioButton) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_GroupName(self: win32more.Windows.UI.Xaml.Controls.IRadioButton, value: WinRT_String) -> Void: ...
    @winrt_classmethod
    def get_GroupNameProperty(cls: win32more.Windows.UI.Xaml.Controls.IRadioButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    GroupName = property(get_GroupName, put_GroupName)
    _RadioButton_Meta_.GroupNameProperty = property(get_GroupNameProperty, None)
class _RatingControl_Meta_(ComPtr.__class__):
    pass
class RatingControl(ComPtr, metaclass=_RatingControl_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IRatingControl
    _classid_ = 'Windows.UI.Xaml.Controls.RatingControl'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.RatingControl.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IRatingControlFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RatingControl: ...
    @winrt_mixinmethod
    def get_Caption(self: win32more.Windows.UI.Xaml.Controls.IRatingControl) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Caption(self: win32more.Windows.UI.Xaml.Controls.IRatingControl, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_InitialSetValue(self: win32more.Windows.UI.Xaml.Controls.IRatingControl) -> Int32: ...
    @winrt_mixinmethod
    def put_InitialSetValue(self: win32more.Windows.UI.Xaml.Controls.IRatingControl, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_IsClearEnabled(self: win32more.Windows.UI.Xaml.Controls.IRatingControl) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsClearEnabled(self: win32more.Windows.UI.Xaml.Controls.IRatingControl, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsReadOnly(self: win32more.Windows.UI.Xaml.Controls.IRatingControl) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsReadOnly(self: win32more.Windows.UI.Xaml.Controls.IRatingControl, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MaxRating(self: win32more.Windows.UI.Xaml.Controls.IRatingControl) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxRating(self: win32more.Windows.UI.Xaml.Controls.IRatingControl, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderValue(self: win32more.Windows.UI.Xaml.Controls.IRatingControl) -> Double: ...
    @winrt_mixinmethod
    def put_PlaceholderValue(self: win32more.Windows.UI.Xaml.Controls.IRatingControl, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ItemInfo(self: win32more.Windows.UI.Xaml.Controls.IRatingControl) -> win32more.Windows.UI.Xaml.Controls.RatingItemInfo: ...
    @winrt_mixinmethod
    def put_ItemInfo(self: win32more.Windows.UI.Xaml.Controls.IRatingControl, value: win32more.Windows.UI.Xaml.Controls.RatingItemInfo) -> Void: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.UI.Xaml.Controls.IRatingControl) -> Double: ...
    @winrt_mixinmethod
    def put_Value(self: win32more.Windows.UI.Xaml.Controls.IRatingControl, value: Double) -> Void: ...
    @winrt_mixinmethod
    def add_ValueChanged(self: win32more.Windows.UI.Xaml.Controls.IRatingControl, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RatingControl, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ValueChanged(self: win32more.Windows.UI.Xaml.Controls.IRatingControl, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_CaptionProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_InitialSetValueProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsClearEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsReadOnlyProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxRatingProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderValueProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemInfoProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ValueProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Caption = property(get_Caption, put_Caption)
    InitialSetValue = property(get_InitialSetValue, put_InitialSetValue)
    IsClearEnabled = property(get_IsClearEnabled, put_IsClearEnabled)
    IsReadOnly = property(get_IsReadOnly, put_IsReadOnly)
    ItemInfo = property(get_ItemInfo, put_ItemInfo)
    MaxRating = property(get_MaxRating, put_MaxRating)
    PlaceholderValue = property(get_PlaceholderValue, put_PlaceholderValue)
    Value = property(get_Value, put_Value)
    _RatingControl_Meta_.CaptionProperty = property(get_CaptionProperty, None)
    _RatingControl_Meta_.InitialSetValueProperty = property(get_InitialSetValueProperty, None)
    _RatingControl_Meta_.IsClearEnabledProperty = property(get_IsClearEnabledProperty, None)
    _RatingControl_Meta_.IsReadOnlyProperty = property(get_IsReadOnlyProperty, None)
    _RatingControl_Meta_.ItemInfoProperty = property(get_ItemInfoProperty, None)
    _RatingControl_Meta_.MaxRatingProperty = property(get_MaxRatingProperty, None)
    _RatingControl_Meta_.PlaceholderValueProperty = property(get_PlaceholderValueProperty, None)
    _RatingControl_Meta_.ValueProperty = property(get_ValueProperty, None)
    ValueChanged = event()
class _RatingItemFontInfo_Meta_(ComPtr.__class__):
    pass
class RatingItemFontInfo(ComPtr, metaclass=_RatingItemFontInfo_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.RatingItemInfo
    default_interface: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfo
    _classid_ = 'Windows.UI.Xaml.Controls.RatingItemFontInfo'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.RatingItemFontInfo.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfoFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RatingItemFontInfo: ...
    @winrt_mixinmethod
    def get_DisabledGlyph(self: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisabledGlyph(self: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfo, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Glyph(self: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Glyph(self: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfo, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_PointerOverGlyph(self: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PointerOverGlyph(self: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfo, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_PointerOverPlaceholderGlyph(self: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PointerOverPlaceholderGlyph(self: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfo, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderGlyph(self: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PlaceholderGlyph(self: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfo, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_UnsetGlyph(self: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_UnsetGlyph(self: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfo, value: WinRT_String) -> Void: ...
    @winrt_classmethod
    def get_DisabledGlyphProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfoStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GlyphProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfoStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderGlyphProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfoStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PointerOverGlyphProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfoStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PointerOverPlaceholderGlyphProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfoStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_UnsetGlyphProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingItemFontInfoStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DisabledGlyph = property(get_DisabledGlyph, put_DisabledGlyph)
    Glyph = property(get_Glyph, put_Glyph)
    PlaceholderGlyph = property(get_PlaceholderGlyph, put_PlaceholderGlyph)
    PointerOverGlyph = property(get_PointerOverGlyph, put_PointerOverGlyph)
    PointerOverPlaceholderGlyph = property(get_PointerOverPlaceholderGlyph, put_PointerOverPlaceholderGlyph)
    UnsetGlyph = property(get_UnsetGlyph, put_UnsetGlyph)
    _RatingItemFontInfo_Meta_.DisabledGlyphProperty = property(get_DisabledGlyphProperty, None)
    _RatingItemFontInfo_Meta_.GlyphProperty = property(get_GlyphProperty, None)
    _RatingItemFontInfo_Meta_.PlaceholderGlyphProperty = property(get_PlaceholderGlyphProperty, None)
    _RatingItemFontInfo_Meta_.PointerOverGlyphProperty = property(get_PointerOverGlyphProperty, None)
    _RatingItemFontInfo_Meta_.PointerOverPlaceholderGlyphProperty = property(get_PointerOverPlaceholderGlyphProperty, None)
    _RatingItemFontInfo_Meta_.UnsetGlyphProperty = property(get_UnsetGlyphProperty, None)
class _RatingItemImageInfo_Meta_(ComPtr.__class__):
    pass
class RatingItemImageInfo(ComPtr, metaclass=_RatingItemImageInfo_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.RatingItemInfo
    default_interface: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfo
    _classid_ = 'Windows.UI.Xaml.Controls.RatingItemImageInfo'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.RatingItemImageInfo.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfoFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RatingItemImageInfo: ...
    @winrt_mixinmethod
    def get_DisabledImage(self: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfo) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_DisabledImage(self: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfo, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_Image(self: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfo) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_Image(self: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfo, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderImage(self: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfo) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_PlaceholderImage(self: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfo, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_PointerOverImage(self: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfo) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_PointerOverImage(self: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfo, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_PointerOverPlaceholderImage(self: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfo) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_PointerOverPlaceholderImage(self: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfo, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_UnsetImage(self: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfo) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_UnsetImage(self: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfo, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_classmethod
    def get_DisabledImageProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfoStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ImageProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfoStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderImageProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfoStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PointerOverImageProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfoStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PointerOverPlaceholderImageProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfoStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_UnsetImageProperty(cls: win32more.Windows.UI.Xaml.Controls.IRatingItemImageInfoStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DisabledImage = property(get_DisabledImage, put_DisabledImage)
    Image = property(get_Image, put_Image)
    PlaceholderImage = property(get_PlaceholderImage, put_PlaceholderImage)
    PointerOverImage = property(get_PointerOverImage, put_PointerOverImage)
    PointerOverPlaceholderImage = property(get_PointerOverPlaceholderImage, put_PointerOverPlaceholderImage)
    UnsetImage = property(get_UnsetImage, put_UnsetImage)
    _RatingItemImageInfo_Meta_.DisabledImageProperty = property(get_DisabledImageProperty, None)
    _RatingItemImageInfo_Meta_.ImageProperty = property(get_ImageProperty, None)
    _RatingItemImageInfo_Meta_.PlaceholderImageProperty = property(get_PlaceholderImageProperty, None)
    _RatingItemImageInfo_Meta_.PointerOverImageProperty = property(get_PointerOverImageProperty, None)
    _RatingItemImageInfo_Meta_.PointerOverPlaceholderImageProperty = property(get_PointerOverPlaceholderImageProperty, None)
    _RatingItemImageInfo_Meta_.UnsetImageProperty = property(get_UnsetImageProperty, None)
class RatingItemInfo(ComPtr):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Controls.IRatingItemInfo
    _classid_ = 'Windows.UI.Xaml.Controls.RatingItemInfo'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.RatingItemInfo.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IRatingItemInfoFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RatingItemInfo: ...
class _RefreshContainer_Meta_(ComPtr.__class__):
    pass
class RefreshContainer(ComPtr, metaclass=_RefreshContainer_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Windows.UI.Xaml.Controls.IRefreshContainer
    _classid_ = 'Windows.UI.Xaml.Controls.RefreshContainer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.RefreshContainer.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IRefreshContainerFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RefreshContainer: ...
    @winrt_mixinmethod
    def get_Visualizer(self: win32more.Windows.UI.Xaml.Controls.IRefreshContainer) -> win32more.Windows.UI.Xaml.Controls.RefreshVisualizer: ...
    @winrt_mixinmethod
    def put_Visualizer(self: win32more.Windows.UI.Xaml.Controls.IRefreshContainer, value: win32more.Windows.UI.Xaml.Controls.RefreshVisualizer) -> Void: ...
    @winrt_mixinmethod
    def get_PullDirection(self: win32more.Windows.UI.Xaml.Controls.IRefreshContainer) -> win32more.Windows.UI.Xaml.Controls.RefreshPullDirection: ...
    @winrt_mixinmethod
    def put_PullDirection(self: win32more.Windows.UI.Xaml.Controls.IRefreshContainer, value: win32more.Windows.UI.Xaml.Controls.RefreshPullDirection) -> Void: ...
    @winrt_mixinmethod
    def add_RefreshRequested(self: win32more.Windows.UI.Xaml.Controls.IRefreshContainer, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RefreshContainer, win32more.Windows.UI.Xaml.Controls.RefreshRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_RefreshRequested(self: win32more.Windows.UI.Xaml.Controls.IRefreshContainer, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def RequestRefresh(self: win32more.Windows.UI.Xaml.Controls.IRefreshContainer) -> Void: ...
    @winrt_classmethod
    def get_VisualizerProperty(cls: win32more.Windows.UI.Xaml.Controls.IRefreshContainerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PullDirectionProperty(cls: win32more.Windows.UI.Xaml.Controls.IRefreshContainerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    PullDirection = property(get_PullDirection, put_PullDirection)
    Visualizer = property(get_Visualizer, put_Visualizer)
    _RefreshContainer_Meta_.PullDirectionProperty = property(get_PullDirectionProperty, None)
    _RefreshContainer_Meta_.VisualizerProperty = property(get_VisualizerProperty, None)
    RefreshRequested = event()
class RefreshInteractionRatioChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IRefreshInteractionRatioChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.RefreshInteractionRatioChangedEventArgs'
    @winrt_mixinmethod
    def get_InteractionRatio(self: win32more.Windows.UI.Xaml.Controls.IRefreshInteractionRatioChangedEventArgs) -> Double: ...
    InteractionRatio = property(get_InteractionRatio, None)
class RefreshPullDirection(Enum, Int32):
    LeftToRight = 0
    TopToBottom = 1
    RightToLeft = 2
    BottomToTop = 3
class RefreshRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IRefreshRequestedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.RefreshRequestedEventArgs'
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.UI.Xaml.Controls.IRefreshRequestedEventArgs) -> win32more.Windows.Foundation.Deferral: ...
class RefreshStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IRefreshStateChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.RefreshStateChangedEventArgs'
    @winrt_mixinmethod
    def get_OldState(self: win32more.Windows.UI.Xaml.Controls.IRefreshStateChangedEventArgs) -> win32more.Windows.UI.Xaml.Controls.RefreshVisualizerState: ...
    @winrt_mixinmethod
    def get_NewState(self: win32more.Windows.UI.Xaml.Controls.IRefreshStateChangedEventArgs) -> win32more.Windows.UI.Xaml.Controls.RefreshVisualizerState: ...
    NewState = property(get_NewState, None)
    OldState = property(get_OldState, None)
class _RefreshVisualizer_Meta_(ComPtr.__class__):
    pass
class RefreshVisualizer(ComPtr, metaclass=_RefreshVisualizer_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IRefreshVisualizer
    _classid_ = 'Windows.UI.Xaml.Controls.RefreshVisualizer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.RefreshVisualizer.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IRefreshVisualizerFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RefreshVisualizer: ...
    @winrt_mixinmethod
    def RequestRefresh(self: win32more.Windows.UI.Xaml.Controls.IRefreshVisualizer) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Windows.UI.Xaml.Controls.IRefreshVisualizer) -> win32more.Windows.UI.Xaml.Controls.RefreshVisualizerOrientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Windows.UI.Xaml.Controls.IRefreshVisualizer, value: win32more.Windows.UI.Xaml.Controls.RefreshVisualizerOrientation) -> Void: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Windows.UI.Xaml.Controls.IRefreshVisualizer) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Windows.UI.Xaml.Controls.IRefreshVisualizer, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.UI.Xaml.Controls.IRefreshVisualizer) -> win32more.Windows.UI.Xaml.Controls.RefreshVisualizerState: ...
    @winrt_mixinmethod
    def add_RefreshRequested(self: win32more.Windows.UI.Xaml.Controls.IRefreshVisualizer, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RefreshVisualizer, win32more.Windows.UI.Xaml.Controls.RefreshRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_RefreshRequested(self: win32more.Windows.UI.Xaml.Controls.IRefreshVisualizer, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_RefreshStateChanged(self: win32more.Windows.UI.Xaml.Controls.IRefreshVisualizer, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RefreshVisualizer, win32more.Windows.UI.Xaml.Controls.RefreshStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_RefreshStateChanged(self: win32more.Windows.UI.Xaml.Controls.IRefreshVisualizer, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_InfoProviderProperty(cls: win32more.Windows.UI.Xaml.Controls.IRefreshVisualizerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Windows.UI.Xaml.Controls.IRefreshVisualizerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Windows.UI.Xaml.Controls.IRefreshVisualizerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StateProperty(cls: win32more.Windows.UI.Xaml.Controls.IRefreshVisualizerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Content = property(get_Content, put_Content)
    Orientation = property(get_Orientation, put_Orientation)
    State = property(get_State, None)
    _RefreshVisualizer_Meta_.ContentProperty = property(get_ContentProperty, None)
    _RefreshVisualizer_Meta_.InfoProviderProperty = property(get_InfoProviderProperty, None)
    _RefreshVisualizer_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _RefreshVisualizer_Meta_.StateProperty = property(get_StateProperty, None)
    RefreshRequested = event()
    RefreshStateChanged = event()
class RefreshVisualizerOrientation(Enum, Int32):
    Auto = 0
    Normal = 1
    Rotate90DegreesCounterclockwise = 2
    Rotate270DegreesCounterclockwise = 3
class RefreshVisualizerState(Enum, Int32):
    Idle = 0
    Peeking = 1
    Interacting = 2
    Pending = 3
    Refreshing = 4
class _RelativePanel_Meta_(ComPtr.__class__):
    pass
class RelativePanel(ComPtr, metaclass=_RelativePanel_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Panel
    default_interface: win32more.Windows.UI.Xaml.Controls.IRelativePanel
    _classid_ = 'Windows.UI.Xaml.Controls.RelativePanel'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.RelativePanel.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RelativePanel: ...
    @winrt_mixinmethod
    def get_BorderBrush(self: win32more.Windows.UI.Xaml.Controls.IRelativePanel) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BorderBrush(self: win32more.Windows.UI.Xaml.Controls.IRelativePanel, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BorderThickness(self: win32more.Windows.UI.Xaml.Controls.IRelativePanel) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_BorderThickness(self: win32more.Windows.UI.Xaml.Controls.IRelativePanel, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_CornerRadius(self: win32more.Windows.UI.Xaml.Controls.IRelativePanel) -> win32more.Windows.UI.Xaml.CornerRadius: ...
    @winrt_mixinmethod
    def put_CornerRadius(self: win32more.Windows.UI.Xaml.Controls.IRelativePanel, value: win32more.Windows.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Windows.UI.Xaml.Controls.IRelativePanel) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Windows.UI.Xaml.Controls.IRelativePanel, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_BackgroundSizing(self: win32more.Windows.UI.Xaml.Controls.IRelativePanel2) -> win32more.Windows.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_mixinmethod
    def put_BackgroundSizing(self: win32more.Windows.UI.Xaml.Controls.IRelativePanel2, value: win32more.Windows.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_classmethod
    def get_BackgroundSizingProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LeftOfProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetLeftOf(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_classmethod
    def SetLeftOf(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_AboveProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAbove(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_classmethod
    def SetAbove(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_RightOfProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetRightOf(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_classmethod
    def SetRightOf(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_BelowProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetBelow(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_classmethod
    def SetBelow(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_AlignHorizontalCenterWithProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignHorizontalCenterWith(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_classmethod
    def SetAlignHorizontalCenterWith(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_AlignVerticalCenterWithProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignVerticalCenterWith(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_classmethod
    def SetAlignVerticalCenterWith(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_AlignLeftWithProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignLeftWith(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_classmethod
    def SetAlignLeftWith(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_AlignTopWithProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignTopWith(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_classmethod
    def SetAlignTopWith(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_AlignRightWithProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignRightWith(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_classmethod
    def SetAlignRightWith(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_AlignBottomWithProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignBottomWith(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_classmethod
    def SetAlignBottomWith(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_AlignLeftWithPanelProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignLeftWithPanel(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_classmethod
    def SetAlignLeftWithPanel(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_AlignTopWithPanelProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignTopWithPanel(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_classmethod
    def SetAlignTopWithPanel(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_AlignRightWithPanelProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignRightWithPanel(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_classmethod
    def SetAlignRightWithPanel(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_AlignBottomWithPanelProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignBottomWithPanel(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_classmethod
    def SetAlignBottomWithPanel(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_AlignHorizontalCenterWithPanelProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignHorizontalCenterWithPanel(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_classmethod
    def SetAlignHorizontalCenterWithPanel(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_AlignVerticalCenterWithPanelProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignVerticalCenterWithPanel(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_classmethod
    def SetAlignVerticalCenterWithPanel(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Windows.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_BorderBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderThicknessProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CornerRadiusProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Windows.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    Padding = property(get_Padding, put_Padding)
    _RelativePanel_Meta_.AboveProperty = property(get_AboveProperty, None)
    _RelativePanel_Meta_.AlignBottomWithPanelProperty = property(get_AlignBottomWithPanelProperty, None)
    _RelativePanel_Meta_.AlignBottomWithProperty = property(get_AlignBottomWithProperty, None)
    _RelativePanel_Meta_.AlignHorizontalCenterWithPanelProperty = property(get_AlignHorizontalCenterWithPanelProperty, None)
    _RelativePanel_Meta_.AlignHorizontalCenterWithProperty = property(get_AlignHorizontalCenterWithProperty, None)
    _RelativePanel_Meta_.AlignLeftWithPanelProperty = property(get_AlignLeftWithPanelProperty, None)
    _RelativePanel_Meta_.AlignLeftWithProperty = property(get_AlignLeftWithProperty, None)
    _RelativePanel_Meta_.AlignRightWithPanelProperty = property(get_AlignRightWithPanelProperty, None)
    _RelativePanel_Meta_.AlignRightWithProperty = property(get_AlignRightWithProperty, None)
    _RelativePanel_Meta_.AlignTopWithPanelProperty = property(get_AlignTopWithPanelProperty, None)
    _RelativePanel_Meta_.AlignTopWithProperty = property(get_AlignTopWithProperty, None)
    _RelativePanel_Meta_.AlignVerticalCenterWithPanelProperty = property(get_AlignVerticalCenterWithPanelProperty, None)
    _RelativePanel_Meta_.AlignVerticalCenterWithProperty = property(get_AlignVerticalCenterWithProperty, None)
    _RelativePanel_Meta_.BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    _RelativePanel_Meta_.BelowProperty = property(get_BelowProperty, None)
    _RelativePanel_Meta_.BorderBrushProperty = property(get_BorderBrushProperty, None)
    _RelativePanel_Meta_.BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    _RelativePanel_Meta_.CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    _RelativePanel_Meta_.LeftOfProperty = property(get_LeftOfProperty, None)
    _RelativePanel_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    _RelativePanel_Meta_.RightOfProperty = property(get_RightOfProperty, None)
class RequiresPointer(Enum, Int32):
    Never = 0
    WhenEngaged = 1
    WhenFocused = 2
class _RichEditBox_Meta_(ComPtr.__class__):
    pass
class RichEditBox(ComPtr, metaclass=_RichEditBox_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IRichEditBox
    _classid_ = 'Windows.UI.Xaml.Controls.RichEditBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.RichEditBox.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.RichEditBox: ...
    @winrt_mixinmethod
    def get_IsReadOnly(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsReadOnly(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AcceptsReturn(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_AcceptsReturn(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TextAlignment(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox) -> win32more.Windows.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_TextAlignment(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox, value: win32more.Windows.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_TextWrapping(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox) -> win32more.Windows.UI.Xaml.TextWrapping: ...
    @winrt_mixinmethod
    def put_TextWrapping(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox, value: win32more.Windows.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_mixinmethod
    def get_IsSpellCheckEnabled(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSpellCheckEnabled(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextPredictionEnabled(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextPredictionEnabled(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Document(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox) -> win32more.Windows.UI.Text.ITextDocument: ...
    @winrt_mixinmethod
    def get_InputScope(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox) -> win32more.Windows.UI.Xaml.Input.InputScope: ...
    @winrt_mixinmethod
    def put_InputScope(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox, value: win32more.Windows.UI.Xaml.Input.InputScope) -> Void: ...
    @winrt_mixinmethod
    def add_TextChanged(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextChanged(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SelectionChanged(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanged(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ContextMenuOpening(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox, handler: win32more.Windows.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContextMenuOpening(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox2) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox2, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox2) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox2, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderText(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PlaceholderText(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionHighlightColor(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox2) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_mixinmethod
    def put_SelectionHighlightColor(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox2, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_mixinmethod
    def get_PreventKeyboardDisplayOnProgrammaticFocus(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox2) -> Boolean: ...
    @winrt_mixinmethod
    def put_PreventKeyboardDisplayOnProgrammaticFocus(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsColorFontEnabled(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsColorFontEnabled(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_Paste(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox2, handler: win32more.Windows.UI.Xaml.Controls.TextControlPasteEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Paste(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextCompositionStarted(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.TextCompositionStartedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextCompositionStarted(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextCompositionChanged(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.TextCompositionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextCompositionChanged(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextCompositionEnded(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.TextCompositionEndedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextCompositionEnded(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_TextReadingOrder(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox3) -> win32more.Windows.UI.Xaml.TextReadingOrder: ...
    @winrt_mixinmethod
    def put_TextReadingOrder(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox3, value: win32more.Windows.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_mixinmethod
    def get_DesiredCandidateWindowAlignment(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox3) -> win32more.Windows.UI.Xaml.Controls.CandidateWindowAlignment: ...
    @winrt_mixinmethod
    def put_DesiredCandidateWindowAlignment(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox3, value: win32more.Windows.UI.Xaml.Controls.CandidateWindowAlignment) -> Void: ...
    @winrt_mixinmethod
    def add_CandidateWindowBoundsChanged(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.CandidateWindowBoundsChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CandidateWindowBoundsChanged(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextChanging(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.RichEditBoxTextChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextChanging(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetLinguisticAlternativesAsync(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox4) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    @winrt_mixinmethod
    def get_ClipboardCopyFormat(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox4) -> win32more.Windows.UI.Xaml.Controls.RichEditClipboardFormat: ...
    @winrt_mixinmethod
    def put_ClipboardCopyFormat(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox4, value: win32more.Windows.UI.Xaml.Controls.RichEditClipboardFormat) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionHighlightColorWhenNotFocused(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox5) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_mixinmethod
    def put_SelectionHighlightColorWhenNotFocused(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox5, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_mixinmethod
    def get_MaxLength(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox5) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxLength(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox5, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalTextAlignment(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox6) -> win32more.Windows.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalTextAlignment(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox6, value: win32more.Windows.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_CharacterCasing(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox6) -> win32more.Windows.UI.Xaml.Controls.CharacterCasing: ...
    @winrt_mixinmethod
    def put_CharacterCasing(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox6, value: win32more.Windows.UI.Xaml.Controls.CharacterCasing) -> Void: ...
    @winrt_mixinmethod
    def get_DisabledFormattingAccelerators(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox6) -> win32more.Windows.UI.Xaml.Controls.DisabledFormattingAccelerators: ...
    @winrt_mixinmethod
    def put_DisabledFormattingAccelerators(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox6, value: win32more.Windows.UI.Xaml.Controls.DisabledFormattingAccelerators) -> Void: ...
    @winrt_mixinmethod
    def add_CopyingToClipboard(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox6, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.TextControlCopyingToClipboardEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CopyingToClipboard(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox6, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CuttingToClipboard(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox6, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.TextControlCuttingToClipboardEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CuttingToClipboard(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox6, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_ContentLinkForegroundColor(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox7) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_mixinmethod
    def put_ContentLinkForegroundColor(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox7, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_mixinmethod
    def get_ContentLinkBackgroundColor(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox7) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_mixinmethod
    def put_ContentLinkBackgroundColor(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox7, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_mixinmethod
    def get_ContentLinkProviders(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox7) -> win32more.Windows.UI.Xaml.Documents.ContentLinkProviderCollection: ...
    @winrt_mixinmethod
    def put_ContentLinkProviders(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox7, value: win32more.Windows.UI.Xaml.Documents.ContentLinkProviderCollection) -> Void: ...
    @winrt_mixinmethod
    def get_HandwritingView(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox7) -> win32more.Windows.UI.Xaml.Controls.HandwritingView: ...
    @winrt_mixinmethod
    def put_HandwritingView(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox7, value: win32more.Windows.UI.Xaml.Controls.HandwritingView) -> Void: ...
    @winrt_mixinmethod
    def get_IsHandwritingViewEnabled(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox7) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsHandwritingViewEnabled(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox7, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_ContentLinkChanged(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox7, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.ContentLinkChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContentLinkChanged(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox7, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ContentLinkInvoked(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox7, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Documents.ContentLinkInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContentLinkInvoked(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox7, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_TextDocument(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox8) -> win32more.Windows.UI.Text.RichEditTextDocument: ...
    @winrt_mixinmethod
    def get_SelectionFlyout(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox8) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def put_SelectionFlyout(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox8, value: win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_mixinmethod
    def get_ProofingMenuFlyout(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox8) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox8) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox8, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def add_SelectionChanging(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox8, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichEditBox, win32more.Windows.UI.Xaml.Controls.RichEditBoxSelectionChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanging(self: win32more.Windows.UI.Xaml.Controls.IRichEditBox8, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_SelectionFlyoutProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics8) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ProofingMenuFlyoutProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics8) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DescriptionProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics8) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentLinkForegroundColorProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics7) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentLinkBackgroundColorProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics7) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentLinkProvidersProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics7) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HandwritingViewProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics7) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsHandwritingViewEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics7) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalTextAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics6) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CharacterCasingProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics6) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisabledFormattingAcceleratorsProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics6) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionHighlightColorWhenNotFocusedProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxLengthProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ClipboardCopyFormatProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DesiredCandidateWindowAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextReadingOrderProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderTextProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionHighlightColorProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PreventKeyboardDisplayOnProgrammaticFocusProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsColorFontEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsReadOnlyProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AcceptsReturnProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextWrappingProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSpellCheckEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextPredictionEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_InputScopeProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AcceptsReturn = property(get_AcceptsReturn, put_AcceptsReturn)
    CharacterCasing = property(get_CharacterCasing, put_CharacterCasing)
    ClipboardCopyFormat = property(get_ClipboardCopyFormat, put_ClipboardCopyFormat)
    ContentLinkBackgroundColor = property(get_ContentLinkBackgroundColor, put_ContentLinkBackgroundColor)
    ContentLinkForegroundColor = property(get_ContentLinkForegroundColor, put_ContentLinkForegroundColor)
    ContentLinkProviders = property(get_ContentLinkProviders, put_ContentLinkProviders)
    Description = property(get_Description, put_Description)
    DesiredCandidateWindowAlignment = property(get_DesiredCandidateWindowAlignment, put_DesiredCandidateWindowAlignment)
    DisabledFormattingAccelerators = property(get_DisabledFormattingAccelerators, put_DisabledFormattingAccelerators)
    Document = property(get_Document, None)
    HandwritingView = property(get_HandwritingView, put_HandwritingView)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    InputScope = property(get_InputScope, put_InputScope)
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    IsHandwritingViewEnabled = property(get_IsHandwritingViewEnabled, put_IsHandwritingViewEnabled)
    IsReadOnly = property(get_IsReadOnly, put_IsReadOnly)
    IsSpellCheckEnabled = property(get_IsSpellCheckEnabled, put_IsSpellCheckEnabled)
    IsTextPredictionEnabled = property(get_IsTextPredictionEnabled, put_IsTextPredictionEnabled)
    MaxLength = property(get_MaxLength, put_MaxLength)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    PreventKeyboardDisplayOnProgrammaticFocus = property(get_PreventKeyboardDisplayOnProgrammaticFocus, put_PreventKeyboardDisplayOnProgrammaticFocus)
    ProofingMenuFlyout = property(get_ProofingMenuFlyout, None)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    SelectionHighlightColorWhenNotFocused = property(get_SelectionHighlightColorWhenNotFocused, put_SelectionHighlightColorWhenNotFocused)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
    TextDocument = property(get_TextDocument, None)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    _RichEditBox_Meta_.AcceptsReturnProperty = property(get_AcceptsReturnProperty, None)
    _RichEditBox_Meta_.CharacterCasingProperty = property(get_CharacterCasingProperty, None)
    _RichEditBox_Meta_.ClipboardCopyFormatProperty = property(get_ClipboardCopyFormatProperty, None)
    _RichEditBox_Meta_.ContentLinkBackgroundColorProperty = property(get_ContentLinkBackgroundColorProperty, None)
    _RichEditBox_Meta_.ContentLinkForegroundColorProperty = property(get_ContentLinkForegroundColorProperty, None)
    _RichEditBox_Meta_.ContentLinkProvidersProperty = property(get_ContentLinkProvidersProperty, None)
    _RichEditBox_Meta_.DescriptionProperty = property(get_DescriptionProperty, None)
    _RichEditBox_Meta_.DesiredCandidateWindowAlignmentProperty = property(get_DesiredCandidateWindowAlignmentProperty, None)
    _RichEditBox_Meta_.DisabledFormattingAcceleratorsProperty = property(get_DisabledFormattingAcceleratorsProperty, None)
    _RichEditBox_Meta_.HandwritingViewProperty = property(get_HandwritingViewProperty, None)
    _RichEditBox_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _RichEditBox_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _RichEditBox_Meta_.HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
    _RichEditBox_Meta_.InputScopeProperty = property(get_InputScopeProperty, None)
    _RichEditBox_Meta_.IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    _RichEditBox_Meta_.IsHandwritingViewEnabledProperty = property(get_IsHandwritingViewEnabledProperty, None)
    _RichEditBox_Meta_.IsReadOnlyProperty = property(get_IsReadOnlyProperty, None)
    _RichEditBox_Meta_.IsSpellCheckEnabledProperty = property(get_IsSpellCheckEnabledProperty, None)
    _RichEditBox_Meta_.IsTextPredictionEnabledProperty = property(get_IsTextPredictionEnabledProperty, None)
    _RichEditBox_Meta_.MaxLengthProperty = property(get_MaxLengthProperty, None)
    _RichEditBox_Meta_.PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    _RichEditBox_Meta_.PreventKeyboardDisplayOnProgrammaticFocusProperty = property(get_PreventKeyboardDisplayOnProgrammaticFocusProperty, None)
    _RichEditBox_Meta_.ProofingMenuFlyoutProperty = property(get_ProofingMenuFlyoutProperty, None)
    _RichEditBox_Meta_.SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
    _RichEditBox_Meta_.SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    _RichEditBox_Meta_.SelectionHighlightColorWhenNotFocusedProperty = property(get_SelectionHighlightColorWhenNotFocusedProperty, None)
    _RichEditBox_Meta_.TextAlignmentProperty = property(get_TextAlignmentProperty, None)
    _RichEditBox_Meta_.TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
    _RichEditBox_Meta_.TextWrappingProperty = property(get_TextWrappingProperty, None)
    TextChanged = event()
    SelectionChanged = event()
    ContextMenuOpening = event()
    Paste = event()
    TextCompositionStarted = event()
    TextCompositionChanged = event()
    TextCompositionEnded = event()
    CandidateWindowBoundsChanged = event()
    TextChanging = event()
    CopyingToClipboard = event()
    CuttingToClipboard = event()
    ContentLinkChanged = event()
    ContentLinkInvoked = event()
    SelectionChanging = event()
class RichEditBoxSelectionChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IRichEditBoxSelectionChangingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.RichEditBoxSelectionChangingEventArgs'
    @winrt_mixinmethod
    def get_SelectionStart(self: win32more.Windows.UI.Xaml.Controls.IRichEditBoxSelectionChangingEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_SelectionLength(self: win32more.Windows.UI.Xaml.Controls.IRichEditBoxSelectionChangingEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Windows.UI.Xaml.Controls.IRichEditBoxSelectionChangingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Windows.UI.Xaml.Controls.IRichEditBoxSelectionChangingEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    SelectionLength = property(get_SelectionLength, None)
    SelectionStart = property(get_SelectionStart, None)
class RichEditBoxTextChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IRichEditBoxTextChangingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.RichEditBoxTextChangingEventArgs'
    @winrt_mixinmethod
    def get_IsContentChanging(self: win32more.Windows.UI.Xaml.Controls.IRichEditBoxTextChangingEventArgs2) -> Boolean: ...
    IsContentChanging = property(get_IsContentChanging, None)
class RichEditClipboardFormat(Enum, Int32):
    AllFormats = 0
    PlainText = 1
class _RichTextBlock_Meta_(ComPtr.__class__):
    pass
class RichTextBlock(ComPtr, metaclass=_RichTextBlock_Meta_):
    extends: win32more.Windows.UI.Xaml.FrameworkElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IRichTextBlock
    _classid_ = 'Windows.UI.Xaml.Controls.RichTextBlock'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.RichTextBlock.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.RichTextBlock: ...
    @winrt_mixinmethod
    def get_FontSize(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> Double: ...
    @winrt_mixinmethod
    def put_FontSize(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FontFamily(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_FontFamily(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_FontWeight(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_FontWeight(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_FontStyle(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_FontStyle(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_FontStretch(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_mixinmethod
    def put_FontStretch(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_mixinmethod
    def get_Foreground(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Foreground(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TextWrapping(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Xaml.TextWrapping: ...
    @winrt_mixinmethod
    def put_TextWrapping(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, value: win32more.Windows.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_mixinmethod
    def get_TextTrimming(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Xaml.TextTrimming: ...
    @winrt_mixinmethod
    def put_TextTrimming(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, value: win32more.Windows.UI.Xaml.TextTrimming) -> Void: ...
    @winrt_mixinmethod
    def get_TextAlignment(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_TextAlignment(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, value: win32more.Windows.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_Blocks(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Xaml.Documents.BlockCollection: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_LineHeight(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> Double: ...
    @winrt_mixinmethod
    def put_LineHeight(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_LineStackingStrategy(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Xaml.LineStackingStrategy: ...
    @winrt_mixinmethod
    def put_LineStackingStrategy(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, value: win32more.Windows.UI.Xaml.LineStackingStrategy) -> Void: ...
    @winrt_mixinmethod
    def get_CharacterSpacing(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> Int32: ...
    @winrt_mixinmethod
    def put_CharacterSpacing(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_OverflowContentTarget(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Xaml.Controls.RichTextBlockOverflow: ...
    @winrt_mixinmethod
    def put_OverflowContentTarget(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, value: win32more.Windows.UI.Xaml.Controls.RichTextBlockOverflow) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextSelectionEnabled(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextSelectionEnabled(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_HasOverflowContent(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> Boolean: ...
    @winrt_mixinmethod
    def get_SelectedText(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ContentStart(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_ContentEnd(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_SelectionStart(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_SelectionEnd(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_BaselineOffset(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> Double: ...
    @winrt_mixinmethod
    def add_SelectionChanged(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanged(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ContextMenuOpening(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, handler: win32more.Windows.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContextMenuOpening(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def SelectAll(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> Void: ...
    @winrt_mixinmethod
    def Select(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, start: win32more.Windows.UI.Xaml.Documents.TextPointer, end: win32more.Windows.UI.Xaml.Documents.TextPointer) -> Void: ...
    @winrt_mixinmethod
    def GetPositionFromPoint(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, point: win32more.Windows.Foundation.Point) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def Focus(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, value: win32more.Windows.UI.Xaml.FocusState) -> Boolean: ...
    @winrt_mixinmethod
    def get_TextIndent(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock) -> Double: ...
    @winrt_mixinmethod
    def put_TextIndent(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_MaxLines(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock2) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxLines(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock2, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_TextLineBounds(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock2) -> win32more.Windows.UI.Xaml.TextLineBounds: ...
    @winrt_mixinmethod
    def put_TextLineBounds(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock2, value: win32more.Windows.UI.Xaml.TextLineBounds) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionHighlightColor(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock2) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_mixinmethod
    def put_SelectionHighlightColor(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock2, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_mixinmethod
    def get_OpticalMarginAlignment(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock2) -> win32more.Windows.UI.Xaml.OpticalMarginAlignment: ...
    @winrt_mixinmethod
    def put_OpticalMarginAlignment(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock2, value: win32more.Windows.UI.Xaml.OpticalMarginAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_IsColorFontEnabled(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsColorFontEnabled(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TextReadingOrder(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock2) -> win32more.Windows.UI.Xaml.TextReadingOrder: ...
    @winrt_mixinmethod
    def put_TextReadingOrder(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock2, value: win32more.Windows.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextScaleFactorEnabled(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock3) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextScaleFactorEnabled(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock3, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TextDecorations(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock4) -> win32more.Windows.UI.Text.TextDecorations: ...
    @winrt_mixinmethod
    def put_TextDecorations(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock4, value: win32more.Windows.UI.Text.TextDecorations) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextTrimmed(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock5) -> Boolean: ...
    @winrt_mixinmethod
    def get_HorizontalTextAlignment(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock5) -> win32more.Windows.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalTextAlignment(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock5, value: win32more.Windows.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_TextHighlighters(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock5) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Documents.TextHighlighter]: ...
    @winrt_mixinmethod
    def add_IsTextTrimmedChanged(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock5, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichTextBlock, win32more.Windows.UI.Xaml.Controls.IsTextTrimmedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_IsTextTrimmedChanged(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock5, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionFlyout(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock6) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def put_SelectionFlyout(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock6, value: win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_mixinmethod
    def CopySelectionToClipboard(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlock6) -> Void: ...
    @winrt_classmethod
    def get_SelectionFlyoutProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics6) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextTrimmedProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalTextAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextDecorationsProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextScaleFactorEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxLinesProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextLineBoundsProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionHighlightColorProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OpticalMarginAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsColorFontEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextReadingOrderProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontSizeProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontFamilyProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontWeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStretchProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextWrappingProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextTrimmingProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LineHeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LineStackingStrategyProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CharacterSpacingProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OverflowContentTargetProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextSelectionEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HasOverflowContentProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedTextProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextIndentProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BaselineOffset = property(get_BaselineOffset, None)
    Blocks = property(get_Blocks, None)
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    ContentEnd = property(get_ContentEnd, None)
    ContentStart = property(get_ContentStart, None)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
    HasOverflowContent = property(get_HasOverflowContent, None)
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    IsTextSelectionEnabled = property(get_IsTextSelectionEnabled, put_IsTextSelectionEnabled)
    IsTextTrimmed = property(get_IsTextTrimmed, None)
    LineHeight = property(get_LineHeight, put_LineHeight)
    LineStackingStrategy = property(get_LineStackingStrategy, put_LineStackingStrategy)
    MaxLines = property(get_MaxLines, put_MaxLines)
    OpticalMarginAlignment = property(get_OpticalMarginAlignment, put_OpticalMarginAlignment)
    OverflowContentTarget = property(get_OverflowContentTarget, put_OverflowContentTarget)
    Padding = property(get_Padding, put_Padding)
    SelectedText = property(get_SelectedText, None)
    SelectionEnd = property(get_SelectionEnd, None)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    SelectionStart = property(get_SelectionStart, None)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
    TextDecorations = property(get_TextDecorations, put_TextDecorations)
    TextHighlighters = property(get_TextHighlighters, None)
    TextIndent = property(get_TextIndent, put_TextIndent)
    TextLineBounds = property(get_TextLineBounds, put_TextLineBounds)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    TextTrimming = property(get_TextTrimming, put_TextTrimming)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    _RichTextBlock_Meta_.CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    _RichTextBlock_Meta_.FontFamilyProperty = property(get_FontFamilyProperty, None)
    _RichTextBlock_Meta_.FontSizeProperty = property(get_FontSizeProperty, None)
    _RichTextBlock_Meta_.FontStretchProperty = property(get_FontStretchProperty, None)
    _RichTextBlock_Meta_.FontStyleProperty = property(get_FontStyleProperty, None)
    _RichTextBlock_Meta_.FontWeightProperty = property(get_FontWeightProperty, None)
    _RichTextBlock_Meta_.ForegroundProperty = property(get_ForegroundProperty, None)
    _RichTextBlock_Meta_.HasOverflowContentProperty = property(get_HasOverflowContentProperty, None)
    _RichTextBlock_Meta_.HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
    _RichTextBlock_Meta_.IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    _RichTextBlock_Meta_.IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    _RichTextBlock_Meta_.IsTextSelectionEnabledProperty = property(get_IsTextSelectionEnabledProperty, None)
    _RichTextBlock_Meta_.IsTextTrimmedProperty = property(get_IsTextTrimmedProperty, None)
    _RichTextBlock_Meta_.LineHeightProperty = property(get_LineHeightProperty, None)
    _RichTextBlock_Meta_.LineStackingStrategyProperty = property(get_LineStackingStrategyProperty, None)
    _RichTextBlock_Meta_.MaxLinesProperty = property(get_MaxLinesProperty, None)
    _RichTextBlock_Meta_.OpticalMarginAlignmentProperty = property(get_OpticalMarginAlignmentProperty, None)
    _RichTextBlock_Meta_.OverflowContentTargetProperty = property(get_OverflowContentTargetProperty, None)
    _RichTextBlock_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    _RichTextBlock_Meta_.SelectedTextProperty = property(get_SelectedTextProperty, None)
    _RichTextBlock_Meta_.SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
    _RichTextBlock_Meta_.SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    _RichTextBlock_Meta_.TextAlignmentProperty = property(get_TextAlignmentProperty, None)
    _RichTextBlock_Meta_.TextDecorationsProperty = property(get_TextDecorationsProperty, None)
    _RichTextBlock_Meta_.TextIndentProperty = property(get_TextIndentProperty, None)
    _RichTextBlock_Meta_.TextLineBoundsProperty = property(get_TextLineBoundsProperty, None)
    _RichTextBlock_Meta_.TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
    _RichTextBlock_Meta_.TextTrimmingProperty = property(get_TextTrimmingProperty, None)
    _RichTextBlock_Meta_.TextWrappingProperty = property(get_TextWrappingProperty, None)
    SelectionChanged = event()
    ContextMenuOpening = event()
    IsTextTrimmedChanged = event()
class _RichTextBlockOverflow_Meta_(ComPtr.__class__):
    pass
class RichTextBlockOverflow(ComPtr, metaclass=_RichTextBlockOverflow_Meta_):
    extends: win32more.Windows.UI.Xaml.FrameworkElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflow
    _classid_ = 'Windows.UI.Xaml.Controls.RichTextBlockOverflow'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.RichTextBlockOverflow.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.RichTextBlockOverflow: ...
    @winrt_mixinmethod
    def get_OverflowContentTarget(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflow) -> win32more.Windows.UI.Xaml.Controls.RichTextBlockOverflow: ...
    @winrt_mixinmethod
    def put_OverflowContentTarget(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflow, value: win32more.Windows.UI.Xaml.Controls.RichTextBlockOverflow) -> Void: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflow) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflow, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_ContentSource(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflow) -> win32more.Windows.UI.Xaml.Controls.RichTextBlock: ...
    @winrt_mixinmethod
    def get_HasOverflowContent(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflow) -> Boolean: ...
    @winrt_mixinmethod
    def get_ContentStart(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflow) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_ContentEnd(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflow) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_BaselineOffset(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflow) -> Double: ...
    @winrt_mixinmethod
    def GetPositionFromPoint(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflow, point: win32more.Windows.Foundation.Point) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def Focus(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflow, value: win32more.Windows.UI.Xaml.FocusState) -> Boolean: ...
    @winrt_mixinmethod
    def get_MaxLines(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflow2) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxLines(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflow2, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextTrimmed(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflow3) -> Boolean: ...
    @winrt_mixinmethod
    def add_IsTextTrimmedChanged(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflow3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.RichTextBlockOverflow, win32more.Windows.UI.Xaml.Controls.IsTextTrimmedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_IsTextTrimmedChanged(self: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflow3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_IsTextTrimmedProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflowStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxLinesProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflowStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OverflowContentTargetProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflowStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflowStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HasOverflowContentProperty(cls: win32more.Windows.UI.Xaml.Controls.IRichTextBlockOverflowStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BaselineOffset = property(get_BaselineOffset, None)
    ContentEnd = property(get_ContentEnd, None)
    ContentSource = property(get_ContentSource, None)
    ContentStart = property(get_ContentStart, None)
    HasOverflowContent = property(get_HasOverflowContent, None)
    IsTextTrimmed = property(get_IsTextTrimmed, None)
    MaxLines = property(get_MaxLines, put_MaxLines)
    OverflowContentTarget = property(get_OverflowContentTarget, put_OverflowContentTarget)
    Padding = property(get_Padding, put_Padding)
    _RichTextBlockOverflow_Meta_.HasOverflowContentProperty = property(get_HasOverflowContentProperty, None)
    _RichTextBlockOverflow_Meta_.IsTextTrimmedProperty = property(get_IsTextTrimmedProperty, None)
    _RichTextBlockOverflow_Meta_.MaxLinesProperty = property(get_MaxLinesProperty, None)
    _RichTextBlockOverflow_Meta_.OverflowContentTargetProperty = property(get_OverflowContentTargetProperty, None)
    _RichTextBlockOverflow_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    IsTextTrimmedChanged = event()
class _RowDefinition_Meta_(ComPtr.__class__):
    pass
class RowDefinition(ComPtr, metaclass=_RowDefinition_Meta_):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Controls.IRowDefinition
    _classid_ = 'Windows.UI.Xaml.Controls.RowDefinition'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.RowDefinition.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.RowDefinition: ...
    @winrt_mixinmethod
    def get_Height(self: win32more.Windows.UI.Xaml.Controls.IRowDefinition) -> win32more.Windows.UI.Xaml.GridLength: ...
    @winrt_mixinmethod
    def put_Height(self: win32more.Windows.UI.Xaml.Controls.IRowDefinition, value: win32more.Windows.UI.Xaml.GridLength) -> Void: ...
    @winrt_mixinmethod
    def get_MaxHeight(self: win32more.Windows.UI.Xaml.Controls.IRowDefinition) -> Double: ...
    @winrt_mixinmethod
    def put_MaxHeight(self: win32more.Windows.UI.Xaml.Controls.IRowDefinition, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_MinHeight(self: win32more.Windows.UI.Xaml.Controls.IRowDefinition) -> Double: ...
    @winrt_mixinmethod
    def put_MinHeight(self: win32more.Windows.UI.Xaml.Controls.IRowDefinition, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ActualHeight(self: win32more.Windows.UI.Xaml.Controls.IRowDefinition) -> Double: ...
    @winrt_classmethod
    def get_HeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IRowDefinitionStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxHeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IRowDefinitionStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinHeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IRowDefinitionStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ActualHeight = property(get_ActualHeight, None)
    Height = property(get_Height, put_Height)
    MaxHeight = property(get_MaxHeight, put_MaxHeight)
    MinHeight = property(get_MinHeight, put_MinHeight)
    _RowDefinition_Meta_.HeightProperty = property(get_HeightProperty, None)
    _RowDefinition_Meta_.MaxHeightProperty = property(get_MaxHeightProperty, None)
    _RowDefinition_Meta_.MinHeightProperty = property(get_MinHeightProperty, None)
class RowDefinitionCollection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[win32more.Windows.UI.Xaml.Controls.RowDefinition]]
    default_interface: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.RowDefinition]
    _classid_ = 'Windows.UI.Xaml.Controls.RowDefinitionCollection'
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.RowDefinition], index: UInt32) -> win32more.Windows.UI.Xaml.Controls.RowDefinition: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.RowDefinition]) -> UInt32: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.RowDefinition]) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.UI.Xaml.Controls.RowDefinition]: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.RowDefinition], value: win32more.Windows.UI.Xaml.Controls.RowDefinition, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def SetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.RowDefinition], index: UInt32, value: win32more.Windows.UI.Xaml.Controls.RowDefinition) -> Void: ...
    @winrt_mixinmethod
    def InsertAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.RowDefinition], index: UInt32, value: win32more.Windows.UI.Xaml.Controls.RowDefinition) -> Void: ...
    @winrt_mixinmethod
    def RemoveAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.RowDefinition], index: UInt32) -> Void: ...
    @winrt_mixinmethod
    def Append(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.RowDefinition], value: win32more.Windows.UI.Xaml.Controls.RowDefinition) -> Void: ...
    @winrt_mixinmethod
    def RemoveAtEnd(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.RowDefinition]) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.RowDefinition]) -> Void: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.RowDefinition], startIndex: UInt32, items: FillArray[win32more.Windows.UI.Xaml.Controls.RowDefinition]) -> UInt32: ...
    @winrt_mixinmethod
    def ReplaceAll(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.RowDefinition], items: PassArray[win32more.Windows.UI.Xaml.Controls.RowDefinition]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.UI.Xaml.Controls.RowDefinition]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.UI.Xaml.Controls.RowDefinition]: ...
    Size = property(get_Size, None)
class ScrollBarVisibility(Enum, Int32):
    Disabled = 0
    Auto = 1
    Hidden = 2
    Visible = 3
class _ScrollContentPresenter_Meta_(ComPtr.__class__):
    pass
class ScrollContentPresenter(ComPtr, metaclass=_ScrollContentPresenter_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ContentPresenter
    default_interface: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter
    _classid_ = 'Windows.UI.Xaml.Controls.ScrollContentPresenter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ScrollContentPresenter.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.ScrollContentPresenter: ...
    @winrt_mixinmethod
    def get_CanVerticallyScroll(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanVerticallyScroll(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CanHorizontallyScroll(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanHorizontallyScroll(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ExtentWidth(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Double: ...
    @winrt_mixinmethod
    def get_ExtentHeight(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Double: ...
    @winrt_mixinmethod
    def get_ViewportWidth(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Double: ...
    @winrt_mixinmethod
    def get_ViewportHeight(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Double: ...
    @winrt_mixinmethod
    def get_HorizontalOffset(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Double: ...
    @winrt_mixinmethod
    def get_VerticalOffset(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Double: ...
    @winrt_mixinmethod
    def get_ScrollOwner(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_ScrollOwner(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def LineUp(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def LineDown(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def LineLeft(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def LineRight(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def PageUp(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def PageDown(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def PageLeft(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def PageRight(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def MouseWheelUp(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def MouseWheelDown(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def MouseWheelLeft(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def MouseWheelRight(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def SetHorizontalOffset(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter, offset: Double) -> Void: ...
    @winrt_mixinmethod
    def SetVerticalOffset(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter, offset: Double) -> Void: ...
    @winrt_mixinmethod
    def MakeVisible(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter, visual: win32more.Windows.UI.Xaml.UIElement, rectangle: win32more.Windows.Foundation.Rect) -> win32more.Windows.Foundation.Rect: ...
    @winrt_mixinmethod
    def get_CanContentRenderOutsideBounds(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter2) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanContentRenderOutsideBounds(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SizesContentToTemplatedParent(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter2) -> Boolean: ...
    @winrt_mixinmethod
    def put_SizesContentToTemplatedParent(self: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenter2, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_CanContentRenderOutsideBoundsProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenterStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SizesContentToTemplatedParentProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollContentPresenterStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CanContentRenderOutsideBounds = property(get_CanContentRenderOutsideBounds, put_CanContentRenderOutsideBounds)
    CanHorizontallyScroll = property(get_CanHorizontallyScroll, put_CanHorizontallyScroll)
    CanVerticallyScroll = property(get_CanVerticallyScroll, put_CanVerticallyScroll)
    ExtentHeight = property(get_ExtentHeight, None)
    ExtentWidth = property(get_ExtentWidth, None)
    HorizontalOffset = property(get_HorizontalOffset, None)
    ScrollOwner = property(get_ScrollOwner, put_ScrollOwner)
    SizesContentToTemplatedParent = property(get_SizesContentToTemplatedParent, put_SizesContentToTemplatedParent)
    VerticalOffset = property(get_VerticalOffset, None)
    ViewportHeight = property(get_ViewportHeight, None)
    ViewportWidth = property(get_ViewportWidth, None)
    _ScrollContentPresenter_Meta_.CanContentRenderOutsideBoundsProperty = property(get_CanContentRenderOutsideBoundsProperty, None)
    _ScrollContentPresenter_Meta_.SizesContentToTemplatedParentProperty = property(get_SizesContentToTemplatedParentProperty, None)
class ScrollIntoViewAlignment(Enum, Int32):
    Default = 0
    Leading = 1
class ScrollMode(Enum, Int32):
    Disabled = 0
    Enabled = 1
    Auto = 2
class _ScrollViewer_Meta_(ComPtr.__class__):
    pass
class ScrollViewer(ComPtr, metaclass=_ScrollViewer_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Windows.UI.Xaml.Controls.IScrollViewer
    _classid_ = 'Windows.UI.Xaml.Controls.ScrollViewer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ScrollViewer.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.ScrollViewer: ...
    @winrt_mixinmethod
    def get_HorizontalScrollBarVisibility(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> win32more.Windows.UI.Xaml.Controls.ScrollBarVisibility: ...
    @winrt_mixinmethod
    def put_HorizontalScrollBarVisibility(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: win32more.Windows.UI.Xaml.Controls.ScrollBarVisibility) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalScrollBarVisibility(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> win32more.Windows.UI.Xaml.Controls.ScrollBarVisibility: ...
    @winrt_mixinmethod
    def put_VerticalScrollBarVisibility(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: win32more.Windows.UI.Xaml.Controls.ScrollBarVisibility) -> Void: ...
    @winrt_mixinmethod
    def get_IsHorizontalRailEnabled(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsHorizontalRailEnabled(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsVerticalRailEnabled(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsVerticalRailEnabled(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsHorizontalScrollChainingEnabled(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsHorizontalScrollChainingEnabled(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsVerticalScrollChainingEnabled(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsVerticalScrollChainingEnabled(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsZoomChainingEnabled(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZoomChainingEnabled(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsScrollInertiaEnabled(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsScrollInertiaEnabled(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsZoomInertiaEnabled(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZoomInertiaEnabled(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalScrollMode(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> win32more.Windows.UI.Xaml.Controls.ScrollMode: ...
    @winrt_mixinmethod
    def put_HorizontalScrollMode(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: win32more.Windows.UI.Xaml.Controls.ScrollMode) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalScrollMode(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> win32more.Windows.UI.Xaml.Controls.ScrollMode: ...
    @winrt_mixinmethod
    def put_VerticalScrollMode(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: win32more.Windows.UI.Xaml.Controls.ScrollMode) -> Void: ...
    @winrt_mixinmethod
    def get_ZoomMode(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> win32more.Windows.UI.Xaml.Controls.ZoomMode: ...
    @winrt_mixinmethod
    def put_ZoomMode(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: win32more.Windows.UI.Xaml.Controls.ZoomMode) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalSnapPointsAlignment(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> win32more.Windows.UI.Xaml.Controls.Primitives.SnapPointsAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalSnapPointsAlignment(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: win32more.Windows.UI.Xaml.Controls.Primitives.SnapPointsAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalSnapPointsAlignment(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> win32more.Windows.UI.Xaml.Controls.Primitives.SnapPointsAlignment: ...
    @winrt_mixinmethod
    def put_VerticalSnapPointsAlignment(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: win32more.Windows.UI.Xaml.Controls.Primitives.SnapPointsAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalSnapPointsType(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> win32more.Windows.UI.Xaml.Controls.SnapPointsType: ...
    @winrt_mixinmethod
    def put_HorizontalSnapPointsType(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: win32more.Windows.UI.Xaml.Controls.SnapPointsType) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalSnapPointsType(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> win32more.Windows.UI.Xaml.Controls.SnapPointsType: ...
    @winrt_mixinmethod
    def put_VerticalSnapPointsType(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: win32more.Windows.UI.Xaml.Controls.SnapPointsType) -> Void: ...
    @winrt_mixinmethod
    def get_ZoomSnapPointsType(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> win32more.Windows.UI.Xaml.Controls.SnapPointsType: ...
    @winrt_mixinmethod
    def put_ZoomSnapPointsType(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: win32more.Windows.UI.Xaml.Controls.SnapPointsType) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalOffset(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def get_ViewportWidth(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def get_ScrollableWidth(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def get_ComputedHorizontalScrollBarVisibility(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_ExtentWidth(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def get_VerticalOffset(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def get_ViewportHeight(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def get_ScrollableHeight(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def get_ComputedVerticalScrollBarVisibility(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_ExtentHeight(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def get_MinZoomFactor(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Single: ...
    @winrt_mixinmethod
    def put_MinZoomFactor(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_MaxZoomFactor(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Single: ...
    @winrt_mixinmethod
    def put_MaxZoomFactor(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_ZoomFactor(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Single: ...
    @winrt_mixinmethod
    def get_ZoomSnapPoints(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> win32more.Windows.Foundation.Collections.IVector[Single]: ...
    @winrt_mixinmethod
    def add_ViewChanged(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.UI.Xaml.Controls.ScrollViewerViewChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ViewChanged(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ScrollToHorizontalOffset(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, offset: Double) -> Void: ...
    @winrt_mixinmethod
    def ScrollToVerticalOffset(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, offset: Double) -> Void: ...
    @winrt_mixinmethod
    def ZoomToFactor(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, factor: Single) -> Void: ...
    @winrt_mixinmethod
    def InvalidateScrollInfo(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Void: ...
    @winrt_mixinmethod
    def get_IsDeferredScrollingEnabled(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDeferredScrollingEnabled(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_BringIntoViewOnFocusChange(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_BringIntoViewOnFocusChange(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TopLeftHeader(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer2) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_TopLeftHeader(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer2, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_LeftHeader(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer2) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_LeftHeader(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer2, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_TopHeader(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer2) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_TopHeader(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer2, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def add_ViewChanging(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer2, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.UI.Xaml.Controls.ScrollViewerViewChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ViewChanging(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ChangeView(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer2, horizontalOffset: win32more.Windows.Foundation.IReference[Double], verticalOffset: win32more.Windows.Foundation.IReference[Double], zoomFactor: win32more.Windows.Foundation.IReference[Single]) -> Boolean: ...
    @winrt_mixinmethod
    def ChangeViewWithOptionalAnimation(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer2, horizontalOffset: win32more.Windows.Foundation.IReference[Double], verticalOffset: win32more.Windows.Foundation.IReference[Double], zoomFactor: win32more.Windows.Foundation.IReference[Single], disableAnimation: Boolean) -> Boolean: ...
    @winrt_mixinmethod
    def add_DirectManipulationStarted(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer3, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DirectManipulationStarted(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DirectManipulationCompleted(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer3, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DirectManipulationCompleted(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_ReduceViewportForCoreInputViewOcclusions(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer4) -> Boolean: ...
    @winrt_mixinmethod
    def put_ReduceViewportForCoreInputViewOcclusions(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer4, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalAnchorRatio(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer4) -> Double: ...
    @winrt_mixinmethod
    def put_HorizontalAnchorRatio(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer4, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalAnchorRatio(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer4) -> Double: ...
    @winrt_mixinmethod
    def put_VerticalAnchorRatio(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer4, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_CanContentRenderOutsideBounds(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer4) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanContentRenderOutsideBounds(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer4, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_AnchorRequested(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer4, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ScrollViewer, win32more.Windows.UI.Xaml.Controls.AnchorRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AnchorRequested(self: win32more.Windows.UI.Xaml.Controls.IScrollViewer4, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_CurrentAnchor(self: win32more.Windows.UI.Xaml.Controls.IScrollAnchorProvider) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def RegisterAnchorCandidate(self: win32more.Windows.UI.Xaml.Controls.IScrollAnchorProvider, element: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def UnregisterAnchorCandidate(self: win32more.Windows.UI.Xaml.Controls.IScrollAnchorProvider, element: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_classmethod
    def get_ReduceViewportForCoreInputViewOcclusionsProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalAnchorRatioProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalAnchorRatioProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanContentRenderOutsideBoundsProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetCanContentRenderOutsideBounds(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics4, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetCanContentRenderOutsideBounds(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics4, element: win32more.Windows.UI.Xaml.DependencyObject, canContentRenderOutsideBounds: Boolean) -> Void: ...
    @winrt_classmethod
    def get_TopLeftHeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LeftHeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TopHeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalSnapPointsAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalSnapPointsAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalSnapPointsTypeProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalSnapPointsTypeProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ZoomSnapPointsTypeProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalOffsetProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ViewportWidthProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ScrollableWidthProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ComputedHorizontalScrollBarVisibilityProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ExtentWidthProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalOffsetProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ViewportHeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ScrollableHeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ComputedVerticalScrollBarVisibilityProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ExtentHeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinZoomFactorProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxZoomFactorProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ZoomFactorProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ZoomSnapPointsProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalScrollBarVisibilityProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetHorizontalScrollBarVisibility(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.ScrollBarVisibility: ...
    @winrt_classmethod
    def SetHorizontalScrollBarVisibility(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject, horizontalScrollBarVisibility: win32more.Windows.UI.Xaml.Controls.ScrollBarVisibility) -> Void: ...
    @winrt_classmethod
    def get_VerticalScrollBarVisibilityProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetVerticalScrollBarVisibility(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.ScrollBarVisibility: ...
    @winrt_classmethod
    def SetVerticalScrollBarVisibility(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject, verticalScrollBarVisibility: win32more.Windows.UI.Xaml.Controls.ScrollBarVisibility) -> Void: ...
    @winrt_classmethod
    def get_IsHorizontalRailEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsHorizontalRailEnabled(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsHorizontalRailEnabled(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject, isHorizontalRailEnabled: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsVerticalRailEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsVerticalRailEnabled(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsVerticalRailEnabled(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject, isVerticalRailEnabled: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsHorizontalScrollChainingEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsHorizontalScrollChainingEnabled(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsHorizontalScrollChainingEnabled(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject, isHorizontalScrollChainingEnabled: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsVerticalScrollChainingEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsVerticalScrollChainingEnabled(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsVerticalScrollChainingEnabled(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject, isVerticalScrollChainingEnabled: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsZoomChainingEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsZoomChainingEnabled(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsZoomChainingEnabled(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject, isZoomChainingEnabled: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsScrollInertiaEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsScrollInertiaEnabled(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsScrollInertiaEnabled(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject, isScrollInertiaEnabled: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsZoomInertiaEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsZoomInertiaEnabled(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsZoomInertiaEnabled(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject, isZoomInertiaEnabled: Boolean) -> Void: ...
    @winrt_classmethod
    def get_HorizontalScrollModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetHorizontalScrollMode(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.ScrollMode: ...
    @winrt_classmethod
    def SetHorizontalScrollMode(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject, horizontalScrollMode: win32more.Windows.UI.Xaml.Controls.ScrollMode) -> Void: ...
    @winrt_classmethod
    def get_VerticalScrollModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetVerticalScrollMode(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.ScrollMode: ...
    @winrt_classmethod
    def SetVerticalScrollMode(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject, verticalScrollMode: win32more.Windows.UI.Xaml.Controls.ScrollMode) -> Void: ...
    @winrt_classmethod
    def get_ZoomModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetZoomMode(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.ZoomMode: ...
    @winrt_classmethod
    def SetZoomMode(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject, zoomMode: win32more.Windows.UI.Xaml.Controls.ZoomMode) -> Void: ...
    @winrt_classmethod
    def get_IsDeferredScrollingEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsDeferredScrollingEnabled(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsDeferredScrollingEnabled(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject, isDeferredScrollingEnabled: Boolean) -> Void: ...
    @winrt_classmethod
    def get_BringIntoViewOnFocusChangeProperty(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetBringIntoViewOnFocusChange(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetBringIntoViewOnFocusChange(cls: win32more.Windows.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Windows.UI.Xaml.DependencyObject, bringIntoViewOnFocusChange: Boolean) -> Void: ...
    BringIntoViewOnFocusChange = property(get_BringIntoViewOnFocusChange, put_BringIntoViewOnFocusChange)
    CanContentRenderOutsideBounds = property(get_CanContentRenderOutsideBounds, put_CanContentRenderOutsideBounds)
    ComputedHorizontalScrollBarVisibility = property(get_ComputedHorizontalScrollBarVisibility, None)
    ComputedVerticalScrollBarVisibility = property(get_ComputedVerticalScrollBarVisibility, None)
    CurrentAnchor = property(get_CurrentAnchor, None)
    ExtentHeight = property(get_ExtentHeight, None)
    ExtentWidth = property(get_ExtentWidth, None)
    HorizontalAnchorRatio = property(get_HorizontalAnchorRatio, put_HorizontalAnchorRatio)
    HorizontalOffset = property(get_HorizontalOffset, None)
    HorizontalScrollBarVisibility = property(get_HorizontalScrollBarVisibility, put_HorizontalScrollBarVisibility)
    HorizontalScrollMode = property(get_HorizontalScrollMode, put_HorizontalScrollMode)
    HorizontalSnapPointsAlignment = property(get_HorizontalSnapPointsAlignment, put_HorizontalSnapPointsAlignment)
    HorizontalSnapPointsType = property(get_HorizontalSnapPointsType, put_HorizontalSnapPointsType)
    IsDeferredScrollingEnabled = property(get_IsDeferredScrollingEnabled, put_IsDeferredScrollingEnabled)
    IsHorizontalRailEnabled = property(get_IsHorizontalRailEnabled, put_IsHorizontalRailEnabled)
    IsHorizontalScrollChainingEnabled = property(get_IsHorizontalScrollChainingEnabled, put_IsHorizontalScrollChainingEnabled)
    IsScrollInertiaEnabled = property(get_IsScrollInertiaEnabled, put_IsScrollInertiaEnabled)
    IsVerticalRailEnabled = property(get_IsVerticalRailEnabled, put_IsVerticalRailEnabled)
    IsVerticalScrollChainingEnabled = property(get_IsVerticalScrollChainingEnabled, put_IsVerticalScrollChainingEnabled)
    IsZoomChainingEnabled = property(get_IsZoomChainingEnabled, put_IsZoomChainingEnabled)
    IsZoomInertiaEnabled = property(get_IsZoomInertiaEnabled, put_IsZoomInertiaEnabled)
    LeftHeader = property(get_LeftHeader, put_LeftHeader)
    MaxZoomFactor = property(get_MaxZoomFactor, put_MaxZoomFactor)
    MinZoomFactor = property(get_MinZoomFactor, put_MinZoomFactor)
    ReduceViewportForCoreInputViewOcclusions = property(get_ReduceViewportForCoreInputViewOcclusions, put_ReduceViewportForCoreInputViewOcclusions)
    ScrollableHeight = property(get_ScrollableHeight, None)
    ScrollableWidth = property(get_ScrollableWidth, None)
    TopHeader = property(get_TopHeader, put_TopHeader)
    TopLeftHeader = property(get_TopLeftHeader, put_TopLeftHeader)
    VerticalAnchorRatio = property(get_VerticalAnchorRatio, put_VerticalAnchorRatio)
    VerticalOffset = property(get_VerticalOffset, None)
    VerticalScrollBarVisibility = property(get_VerticalScrollBarVisibility, put_VerticalScrollBarVisibility)
    VerticalScrollMode = property(get_VerticalScrollMode, put_VerticalScrollMode)
    VerticalSnapPointsAlignment = property(get_VerticalSnapPointsAlignment, put_VerticalSnapPointsAlignment)
    VerticalSnapPointsType = property(get_VerticalSnapPointsType, put_VerticalSnapPointsType)
    ViewportHeight = property(get_ViewportHeight, None)
    ViewportWidth = property(get_ViewportWidth, None)
    ZoomFactor = property(get_ZoomFactor, None)
    ZoomMode = property(get_ZoomMode, put_ZoomMode)
    ZoomSnapPoints = property(get_ZoomSnapPoints, None)
    ZoomSnapPointsType = property(get_ZoomSnapPointsType, put_ZoomSnapPointsType)
    _ScrollViewer_Meta_.BringIntoViewOnFocusChangeProperty = property(get_BringIntoViewOnFocusChangeProperty, None)
    _ScrollViewer_Meta_.CanContentRenderOutsideBoundsProperty = property(get_CanContentRenderOutsideBoundsProperty, None)
    _ScrollViewer_Meta_.ComputedHorizontalScrollBarVisibilityProperty = property(get_ComputedHorizontalScrollBarVisibilityProperty, None)
    _ScrollViewer_Meta_.ComputedVerticalScrollBarVisibilityProperty = property(get_ComputedVerticalScrollBarVisibilityProperty, None)
    _ScrollViewer_Meta_.ExtentHeightProperty = property(get_ExtentHeightProperty, None)
    _ScrollViewer_Meta_.ExtentWidthProperty = property(get_ExtentWidthProperty, None)
    _ScrollViewer_Meta_.HorizontalAnchorRatioProperty = property(get_HorizontalAnchorRatioProperty, None)
    _ScrollViewer_Meta_.HorizontalOffsetProperty = property(get_HorizontalOffsetProperty, None)
    _ScrollViewer_Meta_.HorizontalScrollBarVisibilityProperty = property(get_HorizontalScrollBarVisibilityProperty, None)
    _ScrollViewer_Meta_.HorizontalScrollModeProperty = property(get_HorizontalScrollModeProperty, None)
    _ScrollViewer_Meta_.HorizontalSnapPointsAlignmentProperty = property(get_HorizontalSnapPointsAlignmentProperty, None)
    _ScrollViewer_Meta_.HorizontalSnapPointsTypeProperty = property(get_HorizontalSnapPointsTypeProperty, None)
    _ScrollViewer_Meta_.IsDeferredScrollingEnabledProperty = property(get_IsDeferredScrollingEnabledProperty, None)
    _ScrollViewer_Meta_.IsHorizontalRailEnabledProperty = property(get_IsHorizontalRailEnabledProperty, None)
    _ScrollViewer_Meta_.IsHorizontalScrollChainingEnabledProperty = property(get_IsHorizontalScrollChainingEnabledProperty, None)
    _ScrollViewer_Meta_.IsScrollInertiaEnabledProperty = property(get_IsScrollInertiaEnabledProperty, None)
    _ScrollViewer_Meta_.IsVerticalRailEnabledProperty = property(get_IsVerticalRailEnabledProperty, None)
    _ScrollViewer_Meta_.IsVerticalScrollChainingEnabledProperty = property(get_IsVerticalScrollChainingEnabledProperty, None)
    _ScrollViewer_Meta_.IsZoomChainingEnabledProperty = property(get_IsZoomChainingEnabledProperty, None)
    _ScrollViewer_Meta_.IsZoomInertiaEnabledProperty = property(get_IsZoomInertiaEnabledProperty, None)
    _ScrollViewer_Meta_.LeftHeaderProperty = property(get_LeftHeaderProperty, None)
    _ScrollViewer_Meta_.MaxZoomFactorProperty = property(get_MaxZoomFactorProperty, None)
    _ScrollViewer_Meta_.MinZoomFactorProperty = property(get_MinZoomFactorProperty, None)
    _ScrollViewer_Meta_.ReduceViewportForCoreInputViewOcclusionsProperty = property(get_ReduceViewportForCoreInputViewOcclusionsProperty, None)
    _ScrollViewer_Meta_.ScrollableHeightProperty = property(get_ScrollableHeightProperty, None)
    _ScrollViewer_Meta_.ScrollableWidthProperty = property(get_ScrollableWidthProperty, None)
    _ScrollViewer_Meta_.TopHeaderProperty = property(get_TopHeaderProperty, None)
    _ScrollViewer_Meta_.TopLeftHeaderProperty = property(get_TopLeftHeaderProperty, None)
    _ScrollViewer_Meta_.VerticalAnchorRatioProperty = property(get_VerticalAnchorRatioProperty, None)
    _ScrollViewer_Meta_.VerticalOffsetProperty = property(get_VerticalOffsetProperty, None)
    _ScrollViewer_Meta_.VerticalScrollBarVisibilityProperty = property(get_VerticalScrollBarVisibilityProperty, None)
    _ScrollViewer_Meta_.VerticalScrollModeProperty = property(get_VerticalScrollModeProperty, None)
    _ScrollViewer_Meta_.VerticalSnapPointsAlignmentProperty = property(get_VerticalSnapPointsAlignmentProperty, None)
    _ScrollViewer_Meta_.VerticalSnapPointsTypeProperty = property(get_VerticalSnapPointsTypeProperty, None)
    _ScrollViewer_Meta_.ViewportHeightProperty = property(get_ViewportHeightProperty, None)
    _ScrollViewer_Meta_.ViewportWidthProperty = property(get_ViewportWidthProperty, None)
    _ScrollViewer_Meta_.ZoomFactorProperty = property(get_ZoomFactorProperty, None)
    _ScrollViewer_Meta_.ZoomModeProperty = property(get_ZoomModeProperty, None)
    _ScrollViewer_Meta_.ZoomSnapPointsProperty = property(get_ZoomSnapPointsProperty, None)
    _ScrollViewer_Meta_.ZoomSnapPointsTypeProperty = property(get_ZoomSnapPointsTypeProperty, None)
    ViewChanged = event()
    ViewChanging = event()
    DirectManipulationStarted = event()
    DirectManipulationCompleted = event()
    AnchorRequested = event()
class ScrollViewerView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IScrollViewerView
    _classid_ = 'Windows.UI.Xaml.Controls.ScrollViewerView'
    @winrt_mixinmethod
    def get_HorizontalOffset(self: win32more.Windows.UI.Xaml.Controls.IScrollViewerView) -> Double: ...
    @winrt_mixinmethod
    def get_VerticalOffset(self: win32more.Windows.UI.Xaml.Controls.IScrollViewerView) -> Double: ...
    @winrt_mixinmethod
    def get_ZoomFactor(self: win32more.Windows.UI.Xaml.Controls.IScrollViewerView) -> Single: ...
    HorizontalOffset = property(get_HorizontalOffset, None)
    VerticalOffset = property(get_VerticalOffset, None)
    ZoomFactor = property(get_ZoomFactor, None)
class ScrollViewerViewChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IScrollViewerViewChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.ScrollViewerViewChangedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ScrollViewerViewChangedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.ScrollViewerViewChangedEventArgs: ...
    @winrt_mixinmethod
    def get_IsIntermediate(self: win32more.Windows.UI.Xaml.Controls.IScrollViewerViewChangedEventArgs) -> Boolean: ...
    IsIntermediate = property(get_IsIntermediate, None)
class ScrollViewerViewChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IScrollViewerViewChangingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.ScrollViewerViewChangingEventArgs'
    @winrt_mixinmethod
    def get_NextView(self: win32more.Windows.UI.Xaml.Controls.IScrollViewerViewChangingEventArgs) -> win32more.Windows.UI.Xaml.Controls.ScrollViewerView: ...
    @winrt_mixinmethod
    def get_FinalView(self: win32more.Windows.UI.Xaml.Controls.IScrollViewerViewChangingEventArgs) -> win32more.Windows.UI.Xaml.Controls.ScrollViewerView: ...
    @winrt_mixinmethod
    def get_IsInertial(self: win32more.Windows.UI.Xaml.Controls.IScrollViewerViewChangingEventArgs) -> Boolean: ...
    FinalView = property(get_FinalView, None)
    IsInertial = property(get_IsInertial, None)
    NextView = property(get_NextView, None)
class _SearchBox_Meta_(ComPtr.__class__):
    pass
class SearchBox(ComPtr, metaclass=_SearchBox_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.ISearchBox
    _classid_ = 'Windows.UI.Xaml.Controls.SearchBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SearchBox.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ISearchBoxFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SearchBox: ...
    @winrt_mixinmethod
    def get_SearchHistoryEnabled(self: win32more.Windows.UI.Xaml.Controls.ISearchBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_SearchHistoryEnabled(self: win32more.Windows.UI.Xaml.Controls.ISearchBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SearchHistoryContext(self: win32more.Windows.UI.Xaml.Controls.ISearchBox) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SearchHistoryContext(self: win32more.Windows.UI.Xaml.Controls.ISearchBox, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderText(self: win32more.Windows.UI.Xaml.Controls.ISearchBox) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PlaceholderText(self: win32more.Windows.UI.Xaml.Controls.ISearchBox, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_QueryText(self: win32more.Windows.UI.Xaml.Controls.ISearchBox) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_QueryText(self: win32more.Windows.UI.Xaml.Controls.ISearchBox, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_FocusOnKeyboardInput(self: win32more.Windows.UI.Xaml.Controls.ISearchBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_FocusOnKeyboardInput(self: win32more.Windows.UI.Xaml.Controls.ISearchBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ChooseSuggestionOnEnter(self: win32more.Windows.UI.Xaml.Controls.ISearchBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_ChooseSuggestionOnEnter(self: win32more.Windows.UI.Xaml.Controls.ISearchBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_QueryChanged(self: win32more.Windows.UI.Xaml.Controls.ISearchBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SearchBox, win32more.Windows.UI.Xaml.Controls.SearchBoxQueryChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_QueryChanged(self: win32more.Windows.UI.Xaml.Controls.ISearchBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SuggestionsRequested(self: win32more.Windows.UI.Xaml.Controls.ISearchBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SearchBox, win32more.Windows.UI.Xaml.Controls.SearchBoxSuggestionsRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SuggestionsRequested(self: win32more.Windows.UI.Xaml.Controls.ISearchBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_QuerySubmitted(self: win32more.Windows.UI.Xaml.Controls.ISearchBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SearchBox, win32more.Windows.UI.Xaml.Controls.SearchBoxQuerySubmittedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_QuerySubmitted(self: win32more.Windows.UI.Xaml.Controls.ISearchBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ResultSuggestionChosen(self: win32more.Windows.UI.Xaml.Controls.ISearchBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SearchBox, win32more.Windows.UI.Xaml.Controls.SearchBoxResultSuggestionChosenEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ResultSuggestionChosen(self: win32more.Windows.UI.Xaml.Controls.ISearchBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PrepareForFocusOnKeyboardInput(self: win32more.Windows.UI.Xaml.Controls.ISearchBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SearchBox, win32more.Windows.UI.Xaml.RoutedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PrepareForFocusOnKeyboardInput(self: win32more.Windows.UI.Xaml.Controls.ISearchBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def SetLocalContentSuggestionSettings(self: win32more.Windows.UI.Xaml.Controls.ISearchBox, settings: win32more.Windows.ApplicationModel.Search.LocalContentSuggestionSettings) -> Void: ...
    @winrt_classmethod
    def get_SearchHistoryEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.ISearchBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SearchHistoryContextProperty(cls: win32more.Windows.UI.Xaml.Controls.ISearchBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderTextProperty(cls: win32more.Windows.UI.Xaml.Controls.ISearchBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_QueryTextProperty(cls: win32more.Windows.UI.Xaml.Controls.ISearchBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FocusOnKeyboardInputProperty(cls: win32more.Windows.UI.Xaml.Controls.ISearchBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ChooseSuggestionOnEnterProperty(cls: win32more.Windows.UI.Xaml.Controls.ISearchBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ChooseSuggestionOnEnter = property(get_ChooseSuggestionOnEnter, put_ChooseSuggestionOnEnter)
    FocusOnKeyboardInput = property(get_FocusOnKeyboardInput, put_FocusOnKeyboardInput)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    QueryText = property(get_QueryText, put_QueryText)
    SearchHistoryContext = property(get_SearchHistoryContext, put_SearchHistoryContext)
    SearchHistoryEnabled = property(get_SearchHistoryEnabled, put_SearchHistoryEnabled)
    _SearchBox_Meta_.ChooseSuggestionOnEnterProperty = property(get_ChooseSuggestionOnEnterProperty, None)
    _SearchBox_Meta_.FocusOnKeyboardInputProperty = property(get_FocusOnKeyboardInputProperty, None)
    _SearchBox_Meta_.PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    _SearchBox_Meta_.QueryTextProperty = property(get_QueryTextProperty, None)
    _SearchBox_Meta_.SearchHistoryContextProperty = property(get_SearchHistoryContextProperty, None)
    _SearchBox_Meta_.SearchHistoryEnabledProperty = property(get_SearchHistoryEnabledProperty, None)
    QueryChanged = event()
    SuggestionsRequested = event()
    QuerySubmitted = event()
    ResultSuggestionChosen = event()
    PrepareForFocusOnKeyboardInput = event()
class SearchBoxQueryChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ISearchBoxQueryChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.SearchBoxQueryChangedEventArgs'
    @winrt_mixinmethod
    def get_QueryText(self: win32more.Windows.UI.Xaml.Controls.ISearchBoxQueryChangedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Language(self: win32more.Windows.UI.Xaml.Controls.ISearchBoxQueryChangedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_LinguisticDetails(self: win32more.Windows.UI.Xaml.Controls.ISearchBoxQueryChangedEventArgs) -> win32more.Windows.ApplicationModel.Search.SearchQueryLinguisticDetails: ...
    Language = property(get_Language, None)
    LinguisticDetails = property(get_LinguisticDetails, None)
    QueryText = property(get_QueryText, None)
class SearchBoxQuerySubmittedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ISearchBoxQuerySubmittedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.SearchBoxQuerySubmittedEventArgs'
    @winrt_mixinmethod
    def get_QueryText(self: win32more.Windows.UI.Xaml.Controls.ISearchBoxQuerySubmittedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Language(self: win32more.Windows.UI.Xaml.Controls.ISearchBoxQuerySubmittedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_LinguisticDetails(self: win32more.Windows.UI.Xaml.Controls.ISearchBoxQuerySubmittedEventArgs) -> win32more.Windows.ApplicationModel.Search.SearchQueryLinguisticDetails: ...
    @winrt_mixinmethod
    def get_KeyModifiers(self: win32more.Windows.UI.Xaml.Controls.ISearchBoxQuerySubmittedEventArgs) -> win32more.Windows.System.VirtualKeyModifiers: ...
    KeyModifiers = property(get_KeyModifiers, None)
    Language = property(get_Language, None)
    LinguisticDetails = property(get_LinguisticDetails, None)
    QueryText = property(get_QueryText, None)
class SearchBoxResultSuggestionChosenEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ISearchBoxResultSuggestionChosenEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.SearchBoxResultSuggestionChosenEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SearchBoxResultSuggestionChosenEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.SearchBoxResultSuggestionChosenEventArgs: ...
    @winrt_mixinmethod
    def get_Tag(self: win32more.Windows.UI.Xaml.Controls.ISearchBoxResultSuggestionChosenEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_KeyModifiers(self: win32more.Windows.UI.Xaml.Controls.ISearchBoxResultSuggestionChosenEventArgs) -> win32more.Windows.System.VirtualKeyModifiers: ...
    KeyModifiers = property(get_KeyModifiers, None)
    Tag = property(get_Tag, None)
class SearchBoxSuggestionsRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ISearchBoxSuggestionsRequestedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.SearchBoxSuggestionsRequestedEventArgs'
    @winrt_mixinmethod
    def get_QueryText(self: win32more.Windows.UI.Xaml.Controls.ISearchBoxSuggestionsRequestedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Language(self: win32more.Windows.UI.Xaml.Controls.ISearchBoxSuggestionsRequestedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_LinguisticDetails(self: win32more.Windows.UI.Xaml.Controls.ISearchBoxSuggestionsRequestedEventArgs) -> win32more.Windows.ApplicationModel.Search.SearchQueryLinguisticDetails: ...
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.UI.Xaml.Controls.ISearchBoxSuggestionsRequestedEventArgs) -> win32more.Windows.ApplicationModel.Search.SearchSuggestionsRequest: ...
    Language = property(get_Language, None)
    LinguisticDetails = property(get_LinguisticDetails, None)
    QueryText = property(get_QueryText, None)
    Request = property(get_Request, None)
class SectionsInViewChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ISectionsInViewChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.SectionsInViewChangedEventArgs'
    @winrt_mixinmethod
    def get_AddedSections(self: win32more.Windows.UI.Xaml.Controls.ISectionsInViewChangedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection]: ...
    @winrt_mixinmethod
    def get_RemovedSections(self: win32more.Windows.UI.Xaml.Controls.ISectionsInViewChangedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.HubSection]: ...
    AddedSections = property(get_AddedSections, None)
    RemovedSections = property(get_RemovedSections, None)
class SectionsInViewChangedEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6becaa6a-63f8-47ff-b6ac-76e7da247d67}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Controls.SectionsInViewChangedEventArgs) -> Void: ...
class SelectionChangedEventArgs(ComPtr):
    extends: win32more.Windows.UI.Xaml.RoutedEventArgs
    default_interface: win32more.Windows.UI.Xaml.Controls.ISelectionChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.SelectionChangedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SelectionChangedEventArgs.CreateInstanceWithRemovedItemsAndAddedItems(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstanceWithRemovedItemsAndAddedItems(cls: win32more.Windows.UI.Xaml.Controls.ISelectionChangedEventArgsFactory, removedItems: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable], addedItems: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable], baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SelectionChangedEventArgs: ...
    @winrt_mixinmethod
    def get_AddedItems(self: win32more.Windows.UI.Xaml.Controls.ISelectionChangedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def get_RemovedItems(self: win32more.Windows.UI.Xaml.Controls.ISelectionChangedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    AddedItems = property(get_AddedItems, None)
    RemovedItems = property(get_RemovedItems, None)
class SelectionChangedEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e1a05352-5aa0-42ca-9cd9-068a14db6e68}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Controls.SelectionChangedEventArgs) -> Void: ...
class SelectionMode(Enum, Int32):
    Single = 0
    Multiple = 1
    Extended = 2
class _SemanticZoom_Meta_(ComPtr.__class__):
    pass
class SemanticZoom(ComPtr, metaclass=_SemanticZoom_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.ISemanticZoom
    _classid_ = 'Windows.UI.Xaml.Controls.SemanticZoom'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SemanticZoom.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.SemanticZoom: ...
    @winrt_mixinmethod
    def get_ZoomedInView(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoom) -> win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation: ...
    @winrt_mixinmethod
    def put_ZoomedInView(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoom, value: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation) -> Void: ...
    @winrt_mixinmethod
    def get_ZoomedOutView(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoom) -> win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation: ...
    @winrt_mixinmethod
    def put_ZoomedOutView(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoom, value: win32more.Windows.UI.Xaml.Controls.ISemanticZoomInformation) -> Void: ...
    @winrt_mixinmethod
    def get_IsZoomedInViewActive(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoom) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZoomedInViewActive(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoom, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CanChangeViews(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoom) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanChangeViews(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoom, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_ViewChangeStarted(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoom, handler: win32more.Windows.UI.Xaml.Controls.SemanticZoomViewChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ViewChangeStarted(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoom, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ViewChangeCompleted(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoom, handler: win32more.Windows.UI.Xaml.Controls.SemanticZoomViewChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ViewChangeCompleted(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoom, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ToggleActiveView(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoom) -> Void: ...
    @winrt_mixinmethod
    def get_IsZoomOutButtonEnabled(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoom) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZoomOutButtonEnabled(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoom, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_ZoomedInViewProperty(cls: win32more.Windows.UI.Xaml.Controls.ISemanticZoomStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ZoomedOutViewProperty(cls: win32more.Windows.UI.Xaml.Controls.ISemanticZoomStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsZoomedInViewActiveProperty(cls: win32more.Windows.UI.Xaml.Controls.ISemanticZoomStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanChangeViewsProperty(cls: win32more.Windows.UI.Xaml.Controls.ISemanticZoomStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsZoomOutButtonEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.ISemanticZoomStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CanChangeViews = property(get_CanChangeViews, put_CanChangeViews)
    IsZoomOutButtonEnabled = property(get_IsZoomOutButtonEnabled, put_IsZoomOutButtonEnabled)
    IsZoomedInViewActive = property(get_IsZoomedInViewActive, put_IsZoomedInViewActive)
    ZoomedInView = property(get_ZoomedInView, put_ZoomedInView)
    ZoomedOutView = property(get_ZoomedOutView, put_ZoomedOutView)
    _SemanticZoom_Meta_.CanChangeViewsProperty = property(get_CanChangeViewsProperty, None)
    _SemanticZoom_Meta_.IsZoomOutButtonEnabledProperty = property(get_IsZoomOutButtonEnabledProperty, None)
    _SemanticZoom_Meta_.IsZoomedInViewActiveProperty = property(get_IsZoomedInViewActiveProperty, None)
    _SemanticZoom_Meta_.ZoomedInViewProperty = property(get_ZoomedInViewProperty, None)
    _SemanticZoom_Meta_.ZoomedOutViewProperty = property(get_ZoomedOutViewProperty, None)
    ViewChangeStarted = event()
    ViewChangeCompleted = event()
class SemanticZoomLocation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ISemanticZoomLocation
    _classid_ = 'Windows.UI.Xaml.Controls.SemanticZoomLocation'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomLocation) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Item(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomLocation, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_Bounds(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomLocation) -> win32more.Windows.Foundation.Rect: ...
    @winrt_mixinmethod
    def put_Bounds(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomLocation, value: win32more.Windows.Foundation.Rect) -> Void: ...
    Bounds = property(get_Bounds, put_Bounds)
    Item = property(get_Item, put_Item)
class SemanticZoomViewChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ISemanticZoomViewChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.SemanticZoomViewChangedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SemanticZoomViewChangedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.SemanticZoomViewChangedEventArgs: ...
    @winrt_mixinmethod
    def get_IsSourceZoomedInView(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomViewChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSourceZoomedInView(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomViewChangedEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SourceItem(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomViewChangedEventArgs) -> win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation: ...
    @winrt_mixinmethod
    def put_SourceItem(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomViewChangedEventArgs, value: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def get_DestinationItem(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomViewChangedEventArgs) -> win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation: ...
    @winrt_mixinmethod
    def put_DestinationItem(self: win32more.Windows.UI.Xaml.Controls.ISemanticZoomViewChangedEventArgs, value: win32more.Windows.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    DestinationItem = property(get_DestinationItem, put_DestinationItem)
    IsSourceZoomedInView = property(get_IsSourceZoomedInView, put_IsSourceZoomedInView)
    SourceItem = property(get_SourceItem, put_SourceItem)
class SemanticZoomViewChangedEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1fa9161d-5d73-44fb-81ac-d1c9384919d4}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Controls.SemanticZoomViewChangedEventArgs) -> Void: ...
class _SettingsFlyout_Meta_(ComPtr.__class__):
    pass
class SettingsFlyout(ComPtr, metaclass=_SettingsFlyout_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Windows.UI.Xaml.Controls.ISettingsFlyout
    _classid_ = 'Windows.UI.Xaml.Controls.SettingsFlyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SettingsFlyout.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ISettingsFlyoutFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SettingsFlyout: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Windows.UI.Xaml.Controls.ISettingsFlyout) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Windows.UI.Xaml.Controls.ISettingsFlyout, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderBackground(self: win32more.Windows.UI.Xaml.Controls.ISettingsFlyout) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_HeaderBackground(self: win32more.Windows.UI.Xaml.Controls.ISettingsFlyout, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderForeground(self: win32more.Windows.UI.Xaml.Controls.ISettingsFlyout) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_HeaderForeground(self: win32more.Windows.UI.Xaml.Controls.ISettingsFlyout, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_IconSource(self: win32more.Windows.UI.Xaml.Controls.ISettingsFlyout) -> win32more.Windows.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_IconSource(self: win32more.Windows.UI.Xaml.Controls.ISettingsFlyout, value: win32more.Windows.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Windows.UI.Xaml.Controls.ISettingsFlyout) -> win32more.Windows.UI.Xaml.Controls.Primitives.SettingsFlyoutTemplateSettings: ...
    @winrt_mixinmethod
    def add_BackClick(self: win32more.Windows.UI.Xaml.Controls.ISettingsFlyout, handler: win32more.Windows.UI.Xaml.Controls.BackClickEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_BackClick(self: win32more.Windows.UI.Xaml.Controls.ISettingsFlyout, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Show(self: win32more.Windows.UI.Xaml.Controls.ISettingsFlyout) -> Void: ...
    @winrt_mixinmethod
    def ShowIndependent(self: win32more.Windows.UI.Xaml.Controls.ISettingsFlyout) -> Void: ...
    @winrt_mixinmethod
    def Hide(self: win32more.Windows.UI.Xaml.Controls.ISettingsFlyout) -> Void: ...
    @winrt_classmethod
    def get_TitleProperty(cls: win32more.Windows.UI.Xaml.Controls.ISettingsFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderBackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ISettingsFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ISettingsFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconSourceProperty(cls: win32more.Windows.UI.Xaml.Controls.ISettingsFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HeaderBackground = property(get_HeaderBackground, put_HeaderBackground)
    HeaderForeground = property(get_HeaderForeground, put_HeaderForeground)
    IconSource = property(get_IconSource, put_IconSource)
    TemplateSettings = property(get_TemplateSettings, None)
    Title = property(get_Title, put_Title)
    _SettingsFlyout_Meta_.HeaderBackgroundProperty = property(get_HeaderBackgroundProperty, None)
    _SettingsFlyout_Meta_.HeaderForegroundProperty = property(get_HeaderForegroundProperty, None)
    _SettingsFlyout_Meta_.IconSourceProperty = property(get_IconSourceProperty, None)
    _SettingsFlyout_Meta_.TitleProperty = property(get_TitleProperty, None)
    BackClick = event()
class _Slider_Meta_(ComPtr.__class__):
    pass
class Slider(ComPtr, metaclass=_Slider_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.RangeBase
    default_interface: win32more.Windows.UI.Xaml.Controls.ISlider
    _classid_ = 'Windows.UI.Xaml.Controls.Slider'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.Slider.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ISliderFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.Slider: ...
    @winrt_mixinmethod
    def get_IntermediateValue(self: win32more.Windows.UI.Xaml.Controls.ISlider) -> Double: ...
    @winrt_mixinmethod
    def put_IntermediateValue(self: win32more.Windows.UI.Xaml.Controls.ISlider, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_StepFrequency(self: win32more.Windows.UI.Xaml.Controls.ISlider) -> Double: ...
    @winrt_mixinmethod
    def put_StepFrequency(self: win32more.Windows.UI.Xaml.Controls.ISlider, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_SnapsTo(self: win32more.Windows.UI.Xaml.Controls.ISlider) -> win32more.Windows.UI.Xaml.Controls.Primitives.SliderSnapsTo: ...
    @winrt_mixinmethod
    def put_SnapsTo(self: win32more.Windows.UI.Xaml.Controls.ISlider, value: win32more.Windows.UI.Xaml.Controls.Primitives.SliderSnapsTo) -> Void: ...
    @winrt_mixinmethod
    def get_TickFrequency(self: win32more.Windows.UI.Xaml.Controls.ISlider) -> Double: ...
    @winrt_mixinmethod
    def put_TickFrequency(self: win32more.Windows.UI.Xaml.Controls.ISlider, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_TickPlacement(self: win32more.Windows.UI.Xaml.Controls.ISlider) -> win32more.Windows.UI.Xaml.Controls.Primitives.TickPlacement: ...
    @winrt_mixinmethod
    def put_TickPlacement(self: win32more.Windows.UI.Xaml.Controls.ISlider, value: win32more.Windows.UI.Xaml.Controls.Primitives.TickPlacement) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Windows.UI.Xaml.Controls.ISlider) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Windows.UI.Xaml.Controls.ISlider, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_IsDirectionReversed(self: win32more.Windows.UI.Xaml.Controls.ISlider) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDirectionReversed(self: win32more.Windows.UI.Xaml.Controls.ISlider, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsThumbToolTipEnabled(self: win32more.Windows.UI.Xaml.Controls.ISlider) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsThumbToolTipEnabled(self: win32more.Windows.UI.Xaml.Controls.ISlider, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ThumbToolTipValueConverter(self: win32more.Windows.UI.Xaml.Controls.ISlider) -> win32more.Windows.UI.Xaml.Data.IValueConverter: ...
    @winrt_mixinmethod
    def put_ThumbToolTipValueConverter(self: win32more.Windows.UI.Xaml.Controls.ISlider, value: win32more.Windows.UI.Xaml.Data.IValueConverter) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Windows.UI.Xaml.Controls.ISlider2) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Windows.UI.Xaml.Controls.ISlider2, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.ISlider2) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.ISlider2, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.ISliderStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.ISliderStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IntermediateValueProperty(cls: win32more.Windows.UI.Xaml.Controls.ISliderStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StepFrequencyProperty(cls: win32more.Windows.UI.Xaml.Controls.ISliderStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SnapsToProperty(cls: win32more.Windows.UI.Xaml.Controls.ISliderStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TickFrequencyProperty(cls: win32more.Windows.UI.Xaml.Controls.ISliderStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TickPlacementProperty(cls: win32more.Windows.UI.Xaml.Controls.ISliderStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Windows.UI.Xaml.Controls.ISliderStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsDirectionReversedProperty(cls: win32more.Windows.UI.Xaml.Controls.ISliderStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsThumbToolTipEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.ISliderStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ThumbToolTipValueConverterProperty(cls: win32more.Windows.UI.Xaml.Controls.ISliderStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IntermediateValue = property(get_IntermediateValue, put_IntermediateValue)
    IsDirectionReversed = property(get_IsDirectionReversed, put_IsDirectionReversed)
    IsThumbToolTipEnabled = property(get_IsThumbToolTipEnabled, put_IsThumbToolTipEnabled)
    Orientation = property(get_Orientation, put_Orientation)
    SnapsTo = property(get_SnapsTo, put_SnapsTo)
    StepFrequency = property(get_StepFrequency, put_StepFrequency)
    ThumbToolTipValueConverter = property(get_ThumbToolTipValueConverter, put_ThumbToolTipValueConverter)
    TickFrequency = property(get_TickFrequency, put_TickFrequency)
    TickPlacement = property(get_TickPlacement, put_TickPlacement)
    _Slider_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _Slider_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _Slider_Meta_.IntermediateValueProperty = property(get_IntermediateValueProperty, None)
    _Slider_Meta_.IsDirectionReversedProperty = property(get_IsDirectionReversedProperty, None)
    _Slider_Meta_.IsThumbToolTipEnabledProperty = property(get_IsThumbToolTipEnabledProperty, None)
    _Slider_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _Slider_Meta_.SnapsToProperty = property(get_SnapsToProperty, None)
    _Slider_Meta_.StepFrequencyProperty = property(get_StepFrequencyProperty, None)
    _Slider_Meta_.ThumbToolTipValueConverterProperty = property(get_ThumbToolTipValueConverterProperty, None)
    _Slider_Meta_.TickFrequencyProperty = property(get_TickFrequencyProperty, None)
    _Slider_Meta_.TickPlacementProperty = property(get_TickPlacementProperty, None)
class SnapPointsType(Enum, Int32):
    None_ = 0
    Optional = 1
    Mandatory = 2
    OptionalSingle = 3
    MandatorySingle = 4
class _SplitButton_Meta_(ComPtr.__class__):
    pass
class SplitButton(ComPtr, metaclass=_SplitButton_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Windows.UI.Xaml.Controls.ISplitButton
    _classid_ = 'Windows.UI.Xaml.Controls.SplitButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SplitButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ISplitButtonFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SplitButton: ...
    @winrt_mixinmethod
    def get_Flyout(self: win32more.Windows.UI.Xaml.Controls.ISplitButton) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def put_Flyout(self: win32more.Windows.UI.Xaml.Controls.ISplitButton, value: win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_mixinmethod
    def get_Command(self: win32more.Windows.UI.Xaml.Controls.ISplitButton) -> win32more.Windows.UI.Xaml.Input.ICommand: ...
    @winrt_mixinmethod
    def put_Command(self: win32more.Windows.UI.Xaml.Controls.ISplitButton, value: win32more.Windows.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_mixinmethod
    def get_CommandParameter(self: win32more.Windows.UI.Xaml.Controls.ISplitButton) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_CommandParameter(self: win32more.Windows.UI.Xaml.Controls.ISplitButton, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def add_Click(self: win32more.Windows.UI.Xaml.Controls.ISplitButton, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SplitButton, win32more.Windows.UI.Xaml.Controls.SplitButtonClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Click(self: win32more.Windows.UI.Xaml.Controls.ISplitButton, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_FlyoutProperty(cls: win32more.Windows.UI.Xaml.Controls.ISplitButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CommandProperty(cls: win32more.Windows.UI.Xaml.Controls.ISplitButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CommandParameterProperty(cls: win32more.Windows.UI.Xaml.Controls.ISplitButtonStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Command = property(get_Command, put_Command)
    CommandParameter = property(get_CommandParameter, put_CommandParameter)
    Flyout = property(get_Flyout, put_Flyout)
    _SplitButton_Meta_.CommandParameterProperty = property(get_CommandParameterProperty, None)
    _SplitButton_Meta_.CommandProperty = property(get_CommandProperty, None)
    _SplitButton_Meta_.FlyoutProperty = property(get_FlyoutProperty, None)
    Click = event()
class SplitButtonAutomationPeer(ComPtr):
    extends: win32more.Windows.UI.Xaml.Automation.Peers.FrameworkElementAutomationPeer
    default_interface: win32more.Windows.UI.Xaml.Controls.ISplitButtonAutomationPeer
    _classid_ = 'Windows.UI.Xaml.Controls.SplitButtonAutomationPeer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SplitButtonAutomationPeer.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ISplitButtonAutomationPeerFactory, owner: win32more.Windows.UI.Xaml.Controls.SplitButton, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SplitButtonAutomationPeer: ...
    @winrt_mixinmethod
    def get_ExpandCollapseState(self: win32more.Windows.UI.Xaml.Automation.Provider.IExpandCollapseProvider) -> win32more.Windows.UI.Xaml.Automation.ExpandCollapseState: ...
    @winrt_mixinmethod
    def Collapse(self: win32more.Windows.UI.Xaml.Automation.Provider.IExpandCollapseProvider) -> Void: ...
    @winrt_mixinmethod
    def Expand(self: win32more.Windows.UI.Xaml.Automation.Provider.IExpandCollapseProvider) -> Void: ...
    @winrt_mixinmethod
    def Invoke(self: win32more.Windows.UI.Xaml.Automation.Provider.IInvokeProvider) -> Void: ...
    ExpandCollapseState = property(get_ExpandCollapseState, None)
class SplitButtonClickEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ISplitButtonClickEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.SplitButtonClickEventArgs'
class _SplitView_Meta_(ComPtr.__class__):
    pass
class SplitView(ComPtr, metaclass=_SplitView_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.ISplitView
    _classid_ = 'Windows.UI.Xaml.Controls.SplitView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SplitView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ISplitViewFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SplitView: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Windows.UI.Xaml.Controls.ISplitView) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Windows.UI.Xaml.Controls.ISplitView, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_Pane(self: win32more.Windows.UI.Xaml.Controls.ISplitView) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Pane(self: win32more.Windows.UI.Xaml.Controls.ISplitView, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_IsPaneOpen(self: win32more.Windows.UI.Xaml.Controls.ISplitView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPaneOpen(self: win32more.Windows.UI.Xaml.Controls.ISplitView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_OpenPaneLength(self: win32more.Windows.UI.Xaml.Controls.ISplitView) -> Double: ...
    @winrt_mixinmethod
    def put_OpenPaneLength(self: win32more.Windows.UI.Xaml.Controls.ISplitView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_CompactPaneLength(self: win32more.Windows.UI.Xaml.Controls.ISplitView) -> Double: ...
    @winrt_mixinmethod
    def put_CompactPaneLength(self: win32more.Windows.UI.Xaml.Controls.ISplitView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_PanePlacement(self: win32more.Windows.UI.Xaml.Controls.ISplitView) -> win32more.Windows.UI.Xaml.Controls.SplitViewPanePlacement: ...
    @winrt_mixinmethod
    def put_PanePlacement(self: win32more.Windows.UI.Xaml.Controls.ISplitView, value: win32more.Windows.UI.Xaml.Controls.SplitViewPanePlacement) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayMode(self: win32more.Windows.UI.Xaml.Controls.ISplitView) -> win32more.Windows.UI.Xaml.Controls.SplitViewDisplayMode: ...
    @winrt_mixinmethod
    def put_DisplayMode(self: win32more.Windows.UI.Xaml.Controls.ISplitView, value: win32more.Windows.UI.Xaml.Controls.SplitViewDisplayMode) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Windows.UI.Xaml.Controls.ISplitView) -> win32more.Windows.UI.Xaml.Controls.Primitives.SplitViewTemplateSettings: ...
    @winrt_mixinmethod
    def get_PaneBackground(self: win32more.Windows.UI.Xaml.Controls.ISplitView) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_PaneBackground(self: win32more.Windows.UI.Xaml.Controls.ISplitView, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def add_PaneClosing(self: win32more.Windows.UI.Xaml.Controls.ISplitView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SplitView, win32more.Windows.UI.Xaml.Controls.SplitViewPaneClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PaneClosing(self: win32more.Windows.UI.Xaml.Controls.ISplitView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PaneClosed(self: win32more.Windows.UI.Xaml.Controls.ISplitView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SplitView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PaneClosed(self: win32more.Windows.UI.Xaml.Controls.ISplitView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_LightDismissOverlayMode(self: win32more.Windows.UI.Xaml.Controls.ISplitView2) -> win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_mixinmethod
    def put_LightDismissOverlayMode(self: win32more.Windows.UI.Xaml.Controls.ISplitView2, value: win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_mixinmethod
    def add_PaneOpening(self: win32more.Windows.UI.Xaml.Controls.ISplitView3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SplitView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PaneOpening(self: win32more.Windows.UI.Xaml.Controls.ISplitView3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PaneOpened(self: win32more.Windows.UI.Xaml.Controls.ISplitView3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SplitView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PaneOpened(self: win32more.Windows.UI.Xaml.Controls.ISplitView3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_LightDismissOverlayModeProperty(cls: win32more.Windows.UI.Xaml.Controls.ISplitViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Windows.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneProperty(cls: win32more.Windows.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPaneOpenProperty(cls: win32more.Windows.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OpenPaneLengthProperty(cls: win32more.Windows.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CompactPaneLengthProperty(cls: win32more.Windows.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PanePlacementProperty(cls: win32more.Windows.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisplayModeProperty(cls: win32more.Windows.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TemplateSettingsProperty(cls: win32more.Windows.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneBackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CompactPaneLength = property(get_CompactPaneLength, put_CompactPaneLength)
    Content = property(get_Content, put_Content)
    DisplayMode = property(get_DisplayMode, put_DisplayMode)
    IsPaneOpen = property(get_IsPaneOpen, put_IsPaneOpen)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    OpenPaneLength = property(get_OpenPaneLength, put_OpenPaneLength)
    Pane = property(get_Pane, put_Pane)
    PaneBackground = property(get_PaneBackground, put_PaneBackground)
    PanePlacement = property(get_PanePlacement, put_PanePlacement)
    TemplateSettings = property(get_TemplateSettings, None)
    _SplitView_Meta_.CompactPaneLengthProperty = property(get_CompactPaneLengthProperty, None)
    _SplitView_Meta_.ContentProperty = property(get_ContentProperty, None)
    _SplitView_Meta_.DisplayModeProperty = property(get_DisplayModeProperty, None)
    _SplitView_Meta_.IsPaneOpenProperty = property(get_IsPaneOpenProperty, None)
    _SplitView_Meta_.LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    _SplitView_Meta_.OpenPaneLengthProperty = property(get_OpenPaneLengthProperty, None)
    _SplitView_Meta_.PaneBackgroundProperty = property(get_PaneBackgroundProperty, None)
    _SplitView_Meta_.PanePlacementProperty = property(get_PanePlacementProperty, None)
    _SplitView_Meta_.PaneProperty = property(get_PaneProperty, None)
    _SplitView_Meta_.TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
    PaneClosing = event()
    PaneClosed = event()
    PaneOpening = event()
    PaneOpened = event()
class SplitViewDisplayMode(Enum, Int32):
    Overlay = 0
    Inline = 1
    CompactOverlay = 2
    CompactInline = 3
class SplitViewPaneClosingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ISplitViewPaneClosingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.SplitViewPaneClosingEventArgs'
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Windows.UI.Xaml.Controls.ISplitViewPaneClosingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Windows.UI.Xaml.Controls.ISplitViewPaneClosingEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
class SplitViewPanePlacement(Enum, Int32):
    Left = 0
    Right = 1
class _StackPanel_Meta_(ComPtr.__class__):
    pass
class StackPanel(ComPtr, metaclass=_StackPanel_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Panel
    default_interface: win32more.Windows.UI.Xaml.Controls.IStackPanel
    _classid_ = 'Windows.UI.Xaml.Controls.StackPanel'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.StackPanel.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IStackPanelFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.StackPanel: ...
    @winrt_mixinmethod
    def get_AreScrollSnapPointsRegular(self: win32more.Windows.UI.Xaml.Controls.IStackPanel) -> Boolean: ...
    @winrt_mixinmethod
    def put_AreScrollSnapPointsRegular(self: win32more.Windows.UI.Xaml.Controls.IStackPanel, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Windows.UI.Xaml.Controls.IStackPanel) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Windows.UI.Xaml.Controls.IStackPanel, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_BorderBrush(self: win32more.Windows.UI.Xaml.Controls.IStackPanel2) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BorderBrush(self: win32more.Windows.UI.Xaml.Controls.IStackPanel2, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BorderThickness(self: win32more.Windows.UI.Xaml.Controls.IStackPanel2) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_BorderThickness(self: win32more.Windows.UI.Xaml.Controls.IStackPanel2, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_CornerRadius(self: win32more.Windows.UI.Xaml.Controls.IStackPanel2) -> win32more.Windows.UI.Xaml.CornerRadius: ...
    @winrt_mixinmethod
    def put_CornerRadius(self: win32more.Windows.UI.Xaml.Controls.IStackPanel2, value: win32more.Windows.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Windows.UI.Xaml.Controls.IStackPanel2) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Windows.UI.Xaml.Controls.IStackPanel2, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_Spacing(self: win32more.Windows.UI.Xaml.Controls.IStackPanel4) -> Double: ...
    @winrt_mixinmethod
    def put_Spacing(self: win32more.Windows.UI.Xaml.Controls.IStackPanel4, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_BackgroundSizing(self: win32more.Windows.UI.Xaml.Controls.IStackPanel5) -> win32more.Windows.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_mixinmethod
    def put_BackgroundSizing(self: win32more.Windows.UI.Xaml.Controls.IStackPanel5, value: win32more.Windows.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_mixinmethod
    def get_AreHorizontalSnapPointsRegular(self: win32more.Windows.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo) -> Boolean: ...
    @winrt_mixinmethod
    def get_AreVerticalSnapPointsRegular(self: win32more.Windows.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo) -> Boolean: ...
    @winrt_mixinmethod
    def add_HorizontalSnapPointsChanged(self: win32more.Windows.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HorizontalSnapPointsChanged(self: win32more.Windows.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_VerticalSnapPointsChanged(self: win32more.Windows.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_VerticalSnapPointsChanged(self: win32more.Windows.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetIrregularSnapPoints(self: win32more.Windows.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, orientation: win32more.Windows.UI.Xaml.Controls.Orientation, alignment: win32more.Windows.UI.Xaml.Controls.Primitives.SnapPointsAlignment) -> win32more.Windows.Foundation.Collections.IVectorView[Single]: ...
    @winrt_mixinmethod
    def GetRegularSnapPoints(self: win32more.Windows.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, orientation: win32more.Windows.UI.Xaml.Controls.Orientation, alignment: win32more.Windows.UI.Xaml.Controls.Primitives.SnapPointsAlignment, offset: POINTER(Single)) -> Single: ...
    @winrt_mixinmethod
    def GetInsertionIndexes(self: win32more.Windows.UI.Xaml.Controls.IInsertionPanel, position: win32more.Windows.Foundation.Point, first: POINTER(Int32), second: POINTER(Int32)) -> Void: ...
    @winrt_classmethod
    def get_BackgroundSizingProperty(cls: win32more.Windows.UI.Xaml.Controls.IStackPanelStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SpacingProperty(cls: win32more.Windows.UI.Xaml.Controls.IStackPanelStatics4) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.IStackPanelStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderThicknessProperty(cls: win32more.Windows.UI.Xaml.Controls.IStackPanelStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CornerRadiusProperty(cls: win32more.Windows.UI.Xaml.Controls.IStackPanelStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Windows.UI.Xaml.Controls.IStackPanelStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AreScrollSnapPointsRegularProperty(cls: win32more.Windows.UI.Xaml.Controls.IStackPanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Windows.UI.Xaml.Controls.IStackPanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AreHorizontalSnapPointsRegular = property(get_AreHorizontalSnapPointsRegular, None)
    AreScrollSnapPointsRegular = property(get_AreScrollSnapPointsRegular, put_AreScrollSnapPointsRegular)
    AreVerticalSnapPointsRegular = property(get_AreVerticalSnapPointsRegular, None)
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    Orientation = property(get_Orientation, put_Orientation)
    Padding = property(get_Padding, put_Padding)
    Spacing = property(get_Spacing, put_Spacing)
    _StackPanel_Meta_.AreScrollSnapPointsRegularProperty = property(get_AreScrollSnapPointsRegularProperty, None)
    _StackPanel_Meta_.BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    _StackPanel_Meta_.BorderBrushProperty = property(get_BorderBrushProperty, None)
    _StackPanel_Meta_.BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    _StackPanel_Meta_.CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    _StackPanel_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _StackPanel_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    _StackPanel_Meta_.SpacingProperty = property(get_SpacingProperty, None)
    HorizontalSnapPointsChanged = event()
    VerticalSnapPointsChanged = event()
class StretchDirection(Enum, Int32):
    UpOnly = 0
    DownOnly = 1
    Both = 2
class StyleSelector(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IStyleSelector
    _classid_ = 'Windows.UI.Xaml.Controls.StyleSelector'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.StyleSelector.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IStyleSelectorFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.StyleSelector: ...
    @winrt_mixinmethod
    def SelectStyle(self: win32more.Windows.UI.Xaml.Controls.IStyleSelector, item: win32more.Windows.Win32.System.WinRT.IInspectable, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def SelectStyleCore(self: win32more.Windows.UI.Xaml.Controls.IStyleSelectorOverrides, item: win32more.Windows.Win32.System.WinRT.IInspectable, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Style: ...
class SwapChainBackgroundPanel(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.Grid
    default_interface: win32more.Windows.UI.Xaml.Controls.ISwapChainBackgroundPanel
    _classid_ = 'Windows.UI.Xaml.Controls.SwapChainBackgroundPanel'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SwapChainBackgroundPanel.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ISwapChainBackgroundPanelFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SwapChainBackgroundPanel: ...
    @winrt_mixinmethod
    def CreateCoreIndependentInputSource(self: win32more.Windows.UI.Xaml.Controls.ISwapChainBackgroundPanel2, deviceTypes: win32more.Windows.UI.Core.CoreInputDeviceTypes) -> win32more.Windows.UI.Core.CoreIndependentInputSource: ...
class _SwapChainPanel_Meta_(ComPtr.__class__):
    pass
class SwapChainPanel(ComPtr, metaclass=_SwapChainPanel_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Grid
    default_interface: win32more.Windows.UI.Xaml.Controls.ISwapChainPanel
    _classid_ = 'Windows.UI.Xaml.Controls.SwapChainPanel'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SwapChainPanel.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ISwapChainPanelFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SwapChainPanel: ...
    @winrt_mixinmethod
    def get_CompositionScaleX(self: win32more.Windows.UI.Xaml.Controls.ISwapChainPanel) -> Single: ...
    @winrt_mixinmethod
    def get_CompositionScaleY(self: win32more.Windows.UI.Xaml.Controls.ISwapChainPanel) -> Single: ...
    @winrt_mixinmethod
    def add_CompositionScaleChanged(self: win32more.Windows.UI.Xaml.Controls.ISwapChainPanel, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SwapChainPanel, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CompositionScaleChanged(self: win32more.Windows.UI.Xaml.Controls.ISwapChainPanel, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def CreateCoreIndependentInputSource(self: win32more.Windows.UI.Xaml.Controls.ISwapChainPanel, deviceTypes: win32more.Windows.UI.Core.CoreInputDeviceTypes) -> win32more.Windows.UI.Core.CoreIndependentInputSource: ...
    @winrt_classmethod
    def get_CompositionScaleXProperty(cls: win32more.Windows.UI.Xaml.Controls.ISwapChainPanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CompositionScaleYProperty(cls: win32more.Windows.UI.Xaml.Controls.ISwapChainPanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CompositionScaleX = property(get_CompositionScaleX, None)
    CompositionScaleY = property(get_CompositionScaleY, None)
    _SwapChainPanel_Meta_.CompositionScaleXProperty = property(get_CompositionScaleXProperty, None)
    _SwapChainPanel_Meta_.CompositionScaleYProperty = property(get_CompositionScaleYProperty, None)
    CompositionScaleChanged = event()
class SwipeBehaviorOnInvoked(Enum, Int32):
    Auto = 0
    Close = 1
    RemainOpen = 2
class _SwipeControl_Meta_(ComPtr.__class__):
    pass
class SwipeControl(ComPtr, metaclass=_SwipeControl_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Windows.UI.Xaml.Controls.ISwipeControl
    _classid_ = 'Windows.UI.Xaml.Controls.SwipeControl'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SwipeControl.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ISwipeControlFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SwipeControl: ...
    @winrt_mixinmethod
    def get_LeftItems(self: win32more.Windows.UI.Xaml.Controls.ISwipeControl) -> win32more.Windows.UI.Xaml.Controls.SwipeItems: ...
    @winrt_mixinmethod
    def put_LeftItems(self: win32more.Windows.UI.Xaml.Controls.ISwipeControl, value: win32more.Windows.UI.Xaml.Controls.SwipeItems) -> Void: ...
    @winrt_mixinmethod
    def get_RightItems(self: win32more.Windows.UI.Xaml.Controls.ISwipeControl) -> win32more.Windows.UI.Xaml.Controls.SwipeItems: ...
    @winrt_mixinmethod
    def put_RightItems(self: win32more.Windows.UI.Xaml.Controls.ISwipeControl, value: win32more.Windows.UI.Xaml.Controls.SwipeItems) -> Void: ...
    @winrt_mixinmethod
    def get_TopItems(self: win32more.Windows.UI.Xaml.Controls.ISwipeControl) -> win32more.Windows.UI.Xaml.Controls.SwipeItems: ...
    @winrt_mixinmethod
    def put_TopItems(self: win32more.Windows.UI.Xaml.Controls.ISwipeControl, value: win32more.Windows.UI.Xaml.Controls.SwipeItems) -> Void: ...
    @winrt_mixinmethod
    def get_BottomItems(self: win32more.Windows.UI.Xaml.Controls.ISwipeControl) -> win32more.Windows.UI.Xaml.Controls.SwipeItems: ...
    @winrt_mixinmethod
    def put_BottomItems(self: win32more.Windows.UI.Xaml.Controls.ISwipeControl, value: win32more.Windows.UI.Xaml.Controls.SwipeItems) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.UI.Xaml.Controls.ISwipeControl) -> Void: ...
    @winrt_classmethod
    def get_LeftItemsProperty(cls: win32more.Windows.UI.Xaml.Controls.ISwipeControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RightItemsProperty(cls: win32more.Windows.UI.Xaml.Controls.ISwipeControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TopItemsProperty(cls: win32more.Windows.UI.Xaml.Controls.ISwipeControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BottomItemsProperty(cls: win32more.Windows.UI.Xaml.Controls.ISwipeControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BottomItems = property(get_BottomItems, put_BottomItems)
    LeftItems = property(get_LeftItems, put_LeftItems)
    RightItems = property(get_RightItems, put_RightItems)
    TopItems = property(get_TopItems, put_TopItems)
    _SwipeControl_Meta_.BottomItemsProperty = property(get_BottomItemsProperty, None)
    _SwipeControl_Meta_.LeftItemsProperty = property(get_LeftItemsProperty, None)
    _SwipeControl_Meta_.RightItemsProperty = property(get_RightItemsProperty, None)
    _SwipeControl_Meta_.TopItemsProperty = property(get_TopItemsProperty, None)
class _SwipeItem_Meta_(ComPtr.__class__):
    pass
class SwipeItem(ComPtr, metaclass=_SwipeItem_Meta_):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Controls.ISwipeItem
    _classid_ = 'Windows.UI.Xaml.Controls.SwipeItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SwipeItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ISwipeItemFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SwipeItem: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.UI.Xaml.Controls.ISwipeItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Windows.UI.Xaml.Controls.ISwipeItem, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IconSource(self: win32more.Windows.UI.Xaml.Controls.ISwipeItem) -> win32more.Windows.UI.Xaml.Controls.IconSource: ...
    @winrt_mixinmethod
    def put_IconSource(self: win32more.Windows.UI.Xaml.Controls.ISwipeItem, value: win32more.Windows.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_mixinmethod
    def get_Background(self: win32more.Windows.UI.Xaml.Controls.ISwipeItem) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Background(self: win32more.Windows.UI.Xaml.Controls.ISwipeItem, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_Foreground(self: win32more.Windows.UI.Xaml.Controls.ISwipeItem) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Foreground(self: win32more.Windows.UI.Xaml.Controls.ISwipeItem, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_Command(self: win32more.Windows.UI.Xaml.Controls.ISwipeItem) -> win32more.Windows.UI.Xaml.Input.ICommand: ...
    @winrt_mixinmethod
    def put_Command(self: win32more.Windows.UI.Xaml.Controls.ISwipeItem, value: win32more.Windows.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_mixinmethod
    def get_CommandParameter(self: win32more.Windows.UI.Xaml.Controls.ISwipeItem) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_CommandParameter(self: win32more.Windows.UI.Xaml.Controls.ISwipeItem, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_BehaviorOnInvoked(self: win32more.Windows.UI.Xaml.Controls.ISwipeItem) -> win32more.Windows.UI.Xaml.Controls.SwipeBehaviorOnInvoked: ...
    @winrt_mixinmethod
    def put_BehaviorOnInvoked(self: win32more.Windows.UI.Xaml.Controls.ISwipeItem, value: win32more.Windows.UI.Xaml.Controls.SwipeBehaviorOnInvoked) -> Void: ...
    @winrt_mixinmethod
    def add_Invoked(self: win32more.Windows.UI.Xaml.Controls.ISwipeItem, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.SwipeItem, win32more.Windows.UI.Xaml.Controls.SwipeItemInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Invoked(self: win32more.Windows.UI.Xaml.Controls.ISwipeItem, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_IconSourceProperty(cls: win32more.Windows.UI.Xaml.Controls.ISwipeItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextProperty(cls: win32more.Windows.UI.Xaml.Controls.ISwipeItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackgroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ISwipeItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ISwipeItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CommandProperty(cls: win32more.Windows.UI.Xaml.Controls.ISwipeItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CommandParameterProperty(cls: win32more.Windows.UI.Xaml.Controls.ISwipeItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BehaviorOnInvokedProperty(cls: win32more.Windows.UI.Xaml.Controls.ISwipeItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Background = property(get_Background, put_Background)
    BehaviorOnInvoked = property(get_BehaviorOnInvoked, put_BehaviorOnInvoked)
    Command = property(get_Command, put_Command)
    CommandParameter = property(get_CommandParameter, put_CommandParameter)
    Foreground = property(get_Foreground, put_Foreground)
    IconSource = property(get_IconSource, put_IconSource)
    Text = property(get_Text, put_Text)
    _SwipeItem_Meta_.BackgroundProperty = property(get_BackgroundProperty, None)
    _SwipeItem_Meta_.BehaviorOnInvokedProperty = property(get_BehaviorOnInvokedProperty, None)
    _SwipeItem_Meta_.CommandParameterProperty = property(get_CommandParameterProperty, None)
    _SwipeItem_Meta_.CommandProperty = property(get_CommandProperty, None)
    _SwipeItem_Meta_.ForegroundProperty = property(get_ForegroundProperty, None)
    _SwipeItem_Meta_.IconSourceProperty = property(get_IconSourceProperty, None)
    _SwipeItem_Meta_.TextProperty = property(get_TextProperty, None)
    Invoked = event()
class SwipeItemInvokedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ISwipeItemInvokedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.SwipeItemInvokedEventArgs'
    @winrt_mixinmethod
    def get_SwipeControl(self: win32more.Windows.UI.Xaml.Controls.ISwipeItemInvokedEventArgs) -> win32more.Windows.UI.Xaml.Controls.SwipeControl: ...
    SwipeControl = property(get_SwipeControl, None)
class _SwipeItems_Meta_(ComPtr.__class__):
    pass
class SwipeItems(ComPtr, metaclass=_SwipeItems_Meta_):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    implements: Tuple[SequenceProtocol[win32more.Windows.UI.Xaml.Controls.SwipeItem]]
    default_interface: win32more.Windows.UI.Xaml.Controls.ISwipeItems
    _classid_ = 'Windows.UI.Xaml.Controls.SwipeItems'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SwipeItems.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ISwipeItemsFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SwipeItems: ...
    @winrt_mixinmethod
    def get_Mode(self: win32more.Windows.UI.Xaml.Controls.ISwipeItems) -> win32more.Windows.UI.Xaml.Controls.SwipeMode: ...
    @winrt_mixinmethod
    def put_Mode(self: win32more.Windows.UI.Xaml.Controls.ISwipeItems, value: win32more.Windows.UI.Xaml.Controls.SwipeMode) -> Void: ...
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.SwipeItem], index: UInt32) -> win32more.Windows.UI.Xaml.Controls.SwipeItem: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.SwipeItem]) -> UInt32: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.SwipeItem]) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.UI.Xaml.Controls.SwipeItem]: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.SwipeItem], value: win32more.Windows.UI.Xaml.Controls.SwipeItem, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def SetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.SwipeItem], index: UInt32, value: win32more.Windows.UI.Xaml.Controls.SwipeItem) -> Void: ...
    @winrt_mixinmethod
    def InsertAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.SwipeItem], index: UInt32, value: win32more.Windows.UI.Xaml.Controls.SwipeItem) -> Void: ...
    @winrt_mixinmethod
    def RemoveAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.SwipeItem], index: UInt32) -> Void: ...
    @winrt_mixinmethod
    def Append(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.SwipeItem], value: win32more.Windows.UI.Xaml.Controls.SwipeItem) -> Void: ...
    @winrt_mixinmethod
    def RemoveAtEnd(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.SwipeItem]) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.SwipeItem]) -> Void: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.SwipeItem], startIndex: UInt32, items: FillArray[win32more.Windows.UI.Xaml.Controls.SwipeItem]) -> UInt32: ...
    @winrt_mixinmethod
    def ReplaceAll(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.SwipeItem], items: PassArray[win32more.Windows.UI.Xaml.Controls.SwipeItem]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.UI.Xaml.Controls.SwipeItem]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.UI.Xaml.Controls.SwipeItem]: ...
    @winrt_classmethod
    def get_ModeProperty(cls: win32more.Windows.UI.Xaml.Controls.ISwipeItemsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Mode = property(get_Mode, put_Mode)
    Size = property(get_Size, None)
    _SwipeItems_Meta_.ModeProperty = property(get_ModeProperty, None)
class SwipeMode(Enum, Int32):
    Reveal = 0
    Execute = 1
class Symbol(Enum, Int32):
    Previous = 57600
    Next = 57601
    Play = 57602
    Pause = 57603
    Edit = 57604
    Save = 57605
    Clear = 57606
    Delete = 57607
    Remove = 57608
    Add = 57609
    Cancel = 57610
    Accept = 57611
    More = 57612
    Redo = 57613
    Undo = 57614
    Home = 57615
    Up = 57616
    Forward = 57617
    Back = 57618
    Favorite = 57619
    Camera = 57620
    Setting = 57621
    Video = 57622
    Sync = 57623
    Download = 57624
    Mail = 57625
    Find = 57626
    Help = 57627
    Upload = 57628
    Emoji = 57629
    TwoPage = 57630
    LeaveChat = 57631
    MailForward = 57632
    Clock = 57633
    Send = 57634
    Crop = 57635
    RotateCamera = 57636
    People = 57637
    OpenPane = 57638
    ClosePane = 57639
    World = 57640
    Flag = 57641
    PreviewLink = 57642
    Globe = 57643
    Trim = 57644
    AttachCamera = 57645
    ZoomIn = 57646
    Bookmarks = 57647
    Document = 57648
    ProtectedDocument = 57649
    Page = 57650
    Bullets = 57651
    Comment = 57652
    MailFilled = 57653
    ContactInfo = 57654
    HangUp = 57655
    ViewAll = 57656
    MapPin = 57657
    Phone = 57658
    VideoChat = 57659
    Switch = 57660
    Contact = 57661
    Rename = 57662
    Pin = 57665
    MusicInfo = 57666
    Go = 57667
    Keyboard = 57668
    DockLeft = 57669
    DockRight = 57670
    DockBottom = 57671
    Remote = 57672
    Refresh = 57673
    Rotate = 57674
    Shuffle = 57675
    List = 57676
    Shop = 57677
    SelectAll = 57678
    Orientation = 57679
    Import = 57680
    ImportAll = 57681
    BrowsePhotos = 57685
    WebCam = 57686
    Pictures = 57688
    SaveLocal = 57689
    Caption = 57690
    Stop = 57691
    ShowResults = 57692
    Volume = 57693
    Repair = 57694
    Message = 57695
    Page2 = 57696
    CalendarDay = 57697
    CalendarWeek = 57698
    Calendar = 57699
    Character = 57700
    MailReplyAll = 57701
    Read = 57702
    Link = 57703
    Account = 57704
    ShowBcc = 57705
    HideBcc = 57706
    Cut = 57707
    Attach = 57708
    Paste = 57709
    Filter = 57710
    Copy = 57711
    Emoji2 = 57712
    Important = 57713
    MailReply = 57714
    SlideShow = 57715
    Sort = 57716
    Manage = 57720
    AllApps = 57721
    DisconnectDrive = 57722
    MapDrive = 57723
    NewWindow = 57724
    OpenWith = 57725
    ContactPresence = 57729
    Priority = 57730
    GoToToday = 57732
    Font = 57733
    FontColor = 57734
    Contact2 = 57735
    Folder = 57736
    Audio = 57737
    Placeholder = 57738
    View = 57739
    SetLockScreen = 57740
    SetTile = 57741
    ClosedCaption = 57744
    StopSlideShow = 57745
    Permissions = 57746
    Highlight = 57747
    DisableUpdates = 57748
    UnFavorite = 57749
    UnPin = 57750
    OpenLocal = 57751
    Mute = 57752
    Italic = 57753
    Underline = 57754
    Bold = 57755
    MoveToFolder = 57756
    LikeDislike = 57757
    Dislike = 57758
    Like = 57759
    AlignRight = 57760
    AlignCenter = 57761
    AlignLeft = 57762
    Zoom = 57763
    ZoomOut = 57764
    OpenFile = 57765
    OtherUser = 57766
    Admin = 57767
    Street = 57795
    Map = 57796
    ClearSelection = 57797
    FontDecrease = 57798
    FontIncrease = 57799
    FontSize = 57800
    CellPhone = 57801
    ReShare = 57802
    Tag = 57803
    RepeatOne = 57804
    RepeatAll = 57805
    OutlineStar = 57806
    SolidStar = 57807
    Calculator = 57808
    Directions = 57809
    Target = 57810
    Library = 57811
    PhoneBook = 57812
    Memo = 57813
    Microphone = 57814
    PostUpdate = 57815
    BackToWindow = 57816
    FullScreen = 57817
    NewFolder = 57818
    CalendarReply = 57819
    UnSyncFolder = 57821
    ReportHacked = 57822
    SyncFolder = 57823
    BlockContact = 57824
    SwitchApps = 57825
    AddFriend = 57826
    TouchPointer = 57827
    GoToStart = 57828
    ZeroBars = 57829
    OneBar = 57830
    TwoBars = 57831
    ThreeBars = 57832
    FourBars = 57833
    Scan = 58004
    Preview = 58005
    GlobalNavigationButton = 59136
    Share = 59181
    Print = 59209
    XboxOneConsole = 59792
class _SymbolIcon_Meta_(ComPtr.__class__):
    pass
class SymbolIcon(ComPtr, metaclass=_SymbolIcon_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.IconElement
    default_interface: win32more.Windows.UI.Xaml.Controls.ISymbolIcon
    _classid_ = 'Windows.UI.Xaml.Controls.SymbolIcon'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SymbolIcon.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SymbolIcon.CreateInstanceWithSymbol(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.SymbolIcon: ...
    @winrt_factorymethod
    def CreateInstanceWithSymbol(cls: win32more.Windows.UI.Xaml.Controls.ISymbolIconFactory, symbol: win32more.Windows.UI.Xaml.Controls.Symbol) -> win32more.Windows.UI.Xaml.Controls.SymbolIcon: ...
    @winrt_mixinmethod
    def get_Symbol(self: win32more.Windows.UI.Xaml.Controls.ISymbolIcon) -> win32more.Windows.UI.Xaml.Controls.Symbol: ...
    @winrt_mixinmethod
    def put_Symbol(self: win32more.Windows.UI.Xaml.Controls.ISymbolIcon, value: win32more.Windows.UI.Xaml.Controls.Symbol) -> Void: ...
    @winrt_classmethod
    def get_SymbolProperty(cls: win32more.Windows.UI.Xaml.Controls.ISymbolIconStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Symbol = property(get_Symbol, put_Symbol)
    _SymbolIcon_Meta_.SymbolProperty = property(get_SymbolProperty, None)
class _SymbolIconSource_Meta_(ComPtr.__class__):
    pass
class SymbolIconSource(ComPtr, metaclass=_SymbolIconSource_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.IconSource
    default_interface: win32more.Windows.UI.Xaml.Controls.ISymbolIconSource
    _classid_ = 'Windows.UI.Xaml.Controls.SymbolIconSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.SymbolIconSource.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ISymbolIconSourceFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.SymbolIconSource: ...
    @winrt_mixinmethod
    def get_Symbol(self: win32more.Windows.UI.Xaml.Controls.ISymbolIconSource) -> win32more.Windows.UI.Xaml.Controls.Symbol: ...
    @winrt_mixinmethod
    def put_Symbol(self: win32more.Windows.UI.Xaml.Controls.ISymbolIconSource, value: win32more.Windows.UI.Xaml.Controls.Symbol) -> Void: ...
    @winrt_classmethod
    def get_SymbolProperty(cls: win32more.Windows.UI.Xaml.Controls.ISymbolIconSourceStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Symbol = property(get_Symbol, put_Symbol)
    _SymbolIconSource_Meta_.SymbolProperty = property(get_SymbolProperty, None)
class _TextBlock_Meta_(ComPtr.__class__):
    pass
class TextBlock(ComPtr, metaclass=_TextBlock_Meta_):
    extends: win32more.Windows.UI.Xaml.FrameworkElement
    default_interface: win32more.Windows.UI.Xaml.Controls.ITextBlock
    _classid_ = 'Windows.UI.Xaml.Controls.TextBlock'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.TextBlock.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.TextBlock: ...
    @winrt_mixinmethod
    def get_FontSize(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> Double: ...
    @winrt_mixinmethod
    def put_FontSize(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FontFamily(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_FontFamily(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, value: win32more.Windows.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_FontWeight(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_FontWeight(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_FontStyle(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_FontStyle(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_FontStretch(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_mixinmethod
    def put_FontStretch(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_mixinmethod
    def get_CharacterSpacing(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> Int32: ...
    @winrt_mixinmethod
    def put_CharacterSpacing(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_Foreground(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Foreground(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TextWrapping(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Xaml.TextWrapping: ...
    @winrt_mixinmethod
    def put_TextWrapping(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, value: win32more.Windows.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_mixinmethod
    def get_TextTrimming(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Xaml.TextTrimming: ...
    @winrt_mixinmethod
    def put_TextTrimming(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, value: win32more.Windows.UI.Xaml.TextTrimming) -> Void: ...
    @winrt_mixinmethod
    def get_TextAlignment(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_TextAlignment(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, value: win32more.Windows.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Inlines(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Xaml.Documents.InlineCollection: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, value: win32more.Windows.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_LineHeight(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> Double: ...
    @winrt_mixinmethod
    def put_LineHeight(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_LineStackingStrategy(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Xaml.LineStackingStrategy: ...
    @winrt_mixinmethod
    def put_LineStackingStrategy(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, value: win32more.Windows.UI.Xaml.LineStackingStrategy) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextSelectionEnabled(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextSelectionEnabled(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedText(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ContentStart(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_ContentEnd(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_SelectionStart(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_SelectionEnd(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_BaselineOffset(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> Double: ...
    @winrt_mixinmethod
    def add_SelectionChanged(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanged(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ContextMenuOpening(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, handler: win32more.Windows.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContextMenuOpening(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def SelectAll(self: win32more.Windows.UI.Xaml.Controls.ITextBlock) -> Void: ...
    @winrt_mixinmethod
    def Select(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, start: win32more.Windows.UI.Xaml.Documents.TextPointer, end: win32more.Windows.UI.Xaml.Documents.TextPointer) -> Void: ...
    @winrt_mixinmethod
    def Focus(self: win32more.Windows.UI.Xaml.Controls.ITextBlock, value: win32more.Windows.UI.Xaml.FocusState) -> Boolean: ...
    @winrt_mixinmethod
    def get_SelectionHighlightColor(self: win32more.Windows.UI.Xaml.Controls.ITextBlock2) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_mixinmethod
    def put_SelectionHighlightColor(self: win32more.Windows.UI.Xaml.Controls.ITextBlock2, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_mixinmethod
    def get_MaxLines(self: win32more.Windows.UI.Xaml.Controls.ITextBlock2) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxLines(self: win32more.Windows.UI.Xaml.Controls.ITextBlock2, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_TextLineBounds(self: win32more.Windows.UI.Xaml.Controls.ITextBlock2) -> win32more.Windows.UI.Xaml.TextLineBounds: ...
    @winrt_mixinmethod
    def put_TextLineBounds(self: win32more.Windows.UI.Xaml.Controls.ITextBlock2, value: win32more.Windows.UI.Xaml.TextLineBounds) -> Void: ...
    @winrt_mixinmethod
    def get_OpticalMarginAlignment(self: win32more.Windows.UI.Xaml.Controls.ITextBlock2) -> win32more.Windows.UI.Xaml.OpticalMarginAlignment: ...
    @winrt_mixinmethod
    def put_OpticalMarginAlignment(self: win32more.Windows.UI.Xaml.Controls.ITextBlock2, value: win32more.Windows.UI.Xaml.OpticalMarginAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_IsColorFontEnabled(self: win32more.Windows.UI.Xaml.Controls.ITextBlock2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsColorFontEnabled(self: win32more.Windows.UI.Xaml.Controls.ITextBlock2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TextReadingOrder(self: win32more.Windows.UI.Xaml.Controls.ITextBlock2) -> win32more.Windows.UI.Xaml.TextReadingOrder: ...
    @winrt_mixinmethod
    def put_TextReadingOrder(self: win32more.Windows.UI.Xaml.Controls.ITextBlock2, value: win32more.Windows.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextScaleFactorEnabled(self: win32more.Windows.UI.Xaml.Controls.ITextBlock3) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextScaleFactorEnabled(self: win32more.Windows.UI.Xaml.Controls.ITextBlock3, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def GetAlphaMask(self: win32more.Windows.UI.Xaml.Controls.ITextBlock4) -> win32more.Windows.UI.Composition.CompositionBrush: ...
    @winrt_mixinmethod
    def get_TextDecorations(self: win32more.Windows.UI.Xaml.Controls.ITextBlock5) -> win32more.Windows.UI.Text.TextDecorations: ...
    @winrt_mixinmethod
    def put_TextDecorations(self: win32more.Windows.UI.Xaml.Controls.ITextBlock5, value: win32more.Windows.UI.Text.TextDecorations) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextTrimmed(self: win32more.Windows.UI.Xaml.Controls.ITextBlock6) -> Boolean: ...
    @winrt_mixinmethod
    def get_HorizontalTextAlignment(self: win32more.Windows.UI.Xaml.Controls.ITextBlock6) -> win32more.Windows.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalTextAlignment(self: win32more.Windows.UI.Xaml.Controls.ITextBlock6, value: win32more.Windows.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_TextHighlighters(self: win32more.Windows.UI.Xaml.Controls.ITextBlock6) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Documents.TextHighlighter]: ...
    @winrt_mixinmethod
    def add_IsTextTrimmedChanged(self: win32more.Windows.UI.Xaml.Controls.ITextBlock6, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBlock, win32more.Windows.UI.Xaml.Controls.IsTextTrimmedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_IsTextTrimmedChanged(self: win32more.Windows.UI.Xaml.Controls.ITextBlock6, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionFlyout(self: win32more.Windows.UI.Xaml.Controls.ITextBlock7) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def put_SelectionFlyout(self: win32more.Windows.UI.Xaml.Controls.ITextBlock7, value: win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_mixinmethod
    def CopySelectionToClipboard(self: win32more.Windows.UI.Xaml.Controls.ITextBlock7) -> Void: ...
    @winrt_classmethod
    def get_SelectionFlyoutProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics7) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextTrimmedProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics6) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalTextAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics6) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextDecorationsProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextScaleFactorEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionHighlightColorProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxLinesProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextLineBoundsProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OpticalMarginAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsColorFontEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextReadingOrderProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontSizeProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontFamilyProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontWeightProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStretchProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CharacterSpacingProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextWrappingProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextTrimmingProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LineHeightProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LineStackingStrategyProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextSelectionEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedTextProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    BaselineOffset = property(get_BaselineOffset, None)
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    ContentEnd = property(get_ContentEnd, None)
    ContentStart = property(get_ContentStart, None)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    Inlines = property(get_Inlines, None)
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    IsTextSelectionEnabled = property(get_IsTextSelectionEnabled, put_IsTextSelectionEnabled)
    IsTextTrimmed = property(get_IsTextTrimmed, None)
    LineHeight = property(get_LineHeight, put_LineHeight)
    LineStackingStrategy = property(get_LineStackingStrategy, put_LineStackingStrategy)
    MaxLines = property(get_MaxLines, put_MaxLines)
    OpticalMarginAlignment = property(get_OpticalMarginAlignment, put_OpticalMarginAlignment)
    Padding = property(get_Padding, put_Padding)
    SelectedText = property(get_SelectedText, None)
    SelectionEnd = property(get_SelectionEnd, None)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    SelectionStart = property(get_SelectionStart, None)
    Text = property(get_Text, put_Text)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
    TextDecorations = property(get_TextDecorations, put_TextDecorations)
    TextHighlighters = property(get_TextHighlighters, None)
    TextLineBounds = property(get_TextLineBounds, put_TextLineBounds)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    TextTrimming = property(get_TextTrimming, put_TextTrimming)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    _TextBlock_Meta_.CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    _TextBlock_Meta_.FontFamilyProperty = property(get_FontFamilyProperty, None)
    _TextBlock_Meta_.FontSizeProperty = property(get_FontSizeProperty, None)
    _TextBlock_Meta_.FontStretchProperty = property(get_FontStretchProperty, None)
    _TextBlock_Meta_.FontStyleProperty = property(get_FontStyleProperty, None)
    _TextBlock_Meta_.FontWeightProperty = property(get_FontWeightProperty, None)
    _TextBlock_Meta_.ForegroundProperty = property(get_ForegroundProperty, None)
    _TextBlock_Meta_.HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
    _TextBlock_Meta_.IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    _TextBlock_Meta_.IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    _TextBlock_Meta_.IsTextSelectionEnabledProperty = property(get_IsTextSelectionEnabledProperty, None)
    _TextBlock_Meta_.IsTextTrimmedProperty = property(get_IsTextTrimmedProperty, None)
    _TextBlock_Meta_.LineHeightProperty = property(get_LineHeightProperty, None)
    _TextBlock_Meta_.LineStackingStrategyProperty = property(get_LineStackingStrategyProperty, None)
    _TextBlock_Meta_.MaxLinesProperty = property(get_MaxLinesProperty, None)
    _TextBlock_Meta_.OpticalMarginAlignmentProperty = property(get_OpticalMarginAlignmentProperty, None)
    _TextBlock_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    _TextBlock_Meta_.SelectedTextProperty = property(get_SelectedTextProperty, None)
    _TextBlock_Meta_.SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
    _TextBlock_Meta_.SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    _TextBlock_Meta_.TextAlignmentProperty = property(get_TextAlignmentProperty, None)
    _TextBlock_Meta_.TextDecorationsProperty = property(get_TextDecorationsProperty, None)
    _TextBlock_Meta_.TextLineBoundsProperty = property(get_TextLineBoundsProperty, None)
    _TextBlock_Meta_.TextProperty = property(get_TextProperty, None)
    _TextBlock_Meta_.TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
    _TextBlock_Meta_.TextTrimmingProperty = property(get_TextTrimmingProperty, None)
    _TextBlock_Meta_.TextWrappingProperty = property(get_TextWrappingProperty, None)
    SelectionChanged = event()
    ContextMenuOpening = event()
    IsTextTrimmedChanged = event()
class _TextBox_Meta_(ComPtr.__class__):
    pass
class TextBox(ComPtr, metaclass=_TextBox_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.ITextBox
    _classid_ = 'Windows.UI.Xaml.Controls.TextBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.TextBox.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TextBox: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.UI.Xaml.Controls.ITextBox) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Windows.UI.Xaml.Controls.ITextBox, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedText(self: win32more.Windows.UI.Xaml.Controls.ITextBox) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SelectedText(self: win32more.Windows.UI.Xaml.Controls.ITextBox, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionLength(self: win32more.Windows.UI.Xaml.Controls.ITextBox) -> Int32: ...
    @winrt_mixinmethod
    def put_SelectionLength(self: win32more.Windows.UI.Xaml.Controls.ITextBox, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionStart(self: win32more.Windows.UI.Xaml.Controls.ITextBox) -> Int32: ...
    @winrt_mixinmethod
    def put_SelectionStart(self: win32more.Windows.UI.Xaml.Controls.ITextBox, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_MaxLength(self: win32more.Windows.UI.Xaml.Controls.ITextBox) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxLength(self: win32more.Windows.UI.Xaml.Controls.ITextBox, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_IsReadOnly(self: win32more.Windows.UI.Xaml.Controls.ITextBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsReadOnly(self: win32more.Windows.UI.Xaml.Controls.ITextBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AcceptsReturn(self: win32more.Windows.UI.Xaml.Controls.ITextBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_AcceptsReturn(self: win32more.Windows.UI.Xaml.Controls.ITextBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TextAlignment(self: win32more.Windows.UI.Xaml.Controls.ITextBox) -> win32more.Windows.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_TextAlignment(self: win32more.Windows.UI.Xaml.Controls.ITextBox, value: win32more.Windows.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_TextWrapping(self: win32more.Windows.UI.Xaml.Controls.ITextBox) -> win32more.Windows.UI.Xaml.TextWrapping: ...
    @winrt_mixinmethod
    def put_TextWrapping(self: win32more.Windows.UI.Xaml.Controls.ITextBox, value: win32more.Windows.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_mixinmethod
    def get_IsSpellCheckEnabled(self: win32more.Windows.UI.Xaml.Controls.ITextBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSpellCheckEnabled(self: win32more.Windows.UI.Xaml.Controls.ITextBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextPredictionEnabled(self: win32more.Windows.UI.Xaml.Controls.ITextBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextPredictionEnabled(self: win32more.Windows.UI.Xaml.Controls.ITextBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_InputScope(self: win32more.Windows.UI.Xaml.Controls.ITextBox) -> win32more.Windows.UI.Xaml.Input.InputScope: ...
    @winrt_mixinmethod
    def put_InputScope(self: win32more.Windows.UI.Xaml.Controls.ITextBox, value: win32more.Windows.UI.Xaml.Input.InputScope) -> Void: ...
    @winrt_mixinmethod
    def add_TextChanged(self: win32more.Windows.UI.Xaml.Controls.ITextBox, handler: win32more.Windows.UI.Xaml.Controls.TextChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextChanged(self: win32more.Windows.UI.Xaml.Controls.ITextBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SelectionChanged(self: win32more.Windows.UI.Xaml.Controls.ITextBox, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanged(self: win32more.Windows.UI.Xaml.Controls.ITextBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ContextMenuOpening(self: win32more.Windows.UI.Xaml.Controls.ITextBox, handler: win32more.Windows.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContextMenuOpening(self: win32more.Windows.UI.Xaml.Controls.ITextBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Select(self: win32more.Windows.UI.Xaml.Controls.ITextBox, start: Int32, length: Int32) -> Void: ...
    @winrt_mixinmethod
    def SelectAll(self: win32more.Windows.UI.Xaml.Controls.ITextBox) -> Void: ...
    @winrt_mixinmethod
    def GetRectFromCharacterIndex(self: win32more.Windows.UI.Xaml.Controls.ITextBox, charIndex: Int32, trailingEdge: Boolean) -> win32more.Windows.Foundation.Rect: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Windows.UI.Xaml.Controls.ITextBox2) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Windows.UI.Xaml.Controls.ITextBox2, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.ITextBox2) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.ITextBox2, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderText(self: win32more.Windows.UI.Xaml.Controls.ITextBox2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PlaceholderText(self: win32more.Windows.UI.Xaml.Controls.ITextBox2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionHighlightColor(self: win32more.Windows.UI.Xaml.Controls.ITextBox2) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_mixinmethod
    def put_SelectionHighlightColor(self: win32more.Windows.UI.Xaml.Controls.ITextBox2, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_mixinmethod
    def get_PreventKeyboardDisplayOnProgrammaticFocus(self: win32more.Windows.UI.Xaml.Controls.ITextBox2) -> Boolean: ...
    @winrt_mixinmethod
    def put_PreventKeyboardDisplayOnProgrammaticFocus(self: win32more.Windows.UI.Xaml.Controls.ITextBox2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsColorFontEnabled(self: win32more.Windows.UI.Xaml.Controls.ITextBox2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsColorFontEnabled(self: win32more.Windows.UI.Xaml.Controls.ITextBox2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_Paste(self: win32more.Windows.UI.Xaml.Controls.ITextBox2, handler: win32more.Windows.UI.Xaml.Controls.TextControlPasteEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Paste(self: win32more.Windows.UI.Xaml.Controls.ITextBox2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextCompositionStarted(self: win32more.Windows.UI.Xaml.Controls.ITextBox3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.TextCompositionStartedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextCompositionStarted(self: win32more.Windows.UI.Xaml.Controls.ITextBox3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextCompositionChanged(self: win32more.Windows.UI.Xaml.Controls.ITextBox3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.TextCompositionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextCompositionChanged(self: win32more.Windows.UI.Xaml.Controls.ITextBox3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextCompositionEnded(self: win32more.Windows.UI.Xaml.Controls.ITextBox3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.TextCompositionEndedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextCompositionEnded(self: win32more.Windows.UI.Xaml.Controls.ITextBox3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_TextReadingOrder(self: win32more.Windows.UI.Xaml.Controls.ITextBox3) -> win32more.Windows.UI.Xaml.TextReadingOrder: ...
    @winrt_mixinmethod
    def put_TextReadingOrder(self: win32more.Windows.UI.Xaml.Controls.ITextBox3, value: win32more.Windows.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_mixinmethod
    def get_DesiredCandidateWindowAlignment(self: win32more.Windows.UI.Xaml.Controls.ITextBox3) -> win32more.Windows.UI.Xaml.Controls.CandidateWindowAlignment: ...
    @winrt_mixinmethod
    def put_DesiredCandidateWindowAlignment(self: win32more.Windows.UI.Xaml.Controls.ITextBox3, value: win32more.Windows.UI.Xaml.Controls.CandidateWindowAlignment) -> Void: ...
    @winrt_mixinmethod
    def add_CandidateWindowBoundsChanged(self: win32more.Windows.UI.Xaml.Controls.ITextBox3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.CandidateWindowBoundsChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CandidateWindowBoundsChanged(self: win32more.Windows.UI.Xaml.Controls.ITextBox3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextChanging(self: win32more.Windows.UI.Xaml.Controls.ITextBox3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.TextBoxTextChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextChanging(self: win32more.Windows.UI.Xaml.Controls.ITextBox3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetLinguisticAlternativesAsync(self: win32more.Windows.UI.Xaml.Controls.ITextBox4) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    @winrt_mixinmethod
    def get_SelectionHighlightColorWhenNotFocused(self: win32more.Windows.UI.Xaml.Controls.ITextBox5) -> win32more.Windows.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_mixinmethod
    def put_SelectionHighlightColorWhenNotFocused(self: win32more.Windows.UI.Xaml.Controls.ITextBox5, value: win32more.Windows.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalTextAlignment(self: win32more.Windows.UI.Xaml.Controls.ITextBox6) -> win32more.Windows.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalTextAlignment(self: win32more.Windows.UI.Xaml.Controls.ITextBox6, value: win32more.Windows.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_CharacterCasing(self: win32more.Windows.UI.Xaml.Controls.ITextBox6) -> win32more.Windows.UI.Xaml.Controls.CharacterCasing: ...
    @winrt_mixinmethod
    def put_CharacterCasing(self: win32more.Windows.UI.Xaml.Controls.ITextBox6, value: win32more.Windows.UI.Xaml.Controls.CharacterCasing) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderForeground(self: win32more.Windows.UI.Xaml.Controls.ITextBox6) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_PlaceholderForeground(self: win32more.Windows.UI.Xaml.Controls.ITextBox6, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def add_CopyingToClipboard(self: win32more.Windows.UI.Xaml.Controls.ITextBox6, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.TextControlCopyingToClipboardEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CopyingToClipboard(self: win32more.Windows.UI.Xaml.Controls.ITextBox6, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CuttingToClipboard(self: win32more.Windows.UI.Xaml.Controls.ITextBox6, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.TextControlCuttingToClipboardEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CuttingToClipboard(self: win32more.Windows.UI.Xaml.Controls.ITextBox6, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_BeforeTextChanging(self: win32more.Windows.UI.Xaml.Controls.ITextBox6, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.TextBoxBeforeTextChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_BeforeTextChanging(self: win32more.Windows.UI.Xaml.Controls.ITextBox6, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_HandwritingView(self: win32more.Windows.UI.Xaml.Controls.ITextBox7) -> win32more.Windows.UI.Xaml.Controls.HandwritingView: ...
    @winrt_mixinmethod
    def put_HandwritingView(self: win32more.Windows.UI.Xaml.Controls.ITextBox7, value: win32more.Windows.UI.Xaml.Controls.HandwritingView) -> Void: ...
    @winrt_mixinmethod
    def get_IsHandwritingViewEnabled(self: win32more.Windows.UI.Xaml.Controls.ITextBox7) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsHandwritingViewEnabled(self: win32more.Windows.UI.Xaml.Controls.ITextBox7, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CanPasteClipboardContent(self: win32more.Windows.UI.Xaml.Controls.ITextBox8) -> Boolean: ...
    @winrt_mixinmethod
    def get_CanUndo(self: win32more.Windows.UI.Xaml.Controls.ITextBox8) -> Boolean: ...
    @winrt_mixinmethod
    def get_CanRedo(self: win32more.Windows.UI.Xaml.Controls.ITextBox8) -> Boolean: ...
    @winrt_mixinmethod
    def get_SelectionFlyout(self: win32more.Windows.UI.Xaml.Controls.ITextBox8) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def put_SelectionFlyout(self: win32more.Windows.UI.Xaml.Controls.ITextBox8, value: win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_mixinmethod
    def get_ProofingMenuFlyout(self: win32more.Windows.UI.Xaml.Controls.ITextBox8) -> win32more.Windows.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.UI.Xaml.Controls.ITextBox8) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.UI.Xaml.Controls.ITextBox8, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def add_SelectionChanging(self: win32more.Windows.UI.Xaml.Controls.ITextBox8, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TextBox, win32more.Windows.UI.Xaml.Controls.TextBoxSelectionChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanging(self: win32more.Windows.UI.Xaml.Controls.ITextBox8, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Undo(self: win32more.Windows.UI.Xaml.Controls.ITextBox8) -> Void: ...
    @winrt_mixinmethod
    def Redo(self: win32more.Windows.UI.Xaml.Controls.ITextBox8) -> Void: ...
    @winrt_mixinmethod
    def PasteFromClipboard(self: win32more.Windows.UI.Xaml.Controls.ITextBox8) -> Void: ...
    @winrt_mixinmethod
    def CopySelectionToClipboard(self: win32more.Windows.UI.Xaml.Controls.ITextBox8) -> Void: ...
    @winrt_mixinmethod
    def CutSelectionToClipboard(self: win32more.Windows.UI.Xaml.Controls.ITextBox8) -> Void: ...
    @winrt_mixinmethod
    def ClearUndoRedoHistory(self: win32more.Windows.UI.Xaml.Controls.ITextBox8) -> Void: ...
    @winrt_classmethod
    def get_CanPasteClipboardContentProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics8) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanUndoProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics8) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanRedoProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics8) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionFlyoutProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics8) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ProofingMenuFlyoutProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics8) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DescriptionProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics8) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HandwritingViewProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics7) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsHandwritingViewEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics7) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalTextAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics6) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CharacterCasingProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics6) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderForegroundProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics6) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionHighlightColorWhenNotFocusedProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DesiredCandidateWindowAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextReadingOrderProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderTextProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionHighlightColorProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PreventKeyboardDisplayOnProgrammaticFocusProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsColorFontEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxLengthProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsReadOnlyProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AcceptsReturnProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextWrappingProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSpellCheckEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextPredictionEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_InputScopeProperty(cls: win32more.Windows.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AcceptsReturn = property(get_AcceptsReturn, put_AcceptsReturn)
    CanPasteClipboardContent = property(get_CanPasteClipboardContent, None)
    CanRedo = property(get_CanRedo, None)
    CanUndo = property(get_CanUndo, None)
    CharacterCasing = property(get_CharacterCasing, put_CharacterCasing)
    Description = property(get_Description, put_Description)
    DesiredCandidateWindowAlignment = property(get_DesiredCandidateWindowAlignment, put_DesiredCandidateWindowAlignment)
    HandwritingView = property(get_HandwritingView, put_HandwritingView)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    InputScope = property(get_InputScope, put_InputScope)
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    IsHandwritingViewEnabled = property(get_IsHandwritingViewEnabled, put_IsHandwritingViewEnabled)
    IsReadOnly = property(get_IsReadOnly, put_IsReadOnly)
    IsSpellCheckEnabled = property(get_IsSpellCheckEnabled, put_IsSpellCheckEnabled)
    IsTextPredictionEnabled = property(get_IsTextPredictionEnabled, put_IsTextPredictionEnabled)
    MaxLength = property(get_MaxLength, put_MaxLength)
    PlaceholderForeground = property(get_PlaceholderForeground, put_PlaceholderForeground)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    PreventKeyboardDisplayOnProgrammaticFocus = property(get_PreventKeyboardDisplayOnProgrammaticFocus, put_PreventKeyboardDisplayOnProgrammaticFocus)
    ProofingMenuFlyout = property(get_ProofingMenuFlyout, None)
    SelectedText = property(get_SelectedText, put_SelectedText)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    SelectionHighlightColorWhenNotFocused = property(get_SelectionHighlightColorWhenNotFocused, put_SelectionHighlightColorWhenNotFocused)
    SelectionLength = property(get_SelectionLength, put_SelectionLength)
    SelectionStart = property(get_SelectionStart, put_SelectionStart)
    Text = property(get_Text, put_Text)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    _TextBox_Meta_.AcceptsReturnProperty = property(get_AcceptsReturnProperty, None)
    _TextBox_Meta_.CanPasteClipboardContentProperty = property(get_CanPasteClipboardContentProperty, None)
    _TextBox_Meta_.CanRedoProperty = property(get_CanRedoProperty, None)
    _TextBox_Meta_.CanUndoProperty = property(get_CanUndoProperty, None)
    _TextBox_Meta_.CharacterCasingProperty = property(get_CharacterCasingProperty, None)
    _TextBox_Meta_.DescriptionProperty = property(get_DescriptionProperty, None)
    _TextBox_Meta_.DesiredCandidateWindowAlignmentProperty = property(get_DesiredCandidateWindowAlignmentProperty, None)
    _TextBox_Meta_.HandwritingViewProperty = property(get_HandwritingViewProperty, None)
    _TextBox_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _TextBox_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _TextBox_Meta_.HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
    _TextBox_Meta_.InputScopeProperty = property(get_InputScopeProperty, None)
    _TextBox_Meta_.IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    _TextBox_Meta_.IsHandwritingViewEnabledProperty = property(get_IsHandwritingViewEnabledProperty, None)
    _TextBox_Meta_.IsReadOnlyProperty = property(get_IsReadOnlyProperty, None)
    _TextBox_Meta_.IsSpellCheckEnabledProperty = property(get_IsSpellCheckEnabledProperty, None)
    _TextBox_Meta_.IsTextPredictionEnabledProperty = property(get_IsTextPredictionEnabledProperty, None)
    _TextBox_Meta_.MaxLengthProperty = property(get_MaxLengthProperty, None)
    _TextBox_Meta_.PlaceholderForegroundProperty = property(get_PlaceholderForegroundProperty, None)
    _TextBox_Meta_.PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    _TextBox_Meta_.PreventKeyboardDisplayOnProgrammaticFocusProperty = property(get_PreventKeyboardDisplayOnProgrammaticFocusProperty, None)
    _TextBox_Meta_.ProofingMenuFlyoutProperty = property(get_ProofingMenuFlyoutProperty, None)
    _TextBox_Meta_.SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
    _TextBox_Meta_.SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    _TextBox_Meta_.SelectionHighlightColorWhenNotFocusedProperty = property(get_SelectionHighlightColorWhenNotFocusedProperty, None)
    _TextBox_Meta_.TextAlignmentProperty = property(get_TextAlignmentProperty, None)
    _TextBox_Meta_.TextProperty = property(get_TextProperty, None)
    _TextBox_Meta_.TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
    _TextBox_Meta_.TextWrappingProperty = property(get_TextWrappingProperty, None)
    TextChanged = event()
    SelectionChanged = event()
    ContextMenuOpening = event()
    Paste = event()
    TextCompositionStarted = event()
    TextCompositionChanged = event()
    TextCompositionEnded = event()
    CandidateWindowBoundsChanged = event()
    TextChanging = event()
    CopyingToClipboard = event()
    CuttingToClipboard = event()
    BeforeTextChanging = event()
    SelectionChanging = event()
class TextBoxBeforeTextChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ITextBoxBeforeTextChangingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TextBoxBeforeTextChangingEventArgs'
    @winrt_mixinmethod
    def get_NewText(self: win32more.Windows.UI.Xaml.Controls.ITextBoxBeforeTextChangingEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Windows.UI.Xaml.Controls.ITextBoxBeforeTextChangingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Windows.UI.Xaml.Controls.ITextBoxBeforeTextChangingEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    NewText = property(get_NewText, None)
class TextBoxSelectionChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ITextBoxSelectionChangingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TextBoxSelectionChangingEventArgs'
    @winrt_mixinmethod
    def get_SelectionStart(self: win32more.Windows.UI.Xaml.Controls.ITextBoxSelectionChangingEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_SelectionLength(self: win32more.Windows.UI.Xaml.Controls.ITextBoxSelectionChangingEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Windows.UI.Xaml.Controls.ITextBoxSelectionChangingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Windows.UI.Xaml.Controls.ITextBoxSelectionChangingEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    SelectionLength = property(get_SelectionLength, None)
    SelectionStart = property(get_SelectionStart, None)
class TextBoxTextChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ITextBoxTextChangingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TextBoxTextChangingEventArgs'
    @winrt_mixinmethod
    def get_IsContentChanging(self: win32more.Windows.UI.Xaml.Controls.ITextBoxTextChangingEventArgs2) -> Boolean: ...
    IsContentChanging = property(get_IsContentChanging, None)
class TextChangedEventArgs(ComPtr):
    extends: win32more.Windows.UI.Xaml.RoutedEventArgs
    default_interface: win32more.Windows.UI.Xaml.Controls.ITextChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TextChangedEventArgs'
class TextChangedEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8eb35b97-ad87-40e8-818b-77db24759566}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Controls.TextChangedEventArgs) -> Void: ...
class TextCommandBarFlyout(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.CommandBarFlyout
    default_interface: win32more.Windows.UI.Xaml.Controls.ITextCommandBarFlyout
    _classid_ = 'Windows.UI.Xaml.Controls.TextCommandBarFlyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.TextCommandBarFlyout.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ITextCommandBarFlyoutFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TextCommandBarFlyout: ...
class TextCompositionChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ITextCompositionChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TextCompositionChangedEventArgs'
    @winrt_mixinmethod
    def get_StartIndex(self: win32more.Windows.UI.Xaml.Controls.ITextCompositionChangedEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Length(self: win32more.Windows.UI.Xaml.Controls.ITextCompositionChangedEventArgs) -> Int32: ...
    Length = property(get_Length, None)
    StartIndex = property(get_StartIndex, None)
class TextCompositionEndedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ITextCompositionEndedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TextCompositionEndedEventArgs'
    @winrt_mixinmethod
    def get_StartIndex(self: win32more.Windows.UI.Xaml.Controls.ITextCompositionEndedEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Length(self: win32more.Windows.UI.Xaml.Controls.ITextCompositionEndedEventArgs) -> Int32: ...
    Length = property(get_Length, None)
    StartIndex = property(get_StartIndex, None)
class TextCompositionStartedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ITextCompositionStartedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TextCompositionStartedEventArgs'
    @winrt_mixinmethod
    def get_StartIndex(self: win32more.Windows.UI.Xaml.Controls.ITextCompositionStartedEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Length(self: win32more.Windows.UI.Xaml.Controls.ITextCompositionStartedEventArgs) -> Int32: ...
    Length = property(get_Length, None)
    StartIndex = property(get_StartIndex, None)
class TextControlCopyingToClipboardEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ITextControlCopyingToClipboardEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TextControlCopyingToClipboardEventArgs'
    @winrt_mixinmethod
    def get_Handled(self: win32more.Windows.UI.Xaml.Controls.ITextControlCopyingToClipboardEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Windows.UI.Xaml.Controls.ITextControlCopyingToClipboardEventArgs, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class TextControlCuttingToClipboardEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ITextControlCuttingToClipboardEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TextControlCuttingToClipboardEventArgs'
    @winrt_mixinmethod
    def get_Handled(self: win32more.Windows.UI.Xaml.Controls.ITextControlCuttingToClipboardEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Windows.UI.Xaml.Controls.ITextControlCuttingToClipboardEventArgs, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class TextControlPasteEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ITextControlPasteEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TextControlPasteEventArgs'
    @winrt_mixinmethod
    def get_Handled(self: win32more.Windows.UI.Xaml.Controls.ITextControlPasteEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Windows.UI.Xaml.Controls.ITextControlPasteEventArgs, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class TextControlPasteEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d56db359-6f77-4296-ab9c-794939444365}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Controls.TextControlPasteEventArgs) -> Void: ...
class TimePickedEventArgs(ComPtr):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Controls.ITimePickedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TimePickedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.TimePickedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.TimePickedEventArgs: ...
    @winrt_mixinmethod
    def get_OldTime(self: win32more.Windows.UI.Xaml.Controls.ITimePickedEventArgs) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_NewTime(self: win32more.Windows.UI.Xaml.Controls.ITimePickedEventArgs) -> win32more.Windows.Foundation.TimeSpan: ...
    NewTime = property(get_NewTime, None)
    OldTime = property(get_OldTime, None)
class _TimePicker_Meta_(ComPtr.__class__):
    pass
class TimePicker(ComPtr, metaclass=_TimePicker_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.ITimePicker
    _classid_ = 'Windows.UI.Xaml.Controls.TimePicker'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.TimePicker.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ITimePickerFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TimePicker: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Windows.UI.Xaml.Controls.ITimePicker) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Windows.UI.Xaml.Controls.ITimePicker, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.ITimePicker) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.ITimePicker, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_ClockIdentifier(self: win32more.Windows.UI.Xaml.Controls.ITimePicker) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ClockIdentifier(self: win32more.Windows.UI.Xaml.Controls.ITimePicker, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_MinuteIncrement(self: win32more.Windows.UI.Xaml.Controls.ITimePicker) -> Int32: ...
    @winrt_mixinmethod
    def put_MinuteIncrement(self: win32more.Windows.UI.Xaml.Controls.ITimePicker, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_Time(self: win32more.Windows.UI.Xaml.Controls.ITimePicker) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_Time(self: win32more.Windows.UI.Xaml.Controls.ITimePicker, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def add_TimeChanged(self: win32more.Windows.UI.Xaml.Controls.ITimePicker, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.UI.Xaml.Controls.TimePickerValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TimeChanged(self: win32more.Windows.UI.Xaml.Controls.ITimePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_LightDismissOverlayMode(self: win32more.Windows.UI.Xaml.Controls.ITimePicker2) -> win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_mixinmethod
    def put_LightDismissOverlayMode(self: win32more.Windows.UI.Xaml.Controls.ITimePicker2, value: win32more.Windows.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedTime(self: win32more.Windows.UI.Xaml.Controls.ITimePicker3) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    @winrt_mixinmethod
    def put_SelectedTime(self: win32more.Windows.UI.Xaml.Controls.ITimePicker3, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]) -> Void: ...
    @winrt_mixinmethod
    def add_SelectedTimeChanged(self: win32more.Windows.UI.Xaml.Controls.ITimePicker3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TimePicker, win32more.Windows.UI.Xaml.Controls.TimePickerSelectedValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectedTimeChanged(self: win32more.Windows.UI.Xaml.Controls.ITimePicker3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_SelectedTimeProperty(cls: win32more.Windows.UI.Xaml.Controls.ITimePickerStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LightDismissOverlayModeProperty(cls: win32more.Windows.UI.Xaml.Controls.ITimePickerStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.ITimePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.ITimePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ClockIdentifierProperty(cls: win32more.Windows.UI.Xaml.Controls.ITimePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinuteIncrementProperty(cls: win32more.Windows.UI.Xaml.Controls.ITimePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TimeProperty(cls: win32more.Windows.UI.Xaml.Controls.ITimePickerStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ClockIdentifier = property(get_ClockIdentifier, put_ClockIdentifier)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    MinuteIncrement = property(get_MinuteIncrement, put_MinuteIncrement)
    SelectedTime = property(get_SelectedTime, put_SelectedTime)
    Time = property(get_Time, put_Time)
    _TimePicker_Meta_.ClockIdentifierProperty = property(get_ClockIdentifierProperty, None)
    _TimePicker_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _TimePicker_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _TimePicker_Meta_.LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    _TimePicker_Meta_.MinuteIncrementProperty = property(get_MinuteIncrementProperty, None)
    _TimePicker_Meta_.SelectedTimeProperty = property(get_SelectedTimeProperty, None)
    _TimePicker_Meta_.TimeProperty = property(get_TimeProperty, None)
    TimeChanged = event()
    SelectedTimeChanged = event()
class _TimePickerFlyout_Meta_(ComPtr.__class__):
    pass
class TimePickerFlyout(ComPtr, metaclass=_TimePickerFlyout_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.PickerFlyoutBase
    default_interface: win32more.Windows.UI.Xaml.Controls.ITimePickerFlyout
    _classid_ = 'Windows.UI.Xaml.Controls.TimePickerFlyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.TimePickerFlyout.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.TimePickerFlyout: ...
    @winrt_mixinmethod
    def get_ClockIdentifier(self: win32more.Windows.UI.Xaml.Controls.ITimePickerFlyout) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ClockIdentifier(self: win32more.Windows.UI.Xaml.Controls.ITimePickerFlyout, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Time(self: win32more.Windows.UI.Xaml.Controls.ITimePickerFlyout) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_Time(self: win32more.Windows.UI.Xaml.Controls.ITimePickerFlyout, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_MinuteIncrement(self: win32more.Windows.UI.Xaml.Controls.ITimePickerFlyout) -> Int32: ...
    @winrt_mixinmethod
    def put_MinuteIncrement(self: win32more.Windows.UI.Xaml.Controls.ITimePickerFlyout, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def add_TimePicked(self: win32more.Windows.UI.Xaml.Controls.ITimePickerFlyout, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TimePickerFlyout, win32more.Windows.UI.Xaml.Controls.TimePickedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TimePicked(self: win32more.Windows.UI.Xaml.Controls.ITimePickerFlyout, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ShowAtAsync(self: win32more.Windows.UI.Xaml.Controls.ITimePickerFlyout, target: win32more.Windows.UI.Xaml.FrameworkElement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]]: ...
    @winrt_classmethod
    def get_ClockIdentifierProperty(cls: win32more.Windows.UI.Xaml.Controls.ITimePickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TimeProperty(cls: win32more.Windows.UI.Xaml.Controls.ITimePickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinuteIncrementProperty(cls: win32more.Windows.UI.Xaml.Controls.ITimePickerFlyoutStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    ClockIdentifier = property(get_ClockIdentifier, put_ClockIdentifier)
    MinuteIncrement = property(get_MinuteIncrement, put_MinuteIncrement)
    Time = property(get_Time, put_Time)
    _TimePickerFlyout_Meta_.ClockIdentifierProperty = property(get_ClockIdentifierProperty, None)
    _TimePickerFlyout_Meta_.MinuteIncrementProperty = property(get_MinuteIncrementProperty, None)
    _TimePickerFlyout_Meta_.TimeProperty = property(get_TimeProperty, None)
    TimePicked = event()
class _TimePickerFlyoutPresenter_Meta_(ComPtr.__class__):
    pass
class TimePickerFlyoutPresenter(ComPtr, metaclass=_TimePickerFlyoutPresenter_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.ITimePickerFlyoutPresenter
    _classid_ = 'Windows.UI.Xaml.Controls.TimePickerFlyoutPresenter'
    @winrt_mixinmethod
    def get_IsDefaultShadowEnabled(self: win32more.Windows.UI.Xaml.Controls.ITimePickerFlyoutPresenter2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDefaultShadowEnabled(self: win32more.Windows.UI.Xaml.Controls.ITimePickerFlyoutPresenter2, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsDefaultShadowEnabledProperty(cls: win32more.Windows.UI.Xaml.Controls.ITimePickerFlyoutPresenterStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsDefaultShadowEnabled = property(get_IsDefaultShadowEnabled, put_IsDefaultShadowEnabled)
    _TimePickerFlyoutPresenter_Meta_.IsDefaultShadowEnabledProperty = property(get_IsDefaultShadowEnabledProperty, None)
class TimePickerSelectedValueChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ITimePickerSelectedValueChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TimePickerSelectedValueChangedEventArgs'
    @winrt_mixinmethod
    def get_OldTime(self: win32more.Windows.UI.Xaml.Controls.ITimePickerSelectedValueChangedEventArgs) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    @winrt_mixinmethod
    def get_NewTime(self: win32more.Windows.UI.Xaml.Controls.ITimePickerSelectedValueChangedEventArgs) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    NewTime = property(get_NewTime, None)
    OldTime = property(get_OldTime, None)
class TimePickerValueChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ITimePickerValueChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TimePickerValueChangedEventArgs'
    @winrt_mixinmethod
    def get_OldTime(self: win32more.Windows.UI.Xaml.Controls.ITimePickerValueChangedEventArgs) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_NewTime(self: win32more.Windows.UI.Xaml.Controls.ITimePickerValueChangedEventArgs) -> win32more.Windows.Foundation.TimeSpan: ...
    NewTime = property(get_NewTime, None)
    OldTime = property(get_OldTime, None)
class _ToggleMenuFlyoutItem_Meta_(ComPtr.__class__):
    pass
class ToggleMenuFlyoutItem(ComPtr, metaclass=_ToggleMenuFlyoutItem_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.MenuFlyoutItem
    default_interface: win32more.Windows.UI.Xaml.Controls.IToggleMenuFlyoutItem
    _classid_ = 'Windows.UI.Xaml.Controls.ToggleMenuFlyoutItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ToggleMenuFlyoutItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IToggleMenuFlyoutItemFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ToggleMenuFlyoutItem: ...
    @winrt_mixinmethod
    def get_IsChecked(self: win32more.Windows.UI.Xaml.Controls.IToggleMenuFlyoutItem) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsChecked(self: win32more.Windows.UI.Xaml.Controls.IToggleMenuFlyoutItem, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsCheckedProperty(cls: win32more.Windows.UI.Xaml.Controls.IToggleMenuFlyoutItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    IsChecked = property(get_IsChecked, put_IsChecked)
    _ToggleMenuFlyoutItem_Meta_.IsCheckedProperty = property(get_IsCheckedProperty, None)
class ToggleSplitButton(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.SplitButton
    default_interface: win32more.Windows.UI.Xaml.Controls.IToggleSplitButton
    _classid_ = 'Windows.UI.Xaml.Controls.ToggleSplitButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ToggleSplitButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IToggleSplitButtonFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ToggleSplitButton: ...
    @winrt_mixinmethod
    def get_IsChecked(self: win32more.Windows.UI.Xaml.Controls.IToggleSplitButton) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsChecked(self: win32more.Windows.UI.Xaml.Controls.IToggleSplitButton, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_IsCheckedChanged(self: win32more.Windows.UI.Xaml.Controls.IToggleSplitButton, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.ToggleSplitButton, win32more.Windows.UI.Xaml.Controls.ToggleSplitButtonIsCheckedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_IsCheckedChanged(self: win32more.Windows.UI.Xaml.Controls.IToggleSplitButton, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    IsChecked = property(get_IsChecked, put_IsChecked)
    IsCheckedChanged = event()
class ToggleSplitButtonAutomationPeer(ComPtr):
    extends: win32more.Windows.UI.Xaml.Automation.Peers.FrameworkElementAutomationPeer
    default_interface: win32more.Windows.UI.Xaml.Controls.IToggleSplitButtonAutomationPeer
    _classid_ = 'Windows.UI.Xaml.Controls.ToggleSplitButtonAutomationPeer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ToggleSplitButtonAutomationPeer.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IToggleSplitButtonAutomationPeerFactory, owner: win32more.Windows.UI.Xaml.Controls.ToggleSplitButton, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ToggleSplitButtonAutomationPeer: ...
    @winrt_mixinmethod
    def get_ExpandCollapseState(self: win32more.Windows.UI.Xaml.Automation.Provider.IExpandCollapseProvider) -> win32more.Windows.UI.Xaml.Automation.ExpandCollapseState: ...
    @winrt_mixinmethod
    def Collapse(self: win32more.Windows.UI.Xaml.Automation.Provider.IExpandCollapseProvider) -> Void: ...
    @winrt_mixinmethod
    def Expand(self: win32more.Windows.UI.Xaml.Automation.Provider.IExpandCollapseProvider) -> Void: ...
    @winrt_mixinmethod
    def get_ToggleState(self: win32more.Windows.UI.Xaml.Automation.Provider.IToggleProvider) -> win32more.Windows.UI.Xaml.Automation.ToggleState: ...
    @winrt_mixinmethod
    def Toggle(self: win32more.Windows.UI.Xaml.Automation.Provider.IToggleProvider) -> Void: ...
    ExpandCollapseState = property(get_ExpandCollapseState, None)
    ToggleState = property(get_ToggleState, None)
class ToggleSplitButtonIsCheckedChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IToggleSplitButtonIsCheckedChangedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.ToggleSplitButtonIsCheckedChangedEventArgs'
class _ToggleSwitch_Meta_(ComPtr.__class__):
    pass
class ToggleSwitch(ComPtr, metaclass=_ToggleSwitch_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IToggleSwitch
    _classid_ = 'Windows.UI.Xaml.Controls.ToggleSwitch'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ToggleSwitch.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.ToggleSwitch: ...
    @winrt_mixinmethod
    def get_IsOn(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitch) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsOn(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitch, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitch) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitch, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitch) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitch, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_OnContent(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitch) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_OnContent(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitch, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_OnContentTemplate(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitch) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_OnContentTemplate(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitch, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_OffContent(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitch) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_OffContent(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitch, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_OffContentTemplate(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitch) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_OffContentTemplate(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitch, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitch) -> win32more.Windows.UI.Xaml.Controls.Primitives.ToggleSwitchTemplateSettings: ...
    @winrt_mixinmethod
    def add_Toggled(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitch, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Toggled(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitch, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def OnToggled(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitchOverrides) -> Void: ...
    @winrt_mixinmethod
    def OnOnContentChanged(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitchOverrides, oldContent: win32more.Windows.Win32.System.WinRT.IInspectable, newContent: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnOffContentChanged(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitchOverrides, oldContent: win32more.Windows.Win32.System.WinRT.IInspectable, newContent: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnHeaderChanged(self: win32more.Windows.UI.Xaml.Controls.IToggleSwitchOverrides, oldContent: win32more.Windows.Win32.System.WinRT.IInspectable, newContent: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_IsOnProperty(cls: win32more.Windows.UI.Xaml.Controls.IToggleSwitchStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Windows.UI.Xaml.Controls.IToggleSwitchStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IToggleSwitchStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OnContentProperty(cls: win32more.Windows.UI.Xaml.Controls.IToggleSwitchStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OnContentTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IToggleSwitchStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OffContentProperty(cls: win32more.Windows.UI.Xaml.Controls.IToggleSwitchStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OffContentTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.IToggleSwitchStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsOn = property(get_IsOn, put_IsOn)
    OffContent = property(get_OffContent, put_OffContent)
    OffContentTemplate = property(get_OffContentTemplate, put_OffContentTemplate)
    OnContent = property(get_OnContent, put_OnContent)
    OnContentTemplate = property(get_OnContentTemplate, put_OnContentTemplate)
    TemplateSettings = property(get_TemplateSettings, None)
    _ToggleSwitch_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _ToggleSwitch_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _ToggleSwitch_Meta_.IsOnProperty = property(get_IsOnProperty, None)
    _ToggleSwitch_Meta_.OffContentProperty = property(get_OffContentProperty, None)
    _ToggleSwitch_Meta_.OffContentTemplateProperty = property(get_OffContentTemplateProperty, None)
    _ToggleSwitch_Meta_.OnContentProperty = property(get_OnContentProperty, None)
    _ToggleSwitch_Meta_.OnContentTemplateProperty = property(get_OnContentTemplateProperty, None)
    Toggled = event()
class _ToolTip_Meta_(ComPtr.__class__):
    pass
class ToolTip(ComPtr, metaclass=_ToolTip_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Windows.UI.Xaml.Controls.IToolTip
    _classid_ = 'Windows.UI.Xaml.Controls.ToolTip'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.ToolTip.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IToolTipFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.ToolTip: ...
    @winrt_mixinmethod
    def get_HorizontalOffset(self: win32more.Windows.UI.Xaml.Controls.IToolTip) -> Double: ...
    @winrt_mixinmethod
    def put_HorizontalOffset(self: win32more.Windows.UI.Xaml.Controls.IToolTip, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_IsOpen(self: win32more.Windows.UI.Xaml.Controls.IToolTip) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsOpen(self: win32more.Windows.UI.Xaml.Controls.IToolTip, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Placement(self: win32more.Windows.UI.Xaml.Controls.IToolTip) -> win32more.Windows.UI.Xaml.Controls.Primitives.PlacementMode: ...
    @winrt_mixinmethod
    def put_Placement(self: win32more.Windows.UI.Xaml.Controls.IToolTip, value: win32more.Windows.UI.Xaml.Controls.Primitives.PlacementMode) -> Void: ...
    @winrt_mixinmethod
    def get_PlacementTarget(self: win32more.Windows.UI.Xaml.Controls.IToolTip) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_PlacementTarget(self: win32more.Windows.UI.Xaml.Controls.IToolTip, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalOffset(self: win32more.Windows.UI.Xaml.Controls.IToolTip) -> Double: ...
    @winrt_mixinmethod
    def put_VerticalOffset(self: win32more.Windows.UI.Xaml.Controls.IToolTip, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Windows.UI.Xaml.Controls.IToolTip) -> win32more.Windows.UI.Xaml.Controls.Primitives.ToolTipTemplateSettings: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Windows.UI.Xaml.Controls.IToolTip, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Windows.UI.Xaml.Controls.IToolTip, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Opened(self: win32more.Windows.UI.Xaml.Controls.IToolTip, handler: win32more.Windows.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Opened(self: win32more.Windows.UI.Xaml.Controls.IToolTip, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_PlacementRect(self: win32more.Windows.UI.Xaml.Controls.IToolTip2) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Rect]: ...
    @winrt_mixinmethod
    def put_PlacementRect(self: win32more.Windows.UI.Xaml.Controls.IToolTip2, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Rect]) -> Void: ...
    @winrt_classmethod
    def get_PlacementRectProperty(cls: win32more.Windows.UI.Xaml.Controls.IToolTipStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalOffsetProperty(cls: win32more.Windows.UI.Xaml.Controls.IToolTipStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsOpenProperty(cls: win32more.Windows.UI.Xaml.Controls.IToolTipStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlacementProperty(cls: win32more.Windows.UI.Xaml.Controls.IToolTipStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlacementTargetProperty(cls: win32more.Windows.UI.Xaml.Controls.IToolTipStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalOffsetProperty(cls: win32more.Windows.UI.Xaml.Controls.IToolTipStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HorizontalOffset = property(get_HorizontalOffset, put_HorizontalOffset)
    IsOpen = property(get_IsOpen, put_IsOpen)
    Placement = property(get_Placement, put_Placement)
    PlacementRect = property(get_PlacementRect, put_PlacementRect)
    PlacementTarget = property(get_PlacementTarget, put_PlacementTarget)
    TemplateSettings = property(get_TemplateSettings, None)
    VerticalOffset = property(get_VerticalOffset, put_VerticalOffset)
    _ToolTip_Meta_.HorizontalOffsetProperty = property(get_HorizontalOffsetProperty, None)
    _ToolTip_Meta_.IsOpenProperty = property(get_IsOpenProperty, None)
    _ToolTip_Meta_.PlacementProperty = property(get_PlacementProperty, None)
    _ToolTip_Meta_.PlacementRectProperty = property(get_PlacementRectProperty, None)
    _ToolTip_Meta_.PlacementTargetProperty = property(get_PlacementTargetProperty, None)
    _ToolTip_Meta_.VerticalOffsetProperty = property(get_VerticalOffsetProperty, None)
    Closed = event()
    Opened = event()
class _ToolTipService_Meta_(ComPtr.__class__):
    pass
class ToolTipService(ComPtr, metaclass=_ToolTipService_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IToolTipService
    _classid_ = 'Windows.UI.Xaml.Controls.ToolTipService'
    @winrt_classmethod
    def get_PlacementProperty(cls: win32more.Windows.UI.Xaml.Controls.IToolTipServiceStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetPlacement(cls: win32more.Windows.UI.Xaml.Controls.IToolTipServiceStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.Primitives.PlacementMode: ...
    @winrt_classmethod
    def SetPlacement(cls: win32more.Windows.UI.Xaml.Controls.IToolTipServiceStatics, element: win32more.Windows.UI.Xaml.DependencyObject, value: win32more.Windows.UI.Xaml.Controls.Primitives.PlacementMode) -> Void: ...
    @winrt_classmethod
    def get_PlacementTargetProperty(cls: win32more.Windows.UI.Xaml.Controls.IToolTipServiceStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetPlacementTarget(cls: win32more.Windows.UI.Xaml.Controls.IToolTipServiceStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_classmethod
    def SetPlacementTarget(cls: win32more.Windows.UI.Xaml.Controls.IToolTipServiceStatics, element: win32more.Windows.UI.Xaml.DependencyObject, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_classmethod
    def get_ToolTipProperty(cls: win32more.Windows.UI.Xaml.Controls.IToolTipServiceStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetToolTip(cls: win32more.Windows.UI.Xaml.Controls.IToolTipServiceStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_classmethod
    def SetToolTip(cls: win32more.Windows.UI.Xaml.Controls.IToolTipServiceStatics, element: win32more.Windows.UI.Xaml.DependencyObject, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    _ToolTipService_Meta_.PlacementProperty = property(get_PlacementProperty, None)
    _ToolTipService_Meta_.PlacementTargetProperty = property(get_PlacementTargetProperty, None)
    _ToolTipService_Meta_.ToolTipProperty = property(get_ToolTipProperty, None)
class _TreeView_Meta_(ComPtr.__class__):
    pass
class TreeView(ComPtr, metaclass=_TreeView_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.ITreeView
    _classid_ = 'Windows.UI.Xaml.Controls.TreeView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.TreeView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TreeView: ...
    @winrt_mixinmethod
    def get_RootNodes(self: win32more.Windows.UI.Xaml.Controls.ITreeView) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.TreeViewNode]: ...
    @winrt_mixinmethod
    def get_SelectionMode(self: win32more.Windows.UI.Xaml.Controls.ITreeView) -> win32more.Windows.UI.Xaml.Controls.TreeViewSelectionMode: ...
    @winrt_mixinmethod
    def put_SelectionMode(self: win32more.Windows.UI.Xaml.Controls.ITreeView, value: win32more.Windows.UI.Xaml.Controls.TreeViewSelectionMode) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedNodes(self: win32more.Windows.UI.Xaml.Controls.ITreeView) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.TreeViewNode]: ...
    @winrt_mixinmethod
    def Expand(self: win32more.Windows.UI.Xaml.Controls.ITreeView, value: win32more.Windows.UI.Xaml.Controls.TreeViewNode) -> Void: ...
    @winrt_mixinmethod
    def Collapse(self: win32more.Windows.UI.Xaml.Controls.ITreeView, value: win32more.Windows.UI.Xaml.Controls.TreeViewNode) -> Void: ...
    @winrt_mixinmethod
    def SelectAll(self: win32more.Windows.UI.Xaml.Controls.ITreeView) -> Void: ...
    @winrt_mixinmethod
    def add_ItemInvoked(self: win32more.Windows.UI.Xaml.Controls.ITreeView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TreeView, win32more.Windows.UI.Xaml.Controls.TreeViewItemInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ItemInvoked(self: win32more.Windows.UI.Xaml.Controls.ITreeView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Expanding(self: win32more.Windows.UI.Xaml.Controls.ITreeView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TreeView, win32more.Windows.UI.Xaml.Controls.TreeViewExpandingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Expanding(self: win32more.Windows.UI.Xaml.Controls.ITreeView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Collapsed(self: win32more.Windows.UI.Xaml.Controls.ITreeView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TreeView, win32more.Windows.UI.Xaml.Controls.TreeViewCollapsedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Collapsed(self: win32more.Windows.UI.Xaml.Controls.ITreeView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def NodeFromContainer(self: win32more.Windows.UI.Xaml.Controls.ITreeView2, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.TreeViewNode: ...
    @winrt_mixinmethod
    def ContainerFromNode(self: win32more.Windows.UI.Xaml.Controls.ITreeView2, node: win32more.Windows.UI.Xaml.Controls.TreeViewNode) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def ItemFromContainer(self: win32more.Windows.UI.Xaml.Controls.ITreeView2, container: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def ContainerFromItem(self: win32more.Windows.UI.Xaml.Controls.ITreeView2, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def get_CanDragItems(self: win32more.Windows.UI.Xaml.Controls.ITreeView2) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanDragItems(self: win32more.Windows.UI.Xaml.Controls.ITreeView2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CanReorderItems(self: win32more.Windows.UI.Xaml.Controls.ITreeView2) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanReorderItems(self: win32more.Windows.UI.Xaml.Controls.ITreeView2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ItemTemplate(self: win32more.Windows.UI.Xaml.Controls.ITreeView2) -> win32more.Windows.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_ItemTemplate(self: win32more.Windows.UI.Xaml.Controls.ITreeView2, value: win32more.Windows.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_ItemTemplateSelector(self: win32more.Windows.UI.Xaml.Controls.ITreeView2) -> win32more.Windows.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_mixinmethod
    def put_ItemTemplateSelector(self: win32more.Windows.UI.Xaml.Controls.ITreeView2, value: win32more.Windows.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_mixinmethod
    def get_ItemContainerStyle(self: win32more.Windows.UI.Xaml.Controls.ITreeView2) -> win32more.Windows.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_ItemContainerStyle(self: win32more.Windows.UI.Xaml.Controls.ITreeView2, value: win32more.Windows.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_ItemContainerStyleSelector(self: win32more.Windows.UI.Xaml.Controls.ITreeView2) -> win32more.Windows.UI.Xaml.Controls.StyleSelector: ...
    @winrt_mixinmethod
    def put_ItemContainerStyleSelector(self: win32more.Windows.UI.Xaml.Controls.ITreeView2, value: win32more.Windows.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_mixinmethod
    def get_ItemContainerTransitions(self: win32more.Windows.UI.Xaml.Controls.ITreeView2) -> win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_ItemContainerTransitions(self: win32more.Windows.UI.Xaml.Controls.ITreeView2, value: win32more.Windows.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_ItemsSource(self: win32more.Windows.UI.Xaml.Controls.ITreeView2) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_ItemsSource(self: win32more.Windows.UI.Xaml.Controls.ITreeView2, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def add_DragItemsStarting(self: win32more.Windows.UI.Xaml.Controls.ITreeView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TreeView, win32more.Windows.UI.Xaml.Controls.TreeViewDragItemsStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DragItemsStarting(self: win32more.Windows.UI.Xaml.Controls.ITreeView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DragItemsCompleted(self: win32more.Windows.UI.Xaml.Controls.ITreeView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TreeView, win32more.Windows.UI.Xaml.Controls.TreeViewDragItemsCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DragItemsCompleted(self: win32more.Windows.UI.Xaml.Controls.ITreeView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_CanDragItemsProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanReorderItemsProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemTemplateProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemTemplateSelectorProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemContainerStyleProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemContainerStyleSelectorProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemContainerTransitionsProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemsSourceProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionModeProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CanDragItems = property(get_CanDragItems, put_CanDragItems)
    CanReorderItems = property(get_CanReorderItems, put_CanReorderItems)
    ItemContainerStyle = property(get_ItemContainerStyle, put_ItemContainerStyle)
    ItemContainerStyleSelector = property(get_ItemContainerStyleSelector, put_ItemContainerStyleSelector)
    ItemContainerTransitions = property(get_ItemContainerTransitions, put_ItemContainerTransitions)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemTemplateSelector = property(get_ItemTemplateSelector, put_ItemTemplateSelector)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    RootNodes = property(get_RootNodes, None)
    SelectedNodes = property(get_SelectedNodes, None)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    _TreeView_Meta_.CanDragItemsProperty = property(get_CanDragItemsProperty, None)
    _TreeView_Meta_.CanReorderItemsProperty = property(get_CanReorderItemsProperty, None)
    _TreeView_Meta_.ItemContainerStyleProperty = property(get_ItemContainerStyleProperty, None)
    _TreeView_Meta_.ItemContainerStyleSelectorProperty = property(get_ItemContainerStyleSelectorProperty, None)
    _TreeView_Meta_.ItemContainerTransitionsProperty = property(get_ItemContainerTransitionsProperty, None)
    _TreeView_Meta_.ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    _TreeView_Meta_.ItemTemplateSelectorProperty = property(get_ItemTemplateSelectorProperty, None)
    _TreeView_Meta_.ItemsSourceProperty = property(get_ItemsSourceProperty, None)
    _TreeView_Meta_.SelectionModeProperty = property(get_SelectionModeProperty, None)
    ItemInvoked = event()
    Expanding = event()
    Collapsed = event()
    DragItemsStarting = event()
    DragItemsCompleted = event()
class TreeViewCollapsedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ITreeViewCollapsedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TreeViewCollapsedEventArgs'
    @winrt_mixinmethod
    def get_Node(self: win32more.Windows.UI.Xaml.Controls.ITreeViewCollapsedEventArgs) -> win32more.Windows.UI.Xaml.Controls.TreeViewNode: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Windows.UI.Xaml.Controls.ITreeViewCollapsedEventArgs2) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    Item = property(get_Item, None)
    Node = property(get_Node, None)
class TreeViewDragItemsCompletedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ITreeViewDragItemsCompletedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TreeViewDragItemsCompletedEventArgs'
    @winrt_mixinmethod
    def get_DropResult(self: win32more.Windows.UI.Xaml.Controls.ITreeViewDragItemsCompletedEventArgs) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.UI.Xaml.Controls.ITreeViewDragItemsCompletedEventArgs) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    DropResult = property(get_DropResult, None)
    Items = property(get_Items, None)
class TreeViewDragItemsStartingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ITreeViewDragItemsStartingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TreeViewDragItemsStartingEventArgs'
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Windows.UI.Xaml.Controls.ITreeViewDragItemsStartingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Windows.UI.Xaml.Controls.ITreeViewDragItemsStartingEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Windows.UI.Xaml.Controls.ITreeViewDragItemsStartingEventArgs) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackage: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.UI.Xaml.Controls.ITreeViewDragItemsStartingEventArgs) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    Cancel = property(get_Cancel, put_Cancel)
    Data = property(get_Data, None)
    Items = property(get_Items, None)
class TreeViewExpandingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ITreeViewExpandingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TreeViewExpandingEventArgs'
    @winrt_mixinmethod
    def get_Node(self: win32more.Windows.UI.Xaml.Controls.ITreeViewExpandingEventArgs) -> win32more.Windows.UI.Xaml.Controls.TreeViewNode: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Windows.UI.Xaml.Controls.ITreeViewExpandingEventArgs2) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    Item = property(get_Item, None)
    Node = property(get_Node, None)
class _TreeViewItem_Meta_(ComPtr.__class__):
    pass
class TreeViewItem(ComPtr, metaclass=_TreeViewItem_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.ListViewItem
    default_interface: win32more.Windows.UI.Xaml.Controls.ITreeViewItem
    _classid_ = 'Windows.UI.Xaml.Controls.TreeViewItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.TreeViewItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewItemFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TreeViewItem: ...
    @winrt_mixinmethod
    def get_GlyphOpacity(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItem) -> Double: ...
    @winrt_mixinmethod
    def put_GlyphOpacity(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItem, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_GlyphBrush(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItem) -> win32more.Windows.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_GlyphBrush(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItem, value: win32more.Windows.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_ExpandedGlyph(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ExpandedGlyph(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItem, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_CollapsedGlyph(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_CollapsedGlyph(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItem, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_GlyphSize(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItem) -> Double: ...
    @winrt_mixinmethod
    def put_GlyphSize(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItem, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_IsExpanded(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItem) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsExpanded(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItem, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TreeViewItemTemplateSettings(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItem) -> win32more.Windows.UI.Xaml.Controls.TreeViewItemTemplateSettings: ...
    @winrt_mixinmethod
    def get_HasUnrealizedChildren(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItem2) -> Boolean: ...
    @winrt_mixinmethod
    def put_HasUnrealizedChildren(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItem2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ItemsSource(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItem2) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_ItemsSource(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItem2, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_HasUnrealizedChildrenProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewItemStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemsSourceProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewItemStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GlyphOpacityProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GlyphBrushProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ExpandedGlyphProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CollapsedGlyphProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GlyphSizeProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsExpandedProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TreeViewItemTemplateSettingsProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewItemStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CollapsedGlyph = property(get_CollapsedGlyph, put_CollapsedGlyph)
    ExpandedGlyph = property(get_ExpandedGlyph, put_ExpandedGlyph)
    GlyphBrush = property(get_GlyphBrush, put_GlyphBrush)
    GlyphOpacity = property(get_GlyphOpacity, put_GlyphOpacity)
    GlyphSize = property(get_GlyphSize, put_GlyphSize)
    HasUnrealizedChildren = property(get_HasUnrealizedChildren, put_HasUnrealizedChildren)
    IsExpanded = property(get_IsExpanded, put_IsExpanded)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    TreeViewItemTemplateSettings = property(get_TreeViewItemTemplateSettings, None)
    _TreeViewItem_Meta_.CollapsedGlyphProperty = property(get_CollapsedGlyphProperty, None)
    _TreeViewItem_Meta_.ExpandedGlyphProperty = property(get_ExpandedGlyphProperty, None)
    _TreeViewItem_Meta_.GlyphBrushProperty = property(get_GlyphBrushProperty, None)
    _TreeViewItem_Meta_.GlyphOpacityProperty = property(get_GlyphOpacityProperty, None)
    _TreeViewItem_Meta_.GlyphSizeProperty = property(get_GlyphSizeProperty, None)
    _TreeViewItem_Meta_.HasUnrealizedChildrenProperty = property(get_HasUnrealizedChildrenProperty, None)
    _TreeViewItem_Meta_.IsExpandedProperty = property(get_IsExpandedProperty, None)
    _TreeViewItem_Meta_.ItemsSourceProperty = property(get_ItemsSourceProperty, None)
    _TreeViewItem_Meta_.TreeViewItemTemplateSettingsProperty = property(get_TreeViewItemTemplateSettingsProperty, None)
class TreeViewItemInvokedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.ITreeViewItemInvokedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.TreeViewItemInvokedEventArgs'
    @winrt_mixinmethod
    def get_InvokedItem(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItemInvokedEventArgs) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItemInvokedEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Handled(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItemInvokedEventArgs) -> Boolean: ...
    Handled = property(get_Handled, put_Handled)
    InvokedItem = property(get_InvokedItem, None)
class _TreeViewItemTemplateSettings_Meta_(ComPtr.__class__):
    pass
class TreeViewItemTemplateSettings(ComPtr, metaclass=_TreeViewItemTemplateSettings_Meta_):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Controls.ITreeViewItemTemplateSettings
    _classid_ = 'Windows.UI.Xaml.Controls.TreeViewItemTemplateSettings'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.TreeViewItemTemplateSettings.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewItemTemplateSettingsFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TreeViewItemTemplateSettings: ...
    @winrt_mixinmethod
    def get_ExpandedGlyphVisibility(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItemTemplateSettings) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_CollapsedGlyphVisibility(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItemTemplateSettings) -> win32more.Windows.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_Indentation(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItemTemplateSettings) -> win32more.Windows.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def get_DragItemsCount(self: win32more.Windows.UI.Xaml.Controls.ITreeViewItemTemplateSettings) -> Int32: ...
    @winrt_classmethod
    def get_ExpandedGlyphVisibilityProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewItemTemplateSettingsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CollapsedGlyphVisibilityProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewItemTemplateSettingsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IndentationProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewItemTemplateSettingsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DragItemsCountProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewItemTemplateSettingsStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CollapsedGlyphVisibility = property(get_CollapsedGlyphVisibility, None)
    DragItemsCount = property(get_DragItemsCount, None)
    ExpandedGlyphVisibility = property(get_ExpandedGlyphVisibility, None)
    Indentation = property(get_Indentation, None)
    _TreeViewItemTemplateSettings_Meta_.CollapsedGlyphVisibilityProperty = property(get_CollapsedGlyphVisibilityProperty, None)
    _TreeViewItemTemplateSettings_Meta_.DragItemsCountProperty = property(get_DragItemsCountProperty, None)
    _TreeViewItemTemplateSettings_Meta_.ExpandedGlyphVisibilityProperty = property(get_ExpandedGlyphVisibilityProperty, None)
    _TreeViewItemTemplateSettings_Meta_.IndentationProperty = property(get_IndentationProperty, None)
class TreeViewList(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.ListView
    default_interface: win32more.Windows.UI.Xaml.Controls.ITreeViewList
    _classid_ = 'Windows.UI.Xaml.Controls.TreeViewList'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.TreeViewList.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewListFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TreeViewList: ...
class _TreeViewNode_Meta_(ComPtr.__class__):
    pass
class TreeViewNode(ComPtr, metaclass=_TreeViewNode_Meta_):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Controls.ITreeViewNode
    _classid_ = 'Windows.UI.Xaml.Controls.TreeViewNode'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.TreeViewNode.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewNodeFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TreeViewNode: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Windows.UI.Xaml.Controls.ITreeViewNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Windows.UI.Xaml.Controls.ITreeViewNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_Parent(self: win32more.Windows.UI.Xaml.Controls.ITreeViewNode) -> win32more.Windows.UI.Xaml.Controls.TreeViewNode: ...
    @winrt_mixinmethod
    def get_IsExpanded(self: win32more.Windows.UI.Xaml.Controls.ITreeViewNode) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsExpanded(self: win32more.Windows.UI.Xaml.Controls.ITreeViewNode, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_HasChildren(self: win32more.Windows.UI.Xaml.Controls.ITreeViewNode) -> Boolean: ...
    @winrt_mixinmethod
    def get_Depth(self: win32more.Windows.UI.Xaml.Controls.ITreeViewNode) -> Int32: ...
    @winrt_mixinmethod
    def get_HasUnrealizedChildren(self: win32more.Windows.UI.Xaml.Controls.ITreeViewNode) -> Boolean: ...
    @winrt_mixinmethod
    def put_HasUnrealizedChildren(self: win32more.Windows.UI.Xaml.Controls.ITreeViewNode, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Children(self: win32more.Windows.UI.Xaml.Controls.ITreeViewNode) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.TreeViewNode]: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewNodeStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DepthProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewNodeStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsExpandedProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewNodeStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HasChildrenProperty(cls: win32more.Windows.UI.Xaml.Controls.ITreeViewNodeStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Children = property(get_Children, None)
    Content = property(get_Content, put_Content)
    Depth = property(get_Depth, None)
    HasChildren = property(get_HasChildren, None)
    HasUnrealizedChildren = property(get_HasUnrealizedChildren, put_HasUnrealizedChildren)
    IsExpanded = property(get_IsExpanded, put_IsExpanded)
    Parent = property(get_Parent, None)
    _TreeViewNode_Meta_.ContentProperty = property(get_ContentProperty, None)
    _TreeViewNode_Meta_.DepthProperty = property(get_DepthProperty, None)
    _TreeViewNode_Meta_.HasChildrenProperty = property(get_HasChildrenProperty, None)
    _TreeViewNode_Meta_.IsExpandedProperty = property(get_IsExpandedProperty, None)
class TreeViewSelectionMode(Enum, Int32):
    None_ = 0
    Single = 1
    Multiple = 2
class _TwoPaneView_Meta_(ComPtr.__class__):
    pass
class TwoPaneView(ComPtr, metaclass=_TwoPaneView_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.ITwoPaneView
    _classid_ = 'Windows.UI.Xaml.Controls.TwoPaneView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.TwoPaneView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.ITwoPaneViewFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.TwoPaneView: ...
    @winrt_mixinmethod
    def get_Pane1(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Pane1(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_Pane2(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Pane2(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_Pane1Length(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView) -> win32more.Windows.UI.Xaml.GridLength: ...
    @winrt_mixinmethod
    def put_Pane1Length(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView, value: win32more.Windows.UI.Xaml.GridLength) -> Void: ...
    @winrt_mixinmethod
    def get_Pane2Length(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView) -> win32more.Windows.UI.Xaml.GridLength: ...
    @winrt_mixinmethod
    def put_Pane2Length(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView, value: win32more.Windows.UI.Xaml.GridLength) -> Void: ...
    @winrt_mixinmethod
    def get_PanePriority(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView) -> win32more.Windows.UI.Xaml.Controls.TwoPaneViewPriority: ...
    @winrt_mixinmethod
    def put_PanePriority(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView, value: win32more.Windows.UI.Xaml.Controls.TwoPaneViewPriority) -> Void: ...
    @winrt_mixinmethod
    def get_Mode(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView) -> win32more.Windows.UI.Xaml.Controls.TwoPaneViewMode: ...
    @winrt_mixinmethod
    def get_WideModeConfiguration(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView) -> win32more.Windows.UI.Xaml.Controls.TwoPaneViewWideModeConfiguration: ...
    @winrt_mixinmethod
    def put_WideModeConfiguration(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView, value: win32more.Windows.UI.Xaml.Controls.TwoPaneViewWideModeConfiguration) -> Void: ...
    @winrt_mixinmethod
    def get_TallModeConfiguration(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView) -> win32more.Windows.UI.Xaml.Controls.TwoPaneViewTallModeConfiguration: ...
    @winrt_mixinmethod
    def put_TallModeConfiguration(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView, value: win32more.Windows.UI.Xaml.Controls.TwoPaneViewTallModeConfiguration) -> Void: ...
    @winrt_mixinmethod
    def get_MinWideModeWidth(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView) -> Double: ...
    @winrt_mixinmethod
    def put_MinWideModeWidth(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_MinTallModeHeight(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView) -> Double: ...
    @winrt_mixinmethod
    def put_MinTallModeHeight(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def add_ModeChanged(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.TwoPaneView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ModeChanged(self: win32more.Windows.UI.Xaml.Controls.ITwoPaneView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_Pane1Property(cls: win32more.Windows.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_Pane2Property(cls: win32more.Windows.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_Pane1LengthProperty(cls: win32more.Windows.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_Pane2LengthProperty(cls: win32more.Windows.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PanePriorityProperty(cls: win32more.Windows.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ModeProperty(cls: win32more.Windows.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_WideModeConfigurationProperty(cls: win32more.Windows.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TallModeConfigurationProperty(cls: win32more.Windows.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinWideModeWidthProperty(cls: win32more.Windows.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinTallModeHeightProperty(cls: win32more.Windows.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    MinTallModeHeight = property(get_MinTallModeHeight, put_MinTallModeHeight)
    MinWideModeWidth = property(get_MinWideModeWidth, put_MinWideModeWidth)
    Mode = property(get_Mode, None)
    Pane1 = property(get_Pane1, put_Pane1)
    Pane1Length = property(get_Pane1Length, put_Pane1Length)
    Pane2 = property(get_Pane2, put_Pane2)
    Pane2Length = property(get_Pane2Length, put_Pane2Length)
    PanePriority = property(get_PanePriority, put_PanePriority)
    TallModeConfiguration = property(get_TallModeConfiguration, put_TallModeConfiguration)
    WideModeConfiguration = property(get_WideModeConfiguration, put_WideModeConfiguration)
    _TwoPaneView_Meta_.MinTallModeHeightProperty = property(get_MinTallModeHeightProperty, None)
    _TwoPaneView_Meta_.MinWideModeWidthProperty = property(get_MinWideModeWidthProperty, None)
    _TwoPaneView_Meta_.ModeProperty = property(get_ModeProperty, None)
    _TwoPaneView_Meta_.Pane1LengthProperty = property(get_Pane1LengthProperty, None)
    _TwoPaneView_Meta_.Pane1Property = property(get_Pane1Property, None)
    _TwoPaneView_Meta_.Pane2LengthProperty = property(get_Pane2LengthProperty, None)
    _TwoPaneView_Meta_.Pane2Property = property(get_Pane2Property, None)
    _TwoPaneView_Meta_.PanePriorityProperty = property(get_PanePriorityProperty, None)
    _TwoPaneView_Meta_.TallModeConfigurationProperty = property(get_TallModeConfigurationProperty, None)
    _TwoPaneView_Meta_.WideModeConfigurationProperty = property(get_WideModeConfigurationProperty, None)
    ModeChanged = event()
class TwoPaneViewMode(Enum, Int32):
    SinglePane = 0
    Wide = 1
    Tall = 2
class TwoPaneViewPriority(Enum, Int32):
    Pane1 = 0
    Pane2 = 1
class TwoPaneViewTallModeConfiguration(Enum, Int32):
    SinglePane = 0
    TopBottom = 1
    BottomTop = 2
class TwoPaneViewWideModeConfiguration(Enum, Int32):
    SinglePane = 0
    LeftRight = 1
    RightLeft = 2
class UIElementCollection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[win32more.Windows.UI.Xaml.UIElement]]
    default_interface: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.UIElement]
    _classid_ = 'Windows.UI.Xaml.Controls.UIElementCollection'
    @winrt_mixinmethod
    def Move(self: win32more.Windows.UI.Xaml.Controls.IUIElementCollection, oldIndex: UInt32, newIndex: UInt32) -> Void: ...
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.UIElement], index: UInt32) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.UIElement]) -> UInt32: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.UIElement]) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.UI.Xaml.UIElement]: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.UIElement], value: win32more.Windows.UI.Xaml.UIElement, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def SetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.UIElement], index: UInt32, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def InsertAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.UIElement], index: UInt32, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def RemoveAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.UIElement], index: UInt32) -> Void: ...
    @winrt_mixinmethod
    def Append(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.UIElement], value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def RemoveAtEnd(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.UIElement]) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.UIElement]) -> Void: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.UIElement], startIndex: UInt32, items: FillArray[win32more.Windows.UI.Xaml.UIElement]) -> UInt32: ...
    @winrt_mixinmethod
    def ReplaceAll(self: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.UIElement], items: PassArray[win32more.Windows.UI.Xaml.UIElement]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.UI.Xaml.UIElement]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.UI.Xaml.UIElement]: ...
    Size = property(get_Size, None)
class _UserControl_Meta_(ComPtr.__class__):
    pass
class UserControl(ComPtr, metaclass=_UserControl_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Control
    default_interface: win32more.Windows.UI.Xaml.Controls.IUserControl
    _classid_ = 'Windows.UI.Xaml.Controls.UserControl'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.UserControl.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Controls.IUserControlFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Controls.UserControl: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Windows.UI.Xaml.Controls.IUserControl) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Windows.UI.Xaml.Controls.IUserControl, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Windows.UI.Xaml.Controls.IUserControlStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Content = property(get_Content, put_Content)
    _UserControl_Meta_.ContentProperty = property(get_ContentProperty, None)
class _VariableSizedWrapGrid_Meta_(ComPtr.__class__):
    pass
class VariableSizedWrapGrid(ComPtr, metaclass=_VariableSizedWrapGrid_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Panel
    default_interface: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGrid
    _classid_ = 'Windows.UI.Xaml.Controls.VariableSizedWrapGrid'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.VariableSizedWrapGrid.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.VariableSizedWrapGrid: ...
    @winrt_mixinmethod
    def get_ItemHeight(self: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGrid) -> Double: ...
    @winrt_mixinmethod
    def put_ItemHeight(self: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGrid, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ItemWidth(self: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGrid) -> Double: ...
    @winrt_mixinmethod
    def put_ItemWidth(self: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGrid, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGrid) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGrid, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalChildrenAlignment(self: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGrid) -> win32more.Windows.UI.Xaml.HorizontalAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalChildrenAlignment(self: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGrid, value: win32more.Windows.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalChildrenAlignment(self: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGrid) -> win32more.Windows.UI.Xaml.VerticalAlignment: ...
    @winrt_mixinmethod
    def put_VerticalChildrenAlignment(self: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGrid, value: win32more.Windows.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_MaximumRowsOrColumns(self: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGrid) -> Int32: ...
    @winrt_mixinmethod
    def put_MaximumRowsOrColumns(self: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGrid, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_ItemHeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemWidthProperty(cls: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalChildrenAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalChildrenAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaximumRowsOrColumnsProperty(cls: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RowSpanProperty(cls: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetRowSpan(cls: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGridStatics, element: win32more.Windows.UI.Xaml.UIElement) -> Int32: ...
    @winrt_classmethod
    def SetRowSpan(cls: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGridStatics, element: win32more.Windows.UI.Xaml.UIElement, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_ColumnSpanProperty(cls: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetColumnSpan(cls: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGridStatics, element: win32more.Windows.UI.Xaml.UIElement) -> Int32: ...
    @winrt_classmethod
    def SetColumnSpan(cls: win32more.Windows.UI.Xaml.Controls.IVariableSizedWrapGridStatics, element: win32more.Windows.UI.Xaml.UIElement, value: Int32) -> Void: ...
    HorizontalChildrenAlignment = property(get_HorizontalChildrenAlignment, put_HorizontalChildrenAlignment)
    ItemHeight = property(get_ItemHeight, put_ItemHeight)
    ItemWidth = property(get_ItemWidth, put_ItemWidth)
    MaximumRowsOrColumns = property(get_MaximumRowsOrColumns, put_MaximumRowsOrColumns)
    Orientation = property(get_Orientation, put_Orientation)
    VerticalChildrenAlignment = property(get_VerticalChildrenAlignment, put_VerticalChildrenAlignment)
    _VariableSizedWrapGrid_Meta_.ColumnSpanProperty = property(get_ColumnSpanProperty, None)
    _VariableSizedWrapGrid_Meta_.HorizontalChildrenAlignmentProperty = property(get_HorizontalChildrenAlignmentProperty, None)
    _VariableSizedWrapGrid_Meta_.ItemHeightProperty = property(get_ItemHeightProperty, None)
    _VariableSizedWrapGrid_Meta_.ItemWidthProperty = property(get_ItemWidthProperty, None)
    _VariableSizedWrapGrid_Meta_.MaximumRowsOrColumnsProperty = property(get_MaximumRowsOrColumnsProperty, None)
    _VariableSizedWrapGrid_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _VariableSizedWrapGrid_Meta_.RowSpanProperty = property(get_RowSpanProperty, None)
    _VariableSizedWrapGrid_Meta_.VerticalChildrenAlignmentProperty = property(get_VerticalChildrenAlignmentProperty, None)
class _Viewbox_Meta_(ComPtr.__class__):
    pass
class Viewbox(ComPtr, metaclass=_Viewbox_Meta_):
    extends: win32more.Windows.UI.Xaml.FrameworkElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IViewbox
    _classid_ = 'Windows.UI.Xaml.Controls.Viewbox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.Viewbox.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.Viewbox: ...
    @winrt_mixinmethod
    def get_Child(self: win32more.Windows.UI.Xaml.Controls.IViewbox) -> win32more.Windows.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Child(self: win32more.Windows.UI.Xaml.Controls.IViewbox, value: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_Stretch(self: win32more.Windows.UI.Xaml.Controls.IViewbox) -> win32more.Windows.UI.Xaml.Media.Stretch: ...
    @winrt_mixinmethod
    def put_Stretch(self: win32more.Windows.UI.Xaml.Controls.IViewbox, value: win32more.Windows.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_mixinmethod
    def get_StretchDirection(self: win32more.Windows.UI.Xaml.Controls.IViewbox) -> win32more.Windows.UI.Xaml.Controls.StretchDirection: ...
    @winrt_mixinmethod
    def put_StretchDirection(self: win32more.Windows.UI.Xaml.Controls.IViewbox, value: win32more.Windows.UI.Xaml.Controls.StretchDirection) -> Void: ...
    @winrt_classmethod
    def get_StretchProperty(cls: win32more.Windows.UI.Xaml.Controls.IViewboxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StretchDirectionProperty(cls: win32more.Windows.UI.Xaml.Controls.IViewboxStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Child = property(get_Child, put_Child)
    Stretch = property(get_Stretch, put_Stretch)
    StretchDirection = property(get_StretchDirection, put_StretchDirection)
    _Viewbox_Meta_.StretchDirectionProperty = property(get_StretchDirectionProperty, None)
    _Viewbox_Meta_.StretchProperty = property(get_StretchProperty, None)
class VirtualizationMode(Enum, Int32):
    Standard = 0
    Recycling = 1
class VirtualizingPanel(ComPtr):
    extends: win32more.Windows.UI.Xaml.Controls.Panel
    default_interface: win32more.Windows.UI.Xaml.Controls.IVirtualizingPanel
    _classid_ = 'Windows.UI.Xaml.Controls.VirtualizingPanel'
    @winrt_mixinmethod
    def get_ItemContainerGenerator(self: win32more.Windows.UI.Xaml.Controls.IVirtualizingPanel) -> win32more.Windows.UI.Xaml.Controls.ItemContainerGenerator: ...
    @winrt_mixinmethod
    def AddInternalChild(self: win32more.Windows.UI.Xaml.Controls.IVirtualizingPanelProtected, child: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def InsertInternalChild(self: win32more.Windows.UI.Xaml.Controls.IVirtualizingPanelProtected, index: Int32, child: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def RemoveInternalChildRange(self: win32more.Windows.UI.Xaml.Controls.IVirtualizingPanelProtected, index: Int32, range: Int32) -> Void: ...
    @winrt_mixinmethod
    def OnItemsChanged(self: win32more.Windows.UI.Xaml.Controls.IVirtualizingPanelOverrides, sender: win32more.Windows.Win32.System.WinRT.IInspectable, args: win32more.Windows.UI.Xaml.Controls.Primitives.ItemsChangedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnClearChildren(self: win32more.Windows.UI.Xaml.Controls.IVirtualizingPanelOverrides) -> Void: ...
    @winrt_mixinmethod
    def BringIndexIntoView(self: win32more.Windows.UI.Xaml.Controls.IVirtualizingPanelOverrides, index: Int32) -> Void: ...
    ItemContainerGenerator = property(get_ItemContainerGenerator, None)
class _VirtualizingStackPanel_Meta_(ComPtr.__class__):
    pass
class VirtualizingStackPanel(ComPtr, metaclass=_VirtualizingStackPanel_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.OrientedVirtualizingPanel
    default_interface: win32more.Windows.UI.Xaml.Controls.IVirtualizingStackPanel
    _classid_ = 'Windows.UI.Xaml.Controls.VirtualizingStackPanel'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.VirtualizingStackPanel.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.VirtualizingStackPanel: ...
    @winrt_mixinmethod
    def get_AreScrollSnapPointsRegular(self: win32more.Windows.UI.Xaml.Controls.IVirtualizingStackPanel) -> Boolean: ...
    @winrt_mixinmethod
    def put_AreScrollSnapPointsRegular(self: win32more.Windows.UI.Xaml.Controls.IVirtualizingStackPanel, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Windows.UI.Xaml.Controls.IVirtualizingStackPanel) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Windows.UI.Xaml.Controls.IVirtualizingStackPanel, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def add_CleanUpVirtualizedItemEvent(self: win32more.Windows.UI.Xaml.Controls.IVirtualizingStackPanel, handler: win32more.Windows.UI.Xaml.Controls.CleanUpVirtualizedItemEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CleanUpVirtualizedItemEvent(self: win32more.Windows.UI.Xaml.Controls.IVirtualizingStackPanel, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def OnCleanUpVirtualizedItem(self: win32more.Windows.UI.Xaml.Controls.IVirtualizingStackPanelOverrides, e: win32more.Windows.UI.Xaml.Controls.CleanUpVirtualizedItemEventArgs) -> Void: ...
    @winrt_classmethod
    def get_AreScrollSnapPointsRegularProperty(cls: win32more.Windows.UI.Xaml.Controls.IVirtualizingStackPanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Windows.UI.Xaml.Controls.IVirtualizingStackPanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VirtualizationModeProperty(cls: win32more.Windows.UI.Xaml.Controls.IVirtualizingStackPanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetVirtualizationMode(cls: win32more.Windows.UI.Xaml.Controls.IVirtualizingStackPanelStatics, element: win32more.Windows.UI.Xaml.DependencyObject) -> win32more.Windows.UI.Xaml.Controls.VirtualizationMode: ...
    @winrt_classmethod
    def SetVirtualizationMode(cls: win32more.Windows.UI.Xaml.Controls.IVirtualizingStackPanelStatics, element: win32more.Windows.UI.Xaml.DependencyObject, value: win32more.Windows.UI.Xaml.Controls.VirtualizationMode) -> Void: ...
    @winrt_classmethod
    def get_IsVirtualizingProperty(cls: win32more.Windows.UI.Xaml.Controls.IVirtualizingStackPanelStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsVirtualizing(cls: win32more.Windows.UI.Xaml.Controls.IVirtualizingStackPanelStatics, o: win32more.Windows.UI.Xaml.DependencyObject) -> Boolean: ...
    AreScrollSnapPointsRegular = property(get_AreScrollSnapPointsRegular, put_AreScrollSnapPointsRegular)
    Orientation = property(get_Orientation, put_Orientation)
    _VirtualizingStackPanel_Meta_.AreScrollSnapPointsRegularProperty = property(get_AreScrollSnapPointsRegularProperty, None)
    _VirtualizingStackPanel_Meta_.IsVirtualizingProperty = property(get_IsVirtualizingProperty, None)
    _VirtualizingStackPanel_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _VirtualizingStackPanel_Meta_.VirtualizationModeProperty = property(get_VirtualizationModeProperty, None)
    CleanUpVirtualizedItemEvent = event()
class _WebView_Meta_(ComPtr.__class__):
    pass
class WebView(ComPtr, metaclass=_WebView_Meta_):
    extends: win32more.Windows.UI.Xaml.FrameworkElement
    default_interface: win32more.Windows.UI.Xaml.Controls.IWebView
    _classid_ = 'Windows.UI.Xaml.Controls.WebView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.WebView.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.WebView.CreateInstanceWithExecutionMode(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.WebView: ...
    @winrt_factorymethod
    def CreateInstanceWithExecutionMode(cls: win32more.Windows.UI.Xaml.Controls.IWebViewFactory4, executionMode: win32more.Windows.UI.Xaml.Controls.WebViewExecutionMode) -> win32more.Windows.UI.Xaml.Controls.WebView: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Windows.UI.Xaml.Controls.IWebView) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Windows.UI.Xaml.Controls.IWebView, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_AllowedScriptNotifyUris(self: win32more.Windows.UI.Xaml.Controls.IWebView) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Foundation.Uri]: ...
    @winrt_mixinmethod
    def put_AllowedScriptNotifyUris(self: win32more.Windows.UI.Xaml.Controls.IWebView, value: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Foundation.Uri]) -> Void: ...
    @winrt_mixinmethod
    def get_DataTransferPackage(self: win32more.Windows.UI.Xaml.Controls.IWebView) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackage: ...
    @winrt_mixinmethod
    def add_LoadCompleted(self: win32more.Windows.UI.Xaml.Controls.IWebView, handler: win32more.Windows.UI.Xaml.Navigation.LoadCompletedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_LoadCompleted(self: win32more.Windows.UI.Xaml.Controls.IWebView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ScriptNotify(self: win32more.Windows.UI.Xaml.Controls.IWebView, handler: win32more.Windows.UI.Xaml.Controls.NotifyEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ScriptNotify(self: win32more.Windows.UI.Xaml.Controls.IWebView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_NavigationFailed(self: win32more.Windows.UI.Xaml.Controls.IWebView, handler: win32more.Windows.UI.Xaml.Controls.WebViewNavigationFailedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_NavigationFailed(self: win32more.Windows.UI.Xaml.Controls.IWebView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def InvokeScript(self: win32more.Windows.UI.Xaml.Controls.IWebView, scriptName: WinRT_String, arguments: PassArray[WinRT_String]) -> WinRT_String: ...
    @winrt_mixinmethod
    def Navigate(self: win32more.Windows.UI.Xaml.Controls.IWebView, source: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def NavigateToString(self: win32more.Windows.UI.Xaml.Controls.IWebView, text: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_CanGoBack(self: win32more.Windows.UI.Xaml.Controls.IWebView2) -> Boolean: ...
    @winrt_mixinmethod
    def get_CanGoForward(self: win32more.Windows.UI.Xaml.Controls.IWebView2) -> Boolean: ...
    @winrt_mixinmethod
    def get_DocumentTitle(self: win32more.Windows.UI.Xaml.Controls.IWebView2) -> WinRT_String: ...
    @winrt_mixinmethod
    def add_NavigationStarting(self: win32more.Windows.UI.Xaml.Controls.IWebView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewNavigationStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_NavigationStarting(self: win32more.Windows.UI.Xaml.Controls.IWebView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ContentLoading(self: win32more.Windows.UI.Xaml.Controls.IWebView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewContentLoadingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContentLoading(self: win32more.Windows.UI.Xaml.Controls.IWebView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DOMContentLoaded(self: win32more.Windows.UI.Xaml.Controls.IWebView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewDOMContentLoadedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DOMContentLoaded(self: win32more.Windows.UI.Xaml.Controls.IWebView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GoForward(self: win32more.Windows.UI.Xaml.Controls.IWebView2) -> Void: ...
    @winrt_mixinmethod
    def GoBack(self: win32more.Windows.UI.Xaml.Controls.IWebView2) -> Void: ...
    @winrt_mixinmethod
    def Refresh(self: win32more.Windows.UI.Xaml.Controls.IWebView2) -> Void: ...
    @winrt_mixinmethod
    def Stop(self: win32more.Windows.UI.Xaml.Controls.IWebView2) -> Void: ...
    @winrt_mixinmethod
    def CapturePreviewToStreamAsync(self: win32more.Windows.UI.Xaml.Controls.IWebView2, stream: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def InvokeScriptAsync(self: win32more.Windows.UI.Xaml.Controls.IWebView2, scriptName: WinRT_String, arguments: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[WinRT_String]: ...
    @winrt_mixinmethod
    def CaptureSelectedContentToDataPackageAsync(self: win32more.Windows.UI.Xaml.Controls.IWebView2) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.DataTransfer.DataPackage]: ...
    @winrt_mixinmethod
    def NavigateToLocalStreamUri(self: win32more.Windows.UI.Xaml.Controls.IWebView2, source: win32more.Windows.Foundation.Uri, streamResolver: win32more.Windows.Web.IUriToStreamResolver) -> Void: ...
    @winrt_mixinmethod
    def BuildLocalStreamUri(self: win32more.Windows.UI.Xaml.Controls.IWebView2, contentIdentifier: WinRT_String, relativePath: WinRT_String) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_DefaultBackgroundColor(self: win32more.Windows.UI.Xaml.Controls.IWebView2) -> win32more.Windows.UI.Color: ...
    @winrt_mixinmethod
    def put_DefaultBackgroundColor(self: win32more.Windows.UI.Xaml.Controls.IWebView2, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_mixinmethod
    def add_NavigationCompleted(self: win32more.Windows.UI.Xaml.Controls.IWebView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewNavigationCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_NavigationCompleted(self: win32more.Windows.UI.Xaml.Controls.IWebView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_FrameNavigationStarting(self: win32more.Windows.UI.Xaml.Controls.IWebView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewNavigationStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FrameNavigationStarting(self: win32more.Windows.UI.Xaml.Controls.IWebView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_FrameContentLoading(self: win32more.Windows.UI.Xaml.Controls.IWebView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewContentLoadingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FrameContentLoading(self: win32more.Windows.UI.Xaml.Controls.IWebView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_FrameDOMContentLoaded(self: win32more.Windows.UI.Xaml.Controls.IWebView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewDOMContentLoadedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FrameDOMContentLoaded(self: win32more.Windows.UI.Xaml.Controls.IWebView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_FrameNavigationCompleted(self: win32more.Windows.UI.Xaml.Controls.IWebView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewNavigationCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FrameNavigationCompleted(self: win32more.Windows.UI.Xaml.Controls.IWebView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_LongRunningScriptDetected(self: win32more.Windows.UI.Xaml.Controls.IWebView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewLongRunningScriptDetectedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_LongRunningScriptDetected(self: win32more.Windows.UI.Xaml.Controls.IWebView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_UnsafeContentWarningDisplaying(self: win32more.Windows.UI.Xaml.Controls.IWebView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_UnsafeContentWarningDisplaying(self: win32more.Windows.UI.Xaml.Controls.IWebView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_UnviewableContentIdentified(self: win32more.Windows.UI.Xaml.Controls.IWebView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewUnviewableContentIdentifiedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_UnviewableContentIdentified(self: win32more.Windows.UI.Xaml.Controls.IWebView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def NavigateWithHttpRequestMessage(self: win32more.Windows.UI.Xaml.Controls.IWebView2, requestMessage: win32more.Windows.Web.Http.HttpRequestMessage) -> Void: ...
    @winrt_mixinmethod
    def Focus(self: win32more.Windows.UI.Xaml.Controls.IWebView2, value: win32more.Windows.UI.Xaml.FocusState) -> Boolean: ...
    @winrt_mixinmethod
    def get_ContainsFullScreenElement(self: win32more.Windows.UI.Xaml.Controls.IWebView3) -> Boolean: ...
    @winrt_mixinmethod
    def add_ContainsFullScreenElementChanged(self: win32more.Windows.UI.Xaml.Controls.IWebView3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContainsFullScreenElementChanged(self: win32more.Windows.UI.Xaml.Controls.IWebView3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_ExecutionMode(self: win32more.Windows.UI.Xaml.Controls.IWebView4) -> win32more.Windows.UI.Xaml.Controls.WebViewExecutionMode: ...
    @winrt_mixinmethod
    def get_DeferredPermissionRequests(self: win32more.Windows.UI.Xaml.Controls.IWebView4) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.Xaml.Controls.WebViewDeferredPermissionRequest]: ...
    @winrt_mixinmethod
    def get_Settings(self: win32more.Windows.UI.Xaml.Controls.IWebView4) -> win32more.Windows.UI.Xaml.Controls.WebViewSettings: ...
    @winrt_mixinmethod
    def add_UnsupportedUriSchemeIdentified(self: win32more.Windows.UI.Xaml.Controls.IWebView4, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewUnsupportedUriSchemeIdentifiedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_UnsupportedUriSchemeIdentified(self: win32more.Windows.UI.Xaml.Controls.IWebView4, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_NewWindowRequested(self: win32more.Windows.UI.Xaml.Controls.IWebView4, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewNewWindowRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_NewWindowRequested(self: win32more.Windows.UI.Xaml.Controls.IWebView4, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PermissionRequested(self: win32more.Windows.UI.Xaml.Controls.IWebView4, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewPermissionRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PermissionRequested(self: win32more.Windows.UI.Xaml.Controls.IWebView4, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def AddWebAllowedObject(self: win32more.Windows.UI.Xaml.Controls.IWebView4, name: WinRT_String, pObject: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def DeferredPermissionRequestById(self: win32more.Windows.UI.Xaml.Controls.IWebView4, id: UInt32) -> win32more.Windows.UI.Xaml.Controls.WebViewDeferredPermissionRequest: ...
    @winrt_mixinmethod
    def get_XYFocusLeft(self: win32more.Windows.UI.Xaml.Controls.IWebView5) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def put_XYFocusLeft(self: win32more.Windows.UI.Xaml.Controls.IWebView5, value: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_mixinmethod
    def get_XYFocusRight(self: win32more.Windows.UI.Xaml.Controls.IWebView5) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def put_XYFocusRight(self: win32more.Windows.UI.Xaml.Controls.IWebView5, value: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_mixinmethod
    def get_XYFocusUp(self: win32more.Windows.UI.Xaml.Controls.IWebView5) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def put_XYFocusUp(self: win32more.Windows.UI.Xaml.Controls.IWebView5, value: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_mixinmethod
    def get_XYFocusDown(self: win32more.Windows.UI.Xaml.Controls.IWebView5) -> win32more.Windows.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def put_XYFocusDown(self: win32more.Windows.UI.Xaml.Controls.IWebView5, value: win32more.Windows.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_mixinmethod
    def add_SeparateProcessLost(self: win32more.Windows.UI.Xaml.Controls.IWebView6, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewSeparateProcessLostEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SeparateProcessLost(self: win32more.Windows.UI.Xaml.Controls.IWebView6, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_WebResourceRequested(self: win32more.Windows.UI.Xaml.Controls.IWebView7, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Xaml.Controls.WebView, win32more.Windows.UI.Xaml.Controls.WebViewWebResourceRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_WebResourceRequested(self: win32more.Windows.UI.Xaml.Controls.IWebView7, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_XYFocusLeftProperty(cls: win32more.Windows.UI.Xaml.Controls.IWebViewStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_XYFocusRightProperty(cls: win32more.Windows.UI.Xaml.Controls.IWebViewStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_XYFocusUpProperty(cls: win32more.Windows.UI.Xaml.Controls.IWebViewStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_XYFocusDownProperty(cls: win32more.Windows.UI.Xaml.Controls.IWebViewStatics5) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DefaultExecutionMode(cls: win32more.Windows.UI.Xaml.Controls.IWebViewStatics4) -> win32more.Windows.UI.Xaml.Controls.WebViewExecutionMode: ...
    @winrt_classmethod
    def ClearTemporaryWebDataAsync(cls: win32more.Windows.UI.Xaml.Controls.IWebViewStatics4) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def get_ContainsFullScreenElementProperty(cls: win32more.Windows.UI.Xaml.Controls.IWebViewStatics3) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanGoBackProperty(cls: win32more.Windows.UI.Xaml.Controls.IWebViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanGoForwardProperty(cls: win32more.Windows.UI.Xaml.Controls.IWebViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DocumentTitleProperty(cls: win32more.Windows.UI.Xaml.Controls.IWebViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DefaultBackgroundColorProperty(cls: win32more.Windows.UI.Xaml.Controls.IWebViewStatics2) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AnyScriptNotifyUri(cls: win32more.Windows.UI.Xaml.Controls.IWebViewStatics) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Foundation.Uri]: ...
    @winrt_classmethod
    def get_SourceProperty(cls: win32more.Windows.UI.Xaml.Controls.IWebViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AllowedScriptNotifyUrisProperty(cls: win32more.Windows.UI.Xaml.Controls.IWebViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DataTransferPackageProperty(cls: win32more.Windows.UI.Xaml.Controls.IWebViewStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    AllowedScriptNotifyUris = property(get_AllowedScriptNotifyUris, put_AllowedScriptNotifyUris)
    CanGoBack = property(get_CanGoBack, None)
    CanGoForward = property(get_CanGoForward, None)
    ContainsFullScreenElement = property(get_ContainsFullScreenElement, None)
    DataTransferPackage = property(get_DataTransferPackage, None)
    DefaultBackgroundColor = property(get_DefaultBackgroundColor, put_DefaultBackgroundColor)
    DeferredPermissionRequests = property(get_DeferredPermissionRequests, None)
    DocumentTitle = property(get_DocumentTitle, None)
    ExecutionMode = property(get_ExecutionMode, None)
    Settings = property(get_Settings, None)
    Source = property(get_Source, put_Source)
    XYFocusDown = property(get_XYFocusDown, put_XYFocusDown)
    XYFocusLeft = property(get_XYFocusLeft, put_XYFocusLeft)
    XYFocusRight = property(get_XYFocusRight, put_XYFocusRight)
    XYFocusUp = property(get_XYFocusUp, put_XYFocusUp)
    _WebView_Meta_.AllowedScriptNotifyUrisProperty = property(get_AllowedScriptNotifyUrisProperty, None)
    _WebView_Meta_.AnyScriptNotifyUri = property(get_AnyScriptNotifyUri, None)
    _WebView_Meta_.CanGoBackProperty = property(get_CanGoBackProperty, None)
    _WebView_Meta_.CanGoForwardProperty = property(get_CanGoForwardProperty, None)
    _WebView_Meta_.ContainsFullScreenElementProperty = property(get_ContainsFullScreenElementProperty, None)
    _WebView_Meta_.DataTransferPackageProperty = property(get_DataTransferPackageProperty, None)
    _WebView_Meta_.DefaultBackgroundColorProperty = property(get_DefaultBackgroundColorProperty, None)
    _WebView_Meta_.DefaultExecutionMode = property(get_DefaultExecutionMode, None)
    _WebView_Meta_.DocumentTitleProperty = property(get_DocumentTitleProperty, None)
    _WebView_Meta_.SourceProperty = property(get_SourceProperty, None)
    _WebView_Meta_.XYFocusDownProperty = property(get_XYFocusDownProperty, None)
    _WebView_Meta_.XYFocusLeftProperty = property(get_XYFocusLeftProperty, None)
    _WebView_Meta_.XYFocusRightProperty = property(get_XYFocusRightProperty, None)
    _WebView_Meta_.XYFocusUpProperty = property(get_XYFocusUpProperty, None)
    LoadCompleted = event()
    ScriptNotify = event()
    NavigationFailed = event()
    NavigationStarting = event()
    ContentLoading = event()
    DOMContentLoaded = event()
    NavigationCompleted = event()
    FrameNavigationStarting = event()
    FrameContentLoading = event()
    FrameDOMContentLoaded = event()
    FrameNavigationCompleted = event()
    LongRunningScriptDetected = event()
    UnsafeContentWarningDisplaying = event()
    UnviewableContentIdentified = event()
    ContainsFullScreenElementChanged = event()
    UnsupportedUriSchemeIdentified = event()
    NewWindowRequested = event()
    PermissionRequested = event()
    SeparateProcessLost = event()
    WebResourceRequested = event()
class _WebViewBrush_Meta_(ComPtr.__class__):
    pass
class WebViewBrush(ComPtr, metaclass=_WebViewBrush_Meta_):
    extends: win32more.Windows.UI.Xaml.Media.TileBrush
    default_interface: win32more.Windows.UI.Xaml.Controls.IWebViewBrush
    _classid_ = 'Windows.UI.Xaml.Controls.WebViewBrush'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.WebViewBrush.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.WebViewBrush: ...
    @winrt_mixinmethod
    def get_SourceName(self: win32more.Windows.UI.Xaml.Controls.IWebViewBrush) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SourceName(self: win32more.Windows.UI.Xaml.Controls.IWebViewBrush, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def Redraw(self: win32more.Windows.UI.Xaml.Controls.IWebViewBrush) -> Void: ...
    @winrt_mixinmethod
    def SetSource(self: win32more.Windows.UI.Xaml.Controls.IWebViewBrush, source: win32more.Windows.UI.Xaml.Controls.WebView) -> Void: ...
    @winrt_classmethod
    def get_SourceNameProperty(cls: win32more.Windows.UI.Xaml.Controls.IWebViewBrushStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SourceName = property(get_SourceName, put_SourceName)
    _WebViewBrush_Meta_.SourceNameProperty = property(get_SourceNameProperty, None)
class WebViewContentLoadingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IWebViewContentLoadingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.WebViewContentLoadingEventArgs'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.UI.Xaml.Controls.IWebViewContentLoadingEventArgs) -> win32more.Windows.Foundation.Uri: ...
    Uri = property(get_Uri, None)
class WebViewDOMContentLoadedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IWebViewDOMContentLoadedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.WebViewDOMContentLoadedEventArgs'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.UI.Xaml.Controls.IWebViewDOMContentLoadedEventArgs) -> win32more.Windows.Foundation.Uri: ...
    Uri = property(get_Uri, None)
class WebViewDeferredPermissionRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IWebViewDeferredPermissionRequest
    _classid_ = 'Windows.UI.Xaml.Controls.WebViewDeferredPermissionRequest'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.UI.Xaml.Controls.IWebViewDeferredPermissionRequest) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_PermissionType(self: win32more.Windows.UI.Xaml.Controls.IWebViewDeferredPermissionRequest) -> win32more.Windows.UI.Xaml.Controls.WebViewPermissionType: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.UI.Xaml.Controls.IWebViewDeferredPermissionRequest) -> UInt32: ...
    @winrt_mixinmethod
    def Allow(self: win32more.Windows.UI.Xaml.Controls.IWebViewDeferredPermissionRequest) -> Void: ...
    @winrt_mixinmethod
    def Deny(self: win32more.Windows.UI.Xaml.Controls.IWebViewDeferredPermissionRequest) -> Void: ...
    Id = property(get_Id, None)
    PermissionType = property(get_PermissionType, None)
    Uri = property(get_Uri, None)
class WebViewExecutionMode(Enum, Int32):
    SameThread = 0
    SeparateThread = 1
    SeparateProcess = 2
class WebViewLongRunningScriptDetectedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IWebViewLongRunningScriptDetectedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.WebViewLongRunningScriptDetectedEventArgs'
    @winrt_mixinmethod
    def get_ExecutionTime(self: win32more.Windows.UI.Xaml.Controls.IWebViewLongRunningScriptDetectedEventArgs) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_StopPageScriptExecution(self: win32more.Windows.UI.Xaml.Controls.IWebViewLongRunningScriptDetectedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_StopPageScriptExecution(self: win32more.Windows.UI.Xaml.Controls.IWebViewLongRunningScriptDetectedEventArgs, value: Boolean) -> Void: ...
    ExecutionTime = property(get_ExecutionTime, None)
    StopPageScriptExecution = property(get_StopPageScriptExecution, put_StopPageScriptExecution)
class WebViewNavigationCompletedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IWebViewNavigationCompletedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.WebViewNavigationCompletedEventArgs'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.UI.Xaml.Controls.IWebViewNavigationCompletedEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_IsSuccess(self: win32more.Windows.UI.Xaml.Controls.IWebViewNavigationCompletedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_WebErrorStatus(self: win32more.Windows.UI.Xaml.Controls.IWebViewNavigationCompletedEventArgs) -> win32more.Windows.Web.WebErrorStatus: ...
    IsSuccess = property(get_IsSuccess, None)
    Uri = property(get_Uri, None)
    WebErrorStatus = property(get_WebErrorStatus, None)
class WebViewNavigationFailedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IWebViewNavigationFailedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.WebViewNavigationFailedEventArgs'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.UI.Xaml.Controls.IWebViewNavigationFailedEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_WebErrorStatus(self: win32more.Windows.UI.Xaml.Controls.IWebViewNavigationFailedEventArgs) -> win32more.Windows.Web.WebErrorStatus: ...
    Uri = property(get_Uri, None)
    WebErrorStatus = property(get_WebErrorStatus, None)
class WebViewNavigationFailedEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a31eafe1-41dc-47f8-ae22-9706c8f143d4}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Controls.WebViewNavigationFailedEventArgs) -> Void: ...
class WebViewNavigationStartingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IWebViewNavigationStartingEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.WebViewNavigationStartingEventArgs'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.UI.Xaml.Controls.IWebViewNavigationStartingEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Windows.UI.Xaml.Controls.IWebViewNavigationStartingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Windows.UI.Xaml.Controls.IWebViewNavigationStartingEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    Uri = property(get_Uri, None)
class WebViewNewWindowRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IWebViewNewWindowRequestedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.WebViewNewWindowRequestedEventArgs'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.UI.Xaml.Controls.IWebViewNewWindowRequestedEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_Referrer(self: win32more.Windows.UI.Xaml.Controls.IWebViewNewWindowRequestedEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_Handled(self: win32more.Windows.UI.Xaml.Controls.IWebViewNewWindowRequestedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Windows.UI.Xaml.Controls.IWebViewNewWindowRequestedEventArgs, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
    Referrer = property(get_Referrer, None)
    Uri = property(get_Uri, None)
class WebViewPermissionRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IWebViewPermissionRequest
    _classid_ = 'Windows.UI.Xaml.Controls.WebViewPermissionRequest'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.UI.Xaml.Controls.IWebViewPermissionRequest) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_PermissionType(self: win32more.Windows.UI.Xaml.Controls.IWebViewPermissionRequest) -> win32more.Windows.UI.Xaml.Controls.WebViewPermissionType: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.UI.Xaml.Controls.IWebViewPermissionRequest) -> UInt32: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.UI.Xaml.Controls.IWebViewPermissionRequest) -> win32more.Windows.UI.Xaml.Controls.WebViewPermissionState: ...
    @winrt_mixinmethod
    def Defer(self: win32more.Windows.UI.Xaml.Controls.IWebViewPermissionRequest) -> Void: ...
    @winrt_mixinmethod
    def Allow(self: win32more.Windows.UI.Xaml.Controls.IWebViewPermissionRequest) -> Void: ...
    @winrt_mixinmethod
    def Deny(self: win32more.Windows.UI.Xaml.Controls.IWebViewPermissionRequest) -> Void: ...
    Id = property(get_Id, None)
    PermissionType = property(get_PermissionType, None)
    State = property(get_State, None)
    Uri = property(get_Uri, None)
class WebViewPermissionRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IWebViewPermissionRequestedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.WebViewPermissionRequestedEventArgs'
    @winrt_mixinmethod
    def get_PermissionRequest(self: win32more.Windows.UI.Xaml.Controls.IWebViewPermissionRequestedEventArgs) -> win32more.Windows.UI.Xaml.Controls.WebViewPermissionRequest: ...
    PermissionRequest = property(get_PermissionRequest, None)
class WebViewPermissionState(Enum, Int32):
    Unknown = 0
    Defer = 1
    Allow = 2
    Deny = 3
class WebViewPermissionType(Enum, Int32):
    Geolocation = 0
    UnlimitedIndexedDBQuota = 1
    Media = 2
    PointerLock = 3
    WebNotifications = 4
    Screen = 5
    ImmersiveView = 6
class WebViewSeparateProcessLostEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IWebViewSeparateProcessLostEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.WebViewSeparateProcessLostEventArgs'
class WebViewSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IWebViewSettings
    _classid_ = 'Windows.UI.Xaml.Controls.WebViewSettings'
    @winrt_mixinmethod
    def get_IsJavaScriptEnabled(self: win32more.Windows.UI.Xaml.Controls.IWebViewSettings) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsJavaScriptEnabled(self: win32more.Windows.UI.Xaml.Controls.IWebViewSettings, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsIndexedDBEnabled(self: win32more.Windows.UI.Xaml.Controls.IWebViewSettings) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsIndexedDBEnabled(self: win32more.Windows.UI.Xaml.Controls.IWebViewSettings, value: Boolean) -> Void: ...
    IsIndexedDBEnabled = property(get_IsIndexedDBEnabled, put_IsIndexedDBEnabled)
    IsJavaScriptEnabled = property(get_IsJavaScriptEnabled, put_IsJavaScriptEnabled)
class WebViewUnsupportedUriSchemeIdentifiedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IWebViewUnsupportedUriSchemeIdentifiedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.WebViewUnsupportedUriSchemeIdentifiedEventArgs'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.UI.Xaml.Controls.IWebViewUnsupportedUriSchemeIdentifiedEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_Handled(self: win32more.Windows.UI.Xaml.Controls.IWebViewUnsupportedUriSchemeIdentifiedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Windows.UI.Xaml.Controls.IWebViewUnsupportedUriSchemeIdentifiedEventArgs, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
    Uri = property(get_Uri, None)
class WebViewUnviewableContentIdentifiedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IWebViewUnviewableContentIdentifiedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.WebViewUnviewableContentIdentifiedEventArgs'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.UI.Xaml.Controls.IWebViewUnviewableContentIdentifiedEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_Referrer(self: win32more.Windows.UI.Xaml.Controls.IWebViewUnviewableContentIdentifiedEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_MediaType(self: win32more.Windows.UI.Xaml.Controls.IWebViewUnviewableContentIdentifiedEventArgs2) -> WinRT_String: ...
    MediaType = property(get_MediaType, None)
    Referrer = property(get_Referrer, None)
    Uri = property(get_Uri, None)
class WebViewWebResourceRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Controls.IWebViewWebResourceRequestedEventArgs
    _classid_ = 'Windows.UI.Xaml.Controls.WebViewWebResourceRequestedEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.UI.Xaml.Controls.IWebViewWebResourceRequestedEventArgs) -> win32more.Windows.Web.Http.HttpRequestMessage: ...
    @winrt_mixinmethod
    def get_Response(self: win32more.Windows.UI.Xaml.Controls.IWebViewWebResourceRequestedEventArgs) -> win32more.Windows.Web.Http.HttpResponseMessage: ...
    @winrt_mixinmethod
    def put_Response(self: win32more.Windows.UI.Xaml.Controls.IWebViewWebResourceRequestedEventArgs, value: win32more.Windows.Web.Http.HttpResponseMessage) -> Void: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.UI.Xaml.Controls.IWebViewWebResourceRequestedEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
    Response = property(get_Response, put_Response)
class _WrapGrid_Meta_(ComPtr.__class__):
    pass
class WrapGrid(ComPtr, metaclass=_WrapGrid_Meta_):
    extends: win32more.Windows.UI.Xaml.Controls.Primitives.OrientedVirtualizingPanel
    default_interface: win32more.Windows.UI.Xaml.Controls.IWrapGrid
    _classid_ = 'Windows.UI.Xaml.Controls.WrapGrid'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Controls.WrapGrid.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Controls.WrapGrid: ...
    @winrt_mixinmethod
    def get_ItemWidth(self: win32more.Windows.UI.Xaml.Controls.IWrapGrid) -> Double: ...
    @winrt_mixinmethod
    def put_ItemWidth(self: win32more.Windows.UI.Xaml.Controls.IWrapGrid, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ItemHeight(self: win32more.Windows.UI.Xaml.Controls.IWrapGrid) -> Double: ...
    @winrt_mixinmethod
    def put_ItemHeight(self: win32more.Windows.UI.Xaml.Controls.IWrapGrid, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Windows.UI.Xaml.Controls.IWrapGrid) -> win32more.Windows.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Windows.UI.Xaml.Controls.IWrapGrid, value: win32more.Windows.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalChildrenAlignment(self: win32more.Windows.UI.Xaml.Controls.IWrapGrid) -> win32more.Windows.UI.Xaml.HorizontalAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalChildrenAlignment(self: win32more.Windows.UI.Xaml.Controls.IWrapGrid, value: win32more.Windows.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalChildrenAlignment(self: win32more.Windows.UI.Xaml.Controls.IWrapGrid) -> win32more.Windows.UI.Xaml.VerticalAlignment: ...
    @winrt_mixinmethod
    def put_VerticalChildrenAlignment(self: win32more.Windows.UI.Xaml.Controls.IWrapGrid, value: win32more.Windows.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_MaximumRowsOrColumns(self: win32more.Windows.UI.Xaml.Controls.IWrapGrid) -> Int32: ...
    @winrt_mixinmethod
    def put_MaximumRowsOrColumns(self: win32more.Windows.UI.Xaml.Controls.IWrapGrid, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_ItemWidthProperty(cls: win32more.Windows.UI.Xaml.Controls.IWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemHeightProperty(cls: win32more.Windows.UI.Xaml.Controls.IWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Windows.UI.Xaml.Controls.IWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalChildrenAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalChildrenAlignmentProperty(cls: win32more.Windows.UI.Xaml.Controls.IWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaximumRowsOrColumnsProperty(cls: win32more.Windows.UI.Xaml.Controls.IWrapGridStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    HorizontalChildrenAlignment = property(get_HorizontalChildrenAlignment, put_HorizontalChildrenAlignment)
    ItemHeight = property(get_ItemHeight, put_ItemHeight)
    ItemWidth = property(get_ItemWidth, put_ItemWidth)
    MaximumRowsOrColumns = property(get_MaximumRowsOrColumns, put_MaximumRowsOrColumns)
    Orientation = property(get_Orientation, put_Orientation)
    VerticalChildrenAlignment = property(get_VerticalChildrenAlignment, put_VerticalChildrenAlignment)
    _WrapGrid_Meta_.HorizontalChildrenAlignmentProperty = property(get_HorizontalChildrenAlignmentProperty, None)
    _WrapGrid_Meta_.ItemHeightProperty = property(get_ItemHeightProperty, None)
    _WrapGrid_Meta_.ItemWidthProperty = property(get_ItemWidthProperty, None)
    _WrapGrid_Meta_.MaximumRowsOrColumnsProperty = property(get_MaximumRowsOrColumnsProperty, None)
    _WrapGrid_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _WrapGrid_Meta_.VerticalChildrenAlignmentProperty = property(get_VerticalChildrenAlignmentProperty, None)
class ZoomMode(Enum, Int32):
    Disabled = 0
    Enabled = 1


make_ready(__name__)
