from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Gdi
class ABC(Structure):
    abcA: Int32
    abcB: UInt32
    abcC: Int32
class ABCFLOAT(Structure):
    abcfA: Single
    abcfB: Single
    abcfC: Single
class ABORTPATH(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
ARC_DIRECTION = Int32
AD_COUNTERCLOCKWISE: win32more.Windows.Win32.Graphics.Gdi.ARC_DIRECTION = 1
AD_CLOCKWISE: win32more.Windows.Win32.Graphics.Gdi.ARC_DIRECTION = 2
class AXESLISTA(Structure):
    axlReserved: UInt32
    axlNumAxes: UInt32
    axlAxisInfo: win32more.Windows.Win32.Graphics.Gdi.AXISINFOA * 16
class AXESLISTW(Structure):
    axlReserved: UInt32
    axlNumAxes: UInt32
    axlAxisInfo: win32more.Windows.Win32.Graphics.Gdi.AXISINFOW * 16
AXESLIST = UnicodeAlias('AXESLISTW')
class AXISINFOA(Structure):
    axMinValue: Int32
    axMaxValue: Int32
    axAxisName: Byte * 16
class AXISINFOW(Structure):
    axMinValue: Int32
    axMaxValue: Int32
    axAxisName: Char * 16
AXISINFO = UnicodeAlias('AXISINFOW')
GDI_ERROR: Int32 = -1
ERROR: Int32 = 0
MAXSTRETCHBLTMODE: UInt32 = 4
POLYFILL_LAST: UInt32 = 2
LAYOUT_BTT: UInt32 = 2
LAYOUT_VBH: UInt32 = 4
ASPECT_FILTERING: UInt32 = 1
META_SETBKCOLOR: UInt32 = 513
META_SETBKMODE: UInt32 = 258
META_SETMAPMODE: UInt32 = 259
META_SETROP2: UInt32 = 260
META_SETRELABS: UInt32 = 261
META_SETPOLYFILLMODE: UInt32 = 262
META_SETSTRETCHBLTMODE: UInt32 = 263
META_SETTEXTCHAREXTRA: UInt32 = 264
META_SETTEXTCOLOR: UInt32 = 521
META_SETTEXTJUSTIFICATION: UInt32 = 522
META_SETWINDOWORG: UInt32 = 523
META_SETWINDOWEXT: UInt32 = 524
META_SETVIEWPORTORG: UInt32 = 525
META_SETVIEWPORTEXT: UInt32 = 526
META_OFFSETWINDOWORG: UInt32 = 527
META_SCALEWINDOWEXT: UInt32 = 1040
META_OFFSETVIEWPORTORG: UInt32 = 529
META_SCALEVIEWPORTEXT: UInt32 = 1042
META_LINETO: UInt32 = 531
META_MOVETO: UInt32 = 532
META_EXCLUDECLIPRECT: UInt32 = 1045
META_INTERSECTCLIPRECT: UInt32 = 1046
META_ARC: UInt32 = 2071
META_ELLIPSE: UInt32 = 1048
META_FLOODFILL: UInt32 = 1049
META_PIE: UInt32 = 2074
META_RECTANGLE: UInt32 = 1051
META_ROUNDRECT: UInt32 = 1564
META_PATBLT: UInt32 = 1565
META_SAVEDC: UInt32 = 30
META_SETPIXEL: UInt32 = 1055
META_OFFSETCLIPRGN: UInt32 = 544
META_TEXTOUT: UInt32 = 1313
META_BITBLT: UInt32 = 2338
META_STRETCHBLT: UInt32 = 2851
META_POLYGON: UInt32 = 804
META_POLYLINE: UInt32 = 805
META_ESCAPE: UInt32 = 1574
META_RESTOREDC: UInt32 = 295
META_FILLREGION: UInt32 = 552
META_FRAMEREGION: UInt32 = 1065
META_INVERTREGION: UInt32 = 298
META_PAINTREGION: UInt32 = 299
META_SELECTCLIPREGION: UInt32 = 300
META_SELECTOBJECT: UInt32 = 301
META_SETTEXTALIGN: UInt32 = 302
META_CHORD: UInt32 = 2096
META_SETMAPPERFLAGS: UInt32 = 561
META_EXTTEXTOUT: UInt32 = 2610
META_SETDIBTODEV: UInt32 = 3379
META_SELECTPALETTE: UInt32 = 564
META_REALIZEPALETTE: UInt32 = 53
META_ANIMATEPALETTE: UInt32 = 1078
META_SETPALENTRIES: UInt32 = 55
META_POLYPOLYGON: UInt32 = 1336
META_RESIZEPALETTE: UInt32 = 313
META_DIBBITBLT: UInt32 = 2368
META_DIBSTRETCHBLT: UInt32 = 2881
META_DIBCREATEPATTERNBRUSH: UInt32 = 322
META_STRETCHDIB: UInt32 = 3907
META_EXTFLOODFILL: UInt32 = 1352
META_SETLAYOUT: UInt32 = 329
META_DELETEOBJECT: UInt32 = 496
META_CREATEPALETTE: UInt32 = 247
META_CREATEPATTERNBRUSH: UInt32 = 505
META_CREATEPENINDIRECT: UInt32 = 762
META_CREATEFONTINDIRECT: UInt32 = 763
META_CREATEBRUSHINDIRECT: UInt32 = 764
META_CREATEREGION: UInt32 = 1791
NEWFRAME: UInt32 = 1
ABORTDOC: UInt32 = 2
NEXTBAND: UInt32 = 3
SETCOLORTABLE: UInt32 = 4
GETCOLORTABLE: UInt32 = 5
FLUSHOUTPUT: UInt32 = 6
DRAFTMODE: UInt32 = 7
QUERYESCSUPPORT: UInt32 = 8
SETABORTPROC: UInt32 = 9
STARTDOC: UInt32 = 10
ENDDOC: UInt32 = 11
GETPHYSPAGESIZE: UInt32 = 12
GETPRINTINGOFFSET: UInt32 = 13
GETSCALINGFACTOR: UInt32 = 14
MFCOMMENT: UInt32 = 15
GETPENWIDTH: UInt32 = 16
SETCOPYCOUNT: UInt32 = 17
SELECTPAPERSOURCE: UInt32 = 18
DEVICEDATA: UInt32 = 19
PASSTHROUGH: UInt32 = 19
GETTECHNOLGY: UInt32 = 20
GETTECHNOLOGY: UInt32 = 20
SETLINECAP: UInt32 = 21
SETLINEJOIN: UInt32 = 22
SETMITERLIMIT: UInt32 = 23
BANDINFO: UInt32 = 24
DRAWPATTERNRECT: UInt32 = 25
GETVECTORPENSIZE: UInt32 = 26
GETVECTORBRUSHSIZE: UInt32 = 27
ENABLEDUPLEX: UInt32 = 28
GETSETPAPERBINS: UInt32 = 29
GETSETPRINTORIENT: UInt32 = 30
ENUMPAPERBINS: UInt32 = 31
SETDIBSCALING: UInt32 = 32
EPSPRINTING: UInt32 = 33
ENUMPAPERMETRICS: UInt32 = 34
GETSETPAPERMETRICS: UInt32 = 35
POSTSCRIPT_DATA: UInt32 = 37
POSTSCRIPT_IGNORE: UInt32 = 38
MOUSETRAILS: UInt32 = 39
GETDEVICEUNITS: UInt32 = 42
GETEXTENDEDTEXTMETRICS: UInt32 = 256
GETEXTENTTABLE: UInt32 = 257
GETPAIRKERNTABLE: UInt32 = 258
GETTRACKKERNTABLE: UInt32 = 259
EXTTEXTOUT: UInt32 = 512
GETFACENAME: UInt32 = 513
DOWNLOADFACE: UInt32 = 514
ENABLERELATIVEWIDTHS: UInt32 = 768
ENABLEPAIRKERNING: UInt32 = 769
SETKERNTRACK: UInt32 = 770
SETALLJUSTVALUES: UInt32 = 771
SETCHARSET: UInt32 = 772
STRETCHBLT: UInt32 = 2048
METAFILE_DRIVER: UInt32 = 2049
GETSETSCREENPARAMS: UInt32 = 3072
QUERYDIBSUPPORT: UInt32 = 3073
BEGIN_PATH: UInt32 = 4096
CLIP_TO_PATH: UInt32 = 4097
END_PATH: UInt32 = 4098
EXT_DEVICE_CAPS: UInt32 = 4099
RESTORE_CTM: UInt32 = 4100
SAVE_CTM: UInt32 = 4101
SET_ARC_DIRECTION: UInt32 = 4102
SET_BACKGROUND_COLOR: UInt32 = 4103
SET_POLY_MODE: UInt32 = 4104
SET_SCREEN_ANGLE: UInt32 = 4105
SET_SPREAD: UInt32 = 4106
TRANSFORM_CTM: UInt32 = 4107
SET_CLIP_BOX: UInt32 = 4108
SET_BOUNDS: UInt32 = 4109
SET_MIRROR_MODE: UInt32 = 4110
OPENCHANNEL: UInt32 = 4110
DOWNLOADHEADER: UInt32 = 4111
CLOSECHANNEL: UInt32 = 4112
POSTSCRIPT_PASSTHROUGH: UInt32 = 4115
ENCAPSULATED_POSTSCRIPT: UInt32 = 4116
POSTSCRIPT_IDENTIFY: UInt32 = 4117
POSTSCRIPT_INJECTION: UInt32 = 4118
CHECKJPEGFORMAT: UInt32 = 4119
CHECKPNGFORMAT: UInt32 = 4120
GET_PS_FEATURESETTING: UInt32 = 4121
GDIPLUS_TS_QUERYVER: UInt32 = 4122
GDIPLUS_TS_RECORD: UInt32 = 4123
MILCORE_TS_QUERYVER_RESULT_FALSE: UInt32 = 0
MILCORE_TS_QUERYVER_RESULT_TRUE: UInt32 = 2147483647
SPCLPASSTHROUGH2: UInt32 = 4568
PSIDENT_GDICENTRIC: UInt32 = 0
PSIDENT_PSCENTRIC: UInt32 = 1
PSINJECT_DLFONT: UInt32 = 3722304989
FEATURESETTING_NUP: UInt32 = 0
FEATURESETTING_OUTPUT: UInt32 = 1
FEATURESETTING_PSLEVEL: UInt32 = 2
FEATURESETTING_CUSTPAPER: UInt32 = 3
FEATURESETTING_MIRROR: UInt32 = 4
FEATURESETTING_NEGATIVE: UInt32 = 5
FEATURESETTING_PROTOCOL: UInt32 = 6
FEATURESETTING_PRIVATE_BEGIN: UInt32 = 4096
FEATURESETTING_PRIVATE_END: UInt32 = 8191
PSPROTOCOL_ASCII: UInt32 = 0
PSPROTOCOL_BCP: UInt32 = 1
PSPROTOCOL_TBCP: UInt32 = 2
PSPROTOCOL_BINARY: UInt32 = 3
QDI_SETDIBITS: UInt32 = 1
QDI_GETDIBITS: UInt32 = 2
QDI_DIBTOSCREEN: UInt32 = 4
QDI_STRETCHDIB: UInt32 = 8
SP_NOTREPORTED: UInt32 = 16384
SP_ERROR: Int32 = -1
SP_APPABORT: Int32 = -2
SP_USERABORT: Int32 = -3
SP_OUTOFDISK: Int32 = -4
SP_OUTOFMEMORY: Int32 = -5
PR_JOBSTATUS: UInt32 = 0
LCS_GM_BUSINESS: Int32 = 1
LCS_GM_GRAPHICS: Int32 = 2
LCS_GM_IMAGES: Int32 = 4
LCS_GM_ABS_COLORIMETRIC: Int32 = 8
CM_OUT_OF_GAMUT: UInt32 = 255
CM_IN_GAMUT: UInt32 = 0
NTM_REGULAR: Int32 = 64
NTM_BOLD: Int32 = 32
NTM_ITALIC: Int32 = 1
NTM_NONNEGATIVE_AC: UInt32 = 65536
NTM_PS_OPENTYPE: UInt32 = 131072
NTM_TT_OPENTYPE: UInt32 = 262144
NTM_MULTIPLEMASTER: UInt32 = 524288
NTM_TYPE1: UInt32 = 1048576
NTM_DSIG: UInt32 = 2097152
LF_FACESIZE: UInt32 = 32
LF_FULLFACESIZE: UInt32 = 64
CLEARTYPE_NATURAL_QUALITY: UInt32 = 6
MONO_FONT: UInt32 = 8
FS_LATIN1: Int32 = 1
FS_LATIN2: Int32 = 2
FS_CYRILLIC: Int32 = 4
FS_GREEK: Int32 = 8
FS_TURKISH: Int32 = 16
FS_HEBREW: Int32 = 32
FS_ARABIC: Int32 = 64
FS_BALTIC: Int32 = 128
FS_VIETNAMESE: Int32 = 256
FS_THAI: Int32 = 65536
FS_JISJAPAN: Int32 = 131072
FS_CHINESESIMP: Int32 = 262144
FS_WANSUNG: Int32 = 524288
FS_CHINESETRAD: Int32 = 1048576
FS_JOHAB: Int32 = 2097152
FS_SYMBOL: Int32 = -2147483648
PANOSE_COUNT: UInt32 = 10
PAN_FAMILYTYPE_INDEX: UInt32 = 0
PAN_SERIFSTYLE_INDEX: UInt32 = 1
PAN_PROPORTION_INDEX: UInt32 = 3
PAN_STROKEVARIATION_INDEX: UInt32 = 5
PAN_ARMSTYLE_INDEX: UInt32 = 6
PAN_LETTERFORM_INDEX: UInt32 = 7
PAN_CULTURE_LATIN: UInt32 = 0
PAN_ANY: UInt32 = 0
PAN_NO_FIT: UInt32 = 1
ELF_VENDOR_SIZE: UInt32 = 4
ELF_VERSION: UInt32 = 0
ELF_CULTURE_LATIN: UInt32 = 0
RASTER_FONTTYPE: UInt32 = 1
DEVICE_FONTTYPE: UInt32 = 2
TRUETYPE_FONTTYPE: UInt32 = 4
PC_RESERVED: UInt32 = 1
PC_EXPLICIT: UInt32 = 2
PC_NOCOLLAPSE: UInt32 = 4
BKMODE_LAST: UInt32 = 2
GM_LAST: UInt32 = 2
PT_CLOSEFIGURE: UInt32 = 1
PT_LINETO: UInt32 = 2
PT_BEZIERTO: UInt32 = 4
PT_MOVETO: UInt32 = 6
ABSOLUTE: UInt32 = 1
RELATIVE: UInt32 = 2
STOCK_LAST: UInt32 = 19
CLR_INVALID: UInt32 = 4294967295
HS_API_MAX: UInt32 = 12
DT_PLOTTER: UInt32 = 0
DT_RASDISPLAY: UInt32 = 1
DT_RASPRINTER: UInt32 = 2
DT_RASCAMERA: UInt32 = 3
DT_CHARSTREAM: UInt32 = 4
DT_METAFILE: UInt32 = 5
DT_DISPFILE: UInt32 = 6
CC_NONE: UInt32 = 0
CC_CIRCLES: UInt32 = 1
CC_PIE: UInt32 = 2
CC_CHORD: UInt32 = 4
CC_ELLIPSES: UInt32 = 8
CC_WIDE: UInt32 = 16
CC_STYLED: UInt32 = 32
CC_WIDESTYLED: UInt32 = 64
CC_INTERIORS: UInt32 = 128
CC_ROUNDRECT: UInt32 = 256
LC_NONE: UInt32 = 0
LC_POLYLINE: UInt32 = 2
LC_MARKER: UInt32 = 4
LC_POLYMARKER: UInt32 = 8
LC_WIDE: UInt32 = 16
LC_STYLED: UInt32 = 32
LC_WIDESTYLED: UInt32 = 64
LC_INTERIORS: UInt32 = 128
PC_NONE: UInt32 = 0
PC_POLYGON: UInt32 = 1
PC_RECTANGLE: UInt32 = 2
PC_WINDPOLYGON: UInt32 = 4
PC_TRAPEZOID: UInt32 = 4
PC_SCANLINE: UInt32 = 8
PC_WIDE: UInt32 = 16
PC_STYLED: UInt32 = 32
PC_WIDESTYLED: UInt32 = 64
PC_INTERIORS: UInt32 = 128
PC_POLYPOLYGON: UInt32 = 256
PC_PATHS: UInt32 = 512
CP_NONE: UInt32 = 0
CP_RECTANGLE: UInt32 = 1
CP_REGION: UInt32 = 2
TC_OP_CHARACTER: UInt32 = 1
TC_OP_STROKE: UInt32 = 2
TC_CP_STROKE: UInt32 = 4
TC_CR_90: UInt32 = 8
TC_CR_ANY: UInt32 = 16
TC_SF_X_YINDEP: UInt32 = 32
TC_SA_DOUBLE: UInt32 = 64
TC_SA_INTEGER: UInt32 = 128
TC_SA_CONTIN: UInt32 = 256
TC_EA_DOUBLE: UInt32 = 512
TC_IA_ABLE: UInt32 = 1024
TC_UA_ABLE: UInt32 = 2048
TC_SO_ABLE: UInt32 = 4096
TC_RA_ABLE: UInt32 = 8192
TC_VA_ABLE: UInt32 = 16384
TC_RESERVED: UInt32 = 32768
TC_SCROLLBLT: UInt32 = 65536
RC_BITBLT: UInt32 = 1
RC_BANDING: UInt32 = 2
RC_SCALING: UInt32 = 4
RC_BITMAP64: UInt32 = 8
RC_GDI20_OUTPUT: UInt32 = 16
RC_GDI20_STATE: UInt32 = 32
RC_SAVEBITMAP: UInt32 = 64
RC_DI_BITMAP: UInt32 = 128
RC_PALETTE: UInt32 = 256
RC_DIBTODEV: UInt32 = 512
RC_BIGFONT: UInt32 = 1024
RC_STRETCHBLT: UInt32 = 2048
RC_FLOODFILL: UInt32 = 4096
RC_STRETCHDIB: UInt32 = 8192
RC_OP_DX_OUTPUT: UInt32 = 16384
RC_DEVBITS: UInt32 = 32768
SB_NONE: UInt32 = 0
SB_CONST_ALPHA: UInt32 = 1
SB_PIXEL_ALPHA: UInt32 = 2
SB_PREMULT_ALPHA: UInt32 = 4
SB_GRAD_RECT: UInt32 = 16
SB_GRAD_TRI: UInt32 = 32
CM_NONE: UInt32 = 0
CM_DEVICE_ICM: UInt32 = 1
CM_GAMMA_RAMP: UInt32 = 2
CM_CMYK_COLOR: UInt32 = 4
SYSPAL_ERROR: UInt32 = 0
CBM_INIT: Int32 = 4
CCHFORMNAME: UInt32 = 32
DMORIENT_PORTRAIT: UInt32 = 1
DMORIENT_LANDSCAPE: UInt32 = 2
DMPAPER_LETTER: UInt32 = 1
DMPAPER_LETTERSMALL: UInt32 = 2
DMPAPER_TABLOID: UInt32 = 3
DMPAPER_LEDGER: UInt32 = 4
DMPAPER_LEGAL: UInt32 = 5
DMPAPER_STATEMENT: UInt32 = 6
DMPAPER_EXECUTIVE: UInt32 = 7
DMPAPER_A3: UInt32 = 8
DMPAPER_A4: UInt32 = 9
DMPAPER_A4SMALL: UInt32 = 10
DMPAPER_A5: UInt32 = 11
DMPAPER_B4: UInt32 = 12
DMPAPER_B5: UInt32 = 13
DMPAPER_FOLIO: UInt32 = 14
DMPAPER_QUARTO: UInt32 = 15
DMPAPER_10X14: UInt32 = 16
DMPAPER_11X17: UInt32 = 17
DMPAPER_NOTE: UInt32 = 18
DMPAPER_ENV_9: UInt32 = 19
DMPAPER_ENV_10: UInt32 = 20
DMPAPER_ENV_11: UInt32 = 21
DMPAPER_ENV_12: UInt32 = 22
DMPAPER_ENV_14: UInt32 = 23
DMPAPER_CSHEET: UInt32 = 24
DMPAPER_DSHEET: UInt32 = 25
DMPAPER_ESHEET: UInt32 = 26
DMPAPER_ENV_DL: UInt32 = 27
DMPAPER_ENV_C5: UInt32 = 28
DMPAPER_ENV_C3: UInt32 = 29
DMPAPER_ENV_C4: UInt32 = 30
DMPAPER_ENV_C6: UInt32 = 31
DMPAPER_ENV_C65: UInt32 = 32
DMPAPER_ENV_B4: UInt32 = 33
DMPAPER_ENV_B5: UInt32 = 34
DMPAPER_ENV_B6: UInt32 = 35
DMPAPER_ENV_ITALY: UInt32 = 36
DMPAPER_ENV_MONARCH: UInt32 = 37
DMPAPER_ENV_PERSONAL: UInt32 = 38
DMPAPER_FANFOLD_US: UInt32 = 39
DMPAPER_FANFOLD_STD_GERMAN: UInt32 = 40
DMPAPER_FANFOLD_LGL_GERMAN: UInt32 = 41
DMPAPER_ISO_B4: UInt32 = 42
DMPAPER_JAPANESE_POSTCARD: UInt32 = 43
DMPAPER_9X11: UInt32 = 44
DMPAPER_10X11: UInt32 = 45
DMPAPER_15X11: UInt32 = 46
DMPAPER_ENV_INVITE: UInt32 = 47
DMPAPER_RESERVED_48: UInt32 = 48
DMPAPER_RESERVED_49: UInt32 = 49
DMPAPER_LETTER_EXTRA: UInt32 = 50
DMPAPER_LEGAL_EXTRA: UInt32 = 51
DMPAPER_TABLOID_EXTRA: UInt32 = 52
DMPAPER_A4_EXTRA: UInt32 = 53
DMPAPER_LETTER_TRANSVERSE: UInt32 = 54
DMPAPER_A4_TRANSVERSE: UInt32 = 55
DMPAPER_LETTER_EXTRA_TRANSVERSE: UInt32 = 56
DMPAPER_A_PLUS: UInt32 = 57
DMPAPER_B_PLUS: UInt32 = 58
DMPAPER_LETTER_PLUS: UInt32 = 59
DMPAPER_A4_PLUS: UInt32 = 60
DMPAPER_A5_TRANSVERSE: UInt32 = 61
DMPAPER_B5_TRANSVERSE: UInt32 = 62
DMPAPER_A3_EXTRA: UInt32 = 63
DMPAPER_A5_EXTRA: UInt32 = 64
DMPAPER_B5_EXTRA: UInt32 = 65
DMPAPER_A2: UInt32 = 66
DMPAPER_A3_TRANSVERSE: UInt32 = 67
DMPAPER_A3_EXTRA_TRANSVERSE: UInt32 = 68
DMPAPER_DBL_JAPANESE_POSTCARD: UInt32 = 69
DMPAPER_A6: UInt32 = 70
DMPAPER_JENV_KAKU2: UInt32 = 71
DMPAPER_JENV_KAKU3: UInt32 = 72
DMPAPER_JENV_CHOU3: UInt32 = 73
DMPAPER_JENV_CHOU4: UInt32 = 74
DMPAPER_LETTER_ROTATED: UInt32 = 75
DMPAPER_A3_ROTATED: UInt32 = 76
DMPAPER_A4_ROTATED: UInt32 = 77
DMPAPER_A5_ROTATED: UInt32 = 78
DMPAPER_B4_JIS_ROTATED: UInt32 = 79
DMPAPER_B5_JIS_ROTATED: UInt32 = 80
DMPAPER_JAPANESE_POSTCARD_ROTATED: UInt32 = 81
DMPAPER_DBL_JAPANESE_POSTCARD_ROTATED: UInt32 = 82
DMPAPER_A6_ROTATED: UInt32 = 83
DMPAPER_JENV_KAKU2_ROTATED: UInt32 = 84
DMPAPER_JENV_KAKU3_ROTATED: UInt32 = 85
DMPAPER_JENV_CHOU3_ROTATED: UInt32 = 86
DMPAPER_JENV_CHOU4_ROTATED: UInt32 = 87
DMPAPER_B6_JIS: UInt32 = 88
DMPAPER_B6_JIS_ROTATED: UInt32 = 89
DMPAPER_12X11: UInt32 = 90
DMPAPER_JENV_YOU4: UInt32 = 91
DMPAPER_JENV_YOU4_ROTATED: UInt32 = 92
DMPAPER_P16K: UInt32 = 93
DMPAPER_P32K: UInt32 = 94
DMPAPER_P32KBIG: UInt32 = 95
DMPAPER_PENV_1: UInt32 = 96
DMPAPER_PENV_2: UInt32 = 97
DMPAPER_PENV_3: UInt32 = 98
DMPAPER_PENV_4: UInt32 = 99
DMPAPER_PENV_5: UInt32 = 100
DMPAPER_PENV_6: UInt32 = 101
DMPAPER_PENV_7: UInt32 = 102
DMPAPER_PENV_8: UInt32 = 103
DMPAPER_PENV_9: UInt32 = 104
DMPAPER_PENV_10: UInt32 = 105
DMPAPER_P16K_ROTATED: UInt32 = 106
DMPAPER_P32K_ROTATED: UInt32 = 107
DMPAPER_P32KBIG_ROTATED: UInt32 = 108
DMPAPER_PENV_1_ROTATED: UInt32 = 109
DMPAPER_PENV_2_ROTATED: UInt32 = 110
DMPAPER_PENV_3_ROTATED: UInt32 = 111
DMPAPER_PENV_4_ROTATED: UInt32 = 112
DMPAPER_PENV_5_ROTATED: UInt32 = 113
DMPAPER_PENV_6_ROTATED: UInt32 = 114
DMPAPER_PENV_7_ROTATED: UInt32 = 115
DMPAPER_PENV_8_ROTATED: UInt32 = 116
DMPAPER_PENV_9_ROTATED: UInt32 = 117
DMPAPER_PENV_10_ROTATED: UInt32 = 118
DMPAPER_LAST: UInt32 = 118
DMPAPER_USER: UInt32 = 256
DMBIN_UPPER: UInt32 = 1
DMBIN_ONLYONE: UInt32 = 1
DMBIN_LOWER: UInt32 = 2
DMBIN_MIDDLE: UInt32 = 3
DMBIN_MANUAL: UInt32 = 4
DMBIN_ENVELOPE: UInt32 = 5
DMBIN_ENVMANUAL: UInt32 = 6
DMBIN_AUTO: UInt32 = 7
DMBIN_TRACTOR: UInt32 = 8
DMBIN_SMALLFMT: UInt32 = 9
DMBIN_LARGEFMT: UInt32 = 10
DMBIN_LARGECAPACITY: UInt32 = 11
DMBIN_CASSETTE: UInt32 = 14
DMBIN_FORMSOURCE: UInt32 = 15
DMBIN_LAST: UInt32 = 15
DMBIN_USER: UInt32 = 256
DMRES_DRAFT: Int32 = -1
DMRES_LOW: Int32 = -2
DMRES_MEDIUM: Int32 = -3
DMRES_HIGH: Int32 = -4
DMDISPLAYFLAGS_TEXTMODE: UInt32 = 4
DMNUP_SYSTEM: UInt32 = 1
DMNUP_ONEUP: UInt32 = 2
DMICMMETHOD_NONE: UInt32 = 1
DMICMMETHOD_SYSTEM: UInt32 = 2
DMICMMETHOD_DRIVER: UInt32 = 3
DMICMMETHOD_DEVICE: UInt32 = 4
DMICMMETHOD_USER: UInt32 = 256
DMICM_SATURATE: UInt32 = 1
DMICM_CONTRAST: UInt32 = 2
DMICM_COLORIMETRIC: UInt32 = 3
DMICM_ABS_COLORIMETRIC: UInt32 = 4
DMICM_USER: UInt32 = 256
DMMEDIA_STANDARD: UInt32 = 1
DMMEDIA_TRANSPARENCY: UInt32 = 2
DMMEDIA_GLOSSY: UInt32 = 3
DMMEDIA_USER: UInt32 = 256
DMDITHER_NONE: UInt32 = 1
DMDITHER_COARSE: UInt32 = 2
DMDITHER_FINE: UInt32 = 3
DMDITHER_LINEART: UInt32 = 4
DMDITHER_ERRORDIFFUSION: UInt32 = 5
DMDITHER_RESERVED6: UInt32 = 6
DMDITHER_RESERVED7: UInt32 = 7
DMDITHER_RESERVED8: UInt32 = 8
DMDITHER_RESERVED9: UInt32 = 9
DMDITHER_GRAYSCALE: UInt32 = 10
DMDITHER_USER: UInt32 = 256
DISPLAYCONFIG_MAXPATH: UInt32 = 1024
DISPLAYCONFIG_PATH_MODE_IDX_INVALID: UInt32 = 4294967295
DISPLAYCONFIG_PATH_TARGET_MODE_IDX_INVALID: UInt32 = 65535
DISPLAYCONFIG_PATH_DESKTOP_IMAGE_IDX_INVALID: UInt32 = 65535
DISPLAYCONFIG_PATH_SOURCE_MODE_IDX_INVALID: UInt32 = 65535
DISPLAYCONFIG_PATH_CLONE_GROUP_INVALID: UInt32 = 65535
DISPLAYCONFIG_SOURCE_IN_USE: UInt32 = 1
DISPLAYCONFIG_TARGET_IN_USE: UInt32 = 1
DISPLAYCONFIG_TARGET_FORCIBLE: UInt32 = 2
DISPLAYCONFIG_TARGET_FORCED_AVAILABILITY_BOOT: UInt32 = 4
DISPLAYCONFIG_TARGET_FORCED_AVAILABILITY_PATH: UInt32 = 8
DISPLAYCONFIG_TARGET_FORCED_AVAILABILITY_SYSTEM: UInt32 = 16
DISPLAYCONFIG_TARGET_IS_HMD: UInt32 = 32
DISPLAYCONFIG_PATH_ACTIVE: UInt32 = 1
DISPLAYCONFIG_PATH_PREFERRED_UNSCALED: UInt32 = 4
DISPLAYCONFIG_PATH_SUPPORT_VIRTUAL_MODE: UInt32 = 8
DISPLAYCONFIG_PATH_VALID_FLAGS: UInt32 = 29
RDH_RECTANGLES: UInt32 = 1
SYSRGN: UInt32 = 4
TT_POLYGON_TYPE: UInt32 = 24
TT_PRIM_LINE: UInt32 = 1
TT_PRIM_QSPLINE: UInt32 = 2
TT_PRIM_CSPLINE: UInt32 = 3
GCP_DBCS: UInt32 = 1
GCP_ERROR: UInt32 = 32768
FLI_MASK: UInt32 = 4155
FLI_GLYPHS: Int32 = 262144
GCP_JUSTIFYIN: Int32 = 2097152
GCPCLASS_LATIN: UInt32 = 1
GCPCLASS_HEBREW: UInt32 = 2
GCPCLASS_ARABIC: UInt32 = 2
GCPCLASS_NEUTRAL: UInt32 = 3
GCPCLASS_LOCALNUMBER: UInt32 = 4
GCPCLASS_LATINNUMBER: UInt32 = 5
GCPCLASS_LATINNUMERICTERMINATOR: UInt32 = 6
GCPCLASS_LATINNUMERICSEPARATOR: UInt32 = 7
GCPCLASS_NUMERICSEPARATOR: UInt32 = 8
GCPCLASS_PREBOUNDLTR: UInt32 = 128
GCPCLASS_PREBOUNDRTL: UInt32 = 64
GCPCLASS_POSTBOUNDLTR: UInt32 = 32
GCPCLASS_POSTBOUNDRTL: UInt32 = 16
GCPGLYPH_LINKBEFORE: UInt32 = 32768
GCPGLYPH_LINKAFTER: UInt32 = 16384
TT_AVAILABLE: UInt32 = 1
TT_ENABLED: UInt32 = 2
DC_BINADJUST: UInt32 = 19
DC_EMF_COMPLIANT: UInt32 = 20
DC_DATATYPE_PRODUCED: UInt32 = 21
DC_MANUFACTURER: UInt32 = 23
DC_MODEL: UInt32 = 24
PRINTRATEUNIT_PPM: UInt32 = 1
PRINTRATEUNIT_CPS: UInt32 = 2
PRINTRATEUNIT_LPM: UInt32 = 3
PRINTRATEUNIT_IPM: UInt32 = 4
DCTT_BITMAP: Int32 = 1
DCTT_DOWNLOAD: Int32 = 2
DCTT_SUBDEV: Int32 = 4
DCTT_DOWNLOAD_OUTLINE: Int32 = 8
DCBA_FACEUPNONE: UInt32 = 0
DCBA_FACEUPCENTER: UInt32 = 1
DCBA_FACEUPLEFT: UInt32 = 2
DCBA_FACEUPRIGHT: UInt32 = 3
DCBA_FACEDOWNNONE: UInt32 = 256
DCBA_FACEDOWNCENTER: UInt32 = 257
DCBA_FACEDOWNLEFT: UInt32 = 258
DCBA_FACEDOWNRIGHT: UInt32 = 259
GS_8BIT_INDICES: UInt32 = 1
GGI_MARK_NONEXISTING_GLYPHS: UInt32 = 1
MM_MAX_NUMAXES: UInt32 = 16
MM_MAX_AXES_NAMELEN: UInt32 = 16
GDIREGISTERDDRAWPACKETVERSION: UInt32 = 1
AC_SRC_OVER: UInt32 = 0
AC_SRC_ALPHA: UInt32 = 1
GRADIENT_FILL_OP_FLAG: UInt32 = 255
CA_NEGATIVE: UInt32 = 1
CA_LOG_FILTER: UInt32 = 2
ILLUMINANT_DEVICE_DEFAULT: UInt32 = 0
ILLUMINANT_A: UInt32 = 1
ILLUMINANT_B: UInt32 = 2
ILLUMINANT_C: UInt32 = 3
ILLUMINANT_D50: UInt32 = 4
ILLUMINANT_D55: UInt32 = 5
ILLUMINANT_D65: UInt32 = 6
ILLUMINANT_D75: UInt32 = 7
ILLUMINANT_F2: UInt32 = 8
ILLUMINANT_MAX_INDEX: UInt32 = 8
ILLUMINANT_TUNGSTEN: UInt32 = 1
ILLUMINANT_DAYLIGHT: UInt32 = 3
ILLUMINANT_FLUORESCENT: UInt32 = 8
ILLUMINANT_NTSC: UInt32 = 3
DI_APPBANDING: UInt32 = 1
DI_ROPS_READ_DESTINATION: UInt32 = 2
FONTMAPPER_MAX: UInt32 = 10
ENHMETA_SIGNATURE: UInt32 = 1179469088
ENHMETA_STOCK_OBJECT: UInt32 = 2147483648
SETICMPROFILE_EMBEDED: UInt32 = 1
CREATECOLORSPACE_EMBEDED: UInt32 = 1
COLORMATCHTOTARGET_EMBEDED: UInt32 = 1
GDICOMMENT_IDENTIFIER: UInt32 = 1128875079
GDICOMMENT_WINDOWS_METAFILE: UInt32 = 2147483649
GDICOMMENT_BEGINGROUP: UInt32 = 2
GDICOMMENT_ENDGROUP: UInt32 = 3
GDICOMMENT_MULTIFORMATS: UInt32 = 1073741828
EPS_SIGNATURE: UInt32 = 1179865157
GDICOMMENT_UNICODE_STRING: UInt32 = 64
GDICOMMENT_UNICODE_END: UInt32 = 128
WGL_FONT_LINES: UInt32 = 0
WGL_FONT_POLYGONS: UInt32 = 1
LPD_DOUBLEBUFFER: UInt32 = 1
LPD_STEREO: UInt32 = 2
LPD_SUPPORT_GDI: UInt32 = 16
LPD_SUPPORT_OPENGL: UInt32 = 32
LPD_SHARE_DEPTH: UInt32 = 64
LPD_SHARE_STENCIL: UInt32 = 128
LPD_SHARE_ACCUM: UInt32 = 256
LPD_SWAP_EXCHANGE: UInt32 = 512
LPD_SWAP_COPY: UInt32 = 1024
LPD_TRANSPARENT: UInt32 = 4096
LPD_TYPE_RGBA: UInt32 = 0
LPD_TYPE_COLORINDEX: UInt32 = 1
WGL_SWAP_MAIN_PLANE: UInt32 = 1
WGL_SWAP_OVERLAY1: UInt32 = 2
WGL_SWAP_OVERLAY2: UInt32 = 4
WGL_SWAP_OVERLAY3: UInt32 = 8
WGL_SWAP_OVERLAY4: UInt32 = 16
WGL_SWAP_OVERLAY5: UInt32 = 32
WGL_SWAP_OVERLAY6: UInt32 = 64
WGL_SWAP_OVERLAY7: UInt32 = 128
WGL_SWAP_OVERLAY8: UInt32 = 256
WGL_SWAP_OVERLAY9: UInt32 = 512
WGL_SWAP_OVERLAY10: UInt32 = 1024
WGL_SWAP_OVERLAY11: UInt32 = 2048
WGL_SWAP_OVERLAY12: UInt32 = 4096
WGL_SWAP_OVERLAY13: UInt32 = 8192
WGL_SWAP_OVERLAY14: UInt32 = 16384
WGL_SWAP_OVERLAY15: UInt32 = 32768
WGL_SWAP_UNDERLAY1: UInt32 = 65536
WGL_SWAP_UNDERLAY2: UInt32 = 131072
WGL_SWAP_UNDERLAY3: UInt32 = 262144
WGL_SWAP_UNDERLAY4: UInt32 = 524288
WGL_SWAP_UNDERLAY5: UInt32 = 1048576
WGL_SWAP_UNDERLAY6: UInt32 = 2097152
WGL_SWAP_UNDERLAY7: UInt32 = 4194304
WGL_SWAP_UNDERLAY8: UInt32 = 8388608
WGL_SWAP_UNDERLAY9: UInt32 = 16777216
WGL_SWAP_UNDERLAY10: UInt32 = 33554432
WGL_SWAP_UNDERLAY11: UInt32 = 67108864
WGL_SWAP_UNDERLAY12: UInt32 = 134217728
WGL_SWAP_UNDERLAY13: UInt32 = 268435456
WGL_SWAP_UNDERLAY14: UInt32 = 536870912
WGL_SWAP_UNDERLAY15: UInt32 = 1073741824
WGL_SWAPMULTIPLE_MAX: UInt32 = 16
NEWTRANSPARENT: UInt32 = 3
QUERYROPSUPPORT: UInt32 = 40
SELECTDIB: UInt32 = 41
SC_SCREENSAVE: UInt32 = 61760
TTFCFP_SUBSET: UInt32 = 0
TTFCFP_SUBSET1: UInt32 = 1
TTFCFP_DELTA: UInt32 = 2
TTFCFP_APPLE_PLATFORMID: UInt32 = 1
TTFCFP_MS_PLATFORMID: UInt32 = 3
TTFCFP_DONT_CARE: UInt32 = 65535
TTFCFP_LANG_KEEP_ALL: UInt32 = 0
TTFCFP_FLAGS_SUBSET: UInt32 = 1
TTFCFP_FLAGS_COMPRESS: UInt32 = 2
TTFCFP_FLAGS_TTC: UInt32 = 4
TTFCFP_FLAGS_GLYPHLIST: UInt32 = 8
TTFMFP_SUBSET: UInt32 = 0
TTFMFP_SUBSET1: UInt32 = 1
TTFMFP_DELTA: UInt32 = 2
ERR_GENERIC: UInt32 = 1000
ERR_READOUTOFBOUNDS: UInt32 = 1001
ERR_WRITEOUTOFBOUNDS: UInt32 = 1002
ERR_READCONTROL: UInt32 = 1003
ERR_WRITECONTROL: UInt32 = 1004
ERR_MEM: UInt32 = 1005
ERR_FORMAT: UInt32 = 1006
ERR_WOULD_GROW: UInt32 = 1007
ERR_VERSION: UInt32 = 1008
ERR_NO_GLYPHS: UInt32 = 1009
ERR_INVALID_MERGE_FORMATS: UInt32 = 1010
ERR_INVALID_MERGE_CHECKSUMS: UInt32 = 1011
ERR_INVALID_MERGE_NUMGLYPHS: UInt32 = 1012
ERR_INVALID_DELTA_FORMAT: UInt32 = 1013
ERR_NOT_TTC: UInt32 = 1014
ERR_INVALID_TTC_INDEX: UInt32 = 1015
ERR_MISSING_CMAP: UInt32 = 1030
ERR_MISSING_GLYF: UInt32 = 1031
ERR_MISSING_HEAD: UInt32 = 1032
ERR_MISSING_HHEA: UInt32 = 1033
ERR_MISSING_HMTX: UInt32 = 1034
ERR_MISSING_LOCA: UInt32 = 1035
ERR_MISSING_MAXP: UInt32 = 1036
ERR_MISSING_NAME: UInt32 = 1037
ERR_MISSING_POST: UInt32 = 1038
ERR_MISSING_OS2: UInt32 = 1039
ERR_MISSING_VHEA: UInt32 = 1040
ERR_MISSING_VMTX: UInt32 = 1041
ERR_MISSING_HHEA_OR_VHEA: UInt32 = 1042
ERR_MISSING_HMTX_OR_VMTX: UInt32 = 1043
ERR_MISSING_EBDT: UInt32 = 1044
ERR_INVALID_CMAP: UInt32 = 1060
ERR_INVALID_GLYF: UInt32 = 1061
ERR_INVALID_HEAD: UInt32 = 1062
ERR_INVALID_HHEA: UInt32 = 1063
ERR_INVALID_HMTX: UInt32 = 1064
ERR_INVALID_LOCA: UInt32 = 1065
ERR_INVALID_MAXP: UInt32 = 1066
ERR_INVALID_NAME: UInt32 = 1067
ERR_INVALID_POST: UInt32 = 1068
ERR_INVALID_OS2: UInt32 = 1069
ERR_INVALID_VHEA: UInt32 = 1070
ERR_INVALID_VMTX: UInt32 = 1071
ERR_INVALID_HHEA_OR_VHEA: UInt32 = 1072
ERR_INVALID_HMTX_OR_VMTX: UInt32 = 1073
ERR_INVALID_TTO: UInt32 = 1080
ERR_INVALID_GSUB: UInt32 = 1081
ERR_INVALID_GPOS: UInt32 = 1082
ERR_INVALID_GDEF: UInt32 = 1083
ERR_INVALID_JSTF: UInt32 = 1084
ERR_INVALID_BASE: UInt32 = 1085
ERR_INVALID_EBLC: UInt32 = 1086
ERR_INVALID_LTSH: UInt32 = 1087
ERR_INVALID_VDMX: UInt32 = 1088
ERR_INVALID_HDMX: UInt32 = 1089
ERR_PARAMETER0: UInt32 = 1100
ERR_PARAMETER1: UInt32 = 1101
ERR_PARAMETER2: UInt32 = 1102
ERR_PARAMETER3: UInt32 = 1103
ERR_PARAMETER4: UInt32 = 1104
ERR_PARAMETER5: UInt32 = 1105
ERR_PARAMETER6: UInt32 = 1106
ERR_PARAMETER7: UInt32 = 1107
ERR_PARAMETER8: UInt32 = 1108
ERR_PARAMETER9: UInt32 = 1109
ERR_PARAMETER10: UInt32 = 1110
ERR_PARAMETER11: UInt32 = 1111
ERR_PARAMETER12: UInt32 = 1112
ERR_PARAMETER13: UInt32 = 1113
ERR_PARAMETER14: UInt32 = 1114
ERR_PARAMETER15: UInt32 = 1115
ERR_PARAMETER16: UInt32 = 1116
CHARSET_DEFAULT: UInt32 = 1
CHARSET_GLYPHIDX: UInt32 = 3
TTEMBED_FAILIFVARIATIONSIMULATED: UInt32 = 16
TTEMBED_WEBOBJECT: UInt32 = 128
TTEMBED_XORENCRYPTDATA: UInt32 = 268435456
TTEMBED_VARIATIONSIMULATED: UInt32 = 1
TTEMBED_EUDCEMBEDDED: UInt32 = 2
TTEMBED_SUBSETCANCEL: UInt32 = 4
TTLOAD_PRIVATE: UInt32 = 1
TTLOAD_EUDC_OVERWRITE: UInt32 = 2
TTLOAD_EUDC_SET: UInt32 = 4
TTDELETE_DONTREMOVEFONT: UInt32 = 1
E_NONE: Int32 = 0
E_API_NOTIMPL: Int32 = 1
E_CHARCODECOUNTINVALID: Int32 = 2
E_CHARCODESETINVALID: Int32 = 3
E_DEVICETRUETYPEFONT: Int32 = 4
E_HDCINVALID: Int32 = 6
E_NOFREEMEMORY: Int32 = 7
E_FONTREFERENCEINVALID: Int32 = 8
E_NOTATRUETYPEFONT: Int32 = 10
E_ERRORACCESSINGFONTDATA: Int32 = 12
E_ERRORACCESSINGFACENAME: Int32 = 13
E_ERRORUNICODECONVERSION: Int32 = 17
E_ERRORCONVERTINGCHARS: Int32 = 18
E_EXCEPTION: Int32 = 19
E_RESERVEDPARAMNOTNULL: Int32 = 20
E_CHARSETINVALID: Int32 = 21
E_FILE_NOT_FOUND: Int32 = 23
E_TTC_INDEX_OUT_OF_RANGE: Int32 = 24
E_INPUTPARAMINVALID: Int32 = 25
E_ERRORCOMPRESSINGFONTDATA: Int32 = 256
E_FONTDATAINVALID: Int32 = 258
E_NAMECHANGEFAILED: Int32 = 259
E_FONTNOTEMBEDDABLE: Int32 = 260
E_PRIVSINVALID: Int32 = 261
E_SUBSETTINGFAILED: Int32 = 262
E_READFROMSTREAMFAILED: Int32 = 263
E_SAVETOSTREAMFAILED: Int32 = 264
E_NOOS2: Int32 = 265
E_T2NOFREEMEMORY: Int32 = 266
E_ERRORREADINGFONTDATA: Int32 = 267
E_FLAGSINVALID: Int32 = 268
E_ERRORCREATINGFONTFILE: Int32 = 269
E_FONTALREADYEXISTS: Int32 = 270
E_FONTNAMEALREADYEXISTS: Int32 = 271
E_FONTINSTALLFAILED: Int32 = 272
E_ERRORDECOMPRESSINGFONTDATA: Int32 = 273
E_ERRORACCESSINGEXCLUDELIST: Int32 = 274
E_FACENAMEINVALID: Int32 = 275
E_STREAMINVALID: Int32 = 276
E_STATUSINVALID: Int32 = 277
E_PRIVSTATUSINVALID: Int32 = 278
E_PERMISSIONSINVALID: Int32 = 279
E_PBENABLEDINVALID: Int32 = 280
E_SUBSETTINGEXCEPTION: Int32 = 281
E_SUBSTRING_TEST_FAIL: Int32 = 282
E_FONTVARIATIONSIMULATED: Int32 = 283
E_FONTFAMILYNAMENOTINFULL: Int32 = 285
E_ADDFONTFAILED: Int32 = 512
E_COULDNTCREATETEMPFILE: Int32 = 513
E_FONTFILECREATEFAILED: Int32 = 515
E_WINDOWSAPI: Int32 = 516
E_FONTFILENOTFOUND: Int32 = 517
E_RESOURCEFILECREATEFAILED: Int32 = 518
E_ERROREXPANDINGFONTDATA: Int32 = 519
E_ERRORGETTINGDC: Int32 = 520
E_EXCEPTIONINDECOMPRESSION: Int32 = 521
E_EXCEPTIONINCOMPRESSION: Int32 = 522
@winfunctype('GDI32.dll')
def GetObjectA(h: win32more.Windows.Win32.Graphics.Gdi.HGDIOBJ, c: Int32, pv: VoidPtr) -> Int32: ...
@winfunctype('GDI32.dll')
def AddFontResourceA(param0: win32more.Windows.Win32.Foundation.PSTR) -> Int32: ...
@winfunctype('GDI32.dll')
def AddFontResourceW(param0: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
AddFontResource = UnicodeAlias('AddFontResourceW')
@winfunctype('GDI32.dll')
def AnimatePalette(hPal: win32more.Windows.Win32.Graphics.Gdi.HPALETTE, iStartIndex: UInt32, cEntries: UInt32, ppe: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def Arc(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x1: Int32, y1: Int32, x2: Int32, y2: Int32, x3: Int32, y3: Int32, x4: Int32, y4: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def BitBlt(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, cx: Int32, cy: Int32, hdcSrc: win32more.Windows.Win32.Graphics.Gdi.HDC, x1: Int32, y1: Int32, rop: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def CancelDC(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def Chord(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x1: Int32, y1: Int32, x2: Int32, y2: Int32, x3: Int32, y3: Int32, x4: Int32, y4: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def CloseMetaFile(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Graphics.Gdi.HMETAFILE: ...
@winfunctype('GDI32.dll')
def CombineRgn(hrgnDst: win32more.Windows.Win32.Graphics.Gdi.HRGN, hrgnSrc1: win32more.Windows.Win32.Graphics.Gdi.HRGN, hrgnSrc2: win32more.Windows.Win32.Graphics.Gdi.HRGN, iMode: win32more.Windows.Win32.Graphics.Gdi.RGN_COMBINE_MODE) -> win32more.Windows.Win32.Graphics.Gdi.GDI_REGION_TYPE: ...
@winfunctype('GDI32.dll')
def CopyMetaFileA(param0: win32more.Windows.Win32.Graphics.Gdi.HMETAFILE, param1: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Gdi.HMETAFILE: ...
@winfunctype('GDI32.dll')
def CopyMetaFileW(param0: win32more.Windows.Win32.Graphics.Gdi.HMETAFILE, param1: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Graphics.Gdi.HMETAFILE: ...
CopyMetaFile = UnicodeAlias('CopyMetaFileW')
@winfunctype('GDI32.dll')
def CreateBitmap(nWidth: Int32, nHeight: Int32, nPlanes: UInt32, nBitCount: UInt32, lpBits: VoidPtr) -> win32more.Windows.Win32.Graphics.Gdi.HBITMAP: ...
@winfunctype('GDI32.dll')
def CreateBitmapIndirect(pbm: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAP)) -> win32more.Windows.Win32.Graphics.Gdi.HBITMAP: ...
@winfunctype('GDI32.dll')
def CreateBrushIndirect(plbrush: POINTER(win32more.Windows.Win32.Graphics.Gdi.LOGBRUSH)) -> win32more.Windows.Win32.Graphics.Gdi.HBRUSH: ...
@winfunctype('GDI32.dll')
def CreateCompatibleBitmap(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, cx: Int32, cy: Int32) -> win32more.Windows.Win32.Graphics.Gdi.HBITMAP: ...
@winfunctype('GDI32.dll')
def CreateDiscardableBitmap(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, cx: Int32, cy: Int32) -> win32more.Windows.Win32.Graphics.Gdi.HBITMAP: ...
@winfunctype('GDI32.dll')
def CreateCompatibleDC(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
@winfunctype('GDI32.dll')
def CreateDCA(pwszDriver: win32more.Windows.Win32.Foundation.PSTR, pwszDevice: win32more.Windows.Win32.Foundation.PSTR, pszPort: win32more.Windows.Win32.Foundation.PSTR, pdm: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
@winfunctype('GDI32.dll')
def CreateDCW(pwszDriver: win32more.Windows.Win32.Foundation.PWSTR, pwszDevice: win32more.Windows.Win32.Foundation.PWSTR, pszPort: win32more.Windows.Win32.Foundation.PWSTR, pdm: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW)) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
CreateDC = UnicodeAlias('CreateDCW')
@winfunctype('GDI32.dll')
def CreateDIBitmap(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, pbmih: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER), flInit: UInt32, pjBits: VoidPtr, pbmi: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFO), iUsage: win32more.Windows.Win32.Graphics.Gdi.DIB_USAGE) -> win32more.Windows.Win32.Graphics.Gdi.HBITMAP: ...
@winfunctype('GDI32.dll')
def CreateDIBPatternBrush(h: win32more.Windows.Win32.Foundation.HGLOBAL, iUsage: win32more.Windows.Win32.Graphics.Gdi.DIB_USAGE) -> win32more.Windows.Win32.Graphics.Gdi.HBRUSH: ...
@winfunctype('GDI32.dll')
def CreateDIBPatternBrushPt(lpPackedDIB: VoidPtr, iUsage: win32more.Windows.Win32.Graphics.Gdi.DIB_USAGE) -> win32more.Windows.Win32.Graphics.Gdi.HBRUSH: ...
@winfunctype('GDI32.dll')
def CreateEllipticRgn(x1: Int32, y1: Int32, x2: Int32, y2: Int32) -> win32more.Windows.Win32.Graphics.Gdi.HRGN: ...
@winfunctype('GDI32.dll')
def CreateEllipticRgnIndirect(lprect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Graphics.Gdi.HRGN: ...
@winfunctype('GDI32.dll')
def CreateFontIndirectA(lplf: POINTER(win32more.Windows.Win32.Graphics.Gdi.LOGFONTA)) -> win32more.Windows.Win32.Graphics.Gdi.HFONT: ...
@winfunctype('GDI32.dll')
def CreateFontIndirectW(lplf: POINTER(win32more.Windows.Win32.Graphics.Gdi.LOGFONTW)) -> win32more.Windows.Win32.Graphics.Gdi.HFONT: ...
CreateFontIndirect = UnicodeAlias('CreateFontIndirectW')
@winfunctype('GDI32.dll')
def CreateFontA(cHeight: Int32, cWidth: Int32, cEscapement: Int32, cOrientation: Int32, cWeight: Int32, bItalic: UInt32, bUnderline: UInt32, bStrikeOut: UInt32, iCharSet: UInt32, iOutPrecision: UInt32, iClipPrecision: UInt32, iQuality: UInt32, iPitchAndFamily: UInt32, pszFaceName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Gdi.HFONT: ...
@winfunctype('GDI32.dll')
def CreateFontW(cHeight: Int32, cWidth: Int32, cEscapement: Int32, cOrientation: Int32, cWeight: Int32, bItalic: UInt32, bUnderline: UInt32, bStrikeOut: UInt32, iCharSet: UInt32, iOutPrecision: UInt32, iClipPrecision: UInt32, iQuality: UInt32, iPitchAndFamily: UInt32, pszFaceName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Graphics.Gdi.HFONT: ...
CreateFont = UnicodeAlias('CreateFontW')
@winfunctype('GDI32.dll')
def CreateHatchBrush(iHatch: win32more.Windows.Win32.Graphics.Gdi.HATCH_BRUSH_STYLE, color: win32more.Windows.Win32.Foundation.COLORREF) -> win32more.Windows.Win32.Graphics.Gdi.HBRUSH: ...
@winfunctype('GDI32.dll')
def CreateICA(pszDriver: win32more.Windows.Win32.Foundation.PSTR, pszDevice: win32more.Windows.Win32.Foundation.PSTR, pszPort: win32more.Windows.Win32.Foundation.PSTR, pdm: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
@winfunctype('GDI32.dll')
def CreateICW(pszDriver: win32more.Windows.Win32.Foundation.PWSTR, pszDevice: win32more.Windows.Win32.Foundation.PWSTR, pszPort: win32more.Windows.Win32.Foundation.PWSTR, pdm: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW)) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
CreateIC = UnicodeAlias('CreateICW')
@winfunctype('GDI32.dll')
def CreateMetaFileA(pszFile: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
@winfunctype('GDI32.dll')
def CreateMetaFileW(pszFile: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
CreateMetaFile = UnicodeAlias('CreateMetaFileW')
@winfunctype('GDI32.dll')
def CreatePalette(plpal: POINTER(win32more.Windows.Win32.Graphics.Gdi.LOGPALETTE)) -> win32more.Windows.Win32.Graphics.Gdi.HPALETTE: ...
@winfunctype('GDI32.dll')
def CreatePen(iStyle: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE, cWidth: Int32, color: win32more.Windows.Win32.Foundation.COLORREF) -> win32more.Windows.Win32.Graphics.Gdi.HPEN: ...
@winfunctype('GDI32.dll')
def CreatePenIndirect(plpen: POINTER(win32more.Windows.Win32.Graphics.Gdi.LOGPEN)) -> win32more.Windows.Win32.Graphics.Gdi.HPEN: ...
@winfunctype('GDI32.dll')
def CreatePolyPolygonRgn(pptl: POINTER(win32more.Windows.Win32.Foundation.POINT), pc: POINTER(Int32), cPoly: Int32, iMode: win32more.Windows.Win32.Graphics.Gdi.CREATE_POLYGON_RGN_MODE) -> win32more.Windows.Win32.Graphics.Gdi.HRGN: ...
@winfunctype('GDI32.dll')
def CreatePatternBrush(hbm: win32more.Windows.Win32.Graphics.Gdi.HBITMAP) -> win32more.Windows.Win32.Graphics.Gdi.HBRUSH: ...
@winfunctype('GDI32.dll')
def CreateRectRgn(x1: Int32, y1: Int32, x2: Int32, y2: Int32) -> win32more.Windows.Win32.Graphics.Gdi.HRGN: ...
@winfunctype('GDI32.dll')
def CreateRectRgnIndirect(lprect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Graphics.Gdi.HRGN: ...
@winfunctype('GDI32.dll')
def CreateRoundRectRgn(x1: Int32, y1: Int32, x2: Int32, y2: Int32, w: Int32, h: Int32) -> win32more.Windows.Win32.Graphics.Gdi.HRGN: ...
@winfunctype('GDI32.dll')
def CreateScalableFontResourceA(fdwHidden: UInt32, lpszFont: win32more.Windows.Win32.Foundation.PSTR, lpszFile: win32more.Windows.Win32.Foundation.PSTR, lpszPath: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def CreateScalableFontResourceW(fdwHidden: UInt32, lpszFont: win32more.Windows.Win32.Foundation.PWSTR, lpszFile: win32more.Windows.Win32.Foundation.PWSTR, lpszPath: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
CreateScalableFontResource = UnicodeAlias('CreateScalableFontResourceW')
@winfunctype('GDI32.dll')
def CreateSolidBrush(color: win32more.Windows.Win32.Foundation.COLORREF) -> win32more.Windows.Win32.Graphics.Gdi.HBRUSH: ...
@winfunctype('GDI32.dll')
def DeleteDC(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def DeleteMetaFile(hmf: win32more.Windows.Win32.Graphics.Gdi.HMETAFILE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def DeleteObject(ho: win32more.Windows.Win32.Graphics.Gdi.HGDIOBJ) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def DrawEscape(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iEscape: Int32, cjIn: Int32, lpIn: win32more.Windows.Win32.Foundation.PSTR) -> Int32: ...
@winfunctype('GDI32.dll')
def Ellipse(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, left: Int32, top: Int32, right: Int32, bottom: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def EnumFontFamiliesExA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpLogfont: POINTER(win32more.Windows.Win32.Graphics.Gdi.LOGFONTA), lpProc: win32more.Windows.Win32.Graphics.Gdi.FONTENUMPROCA, lParam: win32more.Windows.Win32.Foundation.LPARAM, dwFlags: UInt32) -> Int32: ...
@winfunctype('GDI32.dll')
def EnumFontFamiliesExW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpLogfont: POINTER(win32more.Windows.Win32.Graphics.Gdi.LOGFONTW), lpProc: win32more.Windows.Win32.Graphics.Gdi.FONTENUMPROCW, lParam: win32more.Windows.Win32.Foundation.LPARAM, dwFlags: UInt32) -> Int32: ...
EnumFontFamiliesEx = UnicodeAlias('EnumFontFamiliesExW')
@winfunctype('GDI32.dll')
def EnumFontFamiliesA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpLogfont: win32more.Windows.Win32.Foundation.PSTR, lpProc: win32more.Windows.Win32.Graphics.Gdi.FONTENUMPROCA, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype('GDI32.dll')
def EnumFontFamiliesW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpLogfont: win32more.Windows.Win32.Foundation.PWSTR, lpProc: win32more.Windows.Win32.Graphics.Gdi.FONTENUMPROCW, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
EnumFontFamilies = UnicodeAlias('EnumFontFamiliesW')
@winfunctype('GDI32.dll')
def EnumFontsA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpLogfont: win32more.Windows.Win32.Foundation.PSTR, lpProc: win32more.Windows.Win32.Graphics.Gdi.FONTENUMPROCA, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype('GDI32.dll')
def EnumFontsW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpLogfont: win32more.Windows.Win32.Foundation.PWSTR, lpProc: win32more.Windows.Win32.Graphics.Gdi.FONTENUMPROCW, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
EnumFonts = UnicodeAlias('EnumFontsW')
@winfunctype('GDI32.dll')
def EnumObjects(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, nType: win32more.Windows.Win32.Graphics.Gdi.OBJ_TYPE, lpFunc: win32more.Windows.Win32.Graphics.Gdi.GOBJENUMPROC, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype('GDI32.dll')
def EqualRgn(hrgn1: win32more.Windows.Win32.Graphics.Gdi.HRGN, hrgn2: win32more.Windows.Win32.Graphics.Gdi.HRGN) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def ExcludeClipRect(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, left: Int32, top: Int32, right: Int32, bottom: Int32) -> win32more.Windows.Win32.Graphics.Gdi.GDI_REGION_TYPE: ...
@winfunctype('GDI32.dll')
def ExtCreateRegion(lpx: POINTER(win32more.Windows.Win32.Graphics.Gdi.XFORM), nCount: UInt32, lpData: POINTER(win32more.Windows.Win32.Graphics.Gdi.RGNDATA)) -> win32more.Windows.Win32.Graphics.Gdi.HRGN: ...
@winfunctype('GDI32.dll')
def ExtFloodFill(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, color: win32more.Windows.Win32.Foundation.COLORREF, type: win32more.Windows.Win32.Graphics.Gdi.EXT_FLOOD_FILL_TYPE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def FillRgn(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hrgn: win32more.Windows.Win32.Graphics.Gdi.HRGN, hbr: win32more.Windows.Win32.Graphics.Gdi.HBRUSH) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def FloodFill(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, color: win32more.Windows.Win32.Foundation.COLORREF) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def FrameRgn(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hrgn: win32more.Windows.Win32.Graphics.Gdi.HRGN, hbr: win32more.Windows.Win32.Graphics.Gdi.HBRUSH, w: Int32, h: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetROP2(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Graphics.Gdi.R2_MODE: ...
@winfunctype('GDI32.dll')
def GetAspectRatioFilterEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpsize: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetBkColor(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.COLORREF: ...
@winfunctype('GDI32.dll')
def GetDCBrushColor(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.COLORREF: ...
@winfunctype('GDI32.dll')
def GetDCPenColor(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.COLORREF: ...
@winfunctype('GDI32.dll')
def GetBkMode(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> Int32: ...
@winfunctype('GDI32.dll')
def GetBitmapBits(hbit: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, cb: Int32, lpvBits: VoidPtr) -> Int32: ...
@winfunctype('GDI32.dll')
def GetBitmapDimensionEx(hbit: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, lpsize: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetBoundsRect(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lprect: POINTER(win32more.Windows.Win32.Foundation.RECT), flags: UInt32) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetBrushOrgEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lppt: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetCharWidthA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iFirst: UInt32, iLast: UInt32, lpBuffer: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetCharWidthW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iFirst: UInt32, iLast: UInt32, lpBuffer: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetCharWidth = UnicodeAlias('GetCharWidthW')
@winfunctype('GDI32.dll')
def GetCharWidth32A(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iFirst: UInt32, iLast: UInt32, lpBuffer: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetCharWidth32W(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iFirst: UInt32, iLast: UInt32, lpBuffer: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetCharWidth32 = UnicodeAlias('GetCharWidth32W')
@winfunctype('GDI32.dll')
def GetCharWidthFloatA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iFirst: UInt32, iLast: UInt32, lpBuffer: POINTER(Single)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetCharWidthFloatW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iFirst: UInt32, iLast: UInt32, lpBuffer: POINTER(Single)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetCharWidthFloat = UnicodeAlias('GetCharWidthFloatW')
@winfunctype('GDI32.dll')
def GetCharABCWidthsA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, wFirst: UInt32, wLast: UInt32, lpABC: POINTER(win32more.Windows.Win32.Graphics.Gdi.ABC)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetCharABCWidthsW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, wFirst: UInt32, wLast: UInt32, lpABC: POINTER(win32more.Windows.Win32.Graphics.Gdi.ABC)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetCharABCWidths = UnicodeAlias('GetCharABCWidthsW')
@winfunctype('GDI32.dll')
def GetCharABCWidthsFloatA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iFirst: UInt32, iLast: UInt32, lpABC: POINTER(win32more.Windows.Win32.Graphics.Gdi.ABCFLOAT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetCharABCWidthsFloatW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iFirst: UInt32, iLast: UInt32, lpABC: POINTER(win32more.Windows.Win32.Graphics.Gdi.ABCFLOAT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetCharABCWidthsFloat = UnicodeAlias('GetCharABCWidthsFloatW')
@winfunctype('GDI32.dll')
def GetClipBox(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lprect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Graphics.Gdi.GDI_REGION_TYPE: ...
@winfunctype('GDI32.dll')
def GetClipRgn(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hrgn: win32more.Windows.Win32.Graphics.Gdi.HRGN) -> Int32: ...
@winfunctype('GDI32.dll')
def GetMetaRgn(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hrgn: win32more.Windows.Win32.Graphics.Gdi.HRGN) -> Int32: ...
@winfunctype('GDI32.dll')
def GetCurrentObject(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, type: UInt32) -> win32more.Windows.Win32.Graphics.Gdi.HGDIOBJ: ...
@winfunctype('GDI32.dll')
def GetCurrentPositionEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lppt: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetDeviceCaps(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, index: Int32) -> Int32: ...
@winfunctype('GDI32.dll')
def GetDIBits(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hbm: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, start: UInt32, cLines: UInt32, lpvBits: VoidPtr, lpbmi: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFO), usage: win32more.Windows.Win32.Graphics.Gdi.DIB_USAGE) -> Int32: ...
@winfunctype('GDI32.dll')
def GetFontData(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, dwTable: UInt32, dwOffset: UInt32, pvBuffer: VoidPtr, cjBuffer: UInt32) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetGlyphOutlineA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, uChar: UInt32, fuFormat: win32more.Windows.Win32.Graphics.Gdi.GET_GLYPH_OUTLINE_FORMAT, lpgm: POINTER(win32more.Windows.Win32.Graphics.Gdi.GLYPHMETRICS), cjBuffer: UInt32, pvBuffer: VoidPtr, lpmat2: POINTER(win32more.Windows.Win32.Graphics.Gdi.MAT2)) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetGlyphOutlineW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, uChar: UInt32, fuFormat: win32more.Windows.Win32.Graphics.Gdi.GET_GLYPH_OUTLINE_FORMAT, lpgm: POINTER(win32more.Windows.Win32.Graphics.Gdi.GLYPHMETRICS), cjBuffer: UInt32, pvBuffer: VoidPtr, lpmat2: POINTER(win32more.Windows.Win32.Graphics.Gdi.MAT2)) -> UInt32: ...
GetGlyphOutline = UnicodeAlias('GetGlyphOutlineW')
@winfunctype('GDI32.dll')
def GetGraphicsMode(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> Int32: ...
@winfunctype('GDI32.dll')
def GetMapMode(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Graphics.Gdi.HDC_MAP_MODE: ...
@winfunctype('GDI32.dll')
def GetMetaFileBitsEx(hMF: win32more.Windows.Win32.Graphics.Gdi.HMETAFILE, cbBuffer: UInt32, lpData: VoidPtr) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetMetaFileA(lpName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Gdi.HMETAFILE: ...
@winfunctype('GDI32.dll')
def GetMetaFileW(lpName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Graphics.Gdi.HMETAFILE: ...
GetMetaFile = UnicodeAlias('GetMetaFileW')
@winfunctype('GDI32.dll')
def GetNearestColor(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, color: win32more.Windows.Win32.Foundation.COLORREF) -> win32more.Windows.Win32.Foundation.COLORREF: ...
@winfunctype('GDI32.dll')
def GetNearestPaletteIndex(h: win32more.Windows.Win32.Graphics.Gdi.HPALETTE, color: win32more.Windows.Win32.Foundation.COLORREF) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetObjectType(h: win32more.Windows.Win32.Graphics.Gdi.HGDIOBJ) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetOutlineTextMetricsA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, cjCopy: UInt32, potm: POINTER(win32more.Windows.Win32.Graphics.Gdi.OUTLINETEXTMETRICA)) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetOutlineTextMetricsW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, cjCopy: UInt32, potm: POINTER(win32more.Windows.Win32.Graphics.Gdi.OUTLINETEXTMETRICW)) -> UInt32: ...
GetOutlineTextMetrics = UnicodeAlias('GetOutlineTextMetricsW')
@winfunctype('GDI32.dll')
def GetPaletteEntries(hpal: win32more.Windows.Win32.Graphics.Gdi.HPALETTE, iStart: UInt32, cEntries: UInt32, pPalEntries: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY)) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetPixel(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.COLORREF: ...
@winfunctype('GDI32.dll')
def GetPolyFillMode(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> Int32: ...
@winfunctype('GDI32.dll')
def GetRasterizerCaps(lpraststat: POINTER(win32more.Windows.Win32.Graphics.Gdi.RASTERIZER_STATUS), cjBytes: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetRandomRgn(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hrgn: win32more.Windows.Win32.Graphics.Gdi.HRGN, i: Int32) -> Int32: ...
@winfunctype('GDI32.dll')
def GetRegionData(hrgn: win32more.Windows.Win32.Graphics.Gdi.HRGN, nCount: UInt32, lpRgnData: POINTER(win32more.Windows.Win32.Graphics.Gdi.RGNDATA)) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetRgnBox(hrgn: win32more.Windows.Win32.Graphics.Gdi.HRGN, lprc: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Graphics.Gdi.GDI_REGION_TYPE: ...
@winfunctype('GDI32.dll')
def GetStockObject(i: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS) -> win32more.Windows.Win32.Graphics.Gdi.HGDIOBJ: ...
@winfunctype('GDI32.dll')
def GetStretchBltMode(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> Int32: ...
@winfunctype('GDI32.dll')
def GetSystemPaletteEntries(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iStart: UInt32, cEntries: UInt32, pPalEntries: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY)) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetSystemPaletteUse(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetTextCharacterExtra(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> Int32: ...
@winfunctype('GDI32.dll')
def GetTextAlign(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS: ...
@winfunctype('GDI32.dll')
def GetTextColor(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.COLORREF: ...
@winfunctype('GDI32.dll')
def GetTextExtentPointA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpString: win32more.Windows.Win32.Foundation.PSTR, c: Int32, lpsz: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetTextExtentPointW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpString: win32more.Windows.Win32.Foundation.PWSTR, c: Int32, lpsz: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetTextExtentPoint = UnicodeAlias('GetTextExtentPointW')
@winfunctype('GDI32.dll')
def GetTextExtentPoint32A(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpString: win32more.Windows.Win32.Foundation.PSTR, c: Int32, psizl: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetTextExtentPoint32W(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpString: win32more.Windows.Win32.Foundation.PWSTR, c: Int32, psizl: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetTextExtentPoint32 = UnicodeAlias('GetTextExtentPoint32W')
@winfunctype('GDI32.dll')
def GetTextExtentExPointA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpszString: win32more.Windows.Win32.Foundation.PSTR, cchString: Int32, nMaxExtent: Int32, lpnFit: POINTER(Int32), lpnDx: POINTER(Int32), lpSize: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetTextExtentExPointW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpszString: win32more.Windows.Win32.Foundation.PWSTR, cchString: Int32, nMaxExtent: Int32, lpnFit: POINTER(Int32), lpnDx: POINTER(Int32), lpSize: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetTextExtentExPoint = UnicodeAlias('GetTextExtentExPointW')
@winfunctype('GDI32.dll')
def GetFontLanguageInfo(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetCharacterPlacementA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpString: win32more.Windows.Win32.Foundation.PSTR, nCount: Int32, nMexExtent: Int32, lpResults: POINTER(win32more.Windows.Win32.Graphics.Gdi.GCP_RESULTSA), dwFlags: win32more.Windows.Win32.Graphics.Gdi.GET_CHARACTER_PLACEMENT_FLAGS) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetCharacterPlacementW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpString: win32more.Windows.Win32.Foundation.PWSTR, nCount: Int32, nMexExtent: Int32, lpResults: POINTER(win32more.Windows.Win32.Graphics.Gdi.GCP_RESULTSW), dwFlags: win32more.Windows.Win32.Graphics.Gdi.GET_CHARACTER_PLACEMENT_FLAGS) -> UInt32: ...
GetCharacterPlacement = UnicodeAlias('GetCharacterPlacementW')
@winfunctype('GDI32.dll')
def GetFontUnicodeRanges(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpgs: POINTER(win32more.Windows.Win32.Graphics.Gdi.GLYPHSET)) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetGlyphIndicesA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpstr: win32more.Windows.Win32.Foundation.PSTR, c: Int32, pgi: POINTER(UInt16), fl: UInt32) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetGlyphIndicesW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpstr: win32more.Windows.Win32.Foundation.PWSTR, c: Int32, pgi: POINTER(UInt16), fl: UInt32) -> UInt32: ...
GetGlyphIndices = UnicodeAlias('GetGlyphIndicesW')
@winfunctype('GDI32.dll')
def GetTextExtentPointI(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, pgiIn: POINTER(UInt16), cgi: Int32, psize: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetTextExtentExPointI(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpwszString: POINTER(UInt16), cwchString: Int32, nMaxExtent: Int32, lpnFit: POINTER(Int32), lpnDx: POINTER(Int32), lpSize: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetCharWidthI(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, giFirst: UInt32, cgi: UInt32, pgi: POINTER(UInt16), piWidths: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetCharABCWidthsI(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, giFirst: UInt32, cgi: UInt32, pgi: POINTER(UInt16), pabc: POINTER(win32more.Windows.Win32.Graphics.Gdi.ABC)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def AddFontResourceExA(name: win32more.Windows.Win32.Foundation.PSTR, fl: win32more.Windows.Win32.Graphics.Gdi.FONT_RESOURCE_CHARACTERISTICS, res: VoidPtr) -> Int32: ...
@winfunctype('GDI32.dll')
def AddFontResourceExW(name: win32more.Windows.Win32.Foundation.PWSTR, fl: win32more.Windows.Win32.Graphics.Gdi.FONT_RESOURCE_CHARACTERISTICS, res: VoidPtr) -> Int32: ...
AddFontResourceEx = UnicodeAlias('AddFontResourceExW')
@winfunctype('GDI32.dll')
def RemoveFontResourceExA(name: win32more.Windows.Win32.Foundation.PSTR, fl: UInt32, pdv: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def RemoveFontResourceExW(name: win32more.Windows.Win32.Foundation.PWSTR, fl: UInt32, pdv: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
RemoveFontResourceEx = UnicodeAlias('RemoveFontResourceExW')
@winfunctype('GDI32.dll')
def AddFontMemResourceEx(pFileView: VoidPtr, cjSize: UInt32, pvResrved: VoidPtr, pNumFonts: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('GDI32.dll')
def RemoveFontMemResourceEx(h: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def CreateFontIndirectExA(param0: POINTER(win32more.Windows.Win32.Graphics.Gdi.ENUMLOGFONTEXDVA)) -> win32more.Windows.Win32.Graphics.Gdi.HFONT: ...
@winfunctype('GDI32.dll')
def CreateFontIndirectExW(param0: POINTER(win32more.Windows.Win32.Graphics.Gdi.ENUMLOGFONTEXDVW)) -> win32more.Windows.Win32.Graphics.Gdi.HFONT: ...
CreateFontIndirectEx = UnicodeAlias('CreateFontIndirectExW')
@winfunctype('GDI32.dll')
def GetViewportExtEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpsize: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetViewportOrgEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lppoint: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetWindowExtEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpsize: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetWindowOrgEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lppoint: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def IntersectClipRect(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, left: Int32, top: Int32, right: Int32, bottom: Int32) -> win32more.Windows.Win32.Graphics.Gdi.GDI_REGION_TYPE: ...
@winfunctype('GDI32.dll')
def InvertRgn(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hrgn: win32more.Windows.Win32.Graphics.Gdi.HRGN) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def LineDDA(xStart: Int32, yStart: Int32, xEnd: Int32, yEnd: Int32, lpProc: win32more.Windows.Win32.Graphics.Gdi.LINEDDAPROC, data: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def LineTo(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def MaskBlt(hdcDest: win32more.Windows.Win32.Graphics.Gdi.HDC, xDest: Int32, yDest: Int32, width: Int32, height: Int32, hdcSrc: win32more.Windows.Win32.Graphics.Gdi.HDC, xSrc: Int32, ySrc: Int32, hbmMask: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, xMask: Int32, yMask: Int32, rop: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def PlgBlt(hdcDest: win32more.Windows.Win32.Graphics.Gdi.HDC, lpPoint: POINTER(win32more.Windows.Win32.Foundation.POINT), hdcSrc: win32more.Windows.Win32.Graphics.Gdi.HDC, xSrc: Int32, ySrc: Int32, width: Int32, height: Int32, hbmMask: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, xMask: Int32, yMask: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def OffsetClipRgn(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32) -> win32more.Windows.Win32.Graphics.Gdi.GDI_REGION_TYPE: ...
@winfunctype('GDI32.dll')
def OffsetRgn(hrgn: win32more.Windows.Win32.Graphics.Gdi.HRGN, x: Int32, y: Int32) -> win32more.Windows.Win32.Graphics.Gdi.GDI_REGION_TYPE: ...
@winfunctype('GDI32.dll')
def PatBlt(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, w: Int32, h: Int32, rop: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def Pie(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, left: Int32, top: Int32, right: Int32, bottom: Int32, xr1: Int32, yr1: Int32, xr2: Int32, yr2: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def PlayMetaFile(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hmf: win32more.Windows.Win32.Graphics.Gdi.HMETAFILE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def PaintRgn(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hrgn: win32more.Windows.Win32.Graphics.Gdi.HRGN) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def PolyPolygon(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, apt: POINTER(win32more.Windows.Win32.Foundation.POINT), asz: POINTER(Int32), csz: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def PtInRegion(hrgn: win32more.Windows.Win32.Graphics.Gdi.HRGN, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def PtVisible(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def RectInRegion(hrgn: win32more.Windows.Win32.Graphics.Gdi.HRGN, lprect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def RectVisible(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lprect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def Rectangle(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, left: Int32, top: Int32, right: Int32, bottom: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def RestoreDC(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, nSavedDC: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def ResetDCA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpdm: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
@winfunctype('GDI32.dll')
def ResetDCW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpdm: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW)) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
ResetDC = UnicodeAlias('ResetDCW')
@winfunctype('GDI32.dll')
def RealizePalette(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> UInt32: ...
@winfunctype('GDI32.dll')
def RemoveFontResourceA(lpFileName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def RemoveFontResourceW(lpFileName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
RemoveFontResource = UnicodeAlias('RemoveFontResourceW')
@winfunctype('GDI32.dll')
def RoundRect(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, left: Int32, top: Int32, right: Int32, bottom: Int32, width: Int32, height: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def ResizePalette(hpal: win32more.Windows.Win32.Graphics.Gdi.HPALETTE, n: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def SaveDC(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> Int32: ...
@winfunctype('GDI32.dll')
def SelectClipRgn(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hrgn: win32more.Windows.Win32.Graphics.Gdi.HRGN) -> win32more.Windows.Win32.Graphics.Gdi.GDI_REGION_TYPE: ...
@winfunctype('GDI32.dll')
def ExtSelectClipRgn(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hrgn: win32more.Windows.Win32.Graphics.Gdi.HRGN, mode: win32more.Windows.Win32.Graphics.Gdi.RGN_COMBINE_MODE) -> win32more.Windows.Win32.Graphics.Gdi.GDI_REGION_TYPE: ...
@winfunctype('GDI32.dll')
def SetMetaRgn(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Graphics.Gdi.GDI_REGION_TYPE: ...
@winfunctype('GDI32.dll')
def SelectObject(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, h: win32more.Windows.Win32.Graphics.Gdi.HGDIOBJ) -> win32more.Windows.Win32.Graphics.Gdi.HGDIOBJ: ...
@winfunctype('GDI32.dll')
def SelectPalette(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hPal: win32more.Windows.Win32.Graphics.Gdi.HPALETTE, bForceBkgd: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Graphics.Gdi.HPALETTE: ...
@winfunctype('GDI32.dll')
def SetBkColor(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, color: win32more.Windows.Win32.Foundation.COLORREF) -> win32more.Windows.Win32.Foundation.COLORREF: ...
@winfunctype('GDI32.dll')
def SetDCBrushColor(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, color: win32more.Windows.Win32.Foundation.COLORREF) -> win32more.Windows.Win32.Foundation.COLORREF: ...
@winfunctype('GDI32.dll')
def SetDCPenColor(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, color: win32more.Windows.Win32.Foundation.COLORREF) -> win32more.Windows.Win32.Foundation.COLORREF: ...
@winfunctype('GDI32.dll')
def SetBkMode(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, mode: Int32) -> Int32: ...
@winfunctype('GDI32.dll')
def SetBitmapBits(hbm: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, cb: UInt32, pvBits: VoidPtr) -> Int32: ...
@winfunctype('GDI32.dll')
def SetBoundsRect(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lprect: POINTER(win32more.Windows.Win32.Foundation.RECT), flags: win32more.Windows.Win32.Graphics.Gdi.SET_BOUNDS_RECT_FLAGS) -> UInt32: ...
@winfunctype('GDI32.dll')
def SetDIBits(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hbm: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, start: UInt32, cLines: UInt32, lpBits: VoidPtr, lpbmi: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFO), ColorUse: win32more.Windows.Win32.Graphics.Gdi.DIB_USAGE) -> Int32: ...
@winfunctype('GDI32.dll')
def SetDIBitsToDevice(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, xDest: Int32, yDest: Int32, w: UInt32, h: UInt32, xSrc: Int32, ySrc: Int32, StartScan: UInt32, cLines: UInt32, lpvBits: VoidPtr, lpbmi: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFO), ColorUse: win32more.Windows.Win32.Graphics.Gdi.DIB_USAGE) -> Int32: ...
@winfunctype('GDI32.dll')
def SetMapperFlags(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, flags: UInt32) -> UInt32: ...
@winfunctype('GDI32.dll')
def SetGraphicsMode(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iMode: win32more.Windows.Win32.Graphics.Gdi.GRAPHICS_MODE) -> Int32: ...
@winfunctype('GDI32.dll')
def SetMapMode(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iMode: win32more.Windows.Win32.Graphics.Gdi.HDC_MAP_MODE) -> Int32: ...
@winfunctype('GDI32.dll')
def SetLayout(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, l: win32more.Windows.Win32.Graphics.Gdi.DC_LAYOUT) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetLayout(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> UInt32: ...
@winfunctype('GDI32.dll')
def SetMetaFileBitsEx(cbBuffer: UInt32, lpData: POINTER(Byte)) -> win32more.Windows.Win32.Graphics.Gdi.HMETAFILE: ...
@winfunctype('GDI32.dll')
def SetPaletteEntries(hpal: win32more.Windows.Win32.Graphics.Gdi.HPALETTE, iStart: UInt32, cEntries: UInt32, pPalEntries: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY)) -> UInt32: ...
@winfunctype('GDI32.dll')
def SetPixel(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, color: win32more.Windows.Win32.Foundation.COLORREF) -> win32more.Windows.Win32.Foundation.COLORREF: ...
@winfunctype('GDI32.dll')
def SetPixelV(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, color: win32more.Windows.Win32.Foundation.COLORREF) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def SetPolyFillMode(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, mode: win32more.Windows.Win32.Graphics.Gdi.CREATE_POLYGON_RGN_MODE) -> Int32: ...
@winfunctype('GDI32.dll')
def StretchBlt(hdcDest: win32more.Windows.Win32.Graphics.Gdi.HDC, xDest: Int32, yDest: Int32, wDest: Int32, hDest: Int32, hdcSrc: win32more.Windows.Win32.Graphics.Gdi.HDC, xSrc: Int32, ySrc: Int32, wSrc: Int32, hSrc: Int32, rop: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def SetRectRgn(hrgn: win32more.Windows.Win32.Graphics.Gdi.HRGN, left: Int32, top: Int32, right: Int32, bottom: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def StretchDIBits(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, xDest: Int32, yDest: Int32, DestWidth: Int32, DestHeight: Int32, xSrc: Int32, ySrc: Int32, SrcWidth: Int32, SrcHeight: Int32, lpBits: VoidPtr, lpbmi: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFO), iUsage: win32more.Windows.Win32.Graphics.Gdi.DIB_USAGE, rop: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE) -> Int32: ...
@winfunctype('GDI32.dll')
def SetROP2(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, rop2: win32more.Windows.Win32.Graphics.Gdi.R2_MODE) -> Int32: ...
@winfunctype('GDI32.dll')
def SetStretchBltMode(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, mode: win32more.Windows.Win32.Graphics.Gdi.STRETCH_BLT_MODE) -> Int32: ...
@winfunctype('GDI32.dll')
def SetSystemPaletteUse(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, use: win32more.Windows.Win32.Graphics.Gdi.SYSTEM_PALETTE_USE) -> UInt32: ...
@winfunctype('GDI32.dll')
def SetTextCharacterExtra(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, extra: Int32) -> Int32: ...
@winfunctype('GDI32.dll')
def SetTextColor(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, color: win32more.Windows.Win32.Foundation.COLORREF) -> win32more.Windows.Win32.Foundation.COLORREF: ...
@winfunctype('GDI32.dll')
def SetTextAlign(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, align: win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS) -> UInt32: ...
@winfunctype('GDI32.dll')
def SetTextJustification(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, extra: Int32, count: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def UpdateColors(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSIMG32.dll')
def AlphaBlend(hdcDest: win32more.Windows.Win32.Graphics.Gdi.HDC, xoriginDest: Int32, yoriginDest: Int32, wDest: Int32, hDest: Int32, hdcSrc: win32more.Windows.Win32.Graphics.Gdi.HDC, xoriginSrc: Int32, yoriginSrc: Int32, wSrc: Int32, hSrc: Int32, ftn: win32more.Windows.Win32.Graphics.Gdi.BLENDFUNCTION) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSIMG32.dll')
def TransparentBlt(hdcDest: win32more.Windows.Win32.Graphics.Gdi.HDC, xoriginDest: Int32, yoriginDest: Int32, wDest: Int32, hDest: Int32, hdcSrc: win32more.Windows.Win32.Graphics.Gdi.HDC, xoriginSrc: Int32, yoriginSrc: Int32, wSrc: Int32, hSrc: Int32, crTransparent: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('MSIMG32.dll')
def GradientFill(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, pVertex: POINTER(win32more.Windows.Win32.Graphics.Gdi.TRIVERTEX), nVertex: UInt32, pMesh: VoidPtr, nMesh: UInt32, ulMode: win32more.Windows.Win32.Graphics.Gdi.GRADIENT_FILL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GdiAlphaBlend(hdcDest: win32more.Windows.Win32.Graphics.Gdi.HDC, xoriginDest: Int32, yoriginDest: Int32, wDest: Int32, hDest: Int32, hdcSrc: win32more.Windows.Win32.Graphics.Gdi.HDC, xoriginSrc: Int32, yoriginSrc: Int32, wSrc: Int32, hSrc: Int32, ftn: win32more.Windows.Win32.Graphics.Gdi.BLENDFUNCTION) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GdiTransparentBlt(hdcDest: win32more.Windows.Win32.Graphics.Gdi.HDC, xoriginDest: Int32, yoriginDest: Int32, wDest: Int32, hDest: Int32, hdcSrc: win32more.Windows.Win32.Graphics.Gdi.HDC, xoriginSrc: Int32, yoriginSrc: Int32, wSrc: Int32, hSrc: Int32, crTransparent: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GdiGradientFill(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, pVertex: POINTER(win32more.Windows.Win32.Graphics.Gdi.TRIVERTEX), nVertex: UInt32, pMesh: VoidPtr, nCount: UInt32, ulMode: win32more.Windows.Win32.Graphics.Gdi.GRADIENT_FILL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def PlayMetaFileRecord(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpHandleTable: POINTER(win32more.Windows.Win32.Graphics.Gdi.HANDLETABLE), lpMR: POINTER(win32more.Windows.Win32.Graphics.Gdi.METARECORD), noObjs: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def EnumMetaFile(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hmf: win32more.Windows.Win32.Graphics.Gdi.HMETAFILE, proc: win32more.Windows.Win32.Graphics.Gdi.MFENUMPROC, param3: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def CloseEnhMetaFile(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE: ...
@winfunctype('GDI32.dll')
def CopyEnhMetaFileA(hEnh: win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE, lpFileName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE: ...
@winfunctype('GDI32.dll')
def CopyEnhMetaFileW(hEnh: win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE, lpFileName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE: ...
CopyEnhMetaFile = UnicodeAlias('CopyEnhMetaFileW')
@winfunctype('GDI32.dll')
def CreateEnhMetaFileA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpFilename: win32more.Windows.Win32.Foundation.PSTR, lprc: POINTER(win32more.Windows.Win32.Foundation.RECT), lpDesc: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
@winfunctype('GDI32.dll')
def CreateEnhMetaFileW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpFilename: win32more.Windows.Win32.Foundation.PWSTR, lprc: POINTER(win32more.Windows.Win32.Foundation.RECT), lpDesc: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
CreateEnhMetaFile = UnicodeAlias('CreateEnhMetaFileW')
@winfunctype('GDI32.dll')
def DeleteEnhMetaFile(hmf: win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def EnumEnhMetaFile(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hmf: win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE, proc: win32more.Windows.Win32.Graphics.Gdi.ENHMFENUMPROC, param3: VoidPtr, lpRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetEnhMetaFileA(lpName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE: ...
@winfunctype('GDI32.dll')
def GetEnhMetaFileW(lpName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE: ...
GetEnhMetaFile = UnicodeAlias('GetEnhMetaFileW')
@winfunctype('GDI32.dll')
def GetEnhMetaFileBits(hEMF: win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE, nSize: UInt32, lpData: POINTER(Byte)) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetEnhMetaFileDescriptionA(hemf: win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE, cchBuffer: UInt32, lpDescription: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetEnhMetaFileDescriptionW(hemf: win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE, cchBuffer: UInt32, lpDescription: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
GetEnhMetaFileDescription = UnicodeAlias('GetEnhMetaFileDescriptionW')
@winfunctype('GDI32.dll')
def GetEnhMetaFileHeader(hemf: win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE, nSize: UInt32, lpEnhMetaHeader: POINTER(win32more.Windows.Win32.Graphics.Gdi.ENHMETAHEADER)) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetEnhMetaFilePaletteEntries(hemf: win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE, nNumEntries: UInt32, lpPaletteEntries: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY)) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetWinMetaFileBits(hemf: win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE, cbData16: UInt32, pData16: POINTER(Byte), iMapMode: Int32, hdcRef: win32more.Windows.Win32.Graphics.Gdi.HDC) -> UInt32: ...
@winfunctype('GDI32.dll')
def PlayEnhMetaFile(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hmf: win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE, lprect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def PlayEnhMetaFileRecord(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, pht: POINTER(win32more.Windows.Win32.Graphics.Gdi.HANDLETABLE), pmr: POINTER(win32more.Windows.Win32.Graphics.Gdi.ENHMETARECORD), cht: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def SetEnhMetaFileBits(nSize: UInt32, pb: POINTER(Byte)) -> win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE: ...
@winfunctype('GDI32.dll')
def GdiComment(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, nSize: UInt32, lpData: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetTextMetricsA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lptm: POINTER(win32more.Windows.Win32.Graphics.Gdi.TEXTMETRICA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetTextMetricsW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lptm: POINTER(win32more.Windows.Win32.Graphics.Gdi.TEXTMETRICW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetTextMetrics = UnicodeAlias('GetTextMetricsW')
@winfunctype('GDI32.dll')
def AngleArc(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, r: UInt32, StartAngle: Single, SweepAngle: Single) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def PolyPolyline(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, apt: POINTER(win32more.Windows.Win32.Foundation.POINT), asz: POINTER(UInt32), csz: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetWorldTransform(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpxf: POINTER(win32more.Windows.Win32.Graphics.Gdi.XFORM)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def SetWorldTransform(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpxf: POINTER(win32more.Windows.Win32.Graphics.Gdi.XFORM)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def ModifyWorldTransform(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpxf: POINTER(win32more.Windows.Win32.Graphics.Gdi.XFORM), mode: win32more.Windows.Win32.Graphics.Gdi.MODIFY_WORLD_TRANSFORM_MODE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def CombineTransform(lpxfOut: POINTER(win32more.Windows.Win32.Graphics.Gdi.XFORM), lpxf1: POINTER(win32more.Windows.Win32.Graphics.Gdi.XFORM), lpxf2: POINTER(win32more.Windows.Win32.Graphics.Gdi.XFORM)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def CreateDIBSection(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, pbmi: POINTER(win32more.Windows.Win32.Graphics.Gdi.BITMAPINFO), usage: win32more.Windows.Win32.Graphics.Gdi.DIB_USAGE, ppvBits: POINTER(VoidPtr), hSection: win32more.Windows.Win32.Foundation.HANDLE, offset: UInt32) -> win32more.Windows.Win32.Graphics.Gdi.HBITMAP: ...
@winfunctype('GDI32.dll')
def GetDIBColorTable(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iStart: UInt32, cEntries: UInt32, prgbq: POINTER(win32more.Windows.Win32.Graphics.Gdi.RGBQUAD)) -> UInt32: ...
@winfunctype('GDI32.dll')
def SetDIBColorTable(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iStart: UInt32, cEntries: UInt32, prgbq: POINTER(win32more.Windows.Win32.Graphics.Gdi.RGBQUAD)) -> UInt32: ...
@winfunctype('GDI32.dll')
def SetColorAdjustment(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpca: POINTER(win32more.Windows.Win32.Graphics.Gdi.COLORADJUSTMENT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetColorAdjustment(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpca: POINTER(win32more.Windows.Win32.Graphics.Gdi.COLORADJUSTMENT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def CreateHalftonePalette(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Graphics.Gdi.HPALETTE: ...
@winfunctype('GDI32.dll')
def AbortPath(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def ArcTo(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, left: Int32, top: Int32, right: Int32, bottom: Int32, xr1: Int32, yr1: Int32, xr2: Int32, yr2: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def BeginPath(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def CloseFigure(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def EndPath(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def FillPath(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def FlattenPath(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetPath(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, apt: POINTER(win32more.Windows.Win32.Foundation.POINT), aj: POINTER(Byte), cpt: Int32) -> Int32: ...
@winfunctype('GDI32.dll')
def PathToRegion(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Graphics.Gdi.HRGN: ...
@winfunctype('GDI32.dll')
def PolyDraw(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, apt: POINTER(win32more.Windows.Win32.Foundation.POINT), aj: POINTER(Byte), cpt: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def SelectClipPath(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, mode: win32more.Windows.Win32.Graphics.Gdi.RGN_COMBINE_MODE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def SetArcDirection(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, dir: win32more.Windows.Win32.Graphics.Gdi.ARC_DIRECTION) -> Int32: ...
@winfunctype('GDI32.dll')
def SetMiterLimit(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, limit: Single, old: POINTER(Single)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def StrokeAndFillPath(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def StrokePath(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def WidenPath(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def ExtCreatePen(iPenStyle: UInt32, cWidth: UInt32, plbrush: POINTER(win32more.Windows.Win32.Graphics.Gdi.LOGBRUSH), cStyle: UInt32, pstyle: POINTER(UInt32)) -> win32more.Windows.Win32.Graphics.Gdi.HPEN: ...
@winfunctype('GDI32.dll')
def GetMiterLimit(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, plimit: POINTER(Single)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetArcDirection(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> Int32: ...
@winfunctype('GDI32.dll')
def GetObjectW(h: win32more.Windows.Win32.Graphics.Gdi.HGDIOBJ, c: Int32, pv: VoidPtr) -> Int32: ...
GetObject = UnicodeAlias('GetObjectW')
@winfunctype('GDI32.dll')
def MoveToEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, lppt: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def TextOutA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, lpString: win32more.Windows.Win32.Foundation.PSTR, c: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def TextOutW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, lpString: win32more.Windows.Win32.Foundation.PWSTR, c: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
TextOut = UnicodeAlias('TextOutW')
@winfunctype('GDI32.dll')
def ExtTextOutA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, options: win32more.Windows.Win32.Graphics.Gdi.ETO_OPTIONS, lprect: POINTER(win32more.Windows.Win32.Foundation.RECT), lpString: win32more.Windows.Win32.Foundation.PSTR, c: UInt32, lpDx: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def ExtTextOutW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, options: win32more.Windows.Win32.Graphics.Gdi.ETO_OPTIONS, lprect: POINTER(win32more.Windows.Win32.Foundation.RECT), lpString: win32more.Windows.Win32.Foundation.PWSTR, c: UInt32, lpDx: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
ExtTextOut = UnicodeAlias('ExtTextOutW')
@winfunctype('GDI32.dll')
def PolyTextOutA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, ppt: POINTER(win32more.Windows.Win32.Graphics.Gdi.POLYTEXTA), nstrings: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def PolyTextOutW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, ppt: POINTER(win32more.Windows.Win32.Graphics.Gdi.POLYTEXTW), nstrings: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
PolyTextOut = UnicodeAlias('PolyTextOutW')
@winfunctype('GDI32.dll')
def CreatePolygonRgn(pptl: POINTER(win32more.Windows.Win32.Foundation.POINT), cPoint: Int32, iMode: win32more.Windows.Win32.Graphics.Gdi.CREATE_POLYGON_RGN_MODE) -> win32more.Windows.Win32.Graphics.Gdi.HRGN: ...
@winfunctype('GDI32.dll')
def DPtoLP(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lppt: POINTER(win32more.Windows.Win32.Foundation.POINT), c: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def LPtoDP(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lppt: POINTER(win32more.Windows.Win32.Foundation.POINT), c: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def Polygon(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, apt: POINTER(win32more.Windows.Win32.Foundation.POINT), cpt: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def Polyline(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, apt: POINTER(win32more.Windows.Win32.Foundation.POINT), cpt: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def PolyBezier(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, apt: POINTER(win32more.Windows.Win32.Foundation.POINT), cpt: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def PolyBezierTo(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, apt: POINTER(win32more.Windows.Win32.Foundation.POINT), cpt: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def PolylineTo(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, apt: POINTER(win32more.Windows.Win32.Foundation.POINT), cpt: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def SetViewportExtEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, lpsz: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def SetViewportOrgEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, lppt: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def SetWindowExtEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, lpsz: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def SetWindowOrgEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, lppt: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def OffsetViewportOrgEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, lppt: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def OffsetWindowOrgEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, lppt: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def ScaleViewportExtEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, xn: Int32, dx: Int32, yn: Int32, yd: Int32, lpsz: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def ScaleWindowExtEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, xn: Int32, xd: Int32, yn: Int32, yd: Int32, lpsz: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def SetBitmapDimensionEx(hbm: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, w: Int32, h: Int32, lpsz: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def SetBrushOrgEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, lppt: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GetTextFaceA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, c: Int32, lpName: win32more.Windows.Win32.Foundation.PSTR) -> Int32: ...
@winfunctype('GDI32.dll')
def GetTextFaceW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, c: Int32, lpName: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
GetTextFace = UnicodeAlias('GetTextFaceW')
@winfunctype('GDI32.dll')
def GetKerningPairsA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, nPairs: UInt32, lpKernPair: POINTER(win32more.Windows.Win32.Graphics.Gdi.KERNINGPAIR)) -> UInt32: ...
@winfunctype('GDI32.dll')
def GetKerningPairsW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, nPairs: UInt32, lpKernPair: POINTER(win32more.Windows.Win32.Graphics.Gdi.KERNINGPAIR)) -> UInt32: ...
GetKerningPairs = UnicodeAlias('GetKerningPairsW')
@winfunctype('GDI32.dll')
def GetDCOrgEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lppt: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def FixBrushOrgEx(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, ptl: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def UnrealizeObject(h: win32more.Windows.Win32.Graphics.Gdi.HGDIOBJ) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GdiFlush() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GdiSetBatchLimit(dw: UInt32) -> UInt32: ...
@winfunctype('GDI32.dll')
def GdiGetBatchLimit() -> UInt32: ...
@winfunctype('OPENGL32.dll')
def wglSwapMultipleBuffers(param0: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.Gdi.WGLSWAP)) -> UInt32: ...
@cfunctype('FONTSUB.dll')
def CreateFontPackage(puchSrcBuffer: POINTER(Byte), ulSrcBufferSize: UInt32, ppuchFontPackageBuffer: POINTER(POINTER(Byte)), pulFontPackageBufferSize: POINTER(UInt32), pulBytesWritten: POINTER(UInt32), usFlag: UInt16, usTTCIndex: UInt16, usSubsetFormat: UInt16, usSubsetLanguage: UInt16, usSubsetPlatform: win32more.Windows.Win32.Graphics.Gdi.CREATE_FONT_PACKAGE_SUBSET_PLATFORM, usSubsetEncoding: win32more.Windows.Win32.Graphics.Gdi.CREATE_FONT_PACKAGE_SUBSET_ENCODING, pusSubsetKeepList: POINTER(UInt16), usSubsetListCount: UInt16, lpfnAllocate: win32more.Windows.Win32.Graphics.Gdi.CFP_ALLOCPROC, lpfnReAllocate: win32more.Windows.Win32.Graphics.Gdi.CFP_REALLOCPROC, lpfnFree: win32more.Windows.Win32.Graphics.Gdi.CFP_FREEPROC, lpvReserved: VoidPtr) -> UInt32: ...
@cfunctype('FONTSUB.dll')
def MergeFontPackage(puchMergeFontBuffer: POINTER(Byte), ulMergeFontBufferSize: UInt32, puchFontPackageBuffer: POINTER(Byte), ulFontPackageBufferSize: UInt32, ppuchDestBuffer: POINTER(POINTER(Byte)), pulDestBufferSize: POINTER(UInt32), pulBytesWritten: POINTER(UInt32), usMode: UInt16, lpfnAllocate: win32more.Windows.Win32.Graphics.Gdi.CFP_ALLOCPROC, lpfnReAllocate: win32more.Windows.Win32.Graphics.Gdi.CFP_REALLOCPROC, lpfnFree: win32more.Windows.Win32.Graphics.Gdi.CFP_FREEPROC, lpvReserved: VoidPtr) -> UInt32: ...
@winfunctype('t2embed.dll')
def TTEmbedFont(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, ulFlags: win32more.Windows.Win32.Graphics.Gdi.TTEMBED_FLAGS, ulCharSet: win32more.Windows.Win32.Graphics.Gdi.EMBED_FONT_CHARSET, pulPrivStatus: POINTER(win32more.Windows.Win32.Graphics.Gdi.EMBEDDED_FONT_PRIV_STATUS), pulStatus: POINTER(UInt32), lpfnWriteToStream: win32more.Windows.Win32.Graphics.Gdi.WRITEEMBEDPROC, lpvWriteStream: VoidPtr, pusCharCodeSet: POINTER(UInt16), usCharCodeCount: UInt16, usLanguage: UInt16, pTTEmbedInfo: POINTER(win32more.Windows.Win32.Graphics.Gdi.TTEMBEDINFO)) -> Int32: ...
@winfunctype('t2embed.dll')
def TTEmbedFontFromFileA(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, szFontFileName: win32more.Windows.Win32.Foundation.PSTR, usTTCIndex: UInt16, ulFlags: win32more.Windows.Win32.Graphics.Gdi.TTEMBED_FLAGS, ulCharSet: win32more.Windows.Win32.Graphics.Gdi.EMBED_FONT_CHARSET, pulPrivStatus: POINTER(win32more.Windows.Win32.Graphics.Gdi.EMBEDDED_FONT_PRIV_STATUS), pulStatus: POINTER(UInt32), lpfnWriteToStream: win32more.Windows.Win32.Graphics.Gdi.WRITEEMBEDPROC, lpvWriteStream: VoidPtr, pusCharCodeSet: POINTER(UInt16), usCharCodeCount: UInt16, usLanguage: UInt16, pTTEmbedInfo: POINTER(win32more.Windows.Win32.Graphics.Gdi.TTEMBEDINFO)) -> Int32: ...
@winfunctype('t2embed.dll')
def TTLoadEmbeddedFont(phFontReference: POINTER(win32more.Windows.Win32.Foundation.HANDLE), ulFlags: UInt32, pulPrivStatus: POINTER(win32more.Windows.Win32.Graphics.Gdi.EMBEDDED_FONT_PRIV_STATUS), ulPrivs: win32more.Windows.Win32.Graphics.Gdi.FONT_LICENSE_PRIVS, pulStatus: POINTER(win32more.Windows.Win32.Graphics.Gdi.TTLOAD_EMBEDDED_FONT_STATUS), lpfnReadFromStream: win32more.Windows.Win32.Graphics.Gdi.READEMBEDPROC, lpvReadStream: VoidPtr, szWinFamilyName: win32more.Windows.Win32.Foundation.PWSTR, szMacFamilyName: win32more.Windows.Win32.Foundation.PSTR, pTTLoadInfo: POINTER(win32more.Windows.Win32.Graphics.Gdi.TTLOADINFO)) -> Int32: ...
@winfunctype('t2embed.dll')
def TTGetEmbeddedFontInfo(ulFlags: win32more.Windows.Win32.Graphics.Gdi.TTEMBED_FLAGS, pulPrivStatus: POINTER(UInt32), ulPrivs: win32more.Windows.Win32.Graphics.Gdi.FONT_LICENSE_PRIVS, pulStatus: POINTER(UInt32), lpfnReadFromStream: win32more.Windows.Win32.Graphics.Gdi.READEMBEDPROC, lpvReadStream: VoidPtr, pTTLoadInfo: POINTER(win32more.Windows.Win32.Graphics.Gdi.TTLOADINFO)) -> Int32: ...
@winfunctype('t2embed.dll')
def TTDeleteEmbeddedFont(hFontReference: win32more.Windows.Win32.Foundation.HANDLE, ulFlags: UInt32, pulStatus: POINTER(UInt32)) -> Int32: ...
@winfunctype('t2embed.dll')
def TTGetEmbeddingType(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, pulEmbedType: POINTER(win32more.Windows.Win32.Graphics.Gdi.EMBEDDED_FONT_PRIV_STATUS)) -> Int32: ...
@winfunctype('t2embed.dll')
def TTCharToUnicode(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, pucCharCodes: POINTER(Byte), ulCharCodeSize: UInt32, pusShortCodes: POINTER(UInt16), ulShortCodeSize: UInt32, ulFlags: UInt32) -> Int32: ...
@winfunctype('t2embed.dll')
def TTRunValidationTests(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, pTestParam: POINTER(win32more.Windows.Win32.Graphics.Gdi.TTVALIDATIONTESTSPARAMS)) -> Int32: ...
@winfunctype('t2embed.dll')
def TTIsEmbeddingEnabled(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, pbEnabled: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> Int32: ...
@winfunctype('t2embed.dll')
def TTIsEmbeddingEnabledForFacename(lpszFacename: win32more.Windows.Win32.Foundation.PSTR, pbEnabled: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> Int32: ...
@winfunctype('t2embed.dll')
def TTEnableEmbeddingForFacename(lpszFacename: win32more.Windows.Win32.Foundation.PSTR, bEnable: win32more.Windows.Win32.Foundation.BOOL) -> Int32: ...
@winfunctype('t2embed.dll')
def TTEmbedFontEx(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, ulFlags: win32more.Windows.Win32.Graphics.Gdi.TTEMBED_FLAGS, ulCharSet: win32more.Windows.Win32.Graphics.Gdi.EMBED_FONT_CHARSET, pulPrivStatus: POINTER(win32more.Windows.Win32.Graphics.Gdi.EMBEDDED_FONT_PRIV_STATUS), pulStatus: POINTER(UInt32), lpfnWriteToStream: win32more.Windows.Win32.Graphics.Gdi.WRITEEMBEDPROC, lpvWriteStream: VoidPtr, pulCharCodeSet: POINTER(UInt32), usCharCodeCount: UInt16, usLanguage: UInt16, pTTEmbedInfo: POINTER(win32more.Windows.Win32.Graphics.Gdi.TTEMBEDINFO)) -> Int32: ...
@winfunctype('t2embed.dll')
def TTRunValidationTestsEx(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, pTestParam: POINTER(win32more.Windows.Win32.Graphics.Gdi.TTVALIDATIONTESTSPARAMSEX)) -> Int32: ...
@winfunctype('t2embed.dll')
def TTGetNewFontName(phFontReference: POINTER(win32more.Windows.Win32.Foundation.HANDLE), wzWinFamilyName: win32more.Windows.Win32.Foundation.PWSTR, cchMaxWinName: Int32, szMacFamilyName: win32more.Windows.Win32.Foundation.PSTR, cchMaxMacName: Int32) -> Int32: ...
@winfunctype('USER32.dll')
def DrawEdge(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, qrc: POINTER(win32more.Windows.Win32.Foundation.RECT), edge: win32more.Windows.Win32.Graphics.Gdi.DRAWEDGE_FLAGS, grfFlags: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DrawFrameControl(param0: win32more.Windows.Win32.Graphics.Gdi.HDC, param1: POINTER(win32more.Windows.Win32.Foundation.RECT), param2: win32more.Windows.Win32.Graphics.Gdi.DFC_TYPE, param3: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DrawCaption(hwnd: win32more.Windows.Win32.Foundation.HWND, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lprect: POINTER(win32more.Windows.Win32.Foundation.RECT), flags: win32more.Windows.Win32.Graphics.Gdi.DRAW_CAPTION_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DrawAnimatedRects(hwnd: win32more.Windows.Win32.Foundation.HWND, idAni: Int32, lprcFrom: POINTER(win32more.Windows.Win32.Foundation.RECT), lprcTo: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DrawTextA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpchText: win32more.Windows.Win32.Foundation.PSTR, cchText: Int32, lprc: POINTER(win32more.Windows.Win32.Foundation.RECT), format: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT) -> Int32: ...
@winfunctype('USER32.dll')
def DrawTextW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpchText: win32more.Windows.Win32.Foundation.PWSTR, cchText: Int32, lprc: POINTER(win32more.Windows.Win32.Foundation.RECT), format: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT) -> Int32: ...
DrawText = UnicodeAlias('DrawTextW')
@winfunctype('USER32.dll')
def DrawTextExA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpchText: win32more.Windows.Win32.Foundation.PSTR, cchText: Int32, lprc: POINTER(win32more.Windows.Win32.Foundation.RECT), format: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT, lpdtp: POINTER(win32more.Windows.Win32.Graphics.Gdi.DRAWTEXTPARAMS)) -> Int32: ...
@winfunctype('USER32.dll')
def DrawTextExW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpchText: win32more.Windows.Win32.Foundation.PWSTR, cchText: Int32, lprc: POINTER(win32more.Windows.Win32.Foundation.RECT), format: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT, lpdtp: POINTER(win32more.Windows.Win32.Graphics.Gdi.DRAWTEXTPARAMS)) -> Int32: ...
DrawTextEx = UnicodeAlias('DrawTextExW')
@winfunctype('USER32.dll')
def GrayStringA(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, hBrush: win32more.Windows.Win32.Graphics.Gdi.HBRUSH, lpOutputFunc: win32more.Windows.Win32.Graphics.Gdi.GRAYSTRINGPROC, lpData: win32more.Windows.Win32.Foundation.LPARAM, nCount: Int32, X: Int32, Y: Int32, nWidth: Int32, nHeight: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GrayStringW(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, hBrush: win32more.Windows.Win32.Graphics.Gdi.HBRUSH, lpOutputFunc: win32more.Windows.Win32.Graphics.Gdi.GRAYSTRINGPROC, lpData: win32more.Windows.Win32.Foundation.LPARAM, nCount: Int32, X: Int32, Y: Int32, nWidth: Int32, nHeight: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
GrayString = UnicodeAlias('GrayStringW')
@winfunctype('USER32.dll')
def DrawStateA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hbrFore: win32more.Windows.Win32.Graphics.Gdi.HBRUSH, qfnCallBack: win32more.Windows.Win32.Graphics.Gdi.DRAWSTATEPROC, lData: win32more.Windows.Win32.Foundation.LPARAM, wData: win32more.Windows.Win32.Foundation.WPARAM, x: Int32, y: Int32, cx: Int32, cy: Int32, uFlags: win32more.Windows.Win32.Graphics.Gdi.DRAWSTATE_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DrawStateW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, hbrFore: win32more.Windows.Win32.Graphics.Gdi.HBRUSH, qfnCallBack: win32more.Windows.Win32.Graphics.Gdi.DRAWSTATEPROC, lData: win32more.Windows.Win32.Foundation.LPARAM, wData: win32more.Windows.Win32.Foundation.WPARAM, x: Int32, y: Int32, cx: Int32, cy: Int32, uFlags: win32more.Windows.Win32.Graphics.Gdi.DRAWSTATE_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
DrawState = UnicodeAlias('DrawStateW')
@winfunctype('USER32.dll')
def TabbedTextOutA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, lpString: win32more.Windows.Win32.Foundation.PSTR, chCount: Int32, nTabPositions: Int32, lpnTabStopPositions: POINTER(Int32), nTabOrigin: Int32) -> Int32: ...
@winfunctype('USER32.dll')
def TabbedTextOutW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, lpString: win32more.Windows.Win32.Foundation.PWSTR, chCount: Int32, nTabPositions: Int32, lpnTabStopPositions: POINTER(Int32), nTabOrigin: Int32) -> Int32: ...
TabbedTextOut = UnicodeAlias('TabbedTextOutW')
@winfunctype('USER32.dll')
def GetTabbedTextExtentA(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpString: win32more.Windows.Win32.Foundation.PSTR, chCount: Int32, nTabPositions: Int32, lpnTabStopPositions: POINTER(Int32)) -> UInt32: ...
@winfunctype('USER32.dll')
def GetTabbedTextExtentW(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpString: win32more.Windows.Win32.Foundation.PWSTR, chCount: Int32, nTabPositions: Int32, lpnTabStopPositions: POINTER(Int32)) -> UInt32: ...
GetTabbedTextExtent = UnicodeAlias('GetTabbedTextExtentW')
@winfunctype('USER32.dll')
def UpdateWindow(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def PaintDesktop(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def WindowFromDC(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def GetDC(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
@winfunctype('USER32.dll')
def GetDCEx(hWnd: win32more.Windows.Win32.Foundation.HWND, hrgnClip: win32more.Windows.Win32.Graphics.Gdi.HRGN, flags: win32more.Windows.Win32.Graphics.Gdi.GET_DCX_FLAGS) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
@winfunctype('USER32.dll')
def GetWindowDC(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
@winfunctype('USER32.dll')
def ReleaseDC(hWnd: win32more.Windows.Win32.Foundation.HWND, hDC: win32more.Windows.Win32.Graphics.Gdi.HDC) -> Int32: ...
@winfunctype('USER32.dll')
def BeginPaint(hWnd: win32more.Windows.Win32.Foundation.HWND, lpPaint: POINTER(win32more.Windows.Win32.Graphics.Gdi.PAINTSTRUCT)) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
@winfunctype('USER32.dll')
def EndPaint(hWnd: win32more.Windows.Win32.Foundation.HWND, lpPaint: POINTER(win32more.Windows.Win32.Graphics.Gdi.PAINTSTRUCT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetUpdateRect(hWnd: win32more.Windows.Win32.Foundation.HWND, lpRect: POINTER(win32more.Windows.Win32.Foundation.RECT), bErase: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetUpdateRgn(hWnd: win32more.Windows.Win32.Foundation.HWND, hRgn: win32more.Windows.Win32.Graphics.Gdi.HRGN, bErase: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Graphics.Gdi.GDI_REGION_TYPE: ...
@winfunctype('USER32.dll')
def SetWindowRgn(hWnd: win32more.Windows.Win32.Foundation.HWND, hRgn: win32more.Windows.Win32.Graphics.Gdi.HRGN, bRedraw: win32more.Windows.Win32.Foundation.BOOL) -> Int32: ...
@winfunctype('USER32.dll')
def GetWindowRgn(hWnd: win32more.Windows.Win32.Foundation.HWND, hRgn: win32more.Windows.Win32.Graphics.Gdi.HRGN) -> win32more.Windows.Win32.Graphics.Gdi.GDI_REGION_TYPE: ...
@winfunctype('USER32.dll')
def GetWindowRgnBox(hWnd: win32more.Windows.Win32.Foundation.HWND, lprc: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Graphics.Gdi.GDI_REGION_TYPE: ...
@winfunctype('USER32.dll')
def ExcludeUpdateRgn(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, hWnd: win32more.Windows.Win32.Foundation.HWND) -> Int32: ...
@winfunctype('USER32.dll')
def InvalidateRect(hWnd: win32more.Windows.Win32.Foundation.HWND, lpRect: POINTER(win32more.Windows.Win32.Foundation.RECT), bErase: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ValidateRect(hWnd: win32more.Windows.Win32.Foundation.HWND, lpRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def InvalidateRgn(hWnd: win32more.Windows.Win32.Foundation.HWND, hRgn: win32more.Windows.Win32.Graphics.Gdi.HRGN, bErase: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ValidateRgn(hWnd: win32more.Windows.Win32.Foundation.HWND, hRgn: win32more.Windows.Win32.Graphics.Gdi.HRGN) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def RedrawWindow(hWnd: win32more.Windows.Win32.Foundation.HWND, lprcUpdate: POINTER(win32more.Windows.Win32.Foundation.RECT), hrgnUpdate: win32more.Windows.Win32.Graphics.Gdi.HRGN, flags: win32more.Windows.Win32.Graphics.Gdi.REDRAW_WINDOW_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def LockWindowUpdate(hWndLock: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ClientToScreen(hWnd: win32more.Windows.Win32.Foundation.HWND, lpPoint: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ScreenToClient(hWnd: win32more.Windows.Win32.Foundation.HWND, lpPoint: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def MapWindowPoints(hWndFrom: win32more.Windows.Win32.Foundation.HWND, hWndTo: win32more.Windows.Win32.Foundation.HWND, lpPoints: POINTER(win32more.Windows.Win32.Foundation.POINT), cPoints: UInt32) -> Int32: ...
@winfunctype('USER32.dll')
def GetSysColor(nIndex: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX) -> UInt32: ...
@winfunctype('USER32.dll')
def GetSysColorBrush(nIndex: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX) -> win32more.Windows.Win32.Graphics.Gdi.HBRUSH: ...
@winfunctype('USER32.dll')
def SetSysColors(cElements: Int32, lpaElements: POINTER(Int32), lpaRgbValues: POINTER(win32more.Windows.Win32.Foundation.COLORREF)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DrawFocusRect(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, lprc: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def FillRect(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, lprc: POINTER(win32more.Windows.Win32.Foundation.RECT), hbr: win32more.Windows.Win32.Graphics.Gdi.HBRUSH) -> Int32: ...
@winfunctype('USER32.dll')
def FrameRect(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, lprc: POINTER(win32more.Windows.Win32.Foundation.RECT), hbr: win32more.Windows.Win32.Graphics.Gdi.HBRUSH) -> Int32: ...
@winfunctype('USER32.dll')
def InvertRect(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, lprc: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetRect(lprc: POINTER(win32more.Windows.Win32.Foundation.RECT), xLeft: Int32, yTop: Int32, xRight: Int32, yBottom: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetRectEmpty(lprc: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def CopyRect(lprcDst: POINTER(win32more.Windows.Win32.Foundation.RECT), lprcSrc: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def InflateRect(lprc: POINTER(win32more.Windows.Win32.Foundation.RECT), dx: Int32, dy: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def IntersectRect(lprcDst: POINTER(win32more.Windows.Win32.Foundation.RECT), lprcSrc1: POINTER(win32more.Windows.Win32.Foundation.RECT), lprcSrc2: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def UnionRect(lprcDst: POINTER(win32more.Windows.Win32.Foundation.RECT), lprcSrc1: POINTER(win32more.Windows.Win32.Foundation.RECT), lprcSrc2: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SubtractRect(lprcDst: POINTER(win32more.Windows.Win32.Foundation.RECT), lprcSrc1: POINTER(win32more.Windows.Win32.Foundation.RECT), lprcSrc2: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def OffsetRect(lprc: POINTER(win32more.Windows.Win32.Foundation.RECT), dx: Int32, dy: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def IsRectEmpty(lprc: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def EqualRect(lprc1: POINTER(win32more.Windows.Win32.Foundation.RECT), lprc2: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def PtInRect(lprc: POINTER(win32more.Windows.Win32.Foundation.RECT), pt: win32more.Windows.Win32.Foundation.POINT) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def LoadBitmapA(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpBitmapName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Gdi.HBITMAP: ...
@winfunctype('USER32.dll')
def LoadBitmapW(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, lpBitmapName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Graphics.Gdi.HBITMAP: ...
LoadBitmap = UnicodeAlias('LoadBitmapW')
@winfunctype('USER32.dll')
def ChangeDisplaySettingsA(lpDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), dwFlags: win32more.Windows.Win32.Graphics.Gdi.CDS_TYPE) -> win32more.Windows.Win32.Graphics.Gdi.DISP_CHANGE: ...
@winfunctype('USER32.dll')
def ChangeDisplaySettingsW(lpDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW), dwFlags: win32more.Windows.Win32.Graphics.Gdi.CDS_TYPE) -> win32more.Windows.Win32.Graphics.Gdi.DISP_CHANGE: ...
ChangeDisplaySettings = UnicodeAlias('ChangeDisplaySettingsW')
@winfunctype('USER32.dll')
def ChangeDisplaySettingsExA(lpszDeviceName: win32more.Windows.Win32.Foundation.PSTR, lpDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), hwnd: win32more.Windows.Win32.Foundation.HWND, dwflags: win32more.Windows.Win32.Graphics.Gdi.CDS_TYPE, lParam: VoidPtr) -> win32more.Windows.Win32.Graphics.Gdi.DISP_CHANGE: ...
@winfunctype('USER32.dll')
def ChangeDisplaySettingsExW(lpszDeviceName: win32more.Windows.Win32.Foundation.PWSTR, lpDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW), hwnd: win32more.Windows.Win32.Foundation.HWND, dwflags: win32more.Windows.Win32.Graphics.Gdi.CDS_TYPE, lParam: VoidPtr) -> win32more.Windows.Win32.Graphics.Gdi.DISP_CHANGE: ...
ChangeDisplaySettingsEx = UnicodeAlias('ChangeDisplaySettingsExW')
@winfunctype('USER32.dll')
def EnumDisplaySettingsA(lpszDeviceName: win32more.Windows.Win32.Foundation.PSTR, iModeNum: win32more.Windows.Win32.Graphics.Gdi.ENUM_DISPLAY_SETTINGS_MODE, lpDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def EnumDisplaySettingsW(lpszDeviceName: win32more.Windows.Win32.Foundation.PWSTR, iModeNum: win32more.Windows.Win32.Graphics.Gdi.ENUM_DISPLAY_SETTINGS_MODE, lpDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumDisplaySettings = UnicodeAlias('EnumDisplaySettingsW')
@winfunctype('USER32.dll')
def EnumDisplaySettingsExA(lpszDeviceName: win32more.Windows.Win32.Foundation.PSTR, iModeNum: win32more.Windows.Win32.Graphics.Gdi.ENUM_DISPLAY_SETTINGS_MODE, lpDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), dwFlags: win32more.Windows.Win32.Graphics.Gdi.ENUM_DISPLAY_SETTINGS_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def EnumDisplaySettingsExW(lpszDeviceName: win32more.Windows.Win32.Foundation.PWSTR, iModeNum: win32more.Windows.Win32.Graphics.Gdi.ENUM_DISPLAY_SETTINGS_MODE, lpDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW), dwFlags: win32more.Windows.Win32.Graphics.Gdi.ENUM_DISPLAY_SETTINGS_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumDisplaySettingsEx = UnicodeAlias('EnumDisplaySettingsExW')
@winfunctype('USER32.dll')
def EnumDisplayDevicesA(lpDevice: win32more.Windows.Win32.Foundation.PSTR, iDevNum: UInt32, lpDisplayDevice: POINTER(win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICEA), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def EnumDisplayDevicesW(lpDevice: win32more.Windows.Win32.Foundation.PWSTR, iDevNum: UInt32, lpDisplayDevice: POINTER(win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICEW), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumDisplayDevices = UnicodeAlias('EnumDisplayDevicesW')
@winfunctype('USER32.dll')
def MonitorFromPoint(pt: win32more.Windows.Win32.Foundation.POINT, dwFlags: win32more.Windows.Win32.Graphics.Gdi.MONITOR_FROM_FLAGS) -> win32more.Windows.Win32.Graphics.Gdi.HMONITOR: ...
@winfunctype('USER32.dll')
def MonitorFromRect(lprc: POINTER(win32more.Windows.Win32.Foundation.RECT), dwFlags: win32more.Windows.Win32.Graphics.Gdi.MONITOR_FROM_FLAGS) -> win32more.Windows.Win32.Graphics.Gdi.HMONITOR: ...
@winfunctype('USER32.dll')
def MonitorFromWindow(hwnd: win32more.Windows.Win32.Foundation.HWND, dwFlags: win32more.Windows.Win32.Graphics.Gdi.MONITOR_FROM_FLAGS) -> win32more.Windows.Win32.Graphics.Gdi.HMONITOR: ...
@winfunctype('USER32.dll')
def GetMonitorInfoA(hMonitor: win32more.Windows.Win32.Graphics.Gdi.HMONITOR, lpmi: POINTER(win32more.Windows.Win32.Graphics.Gdi.MONITORINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetMonitorInfoW(hMonitor: win32more.Windows.Win32.Graphics.Gdi.HMONITOR, lpmi: POINTER(win32more.Windows.Win32.Graphics.Gdi.MONITORINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetMonitorInfo = UnicodeAlias('GetMonitorInfoW')
@winfunctype('USER32.dll')
def EnumDisplayMonitors(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lprcClip: POINTER(win32more.Windows.Win32.Foundation.RECT), lpfnEnum: win32more.Windows.Win32.Graphics.Gdi.MONITORENUMPROC, dwData: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
BACKGROUND_MODE = UInt32
OPAQUE: win32more.Windows.Win32.Graphics.Gdi.BACKGROUND_MODE = 2
TRANSPARENT: win32more.Windows.Win32.Graphics.Gdi.BACKGROUND_MODE = 1
class BITMAP(Structure):
    bmType: Int32
    bmWidth: Int32
    bmHeight: Int32
    bmWidthBytes: Int32
    bmPlanes: UInt16
    bmBitsPixel: UInt16
    bmBits: VoidPtr
class BITMAPCOREHEADER(Structure):
    bcSize: UInt32
    bcWidth: UInt16
    bcHeight: UInt16
    bcPlanes: UInt16
    bcBitCount: UInt16
class BITMAPCOREINFO(Structure):
    bmciHeader: win32more.Windows.Win32.Graphics.Gdi.BITMAPCOREHEADER
    bmciColors: win32more.Windows.Win32.Graphics.Gdi.RGBTRIPLE * 1
class BITMAPFILEHEADER(Structure):
    bfType: UInt16
    bfSize: UInt32
    bfReserved1: UInt16
    bfReserved2: UInt16
    bfOffBits: UInt32
    _pack_ = 2
class BITMAPINFO(Structure):
    bmiHeader: win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER
    bmiColors: win32more.Windows.Win32.Graphics.Gdi.RGBQUAD * 1
class BITMAPINFOHEADER(Structure):
    biSize: UInt32
    biWidth: Int32
    biHeight: Int32
    biPlanes: UInt16
    biBitCount: UInt16
    biCompression: UInt32
    biSizeImage: UInt32
    biXPelsPerMeter: Int32
    biYPelsPerMeter: Int32
    biClrUsed: UInt32
    biClrImportant: UInt32
class BITMAPV4HEADER(Structure):
    bV4Size: UInt32
    bV4Width: Int32
    bV4Height: Int32
    bV4Planes: UInt16
    bV4BitCount: UInt16
    bV4V4Compression: win32more.Windows.Win32.Graphics.Gdi.BI_COMPRESSION
    bV4SizeImage: UInt32
    bV4XPelsPerMeter: Int32
    bV4YPelsPerMeter: Int32
    bV4ClrUsed: UInt32
    bV4ClrImportant: UInt32
    bV4RedMask: UInt32
    bV4GreenMask: UInt32
    bV4BlueMask: UInt32
    bV4AlphaMask: UInt32
    bV4CSType: UInt32
    bV4Endpoints: win32more.Windows.Win32.Graphics.Gdi.CIEXYZTRIPLE
    bV4GammaRed: UInt32
    bV4GammaGreen: UInt32
    bV4GammaBlue: UInt32
class BITMAPV5HEADER(Structure):
    bV5Size: UInt32
    bV5Width: Int32
    bV5Height: Int32
    bV5Planes: UInt16
    bV5BitCount: UInt16
    bV5Compression: win32more.Windows.Win32.Graphics.Gdi.BI_COMPRESSION
    bV5SizeImage: UInt32
    bV5XPelsPerMeter: Int32
    bV5YPelsPerMeter: Int32
    bV5ClrUsed: UInt32
    bV5ClrImportant: UInt32
    bV5RedMask: UInt32
    bV5GreenMask: UInt32
    bV5BlueMask: UInt32
    bV5AlphaMask: UInt32
    bV5CSType: UInt32
    bV5Endpoints: win32more.Windows.Win32.Graphics.Gdi.CIEXYZTRIPLE
    bV5GammaRed: UInt32
    bV5GammaGreen: UInt32
    bV5GammaBlue: UInt32
    bV5Intent: UInt32
    bV5ProfileData: UInt32
    bV5ProfileSize: UInt32
    bV5Reserved: UInt32
BI_COMPRESSION = UInt32
BI_RGB: win32more.Windows.Win32.Graphics.Gdi.BI_COMPRESSION = 0
BI_RLE8: win32more.Windows.Win32.Graphics.Gdi.BI_COMPRESSION = 1
BI_RLE4: win32more.Windows.Win32.Graphics.Gdi.BI_COMPRESSION = 2
BI_BITFIELDS: win32more.Windows.Win32.Graphics.Gdi.BI_COMPRESSION = 3
BI_JPEG: win32more.Windows.Win32.Graphics.Gdi.BI_COMPRESSION = 4
BI_PNG: win32more.Windows.Win32.Graphics.Gdi.BI_COMPRESSION = 5
class BLENDFUNCTION(Structure):
    BlendOp: Byte
    BlendFlags: Byte
    SourceConstantAlpha: Byte
    AlphaFormat: Byte
BRUSH_STYLE = UInt32
BS_SOLID: win32more.Windows.Win32.Graphics.Gdi.BRUSH_STYLE = 0
BS_NULL: win32more.Windows.Win32.Graphics.Gdi.BRUSH_STYLE = 1
BS_HOLLOW: win32more.Windows.Win32.Graphics.Gdi.BRUSH_STYLE = 1
BS_HATCHED: win32more.Windows.Win32.Graphics.Gdi.BRUSH_STYLE = 2
BS_PATTERN: win32more.Windows.Win32.Graphics.Gdi.BRUSH_STYLE = 3
BS_INDEXED: win32more.Windows.Win32.Graphics.Gdi.BRUSH_STYLE = 4
BS_DIBPATTERN: win32more.Windows.Win32.Graphics.Gdi.BRUSH_STYLE = 5
BS_DIBPATTERNPT: win32more.Windows.Win32.Graphics.Gdi.BRUSH_STYLE = 6
BS_PATTERN8X8: win32more.Windows.Win32.Graphics.Gdi.BRUSH_STYLE = 7
BS_DIBPATTERN8X8: win32more.Windows.Win32.Graphics.Gdi.BRUSH_STYLE = 8
BS_MONOPATTERN: win32more.Windows.Win32.Graphics.Gdi.BRUSH_STYLE = 9
CDS_TYPE = UInt32
CDS_FULLSCREEN: win32more.Windows.Win32.Graphics.Gdi.CDS_TYPE = 4
CDS_GLOBAL: win32more.Windows.Win32.Graphics.Gdi.CDS_TYPE = 8
CDS_NORESET: win32more.Windows.Win32.Graphics.Gdi.CDS_TYPE = 268435456
CDS_RESET: win32more.Windows.Win32.Graphics.Gdi.CDS_TYPE = 1073741824
CDS_SET_PRIMARY: win32more.Windows.Win32.Graphics.Gdi.CDS_TYPE = 16
CDS_TEST: win32more.Windows.Win32.Graphics.Gdi.CDS_TYPE = 2
CDS_UPDATEREGISTRY: win32more.Windows.Win32.Graphics.Gdi.CDS_TYPE = 1
CDS_VIDEOPARAMETERS: win32more.Windows.Win32.Graphics.Gdi.CDS_TYPE = 32
CDS_ENABLE_UNSAFE_MODES: win32more.Windows.Win32.Graphics.Gdi.CDS_TYPE = 256
CDS_DISABLE_UNSAFE_MODES: win32more.Windows.Win32.Graphics.Gdi.CDS_TYPE = 512
CDS_RESET_EX: win32more.Windows.Win32.Graphics.Gdi.CDS_TYPE = 536870912
@cfunctype_pointer
def CFP_ALLOCPROC(param0: UIntPtr) -> VoidPtr: ...
@cfunctype_pointer
def CFP_FREEPROC(param0: VoidPtr) -> Void: ...
@cfunctype_pointer
def CFP_REALLOCPROC(param0: VoidPtr, param1: UIntPtr) -> VoidPtr: ...
class CIEXYZ(Structure):
    ciexyzX: Int32
    ciexyzY: Int32
    ciexyzZ: Int32
class CIEXYZTRIPLE(Structure):
    ciexyzRed: win32more.Windows.Win32.Graphics.Gdi.CIEXYZ
    ciexyzGreen: win32more.Windows.Win32.Graphics.Gdi.CIEXYZ
    ciexyzBlue: win32more.Windows.Win32.Graphics.Gdi.CIEXYZ
class COLORADJUSTMENT(Structure):
    caSize: UInt16
    caFlags: UInt16
    caIlluminantIndex: UInt16
    caRedGamma: UInt16
    caGreenGamma: UInt16
    caBlueGamma: UInt16
    caReferenceBlack: UInt16
    caReferenceWhite: UInt16
    caContrast: Int16
    caBrightness: Int16
    caColorfulness: Int16
    caRedGreenTint: Int16
CREATE_FONT_PACKAGE_SUBSET_ENCODING = Int16
TTFCFP_STD_MAC_CHAR_SET: win32more.Windows.Win32.Graphics.Gdi.CREATE_FONT_PACKAGE_SUBSET_ENCODING = 0
TTFCFP_SYMBOL_CHAR_SET: win32more.Windows.Win32.Graphics.Gdi.CREATE_FONT_PACKAGE_SUBSET_ENCODING = 0
TTFCFP_UNICODE_CHAR_SET: win32more.Windows.Win32.Graphics.Gdi.CREATE_FONT_PACKAGE_SUBSET_ENCODING = 1
CREATE_FONT_PACKAGE_SUBSET_PLATFORM = Int16
TTFCFP_UNICODE_PLATFORMID: win32more.Windows.Win32.Graphics.Gdi.CREATE_FONT_PACKAGE_SUBSET_PLATFORM = 0
TTFCFP_ISO_PLATFORMID: win32more.Windows.Win32.Graphics.Gdi.CREATE_FONT_PACKAGE_SUBSET_PLATFORM = 2
CREATE_POLYGON_RGN_MODE = Int32
ALTERNATE: win32more.Windows.Win32.Graphics.Gdi.CREATE_POLYGON_RGN_MODE = 1
WINDING: win32more.Windows.Win32.Graphics.Gdi.CREATE_POLYGON_RGN_MODE = 2
DC_LAYOUT = UInt32
LAYOUT_BITMAPORIENTATIONPRESERVED: win32more.Windows.Win32.Graphics.Gdi.DC_LAYOUT = 8
LAYOUT_RTL: win32more.Windows.Win32.Graphics.Gdi.DC_LAYOUT = 1
class DESIGNVECTOR(Structure):
    dvReserved: UInt32
    dvNumAxes: UInt32
    dvValues: Int32 * 16
class DEVMODEA(Structure):
    dmDeviceName: Byte * 32
    dmSpecVersion: UInt16
    dmDriverVersion: UInt16
    dmSize: UInt16
    dmDriverExtra: UInt16
    dmFields: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS
    Anonymous1: _Anonymous1_e__Union
    dmColor: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_COLOR
    dmDuplex: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_DUPLEX
    dmYResolution: Int16
    dmTTOption: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_TRUETYPE_OPTION
    dmCollate: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_COLLATE
    dmFormName: Byte * 32
    dmLogPixels: UInt16
    dmBitsPerPel: UInt32
    dmPelsWidth: UInt32
    dmPelsHeight: UInt32
    Anonymous2: _Anonymous2_e__Union
    dmDisplayFrequency: UInt32
    dmICMMethod: UInt32
    dmICMIntent: UInt32
    dmMediaType: UInt32
    dmDitherType: UInt32
    dmReserved1: UInt32
    dmReserved2: UInt32
    dmPanningWidth: UInt32
    dmPanningHeight: UInt32
    class _Anonymous1_e__Union(Union):
        Anonymous1: _Anonymous1_e__Struct
        Anonymous2: _Anonymous2_e__Struct
        class _Anonymous1_e__Struct(Structure):
            dmOrientation: Int16
            dmPaperSize: Int16
            dmPaperLength: Int16
            dmPaperWidth: Int16
            dmScale: Int16
            dmCopies: Int16
            dmDefaultSource: Int16
            dmPrintQuality: Int16
        class _Anonymous2_e__Struct(Structure):
            dmPosition: win32more.Windows.Win32.Foundation.POINTL
            dmDisplayOrientation: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_DISPLAY_ORIENTATION
            dmDisplayFixedOutput: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_DISPLAY_FIXED_OUTPUT
    class _Anonymous2_e__Union(Union):
        dmDisplayFlags: UInt32
        dmNup: UInt32
class DEVMODEW(Structure):
    dmDeviceName: Char * 32
    dmSpecVersion: UInt16
    dmDriverVersion: UInt16
    dmSize: UInt16
    dmDriverExtra: UInt16
    dmFields: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS
    Anonymous1: _Anonymous1_e__Union
    dmColor: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_COLOR
    dmDuplex: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_DUPLEX
    dmYResolution: Int16
    dmTTOption: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_TRUETYPE_OPTION
    dmCollate: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_COLLATE
    dmFormName: Char * 32
    dmLogPixels: UInt16
    dmBitsPerPel: UInt32
    dmPelsWidth: UInt32
    dmPelsHeight: UInt32
    Anonymous2: _Anonymous2_e__Union
    dmDisplayFrequency: UInt32
    dmICMMethod: UInt32
    dmICMIntent: UInt32
    dmMediaType: UInt32
    dmDitherType: UInt32
    dmReserved1: UInt32
    dmReserved2: UInt32
    dmPanningWidth: UInt32
    dmPanningHeight: UInt32
    class _Anonymous1_e__Union(Union):
        Anonymous1: _Anonymous1_e__Struct
        Anonymous2: _Anonymous2_e__Struct
        class _Anonymous1_e__Struct(Structure):
            dmOrientation: Int16
            dmPaperSize: Int16
            dmPaperLength: Int16
            dmPaperWidth: Int16
            dmScale: Int16
            dmCopies: Int16
            dmDefaultSource: Int16
            dmPrintQuality: Int16
        class _Anonymous2_e__Struct(Structure):
            dmPosition: win32more.Windows.Win32.Foundation.POINTL
            dmDisplayOrientation: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_DISPLAY_ORIENTATION
            dmDisplayFixedOutput: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_DISPLAY_FIXED_OUTPUT
    class _Anonymous2_e__Union(Union):
        dmDisplayFlags: UInt32
        dmNup: UInt32
DEVMODE = UnicodeAlias('DEVMODEW')
DEVMODE_COLLATE = Int16
DMCOLLATE_FALSE: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_COLLATE = 0
DMCOLLATE_TRUE: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_COLLATE = 1
DEVMODE_COLOR = Int16
DMCOLOR_MONOCHROME: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_COLOR = 1
DMCOLOR_COLOR: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_COLOR = 2
DEVMODE_DISPLAY_FIXED_OUTPUT = UInt32
DMDFO_DEFAULT: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_DISPLAY_FIXED_OUTPUT = 0
DMDFO_STRETCH: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_DISPLAY_FIXED_OUTPUT = 1
DMDFO_CENTER: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_DISPLAY_FIXED_OUTPUT = 2
DEVMODE_DISPLAY_ORIENTATION = UInt32
DMDO_DEFAULT: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_DISPLAY_ORIENTATION = 0
DMDO_90: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_DISPLAY_ORIENTATION = 1
DMDO_180: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_DISPLAY_ORIENTATION = 2
DMDO_270: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_DISPLAY_ORIENTATION = 3
DEVMODE_DUPLEX = Int16
DMDUP_SIMPLEX: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_DUPLEX = 1
DMDUP_VERTICAL: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_DUPLEX = 2
DMDUP_HORIZONTAL: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_DUPLEX = 3
DEVMODE_FIELD_FLAGS = UInt32
DM_SPECVERSION: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 1025
DM_ORIENTATION: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 1
DM_PAPERSIZE: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 2
DM_PAPERLENGTH: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 4
DM_PAPERWIDTH: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 8
DM_SCALE: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 16
DM_POSITION: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 32
DM_NUP: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 64
DM_DISPLAYORIENTATION: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 128
DM_COPIES: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 256
DM_DEFAULTSOURCE: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 512
DM_PRINTQUALITY: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 1024
DM_COLOR: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 2048
DM_DUPLEX: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 4096
DM_YRESOLUTION: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 8192
DM_TTOPTION: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 16384
DM_COLLATE: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 32768
DM_FORMNAME: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 65536
DM_LOGPIXELS: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 131072
DM_BITSPERPEL: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 262144
DM_PELSWIDTH: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 524288
DM_PELSHEIGHT: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 1048576
DM_DISPLAYFLAGS: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 2097152
DM_DISPLAYFREQUENCY: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 4194304
DM_ICMMETHOD: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 8388608
DM_ICMINTENT: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 16777216
DM_MEDIATYPE: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 33554432
DM_DITHERTYPE: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 67108864
DM_PANNINGWIDTH: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 134217728
DM_PANNINGHEIGHT: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 268435456
DM_DISPLAYFIXEDOUTPUT: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 536870912
DM_INTERLACED: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 2
DM_UPDATE: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 1
DM_COPY: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 2
DM_PROMPT: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 4
DM_MODIFY: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 8
DM_IN_BUFFER: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 8
DM_IN_PROMPT: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 4
DM_OUT_BUFFER: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 2
DM_OUT_DEFAULT: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_FIELD_FLAGS = 1
DEVMODE_TRUETYPE_OPTION = Int16
DMTT_BITMAP: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_TRUETYPE_OPTION = 1
DMTT_DOWNLOAD: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_TRUETYPE_OPTION = 2
DMTT_SUBDEV: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_TRUETYPE_OPTION = 3
DMTT_DOWNLOAD_OUTLINE: win32more.Windows.Win32.Graphics.Gdi.DEVMODE_TRUETYPE_OPTION = 4
DFCS_STATE = UInt32
DFCS_CAPTIONCLOSE: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 0
DFCS_CAPTIONMIN: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 1
DFCS_CAPTIONMAX: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 2
DFCS_CAPTIONRESTORE: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 3
DFCS_CAPTIONHELP: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 4
DFCS_MENUARROW: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 0
DFCS_MENUCHECK: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 1
DFCS_MENUBULLET: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 2
DFCS_MENUARROWRIGHT: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 4
DFCS_SCROLLUP: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 0
DFCS_SCROLLDOWN: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 1
DFCS_SCROLLLEFT: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 2
DFCS_SCROLLRIGHT: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 3
DFCS_SCROLLCOMBOBOX: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 5
DFCS_SCROLLSIZEGRIP: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 8
DFCS_SCROLLSIZEGRIPRIGHT: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 16
DFCS_BUTTONCHECK: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 0
DFCS_BUTTONRADIOIMAGE: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 1
DFCS_BUTTONRADIOMASK: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 2
DFCS_BUTTONRADIO: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 4
DFCS_BUTTON3STATE: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 8
DFCS_BUTTONPUSH: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 16
DFCS_INACTIVE: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 256
DFCS_PUSHED: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 512
DFCS_CHECKED: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 1024
DFCS_TRANSPARENT: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 2048
DFCS_HOT: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 4096
DFCS_ADJUSTRECT: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 8192
DFCS_FLAT: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 16384
DFCS_MONO: win32more.Windows.Win32.Graphics.Gdi.DFCS_STATE = 32768
DFC_TYPE = UInt32
DFC_CAPTION: win32more.Windows.Win32.Graphics.Gdi.DFC_TYPE = 1
DFC_MENU: win32more.Windows.Win32.Graphics.Gdi.DFC_TYPE = 2
DFC_SCROLL: win32more.Windows.Win32.Graphics.Gdi.DFC_TYPE = 3
DFC_BUTTON: win32more.Windows.Win32.Graphics.Gdi.DFC_TYPE = 4
DFC_POPUPMENU: win32more.Windows.Win32.Graphics.Gdi.DFC_TYPE = 5
class DIBSECTION(Structure):
    dsBm: win32more.Windows.Win32.Graphics.Gdi.BITMAP
    dsBmih: win32more.Windows.Win32.Graphics.Gdi.BITMAPINFOHEADER
    dsBitfields: UInt32 * 3
    dshSection: win32more.Windows.Win32.Foundation.HANDLE
    dsOffset: UInt32
DIB_USAGE = UInt32
DIB_RGB_COLORS: win32more.Windows.Win32.Graphics.Gdi.DIB_USAGE = 0
DIB_PAL_COLORS: win32more.Windows.Win32.Graphics.Gdi.DIB_USAGE = 1
DISPLAYCONFIG_COLOR_ENCODING = Int32
DISPLAYCONFIG_COLOR_ENCODING_RGB: win32more.Windows.Win32.Graphics.Gdi.DISPLAYCONFIG_COLOR_ENCODING = 0
DISPLAYCONFIG_COLOR_ENCODING_YCBCR444: win32more.Windows.Win32.Graphics.Gdi.DISPLAYCONFIG_COLOR_ENCODING = 1
DISPLAYCONFIG_COLOR_ENCODING_YCBCR422: win32more.Windows.Win32.Graphics.Gdi.DISPLAYCONFIG_COLOR_ENCODING = 2
DISPLAYCONFIG_COLOR_ENCODING_YCBCR420: win32more.Windows.Win32.Graphics.Gdi.DISPLAYCONFIG_COLOR_ENCODING = 3
DISPLAYCONFIG_COLOR_ENCODING_INTENSITY: win32more.Windows.Win32.Graphics.Gdi.DISPLAYCONFIG_COLOR_ENCODING = 4
class DISPLAY_DEVICEA(Structure):
    cb: UInt32
    DeviceName: win32more.Windows.Win32.Foundation.CHAR * 32
    DeviceString: win32more.Windows.Win32.Foundation.CHAR * 128
    StateFlags: win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICE_STATE_FLAGS
    DeviceID: win32more.Windows.Win32.Foundation.CHAR * 128
    DeviceKey: win32more.Windows.Win32.Foundation.CHAR * 128
class DISPLAY_DEVICEW(Structure):
    cb: UInt32
    DeviceName: Char * 32
    DeviceString: Char * 128
    StateFlags: win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICE_STATE_FLAGS
    DeviceID: Char * 128
    DeviceKey: Char * 128
DISPLAY_DEVICE = UnicodeAlias('DISPLAY_DEVICEW')
DISPLAY_DEVICE_STATE_FLAGS = UInt32
DISPLAY_DEVICE_ATTACHED_TO_DESKTOP: win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICE_STATE_FLAGS = 1
DISPLAY_DEVICE_MULTI_DRIVER: win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICE_STATE_FLAGS = 2
DISPLAY_DEVICE_PRIMARY_DEVICE: win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICE_STATE_FLAGS = 4
DISPLAY_DEVICE_MIRRORING_DRIVER: win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICE_STATE_FLAGS = 8
DISPLAY_DEVICE_VGA_COMPATIBLE: win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICE_STATE_FLAGS = 16
DISPLAY_DEVICE_REMOVABLE: win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICE_STATE_FLAGS = 32
DISPLAY_DEVICE_ACC_DRIVER: win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICE_STATE_FLAGS = 64
DISPLAY_DEVICE_MODESPRUNED: win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICE_STATE_FLAGS = 134217728
DISPLAY_DEVICE_RDPUDD: win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICE_STATE_FLAGS = 16777216
DISPLAY_DEVICE_REMOTE: win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICE_STATE_FLAGS = 67108864
DISPLAY_DEVICE_DISCONNECT: win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICE_STATE_FLAGS = 33554432
DISPLAY_DEVICE_TS_COMPATIBLE: win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICE_STATE_FLAGS = 2097152
DISPLAY_DEVICE_UNSAFE_MODES_ON: win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICE_STATE_FLAGS = 524288
DISPLAY_DEVICE_ACTIVE: win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICE_STATE_FLAGS = 1
DISPLAY_DEVICE_ATTACHED: win32more.Windows.Win32.Graphics.Gdi.DISPLAY_DEVICE_STATE_FLAGS = 2
DISP_CHANGE = Int32
DISP_CHANGE_SUCCESSFUL: win32more.Windows.Win32.Graphics.Gdi.DISP_CHANGE = 0
DISP_CHANGE_RESTART: win32more.Windows.Win32.Graphics.Gdi.DISP_CHANGE = 1
DISP_CHANGE_FAILED: win32more.Windows.Win32.Graphics.Gdi.DISP_CHANGE = -1
DISP_CHANGE_BADMODE: win32more.Windows.Win32.Graphics.Gdi.DISP_CHANGE = -2
DISP_CHANGE_NOTUPDATED: win32more.Windows.Win32.Graphics.Gdi.DISP_CHANGE = -3
DISP_CHANGE_BADFLAGS: win32more.Windows.Win32.Graphics.Gdi.DISP_CHANGE = -4
DISP_CHANGE_BADPARAM: win32more.Windows.Win32.Graphics.Gdi.DISP_CHANGE = -5
DISP_CHANGE_BADDUALVIEW: win32more.Windows.Win32.Graphics.Gdi.DISP_CHANGE = -6
DRAWEDGE_FLAGS = UInt32
BDR_RAISEDOUTER: win32more.Windows.Win32.Graphics.Gdi.DRAWEDGE_FLAGS = 1
BDR_SUNKENOUTER: win32more.Windows.Win32.Graphics.Gdi.DRAWEDGE_FLAGS = 2
BDR_RAISEDINNER: win32more.Windows.Win32.Graphics.Gdi.DRAWEDGE_FLAGS = 4
BDR_SUNKENINNER: win32more.Windows.Win32.Graphics.Gdi.DRAWEDGE_FLAGS = 8
BDR_OUTER: win32more.Windows.Win32.Graphics.Gdi.DRAWEDGE_FLAGS = 3
BDR_INNER: win32more.Windows.Win32.Graphics.Gdi.DRAWEDGE_FLAGS = 12
BDR_RAISED: win32more.Windows.Win32.Graphics.Gdi.DRAWEDGE_FLAGS = 5
BDR_SUNKEN: win32more.Windows.Win32.Graphics.Gdi.DRAWEDGE_FLAGS = 10
EDGE_RAISED: win32more.Windows.Win32.Graphics.Gdi.DRAWEDGE_FLAGS = 5
EDGE_SUNKEN: win32more.Windows.Win32.Graphics.Gdi.DRAWEDGE_FLAGS = 10
EDGE_ETCHED: win32more.Windows.Win32.Graphics.Gdi.DRAWEDGE_FLAGS = 6
EDGE_BUMP: win32more.Windows.Win32.Graphics.Gdi.DRAWEDGE_FLAGS = 9
@winfunctype_pointer
def DRAWSTATEPROC(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lData: win32more.Windows.Win32.Foundation.LPARAM, wData: win32more.Windows.Win32.Foundation.WPARAM, cx: Int32, cy: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
DRAWSTATE_FLAGS = UInt32
DST_COMPLEX: win32more.Windows.Win32.Graphics.Gdi.DRAWSTATE_FLAGS = 0
DST_TEXT: win32more.Windows.Win32.Graphics.Gdi.DRAWSTATE_FLAGS = 1
DST_PREFIXTEXT: win32more.Windows.Win32.Graphics.Gdi.DRAWSTATE_FLAGS = 2
DST_ICON: win32more.Windows.Win32.Graphics.Gdi.DRAWSTATE_FLAGS = 3
DST_BITMAP: win32more.Windows.Win32.Graphics.Gdi.DRAWSTATE_FLAGS = 4
DSS_NORMAL: win32more.Windows.Win32.Graphics.Gdi.DRAWSTATE_FLAGS = 0
DSS_UNION: win32more.Windows.Win32.Graphics.Gdi.DRAWSTATE_FLAGS = 16
DSS_DISABLED: win32more.Windows.Win32.Graphics.Gdi.DRAWSTATE_FLAGS = 32
DSS_MONO: win32more.Windows.Win32.Graphics.Gdi.DRAWSTATE_FLAGS = 128
DSS_HIDEPREFIX: win32more.Windows.Win32.Graphics.Gdi.DRAWSTATE_FLAGS = 512
DSS_PREFIXONLY: win32more.Windows.Win32.Graphics.Gdi.DRAWSTATE_FLAGS = 1024
DSS_RIGHT: win32more.Windows.Win32.Graphics.Gdi.DRAWSTATE_FLAGS = 32768
class DRAWTEXTPARAMS(Structure):
    cbSize: UInt32
    iTabLength: Int32
    iLeftMargin: Int32
    iRightMargin: Int32
    uiLengthDrawn: UInt32
DRAW_CAPTION_FLAGS = UInt32
DC_ACTIVE: win32more.Windows.Win32.Graphics.Gdi.DRAW_CAPTION_FLAGS = 1
DC_BUTTONS: win32more.Windows.Win32.Graphics.Gdi.DRAW_CAPTION_FLAGS = 4096
DC_GRADIENT: win32more.Windows.Win32.Graphics.Gdi.DRAW_CAPTION_FLAGS = 32
DC_ICON: win32more.Windows.Win32.Graphics.Gdi.DRAW_CAPTION_FLAGS = 4
DC_INBUTTON: win32more.Windows.Win32.Graphics.Gdi.DRAW_CAPTION_FLAGS = 16
DC_SMALLCAP: win32more.Windows.Win32.Graphics.Gdi.DRAW_CAPTION_FLAGS = 2
DC_TEXT: win32more.Windows.Win32.Graphics.Gdi.DRAW_CAPTION_FLAGS = 8
DRAW_EDGE_FLAGS = UInt32
BF_ADJUST: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 8192
BF_BOTTOM: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 8
BF_BOTTOMLEFT: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 9
BF_BOTTOMRIGHT: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 12
BF_DIAGONAL: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 16
BF_DIAGONAL_ENDBOTTOMLEFT: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 25
BF_DIAGONAL_ENDBOTTOMRIGHT: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 28
BF_DIAGONAL_ENDTOPLEFT: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 19
BF_DIAGONAL_ENDTOPRIGHT: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 22
BF_FLAT: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 16384
BF_LEFT: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 1
BF_MIDDLE: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 2048
BF_MONO: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 32768
BF_RECT: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 15
BF_RIGHT: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 4
BF_SOFT: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 4096
BF_TOP: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 2
BF_TOPLEFT: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 3
BF_TOPRIGHT: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS = 6
DRAW_TEXT_FORMAT = UInt32
DT_BOTTOM: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 8
DT_CALCRECT: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 1024
DT_CENTER: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 1
DT_EDITCONTROL: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 8192
DT_END_ELLIPSIS: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 32768
DT_EXPANDTABS: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 64
DT_EXTERNALLEADING: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 512
DT_HIDEPREFIX: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 1048576
DT_INTERNAL: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 4096
DT_LEFT: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 0
DT_MODIFYSTRING: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 65536
DT_NOCLIP: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 256
DT_NOFULLWIDTHCHARBREAK: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 524288
DT_NOPREFIX: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 2048
DT_PATH_ELLIPSIS: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 16384
DT_PREFIXONLY: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 2097152
DT_RIGHT: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 2
DT_RTLREADING: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 131072
DT_SINGLELINE: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 32
DT_TABSTOP: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 128
DT_TOP: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 0
DT_VCENTER: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 4
DT_WORDBREAK: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 16
DT_WORD_ELLIPSIS: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT = 262144
EMBEDDED_FONT_PRIV_STATUS = UInt32
EMBED_PREVIEWPRINT: win32more.Windows.Win32.Graphics.Gdi.EMBEDDED_FONT_PRIV_STATUS = 1
EMBED_EDITABLE: win32more.Windows.Win32.Graphics.Gdi.EMBEDDED_FONT_PRIV_STATUS = 2
EMBED_INSTALLABLE: win32more.Windows.Win32.Graphics.Gdi.EMBEDDED_FONT_PRIV_STATUS = 3
EMBED_NOEMBEDDING: win32more.Windows.Win32.Graphics.Gdi.EMBEDDED_FONT_PRIV_STATUS = 4
EMBED_FONT_CHARSET = UInt32
CHARSET_UNICODE: win32more.Windows.Win32.Graphics.Gdi.EMBED_FONT_CHARSET = 1
CHARSET_SYMBOL: win32more.Windows.Win32.Graphics.Gdi.EMBED_FONT_CHARSET = 2
class EMR(Structure):
    iType: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE
    nSize: UInt32
class EMRALPHABLEND(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    xDest: Int32
    yDest: Int32
    cxDest: Int32
    cyDest: Int32
    dwRop: UInt32
    xSrc: Int32
    ySrc: Int32
    xformSrc: win32more.Windows.Win32.Graphics.Gdi.XFORM
    crBkColorSrc: win32more.Windows.Win32.Foundation.COLORREF
    iUsageSrc: UInt32
    offBmiSrc: UInt32
    cbBmiSrc: UInt32
    offBitsSrc: UInt32
    cbBitsSrc: UInt32
    cxSrc: Int32
    cySrc: Int32
class EMRANGLEARC(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ptlCenter: win32more.Windows.Win32.Foundation.POINTL
    nRadius: UInt32
    eStartAngle: Single
    eSweepAngle: Single
class EMRARC(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBox: win32more.Windows.Win32.Foundation.RECTL
    ptlStart: win32more.Windows.Win32.Foundation.POINTL
    ptlEnd: win32more.Windows.Win32.Foundation.POINTL
class EMRBITBLT(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    xDest: Int32
    yDest: Int32
    cxDest: Int32
    cyDest: Int32
    dwRop: UInt32
    xSrc: Int32
    ySrc: Int32
    xformSrc: win32more.Windows.Win32.Graphics.Gdi.XFORM
    crBkColorSrc: win32more.Windows.Win32.Foundation.COLORREF
    iUsageSrc: UInt32
    offBmiSrc: UInt32
    cbBmiSrc: UInt32
    offBitsSrc: UInt32
    cbBitsSrc: UInt32
class EMRCOLORCORRECTPALETTE(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ihPalette: UInt32
    nFirstEntry: UInt32
    nPalEntries: UInt32
    nReserved: UInt32
class EMRCOLORMATCHTOTARGET(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    dwAction: UInt32
    dwFlags: UInt32
    cbName: UInt32
    cbData: UInt32
    Data: Byte * 1
class EMRCREATEBRUSHINDIRECT(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ihBrush: UInt32
    lb: win32more.Windows.Win32.Graphics.Gdi.LOGBRUSH32
class EMRCREATEDIBPATTERNBRUSHPT(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ihBrush: UInt32
    iUsage: UInt32
    offBmi: UInt32
    cbBmi: UInt32
    offBits: UInt32
    cbBits: UInt32
class EMRCREATEMONOBRUSH(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ihBrush: UInt32
    iUsage: UInt32
    offBmi: UInt32
    cbBmi: UInt32
    offBits: UInt32
    cbBits: UInt32
class EMRCREATEPALETTE(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ihPal: UInt32
    lgpl: win32more.Windows.Win32.Graphics.Gdi.LOGPALETTE
class EMRCREATEPEN(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ihPen: UInt32
    lopn: win32more.Windows.Win32.Graphics.Gdi.LOGPEN
class EMRELLIPSE(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBox: win32more.Windows.Win32.Foundation.RECTL
class EMREOF(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    nPalEntries: UInt32
    offPalEntries: UInt32
    nSizeLast: UInt32
class EMREXCLUDECLIPRECT(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclClip: win32more.Windows.Win32.Foundation.RECTL
class EMREXTCREATEFONTINDIRECTW(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ihFont: UInt32
    elfw: win32more.Windows.Win32.Graphics.Gdi.EXTLOGFONTW
class EMREXTCREATEPEN(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ihPen: UInt32
    offBmi: UInt32
    cbBmi: UInt32
    offBits: UInt32
    cbBits: UInt32
    elp: win32more.Windows.Win32.Graphics.Gdi.EXTLOGPEN32
class EMREXTESCAPE(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    iEscape: Int32
    cbEscData: Int32
    EscData: Byte * 1
class EMREXTFLOODFILL(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ptlStart: win32more.Windows.Win32.Foundation.POINTL
    crColor: win32more.Windows.Win32.Foundation.COLORREF
    iMode: UInt32
class EMREXTSELECTCLIPRGN(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    cbRgnData: UInt32
    iMode: UInt32
    RgnData: Byte * 1
class EMREXTTEXTOUTA(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    iGraphicsMode: UInt32
    exScale: Single
    eyScale: Single
    emrtext: win32more.Windows.Win32.Graphics.Gdi.EMRTEXT
class EMRFILLPATH(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
class EMRFILLRGN(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    cbRgnData: UInt32
    ihBrush: UInt32
    RgnData: Byte * 1
class EMRFORMAT(Structure):
    dSignature: UInt32
    nVersion: UInt32
    cbData: UInt32
    offData: UInt32
class EMRFRAMERGN(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    cbRgnData: UInt32
    ihBrush: UInt32
    szlStroke: win32more.Windows.Win32.Foundation.SIZE
    RgnData: Byte * 1
class EMRGDICOMMENT(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    cbData: UInt32
    Data: Byte * 1
class EMRGLSBOUNDEDRECORD(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    cbData: UInt32
    Data: Byte * 1
class EMRGLSRECORD(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    cbData: UInt32
    Data: Byte * 1
class EMRGRADIENTFILL(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    nVer: UInt32
    nTri: UInt32
    ulMode: win32more.Windows.Win32.Graphics.Gdi.GRADIENT_FILL
    Ver: win32more.Windows.Win32.Graphics.Gdi.TRIVERTEX * 1
class EMRINVERTRGN(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    cbRgnData: UInt32
    RgnData: Byte * 1
class EMRLINETO(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ptl: win32more.Windows.Win32.Foundation.POINTL
class EMRMASKBLT(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    xDest: Int32
    yDest: Int32
    cxDest: Int32
    cyDest: Int32
    dwRop: UInt32
    xSrc: Int32
    ySrc: Int32
    xformSrc: win32more.Windows.Win32.Graphics.Gdi.XFORM
    crBkColorSrc: win32more.Windows.Win32.Foundation.COLORREF
    iUsageSrc: UInt32
    offBmiSrc: UInt32
    cbBmiSrc: UInt32
    offBitsSrc: UInt32
    cbBitsSrc: UInt32
    xMask: Int32
    yMask: Int32
    iUsageMask: UInt32
    offBmiMask: UInt32
    cbBmiMask: UInt32
    offBitsMask: UInt32
    cbBitsMask: UInt32
class EMRMODIFYWORLDTRANSFORM(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    xform: win32more.Windows.Win32.Graphics.Gdi.XFORM
    iMode: win32more.Windows.Win32.Graphics.Gdi.MODIFY_WORLD_TRANSFORM_MODE
class EMRNAMEDESCAPE(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    iEscape: Int32
    cbDriver: Int32
    cbEscData: Int32
    EscData: Byte * 1
class EMROFFSETCLIPRGN(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ptlOffset: win32more.Windows.Win32.Foundation.POINTL
class EMRPLGBLT(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    aptlDest: win32more.Windows.Win32.Foundation.POINTL * 3
    xSrc: Int32
    ySrc: Int32
    cxSrc: Int32
    cySrc: Int32
    xformSrc: win32more.Windows.Win32.Graphics.Gdi.XFORM
    crBkColorSrc: win32more.Windows.Win32.Foundation.COLORREF
    iUsageSrc: UInt32
    offBmiSrc: UInt32
    cbBmiSrc: UInt32
    offBitsSrc: UInt32
    cbBitsSrc: UInt32
    xMask: Int32
    yMask: Int32
    iUsageMask: UInt32
    offBmiMask: UInt32
    cbBmiMask: UInt32
    offBitsMask: UInt32
    cbBitsMask: UInt32
class EMRPOLYDRAW(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    cptl: UInt32
    aptl: win32more.Windows.Win32.Foundation.POINTL * 1
    abTypes: Byte * 1
class EMRPOLYDRAW16(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    cpts: UInt32
    apts: win32more.Windows.Win32.Foundation.POINTS * 1
    abTypes: Byte * 1
class EMRPOLYLINE(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    cptl: UInt32
    aptl: win32more.Windows.Win32.Foundation.POINTL * 1
class EMRPOLYLINE16(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    cpts: UInt32
    apts: win32more.Windows.Win32.Foundation.POINTS * 1
class EMRPOLYPOLYLINE(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    nPolys: UInt32
    cptl: UInt32
    aPolyCounts: UInt32 * 1
    aptl: win32more.Windows.Win32.Foundation.POINTL * 1
class EMRPOLYPOLYLINE16(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    nPolys: UInt32
    cpts: UInt32
    aPolyCounts: UInt32 * 1
    apts: win32more.Windows.Win32.Foundation.POINTS * 1
class EMRPOLYTEXTOUTA(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    iGraphicsMode: UInt32
    exScale: Single
    eyScale: Single
    cStrings: Int32
    aemrtext: win32more.Windows.Win32.Graphics.Gdi.EMRTEXT * 1
class EMRRESIZEPALETTE(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ihPal: UInt32
    cEntries: UInt32
class EMRRESTOREDC(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    iRelative: Int32
class EMRROUNDRECT(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBox: win32more.Windows.Win32.Foundation.RECTL
    szlCorner: win32more.Windows.Win32.Foundation.SIZE
class EMRSCALEVIEWPORTEXTEX(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    xNum: Int32
    xDenom: Int32
    yNum: Int32
    yDenom: Int32
class EMRSELECTCLIPPATH(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    iMode: UInt32
class EMRSELECTOBJECT(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ihObject: UInt32
class EMRSELECTPALETTE(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ihPal: UInt32
class EMRSETARCDIRECTION(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    iArcDirection: UInt32
class EMRSETCOLORADJUSTMENT(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ColorAdjustment: win32more.Windows.Win32.Graphics.Gdi.COLORADJUSTMENT
class EMRSETCOLORSPACE(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ihCS: UInt32
class EMRSETDIBITSTODEVICE(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    xDest: Int32
    yDest: Int32
    xSrc: Int32
    ySrc: Int32
    cxSrc: Int32
    cySrc: Int32
    offBmiSrc: UInt32
    cbBmiSrc: UInt32
    offBitsSrc: UInt32
    cbBitsSrc: UInt32
    iUsageSrc: UInt32
    iStartScan: UInt32
    cScans: UInt32
class EMRSETICMPROFILE(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    dwFlags: UInt32
    cbName: UInt32
    cbData: UInt32
    Data: Byte * 1
class EMRSETMAPPERFLAGS(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    dwFlags: UInt32
class EMRSETMITERLIMIT(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    eMiterLimit: Single
class EMRSETPALETTEENTRIES(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ihPal: UInt32
    iStart: UInt32
    cEntries: UInt32
    aPalEntries: win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY * 1
class EMRSETPIXELV(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ptlPixel: win32more.Windows.Win32.Foundation.POINTL
    crColor: win32more.Windows.Win32.Foundation.COLORREF
class EMRSETTEXTCOLOR(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    crColor: win32more.Windows.Win32.Foundation.COLORREF
class EMRSETVIEWPORTEXTEX(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    szlExtent: win32more.Windows.Win32.Foundation.SIZE
class EMRSETVIEWPORTORGEX(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    ptlOrigin: win32more.Windows.Win32.Foundation.POINTL
class EMRSETWORLDTRANSFORM(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    xform: win32more.Windows.Win32.Graphics.Gdi.XFORM
class EMRSTRETCHBLT(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    xDest: Int32
    yDest: Int32
    cxDest: Int32
    cyDest: Int32
    dwRop: UInt32
    xSrc: Int32
    ySrc: Int32
    xformSrc: win32more.Windows.Win32.Graphics.Gdi.XFORM
    crBkColorSrc: win32more.Windows.Win32.Foundation.COLORREF
    iUsageSrc: UInt32
    offBmiSrc: UInt32
    cbBmiSrc: UInt32
    offBitsSrc: UInt32
    cbBitsSrc: UInt32
    cxSrc: Int32
    cySrc: Int32
class EMRSTRETCHDIBITS(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    xDest: Int32
    yDest: Int32
    xSrc: Int32
    ySrc: Int32
    cxSrc: Int32
    cySrc: Int32
    offBmiSrc: UInt32
    cbBmiSrc: UInt32
    offBitsSrc: UInt32
    cbBitsSrc: UInt32
    iUsageSrc: UInt32
    dwRop: UInt32
    cxDest: Int32
    cyDest: Int32
class EMRTEXT(Structure):
    ptlReference: win32more.Windows.Win32.Foundation.POINTL
    nChars: UInt32
    offString: UInt32
    fOptions: UInt32
    rcl: win32more.Windows.Win32.Foundation.RECTL
    offDx: UInt32
class EMRTRANSPARENTBLT(Structure):
    emr: win32more.Windows.Win32.Graphics.Gdi.EMR
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    xDest: Int32
    yDest: Int32
    cxDest: Int32
    cyDest: Int32
    dwRop: UInt32
    xSrc: Int32
    ySrc: Int32
    xformSrc: win32more.Windows.Win32.Graphics.Gdi.XFORM
    crBkColorSrc: win32more.Windows.Win32.Foundation.COLORREF
    iUsageSrc: UInt32
    offBmiSrc: UInt32
    cbBmiSrc: UInt32
    offBitsSrc: UInt32
    cbBitsSrc: UInt32
    cxSrc: Int32
    cySrc: Int32
ENHANCED_METAFILE_RECORD_TYPE = UInt32
EMR_HEADER: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 1
EMR_POLYBEZIER: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 2
EMR_POLYGON: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 3
EMR_POLYLINE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 4
EMR_POLYBEZIERTO: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 5
EMR_POLYLINETO: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 6
EMR_POLYPOLYLINE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 7
EMR_POLYPOLYGON: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 8
EMR_SETWINDOWEXTEX: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 9
EMR_SETWINDOWORGEX: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 10
EMR_SETVIEWPORTEXTEX: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 11
EMR_SETVIEWPORTORGEX: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 12
EMR_SETBRUSHORGEX: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 13
EMR_EOF: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 14
EMR_SETPIXELV: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 15
EMR_SETMAPPERFLAGS: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 16
EMR_SETMAPMODE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 17
EMR_SETBKMODE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 18
EMR_SETPOLYFILLMODE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 19
EMR_SETROP2: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 20
EMR_SETSTRETCHBLTMODE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 21
EMR_SETTEXTALIGN: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 22
EMR_SETCOLORADJUSTMENT: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 23
EMR_SETTEXTCOLOR: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 24
EMR_SETBKCOLOR: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 25
EMR_OFFSETCLIPRGN: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 26
EMR_MOVETOEX: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 27
EMR_SETMETARGN: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 28
EMR_EXCLUDECLIPRECT: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 29
EMR_INTERSECTCLIPRECT: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 30
EMR_SCALEVIEWPORTEXTEX: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 31
EMR_SCALEWINDOWEXTEX: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 32
EMR_SAVEDC: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 33
EMR_RESTOREDC: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 34
EMR_SETWORLDTRANSFORM: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 35
EMR_MODIFYWORLDTRANSFORM: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 36
EMR_SELECTOBJECT: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 37
EMR_CREATEPEN: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 38
EMR_CREATEBRUSHINDIRECT: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 39
EMR_DELETEOBJECT: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 40
EMR_ANGLEARC: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 41
EMR_ELLIPSE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 42
EMR_RECTANGLE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 43
EMR_ROUNDRECT: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 44
EMR_ARC: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 45
EMR_CHORD: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 46
EMR_PIE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 47
EMR_SELECTPALETTE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 48
EMR_CREATEPALETTE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 49
EMR_SETPALETTEENTRIES: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 50
EMR_RESIZEPALETTE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 51
EMR_REALIZEPALETTE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 52
EMR_EXTFLOODFILL: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 53
EMR_LINETO: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 54
EMR_ARCTO: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 55
EMR_POLYDRAW: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 56
EMR_SETARCDIRECTION: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 57
EMR_SETMITERLIMIT: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 58
EMR_BEGINPATH: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 59
EMR_ENDPATH: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 60
EMR_CLOSEFIGURE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 61
EMR_FILLPATH: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 62
EMR_STROKEANDFILLPATH: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 63
EMR_STROKEPATH: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 64
EMR_FLATTENPATH: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 65
EMR_WIDENPATH: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 66
EMR_SELECTCLIPPATH: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 67
EMR_ABORTPATH: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 68
EMR_GDICOMMENT: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 70
EMR_FILLRGN: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 71
EMR_FRAMERGN: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 72
EMR_INVERTRGN: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 73
EMR_PAINTRGN: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 74
EMR_EXTSELECTCLIPRGN: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 75
EMR_BITBLT: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 76
EMR_STRETCHBLT: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 77
EMR_MASKBLT: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 78
EMR_PLGBLT: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 79
EMR_SETDIBITSTODEVICE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 80
EMR_STRETCHDIBITS: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 81
EMR_EXTCREATEFONTINDIRECTW: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 82
EMR_EXTTEXTOUTA: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 83
EMR_EXTTEXTOUTW: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 84
EMR_POLYBEZIER16: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 85
EMR_POLYGON16: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 86
EMR_POLYLINE16: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 87
EMR_POLYBEZIERTO16: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 88
EMR_POLYLINETO16: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 89
EMR_POLYPOLYLINE16: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 90
EMR_POLYPOLYGON16: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 91
EMR_POLYDRAW16: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 92
EMR_CREATEMONOBRUSH: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 93
EMR_CREATEDIBPATTERNBRUSHPT: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 94
EMR_EXTCREATEPEN: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 95
EMR_POLYTEXTOUTA: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 96
EMR_POLYTEXTOUTW: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 97
EMR_SETICMMODE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 98
EMR_CREATECOLORSPACE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 99
EMR_SETCOLORSPACE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 100
EMR_DELETECOLORSPACE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 101
EMR_GLSRECORD: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 102
EMR_GLSBOUNDEDRECORD: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 103
EMR_PIXELFORMAT: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 104
EMR_RESERVED_105: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 105
EMR_RESERVED_106: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 106
EMR_RESERVED_107: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 107
EMR_RESERVED_108: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 108
EMR_RESERVED_109: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 109
EMR_RESERVED_110: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 110
EMR_COLORCORRECTPALETTE: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 111
EMR_SETICMPROFILEA: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 112
EMR_SETICMPROFILEW: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 113
EMR_ALPHABLEND: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 114
EMR_SETLAYOUT: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 115
EMR_TRANSPARENTBLT: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 116
EMR_RESERVED_117: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 117
EMR_GRADIENTFILL: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 118
EMR_RESERVED_119: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 119
EMR_RESERVED_120: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 120
EMR_COLORMATCHTOTARGETW: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 121
EMR_CREATECOLORSPACEW: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 122
EMR_MIN: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 1
EMR_MAX: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE = 122
class ENHMETAHEADER(Structure):
    iType: UInt32
    nSize: UInt32
    rclBounds: win32more.Windows.Win32.Foundation.RECTL
    rclFrame: win32more.Windows.Win32.Foundation.RECTL
    dSignature: UInt32
    nVersion: UInt32
    nBytes: UInt32
    nRecords: UInt32
    nHandles: UInt16
    sReserved: UInt16
    nDescription: UInt32
    offDescription: UInt32
    nPalEntries: UInt32
    szlDevice: win32more.Windows.Win32.Foundation.SIZE
    szlMillimeters: win32more.Windows.Win32.Foundation.SIZE
    cbPixelFormat: UInt32
    offPixelFormat: UInt32
    bOpenGL: UInt32
    szlMicrometers: win32more.Windows.Win32.Foundation.SIZE
class ENHMETARECORD(Structure):
    iType: win32more.Windows.Win32.Graphics.Gdi.ENHANCED_METAFILE_RECORD_TYPE
    nSize: UInt32
    dParm: UInt32 * 1
@winfunctype_pointer
def ENHMFENUMPROC(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpht: POINTER(win32more.Windows.Win32.Graphics.Gdi.HANDLETABLE), lpmr: POINTER(win32more.Windows.Win32.Graphics.Gdi.ENHMETARECORD), nHandles: Int32, data: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
class ENUMLOGFONTA(Structure):
    elfLogFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTA
    elfFullName: Byte * 64
    elfStyle: Byte * 32
class ENUMLOGFONTEXA(Structure):
    elfLogFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTA
    elfFullName: Byte * 64
    elfStyle: Byte * 32
    elfScript: Byte * 32
class ENUMLOGFONTEXDVA(Structure):
    elfEnumLogfontEx: win32more.Windows.Win32.Graphics.Gdi.ENUMLOGFONTEXA
    elfDesignVector: win32more.Windows.Win32.Graphics.Gdi.DESIGNVECTOR
class ENUMLOGFONTEXDVW(Structure):
    elfEnumLogfontEx: win32more.Windows.Win32.Graphics.Gdi.ENUMLOGFONTEXW
    elfDesignVector: win32more.Windows.Win32.Graphics.Gdi.DESIGNVECTOR
ENUMLOGFONTEXDV = UnicodeAlias('ENUMLOGFONTEXDVW')
class ENUMLOGFONTEXW(Structure):
    elfLogFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTW
    elfFullName: Char * 64
    elfStyle: Char * 32
    elfScript: Char * 32
ENUMLOGFONTEX = UnicodeAlias('ENUMLOGFONTEXW')
class ENUMLOGFONTW(Structure):
    elfLogFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTW
    elfFullName: Char * 64
    elfStyle: Char * 32
ENUMLOGFONT = UnicodeAlias('ENUMLOGFONTW')
ENUM_DISPLAY_SETTINGS_FLAGS = UInt32
EDS_RAWMODE: win32more.Windows.Win32.Graphics.Gdi.ENUM_DISPLAY_SETTINGS_FLAGS = 2
EDS_ROTATEDMODE: win32more.Windows.Win32.Graphics.Gdi.ENUM_DISPLAY_SETTINGS_FLAGS = 4
ENUM_DISPLAY_SETTINGS_MODE = UInt32
ENUM_CURRENT_SETTINGS: win32more.Windows.Win32.Graphics.Gdi.ENUM_DISPLAY_SETTINGS_MODE = 4294967295
ENUM_REGISTRY_SETTINGS: win32more.Windows.Win32.Graphics.Gdi.ENUM_DISPLAY_SETTINGS_MODE = 4294967294
ETO_OPTIONS = UInt32
ETO_OPAQUE: win32more.Windows.Win32.Graphics.Gdi.ETO_OPTIONS = 2
ETO_CLIPPED: win32more.Windows.Win32.Graphics.Gdi.ETO_OPTIONS = 4
ETO_GLYPH_INDEX: win32more.Windows.Win32.Graphics.Gdi.ETO_OPTIONS = 16
ETO_RTLREADING: win32more.Windows.Win32.Graphics.Gdi.ETO_OPTIONS = 128
ETO_NUMERICSLOCAL: win32more.Windows.Win32.Graphics.Gdi.ETO_OPTIONS = 1024
ETO_NUMERICSLATIN: win32more.Windows.Win32.Graphics.Gdi.ETO_OPTIONS = 2048
ETO_IGNORELANGUAGE: win32more.Windows.Win32.Graphics.Gdi.ETO_OPTIONS = 4096
ETO_PDY: win32more.Windows.Win32.Graphics.Gdi.ETO_OPTIONS = 8192
ETO_REVERSE_INDEX_MAP: win32more.Windows.Win32.Graphics.Gdi.ETO_OPTIONS = 65536
class EXTLOGFONTA(Structure):
    elfLogFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTA
    elfFullName: Byte * 64
    elfStyle: Byte * 32
    elfVersion: UInt32
    elfStyleSize: UInt32
    elfMatch: UInt32
    elfReserved: UInt32
    elfVendorId: Byte * 4
    elfCulture: UInt32
    elfPanose: win32more.Windows.Win32.Graphics.Gdi.PANOSE
class EXTLOGFONTW(Structure):
    elfLogFont: win32more.Windows.Win32.Graphics.Gdi.LOGFONTW
    elfFullName: Char * 64
    elfStyle: Char * 32
    elfVersion: UInt32
    elfStyleSize: UInt32
    elfMatch: UInt32
    elfReserved: UInt32
    elfVendorId: Byte * 4
    elfCulture: UInt32
    elfPanose: win32more.Windows.Win32.Graphics.Gdi.PANOSE
EXTLOGFONT = UnicodeAlias('EXTLOGFONTW')
class EXTLOGPEN(Structure):
    elpPenStyle: UInt32
    elpWidth: UInt32
    elpBrushStyle: UInt32
    elpColor: win32more.Windows.Win32.Foundation.COLORREF
    elpHatch: UIntPtr
    elpNumEntries: UInt32
    elpStyleEntry: UInt32 * 1
class EXTLOGPEN32(Structure):
    elpPenStyle: UInt32
    elpWidth: UInt32
    elpBrushStyle: UInt32
    elpColor: win32more.Windows.Win32.Foundation.COLORREF
    elpHatch: UInt32
    elpNumEntries: UInt32
    elpStyleEntry: UInt32 * 1
EXT_FLOOD_FILL_TYPE = UInt32
FLOODFILLBORDER: win32more.Windows.Win32.Graphics.Gdi.EXT_FLOOD_FILL_TYPE = 0
FLOODFILLSURFACE: win32more.Windows.Win32.Graphics.Gdi.EXT_FLOOD_FILL_TYPE = 1
class FIXED(Structure):
    fract: UInt16
    value: Int16
@winfunctype_pointer
def FONTENUMPROCA(param0: POINTER(win32more.Windows.Win32.Graphics.Gdi.LOGFONTA), param1: POINTER(win32more.Windows.Win32.Graphics.Gdi.TEXTMETRICA), param2: UInt32, param3: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype_pointer
def FONTENUMPROCW(param0: POINTER(win32more.Windows.Win32.Graphics.Gdi.LOGFONTW), param1: POINTER(win32more.Windows.Win32.Graphics.Gdi.TEXTMETRICW), param2: UInt32, param3: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
FONTENUMPROC = UnicodeAlias('FONTENUMPROCW')
FONT_CHARSET = Byte
ANSI_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 0
DEFAULT_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 1
SYMBOL_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 2
SHIFTJIS_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 128
HANGEUL_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 129
HANGUL_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 129
GB2312_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 134
CHINESEBIG5_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 136
OEM_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 255
JOHAB_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 130
HEBREW_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 177
ARABIC_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 178
GREEK_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 161
TURKISH_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 162
VIETNAMESE_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 163
THAI_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 222
EASTEUROPE_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 238
RUSSIAN_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 204
MAC_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 77
BALTIC_CHARSET: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET = 186
FONT_CLIP_PRECISION = Byte
CLIP_DEFAULT_PRECIS: win32more.Windows.Win32.Graphics.Gdi.FONT_CLIP_PRECISION = 0
CLIP_CHARACTER_PRECIS: win32more.Windows.Win32.Graphics.Gdi.FONT_CLIP_PRECISION = 1
CLIP_STROKE_PRECIS: win32more.Windows.Win32.Graphics.Gdi.FONT_CLIP_PRECISION = 2
CLIP_MASK: win32more.Windows.Win32.Graphics.Gdi.FONT_CLIP_PRECISION = 15
CLIP_LH_ANGLES: win32more.Windows.Win32.Graphics.Gdi.FONT_CLIP_PRECISION = 16
CLIP_TT_ALWAYS: win32more.Windows.Win32.Graphics.Gdi.FONT_CLIP_PRECISION = 32
CLIP_DFA_DISABLE: win32more.Windows.Win32.Graphics.Gdi.FONT_CLIP_PRECISION = 64
CLIP_EMBEDDED: win32more.Windows.Win32.Graphics.Gdi.FONT_CLIP_PRECISION = 128
CLIP_DFA_OVERRIDE: win32more.Windows.Win32.Graphics.Gdi.FONT_CLIP_PRECISION = 64
FONT_FAMILY = Byte
FF_DECORATIVE: win32more.Windows.Win32.Graphics.Gdi.FONT_FAMILY = 80
FF_DONTCARE: win32more.Windows.Win32.Graphics.Gdi.FONT_FAMILY = 0
FF_MODERN: win32more.Windows.Win32.Graphics.Gdi.FONT_FAMILY = 48
FF_ROMAN: win32more.Windows.Win32.Graphics.Gdi.FONT_FAMILY = 16
FF_SCRIPT: win32more.Windows.Win32.Graphics.Gdi.FONT_FAMILY = 64
FF_SWISS: win32more.Windows.Win32.Graphics.Gdi.FONT_FAMILY = 32
FONT_LICENSE_PRIVS = UInt32
LICENSE_PREVIEWPRINT: win32more.Windows.Win32.Graphics.Gdi.FONT_LICENSE_PRIVS = 4
LICENSE_EDITABLE: win32more.Windows.Win32.Graphics.Gdi.FONT_LICENSE_PRIVS = 8
LICENSE_INSTALLABLE: win32more.Windows.Win32.Graphics.Gdi.FONT_LICENSE_PRIVS = 0
LICENSE_NOEMBEDDING: win32more.Windows.Win32.Graphics.Gdi.FONT_LICENSE_PRIVS = 2
LICENSE_DEFAULT: win32more.Windows.Win32.Graphics.Gdi.FONT_LICENSE_PRIVS = 0
FONT_OUTPUT_PRECISION = Byte
OUT_DEFAULT_PRECIS: win32more.Windows.Win32.Graphics.Gdi.FONT_OUTPUT_PRECISION = 0
OUT_STRING_PRECIS: win32more.Windows.Win32.Graphics.Gdi.FONT_OUTPUT_PRECISION = 1
OUT_CHARACTER_PRECIS: win32more.Windows.Win32.Graphics.Gdi.FONT_OUTPUT_PRECISION = 2
OUT_STROKE_PRECIS: win32more.Windows.Win32.Graphics.Gdi.FONT_OUTPUT_PRECISION = 3
OUT_TT_PRECIS: win32more.Windows.Win32.Graphics.Gdi.FONT_OUTPUT_PRECISION = 4
OUT_DEVICE_PRECIS: win32more.Windows.Win32.Graphics.Gdi.FONT_OUTPUT_PRECISION = 5
OUT_RASTER_PRECIS: win32more.Windows.Win32.Graphics.Gdi.FONT_OUTPUT_PRECISION = 6
OUT_TT_ONLY_PRECIS: win32more.Windows.Win32.Graphics.Gdi.FONT_OUTPUT_PRECISION = 7
OUT_OUTLINE_PRECIS: win32more.Windows.Win32.Graphics.Gdi.FONT_OUTPUT_PRECISION = 8
OUT_SCREEN_OUTLINE_PRECIS: win32more.Windows.Win32.Graphics.Gdi.FONT_OUTPUT_PRECISION = 9
OUT_PS_ONLY_PRECIS: win32more.Windows.Win32.Graphics.Gdi.FONT_OUTPUT_PRECISION = 10
FONT_PITCH = Byte
DEFAULT_PITCH: win32more.Windows.Win32.Graphics.Gdi.FONT_PITCH = 0
FIXED_PITCH: win32more.Windows.Win32.Graphics.Gdi.FONT_PITCH = 1
VARIABLE_PITCH: win32more.Windows.Win32.Graphics.Gdi.FONT_PITCH = 2
FONT_QUALITY = Byte
DEFAULT_QUALITY: win32more.Windows.Win32.Graphics.Gdi.FONT_QUALITY = 0
DRAFT_QUALITY: win32more.Windows.Win32.Graphics.Gdi.FONT_QUALITY = 1
PROOF_QUALITY: win32more.Windows.Win32.Graphics.Gdi.FONT_QUALITY = 2
NONANTIALIASED_QUALITY: win32more.Windows.Win32.Graphics.Gdi.FONT_QUALITY = 3
ANTIALIASED_QUALITY: win32more.Windows.Win32.Graphics.Gdi.FONT_QUALITY = 4
CLEARTYPE_QUALITY: win32more.Windows.Win32.Graphics.Gdi.FONT_QUALITY = 5
FONT_RESOURCE_CHARACTERISTICS = UInt32
FR_PRIVATE: win32more.Windows.Win32.Graphics.Gdi.FONT_RESOURCE_CHARACTERISTICS = 16
FR_NOT_ENUM: win32more.Windows.Win32.Graphics.Gdi.FONT_RESOURCE_CHARACTERISTICS = 32
FONT_WEIGHT = UInt32
FW_DONTCARE: win32more.Windows.Win32.Graphics.Gdi.FONT_WEIGHT = 0
FW_THIN: win32more.Windows.Win32.Graphics.Gdi.FONT_WEIGHT = 100
FW_EXTRALIGHT: win32more.Windows.Win32.Graphics.Gdi.FONT_WEIGHT = 200
FW_LIGHT: win32more.Windows.Win32.Graphics.Gdi.FONT_WEIGHT = 300
FW_NORMAL: win32more.Windows.Win32.Graphics.Gdi.FONT_WEIGHT = 400
FW_MEDIUM: win32more.Windows.Win32.Graphics.Gdi.FONT_WEIGHT = 500
FW_SEMIBOLD: win32more.Windows.Win32.Graphics.Gdi.FONT_WEIGHT = 600
FW_BOLD: win32more.Windows.Win32.Graphics.Gdi.FONT_WEIGHT = 700
FW_EXTRABOLD: win32more.Windows.Win32.Graphics.Gdi.FONT_WEIGHT = 800
FW_HEAVY: win32more.Windows.Win32.Graphics.Gdi.FONT_WEIGHT = 900
FW_ULTRALIGHT: win32more.Windows.Win32.Graphics.Gdi.FONT_WEIGHT = 200
FW_REGULAR: win32more.Windows.Win32.Graphics.Gdi.FONT_WEIGHT = 400
FW_DEMIBOLD: win32more.Windows.Win32.Graphics.Gdi.FONT_WEIGHT = 600
FW_ULTRABOLD: win32more.Windows.Win32.Graphics.Gdi.FONT_WEIGHT = 800
FW_BLACK: win32more.Windows.Win32.Graphics.Gdi.FONT_WEIGHT = 900
class GCP_RESULTSA(Structure):
    lStructSize: UInt32
    lpOutString: win32more.Windows.Win32.Foundation.PSTR
    lpOrder: POINTER(UInt32)
    lpDx: POINTER(Int32)
    lpCaretPos: POINTER(Int32)
    lpClass: win32more.Windows.Win32.Foundation.PSTR
    lpGlyphs: win32more.Windows.Win32.Foundation.PWSTR
    nGlyphs: UInt32
    nMaxFit: Int32
class GCP_RESULTSW(Structure):
    lStructSize: UInt32
    lpOutString: win32more.Windows.Win32.Foundation.PWSTR
    lpOrder: POINTER(UInt32)
    lpDx: POINTER(Int32)
    lpCaretPos: POINTER(Int32)
    lpClass: win32more.Windows.Win32.Foundation.PSTR
    lpGlyphs: win32more.Windows.Win32.Foundation.PWSTR
    nGlyphs: UInt32
    nMaxFit: Int32
GCP_RESULTS = UnicodeAlias('GCP_RESULTSW')
GDI_REGION_TYPE = Int32
RGN_ERROR: win32more.Windows.Win32.Graphics.Gdi.GDI_REGION_TYPE = 0
NULLREGION: win32more.Windows.Win32.Graphics.Gdi.GDI_REGION_TYPE = 1
SIMPLEREGION: win32more.Windows.Win32.Graphics.Gdi.GDI_REGION_TYPE = 2
COMPLEXREGION: win32more.Windows.Win32.Graphics.Gdi.GDI_REGION_TYPE = 3
GET_CHARACTER_PLACEMENT_FLAGS = UInt32
GCP_CLASSIN: win32more.Windows.Win32.Graphics.Gdi.GET_CHARACTER_PLACEMENT_FLAGS = 524288
GCP_DIACRITIC: win32more.Windows.Win32.Graphics.Gdi.GET_CHARACTER_PLACEMENT_FLAGS = 256
GCP_DISPLAYZWG: win32more.Windows.Win32.Graphics.Gdi.GET_CHARACTER_PLACEMENT_FLAGS = 4194304
GCP_GLYPHSHAPE: win32more.Windows.Win32.Graphics.Gdi.GET_CHARACTER_PLACEMENT_FLAGS = 16
GCP_JUSTIFY: win32more.Windows.Win32.Graphics.Gdi.GET_CHARACTER_PLACEMENT_FLAGS = 65536
GCP_KASHIDA: win32more.Windows.Win32.Graphics.Gdi.GET_CHARACTER_PLACEMENT_FLAGS = 1024
GCP_LIGATE: win32more.Windows.Win32.Graphics.Gdi.GET_CHARACTER_PLACEMENT_FLAGS = 32
GCP_MAXEXTENT: win32more.Windows.Win32.Graphics.Gdi.GET_CHARACTER_PLACEMENT_FLAGS = 1048576
GCP_NEUTRALOVERRIDE: win32more.Windows.Win32.Graphics.Gdi.GET_CHARACTER_PLACEMENT_FLAGS = 33554432
GCP_NUMERICOVERRIDE: win32more.Windows.Win32.Graphics.Gdi.GET_CHARACTER_PLACEMENT_FLAGS = 16777216
GCP_NUMERICSLATIN: win32more.Windows.Win32.Graphics.Gdi.GET_CHARACTER_PLACEMENT_FLAGS = 67108864
GCP_NUMERICSLOCAL: win32more.Windows.Win32.Graphics.Gdi.GET_CHARACTER_PLACEMENT_FLAGS = 134217728
GCP_REORDER: win32more.Windows.Win32.Graphics.Gdi.GET_CHARACTER_PLACEMENT_FLAGS = 2
GCP_SYMSWAPOFF: win32more.Windows.Win32.Graphics.Gdi.GET_CHARACTER_PLACEMENT_FLAGS = 8388608
GCP_USEKERNING: win32more.Windows.Win32.Graphics.Gdi.GET_CHARACTER_PLACEMENT_FLAGS = 8
GET_DCX_FLAGS = UInt32
DCX_WINDOW: win32more.Windows.Win32.Graphics.Gdi.GET_DCX_FLAGS = 1
DCX_CACHE: win32more.Windows.Win32.Graphics.Gdi.GET_DCX_FLAGS = 2
DCX_PARENTCLIP: win32more.Windows.Win32.Graphics.Gdi.GET_DCX_FLAGS = 32
DCX_CLIPSIBLINGS: win32more.Windows.Win32.Graphics.Gdi.GET_DCX_FLAGS = 16
DCX_CLIPCHILDREN: win32more.Windows.Win32.Graphics.Gdi.GET_DCX_FLAGS = 8
DCX_NORESETATTRS: win32more.Windows.Win32.Graphics.Gdi.GET_DCX_FLAGS = 4
DCX_LOCKWINDOWUPDATE: win32more.Windows.Win32.Graphics.Gdi.GET_DCX_FLAGS = 1024
DCX_EXCLUDERGN: win32more.Windows.Win32.Graphics.Gdi.GET_DCX_FLAGS = 64
DCX_INTERSECTRGN: win32more.Windows.Win32.Graphics.Gdi.GET_DCX_FLAGS = 128
DCX_INTERSECTUPDATE: win32more.Windows.Win32.Graphics.Gdi.GET_DCX_FLAGS = 512
DCX_VALIDATE: win32more.Windows.Win32.Graphics.Gdi.GET_DCX_FLAGS = 2097152
GET_DEVICE_CAPS_INDEX = UInt32
DRIVERVERSION: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 0
TECHNOLOGY: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 2
HORZSIZE: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 4
VERTSIZE: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 6
HORZRES: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 8
VERTRES: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 10
BITSPIXEL: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 12
PLANES: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 14
NUMBRUSHES: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 16
NUMPENS: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 18
NUMMARKERS: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 20
NUMFONTS: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 22
NUMCOLORS: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 24
PDEVICESIZE: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 26
CURVECAPS: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 28
LINECAPS: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 30
POLYGONALCAPS: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 32
TEXTCAPS: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 34
CLIPCAPS: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 36
RASTERCAPS: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 38
ASPECTX: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 40
ASPECTY: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 42
ASPECTXY: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 44
LOGPIXELSX: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 88
LOGPIXELSY: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 90
SIZEPALETTE: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 104
NUMRESERVED: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 106
COLORRES: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 108
PHYSICALWIDTH: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 110
PHYSICALHEIGHT: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 111
PHYSICALOFFSETX: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 112
PHYSICALOFFSETY: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 113
SCALINGFACTORX: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 114
SCALINGFACTORY: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 115
VREFRESH: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 116
DESKTOPVERTRES: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 117
DESKTOPHORZRES: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 118
BLTALIGNMENT: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 119
SHADEBLENDCAPS: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 120
COLORMGMTCAPS: win32more.Windows.Win32.Graphics.Gdi.GET_DEVICE_CAPS_INDEX = 121
GET_GLYPH_OUTLINE_FORMAT = UInt32
GGO_BEZIER: win32more.Windows.Win32.Graphics.Gdi.GET_GLYPH_OUTLINE_FORMAT = 3
GGO_BITMAP: win32more.Windows.Win32.Graphics.Gdi.GET_GLYPH_OUTLINE_FORMAT = 1
GGO_GLYPH_INDEX: win32more.Windows.Win32.Graphics.Gdi.GET_GLYPH_OUTLINE_FORMAT = 128
GGO_GRAY2_BITMAP: win32more.Windows.Win32.Graphics.Gdi.GET_GLYPH_OUTLINE_FORMAT = 4
GGO_GRAY4_BITMAP: win32more.Windows.Win32.Graphics.Gdi.GET_GLYPH_OUTLINE_FORMAT = 5
GGO_GRAY8_BITMAP: win32more.Windows.Win32.Graphics.Gdi.GET_GLYPH_OUTLINE_FORMAT = 6
GGO_METRICS: win32more.Windows.Win32.Graphics.Gdi.GET_GLYPH_OUTLINE_FORMAT = 0
GGO_NATIVE: win32more.Windows.Win32.Graphics.Gdi.GET_GLYPH_OUTLINE_FORMAT = 2
GGO_UNHINTED: win32more.Windows.Win32.Graphics.Gdi.GET_GLYPH_OUTLINE_FORMAT = 256
GET_STOCK_OBJECT_FLAGS = Int32
BLACK_BRUSH: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 4
DKGRAY_BRUSH: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 3
DC_BRUSH: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 18
GRAY_BRUSH: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 2
HOLLOW_BRUSH: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 5
LTGRAY_BRUSH: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 1
NULL_BRUSH: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 5
WHITE_BRUSH: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 0
BLACK_PEN: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 7
DC_PEN: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 19
NULL_PEN: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 8
WHITE_PEN: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 6
ANSI_FIXED_FONT: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 11
ANSI_VAR_FONT: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 12
DEVICE_DEFAULT_FONT: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 14
DEFAULT_GUI_FONT: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 17
OEM_FIXED_FONT: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 10
SYSTEM_FONT: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 13
SYSTEM_FIXED_FONT: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 16
DEFAULT_PALETTE: win32more.Windows.Win32.Graphics.Gdi.GET_STOCK_OBJECT_FLAGS = 15
class GLYPHMETRICS(Structure):
    gmBlackBoxX: UInt32
    gmBlackBoxY: UInt32
    gmptGlyphOrigin: win32more.Windows.Win32.Foundation.POINT
    gmCellIncX: Int16
    gmCellIncY: Int16
class GLYPHSET(Structure):
    cbThis: UInt32
    flAccel: UInt32
    cGlyphsSupported: UInt32
    cRanges: UInt32
    ranges: win32more.Windows.Win32.Graphics.Gdi.WCRANGE * 1
@winfunctype_pointer
def GOBJENUMPROC(param0: VoidPtr, param1: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
GRADIENT_FILL = UInt32
GRADIENT_FILL_RECT_H: win32more.Windows.Win32.Graphics.Gdi.GRADIENT_FILL = 0
GRADIENT_FILL_RECT_V: win32more.Windows.Win32.Graphics.Gdi.GRADIENT_FILL = 1
GRADIENT_FILL_TRIANGLE: win32more.Windows.Win32.Graphics.Gdi.GRADIENT_FILL = 2
class GRADIENT_RECT(Structure):
    UpperLeft: UInt32
    LowerRight: UInt32
class GRADIENT_TRIANGLE(Structure):
    Vertex1: UInt32
    Vertex2: UInt32
    Vertex3: UInt32
GRAPHICS_MODE = Int32
GM_COMPATIBLE: win32more.Windows.Win32.Graphics.Gdi.GRAPHICS_MODE = 1
GM_ADVANCED: win32more.Windows.Win32.Graphics.Gdi.GRAPHICS_MODE = 2
@winfunctype_pointer
def GRAYSTRINGPROC(param0: win32more.Windows.Win32.Graphics.Gdi.HDC, param1: win32more.Windows.Win32.Foundation.LPARAM, param2: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
class HANDLETABLE(Structure):
    objectHandle: win32more.Windows.Win32.Graphics.Gdi.HGDIOBJ * 1
HATCH_BRUSH_STYLE = Int32
HS_BDIAGONAL: win32more.Windows.Win32.Graphics.Gdi.HATCH_BRUSH_STYLE = 3
HS_CROSS: win32more.Windows.Win32.Graphics.Gdi.HATCH_BRUSH_STYLE = 4
HS_DIAGCROSS: win32more.Windows.Win32.Graphics.Gdi.HATCH_BRUSH_STYLE = 5
HS_FDIAGONAL: win32more.Windows.Win32.Graphics.Gdi.HATCH_BRUSH_STYLE = 2
HS_HORIZONTAL: win32more.Windows.Win32.Graphics.Gdi.HATCH_BRUSH_STYLE = 0
HS_VERTICAL: win32more.Windows.Win32.Graphics.Gdi.HATCH_BRUSH_STYLE = 1
HBITMAP = VoidPtr
HBRUSH = VoidPtr
HDC = VoidPtr
HDC_MAP_MODE = Int32
MM_ANISOTROPIC: win32more.Windows.Win32.Graphics.Gdi.HDC_MAP_MODE = 8
MM_HIENGLISH: win32more.Windows.Win32.Graphics.Gdi.HDC_MAP_MODE = 5
MM_HIMETRIC: win32more.Windows.Win32.Graphics.Gdi.HDC_MAP_MODE = 3
MM_ISOTROPIC: win32more.Windows.Win32.Graphics.Gdi.HDC_MAP_MODE = 7
MM_LOENGLISH: win32more.Windows.Win32.Graphics.Gdi.HDC_MAP_MODE = 4
MM_LOMETRIC: win32more.Windows.Win32.Graphics.Gdi.HDC_MAP_MODE = 2
MM_TEXT: win32more.Windows.Win32.Graphics.Gdi.HDC_MAP_MODE = 1
MM_TWIPS: win32more.Windows.Win32.Graphics.Gdi.HDC_MAP_MODE = 6
HENHMETAFILE = VoidPtr
HFONT = VoidPtr
HGDIOBJ = VoidPtr
HMETAFILE = VoidPtr
HMONITOR = VoidPtr
HPALETTE = VoidPtr
HPEN = VoidPtr
HRGN = VoidPtr
class KERNINGPAIR(Structure):
    wFirst: UInt16
    wSecond: UInt16
    iKernAmount: Int32
@winfunctype_pointer
def LINEDDAPROC(param0: Int32, param1: Int32, param2: win32more.Windows.Win32.Foundation.LPARAM) -> Void: ...
class LOGBRUSH(Structure):
    lbStyle: win32more.Windows.Win32.Graphics.Gdi.BRUSH_STYLE
    lbColor: win32more.Windows.Win32.Foundation.COLORREF
    lbHatch: UIntPtr
class LOGBRUSH32(Structure):
    lbStyle: win32more.Windows.Win32.Graphics.Gdi.BRUSH_STYLE
    lbColor: win32more.Windows.Win32.Foundation.COLORREF
    lbHatch: UInt32
class LOGFONTA(Structure):
    lfHeight: Int32
    lfWidth: Int32
    lfEscapement: Int32
    lfOrientation: Int32
    lfWeight: Int32
    lfItalic: Byte
    lfUnderline: Byte
    lfStrikeOut: Byte
    lfCharSet: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET
    lfOutPrecision: win32more.Windows.Win32.Graphics.Gdi.FONT_OUTPUT_PRECISION
    lfClipPrecision: win32more.Windows.Win32.Graphics.Gdi.FONT_CLIP_PRECISION
    lfQuality: win32more.Windows.Win32.Graphics.Gdi.FONT_QUALITY
    lfPitchAndFamily: Byte
    lfFaceName: win32more.Windows.Win32.Foundation.CHAR * 32
class LOGFONTW(Structure):
    lfHeight: Int32
    lfWidth: Int32
    lfEscapement: Int32
    lfOrientation: Int32
    lfWeight: Int32
    lfItalic: Byte
    lfUnderline: Byte
    lfStrikeOut: Byte
    lfCharSet: win32more.Windows.Win32.Graphics.Gdi.FONT_CHARSET
    lfOutPrecision: win32more.Windows.Win32.Graphics.Gdi.FONT_OUTPUT_PRECISION
    lfClipPrecision: win32more.Windows.Win32.Graphics.Gdi.FONT_CLIP_PRECISION
    lfQuality: win32more.Windows.Win32.Graphics.Gdi.FONT_QUALITY
    lfPitchAndFamily: Byte
    lfFaceName: Char * 32
LOGFONT = UnicodeAlias('LOGFONTW')
class LOGPALETTE(Structure):
    palVersion: UInt16
    palNumEntries: UInt16
    palPalEntry: win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY * 1
class LOGPEN(Structure):
    lopnStyle: UInt32
    lopnWidth: win32more.Windows.Win32.Foundation.POINT
    lopnColor: win32more.Windows.Win32.Foundation.COLORREF
@winfunctype_pointer
def LPFNDEVCAPS(param0: win32more.Windows.Win32.Foundation.PSTR, param1: win32more.Windows.Win32.Foundation.PSTR, param2: UInt32, param3: win32more.Windows.Win32.Foundation.PSTR, param4: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)) -> UInt32: ...
@winfunctype_pointer
def LPFNDEVMODE(param0: win32more.Windows.Win32.Foundation.HWND, param1: win32more.Windows.Win32.Foundation.HMODULE, param2: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), param3: win32more.Windows.Win32.Foundation.PSTR, param4: win32more.Windows.Win32.Foundation.PSTR, param5: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), param6: win32more.Windows.Win32.Foundation.PSTR, param7: UInt32) -> UInt32: ...
class MAT2(Structure):
    eM11: win32more.Windows.Win32.Graphics.Gdi.FIXED
    eM12: win32more.Windows.Win32.Graphics.Gdi.FIXED
    eM21: win32more.Windows.Win32.Graphics.Gdi.FIXED
    eM22: win32more.Windows.Win32.Graphics.Gdi.FIXED
class METAHEADER(Structure):
    mtType: UInt16
    mtHeaderSize: UInt16
    mtVersion: UInt16
    mtSize: UInt32
    mtNoObjects: UInt16
    mtMaxRecord: UInt32
    mtNoParameters: UInt16
    _pack_ = 2
class METARECORD(Structure):
    rdSize: UInt32
    rdFunction: UInt16
    rdParm: UInt16 * 1
@winfunctype_pointer
def MFENUMPROC(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpht: POINTER(win32more.Windows.Win32.Graphics.Gdi.HANDLETABLE), lpMR: POINTER(win32more.Windows.Win32.Graphics.Gdi.METARECORD), nObj: Int32, param4: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
MODIFY_WORLD_TRANSFORM_MODE = UInt32
MWT_IDENTITY: win32more.Windows.Win32.Graphics.Gdi.MODIFY_WORLD_TRANSFORM_MODE = 1
MWT_LEFTMULTIPLY: win32more.Windows.Win32.Graphics.Gdi.MODIFY_WORLD_TRANSFORM_MODE = 2
MWT_RIGHTMULTIPLY: win32more.Windows.Win32.Graphics.Gdi.MODIFY_WORLD_TRANSFORM_MODE = 3
@winfunctype_pointer
def MONITORENUMPROC(param0: win32more.Windows.Win32.Graphics.Gdi.HMONITOR, param1: win32more.Windows.Win32.Graphics.Gdi.HDC, param2: POINTER(win32more.Windows.Win32.Foundation.RECT), param3: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
class MONITORINFO(Structure):
    cbSize: UInt32
    rcMonitor: win32more.Windows.Win32.Foundation.RECT
    rcWork: win32more.Windows.Win32.Foundation.RECT
    dwFlags: UInt32
class MONITORINFOEXA(Structure):
    monitorInfo: win32more.Windows.Win32.Graphics.Gdi.MONITORINFO
    szDevice: win32more.Windows.Win32.Foundation.CHAR * 32
class MONITORINFOEXW(Structure):
    monitorInfo: win32more.Windows.Win32.Graphics.Gdi.MONITORINFO
    szDevice: Char * 32
MONITORINFOEX = UnicodeAlias('MONITORINFOEXW')
MONITOR_FROM_FLAGS = UInt32
MONITOR_DEFAULTTONEAREST: win32more.Windows.Win32.Graphics.Gdi.MONITOR_FROM_FLAGS = 2
MONITOR_DEFAULTTONULL: win32more.Windows.Win32.Graphics.Gdi.MONITOR_FROM_FLAGS = 0
MONITOR_DEFAULTTOPRIMARY: win32more.Windows.Win32.Graphics.Gdi.MONITOR_FROM_FLAGS = 1
class NEWTEXTMETRICA(Structure):
    tmHeight: Int32
    tmAscent: Int32
    tmDescent: Int32
    tmInternalLeading: Int32
    tmExternalLeading: Int32
    tmAveCharWidth: Int32
    tmMaxCharWidth: Int32
    tmWeight: Int32
    tmOverhang: Int32
    tmDigitizedAspectX: Int32
    tmDigitizedAspectY: Int32
    tmFirstChar: Byte
    tmLastChar: Byte
    tmDefaultChar: Byte
    tmBreakChar: Byte
    tmItalic: Byte
    tmUnderlined: Byte
    tmStruckOut: Byte
    tmPitchAndFamily: win32more.Windows.Win32.Graphics.Gdi.TMPF_FLAGS
    tmCharSet: Byte
    ntmFlags: UInt32
    ntmSizeEM: UInt32
    ntmCellHeight: UInt32
    ntmAvgWidth: UInt32
class NEWTEXTMETRICW(Structure):
    tmHeight: Int32
    tmAscent: Int32
    tmDescent: Int32
    tmInternalLeading: Int32
    tmExternalLeading: Int32
    tmAveCharWidth: Int32
    tmMaxCharWidth: Int32
    tmWeight: Int32
    tmOverhang: Int32
    tmDigitizedAspectX: Int32
    tmDigitizedAspectY: Int32
    tmFirstChar: Char
    tmLastChar: Char
    tmDefaultChar: Char
    tmBreakChar: Char
    tmItalic: Byte
    tmUnderlined: Byte
    tmStruckOut: Byte
    tmPitchAndFamily: win32more.Windows.Win32.Graphics.Gdi.TMPF_FLAGS
    tmCharSet: Byte
    ntmFlags: UInt32
    ntmSizeEM: UInt32
    ntmCellHeight: UInt32
    ntmAvgWidth: UInt32
NEWTEXTMETRIC = UnicodeAlias('NEWTEXTMETRICW')
OBJ_TYPE = Int32
OBJ_PEN: win32more.Windows.Win32.Graphics.Gdi.OBJ_TYPE = 1
OBJ_BRUSH: win32more.Windows.Win32.Graphics.Gdi.OBJ_TYPE = 2
OBJ_DC: win32more.Windows.Win32.Graphics.Gdi.OBJ_TYPE = 3
OBJ_METADC: win32more.Windows.Win32.Graphics.Gdi.OBJ_TYPE = 4
OBJ_PAL: win32more.Windows.Win32.Graphics.Gdi.OBJ_TYPE = 5
OBJ_FONT: win32more.Windows.Win32.Graphics.Gdi.OBJ_TYPE = 6
OBJ_BITMAP: win32more.Windows.Win32.Graphics.Gdi.OBJ_TYPE = 7
OBJ_REGION: win32more.Windows.Win32.Graphics.Gdi.OBJ_TYPE = 8
OBJ_METAFILE: win32more.Windows.Win32.Graphics.Gdi.OBJ_TYPE = 9
OBJ_MEMDC: win32more.Windows.Win32.Graphics.Gdi.OBJ_TYPE = 10
OBJ_EXTPEN: win32more.Windows.Win32.Graphics.Gdi.OBJ_TYPE = 11
OBJ_ENHMETADC: win32more.Windows.Win32.Graphics.Gdi.OBJ_TYPE = 12
OBJ_ENHMETAFILE: win32more.Windows.Win32.Graphics.Gdi.OBJ_TYPE = 13
OBJ_COLORSPACE: win32more.Windows.Win32.Graphics.Gdi.OBJ_TYPE = 14
class OUTLINETEXTMETRICA(Structure):
    otmSize: UInt32
    otmTextMetrics: win32more.Windows.Win32.Graphics.Gdi.TEXTMETRICA
    otmFiller: Byte
    otmPanoseNumber: win32more.Windows.Win32.Graphics.Gdi.PANOSE
    otmfsSelection: UInt32
    otmfsType: UInt32
    otmsCharSlopeRise: Int32
    otmsCharSlopeRun: Int32
    otmItalicAngle: Int32
    otmEMSquare: UInt32
    otmAscent: Int32
    otmDescent: Int32
    otmLineGap: UInt32
    otmsCapEmHeight: UInt32
    otmsXHeight: UInt32
    otmrcFontBox: win32more.Windows.Win32.Foundation.RECT
    otmMacAscent: Int32
    otmMacDescent: Int32
    otmMacLineGap: UInt32
    otmusMinimumPPEM: UInt32
    otmptSubscriptSize: win32more.Windows.Win32.Foundation.POINT
    otmptSubscriptOffset: win32more.Windows.Win32.Foundation.POINT
    otmptSuperscriptSize: win32more.Windows.Win32.Foundation.POINT
    otmptSuperscriptOffset: win32more.Windows.Win32.Foundation.POINT
    otmsStrikeoutSize: UInt32
    otmsStrikeoutPosition: Int32
    otmsUnderscoreSize: Int32
    otmsUnderscorePosition: Int32
    otmpFamilyName: win32more.Windows.Win32.Foundation.PSTR
    otmpFaceName: win32more.Windows.Win32.Foundation.PSTR
    otmpStyleName: win32more.Windows.Win32.Foundation.PSTR
    otmpFullName: win32more.Windows.Win32.Foundation.PSTR
class OUTLINETEXTMETRICW(Structure):
    otmSize: UInt32
    otmTextMetrics: win32more.Windows.Win32.Graphics.Gdi.TEXTMETRICW
    otmFiller: Byte
    otmPanoseNumber: win32more.Windows.Win32.Graphics.Gdi.PANOSE
    otmfsSelection: UInt32
    otmfsType: UInt32
    otmsCharSlopeRise: Int32
    otmsCharSlopeRun: Int32
    otmItalicAngle: Int32
    otmEMSquare: UInt32
    otmAscent: Int32
    otmDescent: Int32
    otmLineGap: UInt32
    otmsCapEmHeight: UInt32
    otmsXHeight: UInt32
    otmrcFontBox: win32more.Windows.Win32.Foundation.RECT
    otmMacAscent: Int32
    otmMacDescent: Int32
    otmMacLineGap: UInt32
    otmusMinimumPPEM: UInt32
    otmptSubscriptSize: win32more.Windows.Win32.Foundation.POINT
    otmptSubscriptOffset: win32more.Windows.Win32.Foundation.POINT
    otmptSuperscriptSize: win32more.Windows.Win32.Foundation.POINT
    otmptSuperscriptOffset: win32more.Windows.Win32.Foundation.POINT
    otmsStrikeoutSize: UInt32
    otmsStrikeoutPosition: Int32
    otmsUnderscoreSize: Int32
    otmsUnderscorePosition: Int32
    otmpFamilyName: win32more.Windows.Win32.Foundation.PSTR
    otmpFaceName: win32more.Windows.Win32.Foundation.PSTR
    otmpStyleName: win32more.Windows.Win32.Foundation.PSTR
    otmpFullName: win32more.Windows.Win32.Foundation.PSTR
OUTLINETEXTMETRIC = UnicodeAlias('OUTLINETEXTMETRICW')
class PAINTSTRUCT(Structure):
    hdc: win32more.Windows.Win32.Graphics.Gdi.HDC
    fErase: win32more.Windows.Win32.Foundation.BOOL
    rcPaint: win32more.Windows.Win32.Foundation.RECT
    fRestore: win32more.Windows.Win32.Foundation.BOOL
    fIncUpdate: win32more.Windows.Win32.Foundation.BOOL
    rgbReserved: Byte * 32
class PALETTEENTRY(Structure):
    peRed: Byte
    peGreen: Byte
    peBlue: Byte
    peFlags: Byte
class PANOSE(Structure):
    bFamilyType: win32more.Windows.Win32.Graphics.Gdi.PAN_FAMILY_TYPE
    bSerifStyle: win32more.Windows.Win32.Graphics.Gdi.PAN_SERIF_STYLE
    bWeight: win32more.Windows.Win32.Graphics.Gdi.PAN_WEIGHT
    bProportion: win32more.Windows.Win32.Graphics.Gdi.PAN_PROPORTION
    bContrast: win32more.Windows.Win32.Graphics.Gdi.PAN_CONTRAST
    bStrokeVariation: win32more.Windows.Win32.Graphics.Gdi.PAN_STROKE_VARIATION
    bArmStyle: win32more.Windows.Win32.Graphics.Gdi.PAN_ARM_STYLE
    bLetterform: win32more.Windows.Win32.Graphics.Gdi.PAN_LETT_FORM
    bMidline: win32more.Windows.Win32.Graphics.Gdi.PAN_MIDLINE
    bXHeight: win32more.Windows.Win32.Graphics.Gdi.PAN_XHEIGHT
PAN_ARM_STYLE = Byte
PAN_ARM_ANY: win32more.Windows.Win32.Graphics.Gdi.PAN_ARM_STYLE = 0
PAN_ARM_NO_FIT: win32more.Windows.Win32.Graphics.Gdi.PAN_ARM_STYLE = 1
PAN_STRAIGHT_ARMS_HORZ: win32more.Windows.Win32.Graphics.Gdi.PAN_ARM_STYLE = 2
PAN_STRAIGHT_ARMS_WEDGE: win32more.Windows.Win32.Graphics.Gdi.PAN_ARM_STYLE = 3
PAN_STRAIGHT_ARMS_VERT: win32more.Windows.Win32.Graphics.Gdi.PAN_ARM_STYLE = 4
PAN_STRAIGHT_ARMS_SINGLE_SERIF: win32more.Windows.Win32.Graphics.Gdi.PAN_ARM_STYLE = 5
PAN_STRAIGHT_ARMS_DOUBLE_SERIF: win32more.Windows.Win32.Graphics.Gdi.PAN_ARM_STYLE = 6
PAN_BENT_ARMS_HORZ: win32more.Windows.Win32.Graphics.Gdi.PAN_ARM_STYLE = 7
PAN_BENT_ARMS_WEDGE: win32more.Windows.Win32.Graphics.Gdi.PAN_ARM_STYLE = 8
PAN_BENT_ARMS_VERT: win32more.Windows.Win32.Graphics.Gdi.PAN_ARM_STYLE = 9
PAN_BENT_ARMS_SINGLE_SERIF: win32more.Windows.Win32.Graphics.Gdi.PAN_ARM_STYLE = 10
PAN_BENT_ARMS_DOUBLE_SERIF: win32more.Windows.Win32.Graphics.Gdi.PAN_ARM_STYLE = 11
PAN_CONTRAST = Byte
PAN_CONTRAST_ANY: win32more.Windows.Win32.Graphics.Gdi.PAN_CONTRAST = 0
PAN_CONTRAST_NO_FIT: win32more.Windows.Win32.Graphics.Gdi.PAN_CONTRAST = 1
PAN_CONTRAST_INDEX: win32more.Windows.Win32.Graphics.Gdi.PAN_CONTRAST = 4
PAN_CONTRAST_NONE: win32more.Windows.Win32.Graphics.Gdi.PAN_CONTRAST = 2
PAN_CONTRAST_VERY_LOW: win32more.Windows.Win32.Graphics.Gdi.PAN_CONTRAST = 3
PAN_CONTRAST_LOW: win32more.Windows.Win32.Graphics.Gdi.PAN_CONTRAST = 4
PAN_CONTRAST_MEDIUM_LOW: win32more.Windows.Win32.Graphics.Gdi.PAN_CONTRAST = 5
PAN_CONTRAST_MEDIUM: win32more.Windows.Win32.Graphics.Gdi.PAN_CONTRAST = 6
PAN_CONTRAST_MEDIUM_HIGH: win32more.Windows.Win32.Graphics.Gdi.PAN_CONTRAST = 7
PAN_CONTRAST_HIGH: win32more.Windows.Win32.Graphics.Gdi.PAN_CONTRAST = 8
PAN_CONTRAST_VERY_HIGH: win32more.Windows.Win32.Graphics.Gdi.PAN_CONTRAST = 9
PAN_FAMILY_TYPE = Byte
PAN_FAMILY_ANY: win32more.Windows.Win32.Graphics.Gdi.PAN_FAMILY_TYPE = 0
PAN_FAMILY_NO_FIT: win32more.Windows.Win32.Graphics.Gdi.PAN_FAMILY_TYPE = 1
PAN_FAMILY_TEXT_DISPLAY: win32more.Windows.Win32.Graphics.Gdi.PAN_FAMILY_TYPE = 2
PAN_FAMILY_SCRIPT: win32more.Windows.Win32.Graphics.Gdi.PAN_FAMILY_TYPE = 3
PAN_FAMILY_DECORATIVE: win32more.Windows.Win32.Graphics.Gdi.PAN_FAMILY_TYPE = 4
PAN_FAMILY_PICTORIAL: win32more.Windows.Win32.Graphics.Gdi.PAN_FAMILY_TYPE = 5
PAN_LETT_FORM = Byte
PAN_LETT_FORM_ANY: win32more.Windows.Win32.Graphics.Gdi.PAN_LETT_FORM = 0
PAN_LETT_FORM_NO_FIT: win32more.Windows.Win32.Graphics.Gdi.PAN_LETT_FORM = 1
PAN_LETT_NORMAL_CONTACT: win32more.Windows.Win32.Graphics.Gdi.PAN_LETT_FORM = 2
PAN_LETT_NORMAL_WEIGHTED: win32more.Windows.Win32.Graphics.Gdi.PAN_LETT_FORM = 3
PAN_LETT_NORMAL_BOXED: win32more.Windows.Win32.Graphics.Gdi.PAN_LETT_FORM = 4
PAN_LETT_NORMAL_FLATTENED: win32more.Windows.Win32.Graphics.Gdi.PAN_LETT_FORM = 5
PAN_LETT_NORMAL_ROUNDED: win32more.Windows.Win32.Graphics.Gdi.PAN_LETT_FORM = 6
PAN_LETT_NORMAL_OFF_CENTER: win32more.Windows.Win32.Graphics.Gdi.PAN_LETT_FORM = 7
PAN_LETT_NORMAL_SQUARE: win32more.Windows.Win32.Graphics.Gdi.PAN_LETT_FORM = 8
PAN_LETT_OBLIQUE_CONTACT: win32more.Windows.Win32.Graphics.Gdi.PAN_LETT_FORM = 9
PAN_LETT_OBLIQUE_WEIGHTED: win32more.Windows.Win32.Graphics.Gdi.PAN_LETT_FORM = 10
PAN_LETT_OBLIQUE_BOXED: win32more.Windows.Win32.Graphics.Gdi.PAN_LETT_FORM = 11
PAN_LETT_OBLIQUE_FLATTENED: win32more.Windows.Win32.Graphics.Gdi.PAN_LETT_FORM = 12
PAN_LETT_OBLIQUE_ROUNDED: win32more.Windows.Win32.Graphics.Gdi.PAN_LETT_FORM = 13
PAN_LETT_OBLIQUE_OFF_CENTER: win32more.Windows.Win32.Graphics.Gdi.PAN_LETT_FORM = 14
PAN_LETT_OBLIQUE_SQUARE: win32more.Windows.Win32.Graphics.Gdi.PAN_LETT_FORM = 15
PAN_MIDLINE = Byte
PAN_MIDLINE_ANY: win32more.Windows.Win32.Graphics.Gdi.PAN_MIDLINE = 0
PAN_MIDLINE_NO_FIT: win32more.Windows.Win32.Graphics.Gdi.PAN_MIDLINE = 1
PAN_MIDLINE_INDEX: win32more.Windows.Win32.Graphics.Gdi.PAN_MIDLINE = 8
PAN_MIDLINE_STANDARD_TRIMMED: win32more.Windows.Win32.Graphics.Gdi.PAN_MIDLINE = 2
PAN_MIDLINE_STANDARD_POINTED: win32more.Windows.Win32.Graphics.Gdi.PAN_MIDLINE = 3
PAN_MIDLINE_STANDARD_SERIFED: win32more.Windows.Win32.Graphics.Gdi.PAN_MIDLINE = 4
PAN_MIDLINE_HIGH_TRIMMED: win32more.Windows.Win32.Graphics.Gdi.PAN_MIDLINE = 5
PAN_MIDLINE_HIGH_POINTED: win32more.Windows.Win32.Graphics.Gdi.PAN_MIDLINE = 6
PAN_MIDLINE_HIGH_SERIFED: win32more.Windows.Win32.Graphics.Gdi.PAN_MIDLINE = 7
PAN_MIDLINE_CONSTANT_TRIMMED: win32more.Windows.Win32.Graphics.Gdi.PAN_MIDLINE = 8
PAN_MIDLINE_CONSTANT_POINTED: win32more.Windows.Win32.Graphics.Gdi.PAN_MIDLINE = 9
PAN_MIDLINE_CONSTANT_SERIFED: win32more.Windows.Win32.Graphics.Gdi.PAN_MIDLINE = 10
PAN_MIDLINE_LOW_TRIMMED: win32more.Windows.Win32.Graphics.Gdi.PAN_MIDLINE = 11
PAN_MIDLINE_LOW_POINTED: win32more.Windows.Win32.Graphics.Gdi.PAN_MIDLINE = 12
PAN_MIDLINE_LOW_SERIFED: win32more.Windows.Win32.Graphics.Gdi.PAN_MIDLINE = 13
PAN_PROPORTION = Byte
PAN_PROP_ANY: win32more.Windows.Win32.Graphics.Gdi.PAN_PROPORTION = 0
PAN_PROP_NO_FIT: win32more.Windows.Win32.Graphics.Gdi.PAN_PROPORTION = 1
PAN_PROP_OLD_STYLE: win32more.Windows.Win32.Graphics.Gdi.PAN_PROPORTION = 2
PAN_PROP_MODERN: win32more.Windows.Win32.Graphics.Gdi.PAN_PROPORTION = 3
PAN_PROP_EVEN_WIDTH: win32more.Windows.Win32.Graphics.Gdi.PAN_PROPORTION = 4
PAN_PROP_EXPANDED: win32more.Windows.Win32.Graphics.Gdi.PAN_PROPORTION = 5
PAN_PROP_CONDENSED: win32more.Windows.Win32.Graphics.Gdi.PAN_PROPORTION = 6
PAN_PROP_VERY_EXPANDED: win32more.Windows.Win32.Graphics.Gdi.PAN_PROPORTION = 7
PAN_PROP_VERY_CONDENSED: win32more.Windows.Win32.Graphics.Gdi.PAN_PROPORTION = 8
PAN_PROP_MONOSPACED: win32more.Windows.Win32.Graphics.Gdi.PAN_PROPORTION = 9
PAN_SERIF_STYLE = Byte
PAN_SERIF_ANY: win32more.Windows.Win32.Graphics.Gdi.PAN_SERIF_STYLE = 0
PAN_SERIF_NO_FIT: win32more.Windows.Win32.Graphics.Gdi.PAN_SERIF_STYLE = 1
PAN_SERIF_COVE: win32more.Windows.Win32.Graphics.Gdi.PAN_SERIF_STYLE = 2
PAN_SERIF_OBTUSE_COVE: win32more.Windows.Win32.Graphics.Gdi.PAN_SERIF_STYLE = 3
PAN_SERIF_SQUARE_COVE: win32more.Windows.Win32.Graphics.Gdi.PAN_SERIF_STYLE = 4
PAN_SERIF_OBTUSE_SQUARE_COVE: win32more.Windows.Win32.Graphics.Gdi.PAN_SERIF_STYLE = 5
PAN_SERIF_SQUARE: win32more.Windows.Win32.Graphics.Gdi.PAN_SERIF_STYLE = 6
PAN_SERIF_THIN: win32more.Windows.Win32.Graphics.Gdi.PAN_SERIF_STYLE = 7
PAN_SERIF_BONE: win32more.Windows.Win32.Graphics.Gdi.PAN_SERIF_STYLE = 8
PAN_SERIF_EXAGGERATED: win32more.Windows.Win32.Graphics.Gdi.PAN_SERIF_STYLE = 9
PAN_SERIF_TRIANGLE: win32more.Windows.Win32.Graphics.Gdi.PAN_SERIF_STYLE = 10
PAN_SERIF_NORMAL_SANS: win32more.Windows.Win32.Graphics.Gdi.PAN_SERIF_STYLE = 11
PAN_SERIF_OBTUSE_SANS: win32more.Windows.Win32.Graphics.Gdi.PAN_SERIF_STYLE = 12
PAN_SERIF_PERP_SANS: win32more.Windows.Win32.Graphics.Gdi.PAN_SERIF_STYLE = 13
PAN_SERIF_FLARED: win32more.Windows.Win32.Graphics.Gdi.PAN_SERIF_STYLE = 14
PAN_SERIF_ROUNDED: win32more.Windows.Win32.Graphics.Gdi.PAN_SERIF_STYLE = 15
PAN_STROKE_VARIATION = Byte
PAN_STROKE_ANY: win32more.Windows.Win32.Graphics.Gdi.PAN_STROKE_VARIATION = 0
PAN_STROKE_NO_FIT: win32more.Windows.Win32.Graphics.Gdi.PAN_STROKE_VARIATION = 1
PAN_STROKE_GRADUAL_DIAG: win32more.Windows.Win32.Graphics.Gdi.PAN_STROKE_VARIATION = 2
PAN_STROKE_GRADUAL_TRAN: win32more.Windows.Win32.Graphics.Gdi.PAN_STROKE_VARIATION = 3
PAN_STROKE_GRADUAL_VERT: win32more.Windows.Win32.Graphics.Gdi.PAN_STROKE_VARIATION = 4
PAN_STROKE_GRADUAL_HORZ: win32more.Windows.Win32.Graphics.Gdi.PAN_STROKE_VARIATION = 5
PAN_STROKE_RAPID_VERT: win32more.Windows.Win32.Graphics.Gdi.PAN_STROKE_VARIATION = 6
PAN_STROKE_RAPID_HORZ: win32more.Windows.Win32.Graphics.Gdi.PAN_STROKE_VARIATION = 7
PAN_STROKE_INSTANT_VERT: win32more.Windows.Win32.Graphics.Gdi.PAN_STROKE_VARIATION = 8
PAN_WEIGHT = Byte
PAN_WEIGHT_ANY: win32more.Windows.Win32.Graphics.Gdi.PAN_WEIGHT = 0
PAN_WEIGHT_NO_FIT: win32more.Windows.Win32.Graphics.Gdi.PAN_WEIGHT = 1
PAN_WEIGHT_INDEX: win32more.Windows.Win32.Graphics.Gdi.PAN_WEIGHT = 2
PAN_WEIGHT_VERY_LIGHT: win32more.Windows.Win32.Graphics.Gdi.PAN_WEIGHT = 2
PAN_WEIGHT_LIGHT: win32more.Windows.Win32.Graphics.Gdi.PAN_WEIGHT = 3
PAN_WEIGHT_THIN: win32more.Windows.Win32.Graphics.Gdi.PAN_WEIGHT = 4
PAN_WEIGHT_BOOK: win32more.Windows.Win32.Graphics.Gdi.PAN_WEIGHT = 5
PAN_WEIGHT_MEDIUM: win32more.Windows.Win32.Graphics.Gdi.PAN_WEIGHT = 6
PAN_WEIGHT_DEMI: win32more.Windows.Win32.Graphics.Gdi.PAN_WEIGHT = 7
PAN_WEIGHT_BOLD: win32more.Windows.Win32.Graphics.Gdi.PAN_WEIGHT = 8
PAN_WEIGHT_HEAVY: win32more.Windows.Win32.Graphics.Gdi.PAN_WEIGHT = 9
PAN_WEIGHT_BLACK: win32more.Windows.Win32.Graphics.Gdi.PAN_WEIGHT = 10
PAN_WEIGHT_NORD: win32more.Windows.Win32.Graphics.Gdi.PAN_WEIGHT = 11
PAN_XHEIGHT = Byte
PAN_XHEIGHT_ANY: win32more.Windows.Win32.Graphics.Gdi.PAN_XHEIGHT = 0
PAN_XHEIGHT_NO_FIT: win32more.Windows.Win32.Graphics.Gdi.PAN_XHEIGHT = 1
PAN_XHEIGHT_INDEX: win32more.Windows.Win32.Graphics.Gdi.PAN_XHEIGHT = 9
PAN_XHEIGHT_CONSTANT_SMALL: win32more.Windows.Win32.Graphics.Gdi.PAN_XHEIGHT = 2
PAN_XHEIGHT_CONSTANT_STD: win32more.Windows.Win32.Graphics.Gdi.PAN_XHEIGHT = 3
PAN_XHEIGHT_CONSTANT_LARGE: win32more.Windows.Win32.Graphics.Gdi.PAN_XHEIGHT = 4
PAN_XHEIGHT_DUCKING_SMALL: win32more.Windows.Win32.Graphics.Gdi.PAN_XHEIGHT = 5
PAN_XHEIGHT_DUCKING_STD: win32more.Windows.Win32.Graphics.Gdi.PAN_XHEIGHT = 6
PAN_XHEIGHT_DUCKING_LARGE: win32more.Windows.Win32.Graphics.Gdi.PAN_XHEIGHT = 7
class PELARRAY(Structure):
    paXCount: Int32
    paYCount: Int32
    paXExt: Int32
    paYExt: Int32
    paRGBs: Byte
PEN_STYLE = Int32
PS_GEOMETRIC: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 65536
PS_COSMETIC: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 0
PS_SOLID: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 0
PS_DASH: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 1
PS_DOT: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 2
PS_DASHDOT: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 3
PS_DASHDOTDOT: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 4
PS_NULL: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 5
PS_INSIDEFRAME: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 6
PS_USERSTYLE: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 7
PS_ALTERNATE: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 8
PS_STYLE_MASK: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 15
PS_ENDCAP_ROUND: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 0
PS_ENDCAP_SQUARE: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 256
PS_ENDCAP_FLAT: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 512
PS_ENDCAP_MASK: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 3840
PS_JOIN_ROUND: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 0
PS_JOIN_BEVEL: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 4096
PS_JOIN_MITER: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 8192
PS_JOIN_MASK: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 61440
PS_TYPE_MASK: win32more.Windows.Win32.Graphics.Gdi.PEN_STYLE = 983040
class POINTFX(Structure):
    x: win32more.Windows.Win32.Graphics.Gdi.FIXED
    y: win32more.Windows.Win32.Graphics.Gdi.FIXED
class POLYTEXTA(Structure):
    x: Int32
    y: Int32
    n: UInt32
    lpstr: win32more.Windows.Win32.Foundation.PSTR
    uiFlags: UInt32
    rcl: win32more.Windows.Win32.Foundation.RECT
    pdx: POINTER(Int32)
class POLYTEXTW(Structure):
    x: Int32
    y: Int32
    n: UInt32
    lpstr: win32more.Windows.Win32.Foundation.PWSTR
    uiFlags: UInt32
    rcl: win32more.Windows.Win32.Foundation.RECT
    pdx: POINTER(Int32)
POLYTEXT = UnicodeAlias('POLYTEXTW')
R2_MODE = Int32
R2_BLACK: win32more.Windows.Win32.Graphics.Gdi.R2_MODE = 1
R2_NOTMERGEPEN: win32more.Windows.Win32.Graphics.Gdi.R2_MODE = 2
R2_MASKNOTPEN: win32more.Windows.Win32.Graphics.Gdi.R2_MODE = 3
R2_NOTCOPYPEN: win32more.Windows.Win32.Graphics.Gdi.R2_MODE = 4
R2_MASKPENNOT: win32more.Windows.Win32.Graphics.Gdi.R2_MODE = 5
R2_NOT: win32more.Windows.Win32.Graphics.Gdi.R2_MODE = 6
R2_XORPEN: win32more.Windows.Win32.Graphics.Gdi.R2_MODE = 7
R2_NOTMASKPEN: win32more.Windows.Win32.Graphics.Gdi.R2_MODE = 8
R2_MASKPEN: win32more.Windows.Win32.Graphics.Gdi.R2_MODE = 9
R2_NOTXORPEN: win32more.Windows.Win32.Graphics.Gdi.R2_MODE = 10
R2_NOP: win32more.Windows.Win32.Graphics.Gdi.R2_MODE = 11
R2_MERGENOTPEN: win32more.Windows.Win32.Graphics.Gdi.R2_MODE = 12
R2_COPYPEN: win32more.Windows.Win32.Graphics.Gdi.R2_MODE = 13
R2_MERGEPENNOT: win32more.Windows.Win32.Graphics.Gdi.R2_MODE = 14
R2_MERGEPEN: win32more.Windows.Win32.Graphics.Gdi.R2_MODE = 15
R2_WHITE: win32more.Windows.Win32.Graphics.Gdi.R2_MODE = 16
R2_LAST: win32more.Windows.Win32.Graphics.Gdi.R2_MODE = 16
class RASTERIZER_STATUS(Structure):
    nSize: Int16
    wFlags: Int16
    nLanguageID: Int16
@cfunctype_pointer
def READEMBEDPROC(param0: VoidPtr, param1: VoidPtr, param2: UInt32) -> UInt32: ...
REDRAW_WINDOW_FLAGS = UInt32
RDW_INVALIDATE: win32more.Windows.Win32.Graphics.Gdi.REDRAW_WINDOW_FLAGS = 1
RDW_INTERNALPAINT: win32more.Windows.Win32.Graphics.Gdi.REDRAW_WINDOW_FLAGS = 2
RDW_ERASE: win32more.Windows.Win32.Graphics.Gdi.REDRAW_WINDOW_FLAGS = 4
RDW_VALIDATE: win32more.Windows.Win32.Graphics.Gdi.REDRAW_WINDOW_FLAGS = 8
RDW_NOINTERNALPAINT: win32more.Windows.Win32.Graphics.Gdi.REDRAW_WINDOW_FLAGS = 16
RDW_NOERASE: win32more.Windows.Win32.Graphics.Gdi.REDRAW_WINDOW_FLAGS = 32
RDW_NOCHILDREN: win32more.Windows.Win32.Graphics.Gdi.REDRAW_WINDOW_FLAGS = 64
RDW_ALLCHILDREN: win32more.Windows.Win32.Graphics.Gdi.REDRAW_WINDOW_FLAGS = 128
RDW_UPDATENOW: win32more.Windows.Win32.Graphics.Gdi.REDRAW_WINDOW_FLAGS = 256
RDW_ERASENOW: win32more.Windows.Win32.Graphics.Gdi.REDRAW_WINDOW_FLAGS = 512
RDW_FRAME: win32more.Windows.Win32.Graphics.Gdi.REDRAW_WINDOW_FLAGS = 1024
RDW_NOFRAME: win32more.Windows.Win32.Graphics.Gdi.REDRAW_WINDOW_FLAGS = 2048
class RGBQUAD(Structure):
    rgbBlue: Byte
    rgbGreen: Byte
    rgbRed: Byte
    rgbReserved: Byte
class RGBTRIPLE(Structure):
    rgbtBlue: Byte
    rgbtGreen: Byte
    rgbtRed: Byte
class RGNDATA(Structure):
    rdh: win32more.Windows.Win32.Graphics.Gdi.RGNDATAHEADER
    Buffer: win32more.Windows.Win32.Foundation.CHAR * 1
class RGNDATAHEADER(Structure):
    dwSize: UInt32
    iType: UInt32
    nCount: UInt32
    nRgnSize: UInt32
    rcBound: win32more.Windows.Win32.Foundation.RECT
RGN_COMBINE_MODE = Int32
RGN_AND: win32more.Windows.Win32.Graphics.Gdi.RGN_COMBINE_MODE = 1
RGN_OR: win32more.Windows.Win32.Graphics.Gdi.RGN_COMBINE_MODE = 2
RGN_XOR: win32more.Windows.Win32.Graphics.Gdi.RGN_COMBINE_MODE = 3
RGN_DIFF: win32more.Windows.Win32.Graphics.Gdi.RGN_COMBINE_MODE = 4
RGN_COPY: win32more.Windows.Win32.Graphics.Gdi.RGN_COMBINE_MODE = 5
RGN_MIN: win32more.Windows.Win32.Graphics.Gdi.RGN_COMBINE_MODE = 1
RGN_MAX: win32more.Windows.Win32.Graphics.Gdi.RGN_COMBINE_MODE = 5
ROP_CODE = UInt32
BLACKNESS: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE = 66
NOTSRCERASE: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE = 1114278
NOTSRCCOPY: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE = 3342344
SRCERASE: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE = 4457256
DSTINVERT: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE = 5570569
PATINVERT: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE = 5898313
SRCINVERT: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE = 6684742
SRCAND: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE = 8913094
MERGEPAINT: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE = 12255782
MERGECOPY: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE = 12583114
SRCCOPY: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE = 13369376
SRCPAINT: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE = 15597702
PATCOPY: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE = 15728673
PATPAINT: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE = 16452105
WHITENESS: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE = 16711778
CAPTUREBLT: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE = 1073741824
NOMIRRORBITMAP: win32more.Windows.Win32.Graphics.Gdi.ROP_CODE = 2147483648
SET_BOUNDS_RECT_FLAGS = UInt32
DCB_ACCUMULATE: win32more.Windows.Win32.Graphics.Gdi.SET_BOUNDS_RECT_FLAGS = 2
DCB_DISABLE: win32more.Windows.Win32.Graphics.Gdi.SET_BOUNDS_RECT_FLAGS = 8
DCB_ENABLE: win32more.Windows.Win32.Graphics.Gdi.SET_BOUNDS_RECT_FLAGS = 4
DCB_RESET: win32more.Windows.Win32.Graphics.Gdi.SET_BOUNDS_RECT_FLAGS = 1
STRETCH_BLT_MODE = Int32
BLACKONWHITE: win32more.Windows.Win32.Graphics.Gdi.STRETCH_BLT_MODE = 1
COLORONCOLOR: win32more.Windows.Win32.Graphics.Gdi.STRETCH_BLT_MODE = 3
HALFTONE: win32more.Windows.Win32.Graphics.Gdi.STRETCH_BLT_MODE = 4
STRETCH_ANDSCANS: win32more.Windows.Win32.Graphics.Gdi.STRETCH_BLT_MODE = 1
STRETCH_DELETESCANS: win32more.Windows.Win32.Graphics.Gdi.STRETCH_BLT_MODE = 3
STRETCH_HALFTONE: win32more.Windows.Win32.Graphics.Gdi.STRETCH_BLT_MODE = 4
STRETCH_ORSCANS: win32more.Windows.Win32.Graphics.Gdi.STRETCH_BLT_MODE = 2
WHITEONBLACK: win32more.Windows.Win32.Graphics.Gdi.STRETCH_BLT_MODE = 2
SYSTEM_PALETTE_USE = UInt32
SYSPAL_NOSTATIC: win32more.Windows.Win32.Graphics.Gdi.SYSTEM_PALETTE_USE = 2
SYSPAL_NOSTATIC256: win32more.Windows.Win32.Graphics.Gdi.SYSTEM_PALETTE_USE = 3
SYSPAL_STATIC: win32more.Windows.Win32.Graphics.Gdi.SYSTEM_PALETTE_USE = 1
SYS_COLOR_INDEX = Int32
COLOR_SCROLLBAR: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 0
COLOR_BACKGROUND: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 1
COLOR_ACTIVECAPTION: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 2
COLOR_INACTIVECAPTION: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 3
COLOR_MENU: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 4
COLOR_WINDOW: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 5
COLOR_WINDOWFRAME: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 6
COLOR_MENUTEXT: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 7
COLOR_WINDOWTEXT: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 8
COLOR_CAPTIONTEXT: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 9
COLOR_ACTIVEBORDER: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 10
COLOR_INACTIVEBORDER: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 11
COLOR_APPWORKSPACE: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 12
COLOR_HIGHLIGHT: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 13
COLOR_HIGHLIGHTTEXT: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 14
COLOR_BTNFACE: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 15
COLOR_BTNSHADOW: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 16
COLOR_GRAYTEXT: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 17
COLOR_BTNTEXT: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 18
COLOR_INACTIVECAPTIONTEXT: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 19
COLOR_BTNHIGHLIGHT: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 20
COLOR_3DDKSHADOW: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 21
COLOR_3DLIGHT: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 22
COLOR_INFOTEXT: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 23
COLOR_INFOBK: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 24
COLOR_HOTLIGHT: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 26
COLOR_GRADIENTACTIVECAPTION: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 27
COLOR_GRADIENTINACTIVECAPTION: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 28
COLOR_MENUHILIGHT: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 29
COLOR_MENUBAR: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 30
COLOR_DESKTOP: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 1
COLOR_3DFACE: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 15
COLOR_3DSHADOW: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 16
COLOR_3DHIGHLIGHT: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 20
COLOR_3DHILIGHT: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 20
COLOR_BTNHILIGHT: win32more.Windows.Win32.Graphics.Gdi.SYS_COLOR_INDEX = 20
class TEXTMETRICA(Structure):
    tmHeight: Int32
    tmAscent: Int32
    tmDescent: Int32
    tmInternalLeading: Int32
    tmExternalLeading: Int32
    tmAveCharWidth: Int32
    tmMaxCharWidth: Int32
    tmWeight: Int32
    tmOverhang: Int32
    tmDigitizedAspectX: Int32
    tmDigitizedAspectY: Int32
    tmFirstChar: Byte
    tmLastChar: Byte
    tmDefaultChar: Byte
    tmBreakChar: Byte
    tmItalic: Byte
    tmUnderlined: Byte
    tmStruckOut: Byte
    tmPitchAndFamily: win32more.Windows.Win32.Graphics.Gdi.TMPF_FLAGS
    tmCharSet: Byte
class TEXTMETRICW(Structure):
    tmHeight: Int32
    tmAscent: Int32
    tmDescent: Int32
    tmInternalLeading: Int32
    tmExternalLeading: Int32
    tmAveCharWidth: Int32
    tmMaxCharWidth: Int32
    tmWeight: Int32
    tmOverhang: Int32
    tmDigitizedAspectX: Int32
    tmDigitizedAspectY: Int32
    tmFirstChar: Char
    tmLastChar: Char
    tmDefaultChar: Char
    tmBreakChar: Char
    tmItalic: Byte
    tmUnderlined: Byte
    tmStruckOut: Byte
    tmPitchAndFamily: win32more.Windows.Win32.Graphics.Gdi.TMPF_FLAGS
    tmCharSet: Byte
TEXTMETRIC = UnicodeAlias('TEXTMETRICW')
TEXT_ALIGN_OPTIONS = UInt32
TA_NOUPDATECP: win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS = 0
TA_UPDATECP: win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS = 1
TA_LEFT: win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS = 0
TA_RIGHT: win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS = 2
TA_CENTER: win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS = 6
TA_TOP: win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS = 0
TA_BOTTOM: win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS = 8
TA_BASELINE: win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS = 24
TA_RTLREADING: win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS = 256
TA_MASK: win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS = 287
VTA_BASELINE: win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS = 24
VTA_LEFT: win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS = 8
VTA_RIGHT: win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS = 0
VTA_CENTER: win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS = 6
VTA_BOTTOM: win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS = 2
VTA_TOP: win32more.Windows.Win32.Graphics.Gdi.TEXT_ALIGN_OPTIONS = 0
TMPF_FLAGS = Byte
TMPF_FIXED_PITCH: win32more.Windows.Win32.Graphics.Gdi.TMPF_FLAGS = 1
TMPF_VECTOR: win32more.Windows.Win32.Graphics.Gdi.TMPF_FLAGS = 2
TMPF_DEVICE: win32more.Windows.Win32.Graphics.Gdi.TMPF_FLAGS = 8
TMPF_TRUETYPE: win32more.Windows.Win32.Graphics.Gdi.TMPF_FLAGS = 4
class TRIVERTEX(Structure):
    x: Int32
    y: Int32
    Red: UInt16
    Green: UInt16
    Blue: UInt16
    Alpha: UInt16
class TTEMBEDINFO(Structure):
    usStructSize: UInt16
    usRootStrSize: UInt16
    pusRootStr: POINTER(UInt16)
TTEMBED_FLAGS = UInt32
TTEMBED_EMBEDEUDC: win32more.Windows.Win32.Graphics.Gdi.TTEMBED_FLAGS = 32
TTEMBED_RAW: win32more.Windows.Win32.Graphics.Gdi.TTEMBED_FLAGS = 0
TTEMBED_SUBSET: win32more.Windows.Win32.Graphics.Gdi.TTEMBED_FLAGS = 1
TTEMBED_TTCOMPRESSED: win32more.Windows.Win32.Graphics.Gdi.TTEMBED_FLAGS = 4
class TTLOADINFO(Structure):
    usStructSize: UInt16
    usRefStrSize: UInt16
    pusRefStr: POINTER(UInt16)
TTLOAD_EMBEDDED_FONT_STATUS = UInt32
TTLOAD_FONT_SUBSETTED: win32more.Windows.Win32.Graphics.Gdi.TTLOAD_EMBEDDED_FONT_STATUS = 1
TTLOAD_FONT_IN_SYSSTARTUP: win32more.Windows.Win32.Graphics.Gdi.TTLOAD_EMBEDDED_FONT_STATUS = 2
class TTPOLYCURVE(Structure):
    wType: UInt16
    cpfx: UInt16
    apfx: win32more.Windows.Win32.Graphics.Gdi.POINTFX * 1
class TTPOLYGONHEADER(Structure):
    cb: UInt32
    dwType: UInt32
    pfxStart: win32more.Windows.Win32.Graphics.Gdi.POINTFX
class TTVALIDATIONTESTSPARAMS(Structure):
    ulStructSize: UInt32
    lTestFromSize: Int32
    lTestToSize: Int32
    ulCharSet: UInt32
    usReserved1: UInt16
    usCharCodeCount: UInt16
    pusCharCodeSet: POINTER(UInt16)
class TTVALIDATIONTESTSPARAMSEX(Structure):
    ulStructSize: UInt32
    lTestFromSize: Int32
    lTestToSize: Int32
    ulCharSet: UInt32
    usReserved1: UInt16
    usCharCodeCount: UInt16
    pulCharCodeSet: POINTER(UInt32)
class WCRANGE(Structure):
    wcLow: Char
    cGlyphs: UInt16
class WGLSWAP(Structure):
    hdc: win32more.Windows.Win32.Graphics.Gdi.HDC
    uiFlags: UInt32
@cfunctype_pointer
def WRITEEMBEDPROC(param0: VoidPtr, param1: VoidPtr, param2: UInt32) -> UInt32: ...
class XFORM(Structure):
    eM11: Single
    eM12: Single
    eM21: Single
    eM22: Single
    eDx: Single
    eDy: Single


make_ready(__name__)
