from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security.Authorization
import win32more.Windows.Win32.Storage.IndexServer
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Com.StructuredStorage
import win32more.Windows.Win32.System.DistributedTransactionCoordinator
import win32more.Windows.Win32.System.Search
import win32more.Windows.Win32.System.Search.Common
import win32more.Windows.Win32.System.Variant
import win32more.Windows.Win32.UI.Shell.Common
ACCESS_MASKENUM = Int32
PERM_EXCLUSIVE: win32more.Windows.Win32.System.Search.ACCESS_MASKENUM = 512
PERM_READDESIGN: win32more.Windows.Win32.System.Search.ACCESS_MASKENUM = 1024
PERM_WRITEDESIGN: win32more.Windows.Win32.System.Search.ACCESS_MASKENUM = 2048
PERM_WITHGRANT: win32more.Windows.Win32.System.Search.ACCESS_MASKENUM = 4096
PERM_REFERENCE: win32more.Windows.Win32.System.Search.ACCESS_MASKENUM = 8192
PERM_CREATE: win32more.Windows.Win32.System.Search.ACCESS_MASKENUM = 16384
PERM_INSERT: win32more.Windows.Win32.System.Search.ACCESS_MASKENUM = 32768
PERM_DELETE: win32more.Windows.Win32.System.Search.ACCESS_MASKENUM = 65536
PERM_READCONTROL: win32more.Windows.Win32.System.Search.ACCESS_MASKENUM = 131072
PERM_WRITEPERMISSIONS: win32more.Windows.Win32.System.Search.ACCESS_MASKENUM = 262144
PERM_WRITEOWNER: win32more.Windows.Win32.System.Search.ACCESS_MASKENUM = 524288
PERM_MAXIMUM_ALLOWED: win32more.Windows.Win32.System.Search.ACCESS_MASKENUM = 33554432
PERM_ALL: win32more.Windows.Win32.System.Search.ACCESS_MASKENUM = 268435456
PERM_EXECUTE: win32more.Windows.Win32.System.Search.ACCESS_MASKENUM = 536870912
PERM_READ: win32more.Windows.Win32.System.Search.ACCESS_MASKENUM = -2147483648
PERM_UPDATE: win32more.Windows.Win32.System.Search.ACCESS_MASKENUM = 1073741824
PERM_DROP: win32more.Windows.Win32.System.Search.ACCESS_MASKENUM = 256
class AUTHENTICATION_INFO(Structure):
    dwSize: UInt32
    atAuthenticationType: win32more.Windows.Win32.System.Search.AUTH_TYPE
    pcwszUser: win32more.Windows.Win32.Foundation.PWSTR
    pcwszPassword: win32more.Windows.Win32.Foundation.PWSTR
AUTH_TYPE = Int32
eAUTH_TYPE_ANONYMOUS: win32more.Windows.Win32.System.Search.AUTH_TYPE = 0
eAUTH_TYPE_NTLM: win32more.Windows.Win32.System.Search.AUTH_TYPE = 1
eAUTH_TYPE_BASIC: win32more.Windows.Win32.System.Search.AUTH_TYPE = 2
SI_TEMPORARY: UInt32 = 2147483648
SUBSINFO_ALLFLAGS: UInt32 = 61311
RS_READY: UInt32 = 1
RS_SUSPENDED: UInt32 = 2
RS_UPDATING: UInt32 = 4
RS_SUSPENDONIDLE: UInt32 = 65536
RS_MAYBOTHERUSER: UInt32 = 131072
RS_COMPLETED: UInt32 = 2147483648
SUBSMGRUPDATE_MINIMIZE: UInt32 = 1
SUBSMGRUPDATE_MASK: UInt32 = 1
SUBSMGRENUM_TEMP: UInt32 = 1
SUBSMGRENUM_MASK: UInt32 = 1
INET_E_AGENT_MAX_SIZE_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2146693248
INET_S_AGENT_PART_FAIL: win32more.Windows.Win32.Foundation.HRESULT = 790401
INET_E_AGENT_CACHE_SIZE_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2146693246
INET_E_AGENT_CONNECTION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2146693245
INET_E_SCHEDULED_UPDATES_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2146693244
INET_E_SCHEDULED_UPDATES_RESTRICTED: win32more.Windows.Win32.Foundation.HRESULT = -2146693243
INET_E_SCHEDULED_UPDATE_INTERVAL: win32more.Windows.Win32.Foundation.HRESULT = -2146693242
INET_E_SCHEDULED_EXCLUDE_RANGE: win32more.Windows.Win32.Foundation.HRESULT = -2146693241
INET_E_AGENT_EXCEEDING_CACHE_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2146693232
INET_S_AGENT_INCREASED_CACHE_SIZE: win32more.Windows.Win32.Foundation.HRESULT = 790416
OLEDBVER: UInt32 = 624
DB_NULL_HACCESSOR: UInt32 = 0
DB_INVALID_HACCESSOR: UInt32 = 0
DB_NULL_HROW: UInt32 = 0
DB_NULL_HCHAPTER: UInt32 = 0
DB_INVALID_HCHAPTER: UInt32 = 0
STD_BOOKMARKLENGTH: UInt32 = 1
DBCIDGUID: Guid = Guid('{0c733a81-2a1c-11ce-ade5-00aa0044773d}')
DB_NULLGUID: Guid = Guid('{00000000-0000-0000-0000-000000000000}')
DBGUID_ROWURL: Guid = Guid('{0c733ab6-2a1c-11ce-ade5-00aa0044773d}')
DBGUID_ROWDEFAULTSTREAM: Guid = Guid('{0c733ab7-2a1c-11ce-ade5-00aa0044773d}')
DBPROPVAL_BMK_NUMERIC: Int32 = 1
DBPROPVAL_BMK_KEY: Int32 = 2
DBPROPVAL_CL_START: Int32 = 1
DBPROPVAL_CL_END: Int32 = 2
DBPROPVAL_CU_DML_STATEMENTS: Int32 = 1
DBPROPVAL_CU_TABLE_DEFINITION: Int32 = 2
DBPROPVAL_CU_INDEX_DEFINITION: Int32 = 4
DBPROPVAL_CU_PRIVILEGE_DEFINITION: Int32 = 8
DBPROPVAL_CD_NOTNULL: Int32 = 1
DBPROPVAL_CB_NULL: Int32 = 1
DBPROPVAL_CB_NON_NULL: Int32 = 2
DBPROPVAL_FU_NOT_SUPPORTED: Int32 = 1
DBPROPVAL_FU_COLUMN: Int32 = 2
DBPROPVAL_FU_TABLE: Int32 = 4
DBPROPVAL_FU_CATALOG: Int32 = 8
DBPROPVAL_GB_NOT_SUPPORTED: Int32 = 1
DBPROPVAL_GB_EQUALS_SELECT: Int32 = 2
DBPROPVAL_GB_CONTAINS_SELECT: Int32 = 4
DBPROPVAL_GB_NO_RELATION: Int32 = 8
DBPROPVAL_HT_DIFFERENT_CATALOGS: Int32 = 1
DBPROPVAL_HT_DIFFERENT_PROVIDERS: Int32 = 2
DBPROPVAL_IC_UPPER: Int32 = 1
DBPROPVAL_IC_LOWER: Int32 = 2
DBPROPVAL_IC_SENSITIVE: Int32 = 4
DBPROPVAL_IC_MIXED: Int32 = 8
DBPROPVAL_LM_NONE: Int32 = 1
DBPROPVAL_LM_READ: Int32 = 2
DBPROPVAL_LM_INTENT: Int32 = 4
DBPROPVAL_LM_RITE: Int32 = 8
DBPROPVAL_NP_OKTODO: Int32 = 1
DBPROPVAL_NP_ABOUTTODO: Int32 = 2
DBPROPVAL_NP_SYNCHAFTER: Int32 = 4
DBPROPVAL_NP_FAILEDTODO: Int32 = 8
DBPROPVAL_NP_DIDEVENT: Int32 = 16
DBPROPVAL_NC_END: Int32 = 1
DBPROPVAL_NC_HIGH: Int32 = 2
DBPROPVAL_NC_LOW: Int32 = 4
DBPROPVAL_NC_START: Int32 = 8
DBPROPVAL_OO_BLOB: Int32 = 1
DBPROPVAL_OO_IPERSIST: Int32 = 2
DBPROPVAL_CB_DELETE: Int32 = 1
DBPROPVAL_CB_PRESERVE: Int32 = 2
DBPROPVAL_SU_DML_STATEMENTS: Int32 = 1
DBPROPVAL_SU_TABLE_DEFINITION: Int32 = 2
DBPROPVAL_SU_INDEX_DEFINITION: Int32 = 4
DBPROPVAL_SU_PRIVILEGE_DEFINITION: Int32 = 8
DBPROPVAL_SQ_CORRELATEDSUBQUERIES: Int32 = 1
DBPROPVAL_SQ_COMPARISON: Int32 = 2
DBPROPVAL_SQ_EXISTS: Int32 = 4
DBPROPVAL_SQ_IN: Int32 = 8
DBPROPVAL_SQ_QUANTIFIED: Int32 = 16
DBPROPVAL_SQ_TABLE: Int32 = 32
DBPROPVAL_SS_ISEQUENTIALSTREAM: Int32 = 1
DBPROPVAL_SS_ISTREAM: Int32 = 2
DBPROPVAL_SS_ISTORAGE: Int32 = 4
DBPROPVAL_SS_ILOCKBYTES: Int32 = 8
DBPROPVAL_TI_CHAOS: Int32 = 16
DBPROPVAL_TI_READUNCOMMITTED: Int32 = 256
DBPROPVAL_TI_BROWSE: Int32 = 256
DBPROPVAL_TI_CURSORSTABILITY: Int32 = 4096
DBPROPVAL_TI_READCOMMITTED: Int32 = 4096
DBPROPVAL_TI_REPEATABLEREAD: Int32 = 65536
DBPROPVAL_TI_SERIALIZABLE: Int32 = 1048576
DBPROPVAL_TI_ISOLATED: Int32 = 1048576
DBPROPVAL_TR_COMMIT_DC: Int32 = 1
DBPROPVAL_TR_COMMIT: Int32 = 2
DBPROPVAL_TR_COMMIT_NO: Int32 = 4
DBPROPVAL_TR_ABORT_DC: Int32 = 8
DBPROPVAL_TR_ABORT: Int32 = 16
DBPROPVAL_TR_ABORT_NO: Int32 = 32
DBPROPVAL_TR_DONTCARE: Int32 = 64
DBPROPVAL_TR_BOTH: Int32 = 128
DBPROPVAL_TR_NONE: Int32 = 256
DBPROPVAL_TR_OPTIMISTIC: Int32 = 512
DBPROPVAL_RT_FREETHREAD: Int32 = 1
DBPROPVAL_RT_APTMTTHREAD: Int32 = 2
DBPROPVAL_RT_SINGLETHREAD: Int32 = 4
DBPROPVAL_UP_CHANGE: Int32 = 1
DBPROPVAL_UP_DELETE: Int32 = 2
DBPROPVAL_UP_INSERT: Int32 = 4
DBPROPVAL_SQL_NONE: Int32 = 0
DBPROPVAL_SQL_ODBC_MINIMUM: Int32 = 1
DBPROPVAL_SQL_ODBC_CORE: Int32 = 2
DBPROPVAL_SQL_ODBC_EXTENDED: Int32 = 4
DBPROPVAL_SQL_ANSI89_IEF: Int32 = 8
DBPROPVAL_SQL_ANSI92_ENTRY: Int32 = 16
DBPROPVAL_SQL_FIPS_TRANSITIONAL: Int32 = 32
DBPROPVAL_SQL_ANSI92_INTERMEDIATE: Int32 = 64
DBPROPVAL_SQL_ANSI92_FULL: Int32 = 128
DBPROPVAL_SQL_ESCAPECLAUSES: Int32 = 256
DBPROPVAL_IT_BTREE: Int32 = 1
DBPROPVAL_IT_HASH: Int32 = 2
DBPROPVAL_IT_CONTENT: Int32 = 3
DBPROPVAL_IT_OTHER: Int32 = 4
DBPROPVAL_IN_DISALLOWNULL: Int32 = 1
DBPROPVAL_IN_IGNORENULL: Int32 = 2
DBPROPVAL_IN_IGNOREANYNULL: Int32 = 4
DBPROPVAL_TC_NONE: Int32 = 0
DBPROPVAL_TC_DML: Int32 = 1
DBPROPVAL_TC_DDL_COMMIT: Int32 = 2
DBPROPVAL_TC_DDL_IGNORE: Int32 = 4
DBPROPVAL_TC_ALL: Int32 = 8
DBPROPVAL_OA_NOTSUPPORTED: Int32 = 1
DBPROPVAL_OA_ATEXECUTE: Int32 = 2
DBPROPVAL_OA_ATROWRELEASE: Int32 = 4
DBPROPVAL_MR_NOTSUPPORTED: Int32 = 0
DBPROPVAL_MR_SUPPORTED: Int32 = 1
DBPROPVAL_MR_CONCURRENT: Int32 = 2
DBPROPVAL_PT_GUID_NAME: Int32 = 1
DBPROPVAL_PT_GUID_PROPID: Int32 = 2
DBPROPVAL_PT_NAME: Int32 = 4
DBPROPVAL_PT_GUID: Int32 = 8
DBPROPVAL_PT_PROPID: Int32 = 16
DBPROPVAL_PT_PGUID_NAME: Int32 = 32
DBPROPVAL_PT_PGUID_PROPID: Int32 = 64
DBPROPVAL_NT_SINGLEROW: Int32 = 1
DBPROPVAL_NT_MULTIPLEROWS: Int32 = 2
DBPROPVAL_ASYNCH_INITIALIZE: Int32 = 1
DBPROPVAL_ASYNCH_SEQUENTIALPOPULATION: Int32 = 2
DBPROPVAL_ASYNCH_RANDOMPOPULATION: Int32 = 4
DBPROPVAL_OP_EQUAL: Int32 = 1
DBPROPVAL_OP_RELATIVE: Int32 = 2
DBPROPVAL_OP_STRING: Int32 = 4
DBPROPVAL_CO_EQUALITY: Int32 = 1
DBPROPVAL_CO_STRING: Int32 = 2
DBPROPVAL_CO_CASESENSITIVE: Int32 = 4
DBPROPVAL_CO_CASEINSENSITIVE: Int32 = 8
DBPROPVAL_CO_CONTAINS: Int32 = 16
DBPROPVAL_CO_BEGINSWITH: Int32 = 32
DBPROPVAL_ASYNCH_BACKGROUNDPOPULATION: Int32 = 8
DBPROPVAL_ASYNCH_PREPOPULATE: Int32 = 16
DBPROPVAL_ASYNCH_POPULATEONDEMAND: Int32 = 32
DBPROPVAL_LM_SINGLEROW: Int32 = 2
DBPROPVAL_SQL_SUBMINIMUM: Int32 = 512
DBPROPVAL_DST_TDP: Int32 = 1
DBPROPVAL_DST_MDP: Int32 = 2
DBPROPVAL_DST_TDPANDMDP: Int32 = 3
MDPROPVAL_AU_UNSUPPORTED: Int32 = 0
MDPROPVAL_AU_UNCHANGED: Int32 = 1
MDPROPVAL_AU_UNKNOWN: Int32 = 2
MDPROPVAL_MF_WITH_CALCMEMBERS: Int32 = 1
MDPROPVAL_MF_WITH_NAMEDSETS: Int32 = 2
MDPROPVAL_MF_CREATE_CALCMEMBERS: Int32 = 4
MDPROPVAL_MF_CREATE_NAMEDSETS: Int32 = 8
MDPROPVAL_MF_SCOPE_SESSION: Int32 = 16
MDPROPVAL_MF_SCOPE_GLOBAL: Int32 = 32
MDPROPVAL_MMF_COUSIN: Int32 = 1
MDPROPVAL_MMF_PARALLELPERIOD: Int32 = 2
MDPROPVAL_MMF_OPENINGPERIOD: Int32 = 4
MDPROPVAL_MMF_CLOSINGPERIOD: Int32 = 8
MDPROPVAL_MNF_MEDIAN: Int32 = 1
MDPROPVAL_MNF_VAR: Int32 = 2
MDPROPVAL_MNF_STDDEV: Int32 = 4
MDPROPVAL_MNF_RANK: Int32 = 8
MDPROPVAL_MNF_AGGREGATE: Int32 = 16
MDPROPVAL_MNF_COVARIANCE: Int32 = 32
MDPROPVAL_MNF_CORRELATION: Int32 = 64
MDPROPVAL_MNF_LINREGSLOPE: Int32 = 128
MDPROPVAL_MNF_LINREGVARIANCE: Int32 = 256
MDPROPVAL_MNF_LINREG2: Int32 = 512
MDPROPVAL_MNF_LINREGPOINT: Int32 = 1024
MDPROPVAL_MNF_DRILLDOWNLEVEL: Int32 = 2048
MDPROPVAL_MNF_DRILLDOWNMEMBERTOP: Int32 = 4096
MDPROPVAL_MNF_DRILLDOWNMEMBERBOTTOM: Int32 = 8192
MDPROPVAL_MNF_DRILLDOWNLEVELTOP: Int32 = 16384
MDPROPVAL_MNF_DRILLDOWNLEVELBOTTOM: Int32 = 32768
MDPROPVAL_MNF_DRILLUPMEMBER: Int32 = 65536
MDPROPVAL_MNF_DRILLUPLEVEL: Int32 = 131072
MDPROPVAL_MSF_TOPPERCENT: Int32 = 1
MDPROPVAL_MSF_BOTTOMPERCENT: Int32 = 2
MDPROPVAL_MSF_TOPSUM: Int32 = 4
MDPROPVAL_MSF_BOTTOMSUM: Int32 = 8
MDPROPVAL_MSF_PERIODSTODATE: Int32 = 16
MDPROPVAL_MSF_LASTPERIODS: Int32 = 32
MDPROPVAL_MSF_YTD: Int32 = 64
MDPROPVAL_MSF_QTD: Int32 = 128
MDPROPVAL_MSF_MTD: Int32 = 256
MDPROPVAL_MSF_WTD: Int32 = 512
MDPROPVAL_MSF_DRILLDOWNMEMBBER: Int32 = 1024
MDPROPVAL_MSF_DRILLDOWNLEVEL: Int32 = 2048
MDPROPVAL_MSF_DRILLDOWNMEMBERTOP: Int32 = 4096
MDPROPVAL_MSF_DRILLDOWNMEMBERBOTTOM: Int32 = 8192
MDPROPVAL_MSF_DRILLDOWNLEVELTOP: Int32 = 16384
MDPROPVAL_MSF_DRILLDOWNLEVELBOTTOM: Int32 = 32768
MDPROPVAL_MSF_DRILLUPMEMBER: Int32 = 65536
MDPROPVAL_MSF_DRILLUPLEVEL: Int32 = 131072
MDPROPVAL_MSF_TOGGLEDRILLSTATE: Int32 = 262144
MDPROPVAL_MD_SELF: Int32 = 1
MDPROPVAL_MD_BEFORE: Int32 = 2
MDPROPVAL_MD_AFTER: Int32 = 4
MDPROPVAL_MSC_LESSTHAN: Int32 = 1
MDPROPVAL_MSC_GREATERTHAN: Int32 = 2
MDPROPVAL_MSC_LESSTHANEQUAL: Int32 = 4
MDPROPVAL_MSC_GREATERTHANEQUAL: Int32 = 8
MDPROPVAL_MC_SINGLECASE: Int32 = 1
MDPROPVAL_MC_SEARCHEDCASE: Int32 = 2
MDPROPVAL_MOQ_OUTERREFERENCE: Int32 = 1
MDPROPVAL_MOQ_DATASOURCE_CUBE: Int32 = 1
MDPROPVAL_MOQ_CATALOG_CUBE: Int32 = 2
MDPROPVAL_MOQ_SCHEMA_CUBE: Int32 = 4
MDPROPVAL_MOQ_CUBE_DIM: Int32 = 8
MDPROPVAL_MOQ_DIM_HIER: Int32 = 16
MDPROPVAL_MOQ_DIMHIER_LEVEL: Int32 = 32
MDPROPVAL_MOQ_LEVEL_MEMBER: Int32 = 64
MDPROPVAL_MOQ_MEMBER_MEMBER: Int32 = 128
MDPROPVAL_MOQ_DIMHIER_MEMBER: Int32 = 256
MDPROPVAL_FS_FULL_SUPPORT: Int32 = 1
MDPROPVAL_FS_GENERATED_COLUMN: Int32 = 2
MDPROPVAL_FS_GENERATED_DIMENSION: Int32 = 3
MDPROPVAL_FS_NO_SUPPORT: Int32 = 4
MDPROPVAL_NL_NAMEDLEVELS: Int32 = 1
MDPROPVAL_NL_NUMBEREDLEVELS: Int32 = 2
MDPROPVAL_MJC_SINGLECUBE: Int32 = 1
MDPROPVAL_MJC_MULTICUBES: Int32 = 2
MDPROPVAL_MJC_IMPLICITCUBE: Int32 = 4
MDPROPVAL_RR_NORANGEROWSET: Int32 = 1
MDPROPVAL_RR_READONLY: Int32 = 2
MDPROPVAL_RR_UPDATE: Int32 = 4
MDPROPVAL_MS_MULTIPLETUPLES: Int32 = 1
MDPROPVAL_MS_SINGLETUPLE: Int32 = 2
MDPROPVAL_NME_ALLDIMENSIONS: Int32 = 0
MDPROPVAL_NME_MEASURESONLY: Int32 = 1
DBPROPVAL_AO_SEQUENTIAL: Int32 = 0
DBPROPVAL_AO_SEQUENTIALSTORAGEOBJECTS: Int32 = 1
DBPROPVAL_AO_RANDOM: Int32 = 2
DBPROPVAL_BD_ROWSET: Int32 = 0
DBPROPVAL_BD_INTRANSACTION: Int32 = 1
DBPROPVAL_BD_XTRANSACTION: Int32 = 2
DBPROPVAL_BD_REORGANIZATION: Int32 = 3
BMK_DURABILITY_ROWSET: Int32 = 0
BMK_DURABILITY_INTRANSACTION: Int32 = 1
BMK_DURABILITY_XTRANSACTION: Int32 = 2
BMK_DURABILITY_REORGANIZATION: Int32 = 3
DBPROPVAL_BO_NOLOG: Int32 = 0
DBPROPVAL_BO_NOINDEXUPDATE: Int32 = 1
DBPROPVAL_BO_REFINTEGRITY: Int32 = 2
DBPROPVAL_STGM_DIRECT: UInt32 = 65536
DBPROPVAL_STGM_TRANSACTED: UInt32 = 131072
DBPROPVAL_STGM_CONVERT: UInt32 = 262144
DBPROPVAL_STGM_FAILIFTHERE: UInt32 = 524288
DBPROPVAL_STGM_PRIORITY: UInt32 = 1048576
DBPROPVAL_STGM_DELETEONRELEASE: UInt32 = 2097152
DBPROPVAL_GB_COLLATE: Int32 = 16
DBPROPVAL_CS_UNINITIALIZED: Int32 = 0
DBPROPVAL_CS_INITIALIZED: Int32 = 1
DBPROPVAL_CS_COMMUNICATIONFAILURE: Int32 = 2
DBPROPVAL_RD_RESETALL: Int32 = -1
DBPROPVAL_OS_RESOURCEPOOLING: Int32 = 1
DBPROPVAL_OS_TXNENLISTMENT: Int32 = 2
DBPROPVAL_OS_CLIENTCURSOR: Int32 = 4
DBPROPVAL_OS_ENABLEALL: Int32 = -1
DBPROPVAL_BI_CROSSROWSET: Int32 = 1
MDPROPVAL_NL_SCHEMAONLY: Int32 = 4
DBPROPVAL_OS_DISABLEALL: Int32 = 0
DBPROPVAL_OO_ROWOBJECT: Int32 = 4
DBPROPVAL_OO_SCOPED: Int32 = 8
DBPROPVAL_OO_DIRECTBIND: Int32 = 16
DBPROPVAL_DST_DOCSOURCE: Int32 = 4
DBPROPVAL_GU_NOTSUPPORTED: Int32 = 1
DBPROPVAL_GU_SUFFIX: Int32 = 2
DB_BINDFLAGS_DELAYFETCHCOLUMNS: Int32 = 1
DB_BINDFLAGS_DELAYFETCHSTREAM: Int32 = 2
DB_BINDFLAGS_RECURSIVE: Int32 = 4
DB_BINDFLAGS_OUTPUT: Int32 = 8
DB_BINDFLAGS_COLLECTION: Int32 = 16
DB_BINDFLAGS_OPENIFEXISTS: Int32 = 32
DB_BINDFLAGS_OVERWRITE: Int32 = 64
DB_BINDFLAGS_ISSTRUCTUREDDOCUMENT: Int32 = 128
DBPROPVAL_ORS_TABLE: Int32 = 0
DBPROPVAL_ORS_INDEX: Int32 = 1
DBPROPVAL_ORS_INTEGRATEDINDEX: Int32 = 2
DBPROPVAL_TC_DDL_LOCK: Int32 = 16
DBPROPVAL_ORS_STOREDPROC: Int32 = 4
DBPROPVAL_IN_ALLOWNULL: Int32 = 0
DBPROPVAL_OO_SINGLETON: Int32 = 32
DBPROPVAL_OS_AGR_AFTERSESSION: Int32 = 8
DBPROPVAL_CM_TRANSACTIONS: Int32 = 1
DBPROPVAL_TS_CARDINALITY: Int32 = 1
DBPROPVAL_TS_HISTOGRAM: Int32 = 2
DBPROPVAL_ORS_HISTOGRAM: Int32 = 8
MDPROPVAL_VISUAL_MODE_DEFAULT: Int32 = 0
MDPROPVAL_VISUAL_MODE_VISUAL: Int32 = 1
MDPROPVAL_VISUAL_MODE_VISUAL_OFF: Int32 = 2
DB_IMP_LEVEL_ANONYMOUS: UInt32 = 0
DB_IMP_LEVEL_IDENTIFY: UInt32 = 1
DB_IMP_LEVEL_IMPERSONATE: UInt32 = 2
DB_IMP_LEVEL_DELEGATE: UInt32 = 3
DBPROMPT_PROMPT: UInt32 = 1
DBPROMPT_COMPLETE: UInt32 = 2
DBPROMPT_COMPLETEREQUIRED: UInt32 = 3
DBPROMPT_NOPROMPT: UInt32 = 4
DB_PROT_LEVEL_NONE: UInt32 = 0
DB_PROT_LEVEL_CONNECT: UInt32 = 1
DB_PROT_LEVEL_CALL: UInt32 = 2
DB_PROT_LEVEL_PKT: UInt32 = 3
DB_PROT_LEVEL_PKT_INTEGRITY: UInt32 = 4
DB_PROT_LEVEL_PKT_PRIVACY: UInt32 = 5
DB_MODE_READ: UInt32 = 1
DB_MODE_WRITE: UInt32 = 2
DB_MODE_READWRITE: UInt32 = 3
DB_MODE_SHARE_DENY_READ: UInt32 = 4
DB_MODE_SHARE_DENY_WRITE: UInt32 = 8
DB_MODE_SHARE_EXCLUSIVE: UInt32 = 12
DB_MODE_SHARE_DENY_NONE: UInt32 = 16
DBCOMPUTEMODE_COMPUTED: UInt32 = 1
DBCOMPUTEMODE_DYNAMIC: UInt32 = 2
DBCOMPUTEMODE_NOTCOMPUTED: UInt32 = 3
DBPROPVAL_DF_INITIALLY_DEFERRED: UInt32 = 1
DBPROPVAL_DF_INITIALLY_IMMEDIATE: UInt32 = 2
DBPROPVAL_DF_NOT_DEFERRABLE: UInt32 = 3
DBPARAMTYPE_INPUT: UInt32 = 1
DBPARAMTYPE_INPUTOUTPUT: UInt32 = 2
DBPARAMTYPE_OUTPUT: UInt32 = 3
DBPARAMTYPE_RETURNVALUE: UInt32 = 4
DB_PT_UNKNOWN: UInt32 = 1
DB_PT_PROCEDURE: UInt32 = 2
DB_PT_FUNCTION: UInt32 = 3
DB_REMOTE: UInt32 = 1
DB_LOCAL_SHARED: UInt32 = 2
DB_LOCAL_EXCLUSIVE: UInt32 = 3
DB_COLLATION_ASC: UInt32 = 1
DB_COLLATION_DESC: UInt32 = 2
DB_UNSEARCHABLE: UInt32 = 1
DB_LIKE_ONLY: UInt32 = 2
DB_ALL_EXCEPT_LIKE: UInt32 = 3
DB_SEARCHABLE: UInt32 = 4
MDTREEOP_CHILDREN: UInt32 = 1
MDTREEOP_SIBLINGS: UInt32 = 2
MDTREEOP_PARENT: UInt32 = 4
MDTREEOP_SELF: UInt32 = 8
MDTREEOP_DESCENDANTS: UInt32 = 16
MDTREEOP_ANCESTORS: UInt32 = 32
MD_DIMTYPE_UNKNOWN: UInt32 = 0
MD_DIMTYPE_TIME: UInt32 = 1
MD_DIMTYPE_MEASURE: UInt32 = 2
MD_DIMTYPE_OTHER: UInt32 = 3
MDLEVEL_TYPE_UNKNOWN: UInt32 = 0
MDLEVEL_TYPE_REGULAR: UInt32 = 0
MDLEVEL_TYPE_ALL: UInt32 = 1
MDLEVEL_TYPE_CALCULATED: UInt32 = 2
MDLEVEL_TYPE_TIME: UInt32 = 4
MDLEVEL_TYPE_RESERVED1: UInt32 = 8
MDLEVEL_TYPE_TIME_YEARS: UInt32 = 20
MDLEVEL_TYPE_TIME_HALF_YEAR: UInt32 = 36
MDLEVEL_TYPE_TIME_QUARTERS: UInt32 = 68
MDLEVEL_TYPE_TIME_MONTHS: UInt32 = 132
MDLEVEL_TYPE_TIME_WEEKS: UInt32 = 260
MDLEVEL_TYPE_TIME_DAYS: UInt32 = 516
MDLEVEL_TYPE_TIME_HOURS: UInt32 = 772
MDLEVEL_TYPE_TIME_MINUTES: UInt32 = 1028
MDLEVEL_TYPE_TIME_SECONDS: UInt32 = 2052
MDLEVEL_TYPE_TIME_UNDEFINED: UInt32 = 4100
MDMEASURE_AGGR_UNKNOWN: UInt32 = 0
MDMEASURE_AGGR_SUM: UInt32 = 1
MDMEASURE_AGGR_COUNT: UInt32 = 2
MDMEASURE_AGGR_MIN: UInt32 = 3
MDMEASURE_AGGR_MAX: UInt32 = 4
MDMEASURE_AGGR_AVG: UInt32 = 5
MDMEASURE_AGGR_VAR: UInt32 = 6
MDMEASURE_AGGR_STD: UInt32 = 7
MDMEASURE_AGGR_CALCULATED: UInt32 = 127
MDPROP_MEMBER: UInt32 = 1
MDPROP_CELL: UInt32 = 2
MDMEMBER_TYPE_UNKNOWN: UInt32 = 0
MDMEMBER_TYPE_REGULAR: UInt32 = 1
MDMEMBER_TYPE_ALL: UInt32 = 2
MDMEMBER_TYPE_MEASURE: UInt32 = 3
MDMEMBER_TYPE_FORMULA: UInt32 = 4
MDMEMBER_TYPE_RESERVE1: UInt32 = 5
MDMEMBER_TYPE_RESERVE2: UInt32 = 6
MDMEMBER_TYPE_RESERVE3: UInt32 = 7
MDMEMBER_TYPE_RESERVE4: UInt32 = 8
MDDISPINFO_DRILLED_DOWN: UInt32 = 65536
MDDISPINFO_PARENT_SAME_AS_PREV: UInt32 = 131072
DB_COUNTUNAVAILABLE: Int32 = -1
MDFF_BOLD: UInt32 = 1
MDFF_ITALIC: UInt32 = 2
MDFF_UNDERLINE: UInt32 = 4
MDFF_STRIKEOUT: UInt32 = 8
MDAXIS_COLUMNS: UInt32 = 0
MDAXIS_ROWS: UInt32 = 1
MDAXIS_PAGES: UInt32 = 2
MDAXIS_SECTIONS: UInt32 = 3
MDAXIS_CHAPTERS: UInt32 = 4
MDAXIS_SLICERS: UInt32 = 4294967295
CRESTRICTIONS_DBSCHEMA_ASSERTIONS: UInt32 = 3
CRESTRICTIONS_DBSCHEMA_CATALOGS: UInt32 = 1
CRESTRICTIONS_DBSCHEMA_CHARACTER_SETS: UInt32 = 3
CRESTRICTIONS_DBSCHEMA_COLLATIONS: UInt32 = 3
CRESTRICTIONS_DBSCHEMA_COLUMNS: UInt32 = 4
CRESTRICTIONS_DBSCHEMA_CHECK_CONSTRAINTS: UInt32 = 3
CRESTRICTIONS_DBSCHEMA_CONSTRAINT_COLUMN_USAGE: UInt32 = 4
CRESTRICTIONS_DBSCHEMA_CONSTRAINT_TABLE_USAGE: UInt32 = 3
CRESTRICTIONS_DBSCHEMA_KEY_COLUMN_USAGE: UInt32 = 7
CRESTRICTIONS_DBSCHEMA_REFERENTIAL_CONSTRAINTS: UInt32 = 3
CRESTRICTIONS_DBSCHEMA_TABLE_CONSTRAINTS: UInt32 = 7
CRESTRICTIONS_DBSCHEMA_COLUMN_DOMAIN_USAGE: UInt32 = 4
CRESTRICTIONS_DBSCHEMA_INDEXES: UInt32 = 5
CRESTRICTIONS_DBSCHEMA_OBJECT_ACTIONS: UInt32 = 1
CRESTRICTIONS_DBSCHEMA_OBJECTS: UInt32 = 1
CRESTRICTIONS_DBSCHEMA_COLUMN_PRIVILEGES: UInt32 = 6
CRESTRICTIONS_DBSCHEMA_TABLE_PRIVILEGES: UInt32 = 5
CRESTRICTIONS_DBSCHEMA_USAGE_PRIVILEGES: UInt32 = 6
CRESTRICTIONS_DBSCHEMA_PROCEDURES: UInt32 = 4
CRESTRICTIONS_DBSCHEMA_SCHEMATA: UInt32 = 3
CRESTRICTIONS_DBSCHEMA_SQL_LANGUAGES: UInt32 = 0
CRESTRICTIONS_DBSCHEMA_STATISTICS: UInt32 = 3
CRESTRICTIONS_DBSCHEMA_TABLES: UInt32 = 4
CRESTRICTIONS_DBSCHEMA_TRANSLATIONS: UInt32 = 3
CRESTRICTIONS_DBSCHEMA_PROVIDER_TYPES: UInt32 = 2
CRESTRICTIONS_DBSCHEMA_VIEWS: UInt32 = 3
CRESTRICTIONS_DBSCHEMA_VIEW_COLUMN_USAGE: UInt32 = 3
CRESTRICTIONS_DBSCHEMA_VIEW_TABLE_USAGE: UInt32 = 3
CRESTRICTIONS_DBSCHEMA_PROCEDURE_PARAMETERS: UInt32 = 4
CRESTRICTIONS_DBSCHEMA_FOREIGN_KEYS: UInt32 = 6
CRESTRICTIONS_DBSCHEMA_PRIMARY_KEYS: UInt32 = 3
CRESTRICTIONS_DBSCHEMA_PROCEDURE_COLUMNS: UInt32 = 4
CRESTRICTIONS_DBSCHEMA_TABLES_INFO: UInt32 = 4
CRESTRICTIONS_MDSCHEMA_CUBES: UInt32 = 3
CRESTRICTIONS_MDSCHEMA_DIMENSIONS: UInt32 = 5
CRESTRICTIONS_MDSCHEMA_HIERARCHIES: UInt32 = 6
CRESTRICTIONS_MDSCHEMA_LEVELS: UInt32 = 7
CRESTRICTIONS_MDSCHEMA_MEASURES: UInt32 = 5
CRESTRICTIONS_MDSCHEMA_PROPERTIES: UInt32 = 9
CRESTRICTIONS_MDSCHEMA_MEMBERS: UInt32 = 12
CRESTRICTIONS_DBSCHEMA_TRUSTEE: UInt32 = 4
CRESTRICTIONS_DBSCHEMA_TABLE_STATISTICS: UInt32 = 7
CRESTRICTIONS_DBSCHEMA_CHECK_CONSTRAINTS_BY_TABLE: UInt32 = 6
CRESTRICTIONS_MDSCHEMA_FUNCTIONS: UInt32 = 4
CRESTRICTIONS_MDSCHEMA_ACTIONS: UInt32 = 8
CRESTRICTIONS_MDSCHEMA_COMMANDS: UInt32 = 5
CRESTRICTIONS_MDSCHEMA_SETS: UInt32 = 5
IDENTIFIER_SDK_MASK: UInt32 = 4026531840
IDENTIFIER_SDK_ERROR: UInt32 = 268435456
CLSID_CISimpleCommandCreator: Guid = Guid('{c7b6c04a-cbb5-11d0-bb4c-00c04fc2f410}')
DBPROP_MSDAORA_DETERMINEKEYCOLUMNS: UInt32 = 1
DBPROP_MSDAORA8_DETERMINEKEYCOLUMNS: UInt32 = 2
PWPROP_OSPVALUE: UInt32 = 2
STGM_COLLECTION: Int32 = 8192
STGM_OUTPUT: Int32 = 32768
STGM_OPEN: Int32 = -2147483648
STGM_RECURSIVE: Int32 = 16777216
STGM_STRICTOPEN: Int32 = 1073741824
KAGPROP_QUERYBASEDUPDATES: UInt32 = 2
KAGPROP_MARSHALLABLE: UInt32 = 3
KAGPROP_POSITIONONNEWROW: UInt32 = 4
KAGPROP_IRowsetChangeExtInfo: UInt32 = 5
KAGPROP_CURSOR: UInt32 = 6
KAGPROP_CONCURRENCY: UInt32 = 7
KAGPROP_BLOBSONFOCURSOR: UInt32 = 8
KAGPROP_INCLUDENONEXACT: UInt32 = 9
KAGPROP_FORCESSFIREHOSEMODE: UInt32 = 10
KAGPROP_FORCENOPARAMETERREBIND: UInt32 = 11
KAGPROP_FORCENOPREPARE: UInt32 = 12
KAGPROP_FORCENOREEXECUTE: UInt32 = 13
KAGPROP_ACCESSIBLEPROCEDURES: UInt32 = 2
KAGPROP_ACCESSIBLETABLES: UInt32 = 3
KAGPROP_ODBCSQLOPTIEF: UInt32 = 4
KAGPROP_OJCAPABILITY: UInt32 = 5
KAGPROP_PROCEDURES: UInt32 = 6
KAGPROP_DRIVERNAME: UInt32 = 7
KAGPROP_DRIVERVER: UInt32 = 8
KAGPROP_DRIVERODBCVER: UInt32 = 9
KAGPROP_LIKEESCAPECLAUSE: UInt32 = 10
KAGPROP_SPECIALCHARACTERS: UInt32 = 11
KAGPROP_MAXCOLUMNSINGROUPBY: UInt32 = 12
KAGPROP_MAXCOLUMNSININDEX: UInt32 = 13
KAGPROP_MAXCOLUMNSINORDERBY: UInt32 = 14
KAGPROP_MAXCOLUMNSINSELECT: UInt32 = 15
KAGPROP_MAXCOLUMNSINTABLE: UInt32 = 16
KAGPROP_NUMERICFUNCTIONS: UInt32 = 17
KAGPROP_ODBCSQLCONFORMANCE: UInt32 = 18
KAGPROP_OUTERJOINS: UInt32 = 19
KAGPROP_STRINGFUNCTIONS: UInt32 = 20
KAGPROP_SYSTEMFUNCTIONS: UInt32 = 21
KAGPROP_TIMEDATEFUNCTIONS: UInt32 = 22
KAGPROP_FILEUSAGE: UInt32 = 23
KAGPROP_ACTIVESTATEMENTS: UInt32 = 24
KAGPROP_AUTH_TRUSTEDCONNECTION: UInt32 = 2
KAGPROP_AUTH_SERVERINTEGRATED: UInt32 = 3
KAGPROPVAL_CONCUR_ROWVER: UInt32 = 1
KAGPROPVAL_CONCUR_VALUES: UInt32 = 2
KAGPROPVAL_CONCUR_LOCK: UInt32 = 4
KAGPROPVAL_CONCUR_READ_ONLY: UInt32 = 8
ODBCVER: UInt32 = 896
ODBC_ADD_DSN: UInt32 = 1
ODBC_CONFIG_DSN: UInt32 = 2
ODBC_REMOVE_DSN: UInt32 = 3
ODBC_ADD_SYS_DSN: UInt32 = 4
ODBC_CONFIG_SYS_DSN: UInt32 = 5
ODBC_REMOVE_SYS_DSN: UInt32 = 6
ODBC_REMOVE_DEFAULT_DSN: UInt32 = 7
ODBC_INSTALL_INQUIRY: UInt32 = 1
ODBC_INSTALL_COMPLETE: UInt32 = 2
ODBC_INSTALL_DRIVER: UInt32 = 1
ODBC_REMOVE_DRIVER: UInt32 = 2
ODBC_CONFIG_DRIVER: UInt32 = 3
ODBC_CONFIG_DRIVER_MAX: UInt32 = 100
ODBC_BOTH_DSN: UInt32 = 0
ODBC_USER_DSN: UInt32 = 1
ODBC_SYSTEM_DSN: UInt32 = 2
ODBC_ERROR_GENERAL_ERR: UInt32 = 1
ODBC_ERROR_INVALID_BUFF_LEN: UInt32 = 2
ODBC_ERROR_INVALID_HWND: UInt32 = 3
ODBC_ERROR_INVALID_STR: UInt32 = 4
ODBC_ERROR_INVALID_REQUEST_TYPE: UInt32 = 5
ODBC_ERROR_COMPONENT_NOT_FOUND: UInt32 = 6
ODBC_ERROR_INVALID_NAME: UInt32 = 7
ODBC_ERROR_INVALID_KEYWORD_VALUE: UInt32 = 8
ODBC_ERROR_INVALID_DSN: UInt32 = 9
ODBC_ERROR_INVALID_INF: UInt32 = 10
ODBC_ERROR_REQUEST_FAILED: UInt32 = 11
ODBC_ERROR_INVALID_PATH: UInt32 = 12
ODBC_ERROR_LOAD_LIB_FAILED: UInt32 = 13
ODBC_ERROR_INVALID_PARAM_SEQUENCE: UInt32 = 14
ODBC_ERROR_INVALID_LOG_FILE: UInt32 = 15
ODBC_ERROR_USER_CANCELED: UInt32 = 16
ODBC_ERROR_USAGE_UPDATE_FAILED: UInt32 = 17
ODBC_ERROR_CREATE_DSN_FAILED: UInt32 = 18
ODBC_ERROR_WRITING_SYSINFO_FAILED: UInt32 = 19
ODBC_ERROR_REMOVE_DSN_FAILED: UInt32 = 20
ODBC_ERROR_OUT_OF_MEM: UInt32 = 21
ODBC_ERROR_OUTPUT_STRING_TRUNCATED: UInt32 = 22
ODBC_ERROR_NOTRANINFO: UInt32 = 23
ODBC_ERROR_MAX: UInt32 = 23
SQL_MAX_SQLSERVERNAME: UInt32 = 128
SQL_COPT_SS_BASE: UInt32 = 1200
SQL_COPT_SS_REMOTE_PWD: UInt32 = 1201
SQL_COPT_SS_USE_PROC_FOR_PREP: UInt32 = 1202
SQL_COPT_SS_INTEGRATED_SECURITY: UInt32 = 1203
SQL_COPT_SS_PRESERVE_CURSORS: UInt32 = 1204
SQL_COPT_SS_USER_DATA: UInt32 = 1205
SQL_COPT_SS_FALLBACK_CONNECT: UInt32 = 1210
SQL_COPT_SS_PERF_DATA: UInt32 = 1211
SQL_COPT_SS_PERF_DATA_LOG: UInt32 = 1212
SQL_COPT_SS_PERF_QUERY_INTERVAL: UInt32 = 1213
SQL_COPT_SS_PERF_QUERY_LOG: UInt32 = 1214
SQL_COPT_SS_PERF_QUERY: UInt32 = 1215
SQL_COPT_SS_PERF_DATA_LOG_NOW: UInt32 = 1216
SQL_COPT_SS_QUOTED_IDENT: UInt32 = 1217
SQL_COPT_SS_ANSI_NPW: UInt32 = 1218
SQL_COPT_SS_BCP: UInt32 = 1219
SQL_COPT_SS_TRANSLATE: UInt32 = 1220
SQL_COPT_SS_ATTACHDBFILENAME: UInt32 = 1221
SQL_COPT_SS_CONCAT_NULL: UInt32 = 1222
SQL_COPT_SS_ENCRYPT: UInt32 = 1223
SQL_COPT_SS_MAX_USED: UInt32 = 1223
SQL_SOPT_SS_BASE: UInt32 = 1225
SQL_SOPT_SS_TEXTPTR_LOGGING: UInt32 = 1225
SQL_SOPT_SS_CURRENT_COMMAND: UInt32 = 1226
SQL_SOPT_SS_HIDDEN_COLUMNS: UInt32 = 1227
SQL_SOPT_SS_NOBROWSETABLE: UInt32 = 1228
SQL_SOPT_SS_REGIONALIZE: UInt32 = 1229
SQL_SOPT_SS_CURSOR_OPTIONS: UInt32 = 1230
SQL_SOPT_SS_NOCOUNT_STATUS: UInt32 = 1231
SQL_SOPT_SS_DEFER_PREPARE: UInt32 = 1232
SQL_SOPT_SS_MAX_USED: UInt32 = 1232
SQL_COPT_SS_BASE_EX: UInt32 = 1240
SQL_COPT_SS_BROWSE_CONNECT: UInt32 = 1241
SQL_COPT_SS_BROWSE_SERVER: UInt32 = 1242
SQL_COPT_SS_WARN_ON_CP_ERROR: UInt32 = 1243
SQL_COPT_SS_CONNECTION_DEAD: UInt32 = 1244
SQL_COPT_SS_BROWSE_CACHE_DATA: UInt32 = 1245
SQL_COPT_SS_RESET_CONNECTION: UInt32 = 1246
SQL_COPT_SS_EX_MAX_USED: UInt32 = 1246
SQL_UP_OFF: Int32 = 0
SQL_UP_ON: Int32 = 1
SQL_UP_ON_DROP: Int32 = 2
SQL_UP_DEFAULT: Int32 = 1
SQL_IS_OFF: Int32 = 0
SQL_IS_ON: Int32 = 1
SQL_IS_DEFAULT: Int32 = 0
SQL_PC_OFF: Int32 = 0
SQL_PC_ON: Int32 = 1
SQL_PC_DEFAULT: Int32 = 0
SQL_XL_OFF: Int32 = 0
SQL_XL_ON: Int32 = 1
SQL_XL_DEFAULT: Int32 = 1
SQL_FB_OFF: Int32 = 0
SQL_FB_ON: Int32 = 1
SQL_FB_DEFAULT: Int32 = 0
SQL_BCP_OFF: Int32 = 0
SQL_BCP_ON: Int32 = 1
SQL_BCP_DEFAULT: Int32 = 0
SQL_QI_OFF: Int32 = 0
SQL_QI_ON: Int32 = 1
SQL_QI_DEFAULT: Int32 = 1
SQL_AD_OFF: Int32 = 0
SQL_AD_ON: Int32 = 1
SQL_AD_DEFAULT: Int32 = 1
SQL_CN_OFF: Int32 = 0
SQL_CN_ON: Int32 = 1
SQL_CN_DEFAULT: Int32 = 1
SQL_TL_OFF: Int32 = 0
SQL_TL_ON: Int32 = 1
SQL_TL_DEFAULT: Int32 = 1
SQL_HC_OFF: Int32 = 0
SQL_HC_ON: Int32 = 1
SQL_HC_DEFAULT: Int32 = 0
SQL_NB_OFF: Int32 = 0
SQL_NB_ON: Int32 = 1
SQL_NB_DEFAULT: Int32 = 0
SQL_RE_OFF: Int32 = 0
SQL_RE_ON: Int32 = 1
SQL_RE_DEFAULT: Int32 = 0
SQL_CO_OFF: Int32 = 0
SQL_CO_FFO: Int32 = 1
SQL_CO_AF: Int32 = 2
SQL_CO_FIREHOSE_AF: Int32 = 4
SQL_CO_DEFAULT: Int32 = 0
SQL_NC_OFF: Int32 = 0
SQL_NC_ON: Int32 = 1
SQL_DP_OFF: Int32 = 0
SQL_DP_ON: Int32 = 1
SQL_EN_OFF: Int32 = 0
SQL_EN_ON: Int32 = 1
SQL_MORE_INFO_NO: Int32 = 0
SQL_MORE_INFO_YES: Int32 = 1
SQL_CACHE_DATA_NO: Int32 = 0
SQL_CACHE_DATA_YES: Int32 = 1
SQL_RESET_YES: Int32 = 1
SQL_WARN_NO: Int32 = 0
SQL_WARN_YES: Int32 = 1
SQL_CURSOR_FAST_FORWARD_ONLY: UInt32 = 8
SQL_CA_SS_BASE: UInt32 = 1200
SQL_CA_SS_COLUMN_SSTYPE: UInt32 = 1200
SQL_CA_SS_COLUMN_UTYPE: UInt32 = 1201
SQL_CA_SS_NUM_ORDERS: UInt32 = 1202
SQL_CA_SS_COLUMN_ORDER: UInt32 = 1203
SQL_CA_SS_COLUMN_VARYLEN: UInt32 = 1204
SQL_CA_SS_NUM_COMPUTES: UInt32 = 1205
SQL_CA_SS_COMPUTE_ID: UInt32 = 1206
SQL_CA_SS_COMPUTE_BYLIST: UInt32 = 1207
SQL_CA_SS_COLUMN_ID: UInt32 = 1208
SQL_CA_SS_COLUMN_OP: UInt32 = 1209
SQL_CA_SS_COLUMN_SIZE: UInt32 = 1210
SQL_CA_SS_COLUMN_HIDDEN: UInt32 = 1211
SQL_CA_SS_COLUMN_KEY: UInt32 = 1212
SQL_CA_SS_COLUMN_COLLATION: UInt32 = 1214
SQL_CA_SS_VARIANT_TYPE: UInt32 = 1215
SQL_CA_SS_VARIANT_SQL_TYPE: UInt32 = 1216
SQL_CA_SS_VARIANT_SERVER_TYPE: UInt32 = 1217
SQL_CA_SS_MAX_USED: UInt32 = 1218
SQLTEXT: UInt32 = 35
SQLVARBINARY: UInt32 = 37
SQLINTN: UInt32 = 38
SQLVARCHAR: UInt32 = 39
SQLBINARY: UInt32 = 45
SQLIMAGE: UInt32 = 34
SQLCHARACTER: UInt32 = 47
SQLINT1: UInt32 = 48
SQLBIT: UInt32 = 50
SQLINT2: UInt32 = 52
SQLINT4: UInt32 = 56
SQLMONEY: UInt32 = 60
SQLDATETIME: UInt32 = 61
SQLFLT8: UInt32 = 62
SQLFLTN: UInt32 = 109
SQLMONEYN: UInt32 = 110
SQLDATETIMN: UInt32 = 111
SQLFLT4: UInt32 = 59
SQLMONEY4: UInt32 = 122
SQLDATETIM4: UInt32 = 58
SQLDECIMAL: UInt32 = 106
SQLNUMERIC: UInt32 = 108
SQLUNIQUEID: UInt32 = 36
SQLBIGCHAR: UInt32 = 175
SQLBIGVARCHAR: UInt32 = 167
SQLBIGBINARY: UInt32 = 173
SQLBIGVARBINARY: UInt32 = 165
SQLBITN: UInt32 = 104
SQLNCHAR: UInt32 = 239
SQLNVARCHAR: UInt32 = 231
SQLNTEXT: UInt32 = 99
SQLINT8: UInt32 = 127
SQLVARIANT: UInt32 = 98
SQLudtBINARY: UInt32 = 3
SQLudtBIT: UInt32 = 16
SQLudtBITN: UInt32 = 0
SQLudtCHAR: UInt32 = 1
SQLudtDATETIM4: UInt32 = 22
SQLudtDATETIME: UInt32 = 12
SQLudtDATETIMN: UInt32 = 15
SQLudtDECML: UInt32 = 24
SQLudtDECMLN: UInt32 = 26
SQLudtFLT4: UInt32 = 23
SQLudtFLT8: UInt32 = 8
SQLudtFLTN: UInt32 = 14
SQLudtIMAGE: UInt32 = 20
SQLudtINT1: UInt32 = 5
SQLudtINT2: UInt32 = 6
SQLudtINT4: UInt32 = 7
SQLudtINTN: UInt32 = 13
SQLudtMONEY: UInt32 = 11
SQLudtMONEY4: UInt32 = 21
SQLudtMONEYN: UInt32 = 17
SQLudtNUM: UInt32 = 10
SQLudtNUMN: UInt32 = 25
SQLudtSYSNAME: UInt32 = 18
SQLudtTEXT: UInt32 = 19
SQLudtTIMESTAMP: UInt32 = 80
SQLudtUNIQUEIDENTIFIER: UInt32 = 0
SQLudtVARBINARY: UInt32 = 4
SQLudtVARCHAR: UInt32 = 2
MIN_USER_DATATYPE: UInt32 = 256
SQLAOPSTDEV: UInt32 = 48
SQLAOPSTDEVP: UInt32 = 49
SQLAOPVAR: UInt32 = 50
SQLAOPVARP: UInt32 = 51
SQLAOPCNT: UInt32 = 75
SQLAOPSUM: UInt32 = 77
SQLAOPAVG: UInt32 = 79
SQLAOPMIN: UInt32 = 81
SQLAOPMAX: UInt32 = 82
SQLAOPANY: UInt32 = 83
SQLAOPNOOP: UInt32 = 86
SQL_INFO_SS_FIRST: UInt32 = 1199
SQL_INFO_SS_NETLIB_NAMEW: UInt32 = 1199
SQL_INFO_SS_NETLIB_NAMEA: UInt32 = 1200
SQL_INFO_SS_MAX_USED: UInt32 = 1200
SQL_INFO_SS_NETLIB_NAME: UInt32 = 1199
SQL_SS_VARIANT: Int32 = -150
SQL_DIAG_SS_BASE: Int32 = -1150
SQL_DIAG_SS_MSGSTATE: Int32 = -1150
SQL_DIAG_SS_SEVERITY: Int32 = -1151
SQL_DIAG_SS_SRVNAME: Int32 = -1152
SQL_DIAG_SS_PROCNAME: Int32 = -1153
SQL_DIAG_SS_LINE: Int32 = -1154
SQL_DIAG_DFC_SS_BASE: Int32 = -200
SQL_DIAG_DFC_SS_ALTER_DATABASE: Int32 = -200
SQL_DIAG_DFC_SS_CHECKPOINT: Int32 = -201
SQL_DIAG_DFC_SS_CONDITION: Int32 = -202
SQL_DIAG_DFC_SS_CREATE_DATABASE: Int32 = -203
SQL_DIAG_DFC_SS_CREATE_DEFAULT: Int32 = -204
SQL_DIAG_DFC_SS_CREATE_PROCEDURE: Int32 = -205
SQL_DIAG_DFC_SS_CREATE_RULE: Int32 = -206
SQL_DIAG_DFC_SS_CREATE_TRIGGER: Int32 = -207
SQL_DIAG_DFC_SS_CURSOR_DECLARE: Int32 = -208
SQL_DIAG_DFC_SS_CURSOR_OPEN: Int32 = -209
SQL_DIAG_DFC_SS_CURSOR_FETCH: Int32 = -210
SQL_DIAG_DFC_SS_CURSOR_CLOSE: Int32 = -211
SQL_DIAG_DFC_SS_DEALLOCATE_CURSOR: Int32 = -212
SQL_DIAG_DFC_SS_DBCC: Int32 = -213
SQL_DIAG_DFC_SS_DISK: Int32 = -214
SQL_DIAG_DFC_SS_DROP_DATABASE: Int32 = -215
SQL_DIAG_DFC_SS_DROP_DEFAULT: Int32 = -216
SQL_DIAG_DFC_SS_DROP_PROCEDURE: Int32 = -217
SQL_DIAG_DFC_SS_DROP_RULE: Int32 = -218
SQL_DIAG_DFC_SS_DROP_TRIGGER: Int32 = -219
SQL_DIAG_DFC_SS_DUMP_DATABASE: Int32 = -220
SQL_DIAG_DFC_SS_DUMP_TABLE: Int32 = -221
SQL_DIAG_DFC_SS_DUMP_TRANSACTION: Int32 = -222
SQL_DIAG_DFC_SS_GOTO: Int32 = -223
SQL_DIAG_DFC_SS_INSERT_BULK: Int32 = -224
SQL_DIAG_DFC_SS_KILL: Int32 = -225
SQL_DIAG_DFC_SS_LOAD_DATABASE: Int32 = -226
SQL_DIAG_DFC_SS_LOAD_HEADERONLY: Int32 = -227
SQL_DIAG_DFC_SS_LOAD_TABLE: Int32 = -228
SQL_DIAG_DFC_SS_LOAD_TRANSACTION: Int32 = -229
SQL_DIAG_DFC_SS_PRINT: Int32 = -230
SQL_DIAG_DFC_SS_RAISERROR: Int32 = -231
SQL_DIAG_DFC_SS_READTEXT: Int32 = -232
SQL_DIAG_DFC_SS_RECONFIGURE: Int32 = -233
SQL_DIAG_DFC_SS_RETURN: Int32 = -234
SQL_DIAG_DFC_SS_SELECT_INTO: Int32 = -235
SQL_DIAG_DFC_SS_SET: Int32 = -236
SQL_DIAG_DFC_SS_SET_IDENTITY_INSERT: Int32 = -237
SQL_DIAG_DFC_SS_SET_ROW_COUNT: Int32 = -238
SQL_DIAG_DFC_SS_SET_STATISTICS: Int32 = -239
SQL_DIAG_DFC_SS_SET_TEXTSIZE: Int32 = -240
SQL_DIAG_DFC_SS_SETUSER: Int32 = -241
SQL_DIAG_DFC_SS_SHUTDOWN: Int32 = -242
SQL_DIAG_DFC_SS_TRANS_BEGIN: Int32 = -243
SQL_DIAG_DFC_SS_TRANS_COMMIT: Int32 = -244
SQL_DIAG_DFC_SS_TRANS_PREPARE: Int32 = -245
SQL_DIAG_DFC_SS_TRANS_ROLLBACK: Int32 = -246
SQL_DIAG_DFC_SS_TRANS_SAVE: Int32 = -247
SQL_DIAG_DFC_SS_TRUNCATE_TABLE: Int32 = -248
SQL_DIAG_DFC_SS_UPDATE_STATISTICS: Int32 = -249
SQL_DIAG_DFC_SS_UPDATETEXT: Int32 = -250
SQL_DIAG_DFC_SS_USE: Int32 = -251
SQL_DIAG_DFC_SS_WAITFOR: Int32 = -252
SQL_DIAG_DFC_SS_WRITETEXT: Int32 = -253
SQL_DIAG_DFC_SS_DENY: Int32 = -254
SQL_DIAG_DFC_SS_SET_XCTLVL: Int32 = -255
EX_ANY: UInt32 = 0
EX_INFO: UInt32 = 10
EX_MAXISEVERITY: UInt32 = 10
EX_MISSING: UInt32 = 11
EX_TYPE: UInt32 = 12
EX_DEADLOCK: UInt32 = 13
EX_PERMIT: UInt32 = 14
EX_SYNTAX: UInt32 = 15
EX_USER: UInt32 = 16
EX_RESOURCE: UInt32 = 17
EX_INTOK: UInt32 = 18
MAXUSEVERITY: UInt32 = 18
EX_LIMIT: UInt32 = 19
EX_CMDFATAL: UInt32 = 20
MINFATALERR: UInt32 = 20
EX_DBFATAL: UInt32 = 21
EX_TABCORRUPT: UInt32 = 22
EX_DBCORRUPT: UInt32 = 23
EX_HARDWARE: UInt32 = 24
EX_CONTROL: UInt32 = 25
DBMAXCHAR: UInt32 = 8001
MAXNAME: UInt32 = 129
MAXNUMERICLEN: UInt32 = 16
SQL_PERF_START: UInt32 = 1
SQL_PERF_STOP: UInt32 = 2
SQL_SS_DL_DEFAULT: String = 'STATS.LOG'
SQL_SS_QL_DEFAULT: String = 'QUERY.LOG'
SQL_SS_QI_DEFAULT: UInt32 = 30000
SUCCEED: UInt32 = 1
FAIL: UInt32 = 0
SUCCEED_ABORT: UInt32 = 2
SUCCEED_ASYNC: UInt32 = 3
DB_IN: UInt32 = 1
DB_OUT: UInt32 = 2
BCPMAXERRS: UInt32 = 1
BCPFIRST: UInt32 = 2
BCPLAST: UInt32 = 3
BCPBATCH: UInt32 = 4
BCPKEEPNULLS: UInt32 = 5
BCPABORT: UInt32 = 6
BCPODBC: UInt32 = 7
BCPKEEPIDENTITY: UInt32 = 8
BCP6xFILEFMT: UInt32 = 9
BCPHINTSA: UInt32 = 10
BCPHINTSW: UInt32 = 11
BCPFILECP: UInt32 = 12
BCPUNICODEFILE: UInt32 = 13
BCPTEXTFILE: UInt32 = 14
BCPFILEFMT: UInt32 = 15
BCPFILECP_ACP: UInt32 = 0
BCPFILECP_OEMCP: UInt32 = 1
BCPFILECP_RAW: Int32 = -1
SQL_VARLEN_DATA: Int32 = -10
BCPHINTS: UInt32 = 11
BCP_FMT_TYPE: UInt32 = 1
BCP_FMT_INDICATOR_LEN: UInt32 = 2
BCP_FMT_DATA_LEN: UInt32 = 3
BCP_FMT_TERMINATOR: UInt32 = 4
BCP_FMT_SERVER_COL: UInt32 = 5
BCP_FMT_COLLATION: UInt32 = 6
BCP_FMT_COLLATION_ID: UInt32 = 7
SQL_FAST_CONNECT: UInt32 = 1200
SQL_FC_OFF: Int32 = 0
SQL_FC_ON: Int32 = 1
SQL_FC_DEFAULT: Int32 = 0
SQL_COPT_SS_ANSI_OEM: UInt32 = 1206
SQL_AO_OFF: Int32 = 0
SQL_AO_ON: Int32 = 1
SQL_AO_DEFAULT: Int32 = 0
SQL_REMOTE_PWD: UInt32 = 1201
SQL_USE_PROCEDURE_FOR_PREPARE: UInt32 = 1202
SQL_INTEGRATED_SECURITY: UInt32 = 1203
SQL_PRESERVE_CURSORS: UInt32 = 1204
SQL_TEXTPTR_LOGGING: UInt32 = 1225
SQLDECIMALN: UInt32 = 106
SQLNUMERICN: UInt32 = 108
DB_E_BOGUS: win32more.Windows.Win32.Foundation.HRESULT = -2147217665
DB_E_BADACCESSORHANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2147217920
DB_E_ROWLIMITEXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2147217919
DB_E_READONLYACCESSOR: win32more.Windows.Win32.Foundation.HRESULT = -2147217918
DB_E_SCHEMAVIOLATION: win32more.Windows.Win32.Foundation.HRESULT = -2147217917
DB_E_BADROWHANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2147217916
DB_E_OBJECTOPEN: win32more.Windows.Win32.Foundation.HRESULT = -2147217915
DB_E_BADCHAPTER: win32more.Windows.Win32.Foundation.HRESULT = -2147217914
DB_E_CANTCONVERTVALUE: win32more.Windows.Win32.Foundation.HRESULT = -2147217913
DB_E_BADBINDINFO: win32more.Windows.Win32.Foundation.HRESULT = -2147217912
DB_SEC_E_PERMISSIONDENIED: win32more.Windows.Win32.Foundation.HRESULT = -2147217911
DB_E_NOTAREFERENCECOLUMN: win32more.Windows.Win32.Foundation.HRESULT = -2147217910
DB_E_LIMITREJECTED: win32more.Windows.Win32.Foundation.HRESULT = -2147217909
DB_E_NOCOMMAND: win32more.Windows.Win32.Foundation.HRESULT = -2147217908
DB_E_COSTLIMIT: win32more.Windows.Win32.Foundation.HRESULT = -2147217907
DB_E_BADBOOKMARK: win32more.Windows.Win32.Foundation.HRESULT = -2147217906
DB_E_BADLOCKMODE: win32more.Windows.Win32.Foundation.HRESULT = -2147217905
DB_E_PARAMNOTOPTIONAL: win32more.Windows.Win32.Foundation.HRESULT = -2147217904
DB_E_BADCOLUMNID: win32more.Windows.Win32.Foundation.HRESULT = -2147217903
DB_E_BADRATIO: win32more.Windows.Win32.Foundation.HRESULT = -2147217902
DB_E_BADVALUES: win32more.Windows.Win32.Foundation.HRESULT = -2147217901
DB_E_ERRORSINCOMMAND: win32more.Windows.Win32.Foundation.HRESULT = -2147217900
DB_E_CANTCANCEL: win32more.Windows.Win32.Foundation.HRESULT = -2147217899
DB_E_DIALECTNOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147217898
DB_E_DUPLICATEDATASOURCE: win32more.Windows.Win32.Foundation.HRESULT = -2147217897
DB_E_CANNOTRESTART: win32more.Windows.Win32.Foundation.HRESULT = -2147217896
DB_E_NOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147217895
DB_E_NEWLYINSERTED: win32more.Windows.Win32.Foundation.HRESULT = -2147217893
DB_E_CANNOTFREE: win32more.Windows.Win32.Foundation.HRESULT = -2147217894
DB_E_GOALREJECTED: win32more.Windows.Win32.Foundation.HRESULT = -2147217892
DB_E_UNSUPPORTEDCONVERSION: win32more.Windows.Win32.Foundation.HRESULT = -2147217891
DB_E_BADSTARTPOSITION: win32more.Windows.Win32.Foundation.HRESULT = -2147217890
DB_E_NOQUERY: win32more.Windows.Win32.Foundation.HRESULT = -2147217889
DB_E_NOTREENTRANT: win32more.Windows.Win32.Foundation.HRESULT = -2147217888
DB_E_ERRORSOCCURRED: win32more.Windows.Win32.Foundation.HRESULT = -2147217887
DB_E_NOAGGREGATION: win32more.Windows.Win32.Foundation.HRESULT = -2147217886
DB_E_DELETEDROW: win32more.Windows.Win32.Foundation.HRESULT = -2147217885
DB_E_CANTFETCHBACKWARDS: win32more.Windows.Win32.Foundation.HRESULT = -2147217884
DB_E_ROWSNOTRELEASED: win32more.Windows.Win32.Foundation.HRESULT = -2147217883
DB_E_BADSTORAGEFLAG: win32more.Windows.Win32.Foundation.HRESULT = -2147217882
DB_E_BADCOMPAREOP: win32more.Windows.Win32.Foundation.HRESULT = -2147217881
DB_E_BADSTATUSVALUE: win32more.Windows.Win32.Foundation.HRESULT = -2147217880
DB_E_CANTSCROLLBACKWARDS: win32more.Windows.Win32.Foundation.HRESULT = -2147217879
DB_E_BADREGIONHANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2147217878
DB_E_NONCONTIGUOUSRANGE: win32more.Windows.Win32.Foundation.HRESULT = -2147217877
DB_E_INVALIDTRANSITION: win32more.Windows.Win32.Foundation.HRESULT = -2147217876
DB_E_NOTASUBREGION: win32more.Windows.Win32.Foundation.HRESULT = -2147217875
DB_E_MULTIPLESTATEMENTS: win32more.Windows.Win32.Foundation.HRESULT = -2147217874
DB_E_INTEGRITYVIOLATION: win32more.Windows.Win32.Foundation.HRESULT = -2147217873
DB_E_BADTYPENAME: win32more.Windows.Win32.Foundation.HRESULT = -2147217872
DB_E_ABORTLIMITREACHED: win32more.Windows.Win32.Foundation.HRESULT = -2147217871
DB_E_ROWSETINCOMMAND: win32more.Windows.Win32.Foundation.HRESULT = -2147217870
DB_E_CANTTRANSLATE: win32more.Windows.Win32.Foundation.HRESULT = -2147217869
DB_E_DUPLICATEINDEXID: win32more.Windows.Win32.Foundation.HRESULT = -2147217868
DB_E_NOINDEX: win32more.Windows.Win32.Foundation.HRESULT = -2147217867
DB_E_INDEXINUSE: win32more.Windows.Win32.Foundation.HRESULT = -2147217866
DB_E_NOTABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147217865
DB_E_CONCURRENCYVIOLATION: win32more.Windows.Win32.Foundation.HRESULT = -2147217864
DB_E_BADCOPY: win32more.Windows.Win32.Foundation.HRESULT = -2147217863
DB_E_BADPRECISION: win32more.Windows.Win32.Foundation.HRESULT = -2147217862
DB_E_BADSCALE: win32more.Windows.Win32.Foundation.HRESULT = -2147217861
DB_E_BADTABLEID: win32more.Windows.Win32.Foundation.HRESULT = -2147217860
DB_E_BADID: Int32 = -2147217860
DB_E_BADTYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147217859
DB_E_DUPLICATECOLUMNID: win32more.Windows.Win32.Foundation.HRESULT = -2147217858
DB_E_DUPLICATETABLEID: win32more.Windows.Win32.Foundation.HRESULT = -2147217857
DB_E_TABLEINUSE: win32more.Windows.Win32.Foundation.HRESULT = -2147217856
DB_E_NOLOCALE: win32more.Windows.Win32.Foundation.HRESULT = -2147217855
DB_E_BADRECORDNUM: win32more.Windows.Win32.Foundation.HRESULT = -2147217854
DB_E_BOOKMARKSKIPPED: win32more.Windows.Win32.Foundation.HRESULT = -2147217853
DB_E_BADPROPERTYVALUE: win32more.Windows.Win32.Foundation.HRESULT = -2147217852
DB_E_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2147217851
DB_E_BADACCESSORFLAGS: win32more.Windows.Win32.Foundation.HRESULT = -2147217850
DB_E_BADSTORAGEFLAGS: win32more.Windows.Win32.Foundation.HRESULT = -2147217849
DB_E_BYREFACCESSORNOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147217848
DB_E_NULLACCESSORNOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147217847
DB_E_NOTPREPARED: win32more.Windows.Win32.Foundation.HRESULT = -2147217846
DB_E_BADACCESSORTYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147217845
DB_E_WRITEONLYACCESSOR: win32more.Windows.Win32.Foundation.HRESULT = -2147217844
DB_SEC_E_AUTH_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147217843
DB_E_CANCELED: win32more.Windows.Win32.Foundation.HRESULT = -2147217842
DB_E_CHAPTERNOTRELEASED: win32more.Windows.Win32.Foundation.HRESULT = -2147217841
DB_E_BADSOURCEHANDLE: win32more.Windows.Win32.Foundation.HRESULT = -2147217840
DB_E_PARAMUNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147217839
DB_E_ALREADYINITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2147217838
DB_E_NOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147217837
DB_E_MAXPENDCHANGESEXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2147217836
DB_E_BADORDINAL: win32more.Windows.Win32.Foundation.HRESULT = -2147217835
DB_E_PENDINGCHANGES: win32more.Windows.Win32.Foundation.HRESULT = -2147217834
DB_E_DATAOVERFLOW: win32more.Windows.Win32.Foundation.HRESULT = -2147217833
DB_E_BADHRESULT: win32more.Windows.Win32.Foundation.HRESULT = -2147217832
DB_E_BADLOOKUPID: win32more.Windows.Win32.Foundation.HRESULT = -2147217831
DB_E_BADDYNAMICERRORID: win32more.Windows.Win32.Foundation.HRESULT = -2147217830
DB_E_PENDINGINSERT: win32more.Windows.Win32.Foundation.HRESULT = -2147217829
DB_E_BADCONVERTFLAG: win32more.Windows.Win32.Foundation.HRESULT = -2147217828
DB_E_BADPARAMETERNAME: win32more.Windows.Win32.Foundation.HRESULT = -2147217827
DB_E_MULTIPLESTORAGE: win32more.Windows.Win32.Foundation.HRESULT = -2147217826
DB_E_CANTFILTER: win32more.Windows.Win32.Foundation.HRESULT = -2147217825
DB_E_CANTORDER: win32more.Windows.Win32.Foundation.HRESULT = -2147217824
MD_E_BADTUPLE: win32more.Windows.Win32.Foundation.HRESULT = -2147217823
MD_E_BADCOORDINATE: win32more.Windows.Win32.Foundation.HRESULT = -2147217822
MD_E_INVALIDAXIS: win32more.Windows.Win32.Foundation.HRESULT = -2147217821
MD_E_INVALIDCELLRANGE: win32more.Windows.Win32.Foundation.HRESULT = -2147217820
DB_E_NOCOLUMN: win32more.Windows.Win32.Foundation.HRESULT = -2147217819
DB_E_COMMANDNOTPERSISTED: win32more.Windows.Win32.Foundation.HRESULT = -2147217817
DB_E_DUPLICATEID: win32more.Windows.Win32.Foundation.HRESULT = -2147217816
DB_E_OBJECTCREATIONLIMITREACHED: win32more.Windows.Win32.Foundation.HRESULT = -2147217815
DB_E_BADINDEXID: win32more.Windows.Win32.Foundation.HRESULT = -2147217806
DB_E_BADINITSTRING: win32more.Windows.Win32.Foundation.HRESULT = -2147217805
DB_E_NOPROVIDERSREGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2147217804
DB_E_MISMATCHEDPROVIDER: win32more.Windows.Win32.Foundation.HRESULT = -2147217803
DB_E_BADCOMMANDID: win32more.Windows.Win32.Foundation.HRESULT = -2147217802
SEC_E_PERMISSIONDENIED: Int32 = -2147217911
SEC_E_BADTRUSTEEID: win32more.Windows.Win32.Foundation.HRESULT = -2147217814
SEC_E_NOTRUSTEEID: win32more.Windows.Win32.Foundation.HRESULT = -2147217813
SEC_E_NOMEMBERSHIPSUPPORT: win32more.Windows.Win32.Foundation.HRESULT = -2147217812
SEC_E_INVALIDOBJECT: win32more.Windows.Win32.Foundation.HRESULT = -2147217811
SEC_E_NOOWNER: win32more.Windows.Win32.Foundation.HRESULT = -2147217810
SEC_E_INVALIDACCESSENTRYLIST: win32more.Windows.Win32.Foundation.HRESULT = -2147217809
SEC_E_INVALIDOWNER: win32more.Windows.Win32.Foundation.HRESULT = -2147217808
SEC_E_INVALIDACCESSENTRY: win32more.Windows.Win32.Foundation.HRESULT = -2147217807
DB_E_BADCONSTRAINTTYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147217801
DB_E_BADCONSTRAINTFORM: win32more.Windows.Win32.Foundation.HRESULT = -2147217800
DB_E_BADDEFERRABILITY: win32more.Windows.Win32.Foundation.HRESULT = -2147217799
DB_E_BADMATCHTYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147217792
DB_E_BADUPDATEDELETERULE: win32more.Windows.Win32.Foundation.HRESULT = -2147217782
DB_E_BADCONSTRAINTID: win32more.Windows.Win32.Foundation.HRESULT = -2147217781
DB_E_BADCOMMANDFLAGS: win32more.Windows.Win32.Foundation.HRESULT = -2147217780
DB_E_OBJECTMISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2147217779
DB_E_NOSOURCEOBJECT: win32more.Windows.Win32.Foundation.HRESULT = -2147217775
DB_E_RESOURCELOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2147217774
DB_E_NOTCOLLECTION: win32more.Windows.Win32.Foundation.HRESULT = -2147217773
DB_E_READONLY: win32more.Windows.Win32.Foundation.HRESULT = -2147217772
DB_E_ASYNCNOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147217771
DB_E_CANNOTCONNECT: win32more.Windows.Win32.Foundation.HRESULT = -2147217770
DB_E_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2147217769
DB_E_RESOURCEEXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2147217768
DB_E_RESOURCEOUTOFSCOPE: win32more.Windows.Win32.Foundation.HRESULT = -2147217778
DB_E_DROPRESTRICTED: win32more.Windows.Win32.Foundation.HRESULT = -2147217776
DB_E_DUPLICATECONSTRAINTID: win32more.Windows.Win32.Foundation.HRESULT = -2147217767
DB_E_OUTOFSPACE: win32more.Windows.Win32.Foundation.HRESULT = -2147217766
DB_SEC_E_SAFEMODE_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2147217765
DB_E_NOSTATISTIC: win32more.Windows.Win32.Foundation.HRESULT = -2147217764
DB_E_ALTERRESTRICTED: win32more.Windows.Win32.Foundation.HRESULT = -2147217763
DB_E_RESOURCENOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147217762
DB_E_NOCONSTRAINT: win32more.Windows.Win32.Foundation.HRESULT = -2147217761
DB_E_COLUMNUNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147217760
DB_S_ROWLIMITEXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = 265920
DB_S_COLUMNTYPEMISMATCH: win32more.Windows.Win32.Foundation.HRESULT = 265921
DB_S_TYPEINFOOVERRIDDEN: win32more.Windows.Win32.Foundation.HRESULT = 265922
DB_S_BOOKMARKSKIPPED: win32more.Windows.Win32.Foundation.HRESULT = 265923
DB_S_NONEXTROWSET: win32more.Windows.Win32.Foundation.HRESULT = 265925
DB_S_ENDOFROWSET: win32more.Windows.Win32.Foundation.HRESULT = 265926
DB_S_COMMANDREEXECUTED: win32more.Windows.Win32.Foundation.HRESULT = 265927
DB_S_BUFFERFULL: win32more.Windows.Win32.Foundation.HRESULT = 265928
DB_S_NORESULT: win32more.Windows.Win32.Foundation.HRESULT = 265929
DB_S_CANTRELEASE: win32more.Windows.Win32.Foundation.HRESULT = 265930
DB_S_GOALCHANGED: win32more.Windows.Win32.Foundation.HRESULT = 265931
DB_S_UNWANTEDOPERATION: win32more.Windows.Win32.Foundation.HRESULT = 265932
DB_S_DIALECTIGNORED: win32more.Windows.Win32.Foundation.HRESULT = 265933
DB_S_UNWANTEDPHASE: win32more.Windows.Win32.Foundation.HRESULT = 265934
DB_S_UNWANTEDREASON: win32more.Windows.Win32.Foundation.HRESULT = 265935
DB_S_ASYNCHRONOUS: win32more.Windows.Win32.Foundation.HRESULT = 265936
DB_S_COLUMNSCHANGED: win32more.Windows.Win32.Foundation.HRESULT = 265937
DB_S_ERRORSRETURNED: win32more.Windows.Win32.Foundation.HRESULT = 265938
DB_S_BADROWHANDLE: win32more.Windows.Win32.Foundation.HRESULT = 265939
DB_S_DELETEDROW: win32more.Windows.Win32.Foundation.HRESULT = 265940
DB_S_TOOMANYCHANGES: win32more.Windows.Win32.Foundation.HRESULT = 265941
DB_S_STOPLIMITREACHED: win32more.Windows.Win32.Foundation.HRESULT = 265942
DB_S_LOCKUPGRADED: win32more.Windows.Win32.Foundation.HRESULT = 265944
DB_S_PROPERTIESCHANGED: win32more.Windows.Win32.Foundation.HRESULT = 265945
DB_S_ERRORSOCCURRED: win32more.Windows.Win32.Foundation.HRESULT = 265946
DB_S_PARAMUNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = 265947
DB_S_MULTIPLECHANGES: win32more.Windows.Win32.Foundation.HRESULT = 265948
DB_S_NOTSINGLETON: win32more.Windows.Win32.Foundation.HRESULT = 265943
DB_S_NOROWSPECIFICCOLUMNS: win32more.Windows.Win32.Foundation.HRESULT = 265949
DBPROPFLAGS_PERSIST: UInt32 = 8192
DBPROPVAL_PERSIST_ADTG: UInt32 = 0
DBPROPVAL_PERSIST_XML: UInt32 = 1
DBPROP_PersistFormat: UInt32 = 2
DBPROP_PersistSchema: UInt32 = 3
DBPROP_HCHAPTER: UInt32 = 4
DBPROP_MAINTAINPROPS: UInt32 = 5
DBPROP_Unicode: UInt32 = 6
DBPROP_INTERLEAVEDROWS: UInt32 = 8
MS_PERSIST_PROGID: String = 'MSPersist'
DBQUERYGUID: Guid = Guid('{49691c90-7e17-101a-a91c-08002b2ecda9}')
DISPID_QUERY_RANKVECTOR: UInt32 = 2
DISPID_QUERY_RANK: UInt32 = 3
DISPID_QUERY_HITCOUNT: UInt32 = 4
DISPID_QUERY_WORKID: UInt32 = 5
DISPID_QUERY_ALL: UInt32 = 6
DISPID_QUERY_UNFILTERED: UInt32 = 7
DISPID_QUERY_REVNAME: UInt32 = 8
DISPID_QUERY_VIRTUALPATH: UInt32 = 9
DISPID_QUERY_LASTSEENTIME: UInt32 = 10
CQUERYDISPIDS: UInt32 = 11
PSGUID_QUERY_METADATA: Guid = Guid('{624c9360-93d0-11cf-a787-00004c752752}')
DISPID_QUERY_METADATA_VROOTUSED: UInt32 = 2
DISPID_QUERY_METADATA_VROOTAUTOMATIC: UInt32 = 3
DISPID_QUERY_METADATA_VROOTMANUAL: UInt32 = 4
DISPID_QUERY_METADATA_PROPGUID: UInt32 = 5
DISPID_QUERY_METADATA_PROPDISPID: UInt32 = 6
DISPID_QUERY_METADATA_PROPNAME: UInt32 = 7
DISPID_QUERY_METADATA_STORELEVEL: UInt32 = 8
DISPID_QUERY_METADATA_PROPMODIFIABLE: UInt32 = 9
CQUERYMETADISPIDS: UInt32 = 10
DBBMKGUID: Guid = Guid('{c8b52232-5cf3-11ce-ade5-00aa0044773d}')
PROPID_DBBMK_BOOKMARK: UInt32 = 2
PROPID_DBBMK_CHAPTER: UInt32 = 3
CDBBMKDISPIDS: UInt32 = 8
DBSELFGUID: Guid = Guid('{c8b52231-5cf3-11ce-ade5-00aa0044773d}')
PROPID_DBSELF_SELF: UInt32 = 2
CDBSELFDISPIDS: UInt32 = 8
CDBCOLDISPIDS: UInt32 = 28
CQUERYPROPERTY: UInt32 = 64
PSGUID_CHARACTERIZATION: Guid = Guid('{560c36c0-503a-11cf-baa1-00004c752a9a}')
QUERY_VALIDBITS: UInt32 = 3
RTNone: UInt32 = 0
RTAnd: UInt32 = 1
RTOr: UInt32 = 2
RTNot: UInt32 = 3
RTContent: UInt32 = 4
RTProperty: UInt32 = 5
RTProximity: UInt32 = 6
RTVector: UInt32 = 7
RTNatLanguage: UInt32 = 8
GENERATE_METHOD_PREFIXMATCH: UInt32 = 1
GENERATE_METHOD_STEMMED: UInt32 = 2
PRRE: UInt32 = 6
PRAllBits: UInt32 = 7
PRSomeBits: UInt32 = 8
PRAll: UInt32 = 256
PRAny: UInt32 = 512
QUERY_SORTXASCEND: UInt32 = 2
QUERY_SORTXDESCEND: UInt32 = 3
QUERY_SORTDEFAULT: UInt32 = 4
CATEGORIZE_UNIQUE: UInt32 = 0
CATEGORIZE_CLUSTER: UInt32 = 1
CATEGORIZE_BUCKETS: UInt32 = 2
BUCKET_LINEAR: UInt32 = 0
BUCKET_EXPONENTIAL: UInt32 = 1
CATEGORIZE_RANGE: UInt32 = 3
OCC_INVALID: UInt32 = 4294967295
MAX_QUERY_RANK: UInt32 = 1000
OSP_IndexLabel: UInt32 = 0
SQL_NULL_DATA: Int32 = -1
SQL_DATA_AT_EXEC: Int32 = -2
SQL_SUCCESS: UInt32 = 0
SQL_SUCCESS_WITH_INFO: UInt32 = 1
SQL_NO_DATA: UInt32 = 100
SQL_PARAM_DATA_AVAILABLE: UInt32 = 101
SQL_ERROR: Int32 = -1
SQL_INVALID_HANDLE: Int32 = -2
SQL_STILL_EXECUTING: UInt32 = 2
SQL_NEED_DATA: UInt32 = 99
SQL_NTS: Int32 = -3
SQL_NTSL: Int32 = -3
SQL_MAX_MESSAGE_LENGTH: UInt32 = 512
SQL_DATE_LEN: UInt32 = 10
SQL_TIME_LEN: UInt32 = 8
SQL_TIMESTAMP_LEN: UInt32 = 19
SQL_HANDLE_ENV: UInt32 = 1
SQL_HANDLE_DBC: UInt32 = 2
SQL_HANDLE_STMT: UInt32 = 3
SQL_HANDLE_DESC: UInt32 = 4
SQL_ATTR_OUTPUT_NTS: UInt32 = 10001
SQL_ATTR_AUTO_IPD: UInt32 = 10001
SQL_ATTR_METADATA_ID: UInt32 = 10014
SQL_ATTR_APP_ROW_DESC: UInt32 = 10010
SQL_ATTR_APP_PARAM_DESC: UInt32 = 10011
SQL_ATTR_IMP_ROW_DESC: UInt32 = 10012
SQL_ATTR_IMP_PARAM_DESC: UInt32 = 10013
SQL_ATTR_CURSOR_SCROLLABLE: Int32 = -1
SQL_ATTR_CURSOR_SENSITIVITY: Int32 = -2
SQL_NONSCROLLABLE: UInt32 = 0
SQL_SCROLLABLE: UInt32 = 1
SQL_DESC_COUNT: UInt32 = 1001
SQL_DESC_TYPE: UInt32 = 1002
SQL_DESC_LENGTH: UInt32 = 1003
SQL_DESC_OCTET_LENGTH_PTR: UInt32 = 1004
SQL_DESC_PRECISION: UInt32 = 1005
SQL_DESC_SCALE: UInt32 = 1006
SQL_DESC_DATETIME_INTERVAL_CODE: UInt32 = 1007
SQL_DESC_NULLABLE: UInt32 = 1008
SQL_DESC_INDICATOR_PTR: UInt32 = 1009
SQL_DESC_DATA_PTR: UInt32 = 1010
SQL_DESC_NAME: UInt32 = 1011
SQL_DESC_UNNAMED: UInt32 = 1012
SQL_DESC_OCTET_LENGTH: UInt32 = 1013
SQL_DESC_ALLOC_TYPE: UInt32 = 1099
SQL_DIAG_RETURNCODE: UInt32 = 1
SQL_DIAG_NUMBER: UInt32 = 2
SQL_DIAG_ROW_COUNT: UInt32 = 3
SQL_DIAG_SQLSTATE: UInt32 = 4
SQL_DIAG_NATIVE: UInt32 = 5
SQL_DIAG_MESSAGE_TEXT: UInt32 = 6
SQL_DIAG_DYNAMIC_FUNCTION: UInt32 = 7
SQL_DIAG_CLASS_ORIGIN: UInt32 = 8
SQL_DIAG_SUBCLASS_ORIGIN: UInt32 = 9
SQL_DIAG_CONNECTION_NAME: UInt32 = 10
SQL_DIAG_SERVER_NAME: UInt32 = 11
SQL_DIAG_DYNAMIC_FUNCTION_CODE: UInt32 = 12
SQL_DIAG_ALTER_DOMAIN: UInt32 = 3
SQL_DIAG_ALTER_TABLE: UInt32 = 4
SQL_DIAG_CALL: UInt32 = 7
SQL_DIAG_CREATE_ASSERTION: UInt32 = 6
SQL_DIAG_CREATE_CHARACTER_SET: UInt32 = 8
SQL_DIAG_CREATE_COLLATION: UInt32 = 10
SQL_DIAG_CREATE_DOMAIN: UInt32 = 23
SQL_DIAG_CREATE_INDEX: Int32 = -1
SQL_DIAG_CREATE_SCHEMA: UInt32 = 64
SQL_DIAG_CREATE_TABLE: UInt32 = 77
SQL_DIAG_CREATE_TRANSLATION: UInt32 = 79
SQL_DIAG_CREATE_VIEW: UInt32 = 84
SQL_DIAG_DELETE_WHERE: UInt32 = 19
SQL_DIAG_DROP_ASSERTION: UInt32 = 24
SQL_DIAG_DROP_CHARACTER_SET: UInt32 = 25
SQL_DIAG_DROP_COLLATION: UInt32 = 26
SQL_DIAG_DROP_DOMAIN: UInt32 = 27
SQL_DIAG_DROP_INDEX: Int32 = -2
SQL_DIAG_DROP_SCHEMA: UInt32 = 31
SQL_DIAG_DROP_TABLE: UInt32 = 32
SQL_DIAG_DROP_TRANSLATION: UInt32 = 33
SQL_DIAG_DROP_VIEW: UInt32 = 36
SQL_DIAG_DYNAMIC_DELETE_CURSOR: UInt32 = 38
SQL_DIAG_DYNAMIC_UPDATE_CURSOR: UInt32 = 81
SQL_DIAG_GRANT: UInt32 = 48
SQL_DIAG_INSERT: UInt32 = 50
SQL_DIAG_REVOKE: UInt32 = 59
SQL_DIAG_SELECT_CURSOR: UInt32 = 85
SQL_DIAG_UNKNOWN_STATEMENT: UInt32 = 0
SQL_DIAG_UPDATE_WHERE: UInt32 = 82
SQL_UNKNOWN_TYPE: UInt32 = 0
SQL_CHAR: UInt32 = 1
SQL_NUMERIC: UInt32 = 2
SQL_DECIMAL: UInt32 = 3
SQL_INTEGER: UInt32 = 4
SQL_SMALLINT: UInt32 = 5
SQL_FLOAT: UInt32 = 6
SQL_REAL: UInt32 = 7
SQL_DOUBLE: UInt32 = 8
SQL_DATETIME: UInt32 = 9
SQL_VARCHAR: UInt32 = 12
SQL_TYPE_DATE: UInt32 = 91
SQL_TYPE_TIME: UInt32 = 92
SQL_TYPE_TIMESTAMP: UInt32 = 93
SQL_UNSPECIFIED: UInt32 = 0
SQL_INSENSITIVE: UInt32 = 1
SQL_SENSITIVE: UInt32 = 2
SQL_ALL_TYPES: UInt32 = 0
SQL_DEFAULT: UInt32 = 99
SQL_ARD_TYPE: Int32 = -99
SQL_APD_TYPE: Int32 = -100
SQL_CODE_DATE: UInt32 = 1
SQL_CODE_TIME: UInt32 = 2
SQL_CODE_TIMESTAMP: UInt32 = 3
SQL_FALSE: UInt32 = 0
SQL_TRUE: UInt32 = 1
SQL_NO_NULLS: UInt32 = 0
SQL_NULLABLE: UInt32 = 1
SQL_NULLABLE_UNKNOWN: UInt32 = 2
SQL_PRED_NONE: UInt32 = 0
SQL_PRED_CHAR: UInt32 = 1
SQL_PRED_BASIC: UInt32 = 2
SQL_NAMED: UInt32 = 0
SQL_UNNAMED: UInt32 = 1
SQL_DESC_ALLOC_AUTO: UInt32 = 1
SQL_DESC_ALLOC_USER: UInt32 = 2
SQL_CLOSE: UInt32 = 0
SQL_DROP: UInt32 = 1
SQL_UNBIND: UInt32 = 2
SQL_RESET_PARAMS: UInt32 = 3
SQL_FETCH_NEXT: UInt32 = 1
SQL_FETCH_FIRST: UInt32 = 2
SQL_FETCH_LAST: UInt32 = 3
SQL_FETCH_PRIOR: UInt32 = 4
SQL_FETCH_ABSOLUTE: UInt32 = 5
SQL_FETCH_RELATIVE: UInt32 = 6
SQL_COMMIT: UInt32 = 0
SQL_ROLLBACK: UInt32 = 1
SQL_NULL_HENV: UInt32 = 0
SQL_NULL_HDBC: UInt32 = 0
SQL_NULL_HSTMT: UInt32 = 0
SQL_NULL_HDESC: UInt32 = 0
SQL_NULL_HANDLE: Int32 = 0
SQL_SCOPE_CURROW: UInt32 = 0
SQL_SCOPE_TRANSACTION: UInt32 = 1
SQL_SCOPE_SESSION: UInt32 = 2
SQL_PC_UNKNOWN: UInt32 = 0
SQL_PC_NON_PSEUDO: UInt32 = 1
SQL_PC_PSEUDO: UInt32 = 2
SQL_ROW_IDENTIFIER: UInt32 = 1
SQL_INDEX_UNIQUE: UInt32 = 0
SQL_INDEX_ALL: UInt32 = 1
SQL_INDEX_CLUSTERED: UInt32 = 1
SQL_INDEX_HASHED: UInt32 = 2
SQL_INDEX_OTHER: UInt32 = 3
SQL_API_SQLALLOCCONNECT: UInt32 = 1
SQL_API_SQLALLOCENV: UInt32 = 2
SQL_API_SQLALLOCHANDLE: UInt32 = 1001
SQL_API_SQLALLOCSTMT: UInt32 = 3
SQL_API_SQLBINDCOL: UInt32 = 4
SQL_API_SQLBINDPARAM: UInt32 = 1002
SQL_API_SQLCANCEL: UInt32 = 5
SQL_API_SQLCLOSECURSOR: UInt32 = 1003
SQL_API_SQLCOLATTRIBUTE: UInt32 = 6
SQL_API_SQLCOLUMNS: UInt32 = 40
SQL_API_SQLCONNECT: UInt32 = 7
SQL_API_SQLCOPYDESC: UInt32 = 1004
SQL_API_SQLDATASOURCES: UInt32 = 57
SQL_API_SQLDESCRIBECOL: UInt32 = 8
SQL_API_SQLDISCONNECT: UInt32 = 9
SQL_API_SQLENDTRAN: UInt32 = 1005
SQL_API_SQLERROR: UInt32 = 10
SQL_API_SQLEXECDIRECT: UInt32 = 11
SQL_API_SQLEXECUTE: UInt32 = 12
SQL_API_SQLFETCH: UInt32 = 13
SQL_API_SQLFETCHSCROLL: UInt32 = 1021
SQL_API_SQLFREECONNECT: UInt32 = 14
SQL_API_SQLFREEENV: UInt32 = 15
SQL_API_SQLFREEHANDLE: UInt32 = 1006
SQL_API_SQLFREESTMT: UInt32 = 16
SQL_API_SQLGETCONNECTATTR: UInt32 = 1007
SQL_API_SQLGETCONNECTOPTION: UInt32 = 42
SQL_API_SQLGETCURSORNAME: UInt32 = 17
SQL_API_SQLGETDATA: UInt32 = 43
SQL_API_SQLGETDESCFIELD: UInt32 = 1008
SQL_API_SQLGETDESCREC: UInt32 = 1009
SQL_API_SQLGETDIAGFIELD: UInt32 = 1010
SQL_API_SQLGETDIAGREC: UInt32 = 1011
SQL_API_SQLGETENVATTR: UInt32 = 1012
SQL_API_SQLGETFUNCTIONS: UInt32 = 44
SQL_API_SQLGETINFO: UInt32 = 45
SQL_API_SQLGETSTMTATTR: UInt32 = 1014
SQL_API_SQLGETSTMTOPTION: UInt32 = 46
SQL_API_SQLGETTYPEINFO: UInt32 = 47
SQL_API_SQLNUMRESULTCOLS: UInt32 = 18
SQL_API_SQLPARAMDATA: UInt32 = 48
SQL_API_SQLPREPARE: UInt32 = 19
SQL_API_SQLPUTDATA: UInt32 = 49
SQL_API_SQLROWCOUNT: UInt32 = 20
SQL_API_SQLSETCONNECTATTR: UInt32 = 1016
SQL_API_SQLSETCONNECTOPTION: UInt32 = 50
SQL_API_SQLSETCURSORNAME: UInt32 = 21
SQL_API_SQLSETDESCFIELD: UInt32 = 1017
SQL_API_SQLSETDESCREC: UInt32 = 1018
SQL_API_SQLSETENVATTR: UInt32 = 1019
SQL_API_SQLSETPARAM: UInt32 = 22
SQL_API_SQLSETSTMTATTR: UInt32 = 1020
SQL_API_SQLSETSTMTOPTION: UInt32 = 51
SQL_API_SQLSPECIALCOLUMNS: UInt32 = 52
SQL_API_SQLSTATISTICS: UInt32 = 53
SQL_API_SQLTABLES: UInt32 = 54
SQL_API_SQLTRANSACT: UInt32 = 23
SQL_API_SQLCANCELHANDLE: UInt32 = 1550
SQL_API_SQLCOMPLETEASYNC: UInt32 = 1551
SQL_MAX_DRIVER_CONNECTIONS: UInt32 = 0
SQL_MAXIMUM_DRIVER_CONNECTIONS: UInt32 = 0
SQL_MAX_CONCURRENT_ACTIVITIES: UInt32 = 1
SQL_MAXIMUM_CONCURRENT_ACTIVITIES: UInt32 = 1
SQL_DATA_SOURCE_NAME: UInt32 = 2
SQL_FETCH_DIRECTION: UInt32 = 8
SQL_SERVER_NAME: UInt32 = 13
SQL_SEARCH_PATTERN_ESCAPE: UInt32 = 14
SQL_DBMS_NAME: UInt32 = 17
SQL_DBMS_VER: UInt32 = 18
SQL_ACCESSIBLE_TABLES: UInt32 = 19
SQL_ACCESSIBLE_PROCEDURES: UInt32 = 20
SQL_CURSOR_COMMIT_BEHAVIOR: UInt32 = 23
SQL_DATA_SOURCE_READ_ONLY: UInt32 = 25
SQL_DEFAULT_TXN_ISOLATION: UInt32 = 26
SQL_IDENTIFIER_CASE: UInt32 = 28
SQL_IDENTIFIER_QUOTE_CHAR: UInt32 = 29
SQL_MAX_COLUMN_NAME_LEN: UInt32 = 30
SQL_MAXIMUM_COLUMN_NAME_LENGTH: UInt32 = 30
SQL_MAX_CURSOR_NAME_LEN: UInt32 = 31
SQL_MAXIMUM_CURSOR_NAME_LENGTH: UInt32 = 31
SQL_MAX_SCHEMA_NAME_LEN: UInt32 = 32
SQL_MAXIMUM_SCHEMA_NAME_LENGTH: UInt32 = 32
SQL_MAX_CATALOG_NAME_LEN: UInt32 = 34
SQL_MAXIMUM_CATALOG_NAME_LENGTH: UInt32 = 34
SQL_MAX_TABLE_NAME_LEN: UInt32 = 35
SQL_SCROLL_CONCURRENCY: UInt32 = 43
SQL_TXN_CAPABLE: UInt32 = 46
SQL_TRANSACTION_CAPABLE: UInt32 = 46
SQL_USER_NAME: UInt32 = 47
SQL_TXN_ISOLATION_OPTION: UInt32 = 72
SQL_TRANSACTION_ISOLATION_OPTION: UInt32 = 72
SQL_INTEGRITY: UInt32 = 73
SQL_GETDATA_EXTENSIONS: UInt32 = 81
SQL_NULL_COLLATION: UInt32 = 85
SQL_ALTER_TABLE: UInt32 = 86
SQL_ORDER_BY_COLUMNS_IN_SELECT: UInt32 = 90
SQL_SPECIAL_CHARACTERS: UInt32 = 94
SQL_MAX_COLUMNS_IN_GROUP_BY: UInt32 = 97
SQL_MAXIMUM_COLUMNS_IN_GROUP_BY: UInt32 = 97
SQL_MAX_COLUMNS_IN_INDEX: UInt32 = 98
SQL_MAXIMUM_COLUMNS_IN_INDEX: UInt32 = 98
SQL_MAX_COLUMNS_IN_ORDER_BY: UInt32 = 99
SQL_MAXIMUM_COLUMNS_IN_ORDER_BY: UInt32 = 99
SQL_MAX_COLUMNS_IN_SELECT: UInt32 = 100
SQL_MAXIMUM_COLUMNS_IN_SELECT: UInt32 = 100
SQL_MAX_COLUMNS_IN_TABLE: UInt32 = 101
SQL_MAX_INDEX_SIZE: UInt32 = 102
SQL_MAXIMUM_INDEX_SIZE: UInt32 = 102
SQL_MAX_ROW_SIZE: UInt32 = 104
SQL_MAXIMUM_ROW_SIZE: UInt32 = 104
SQL_MAX_STATEMENT_LEN: UInt32 = 105
SQL_MAXIMUM_STATEMENT_LENGTH: UInt32 = 105
SQL_MAX_TABLES_IN_SELECT: UInt32 = 106
SQL_MAXIMUM_TABLES_IN_SELECT: UInt32 = 106
SQL_MAX_USER_NAME_LEN: UInt32 = 107
SQL_MAXIMUM_USER_NAME_LENGTH: UInt32 = 107
SQL_OJ_CAPABILITIES: UInt32 = 115
SQL_OUTER_JOIN_CAPABILITIES: UInt32 = 115
SQL_XOPEN_CLI_YEAR: UInt32 = 10000
SQL_CURSOR_SENSITIVITY: UInt32 = 10001
SQL_DESCRIBE_PARAMETER: UInt32 = 10002
SQL_CATALOG_NAME: UInt32 = 10003
SQL_COLLATION_SEQ: UInt32 = 10004
SQL_MAX_IDENTIFIER_LEN: UInt32 = 10005
SQL_MAXIMUM_IDENTIFIER_LENGTH: UInt32 = 10005
SQL_AT_ADD_COLUMN: Int32 = 1
SQL_AT_DROP_COLUMN: Int32 = 2
SQL_AT_ADD_CONSTRAINT: Int32 = 8
SQL_AM_NONE: UInt32 = 0
SQL_AM_CONNECTION: UInt32 = 1
SQL_AM_STATEMENT: UInt32 = 2
SQL_CB_DELETE: UInt32 = 0
SQL_CB_CLOSE: UInt32 = 1
SQL_CB_PRESERVE: UInt32 = 2
SQL_FD_FETCH_NEXT: Int32 = 1
SQL_FD_FETCH_FIRST: Int32 = 2
SQL_FD_FETCH_LAST: Int32 = 4
SQL_FD_FETCH_PRIOR: Int32 = 8
SQL_FD_FETCH_ABSOLUTE: Int32 = 16
SQL_FD_FETCH_RELATIVE: Int32 = 32
SQL_GD_ANY_COLUMN: Int32 = 1
SQL_GD_ANY_ORDER: Int32 = 2
SQL_IC_UPPER: UInt32 = 1
SQL_IC_LOWER: UInt32 = 2
SQL_IC_SENSITIVE: UInt32 = 3
SQL_IC_MIXED: UInt32 = 4
SQL_OJ_LEFT: Int32 = 1
SQL_OJ_RIGHT: Int32 = 2
SQL_OJ_FULL: Int32 = 4
SQL_OJ_NESTED: Int32 = 8
SQL_OJ_NOT_ORDERED: Int32 = 16
SQL_OJ_INNER: Int32 = 32
SQL_OJ_ALL_COMPARISON_OPS: Int32 = 64
SQL_SCCO_READ_ONLY: Int32 = 1
SQL_SCCO_LOCK: Int32 = 2
SQL_SCCO_OPT_ROWVER: Int32 = 4
SQL_SCCO_OPT_VALUES: Int32 = 8
SQL_TC_NONE: UInt32 = 0
SQL_TC_DML: UInt32 = 1
SQL_TC_ALL: UInt32 = 2
SQL_TC_DDL_COMMIT: UInt32 = 3
SQL_TC_DDL_IGNORE: UInt32 = 4
SQL_TXN_READ_UNCOMMITTED: Int32 = 1
SQL_TRANSACTION_READ_UNCOMMITTED: Int32 = 1
SQL_TXN_READ_COMMITTED: Int32 = 2
SQL_TRANSACTION_READ_COMMITTED: Int32 = 2
SQL_TXN_REPEATABLE_READ: Int32 = 4
SQL_TRANSACTION_REPEATABLE_READ: Int32 = 4
SQL_TXN_SERIALIZABLE: Int32 = 8
SQL_TRANSACTION_SERIALIZABLE: Int32 = 8
SQL_NC_HIGH: UInt32 = 0
SQL_NC_LOW: UInt32 = 1
SQL_SPEC_MAJOR: UInt32 = 3
SQL_SPEC_MINOR: UInt32 = 80
SQL_SPEC_STRING: String = '03.80'
SQL_SQLSTATE_SIZE: UInt32 = 5
SQL_MAX_DSN_LENGTH: UInt32 = 32
SQL_MAX_OPTION_STRING_LENGTH: UInt32 = 256
SQL_NO_DATA_FOUND: UInt32 = 100
SQL_HANDLE_SENV: UInt32 = 5
SQL_ATTR_ODBC_VERSION: UInt32 = 200
SQL_ATTR_CONNECTION_POOLING: UInt32 = 201
SQL_ATTR_CP_MATCH: UInt32 = 202
SQL_ATTR_APPLICATION_KEY: UInt32 = 203
SQL_CP_OFF: UInt32 = 0
SQL_CP_ONE_PER_DRIVER: UInt32 = 1
SQL_CP_ONE_PER_HENV: UInt32 = 2
SQL_CP_DRIVER_AWARE: UInt32 = 3
SQL_CP_DEFAULT: UInt32 = 0
SQL_CP_STRICT_MATCH: UInt32 = 0
SQL_CP_RELAXED_MATCH: UInt32 = 1
SQL_CP_MATCH_DEFAULT: UInt32 = 0
SQL_OV_ODBC2: UInt32 = 2
SQL_OV_ODBC3: UInt32 = 3
SQL_OV_ODBC3_80: UInt32 = 380
SQL_ACCESS_MODE: UInt32 = 101
SQL_AUTOCOMMIT: UInt32 = 102
SQL_LOGIN_TIMEOUT: UInt32 = 103
SQL_OPT_TRACE: UInt32 = 104
SQL_OPT_TRACEFILE: UInt32 = 105
SQL_TRANSLATE_DLL: UInt32 = 106
SQL_TRANSLATE_OPTION: UInt32 = 107
SQL_TXN_ISOLATION: UInt32 = 108
SQL_CURRENT_QUALIFIER: UInt32 = 109
SQL_ODBC_CURSORS: UInt32 = 110
SQL_QUIET_MODE: UInt32 = 111
SQL_PACKET_SIZE: UInt32 = 112
SQL_ATTR_ACCESS_MODE: UInt32 = 101
SQL_ATTR_AUTOCOMMIT: UInt32 = 102
SQL_ATTR_CONNECTION_TIMEOUT: UInt32 = 113
SQL_ATTR_CURRENT_CATALOG: UInt32 = 109
SQL_ATTR_DISCONNECT_BEHAVIOR: UInt32 = 114
SQL_ATTR_ENLIST_IN_DTC: UInt32 = 1207
SQL_ATTR_ENLIST_IN_XA: UInt32 = 1208
SQL_ATTR_LOGIN_TIMEOUT: UInt32 = 103
SQL_ATTR_ODBC_CURSORS: UInt32 = 110
SQL_ATTR_PACKET_SIZE: UInt32 = 112
SQL_ATTR_QUIET_MODE: UInt32 = 111
SQL_ATTR_TRACE: UInt32 = 104
SQL_ATTR_TRACEFILE: UInt32 = 105
SQL_ATTR_TRANSLATE_LIB: UInt32 = 106
SQL_ATTR_TRANSLATE_OPTION: UInt32 = 107
SQL_ATTR_TXN_ISOLATION: UInt32 = 108
SQL_ATTR_CONNECTION_DEAD: UInt32 = 1209
SQL_ATTR_ANSI_APP: UInt32 = 115
SQL_ATTR_RESET_CONNECTION: UInt32 = 116
SQL_ATTR_ASYNC_DBC_FUNCTIONS_ENABLE: UInt32 = 117
SQL_ATTR_ASYNC_DBC_EVENT: UInt32 = 119
SQL_CONNECT_OPT_DRVR_START: UInt32 = 1000
SQL_CONN_OPT_MAX: UInt32 = 112
SQL_CONN_OPT_MIN: UInt32 = 101
SQL_MODE_READ_WRITE: UInt32 = 0
SQL_MODE_READ_ONLY: UInt32 = 1
SQL_MODE_DEFAULT: UInt32 = 0
SQL_AUTOCOMMIT_OFF: UInt32 = 0
SQL_AUTOCOMMIT_ON: UInt32 = 1
SQL_AUTOCOMMIT_DEFAULT: UInt32 = 1
SQL_LOGIN_TIMEOUT_DEFAULT: UInt32 = 15
SQL_OPT_TRACE_OFF: UInt32 = 0
SQL_OPT_TRACE_ON: UInt32 = 1
SQL_OPT_TRACE_DEFAULT: UInt32 = 0
SQL_OPT_TRACE_FILE_DEFAULT: String = '\\SQL.LOG'
SQL_CUR_USE_IF_NEEDED: UInt32 = 0
SQL_CUR_USE_ODBC: UInt32 = 1
SQL_CUR_USE_DRIVER: UInt32 = 2
SQL_CUR_DEFAULT: UInt32 = 2
SQL_DB_RETURN_TO_POOL: UInt32 = 0
SQL_DB_DISCONNECT: UInt32 = 1
SQL_DB_DEFAULT: UInt32 = 0
SQL_DTC_DONE: Int32 = 0
SQL_CD_TRUE: Int32 = 1
SQL_CD_FALSE: Int32 = 0
SQL_AA_TRUE: Int32 = 1
SQL_AA_FALSE: Int32 = 0
SQL_RESET_CONNECTION_YES: UInt32 = 1
SQL_ASYNC_DBC_ENABLE_ON: UInt32 = 1
SQL_ASYNC_DBC_ENABLE_OFF: UInt32 = 0
SQL_ASYNC_DBC_ENABLE_DEFAULT: UInt32 = 0
SQL_QUERY_TIMEOUT: UInt32 = 0
SQL_MAX_ROWS: UInt32 = 1
SQL_NOSCAN: UInt32 = 2
SQL_MAX_LENGTH: UInt32 = 3
SQL_ASYNC_ENABLE: UInt32 = 4
SQL_BIND_TYPE: UInt32 = 5
SQL_CURSOR_TYPE: UInt32 = 6
SQL_CONCURRENCY: UInt32 = 7
SQL_KEYSET_SIZE: UInt32 = 8
SQL_ROWSET_SIZE: UInt32 = 9
SQL_SIMULATE_CURSOR: UInt32 = 10
SQL_RETRIEVE_DATA: UInt32 = 11
SQL_USE_BOOKMARKS: UInt32 = 12
SQL_GET_BOOKMARK: UInt32 = 13
SQL_ROW_NUMBER: UInt32 = 14
SQL_ATTR_ASYNC_ENABLE: UInt32 = 4
SQL_ATTR_CONCURRENCY: UInt32 = 7
SQL_ATTR_CURSOR_TYPE: UInt32 = 6
SQL_ATTR_ENABLE_AUTO_IPD: UInt32 = 15
SQL_ATTR_FETCH_BOOKMARK_PTR: UInt32 = 16
SQL_ATTR_KEYSET_SIZE: UInt32 = 8
SQL_ATTR_MAX_LENGTH: UInt32 = 3
SQL_ATTR_MAX_ROWS: UInt32 = 1
SQL_ATTR_NOSCAN: UInt32 = 2
SQL_ATTR_PARAM_BIND_OFFSET_PTR: UInt32 = 17
SQL_ATTR_PARAM_BIND_TYPE: UInt32 = 18
SQL_ATTR_PARAM_OPERATION_PTR: UInt32 = 19
SQL_ATTR_PARAM_STATUS_PTR: UInt32 = 20
SQL_ATTR_PARAMS_PROCESSED_PTR: UInt32 = 21
SQL_ATTR_PARAMSET_SIZE: UInt32 = 22
SQL_ATTR_QUERY_TIMEOUT: UInt32 = 0
SQL_ATTR_RETRIEVE_DATA: UInt32 = 11
SQL_ATTR_ROW_BIND_OFFSET_PTR: UInt32 = 23
SQL_ATTR_ROW_BIND_TYPE: UInt32 = 5
SQL_ATTR_ROW_NUMBER: UInt32 = 14
SQL_ATTR_ROW_OPERATION_PTR: UInt32 = 24
SQL_ATTR_ROW_STATUS_PTR: UInt32 = 25
SQL_ATTR_ROWS_FETCHED_PTR: UInt32 = 26
SQL_ATTR_ROW_ARRAY_SIZE: UInt32 = 27
SQL_ATTR_SIMULATE_CURSOR: UInt32 = 10
SQL_ATTR_USE_BOOKMARKS: UInt32 = 12
SQL_ATTR_ASYNC_STMT_EVENT: UInt32 = 29
SQL_STMT_OPT_MAX: UInt32 = 14
SQL_STMT_OPT_MIN: UInt32 = 0
SQL_IS_POINTER: Int32 = -4
SQL_IS_UINTEGER: Int32 = -5
SQL_IS_INTEGER: Int32 = -6
SQL_IS_USMALLINT: Int32 = -7
SQL_IS_SMALLINT: Int32 = -8
SQL_PARAM_BIND_BY_COLUMN: UInt32 = 0
SQL_PARAM_BIND_TYPE_DEFAULT: UInt32 = 0
SQL_QUERY_TIMEOUT_DEFAULT: UInt32 = 0
SQL_MAX_ROWS_DEFAULT: UInt32 = 0
SQL_NOSCAN_OFF: UInt32 = 0
SQL_NOSCAN_ON: UInt32 = 1
SQL_NOSCAN_DEFAULT: UInt32 = 0
SQL_MAX_LENGTH_DEFAULT: UInt32 = 0
SQL_ASYNC_ENABLE_OFF: UInt32 = 0
SQL_ASYNC_ENABLE_ON: UInt32 = 1
SQL_ASYNC_ENABLE_DEFAULT: UInt32 = 0
SQL_BIND_BY_COLUMN: UInt32 = 0
SQL_BIND_TYPE_DEFAULT: UInt32 = 0
SQL_CONCUR_READ_ONLY: UInt32 = 1
SQL_CONCUR_LOCK: UInt32 = 2
SQL_CONCUR_ROWVER: UInt32 = 3
SQL_CONCUR_VALUES: UInt32 = 4
SQL_CONCUR_DEFAULT: UInt32 = 1
SQL_CURSOR_FORWARD_ONLY: UInt32 = 0
SQL_CURSOR_KEYSET_DRIVEN: UInt32 = 1
SQL_CURSOR_DYNAMIC: UInt32 = 2
SQL_CURSOR_STATIC: UInt32 = 3
SQL_CURSOR_TYPE_DEFAULT: UInt32 = 0
SQL_ROWSET_SIZE_DEFAULT: UInt32 = 1
SQL_KEYSET_SIZE_DEFAULT: UInt32 = 0
SQL_SC_NON_UNIQUE: UInt32 = 0
SQL_SC_TRY_UNIQUE: UInt32 = 1
SQL_SC_UNIQUE: UInt32 = 2
SQL_RD_OFF: UInt32 = 0
SQL_RD_ON: UInt32 = 1
SQL_RD_DEFAULT: UInt32 = 1
SQL_UB_OFF: UInt32 = 0
SQL_UB_ON: UInt32 = 1
SQL_UB_DEFAULT: UInt32 = 0
SQL_UB_FIXED: UInt32 = 1
SQL_UB_VARIABLE: UInt32 = 2
SQL_DESC_ARRAY_SIZE: UInt32 = 20
SQL_DESC_ARRAY_STATUS_PTR: UInt32 = 21
SQL_DESC_BASE_COLUMN_NAME: UInt32 = 22
SQL_DESC_BASE_TABLE_NAME: UInt32 = 23
SQL_DESC_BIND_OFFSET_PTR: UInt32 = 24
SQL_DESC_BIND_TYPE: UInt32 = 25
SQL_DESC_DATETIME_INTERVAL_PRECISION: UInt32 = 26
SQL_DESC_LITERAL_PREFIX: UInt32 = 27
SQL_DESC_LITERAL_SUFFIX: UInt32 = 28
SQL_DESC_LOCAL_TYPE_NAME: UInt32 = 29
SQL_DESC_MAXIMUM_SCALE: UInt32 = 30
SQL_DESC_MINIMUM_SCALE: UInt32 = 31
SQL_DESC_NUM_PREC_RADIX: UInt32 = 32
SQL_DESC_PARAMETER_TYPE: UInt32 = 33
SQL_DESC_ROWS_PROCESSED_PTR: UInt32 = 34
SQL_DESC_ROWVER: UInt32 = 35
SQL_DIAG_CURSOR_ROW_COUNT: Int32 = -1249
SQL_DIAG_ROW_NUMBER: Int32 = -1248
SQL_DIAG_COLUMN_NUMBER: Int32 = -1247
SQL_DATE: UInt32 = 9
SQL_INTERVAL: UInt32 = 10
SQL_TIME: UInt32 = 10
SQL_TIMESTAMP: UInt32 = 11
SQL_LONGVARCHAR: Int32 = -1
SQL_BINARY: Int32 = -2
SQL_VARBINARY: Int32 = -3
SQL_LONGVARBINARY: Int32 = -4
SQL_BIGINT: Int32 = -5
SQL_TINYINT: Int32 = -6
SQL_BIT: Int32 = -7
SQL_GUID: Int32 = -11
SQL_CODE_YEAR: UInt32 = 1
SQL_CODE_MONTH: UInt32 = 2
SQL_CODE_DAY: UInt32 = 3
SQL_CODE_HOUR: UInt32 = 4
SQL_CODE_MINUTE: UInt32 = 5
SQL_CODE_SECOND: UInt32 = 6
SQL_CODE_YEAR_TO_MONTH: UInt32 = 7
SQL_CODE_DAY_TO_HOUR: UInt32 = 8
SQL_CODE_DAY_TO_MINUTE: UInt32 = 9
SQL_CODE_DAY_TO_SECOND: UInt32 = 10
SQL_CODE_HOUR_TO_MINUTE: UInt32 = 11
SQL_CODE_HOUR_TO_SECOND: UInt32 = 12
SQL_CODE_MINUTE_TO_SECOND: UInt32 = 13
SQL_INTERVAL_YEAR: Int32 = -80
SQL_INTERVAL_MONTH: Int32 = -81
SQL_INTERVAL_YEAR_TO_MONTH: Int32 = -82
SQL_INTERVAL_DAY: Int32 = -83
SQL_INTERVAL_HOUR: Int32 = -84
SQL_INTERVAL_MINUTE: Int32 = -85
SQL_INTERVAL_SECOND: Int32 = -86
SQL_INTERVAL_DAY_TO_HOUR: Int32 = -87
SQL_INTERVAL_DAY_TO_MINUTE: Int32 = -88
SQL_INTERVAL_DAY_TO_SECOND: Int32 = -89
SQL_INTERVAL_HOUR_TO_MINUTE: Int32 = -90
SQL_INTERVAL_HOUR_TO_SECOND: Int32 = -91
SQL_INTERVAL_MINUTE_TO_SECOND: Int32 = -92
SQL_UNICODE: Int32 = -95
SQL_UNICODE_VARCHAR: Int32 = -96
SQL_UNICODE_LONGVARCHAR: Int32 = -97
SQL_UNICODE_CHAR: Int32 = -95
SQL_TYPE_DRIVER_START: Int32 = -80
SQL_TYPE_DRIVER_END: Int32 = -97
SQL_C_CHAR: UInt32 = 1
SQL_C_LONG: UInt32 = 4
SQL_C_SHORT: UInt32 = 5
SQL_C_FLOAT: UInt32 = 7
SQL_C_DOUBLE: UInt32 = 8
SQL_C_NUMERIC: UInt32 = 2
SQL_C_DEFAULT: UInt32 = 99
SQL_SIGNED_OFFSET: Int32 = -20
SQL_UNSIGNED_OFFSET: Int32 = -22
SQL_C_DATE: UInt32 = 9
SQL_C_TIME: UInt32 = 10
SQL_C_TIMESTAMP: UInt32 = 11
SQL_C_TYPE_DATE: UInt32 = 91
SQL_C_TYPE_TIME: UInt32 = 92
SQL_C_TYPE_TIMESTAMP: UInt32 = 93
SQL_C_INTERVAL_YEAR: Int32 = -80
SQL_C_INTERVAL_MONTH: Int32 = -81
SQL_C_INTERVAL_DAY: Int32 = -83
SQL_C_INTERVAL_HOUR: Int32 = -84
SQL_C_INTERVAL_MINUTE: Int32 = -85
SQL_C_INTERVAL_SECOND: Int32 = -86
SQL_C_INTERVAL_YEAR_TO_MONTH: Int32 = -82
SQL_C_INTERVAL_DAY_TO_HOUR: Int32 = -87
SQL_C_INTERVAL_DAY_TO_MINUTE: Int32 = -88
SQL_C_INTERVAL_DAY_TO_SECOND: Int32 = -89
SQL_C_INTERVAL_HOUR_TO_MINUTE: Int32 = -90
SQL_C_INTERVAL_HOUR_TO_SECOND: Int32 = -91
SQL_C_INTERVAL_MINUTE_TO_SECOND: Int32 = -92
SQL_C_BINARY: Int32 = -2
SQL_C_BIT: Int32 = -7
SQL_C_TINYINT: Int32 = -6
SQL_C_GUID: Int32 = -11
SQL_TYPE_NULL: UInt32 = 0
SQL_TYPE_MIN: Int32 = -7
SQL_TYPE_MAX: UInt32 = 12
SQL_DRIVER_C_TYPE_BASE: UInt32 = 16384
SQL_DRIVER_SQL_TYPE_BASE: UInt32 = 16384
SQL_DRIVER_DESC_FIELD_BASE: UInt32 = 16384
SQL_DRIVER_DIAG_FIELD_BASE: UInt32 = 16384
SQL_DRIVER_INFO_TYPE_BASE: UInt32 = 16384
SQL_DRIVER_CONN_ATTR_BASE: UInt32 = 16384
SQL_DRIVER_STMT_ATTR_BASE: UInt32 = 16384
SQL_C_VARBOOKMARK: Int32 = -2
SQL_NO_ROW_NUMBER: Int32 = -1
SQL_NO_COLUMN_NUMBER: Int32 = -1
SQL_ROW_NUMBER_UNKNOWN: Int32 = -2
SQL_COLUMN_NUMBER_UNKNOWN: Int32 = -2
SQL_DEFAULT_PARAM: Int32 = -5
SQL_IGNORE: Int32 = -6
SQL_COLUMN_IGNORE: Int32 = -6
SQL_LEN_DATA_AT_EXEC_OFFSET: Int32 = -100
SQL_LEN_BINARY_ATTR_OFFSET: Int32 = -100
SQL_SETPARAM_VALUE_MAX: Int32 = -1
SQL_COLUMN_COUNT: UInt32 = 0
SQL_COLUMN_NAME: UInt32 = 1
SQL_COLUMN_TYPE: UInt32 = 2
SQL_COLUMN_LENGTH: UInt32 = 3
SQL_COLUMN_PRECISION: UInt32 = 4
SQL_COLUMN_SCALE: UInt32 = 5
SQL_COLUMN_DISPLAY_SIZE: UInt32 = 6
SQL_COLUMN_NULLABLE: UInt32 = 7
SQL_COLUMN_UNSIGNED: UInt32 = 8
SQL_COLUMN_MONEY: UInt32 = 9
SQL_COLUMN_UPDATABLE: UInt32 = 10
SQL_COLUMN_AUTO_INCREMENT: UInt32 = 11
SQL_COLUMN_CASE_SENSITIVE: UInt32 = 12
SQL_COLUMN_SEARCHABLE: UInt32 = 13
SQL_COLUMN_TYPE_NAME: UInt32 = 14
SQL_COLUMN_TABLE_NAME: UInt32 = 15
SQL_COLUMN_OWNER_NAME: UInt32 = 16
SQL_COLUMN_QUALIFIER_NAME: UInt32 = 17
SQL_COLUMN_LABEL: UInt32 = 18
SQL_COLATT_OPT_MAX: UInt32 = 18
SQL_COLUMN_DRIVER_START: UInt32 = 1000
SQL_COLATT_OPT_MIN: UInt32 = 0
SQL_ATTR_READONLY: UInt32 = 0
SQL_ATTR_WRITE: UInt32 = 1
SQL_ATTR_READWRITE_UNKNOWN: UInt32 = 2
SQL_UNSEARCHABLE: UInt32 = 0
SQL_LIKE_ONLY: UInt32 = 1
SQL_ALL_EXCEPT_LIKE: UInt32 = 2
SQL_SEARCHABLE: UInt32 = 3
SQL_PRED_SEARCHABLE: UInt32 = 3
SQL_NO_TOTAL: Int32 = -4
SQL_API_SQLALLOCHANDLESTD: UInt32 = 73
SQL_API_SQLBULKOPERATIONS: UInt32 = 24
SQL_API_SQLBINDPARAMETER: UInt32 = 72
SQL_API_SQLBROWSECONNECT: UInt32 = 55
SQL_API_SQLCOLATTRIBUTES: UInt32 = 6
SQL_API_SQLCOLUMNPRIVILEGES: UInt32 = 56
SQL_API_SQLDESCRIBEPARAM: UInt32 = 58
SQL_API_SQLDRIVERCONNECT: UInt32 = 41
SQL_API_SQLDRIVERS: UInt32 = 71
SQL_API_SQLPRIVATEDRIVERS: UInt32 = 79
SQL_API_SQLEXTENDEDFETCH: UInt32 = 59
SQL_API_SQLFOREIGNKEYS: UInt32 = 60
SQL_API_SQLMORERESULTS: UInt32 = 61
SQL_API_SQLNATIVESQL: UInt32 = 62
SQL_API_SQLNUMPARAMS: UInt32 = 63
SQL_API_SQLPARAMOPTIONS: UInt32 = 64
SQL_API_SQLPRIMARYKEYS: UInt32 = 65
SQL_API_SQLPROCEDURECOLUMNS: UInt32 = 66
SQL_API_SQLPROCEDURES: UInt32 = 67
SQL_API_SQLSETPOS: UInt32 = 68
SQL_API_SQLSETSCROLLOPTIONS: UInt32 = 69
SQL_API_SQLTABLEPRIVILEGES: UInt32 = 70
SQL_EXT_API_LAST: UInt32 = 72
SQL_NUM_FUNCTIONS: UInt32 = 23
SQL_EXT_API_START: UInt32 = 40
SQL_API_ALL_FUNCTIONS: UInt32 = 0
SQL_API_LOADBYORDINAL: UInt32 = 199
SQL_API_ODBC3_ALL_FUNCTIONS: UInt32 = 999
SQL_API_ODBC3_ALL_FUNCTIONS_SIZE: UInt32 = 250
SQL_INFO_FIRST: UInt32 = 0
SQL_ACTIVE_CONNECTIONS: UInt32 = 0
SQL_ACTIVE_STATEMENTS: UInt32 = 1
SQL_DRIVER_HDBC: UInt32 = 3
SQL_DRIVER_HENV: UInt32 = 4
SQL_DRIVER_HSTMT: UInt32 = 5
SQL_DRIVER_NAME: UInt32 = 6
SQL_DRIVER_VER: UInt32 = 7
SQL_ODBC_API_CONFORMANCE: UInt32 = 9
SQL_ODBC_VER: UInt32 = 10
SQL_ROW_UPDATES: UInt32 = 11
SQL_ODBC_SAG_CLI_CONFORMANCE: UInt32 = 12
SQL_ODBC_SQL_CONFORMANCE: UInt32 = 15
SQL_PROCEDURES: UInt32 = 21
SQL_CONCAT_NULL_BEHAVIOR: UInt32 = 22
SQL_CURSOR_ROLLBACK_BEHAVIOR: UInt32 = 24
SQL_EXPRESSIONS_IN_ORDERBY: UInt32 = 27
SQL_MAX_OWNER_NAME_LEN: UInt32 = 32
SQL_MAX_PROCEDURE_NAME_LEN: UInt32 = 33
SQL_MAX_QUALIFIER_NAME_LEN: UInt32 = 34
SQL_MULT_RESULT_SETS: UInt32 = 36
SQL_MULTIPLE_ACTIVE_TXN: UInt32 = 37
SQL_OUTER_JOINS: UInt32 = 38
SQL_OWNER_TERM: UInt32 = 39
SQL_PROCEDURE_TERM: UInt32 = 40
SQL_QUALIFIER_NAME_SEPARATOR: UInt32 = 41
SQL_QUALIFIER_TERM: UInt32 = 42
SQL_SCROLL_OPTIONS: UInt32 = 44
SQL_TABLE_TERM: UInt32 = 45
SQL_CONVERT_FUNCTIONS: UInt32 = 48
SQL_NUMERIC_FUNCTIONS: UInt32 = 49
SQL_STRING_FUNCTIONS: UInt32 = 50
SQL_SYSTEM_FUNCTIONS: UInt32 = 51
SQL_TIMEDATE_FUNCTIONS: UInt32 = 52
SQL_CONVERT_BIGINT: UInt32 = 53
SQL_CONVERT_BINARY: UInt32 = 54
SQL_CONVERT_BIT: UInt32 = 55
SQL_CONVERT_CHAR: UInt32 = 56
SQL_CONVERT_DATE: UInt32 = 57
SQL_CONVERT_DECIMAL: UInt32 = 58
SQL_CONVERT_DOUBLE: UInt32 = 59
SQL_CONVERT_FLOAT: UInt32 = 60
SQL_CONVERT_INTEGER: UInt32 = 61
SQL_CONVERT_LONGVARCHAR: UInt32 = 62
SQL_CONVERT_NUMERIC: UInt32 = 63
SQL_CONVERT_REAL: UInt32 = 64
SQL_CONVERT_SMALLINT: UInt32 = 65
SQL_CONVERT_TIME: UInt32 = 66
SQL_CONVERT_TIMESTAMP: UInt32 = 67
SQL_CONVERT_TINYINT: UInt32 = 68
SQL_CONVERT_VARBINARY: UInt32 = 69
SQL_CONVERT_VARCHAR: UInt32 = 70
SQL_CONVERT_LONGVARBINARY: UInt32 = 71
SQL_ODBC_SQL_OPT_IEF: UInt32 = 73
SQL_CORRELATION_NAME: UInt32 = 74
SQL_NON_NULLABLE_COLUMNS: UInt32 = 75
SQL_DRIVER_HLIB: UInt32 = 76
SQL_DRIVER_ODBC_VER: UInt32 = 77
SQL_LOCK_TYPES: UInt32 = 78
SQL_POS_OPERATIONS: UInt32 = 79
SQL_POSITIONED_STATEMENTS: UInt32 = 80
SQL_BOOKMARK_PERSISTENCE: UInt32 = 82
SQL_STATIC_SENSITIVITY: UInt32 = 83
SQL_FILE_USAGE: UInt32 = 84
SQL_COLUMN_ALIAS: UInt32 = 87
SQL_GROUP_BY: UInt32 = 88
SQL_KEYWORDS: UInt32 = 89
SQL_OWNER_USAGE: UInt32 = 91
SQL_QUALIFIER_USAGE: UInt32 = 92
SQL_QUOTED_IDENTIFIER_CASE: UInt32 = 93
SQL_SUBQUERIES: UInt32 = 95
SQL_UNION: UInt32 = 96
SQL_MAX_ROW_SIZE_INCLUDES_LONG: UInt32 = 103
SQL_MAX_CHAR_LITERAL_LEN: UInt32 = 108
SQL_TIMEDATE_ADD_INTERVALS: UInt32 = 109
SQL_TIMEDATE_DIFF_INTERVALS: UInt32 = 110
SQL_NEED_LONG_DATA_LEN: UInt32 = 111
SQL_MAX_BINARY_LITERAL_LEN: UInt32 = 112
SQL_LIKE_ESCAPE_CLAUSE: UInt32 = 113
SQL_QUALIFIER_LOCATION: UInt32 = 114
SQL_INFO_LAST: UInt32 = 114
SQL_INFO_DRIVER_START: UInt32 = 1000
SQL_ACTIVE_ENVIRONMENTS: UInt32 = 116
SQL_ALTER_DOMAIN: UInt32 = 117
SQL_SQL_CONFORMANCE: UInt32 = 118
SQL_DATETIME_LITERALS: UInt32 = 119
SQL_ASYNC_MODE: UInt32 = 10021
SQL_BATCH_ROW_COUNT: UInt32 = 120
SQL_BATCH_SUPPORT: UInt32 = 121
SQL_CATALOG_LOCATION: UInt32 = 114
SQL_CATALOG_NAME_SEPARATOR: UInt32 = 41
SQL_CATALOG_TERM: UInt32 = 42
SQL_CATALOG_USAGE: UInt32 = 92
SQL_CONVERT_WCHAR: UInt32 = 122
SQL_CONVERT_INTERVAL_DAY_TIME: UInt32 = 123
SQL_CONVERT_INTERVAL_YEAR_MONTH: UInt32 = 124
SQL_CONVERT_WLONGVARCHAR: UInt32 = 125
SQL_CONVERT_WVARCHAR: UInt32 = 126
SQL_CREATE_ASSERTION: UInt32 = 127
SQL_CREATE_CHARACTER_SET: UInt32 = 128
SQL_CREATE_COLLATION: UInt32 = 129
SQL_CREATE_DOMAIN: UInt32 = 130
SQL_CREATE_SCHEMA: UInt32 = 131
SQL_CREATE_TABLE: UInt32 = 132
SQL_CREATE_TRANSLATION: UInt32 = 133
SQL_CREATE_VIEW: UInt32 = 134
SQL_DRIVER_HDESC: UInt32 = 135
SQL_DROP_ASSERTION: UInt32 = 136
SQL_DROP_CHARACTER_SET: UInt32 = 137
SQL_DROP_COLLATION: UInt32 = 138
SQL_DROP_DOMAIN: UInt32 = 139
SQL_DROP_SCHEMA: UInt32 = 140
SQL_DROP_TABLE: UInt32 = 141
SQL_DROP_TRANSLATION: UInt32 = 142
SQL_DROP_VIEW: UInt32 = 143
SQL_DYNAMIC_CURSOR_ATTRIBUTES1: UInt32 = 144
SQL_DYNAMIC_CURSOR_ATTRIBUTES2: UInt32 = 145
SQL_FORWARD_ONLY_CURSOR_ATTRIBUTES1: UInt32 = 146
SQL_FORWARD_ONLY_CURSOR_ATTRIBUTES2: UInt32 = 147
SQL_INDEX_KEYWORDS: UInt32 = 148
SQL_INFO_SCHEMA_VIEWS: UInt32 = 149
SQL_KEYSET_CURSOR_ATTRIBUTES1: UInt32 = 150
SQL_KEYSET_CURSOR_ATTRIBUTES2: UInt32 = 151
SQL_MAX_ASYNC_CONCURRENT_STATEMENTS: UInt32 = 10022
SQL_ODBC_INTERFACE_CONFORMANCE: UInt32 = 152
SQL_PARAM_ARRAY_ROW_COUNTS: UInt32 = 153
SQL_PARAM_ARRAY_SELECTS: UInt32 = 154
SQL_SCHEMA_TERM: UInt32 = 39
SQL_SCHEMA_USAGE: UInt32 = 91
SQL_SQL92_DATETIME_FUNCTIONS: UInt32 = 155
SQL_SQL92_FOREIGN_KEY_DELETE_RULE: UInt32 = 156
SQL_SQL92_FOREIGN_KEY_UPDATE_RULE: UInt32 = 157
SQL_SQL92_GRANT: UInt32 = 158
SQL_SQL92_NUMERIC_VALUE_FUNCTIONS: UInt32 = 159
SQL_SQL92_PREDICATES: UInt32 = 160
SQL_SQL92_RELATIONAL_JOIN_OPERATORS: UInt32 = 161
SQL_SQL92_REVOKE: UInt32 = 162
SQL_SQL92_ROW_VALUE_CONSTRUCTOR: UInt32 = 163
SQL_SQL92_STRING_FUNCTIONS: UInt32 = 164
SQL_SQL92_VALUE_EXPRESSIONS: UInt32 = 165
SQL_STANDARD_CLI_CONFORMANCE: UInt32 = 166
SQL_STATIC_CURSOR_ATTRIBUTES1: UInt32 = 167
SQL_STATIC_CURSOR_ATTRIBUTES2: UInt32 = 168
SQL_AGGREGATE_FUNCTIONS: UInt32 = 169
SQL_DDL_INDEX: UInt32 = 170
SQL_DM_VER: UInt32 = 171
SQL_INSERT_STATEMENT: UInt32 = 172
SQL_CONVERT_GUID: UInt32 = 173
SQL_UNION_STATEMENT: UInt32 = 96
SQL_ASYNC_DBC_FUNCTIONS: UInt32 = 10023
SQL_DRIVER_AWARE_POOLING_SUPPORTED: UInt32 = 10024
SQL_ASYNC_NOTIFICATION: UInt32 = 10025
SQL_ASYNC_NOTIFICATION_NOT_CAPABLE: Int32 = 0
SQL_ASYNC_NOTIFICATION_CAPABLE: Int32 = 1
SQL_DTC_TRANSITION_COST: UInt32 = 1750
SQL_AT_ADD_COLUMN_SINGLE: Int32 = 32
SQL_AT_ADD_COLUMN_DEFAULT: Int32 = 64
SQL_AT_ADD_COLUMN_COLLATION: Int32 = 128
SQL_AT_SET_COLUMN_DEFAULT: Int32 = 256
SQL_AT_DROP_COLUMN_DEFAULT: Int32 = 512
SQL_AT_DROP_COLUMN_CASCADE: Int32 = 1024
SQL_AT_DROP_COLUMN_RESTRICT: Int32 = 2048
SQL_AT_ADD_TABLE_CONSTRAINT: Int32 = 4096
SQL_AT_DROP_TABLE_CONSTRAINT_CASCADE: Int32 = 8192
SQL_AT_DROP_TABLE_CONSTRAINT_RESTRICT: Int32 = 16384
SQL_AT_CONSTRAINT_NAME_DEFINITION: Int32 = 32768
SQL_AT_CONSTRAINT_INITIALLY_DEFERRED: Int32 = 65536
SQL_AT_CONSTRAINT_INITIALLY_IMMEDIATE: Int32 = 131072
SQL_AT_CONSTRAINT_DEFERRABLE: Int32 = 262144
SQL_AT_CONSTRAINT_NON_DEFERRABLE: Int32 = 524288
SQL_CVT_CHAR: Int32 = 1
SQL_CVT_NUMERIC: Int32 = 2
SQL_CVT_DECIMAL: Int32 = 4
SQL_CVT_INTEGER: Int32 = 8
SQL_CVT_SMALLINT: Int32 = 16
SQL_CVT_FLOAT: Int32 = 32
SQL_CVT_REAL: Int32 = 64
SQL_CVT_DOUBLE: Int32 = 128
SQL_CVT_VARCHAR: Int32 = 256
SQL_CVT_LONGVARCHAR: Int32 = 512
SQL_CVT_BINARY: Int32 = 1024
SQL_CVT_VARBINARY: Int32 = 2048
SQL_CVT_BIT: Int32 = 4096
SQL_CVT_TINYINT: Int32 = 8192
SQL_CVT_BIGINT: Int32 = 16384
SQL_CVT_DATE: Int32 = 32768
SQL_CVT_TIME: Int32 = 65536
SQL_CVT_TIMESTAMP: Int32 = 131072
SQL_CVT_LONGVARBINARY: Int32 = 262144
SQL_CVT_INTERVAL_YEAR_MONTH: Int32 = 524288
SQL_CVT_INTERVAL_DAY_TIME: Int32 = 1048576
SQL_CVT_WCHAR: Int32 = 2097152
SQL_CVT_WLONGVARCHAR: Int32 = 4194304
SQL_CVT_WVARCHAR: Int32 = 8388608
SQL_CVT_GUID: Int32 = 16777216
SQL_FN_CVT_CONVERT: Int32 = 1
SQL_FN_CVT_CAST: Int32 = 2
SQL_FN_STR_CONCAT: Int32 = 1
SQL_FN_STR_INSERT: Int32 = 2
SQL_FN_STR_LEFT: Int32 = 4
SQL_FN_STR_LTRIM: Int32 = 8
SQL_FN_STR_LENGTH: Int32 = 16
SQL_FN_STR_LOCATE: Int32 = 32
SQL_FN_STR_LCASE: Int32 = 64
SQL_FN_STR_REPEAT: Int32 = 128
SQL_FN_STR_REPLACE: Int32 = 256
SQL_FN_STR_RIGHT: Int32 = 512
SQL_FN_STR_RTRIM: Int32 = 1024
SQL_FN_STR_SUBSTRING: Int32 = 2048
SQL_FN_STR_UCASE: Int32 = 4096
SQL_FN_STR_ASCII: Int32 = 8192
SQL_FN_STR_CHAR: Int32 = 16384
SQL_FN_STR_DIFFERENCE: Int32 = 32768
SQL_FN_STR_LOCATE_2: Int32 = 65536
SQL_FN_STR_SOUNDEX: Int32 = 131072
SQL_FN_STR_SPACE: Int32 = 262144
SQL_FN_STR_BIT_LENGTH: Int32 = 524288
SQL_FN_STR_CHAR_LENGTH: Int32 = 1048576
SQL_FN_STR_CHARACTER_LENGTH: Int32 = 2097152
SQL_FN_STR_OCTET_LENGTH: Int32 = 4194304
SQL_FN_STR_POSITION: Int32 = 8388608
SQL_SSF_CONVERT: Int32 = 1
SQL_SSF_LOWER: Int32 = 2
SQL_SSF_UPPER: Int32 = 4
SQL_SSF_SUBSTRING: Int32 = 8
SQL_SSF_TRANSLATE: Int32 = 16
SQL_SSF_TRIM_BOTH: Int32 = 32
SQL_SSF_TRIM_LEADING: Int32 = 64
SQL_SSF_TRIM_TRAILING: Int32 = 128
SQL_FN_NUM_ABS: Int32 = 1
SQL_FN_NUM_ACOS: Int32 = 2
SQL_FN_NUM_ASIN: Int32 = 4
SQL_FN_NUM_ATAN: Int32 = 8
SQL_FN_NUM_ATAN2: Int32 = 16
SQL_FN_NUM_CEILING: Int32 = 32
SQL_FN_NUM_COS: Int32 = 64
SQL_FN_NUM_COT: Int32 = 128
SQL_FN_NUM_EXP: Int32 = 256
SQL_FN_NUM_FLOOR: Int32 = 512
SQL_FN_NUM_LOG: Int32 = 1024
SQL_FN_NUM_MOD: Int32 = 2048
SQL_FN_NUM_SIGN: Int32 = 4096
SQL_FN_NUM_SIN: Int32 = 8192
SQL_FN_NUM_SQRT: Int32 = 16384
SQL_FN_NUM_TAN: Int32 = 32768
SQL_FN_NUM_PI: Int32 = 65536
SQL_FN_NUM_RAND: Int32 = 131072
SQL_FN_NUM_DEGREES: Int32 = 262144
SQL_FN_NUM_LOG10: Int32 = 524288
SQL_FN_NUM_POWER: Int32 = 1048576
SQL_FN_NUM_RADIANS: Int32 = 2097152
SQL_FN_NUM_ROUND: Int32 = 4194304
SQL_FN_NUM_TRUNCATE: Int32 = 8388608
SQL_SNVF_BIT_LENGTH: Int32 = 1
SQL_SNVF_CHAR_LENGTH: Int32 = 2
SQL_SNVF_CHARACTER_LENGTH: Int32 = 4
SQL_SNVF_EXTRACT: Int32 = 8
SQL_SNVF_OCTET_LENGTH: Int32 = 16
SQL_SNVF_POSITION: Int32 = 32
SQL_FN_TD_NOW: Int32 = 1
SQL_FN_TD_CURDATE: Int32 = 2
SQL_FN_TD_DAYOFMONTH: Int32 = 4
SQL_FN_TD_DAYOFWEEK: Int32 = 8
SQL_FN_TD_DAYOFYEAR: Int32 = 16
SQL_FN_TD_MONTH: Int32 = 32
SQL_FN_TD_QUARTER: Int32 = 64
SQL_FN_TD_WEEK: Int32 = 128
SQL_FN_TD_YEAR: Int32 = 256
SQL_FN_TD_CURTIME: Int32 = 512
SQL_FN_TD_HOUR: Int32 = 1024
SQL_FN_TD_MINUTE: Int32 = 2048
SQL_FN_TD_SECOND: Int32 = 4096
SQL_FN_TD_TIMESTAMPADD: Int32 = 8192
SQL_FN_TD_TIMESTAMPDIFF: Int32 = 16384
SQL_FN_TD_DAYNAME: Int32 = 32768
SQL_FN_TD_MONTHNAME: Int32 = 65536
SQL_FN_TD_CURRENT_DATE: Int32 = 131072
SQL_FN_TD_CURRENT_TIME: Int32 = 262144
SQL_FN_TD_CURRENT_TIMESTAMP: Int32 = 524288
SQL_FN_TD_EXTRACT: Int32 = 1048576
SQL_SDF_CURRENT_DATE: Int32 = 1
SQL_SDF_CURRENT_TIME: Int32 = 2
SQL_SDF_CURRENT_TIMESTAMP: Int32 = 4
SQL_FN_SYS_USERNAME: Int32 = 1
SQL_FN_SYS_DBNAME: Int32 = 2
SQL_FN_SYS_IFNULL: Int32 = 4
SQL_FN_TSI_FRAC_SECOND: Int32 = 1
SQL_FN_TSI_SECOND: Int32 = 2
SQL_FN_TSI_MINUTE: Int32 = 4
SQL_FN_TSI_HOUR: Int32 = 8
SQL_FN_TSI_DAY: Int32 = 16
SQL_FN_TSI_WEEK: Int32 = 32
SQL_FN_TSI_MONTH: Int32 = 64
SQL_FN_TSI_QUARTER: Int32 = 128
SQL_FN_TSI_YEAR: Int32 = 256
SQL_CA1_NEXT: Int32 = 1
SQL_CA1_ABSOLUTE: Int32 = 2
SQL_CA1_RELATIVE: Int32 = 4
SQL_CA1_BOOKMARK: Int32 = 8
SQL_CA1_LOCK_NO_CHANGE: Int32 = 64
SQL_CA1_LOCK_EXCLUSIVE: Int32 = 128
SQL_CA1_LOCK_UNLOCK: Int32 = 256
SQL_CA1_POS_POSITION: Int32 = 512
SQL_CA1_POS_UPDATE: Int32 = 1024
SQL_CA1_POS_DELETE: Int32 = 2048
SQL_CA1_POS_REFRESH: Int32 = 4096
SQL_CA1_POSITIONED_UPDATE: Int32 = 8192
SQL_CA1_POSITIONED_DELETE: Int32 = 16384
SQL_CA1_SELECT_FOR_UPDATE: Int32 = 32768
SQL_CA1_BULK_ADD: Int32 = 65536
SQL_CA1_BULK_UPDATE_BY_BOOKMARK: Int32 = 131072
SQL_CA1_BULK_DELETE_BY_BOOKMARK: Int32 = 262144
SQL_CA1_BULK_FETCH_BY_BOOKMARK: Int32 = 524288
SQL_CA2_READ_ONLY_CONCURRENCY: Int32 = 1
SQL_CA2_LOCK_CONCURRENCY: Int32 = 2
SQL_CA2_OPT_ROWVER_CONCURRENCY: Int32 = 4
SQL_CA2_OPT_VALUES_CONCURRENCY: Int32 = 8
SQL_CA2_SENSITIVITY_ADDITIONS: Int32 = 16
SQL_CA2_SENSITIVITY_DELETIONS: Int32 = 32
SQL_CA2_SENSITIVITY_UPDATES: Int32 = 64
SQL_CA2_MAX_ROWS_SELECT: Int32 = 128
SQL_CA2_MAX_ROWS_INSERT: Int32 = 256
SQL_CA2_MAX_ROWS_DELETE: Int32 = 512
SQL_CA2_MAX_ROWS_UPDATE: Int32 = 1024
SQL_CA2_MAX_ROWS_CATALOG: Int32 = 2048
SQL_CA2_CRC_EXACT: Int32 = 4096
SQL_CA2_CRC_APPROXIMATE: Int32 = 8192
SQL_CA2_SIMULATE_NON_UNIQUE: Int32 = 16384
SQL_CA2_SIMULATE_TRY_UNIQUE: Int32 = 32768
SQL_CA2_SIMULATE_UNIQUE: Int32 = 65536
SQL_OAC_NONE: UInt32 = 0
SQL_OAC_LEVEL1: UInt32 = 1
SQL_OAC_LEVEL2: UInt32 = 2
SQL_OSCC_NOT_COMPLIANT: UInt32 = 0
SQL_OSCC_COMPLIANT: UInt32 = 1
SQL_OSC_MINIMUM: UInt32 = 0
SQL_OSC_CORE: UInt32 = 1
SQL_OSC_EXTENDED: UInt32 = 2
SQL_CB_NULL: UInt32 = 0
SQL_CB_NON_NULL: UInt32 = 1
SQL_SO_FORWARD_ONLY: Int32 = 1
SQL_SO_KEYSET_DRIVEN: Int32 = 2
SQL_SO_DYNAMIC: Int32 = 4
SQL_SO_MIXED: Int32 = 8
SQL_SO_STATIC: Int32 = 16
SQL_FD_FETCH_RESUME: Int32 = 64
SQL_FD_FETCH_BOOKMARK: Int32 = 128
SQL_TXN_VERSIONING: Int32 = 16
SQL_CN_NONE: UInt32 = 0
SQL_CN_DIFFERENT: UInt32 = 1
SQL_CN_ANY: UInt32 = 2
SQL_NNC_NULL: UInt32 = 0
SQL_NNC_NON_NULL: UInt32 = 1
SQL_NC_START: UInt32 = 2
SQL_NC_END: UInt32 = 4
SQL_FILE_NOT_SUPPORTED: UInt32 = 0
SQL_FILE_TABLE: UInt32 = 1
SQL_FILE_QUALIFIER: UInt32 = 2
SQL_FILE_CATALOG: UInt32 = 2
SQL_GD_BLOCK: Int32 = 4
SQL_GD_BOUND: Int32 = 8
SQL_GD_OUTPUT_PARAMS: Int32 = 16
SQL_PS_POSITIONED_DELETE: Int32 = 1
SQL_PS_POSITIONED_UPDATE: Int32 = 2
SQL_PS_SELECT_FOR_UPDATE: Int32 = 4
SQL_GB_NOT_SUPPORTED: UInt32 = 0
SQL_GB_GROUP_BY_EQUALS_SELECT: UInt32 = 1
SQL_GB_GROUP_BY_CONTAINS_SELECT: UInt32 = 2
SQL_GB_NO_RELATION: UInt32 = 3
SQL_GB_COLLATE: UInt32 = 4
SQL_OU_DML_STATEMENTS: Int32 = 1
SQL_OU_PROCEDURE_INVOCATION: Int32 = 2
SQL_OU_TABLE_DEFINITION: Int32 = 4
SQL_OU_INDEX_DEFINITION: Int32 = 8
SQL_OU_PRIVILEGE_DEFINITION: Int32 = 16
SQL_SU_DML_STATEMENTS: Int32 = 1
SQL_SU_PROCEDURE_INVOCATION: Int32 = 2
SQL_SU_TABLE_DEFINITION: Int32 = 4
SQL_SU_INDEX_DEFINITION: Int32 = 8
SQL_SU_PRIVILEGE_DEFINITION: Int32 = 16
SQL_QU_DML_STATEMENTS: Int32 = 1
SQL_QU_PROCEDURE_INVOCATION: Int32 = 2
SQL_QU_TABLE_DEFINITION: Int32 = 4
SQL_QU_INDEX_DEFINITION: Int32 = 8
SQL_QU_PRIVILEGE_DEFINITION: Int32 = 16
SQL_CU_DML_STATEMENTS: Int32 = 1
SQL_CU_PROCEDURE_INVOCATION: Int32 = 2
SQL_CU_TABLE_DEFINITION: Int32 = 4
SQL_CU_INDEX_DEFINITION: Int32 = 8
SQL_CU_PRIVILEGE_DEFINITION: Int32 = 16
SQL_SQ_COMPARISON: Int32 = 1
SQL_SQ_EXISTS: Int32 = 2
SQL_SQ_IN: Int32 = 4
SQL_SQ_QUANTIFIED: Int32 = 8
SQL_SQ_CORRELATED_SUBQUERIES: Int32 = 16
SQL_U_UNION: Int32 = 1
SQL_U_UNION_ALL: Int32 = 2
SQL_BP_CLOSE: Int32 = 1
SQL_BP_DELETE: Int32 = 2
SQL_BP_DROP: Int32 = 4
SQL_BP_TRANSACTION: Int32 = 8
SQL_BP_UPDATE: Int32 = 16
SQL_BP_OTHER_HSTMT: Int32 = 32
SQL_BP_SCROLL: Int32 = 64
SQL_SS_ADDITIONS: Int32 = 1
SQL_SS_DELETIONS: Int32 = 2
SQL_SS_UPDATES: Int32 = 4
SQL_CV_CREATE_VIEW: Int32 = 1
SQL_CV_CHECK_OPTION: Int32 = 2
SQL_CV_CASCADED: Int32 = 4
SQL_CV_LOCAL: Int32 = 8
SQL_LCK_NO_CHANGE: Int32 = 1
SQL_LCK_EXCLUSIVE: Int32 = 2
SQL_LCK_UNLOCK: Int32 = 4
SQL_POS_POSITION: Int32 = 1
SQL_POS_REFRESH: Int32 = 2
SQL_POS_UPDATE: Int32 = 4
SQL_POS_DELETE: Int32 = 8
SQL_POS_ADD: Int32 = 16
SQL_QL_START: UInt32 = 1
SQL_QL_END: UInt32 = 2
SQL_AF_AVG: Int32 = 1
SQL_AF_COUNT: Int32 = 2
SQL_AF_MAX: Int32 = 4
SQL_AF_MIN: Int32 = 8
SQL_AF_SUM: Int32 = 16
SQL_AF_DISTINCT: Int32 = 32
SQL_AF_ALL: Int32 = 64
SQL_SC_SQL92_ENTRY: Int32 = 1
SQL_SC_FIPS127_2_TRANSITIONAL: Int32 = 2
SQL_SC_SQL92_INTERMEDIATE: Int32 = 4
SQL_SC_SQL92_FULL: Int32 = 8
SQL_DL_SQL92_DATE: Int32 = 1
SQL_DL_SQL92_TIME: Int32 = 2
SQL_DL_SQL92_TIMESTAMP: Int32 = 4
SQL_DL_SQL92_INTERVAL_YEAR: Int32 = 8
SQL_DL_SQL92_INTERVAL_MONTH: Int32 = 16
SQL_DL_SQL92_INTERVAL_DAY: Int32 = 32
SQL_DL_SQL92_INTERVAL_HOUR: Int32 = 64
SQL_DL_SQL92_INTERVAL_MINUTE: Int32 = 128
SQL_DL_SQL92_INTERVAL_SECOND: Int32 = 256
SQL_DL_SQL92_INTERVAL_YEAR_TO_MONTH: Int32 = 512
SQL_DL_SQL92_INTERVAL_DAY_TO_HOUR: Int32 = 1024
SQL_DL_SQL92_INTERVAL_DAY_TO_MINUTE: Int32 = 2048
SQL_DL_SQL92_INTERVAL_DAY_TO_SECOND: Int32 = 4096
SQL_DL_SQL92_INTERVAL_HOUR_TO_MINUTE: Int32 = 8192
SQL_DL_SQL92_INTERVAL_HOUR_TO_SECOND: Int32 = 16384
SQL_DL_SQL92_INTERVAL_MINUTE_TO_SECOND: Int32 = 32768
SQL_CL_START: UInt32 = 1
SQL_CL_END: UInt32 = 2
SQL_BRC_PROCEDURES: UInt32 = 1
SQL_BRC_EXPLICIT: UInt32 = 2
SQL_BRC_ROLLED_UP: UInt32 = 4
SQL_BS_SELECT_EXPLICIT: Int32 = 1
SQL_BS_ROW_COUNT_EXPLICIT: Int32 = 2
SQL_BS_SELECT_PROC: Int32 = 4
SQL_BS_ROW_COUNT_PROC: Int32 = 8
SQL_PARC_BATCH: UInt32 = 1
SQL_PARC_NO_BATCH: UInt32 = 2
SQL_PAS_BATCH: UInt32 = 1
SQL_PAS_NO_BATCH: UInt32 = 2
SQL_PAS_NO_SELECT: UInt32 = 3
SQL_IK_NONE: Int32 = 0
SQL_IK_ASC: Int32 = 1
SQL_IK_DESC: Int32 = 2
SQL_ISV_ASSERTIONS: Int32 = 1
SQL_ISV_CHARACTER_SETS: Int32 = 2
SQL_ISV_CHECK_CONSTRAINTS: Int32 = 4
SQL_ISV_COLLATIONS: Int32 = 8
SQL_ISV_COLUMN_DOMAIN_USAGE: Int32 = 16
SQL_ISV_COLUMN_PRIVILEGES: Int32 = 32
SQL_ISV_COLUMNS: Int32 = 64
SQL_ISV_CONSTRAINT_COLUMN_USAGE: Int32 = 128
SQL_ISV_CONSTRAINT_TABLE_USAGE: Int32 = 256
SQL_ISV_DOMAIN_CONSTRAINTS: Int32 = 512
SQL_ISV_DOMAINS: Int32 = 1024
SQL_ISV_KEY_COLUMN_USAGE: Int32 = 2048
SQL_ISV_REFERENTIAL_CONSTRAINTS: Int32 = 4096
SQL_ISV_SCHEMATA: Int32 = 8192
SQL_ISV_SQL_LANGUAGES: Int32 = 16384
SQL_ISV_TABLE_CONSTRAINTS: Int32 = 32768
SQL_ISV_TABLE_PRIVILEGES: Int32 = 65536
SQL_ISV_TABLES: Int32 = 131072
SQL_ISV_TRANSLATIONS: Int32 = 262144
SQL_ISV_USAGE_PRIVILEGES: Int32 = 524288
SQL_ISV_VIEW_COLUMN_USAGE: Int32 = 1048576
SQL_ISV_VIEW_TABLE_USAGE: Int32 = 2097152
SQL_ISV_VIEWS: Int32 = 4194304
SQL_AD_CONSTRAINT_NAME_DEFINITION: Int32 = 1
SQL_AD_ADD_DOMAIN_CONSTRAINT: Int32 = 2
SQL_AD_DROP_DOMAIN_CONSTRAINT: Int32 = 4
SQL_AD_ADD_DOMAIN_DEFAULT: Int32 = 8
SQL_AD_DROP_DOMAIN_DEFAULT: Int32 = 16
SQL_AD_ADD_CONSTRAINT_INITIALLY_DEFERRED: Int32 = 32
SQL_AD_ADD_CONSTRAINT_INITIALLY_IMMEDIATE: Int32 = 64
SQL_AD_ADD_CONSTRAINT_DEFERRABLE: Int32 = 128
SQL_AD_ADD_CONSTRAINT_NON_DEFERRABLE: Int32 = 256
SQL_CS_CREATE_SCHEMA: Int32 = 1
SQL_CS_AUTHORIZATION: Int32 = 2
SQL_CS_DEFAULT_CHARACTER_SET: Int32 = 4
SQL_CTR_CREATE_TRANSLATION: Int32 = 1
SQL_CA_CREATE_ASSERTION: Int32 = 1
SQL_CA_CONSTRAINT_INITIALLY_DEFERRED: Int32 = 16
SQL_CA_CONSTRAINT_INITIALLY_IMMEDIATE: Int32 = 32
SQL_CA_CONSTRAINT_DEFERRABLE: Int32 = 64
SQL_CA_CONSTRAINT_NON_DEFERRABLE: Int32 = 128
SQL_CCS_CREATE_CHARACTER_SET: Int32 = 1
SQL_CCS_COLLATE_CLAUSE: Int32 = 2
SQL_CCS_LIMITED_COLLATION: Int32 = 4
SQL_CCOL_CREATE_COLLATION: Int32 = 1
SQL_CDO_CREATE_DOMAIN: Int32 = 1
SQL_CDO_DEFAULT: Int32 = 2
SQL_CDO_CONSTRAINT: Int32 = 4
SQL_CDO_COLLATION: Int32 = 8
SQL_CDO_CONSTRAINT_NAME_DEFINITION: Int32 = 16
SQL_CDO_CONSTRAINT_INITIALLY_DEFERRED: Int32 = 32
SQL_CDO_CONSTRAINT_INITIALLY_IMMEDIATE: Int32 = 64
SQL_CDO_CONSTRAINT_DEFERRABLE: Int32 = 128
SQL_CDO_CONSTRAINT_NON_DEFERRABLE: Int32 = 256
SQL_CT_CREATE_TABLE: Int32 = 1
SQL_CT_COMMIT_PRESERVE: Int32 = 2
SQL_CT_COMMIT_DELETE: Int32 = 4
SQL_CT_GLOBAL_TEMPORARY: Int32 = 8
SQL_CT_LOCAL_TEMPORARY: Int32 = 16
SQL_CT_CONSTRAINT_INITIALLY_DEFERRED: Int32 = 32
SQL_CT_CONSTRAINT_INITIALLY_IMMEDIATE: Int32 = 64
SQL_CT_CONSTRAINT_DEFERRABLE: Int32 = 128
SQL_CT_CONSTRAINT_NON_DEFERRABLE: Int32 = 256
SQL_CT_COLUMN_CONSTRAINT: Int32 = 512
SQL_CT_COLUMN_DEFAULT: Int32 = 1024
SQL_CT_COLUMN_COLLATION: Int32 = 2048
SQL_CT_TABLE_CONSTRAINT: Int32 = 4096
SQL_CT_CONSTRAINT_NAME_DEFINITION: Int32 = 8192
SQL_DI_CREATE_INDEX: Int32 = 1
SQL_DI_DROP_INDEX: Int32 = 2
SQL_DC_DROP_COLLATION: Int32 = 1
SQL_DD_DROP_DOMAIN: Int32 = 1
SQL_DD_RESTRICT: Int32 = 2
SQL_DD_CASCADE: Int32 = 4
SQL_DS_DROP_SCHEMA: Int32 = 1
SQL_DS_RESTRICT: Int32 = 2
SQL_DS_CASCADE: Int32 = 4
SQL_DCS_DROP_CHARACTER_SET: Int32 = 1
SQL_DA_DROP_ASSERTION: Int32 = 1
SQL_DT_DROP_TABLE: Int32 = 1
SQL_DT_RESTRICT: Int32 = 2
SQL_DT_CASCADE: Int32 = 4
SQL_DTR_DROP_TRANSLATION: Int32 = 1
SQL_DV_DROP_VIEW: Int32 = 1
SQL_DV_RESTRICT: Int32 = 2
SQL_DV_CASCADE: Int32 = 4
SQL_IS_INSERT_LITERALS: Int32 = 1
SQL_IS_INSERT_SEARCHED: Int32 = 2
SQL_IS_SELECT_INTO: Int32 = 4
SQL_OIC_CORE: UInt32 = 1
SQL_OIC_LEVEL1: UInt32 = 2
SQL_OIC_LEVEL2: UInt32 = 3
SQL_SFKD_CASCADE: Int32 = 1
SQL_SFKD_NO_ACTION: Int32 = 2
SQL_SFKD_SET_DEFAULT: Int32 = 4
SQL_SFKD_SET_NULL: Int32 = 8
SQL_SFKU_CASCADE: Int32 = 1
SQL_SFKU_NO_ACTION: Int32 = 2
SQL_SFKU_SET_DEFAULT: Int32 = 4
SQL_SFKU_SET_NULL: Int32 = 8
SQL_SG_USAGE_ON_DOMAIN: Int32 = 1
SQL_SG_USAGE_ON_CHARACTER_SET: Int32 = 2
SQL_SG_USAGE_ON_COLLATION: Int32 = 4
SQL_SG_USAGE_ON_TRANSLATION: Int32 = 8
SQL_SG_WITH_GRANT_OPTION: Int32 = 16
SQL_SG_DELETE_TABLE: Int32 = 32
SQL_SG_INSERT_TABLE: Int32 = 64
SQL_SG_INSERT_COLUMN: Int32 = 128
SQL_SG_REFERENCES_TABLE: Int32 = 256
SQL_SG_REFERENCES_COLUMN: Int32 = 512
SQL_SG_SELECT_TABLE: Int32 = 1024
SQL_SG_UPDATE_TABLE: Int32 = 2048
SQL_SG_UPDATE_COLUMN: Int32 = 4096
SQL_SP_EXISTS: Int32 = 1
SQL_SP_ISNOTNULL: Int32 = 2
SQL_SP_ISNULL: Int32 = 4
SQL_SP_MATCH_FULL: Int32 = 8
SQL_SP_MATCH_PARTIAL: Int32 = 16
SQL_SP_MATCH_UNIQUE_FULL: Int32 = 32
SQL_SP_MATCH_UNIQUE_PARTIAL: Int32 = 64
SQL_SP_OVERLAPS: Int32 = 128
SQL_SP_UNIQUE: Int32 = 256
SQL_SP_LIKE: Int32 = 512
SQL_SP_IN: Int32 = 1024
SQL_SP_BETWEEN: Int32 = 2048
SQL_SP_COMPARISON: Int32 = 4096
SQL_SP_QUANTIFIED_COMPARISON: Int32 = 8192
SQL_SRJO_CORRESPONDING_CLAUSE: Int32 = 1
SQL_SRJO_CROSS_JOIN: Int32 = 2
SQL_SRJO_EXCEPT_JOIN: Int32 = 4
SQL_SRJO_FULL_OUTER_JOIN: Int32 = 8
SQL_SRJO_INNER_JOIN: Int32 = 16
SQL_SRJO_INTERSECT_JOIN: Int32 = 32
SQL_SRJO_LEFT_OUTER_JOIN: Int32 = 64
SQL_SRJO_NATURAL_JOIN: Int32 = 128
SQL_SRJO_RIGHT_OUTER_JOIN: Int32 = 256
SQL_SRJO_UNION_JOIN: Int32 = 512
SQL_SR_USAGE_ON_DOMAIN: Int32 = 1
SQL_SR_USAGE_ON_CHARACTER_SET: Int32 = 2
SQL_SR_USAGE_ON_COLLATION: Int32 = 4
SQL_SR_USAGE_ON_TRANSLATION: Int32 = 8
SQL_SR_GRANT_OPTION_FOR: Int32 = 16
SQL_SR_CASCADE: Int32 = 32
SQL_SR_RESTRICT: Int32 = 64
SQL_SR_DELETE_TABLE: Int32 = 128
SQL_SR_INSERT_TABLE: Int32 = 256
SQL_SR_INSERT_COLUMN: Int32 = 512
SQL_SR_REFERENCES_TABLE: Int32 = 1024
SQL_SR_REFERENCES_COLUMN: Int32 = 2048
SQL_SR_SELECT_TABLE: Int32 = 4096
SQL_SR_UPDATE_TABLE: Int32 = 8192
SQL_SR_UPDATE_COLUMN: Int32 = 16384
SQL_SRVC_VALUE_EXPRESSION: Int32 = 1
SQL_SRVC_NULL: Int32 = 2
SQL_SRVC_DEFAULT: Int32 = 4
SQL_SRVC_ROW_SUBQUERY: Int32 = 8
SQL_SVE_CASE: Int32 = 1
SQL_SVE_CAST: Int32 = 2
SQL_SVE_COALESCE: Int32 = 4
SQL_SVE_NULLIF: Int32 = 8
SQL_SCC_XOPEN_CLI_VERSION1: Int32 = 1
SQL_SCC_ISO92_CLI: Int32 = 2
SQL_US_UNION: Int32 = 1
SQL_US_UNION_ALL: Int32 = 2
SQL_DRIVER_AWARE_POOLING_NOT_CAPABLE: Int32 = 0
SQL_DRIVER_AWARE_POOLING_CAPABLE: Int32 = 1
SQL_DTC_ENLIST_EXPENSIVE: Int32 = 1
SQL_DTC_UNENLIST_EXPENSIVE: Int32 = 2
SQL_ASYNC_DBC_NOT_CAPABLE: Int32 = 0
SQL_ASYNC_DBC_CAPABLE: Int32 = 1
SQL_FETCH_FIRST_USER: UInt32 = 31
SQL_FETCH_FIRST_SYSTEM: UInt32 = 32
SQL_ENTIRE_ROWSET: UInt32 = 0
SQL_POSITION: UInt32 = 0
SQL_REFRESH: UInt32 = 1
SQL_UPDATE: UInt32 = 2
SQL_DELETE: UInt32 = 3
SQL_ADD: UInt32 = 4
SQL_SETPOS_MAX_OPTION_VALUE: UInt32 = 4
SQL_UPDATE_BY_BOOKMARK: UInt32 = 5
SQL_DELETE_BY_BOOKMARK: UInt32 = 6
SQL_FETCH_BY_BOOKMARK: UInt32 = 7
SQL_LOCK_NO_CHANGE: UInt32 = 0
SQL_LOCK_EXCLUSIVE: UInt32 = 1
SQL_LOCK_UNLOCK: UInt32 = 2
SQL_SETPOS_MAX_LOCK_VALUE: UInt32 = 2
SQL_BEST_ROWID: UInt32 = 1
SQL_ROWVER: UInt32 = 2
SQL_PC_NOT_PSEUDO: UInt32 = 1
SQL_QUICK: UInt32 = 0
SQL_ENSURE: UInt32 = 1
SQL_TABLE_STAT: UInt32 = 0
SQL_ALL_CATALOGS: String = '%'
SQL_ALL_SCHEMAS: String = '%'
SQL_ALL_TABLE_TYPES: String = '%'
SQL_DRIVER_NOPROMPT: UInt32 = 0
SQL_DRIVER_COMPLETE: UInt32 = 1
SQL_DRIVER_PROMPT: UInt32 = 2
SQL_DRIVER_COMPLETE_REQUIRED: UInt32 = 3
SQL_FETCH_BOOKMARK: UInt32 = 8
SQL_ROW_SUCCESS: UInt32 = 0
SQL_ROW_DELETED: UInt32 = 1
SQL_ROW_UPDATED: UInt32 = 2
SQL_ROW_NOROW: UInt32 = 3
SQL_ROW_ADDED: UInt32 = 4
SQL_ROW_ERROR: UInt32 = 5
SQL_ROW_SUCCESS_WITH_INFO: UInt32 = 6
SQL_ROW_PROCEED: UInt32 = 0
SQL_ROW_IGNORE: UInt32 = 1
SQL_PARAM_SUCCESS: UInt32 = 0
SQL_PARAM_SUCCESS_WITH_INFO: UInt32 = 6
SQL_PARAM_ERROR: UInt32 = 5
SQL_PARAM_UNUSED: UInt32 = 7
SQL_PARAM_DIAG_UNAVAILABLE: UInt32 = 1
SQL_PARAM_PROCEED: UInt32 = 0
SQL_PARAM_IGNORE: UInt32 = 1
SQL_CASCADE: UInt32 = 0
SQL_RESTRICT: UInt32 = 1
SQL_SET_NULL: UInt32 = 2
SQL_NO_ACTION: UInt32 = 3
SQL_SET_DEFAULT: UInt32 = 4
SQL_INITIALLY_DEFERRED: UInt32 = 5
SQL_INITIALLY_IMMEDIATE: UInt32 = 6
SQL_NOT_DEFERRABLE: UInt32 = 7
SQL_PARAM_TYPE_UNKNOWN: UInt32 = 0
SQL_PARAM_INPUT: UInt32 = 1
SQL_PARAM_INPUT_OUTPUT: UInt32 = 2
SQL_RESULT_COL: UInt32 = 3
SQL_PARAM_OUTPUT: UInt32 = 4
SQL_RETURN_VALUE: UInt32 = 5
SQL_PARAM_INPUT_OUTPUT_STREAM: UInt32 = 8
SQL_PARAM_OUTPUT_STREAM: UInt32 = 16
SQL_PT_UNKNOWN: UInt32 = 0
SQL_PT_PROCEDURE: UInt32 = 1
SQL_PT_FUNCTION: UInt32 = 2
SQL_ODBC_KEYWORDS: String = 'ABSOLUTE,ACTION,ADA,ADD,ALL,ALLOCATE,ALTER,AND,ANY,ARE,AS,ASC,ASSERTION,AT,AUTHORIZATION,AVG,BEGIN,BETWEEN,BIT,BIT_LENGTH,BOTH,BY,CASCADE,CASCADED,CASE,CAST,CATALOG,CHAR,CHAR_LENGTH,CHARACTER,CHARACTER_LENGTH,CHECK,CLOSE,COALESCE,COLLATE,COLLATION,COLUMN,COMMIT,CONNECT,CONNECTION,CONSTRAINT,CONSTRAINTS,CONTINUE,CONVERT,CORRESPONDING,COUNT,CREATE,CROSS,CURRENT,CURRENT_DATE,CURRENT_TIME,CURRENT_TIMESTAMP,CURRENT_USER,CURSOR,DATE,DAY,DEALLOCATE,DEC,DECIMAL,DECLARE,DEFAULT,DEFERRABLE,DEFERRED,DELETE,DESC,DESCRIBE,DESCRIPTOR,DIAGNOSTICS,DISCONNECT,DISTINCT,DOMAIN,DOUBLE,DROP,ELSE,END,END-EXEC,ESCAPE,EXCEPT,EXCEPTION,EXEC,EXECUTE,EXISTS,EXTERNAL,EXTRACT,FALSE,FETCH,FIRST,FLOAT,FOR,FOREIGN,FORTRAN,FOUND,FROM,FULL,GET,GLOBAL,GO,GOTO,GRANT,GROUP,HAVING,HOUR,IDENTITY,IMMEDIATE,IN,INCLUDE,INDEX,INDICATOR,INITIALLY,INNER,INPUT,INSENSITIVE,INSERT,INT,INTEGER,INTERSECT,INTERVAL,INTO,IS,ISOLATION,JOIN,KEY,LANGUAGE,LAST,LEADING,LEFT,LEVEL,LIKE,LOCAL,LOWER,MATCH,MAX,MIN,MINUTE,MODULE,MONTH,NAMES,NATIONAL,NATURAL,NCHAR,NEXT,NO,NONE,NOT,NULL,NULLIF,NUMERIC,OCTET_LENGTH,OF,ON,ONLY,OPEN,OPTION,OR,ORDER,OUTER,OUTPUT,OVERLAPS,PAD,PARTIAL,PASCAL,PLI,POSITION,PRECISION,PREPARE,PRESERVE,PRIMARY,PRIOR,PRIVILEGES,PROCEDURE,PUBLIC,READ,REAL,REFERENCES,RELATIVE,RESTRICT,REVOKE,RIGHT,ROLLBACK,ROWSSCHEMA,SCROLL,SECOND,SECTION,SELECT,SESSION,SESSION_USER,SET,SIZE,SMALLINT,SOME,SPACE,SQL,SQLCA,SQLCODE,SQLERROR,SQLSTATE,SQLWARNING,SUBSTRING,SUM,SYSTEM_USER,TABLE,TEMPORARY,THEN,TIME,TIMESTAMP,TIMEZONE_HOUR,TIMEZONE_MINUTE,TO,TRAILING,TRANSACTION,TRANSLATE,TRANSLATION,TRIM,TRUE,UNION,UNIQUE,UNKNOWN,UPDATE,UPPER,USAGE,USER,USING,VALUE,VALUES,VARCHAR,VARYING,VIEW,WHEN,WHENEVER,WHERE,WITH,WORK,WRITE,YEAR,ZONE'
SQL_YEAR: UInt32 = 1
SQL_MONTH: UInt32 = 2
SQL_DAY: UInt32 = 3
SQL_HOUR: UInt32 = 4
SQL_MINUTE: UInt32 = 5
SQL_SECOND: UInt32 = 6
SQL_YEAR_TO_MONTH: UInt32 = 7
SQL_DAY_TO_HOUR: UInt32 = 8
SQL_DAY_TO_MINUTE: UInt32 = 9
SQL_DAY_TO_SECOND: UInt32 = 10
SQL_HOUR_TO_MINUTE: UInt32 = 11
SQL_HOUR_TO_SECOND: UInt32 = 12
SQL_MINUTE_TO_SECOND: UInt32 = 13
SQL_DATABASE_NAME: UInt32 = 16
SQL_FD_FETCH_PREV: Int32 = 8
SQL_FETCH_PREV: UInt32 = 4
SQL_CONCUR_TIMESTAMP: UInt32 = 3
SQL_SCCO_OPT_TIMESTAMP: Int32 = 4
SQL_CC_DELETE: UInt32 = 0
SQL_CR_DELETE: UInt32 = 0
SQL_CC_CLOSE: UInt32 = 1
SQL_CR_CLOSE: UInt32 = 1
SQL_CC_PRESERVE: UInt32 = 2
SQL_CR_PRESERVE: UInt32 = 2
SQL_FETCH_RESUME: UInt32 = 7
SQL_SCROLL_FORWARD_ONLY: Int32 = 0
SQL_SCROLL_KEYSET_DRIVEN: Int32 = -1
SQL_SCROLL_DYNAMIC: Int32 = -2
SQL_SCROLL_STATIC: Int32 = -3
TRACE_VERSION: UInt32 = 1000
TRACE_ON: Int32 = 1
TRACE_VS_EVENT_ON: Int32 = 2
ODBC_VS_FLAG_UNICODE_ARG: Int32 = 1
ODBC_VS_FLAG_UNICODE_COR: Int32 = 2
ODBC_VS_FLAG_RETCODE: Int32 = 4
ODBC_VS_FLAG_STOP: Int32 = 8
CRESTRICTIONS_DBSCHEMA_LINKEDSERVERS: UInt32 = 1
SSPROP_ENABLEFASTLOAD: UInt32 = 2
SSPROP_UNICODELCID: UInt32 = 2
SSPROP_UNICODECOMPARISONSTYLE: UInt32 = 3
SSPROP_COLUMNLEVELCOLLATION: UInt32 = 4
SSPROP_CHARACTERSET: UInt32 = 5
SSPROP_SORTORDER: UInt32 = 6
SSPROP_CURRENTCOLLATION: UInt32 = 7
SSPROP_INIT_CURRENTLANGUAGE: UInt32 = 4
SSPROP_INIT_NETWORKADDRESS: UInt32 = 5
SSPROP_INIT_NETWORKLIBRARY: UInt32 = 6
SSPROP_INIT_USEPROCFORPREP: UInt32 = 7
SSPROP_INIT_AUTOTRANSLATE: UInt32 = 8
SSPROP_INIT_PACKETSIZE: UInt32 = 9
SSPROP_INIT_APPNAME: UInt32 = 10
SSPROP_INIT_WSID: UInt32 = 11
SSPROP_INIT_FILENAME: UInt32 = 12
SSPROP_INIT_ENCRYPT: UInt32 = 13
SSPROP_AUTH_REPL_SERVER_NAME: UInt32 = 14
SSPROP_INIT_TAGCOLUMNCOLLATION: UInt32 = 15
SSPROPVAL_USEPROCFORPREP_OFF: UInt32 = 0
SSPROPVAL_USEPROCFORPREP_ON: UInt32 = 1
SSPROPVAL_USEPROCFORPREP_ON_DROP: UInt32 = 2
SSPROP_QUOTEDCATALOGNAMES: UInt32 = 2
SSPROP_ALLOWNATIVEVARIANT: UInt32 = 3
SSPROP_SQLXMLXPROGID: UInt32 = 4
SSPROP_MAXBLOBLENGTH: UInt32 = 8
SSPROP_FASTLOADOPTIONS: UInt32 = 9
SSPROP_FASTLOADKEEPNULLS: UInt32 = 10
SSPROP_FASTLOADKEEPIDENTITY: UInt32 = 11
SSPROP_CURSORAUTOFETCH: UInt32 = 12
SSPROP_DEFERPREPARE: UInt32 = 13
SSPROP_IRowsetFastLoad: UInt32 = 14
SSPROP_COL_COLLATIONNAME: UInt32 = 14
SSPROP_STREAM_MAPPINGSCHEMA: UInt32 = 15
SSPROP_STREAM_XSL: UInt32 = 16
SSPROP_STREAM_BASEPATH: UInt32 = 17
SSPROP_STREAM_COMMANDTYPE: UInt32 = 18
SSPROP_STREAM_XMLROOT: UInt32 = 19
SSPROP_STREAM_FLAGS: UInt32 = 20
SSPROP_STREAM_CONTENTTYPE: UInt32 = 23
STREAM_FLAGS_DISALLOW_URL: UInt32 = 1
STREAM_FLAGS_DISALLOW_ABSOLUTE_PATH: UInt32 = 2
STREAM_FLAGS_DISALLOW_QUERY: UInt32 = 4
STREAM_FLAGS_DONTCACHEMAPPINGSCHEMA: UInt32 = 8
STREAM_FLAGS_DONTCACHETEMPLATE: UInt32 = 16
STREAM_FLAGS_DONTCACHEXSL: UInt32 = 32
STREAM_FLAGS_DISALLOW_UPDATEGRAMS: UInt32 = 64
STREAM_FLAGS_RESERVED: UInt32 = 4294901760
SSPROPVAL_COMMANDTYPE_REGULAR: UInt32 = 21
SSPROPVAL_COMMANDTYPE_BULKLOAD: UInt32 = 22
DBTYPE_SQLVARIANT: UInt32 = 144
SQL_HANDLE_DBC_INFO_TOKEN: UInt32 = 6
SQL_CONN_POOL_RATING_BEST: UInt32 = 100
SQL_CONN_POOL_RATING_GOOD_ENOUGH: UInt32 = 99
SQL_CONN_POOL_RATING_USELESS: UInt32 = 0
SQL_ATTR_DBC_INFO_TOKEN: UInt32 = 118
SQL_ATTR_ASYNC_DBC_NOTIFICATION_CALLBACK: UInt32 = 120
SQL_ATTR_ASYNC_DBC_NOTIFICATION_CONTEXT: UInt32 = 121
SQL_ATTR_ASYNC_STMT_NOTIFICATION_CALLBACK: UInt32 = 30
SQL_ATTR_ASYNC_STMT_NOTIFICATION_CONTEXT: UInt32 = 31
SQL_MAX_NUMERIC_LEN: UInt32 = 16
SQL_WCHAR: Int32 = -8
SQL_WVARCHAR: Int32 = -9
SQL_WLONGVARCHAR: Int32 = -10
SQL_C_WCHAR: Int32 = -8
SQL_C_TCHAR: Int32 = -8
SQL_SQLSTATE_SIZEW: UInt32 = 10
PSGUID_STORAGE: Guid = Guid('{b725f130-47ef-101a-a5f1-02608c9eebac}')
CSTORAGEPROPERTY: UInt32 = 23
CATEGORY_SEARCH: Int32 = 1
CATEGORY_COLLATOR: Int32 = 2
CATEGORY_GATHERER: Int32 = 3
CATEGORY_INDEXER: Int32 = 4
EVENT_SSSEARCH_STARTED: Int32 = 1073742827
EVENT_SSSEARCH_STARTING_SETUP: Int32 = 1073742828
EVENT_SSSEARCH_SETUP_SUCCEEDED: Int32 = 1073742829
EVENT_SSSEARCH_SETUP_FAILED: Int32 = -1073740818
EVENT_OUTOFMEMORY: Int32 = -1073740817
EVENT_SSSEARCH_SETUP_CLEANUP_STARTED: Int32 = -2147482640
EVENT_EXCEPTION: Int32 = -1073740815
EVENT_SSSEARCH_SETUP_CLEANUP_SUCCEEDED: Int32 = 1073742834
EVENT_SSSEARCH_SETUP_CLEANUP_FAILED: Int32 = -1073740813
EVENT_SSSEARCH_STOPPED: Int32 = 1073742837
EVENT_SSSEARCH_CREATE_PATH_RULES_FAILED: Int32 = -2147482634
EVENT_SSSEARCH_DROPPED_EVENTS: Int32 = -2147482633
EVENT_SSSEARCH_DATAFILES_MOVE_FAILED: Int32 = -1073740808
EVENT_SSSEARCH_DATAFILES_MOVE_SUCCEEDED: Int32 = 1073742841
EVENT_SSSEARCH_DATAFILES_MOVE_ROLLBACK_ERRORS: Int32 = -2147482630
EVENT_SSSEARCH_CSM_SAVE_FAILED: Int32 = -1073740805
EVENT_CONFIG_SYNTAX: Int32 = -2147482604
EVENT_UNPRIVILEGED_SERVICE_ACCOUNT: Int32 = -2147482596
EVENT_SYSTEM_EXCEPTION: Int32 = -2147482595
EVENT_CONFIG_ERROR: Int32 = -1073738821
EVENT_GATHERSVC_PERFMON: Int32 = -1073738818
EVENT_GATHERER_PERFMON: Int32 = -1073738817
EVENT_HASHMAP_INSERT: Int32 = -1073738816
EVENT_TRANSLOG_CREATE_TRX: Int32 = -1073738815
EVENT_TRANSLOG_APPEND: Int32 = -1073738814
EVENT_TRANSLOG_UPDATE: Int32 = -1073738813
EVENT_HASHMAP_UPDATE: Int32 = -1073738811
EVENT_GATHER_EXCEPTION: Int32 = -1073738810
EVENT_TRANSACTION_READ: Int32 = -1073738809
EVENT_GATHER_END_CRAWL: Int32 = 1073744842
EVENT_GATHER_START_CRAWL: Int32 = 1073744843
EVENT_GATHER_INTERNAL: Int32 = -1073738804
EVENT_GATHER_CRAWL_NOT_STARTED: Int32 = -2147480625
EVENT_GATHER_CRAWL_SEED_ERROR: Int32 = -2147480624
EVENT_GATHER_CRITICAL_ERROR: Int32 = -1073738799
EVENT_GATHER_ADVISE_FAILED: Int32 = -1073738798
EVENT_GATHER_TRANSACTION_FAIL: Int32 = -1073738797
EVENT_GATHER_OBJ_INIT_FAILED: Int32 = -1073738796
EVENT_GATHER_PLUGIN_INIT_FAILED: Int32 = -1073738795
EVENT_GATHER_SERVICE_INIT: Int32 = -1073738794
EVENT_GATHER_CANT_CREATE_DOCID: Int32 = -1073738793
EVENT_GATHER_CANT_DELETE_DOCID: Int32 = -1073738792
EVENT_TRANSLOG_CREATE: Int32 = -1073738791
EVENT_REG_VERSION: Int32 = -1073738790
EVENT_GATHER_CRAWL_SEED_FAILED: Int32 = -2147480612
EVENT_GATHER_CRAWL_SEED_FAILED_INIT: Int32 = -2147480611
EVENT_GATHER_REG_MISSING: Int32 = -2147480610
EVENT_GATHER_CRAWL_IN_PROGRESS: Int32 = -2147480609
EVENT_GATHER_LOCK_FAILED: Int32 = -1073738784
EVENT_GATHER_RESET_START: Int32 = 1073744865
EVENT_GATHER_START_PAUSE: Int32 = -2147480606
EVENT_GATHER_THROTTLE: Int32 = 1073744867
EVENT_GATHER_RESUME: Int32 = 1073744868
EVENT_GATHER_AUTODESCLEN_ADJUSTED: Int32 = -2147480603
EVENT_GATHER_NO_CRAWL_SEEDS: Int32 = -2147480602
EVENT_GATHER_END_INCREMENTAL: Int32 = 1073744871
EVENT_GATHER_FROM_NOT_SET: Int32 = -1073738776
EVENT_GATHER_DELETING_HISTORY_ITEMS: Int32 = -1073738774
EVENT_GATHER_STOP_START: Int32 = 1073744876
EVENT_GATHER_START_CRAWL_IF_RESET: Int32 = -2147480595
EVENT_GATHER_DISK_FULL: Int32 = -2147480594
EVENT_GATHER_NO_SCHEMA: Int32 = -2147480593
EVENT_GATHER_AUTODESCENCODE_INVALID: Int32 = -2147480592
EVENT_GATHER_PLUGINMGR_INIT_FAILED: Int32 = -1073738767
EVENT_GATHER_APP_INIT_FAILED: Int32 = -1073738766
EVENT_FAILED_INITIALIZE_CRAWL: Int32 = -1073738765
EVENT_CRAWL_SCHEDULED: Int32 = 1073744884
EVENT_FAILED_CREATE_GATHERER_LOG: Int32 = -2147480587
EVENT_WBREAKER_NOT_LOADED: Int32 = -2147480586
EVENT_LEARN_PROPAGATION_COPY_FAILED: Int32 = -2147480585
EVENT_LEARN_CREATE_DB_FAILED: Int32 = -2147480584
EVENT_LEARN_COMPILE_FAILED: Int32 = -2147480583
EVENT_LEARN_PROPAGATION_FAILED: Int32 = -2147480582
EVENT_GATHER_END_ADAPTIVE: Int32 = 1073744891
EVENT_USING_DIFFERENT_WORD_BREAKER: Int32 = -2147480580
EVENT_GATHER_RESTORE_COMPLETE: Int32 = 3069
EVENT_GATHER_RESTORE_ERROR: Int32 = -1073738754
EVENT_AUTOCAT_PERFMON: Int32 = -1073738753
EVENT_GATHER_DIRTY_STARTUP: Int32 = -2147480576
EVENT_GATHER_HISTORY_CORRUPTION_DETECTED: Int32 = -2147480575
EVENT_GATHER_RESTOREAPP_ERROR: Int32 = -1073738750
EVENT_GATHER_RESTOREAPP_COMPLETE: Int32 = 3075
EVENT_GATHER_BACKUPAPP_ERROR: Int32 = -1073738748
EVENT_GATHER_BACKUPAPP_COMPLETE: Int32 = 3077
EVENT_GATHER_DAEMON_TERMINATED: Int32 = -2147480570
EVENT_NOTIFICATION_FAILURE: Int32 = -1073738745
EVENT_NOTIFICATION_FAILURE_SCOPE_EXCEEDED_LOGGING: Int32 = -2147480568
EVENT_NOTIFICATION_RESTORED: Int32 = 1073744905
EVENT_NOTIFICATION_RESTORED_SCOPE_EXCEEDED_LOGGING: Int32 = -2147480566
EVENT_GATHER_PROTOCOLHANDLER_LOAD_FAILED: Int32 = -1073738741
EVENT_GATHER_PROTOCOLHANDLER_INIT_FAILED: Int32 = -1073738740
EVENT_GATHER_INVALID_NETWORK_ACCESS_ACCOUNT: Int32 = -1073738739
EVENT_GATHER_SYSTEM_LCID_CHANGED: Int32 = -2147480562
EVENT_GATHER_FLUSH_FAILED: Int32 = -1073738737
EVENT_GATHER_CHECKPOINT_FAILED: Int32 = -1073738736
EVENT_GATHER_SAVE_FAILED: Int32 = -1073738735
EVENT_GATHER_RESTORE_CHECKPOINT_FAILED: Int32 = -1073738734
EVENT_GATHER_READ_CHECKPOINT_FAILED: Int32 = -1073738733
EVENT_GATHER_CHECKPOINT_CORRUPT: Int32 = -1073738732
EVENT_GATHER_CHECKPOINT_FILE_MISSING: Int32 = -1073738731
EVENT_STS_INIT_SECURITY_FAILED: Int32 = -2147480554
EVENT_LOCAL_GROUP_NOT_EXPANDED: Int32 = 1073744919
EVENT_LOCAL_GROUPS_CACHE_FLUSHED: Int32 = 1073744920
EVENT_GATHERER_DATASOURCE: Int32 = -1073738727
EVENT_AUTOCAT_CANT_CREATE_FILE_SHARE: Int32 = -1073738726
EVENT_NOTIFICATION_THREAD_EXIT_FAILED: Int32 = -1073738725
EVENT_FILTER_HOST_NOT_INITIALIZED: Int32 = -1073738724
EVENT_FILTER_HOST_NOT_TERMINATED: Int32 = -1073738723
EVENT_FILTERPOOL_ADD_FAILED: Int32 = -1073738722
EVENT_FILTERPOOL_DELETE_FAILED: Int32 = -1073738721
EVENT_ENUMERATE_SESSIONS_FAILED: Int32 = -1073738720
EVENT_DETAILED_FILTERPOOL_ADD_FAILED: Int32 = -1073738719
EVENT_AUDIENCECOMPUTATION_CANNOTSTART: Int32 = -1073738223
EVENT_GATHER_RECOVERY_FAILURE: Int32 = -1073738222
EVENT_GATHER_INPLACE_INDEX_REBUILD: Int32 = 1073745427
EVENT_INDEXER_STARTED: Int32 = 1073748824
EVENT_INDEXER_SCHEMA_COPY_ERROR: Int32 = -1073734823
EVENT_INDEXER_INIT_ERROR: Int32 = -1073734814
EVENT_INDEXER_INVALID_DIRECTORY: Int32 = -1073734813
EVENT_INDEXER_PROP_ERROR: Int32 = -1073734812
EVENT_INDEXER_PAUSED_FOR_DISKFULL: Int32 = -1073734811
EVENT_INDEXER_PROP_STOPPED: Int32 = -2147476633
EVENT_INDEXER_PROP_SUCCEEDED: Int32 = 7016
EVENT_INDEXER_PROP_STARTED: Int32 = 1073748841
EVENT_INDEXER_NO_SEARCH_SERVERS: Int32 = -2147476630
EVENT_INDEXER_ADD_DSS_SUCCEEDED: Int32 = 7019
EVENT_INDEXER_REMOVE_DSS_SUCCEEDED: Int32 = 7020
EVENT_INDEXER_ADD_DSS_FAILED: Int32 = -2147476627
EVENT_INDEXER_REMOVE_DSS_FAILED: Int32 = -1073734801
EVENT_INDEXER_DSS_CONTACT_FAILED: Int32 = -1073734800
EVENT_INDEXER_BUILD_FAILED: Int32 = -1073734797
EVENT_INDEXER_REG_MISSING: Int32 = -1073734796
EVENT_INDEXER_PROPSTORE_INIT_FAILED: Int32 = -1073734787
EVENT_INDEXER_CI_LOAD_ERROR: Int32 = -1073734785
EVENT_INDEXER_RESET_FOR_CORRUPTION: Int32 = -1073734784
EVENT_INDEXER_SHUTDOWN: Int32 = 1073748866
EVENT_INDEXER_LOAD_FAIL: Int32 = -1073734781
EVENT_INDEXER_PROP_STATE_CORRUPT: Int32 = -1073734780
EVENT_INDEXER_DSS_ALREADY_ADDED: Int32 = 1073748870
EVENT_INDEXER_BUILD_START: Int32 = 1073748872
EVENT_INDEXER_BUILD_ENDED: Int32 = 1073748873
EVENT_INDEXER_VERIFY_PROP_ACCOUNT: Int32 = -1073734768
EVENT_INDEXER_ADD_DSS_DISCONNECT: Int32 = -2147476585
EVENT_INDEXER_PERFMON: Int32 = -1073734760
EVENT_INDEXER_MISSING_APP_DIRECTORY: Int32 = -1073734758
EVENT_INDEXER_REG_ERROR: Int32 = -1073734756
EVENT_INDEXER_DSS_UNABLE_TO_REMOVE: Int32 = -1073734755
EVENT_INDEXER_NEW_PROJECT: Int32 = -1073734754
EVENT_INDEXER_REMOVED_PROJECT: Int32 = -1073734753
EVENT_INDEXER_PROP_COMMITTED: Int32 = 1073748898
EVENT_INDEXER_PROP_ABORTED: Int32 = 1073748899
EVENT_DSS_NOT_ENABLED: Int32 = -2147476572
EVENT_INDEXER_PROP_COMMIT_FAILED: Int32 = -1073734747
JET_INIT_ERROR: Int32 = -1073732824
JET_NEW_PROP_STORE_ERROR: Int32 = -1073732823
JET_GET_PROP_STORE_ERROR: Int32 = -1073732822
JET_MULTIINSTANCE_DISABLED: Int32 = -2147474645
EVENT_WARNING_CANNOT_UPGRADE_NOISE_FILES: Int32 = -2147473635
EVENT_WARNING_CANNOT_UPGRADE_NOISE_FILE: Int32 = -2147473634
EVENT_WIN32_ERROR: Int32 = -2147473633
EVENT_PERF_COUNTERS_NOT_LOADED: Int32 = -2147473628
EVENT_PERF_COUNTERS_REGISTRY_TROUBLE: Int32 = -2147473627
EVENT_PERF_COUNTERS_ALREADY_EXISTS: Int32 = -2147473626
EVENT_PROTOCOL_HOST_FORCE_TERMINATE: Int32 = -2147473625
EVENT_FILTER_HOST_FORCE_TERMINATE: Int32 = -2147473624
EVENT_INDEXER_OUT_OF_DATABASE_INSTANCE: Int32 = -1073731799
EVENT_INDEXER_FAIL_TO_SET_MAX_JETINSTANCE: Int32 = -1073731798
EVENT_INDEXER_FAIL_TO_CREATE_PER_USER_CATALOG: Int32 = -1073731797
EVENT_INDEXER_FAIL_TO_UNLOAD_PER_USER_CATALOG: Int32 = -1073731796
ERROR_SOURCE_NETWORKING: UInt32 = 768
ERROR_SOURCE_DATASOURCE: UInt32 = 1024
ERROR_SOURCE_COLLATOR: UInt32 = 1280
ERROR_SOURCE_CONNMGR: UInt32 = 1536
ERROR_SOURCE_QUERY: UInt32 = 1792
ERROR_SOURCE_SCHEMA: UInt32 = 3072
ERROR_SOURCE_GATHERER: UInt32 = 3328
ERROR_SOURCE_INDEXER: UInt32 = 4352
ERROR_SOURCE_SETUP: UInt32 = 4864
ERROR_SOURCE_SECURITY: UInt32 = 5120
ERROR_SOURCE_CMDLINE: UInt32 = 5376
ERROR_SOURCE_NLADMIN: UInt32 = 6400
ERROR_SOURCE_SCRIPTPI: UInt32 = 8192
ERROR_SOURCE_MSS: UInt32 = 8448
ERROR_SOURCE_XML: UInt32 = 8704
ERROR_SOURCE_DAV: UInt32 = 8960
ERROR_SOURCE_FLTRDMN: UInt32 = 9216
ERROR_SOURCE_OLEDB_BINDER: UInt32 = 9472
ERROR_SOURCE_NOTESPH: UInt32 = 9728
ERROR_SOURCE_EXSTOREPH: UInt32 = 9984
ERROR_SOURCE_SRCH_SCHEMA_CACHE: UInt32 = 13056
ERROR_SOURCE_CONTENT_SOURCE: UInt32 = 13312
ERROR_SOURCE_REMOTE_EXSTOREPH: UInt32 = 13568
ERROR_SOURCE_PEOPLE_IMPORT: UInt32 = 16384
ERROR_FTE: UInt32 = 13824
ERROR_FTE_CB: UInt32 = 51968
ERROR_FTE_FD: UInt32 = 64768
XML_E_NODEFAULTNS: Int32 = -2147212800
XML_E_BADSXQL: Int32 = -2147212799
MSS_E_INVALIDAPPNAME: Int32 = -2147213056
MSS_E_APPNOTFOUND: Int32 = -2147213055
MSS_E_APPALREADYEXISTS: Int32 = -2147213054
MSS_E_CATALOGNOTFOUND: Int32 = -2147213053
MSS_E_CATALOGSTOPPING: Int32 = -2147213052
MSS_E_UNICODEFILEHEADERMISSING: Int32 = -2147213051
MSS_E_CATALOGALREADYEXISTS: Int32 = -2147213050
NET_E_GENERAL: Int32 = -2147220736
NET_E_DISCONNECTED: Int32 = -2147220733
NET_E_INVALIDPARAMS: Int32 = -2147220728
NET_E_OPERATIONINPROGRESS: Int32 = -2147220727
SEC_E_INVALIDCONTEXT: Int32 = -2147216381
SEC_E_INITFAILED: Int32 = -2147216383
SEC_E_NOTINITIALIZED: Int32 = -2147216382
SEC_E_ACCESSDENIED: Int32 = -2147216129
DS_E_NOMOREDATA: Int32 = -2147220480
DS_E_INVALIDDATASOURCE: Int32 = -2147220479
DS_E_DATASOURCENOTAVAILABLE: Int32 = -2147220478
DS_E_QUERYCANCELED: Int32 = -2147220477
DS_E_UNKNOWNREQUEST: Int32 = -2147220476
DS_E_BADREQUEST: Int32 = -2147220475
DS_E_SERVERCAPACITY: Int32 = -2147220474
DS_E_BADSEQUENCE: Int32 = -2147220473
DS_E_MESSAGETOOLONG: Int32 = -2147220472
DS_E_SERVERERROR: Int32 = -2147220471
DS_E_CONFIGBAD: Int32 = -2147220470
DS_E_DATANOTPRESENT: Int32 = -2147220464
DS_E_SETSTATUSINPROGRESS: Int32 = -2147220463
DS_E_DUPLICATEID: Int32 = -2147220462
DS_E_TOOMANYDATASOURCES: Int32 = -2147220461
DS_E_REGISTRY: Int32 = -2147220460
DS_E_DATASOURCENOTDISABLED: Int32 = -2147220459
DS_E_INVALIDTAGDB: Int32 = -2147220458
DS_E_INVALIDCATALOGNAME: Int32 = -2147220457
DS_E_CONFIGNOTRIGHTTYPE: Int32 = -2147220456
DS_E_PROTOCOLVERSION: Int32 = -2147220455
DS_E_ALREADYENABLED: Int32 = -2147220454
DS_E_INDEXDIRECTORY: Int32 = -2147220452
DS_E_VALUETOOLARGE: Int32 = -2147220451
DS_E_UNKNOWNPARAM: Int32 = -2147220450
DS_E_BUFFERTOOSMALL: Int32 = -2147220449
DS_E_PARAMOUTOFRANGE: Int32 = -2147220448
DS_E_ALREADYDISABLED: Int32 = -2147220447
DS_E_QUERYHUNG: Int32 = -2147220446
DS_E_BADRESULT: Int32 = -2147220445
DS_E_CANNOTWRITEREGISTRY: Int32 = -2147220444
DS_E_CANNOTREMOVECONCURRENT: Int32 = -2147220443
DS_E_SEARCHCATNAMECOLLISION: Int32 = -2147220442
DS_E_PROPVERSIONMISMATCH: Int32 = -2147220441
DS_E_MISSINGCATALOG: Int32 = -2147220440
COLL_E_BADSEQUENCE: Int32 = -2147220223
COLL_E_NOMOREDATA: Int32 = -2147220222
COLL_E_INCOMPATIBLECOLUMNS: Int32 = -2147220221
COLL_E_BUFFERTOOSMALL: Int32 = -2147220220
COLL_E_BADRESULT: Int32 = -2147220218
COLL_E_NOSORTCOLUMN: Int32 = -2147220217
COLL_E_DUPLICATEDBID: Int32 = -2147220216
COLL_E_TOOMANYMERGECOLUMNS: Int32 = -2147220215
COLL_E_NODEFAULTCATALOG: Int32 = -2147220214
COLL_E_MAXCONNEXCEEDED: Int32 = -2147220213
CM_E_TOOMANYDATASERVERS: Int32 = -2147219967
CM_E_TOOMANYDATASOURCES: Int32 = -2147219966
CM_E_NOQUERYCONNECTIONS: Int32 = -2147219965
CM_E_DATASOURCENOTAVAILABLE: Int32 = -2147219964
CM_E_CONNECTIONTIMEOUT: Int32 = -2147219963
CM_E_SERVERNOTFOUND: Int32 = -2147219962
CM_S_NODATASERVERS: Int32 = 263687
CM_E_REGISTRY: Int32 = -2147219960
CM_E_INVALIDDATASOURCE: Int32 = -2147219959
CM_E_TIMEOUT: Int32 = -2147219958
CM_E_INSUFFICIENTBUFFER: Int32 = -2147219957
QRY_E_QUERYSYNTAX: Int32 = -2147219711
QRY_E_TYPEMISMATCH: Int32 = -2147219710
QRY_E_UNHANDLEDTYPE: Int32 = -2147219709
QRY_S_NOROWSFOUND: Int32 = 263940
QRY_E_TOOMANYCOLUMNS: Int32 = -2147219707
QRY_E_TOOMANYDATABASES: Int32 = -2147219706
QRY_E_STARTHITTOBIG: Int32 = -2147219705
QRY_E_TOOMANYQUERYTERMS: Int32 = -2147219704
QRY_E_NODATASOURCES: Int32 = -2147219703
QRY_E_TIMEOUT: Int32 = -2147219702
QRY_E_COLUMNNOTSORTABLE: Int32 = -2147219701
QRY_E_COLUMNNOTSEARCHABLE: Int32 = -2147219700
QRY_E_INVALIDCOLUMN: Int32 = -2147219699
QRY_E_QUERYCORRUPT: Int32 = -2147219698
QRY_E_PREFIXWILDCARD: Int32 = -2147219697
QRY_E_INFIXWILDCARD: Int32 = -2147219696
QRY_E_WILDCARDPREFIXLENGTH: Int32 = -2147219695
QRY_S_TERMIGNORED: Int32 = 263954
QRY_E_ENGINEFAILED: Int32 = -2147219693
QRY_E_SEARCHTOOBIG: Int32 = -2147219692
QRY_E_NULLQUERY: Int32 = -2147219691
QRY_S_INEXACTRESULTS: Int32 = 263958
QRY_E_NOCOLUMNS: Int32 = -2147219689
QRY_E_INVALIDSCOPES: Int32 = -2147219688
QRY_E_INVALIDCATALOG: Int32 = -2147219687
QRY_E_SCOPECARDINALIDY: Int32 = -2147219686
QRY_E_UNEXPECTED: Int32 = -2147219685
QRY_E_INVALIDPATH: Int32 = -2147219684
QRY_E_LMNOTINITIALIZED: Int32 = -2147219683
QRY_E_INVALIDINTERVAL: Int32 = -2147219682
QRY_E_NOLOGMANAGER: Int32 = -2147219681
SCHEMA_E_LOAD_SPECIAL: Int32 = -2147218431
SCHEMA_E_FILENOTFOUND: Int32 = -2147218430
SCHEMA_E_NESTEDTAG: Int32 = -2147218429
SCHEMA_E_UNEXPECTEDTAG: Int32 = -2147218428
SCHEMA_E_VERSIONMISMATCH: Int32 = -2147218427
SCHEMA_E_CANNOTCREATEFILE: Int32 = -2147218426
SCHEMA_E_CANNOTWRITEFILE: Int32 = -2147218425
SCHEMA_E_EMPTYFILE: Int32 = -2147218424
SCHEMA_E_INVALIDFILETYPE: Int32 = -2147218423
SCHEMA_E_INVALIDDATATYPE: Int32 = -2147218422
SCHEMA_E_CANNOTCREATENOISEWORDFILE: Int32 = -2147218421
SCHEMA_E_ADDSTOPWORDS: Int32 = -2147218420
SCHEMA_E_NAMEEXISTS: Int32 = -2147218419
SCHEMA_E_INVALIDVALUE: Int32 = -2147218418
SCHEMA_E_BADPROPSPEC: Int32 = -2147218417
SCHEMA_E_NOMORECOLUMNS: Int32 = -2147218416
SCHEMA_E_FILECHANGED: Int32 = -2147218415
SCHEMA_E_BADCOLUMNNAME: Int32 = -2147218414
SCHEMA_E_BADPROPPID: Int32 = -2147218413
SCHEMA_E_BADATTRIBUTE: Int32 = -2147218412
SCHEMA_E_BADFILENAME: Int32 = -2147218411
SCHEMA_E_PROPEXISTS: Int32 = -2147218410
SCHEMA_E_DUPLICATENOISE: Int32 = -2147218409
GTHR_E_DUPLICATE_OBJECT: Int32 = -2147218174
GTHR_E_UNABLE_TO_READ_REGISTRY: Int32 = -2147218173
GTHR_E_ERROR_WRITING_REGISTRY: Int32 = -2147218172
GTHR_E_ERROR_INITIALIZING_PERFMON: Int32 = -2147218171
GTHR_E_ERROR_OBJECT_NOT_FOUND: Int32 = -2147218170
GTHR_E_URL_EXCLUDED: Int32 = -2147218169
GTHR_E_CONFIG_DUP_PROJECT: Int32 = -2147218166
GTHR_E_CONFIG_DUP_EXTENSION: Int32 = -2147218165
GTHR_E_DUPLICATE_URL: Int32 = -2147218163
GTHR_E_TOO_MANY_PLUGINS: Int32 = -2147218162
GTHR_E_INVALIDFUNCTION: Int32 = -2147218161
GTHR_E_NOFILTERSINK: Int32 = -2147218160
GTHR_E_FILTER_PROCESS_TERMINATED: Int32 = -2147218159
GTHR_E_FILTER_INVALID_MESSAGE: Int32 = -2147218158
GTHR_E_UNSUPPORTED_PROPERTY_TYPE: Int32 = -2147218157
GTHR_E_NAME_TOO_LONG: Int32 = -2147218156
GTHR_E_NO_IDENTITY: Int32 = -2147218155
GTHR_E_FILTER_NOT_FOUND: Int32 = -2147218154
GTHR_E_FILTER_NO_MORE_THREADS: Int32 = -2147218153
GTHR_E_PRT_HNDLR_PROGID_MISSING: Int32 = -2147218152
GTHR_E_FILTER_PROCESS_TERMINATED_QUOTA: Int32 = -2147218151
GTHR_E_UNKNOWN_PROTOCOL: Int32 = -2147218150
GTHR_E_PROJECT_NOT_INITIALIZED: Int32 = -2147218149
GTHR_S_STATUS_CHANGE_IGNORED: Int32 = 265500
GTHR_S_STATUS_END_CRAWL: Int32 = 265501
GTHR_S_STATUS_RESET: Int32 = 265502
GTHR_S_STATUS_THROTTLE: Int32 = 265503
GTHR_S_STATUS_RESUME: Int32 = 265504
GTHR_S_STATUS_PAUSE: Int32 = 265505
GTHR_E_INVALID_PROJECT_NAME: Int32 = -2147218142
GTHR_E_SHUTTING_DOWN: Int32 = -2147218141
GTHR_S_END_STD_CHUNKS: Int32 = 265508
GTHR_E_VALUE_NOT_AVAILABLE: Int32 = -2147218139
GTHR_E_OUT_OF_DOC_ID: Int32 = -2147218138
GTHR_E_NOTIFICATION_START_PAGE: Int32 = -2147218137
GTHR_E_DUP_PROPERTY_MAPPING: Int32 = -2147218134
GTHR_S_NO_CRAWL_SEEDS: Int32 = 265515
GTHR_E_INVALID_ACCOUNT: Int32 = -2147218132
GTHR_E_FILTER_INIT: Int32 = -2147218130
GTHR_E_INVALID_ACCOUNT_SYNTAX: Int32 = -2147218129
GTHR_S_CANNOT_FILTER: Int32 = 265520
GTHR_E_PROXY_NAME: Int32 = -2147218127
GTHR_E_SERVER_UNAVAILABLE: Int32 = -2147218126
GTHR_S_STATUS_STOP: Int32 = 265523
GTHR_E_INVALID_PATH: Int32 = -2147218124
GTHR_E_FILTER_NO_CODEPAGE: Int32 = -2147218123
GTHR_S_STATUS_START: Int32 = 265526
GTHR_E_NO_PRTCLHNLR: Int32 = -2147218121
GTHR_E_IE_OFFLINE: Int32 = -2147218120
GTHR_E_BAD_FILTER_DAEMON: Int32 = -2147218119
GTHR_E_INVALID_MAPPING: Int32 = -2147218112
GTHR_E_USER_AGENT_NOT_SPECIFIED: Int32 = -2147218111
GTHR_E_FROM_NOT_SPECIFIED: Int32 = -2147218109
GTHR_E_INVALID_STREAM_LOGS_COUNT: Int32 = -2147218108
GTHR_E_INVALID_EXTENSION: Int32 = -2147218107
GTHR_E_INVALID_GROW_FACTOR: Int32 = -2147218106
GTHR_E_INVALID_TIME_OUT: Int32 = -2147218105
GTHR_E_INVALID_RETRIES: Int32 = -2147218104
GTHR_E_INVALID_LOG_FILE_NAME: Int32 = -2147218103
GTHR_E_INVALID_HOST_NAME: Int32 = -2147218096
GTHR_E_INVALID_START_PAGE: Int32 = -2147218095
GTHR_E_DUPLICATE_PROJECT: Int32 = -2147218094
GTHR_E_INVALID_DIRECTORY: Int32 = -2147218093
GTHR_E_FILTER_INTERRUPTED: Int32 = -2147218092
GTHR_E_INVALID_PROXY_PORT: Int32 = -2147218091
GTHR_S_CONFIG_HAS_ACCOUNTS: Int32 = 265558
GTHR_E_SECRET_NOT_FOUND: Int32 = -2147218089
GTHR_E_INVALID_PATH_EXPRESSION: Int32 = -2147218088
GTHR_E_INVALID_START_PAGE_HOST: Int32 = -2147218087
GTHR_E_INVALID_START_PAGE_PATH: Int32 = -2147218080
GTHR_E_APPLICATION_NOT_FOUND: Int32 = -2147218079
GTHR_E_CANNOT_REMOVE_PLUGINMGR: Int32 = -2147218078
GTHR_E_INVALID_APPLICATION_NAME: Int32 = -2147218077
GTHR_E_FILTER_FAULT: Int32 = -2147218075
GTHR_E_NON_FIXED_DRIVE: Int32 = -2147218074
GTHR_S_PROB_NOT_MODIFIED: Int32 = 265575
GTHR_S_CRAWL_SCHEDULED: Int32 = 265576
GTHR_S_TRANSACTION_IGNORED: Int32 = 265577
GTHR_S_START_FILTER_FROM_PROTOCOL: Int32 = 265578
GTHR_E_FILTER_SINGLE_THREADED: Int32 = -2147218069
GTHR_S_BAD_FILE_LINK: Int32 = 265580
GTHR_E_URL_UNIDENTIFIED: Int32 = -2147218067
GTHR_S_NOT_ALL_PARTS: Int32 = 265582
GTHR_E_FORCE_NOTIFICATION_RESET: Int32 = -2147218065
GTHR_S_END_PROCESS_LOOP_NOTIFY_QUEUE: Int32 = 265584
GTHR_S_START_FILTER_FROM_BODY: Int32 = 265585
GTHR_E_CONTENT_ID_CONFLICT: Int32 = -2147218062
GTHR_E_UNABLE_TO_READ_EXCHANGE_STORE: Int32 = -2147218061
GTHR_E_RECOVERABLE_EXOLEDB_ERROR: Int32 = -2147218060
GTHR_E_INVALID_CALL_FROM_WBREAKER: Int32 = -2147218058
GTHR_E_PROPERTY_LIST_NOT_INITIALIZED: Int32 = -2147218057
GTHR_S_MODIFIED_PARTS: Int32 = 265592
GHTR_E_LOCAL_SERVER_UNAVAILABLE: Int32 = -2147218055
GTHR_E_SCHEMA_ERRORS_OCCURRED: Int32 = -2147218054
GTHR_E_TIMEOUT: Int32 = -2147218053
GTHR_S_CRAWL_FULL: Int32 = 265603
GTHR_S_CRAWL_INCREMENTAL: Int32 = 265604
GTHR_S_CRAWL_ADAPTIVE: Int32 = 265605
GTHR_E_NOTIFICATION_START_ADDRESS_INVALID: Int32 = -2147218042
GTHR_E_NOTIFICATION_TYPE_NOT_SUPPORTED: Int32 = -2147218041
GTHR_E_NOTIFICATION_FILE_SHARE_INFO_NOT_AVAILABLE: Int32 = -2147218040
GTHR_E_NOTIFICATION_LOCAL_PATH_MUST_USE_FIXED_DRIVE: Int32 = -2147218039
GHTR_E_INSUFFICIENT_DISK_SPACE: Int32 = -2147218037
GTHR_E_INVALID_RESOURCE_ID: Int32 = -2147218035
GTHR_E_NESTED_HIERARCHICAL_START_ADDRESSES: Int32 = -2147218034
GTHR_S_NO_INDEX: Int32 = 265616
GTHR_S_PAUSE_REASON_EXTERNAL: Int32 = 265618
GTHR_S_PAUSE_REASON_UPGRADING: Int32 = 265619
GTHR_S_PAUSE_REASON_BACKOFF: Int32 = 265620
GTHR_E_RETRY: Int32 = -2147218027
GTHR_E_JET_BACKUP_ERROR: Int32 = -2147218026
GTHR_E_JET_RESTORE_ERROR: Int32 = -2147218025
GTHR_S_OFFICE_CHILD: Int32 = 265626
GTHR_E_PLUGIN_NOT_REGISTERED: Int32 = -2147218021
GTHR_E_NOTIF_ACCESS_TOKEN_UPDATED: Int32 = -2147218020
GTHR_E_DIRMON_NOT_INITIALZED: Int32 = -2147218019
GTHR_E_NOTIF_BEING_REMOVED: Int32 = -2147218018
GTHR_E_NOTIF_EXCESSIVE_THROUGHPUT: Int32 = -2147218017
GTHR_E_INVALID_PATH_SPEC: Int32 = -2147218016
GTHR_E_INSUFFICIENT_FEATURE_TERMS: Int32 = -2147218015
GTHR_E_INSUFFICIENT_EXAMPLE_CATEGORIES: Int32 = -2147218014
GTHR_E_INSUFFICIENT_EXAMPLE_DOCUMENTS: Int32 = -2147218013
GTHR_E_AUTOCAT_UNEXPECTED: Int32 = -2147218012
GTHR_E_SINGLE_THREADED_EMBEDDING: Int32 = -2147218011
GTHR_S_CANNOT_WORDBREAK: Int32 = 265638
GTHR_S_USE_MIME_FILTER: Int32 = 265639
GTHR_E_FOLDER_CRAWLED_BY_ANOTHER_WORKSPACE: Int32 = -2147218007
GTHR_E_EMPTY_DACL: Int32 = -2147218006
GTHR_E_OBJECT_NOT_VALID: Int32 = -2147218005
GTHR_E_CANNOT_ENABLE_CHECKPOINT: Int32 = -2147218002
GTHR_E_SCOPES_EXCEEDED: Int32 = -2147218001
GTHR_E_PROPERTIES_EXCEEDED: Int32 = -2147218000
GTHR_E_INVALID_START_ADDRESS: Int32 = -2147217998
GTHR_S_PAUSE_REASON_PROFILE_IMPORT: Int32 = 265651
GTHR_E_PIPE_NOT_CONNECTTED: Int32 = -2147217996
GTHR_E_BACKUP_VALIDATION_FAIL: Int32 = -2147217994
GTHR_E_BAD_FILTER_HOST: Int32 = -2147217993
GTHR_E_NTF_CLIENT_NOT_SUBSCRIBED: Int32 = -1073476167
GTHR_E_FILTERPOOL_NOTFOUND: Int32 = -2147217990
GTHR_E_ADDLINKS_FAILED_WILL_RETRY_PARENT: Int32 = -2147217989
IDX_E_INVALIDTAG: Int32 = -2147217151
IDX_E_METAFILE_CORRUPT: Int32 = -2147217150
IDX_E_TOO_MANY_SEARCH_SERVERS: Int32 = -2147217149
IDX_E_SEARCH_SERVER_ALREADY_EXISTS: Int32 = -2147217148
IDX_E_BUILD_IN_PROGRESS: Int32 = -2147217147
IDX_E_IDXLSTFILE_CORRUPT: Int32 = -2147217146
IDX_E_REGISTRY_ENTRY: Int32 = -2147217145
IDX_E_OBJECT_NOT_FOUND: Int32 = -2147217144
IDX_E_SEARCH_SERVER_NOT_FOUND: Int32 = -2147217143
IDX_E_WB_NOTFOUND: Int32 = -2147217142
IDX_E_NOISELIST_NOTFOUND: Int32 = -2147217141
IDX_E_STEMMER_NOTFOUND: Int32 = -2147217140
IDX_E_PROP_STOPPED: Int32 = -2147217139
IDX_E_DISKFULL: Int32 = -2147217138
IDX_E_INVALID_INDEX: Int32 = -2147217137
IDX_E_CORRUPT_INDEX: Int32 = -2147217136
IDX_E_PROPSTORE_INIT_FAILED: Int32 = -2147217134
IDX_E_PROP_STATE_CORRUPT: Int32 = -2147217133
IDX_S_NO_BUILD_IN_PROGRESS: Int32 = 266516
IDX_S_SEARCH_SERVER_ALREADY_EXISTS: Int32 = 266517
IDX_S_SEARCH_SERVER_DOES_NOT_EXIST: Int32 = 266518
IDX_E_NOT_LOADED: Int32 = -2147217129
IDX_E_PROP_MAJOR_VERSION_MISMATCH: Int32 = -2147217128
IDX_E_PROP_MINOR_VERSION_MISMATCH: Int32 = -2147217127
IDX_E_DSS_NOT_CONNECTED: Int32 = -2147217126
IDX_E_DOCUMENT_ABORTED: Int32 = -2147217125
IDX_E_CATALOG_DISMOUNTED: Int32 = -2147217124
IDX_S_DSS_NOT_AVAILABLE: Int32 = 266525
IDX_E_USE_DEFAULT_CONTENTCLASS: Int32 = -2147217121
IDX_E_USE_APPGLOBAL_PROPTABLE: Int32 = -2147217120
JPS_E_JET_ERR: Int32 = -2147217025
JPS_S_DUPLICATE_DOC_DETECTED: Int32 = 266624
JPS_E_CATALOG_DECSRIPTION_MISSING: Int32 = -2147217023
JPS_E_MISSING_INFORMATION: Int32 = -2147217022
JPS_E_INSUFFICIENT_VERSION_STORAGE: Int32 = -2147217021
JPS_E_INSUFFICIENT_DATABASE_SESSIONS: Int32 = -2147217020
JPS_E_INSUFFICIENT_DATABASE_RESOURCES: Int32 = -2147217019
JPS_E_SCHEMA_ERROR: Int32 = -2147217018
JPS_E_PROPAGATION_FILE: Int32 = -2147217017
JPS_E_PROPAGATION_CORRUPTION: Int32 = -2147217016
JPS_E_PROPAGATION_VERSION_MISMATCH: Int32 = -2147217015
JPS_E_SHARING_VIOLATION: Int32 = -2147217014
EXCI_E_NO_CONFIG: Int32 = -2147216992
EXCI_E_INVALID_SERVER_CONFIG: Int32 = -2147216991
EXCI_E_ACCESS_DENIED: Int32 = -2147216990
EXCI_E_INVALID_EXCHANGE_SERVER: Int32 = -2147216989
EXCI_E_BADCONFIG_OR_ACCESSDENIED: Int32 = -2147216988
EXCI_E_WRONG_SERVER_OR_ACCT: Int32 = -2147216987
EXCI_E_NOT_ADMIN_OR_WRONG_SITE: Int32 = -2147216986
EXCI_E_NO_MAPI: Int32 = -2147216985
EXCI_E_INVALID_ACCOUNT_INFO: Int32 = -2147216984
PRTH_E_INTERNAL_ERROR: Int32 = -2147216892
PRTH_S_MAX_GROWTH: Int32 = 266761
PRTH_E_WININET: Int32 = -2147216886
PRTH_E_RETRY: Int32 = -2147216885
PRTH_S_MAX_DOWNLOAD: Int32 = 266764
PRTH_E_MIME_EXCLUDED: Int32 = -2147216883
PRTH_E_CANT_TRANSFORM_EXTERNAL_ACL: Int32 = -2147216882
PRTH_E_CANT_TRANSFORM_DENIED_ACE: Int32 = -2147216881
PRTH_E_NO_PROPERTY: Int32 = -2147216877
PRTH_S_USE_ROSEBUD: Int32 = 266772
PRTH_E_DATABASE_OPEN_ERROR: Int32 = -2147216875
PRTH_E_OPLOCK_BROKEN: Int32 = -2147216874
PRTH_E_LOAD_FAILED: Int32 = -2147216873
PRTH_E_INIT_FAILED: Int32 = -2147216872
PRTH_E_VOLUME_MOUNT_POINT: Int32 = -2147216871
PRTH_E_TRUNCATED: Int32 = -2147216870
GTHR_E_LOCAL_GROUPS_EXPANSION_INTERNAL_ERROR: Int32 = -2147216867
PRTH_E_HTTPS_CERTIFICATE_ERROR: Int32 = -2147216861
PRTH_E_HTTPS_REQUIRE_CERTIFICATE: Int32 = -2147216860
PRTH_S_TRY_IMPERSONATING: Int32 = 266789
CMDLINE_E_UNEXPECTED: Int32 = -2147216127
CMDLINE_E_PAREN: Int32 = -2147216126
CMDLINE_E_PARAM_SIZE: Int32 = -2147216125
CMDLINE_E_NOT_INIT: Int32 = -2147216124
CMDLINE_E_ALREADY_INIT: Int32 = -2147216123
CMDLINE_E_NUM_PARAMS: Int32 = -2147216122
NLADMIN_E_DUPLICATE_CATALOG: Int32 = -2147215103
NLADMIN_S_NOT_ALL_BUILD_CATALOGS_INITIALIZED: Int32 = 268546
NLADMIN_E_FAILED_TO_GIVE_ACCOUNT_PRIVILEGE: Int32 = -2147215101
NLADMIN_E_BUILD_CATALOG_NOT_INITIALIZED: Int32 = -2147215100
SCRIPTPI_E_CHUNK_NOT_TEXT: Int32 = -2147213312
SCRIPTPI_E_PID_NOT_NAME: Int32 = -2147213311
SCRIPTPI_E_PID_NOT_NUMERIC: Int32 = -2147213310
SCRIPTPI_E_CHUNK_NOT_VALUE: Int32 = -2147213309
SCRIPTPI_E_CANNOT_ALTER_CHUNK: Int32 = -2147213308
SCRIPTPI_E_ALREADY_COMPLETED: Int32 = -2147213307
_MAPI_E_NO_SUPPORT: Int32 = -2147221246
_MAPI_E_BAD_CHARWIDTH: Int32 = -2147221245
_MAPI_E_STRING_TOO_LONG: Int32 = -2147221243
_MAPI_E_UNKNOWN_FLAGS: Int32 = -2147221242
_MAPI_E_INVALID_ENTRYID: Int32 = -2147221241
_MAPI_E_INVALID_OBJECT: Int32 = -2147221240
_MAPI_E_OBJECT_CHANGED: Int32 = -2147221239
_MAPI_E_OBJECT_DELETED: Int32 = -2147221238
_MAPI_E_BUSY: Int32 = -2147221237
_MAPI_E_NOT_ENOUGH_DISK: Int32 = -2147221235
_MAPI_E_NOT_ENOUGH_RESOURCES: Int32 = -2147221234
_MAPI_E_NOT_FOUND: Int32 = -2147221233
_MAPI_E_VERSION: Int32 = -2147221232
_MAPI_E_LOGON_FAILED: Int32 = -2147221231
_MAPI_E_SESSION_LIMIT: Int32 = -2147221230
_MAPI_E_USER_CANCEL: Int32 = -2147221229
_MAPI_E_UNABLE_TO_ABORT: Int32 = -2147221228
_MAPI_E_NETWORK_ERROR: Int32 = -2147221227
_MAPI_E_DISK_ERROR: Int32 = -2147221226
_MAPI_E_TOO_COMPLEX: Int32 = -2147221225
_MAPI_E_BAD_COLUMN: Int32 = -2147221224
_MAPI_E_EXTENDED_ERROR: Int32 = -2147221223
_MAPI_E_COMPUTED: Int32 = -2147221222
_MAPI_E_CORRUPT_DATA: Int32 = -2147221221
_MAPI_E_UNCONFIGURED: Int32 = -2147221220
_MAPI_E_FAILONEPROVIDER: Int32 = -2147221219
_MAPI_E_UNKNOWN_CPID: Int32 = -2147221218
_MAPI_E_UNKNOWN_LCID: Int32 = -2147221217
_MAPI_E_PASSWORD_CHANGE_REQUIRED: Int32 = -2147221216
_MAPI_E_PASSWORD_EXPIRED: Int32 = -2147221215
_MAPI_E_INVALID_WORKSTATION_ACCOUNT: Int32 = -2147221214
_MAPI_E_INVALID_ACCESS_TIME: Int32 = -2147221213
_MAPI_E_ACCOUNT_DISABLED: Int32 = -2147221212
_MAPI_E_END_OF_SESSION: Int32 = -2147220992
_MAPI_E_UNKNOWN_ENTRYID: Int32 = -2147220991
_MAPI_E_MISSING_REQUIRED_COLUMN: Int32 = -2147220990
_MAPI_W_NO_SERVICE: Int32 = 262659
MSG_TEST_MESSAGE: Int32 = 1074008064
FLTRDMN_E_UNEXPECTED: Int32 = -2147212287
FLTRDMN_E_QI_FILTER_FAILED: Int32 = -2147212286
FLTRDMN_E_FILTER_INIT_FAILED: Int32 = -2147212284
FLTRDMN_E_ENCRYPTED_DOCUMENT: Int32 = -2147212283
FLTRDMN_E_CANNOT_DECRYPT_PASSWORD: Int32 = -2147212282
OLEDB_BINDER_CUSTOM_ERROR: Int32 = -2147212032
NOTESPH_E_UNEXPECTED_STATE: Int32 = -2147211775
NOTESPH_S_IGNORE_ID: Int32 = 271874
NOTESPH_E_UNSUPPORTED_CONTENT_FIELD_TYPE: Int32 = -2147211773
NOTESPH_E_ITEM_NOT_FOUND: Int32 = -2147211772
NOTESPH_E_SERVER_CONFIG: Int32 = -2147211771
NOTESPH_E_ATTACHMENTS: Int32 = -2147211770
NOTESPH_E_NO_NTID: Int32 = -2147211769
NOTESPH_E_DB_ACCESS_DENIED: Int32 = -2147211768
NOTESPH_E_NOTESSETUP_ID_MAPPING_ERROR: Int32 = -2147211767
NOTESPH_S_LISTKNOWNFIELDS: Int32 = 271888
NOTESPH_E_FAIL: Int32 = -2147211759
STS_ABORTXMLPARSE: Int32 = -2147211756
STS_WS_ERROR: Int32 = -2147211754
SPS_WS_ERROR: Int32 = -2147211753
EXSTOREPH_E_UNEXPECTED: Int32 = -2147211519
CERT_E_NOT_FOUND_OR_NO_PERMISSSION: Int32 = -2147211263
SRCH_SCHEMA_CACHE_E_UNEXPECTED: Int32 = -2147208447
CONTENT_SOURCE_E_PROPERTY_MAPPING_READ: Int32 = -2147208191
CONTENT_SOURCE_E_UNEXPECTED_NULL_POINTER: Int32 = -2147208190
CONTENT_SOURCE_E_PROPERTY_MAPPING_BAD_VECTOR_SIZE: Int32 = -2147208189
CONTENT_SOURCE_E_CONTENT_CLASS_READ: Int32 = -2147208188
CONTENT_SOURCE_E_UNEXPECTED_EXCEPTION: Int32 = -2147208187
CONTENT_SOURCE_E_NULL_CONTENT_CLASS_BSTR: Int32 = -2147208186
CONTENT_SOURCE_E_CONTENT_SOURCE_COLUMN_TYPE: Int32 = -2147208185
CONTENT_SOURCE_E_OUT_OF_RANGE: Int32 = -2147208184
CONTENT_SOURCE_E_NULL_URI: Int32 = -2147208183
REXSPH_E_INVALID_CALL: Int32 = -2147207936
REXSPH_S_REDIRECTED: Int32 = 275713
REXSPH_E_REDIRECT_ON_SECURITY_UPDATE: Int32 = -2147207934
REXSPH_E_MULTIPLE_REDIRECT: Int32 = -2147207933
REXSPH_E_NO_PROPERTY_ON_ROW: Int32 = -2147207932
REXSPH_E_TYPE_MISMATCH_ON_READ: Int32 = -2147207931
REXSPH_E_UNEXPECTED_DATA_STATUS: Int32 = -2147207930
REXSPH_E_UNKNOWN_DATA_TYPE: Int32 = -2147207929
REXSPH_E_UNEXPECTED_FILTER_STATE: Int32 = -2147207928
REXSPH_E_DUPLICATE_PROPERTY: Int32 = -2147207927
PEOPLE_IMPORT_E_DBCONNFAIL: Int32 = -2147205120
PEOPLE_IMPORT_NODSDEFINED: Int32 = -2147205119
PEOPLE_IMPORT_E_FAILTOGETDSDEF: Int32 = -2147205118
PEOPLE_IMPORT_NOMAPPINGDEFINED: Int32 = -2147205117
PEOPLE_IMPORT_E_FAILTOGETDSMAPPING: Int32 = -2147205116
PEOPLE_IMPORT_E_DATATYPENOTSUPPORTED: Int32 = -2147205115
PEOPLE_IMPORT_E_NOCASTINGSUPPORTED: Int32 = -2147205114
PEOPLE_IMPORT_E_UPDATE_DIRSYNC_COOKIE: Int32 = -2147205113
PEOPLE_IMPORT_E_DIRSYNC_ZERO_COOKIE: Int32 = -2147205112
PEOPLE_IMPORT_E_LDAPPATH_TOOLONG: Int32 = -2147205111
PEOPLE_IMPORT_E_CANONICALURL_TOOLONG: Int32 = -2147205110
PEOPLE_IMPORT_E_USERNAME_NOTRESOLVED: Int32 = -2147205109
PEOPLE_IMPORT_E_DC_NOT_AVAILABLE: Int32 = -2147205108
PEOPLE_IMPORT_E_DOMAIN_DISCOVER_FAILED: Int32 = -2147205107
PEOPLE_IMPORT_E_FAILTOGETLCID: Int32 = -2147205106
PEOPLE_IMPORT_E_DOMAIN_REMOVED: Int32 = -2147205105
PEOPLE_IMPORT_E_ENUM_ACCESSDENIED: Int32 = -2147205104
PEOPLE_IMPORT_E_DIRSYNC_NOTREFRESHED: Int32 = -2147205103
FTE_E_SECRET_NOT_FOUND: Int32 = -2147207678
FTE_E_PIPE_NOT_CONNECTED: Int32 = -2147207677
FTE_E_ADMIN_BLOB_CORRUPT: Int32 = -2147207676
FTE_E_FILTER_SINGLE_THREADED: Int32 = -2147207675
FTE_E_ERROR_WRITING_REGISTRY: Int32 = -2147207674
FTE_E_PROJECT_SHUTDOWN: Int32 = -2147207673
FTE_E_PROJECT_NOT_INITALIZED: Int32 = -2147207672
FTE_E_PIPE_DATA_CORRUPTED: Int32 = -2147207671
FTE_E_URB_TOO_BIG: Int32 = -2147207664
FTE_E_INVALID_DOCID: Int32 = -2147207663
FTE_E_PAUSE_EXTERNAL: Int32 = -2147207662
FTE_E_REJECTED_DUE_TO_PROJECT_STATUS: Int32 = -2147207661
FTE_E_FD_DID_NOT_CONNECT: Int32 = -2147207660
FTE_E_PROGID_REQUIRED: Int32 = -2147207658
FTE_E_STATIC_THREAD_INVALID_ARGUMENTS: Int32 = -2147207657
FTE_E_CATALOG_ALREADY_EXISTS: Int32 = -2147207656
FTE_S_RESOURCES_STARTING_TO_GET_LOW: Int32 = 275993
FTE_E_PATH_TOO_LONG: Int32 = -2147207654
FTE_INVALID_ADMIN_CLIENT: Int32 = -2147207653
FTE_E_COM_SIGNATURE_VALIDATION: Int32 = -2147207652
FTE_E_AFFINITY_MASK: Int32 = -2147207651
FTE_E_FD_OWNERSHIP_OBSOLETE: Int32 = -2147207650
FTE_E_EXCEEDED_MAX_PLUGINS: Int32 = -2147207647
FTE_S_BEYOND_QUOTA: Int32 = 276002
FTE_E_DUPLICATE_OBJECT: Int32 = -2147207644
FTE_S_REDUNDANT: Int32 = 276005
FTE_E_REDUNDANT_TRAN_FAILURE: Int32 = -2147207642
FTE_E_DEPENDENT_TRAN_FAILED_TO_PERSIST: Int32 = -2147207641
FTE_E_FD_SHUTDOWN: Int32 = -2147207640
FTE_E_CATALOG_DOES_NOT_EXIST: Int32 = -2147207639
FTE_E_NO_PLUGINS: Int32 = -2147207638
FTE_S_STATUS_CHANGE_REQUEST: Int32 = 276011
FTE_E_BATCH_ABORTED: Int32 = -2147207636
FTE_E_ANOTHER_STATUS_CHANGE_IS_ALREADY_ACTIVE: Int32 = -2147207635
FTE_S_RESUME: Int32 = 276014
FTE_E_NOT_PROCESSED_DUE_TO_PREVIOUS_ERRORS: Int32 = -2147207633
FTE_E_FD_TIMEOUT: Int32 = -2147207632
FTE_E_RESOURCE_SHUTDOWN: Int32 = -2147207631
FTE_E_INVALID_PROPERTY: Int32 = -2147207630
FTE_E_NO_MORE_PROPERTIES: Int32 = -2147207629
FTE_E_UNKNOWN_PLUGIN: Int32 = -2147207628
FTE_E_LIBRARY_NOT_LOADED: Int32 = -2147207627
FTE_E_PERFMON_FULL: Int32 = -2147207626
FTE_E_FAILED_TO_CREATE_ACCESSOR: Int32 = -2147207625
FTE_E_INVALID_TYPE: Int32 = -2147207624
FTE_E_OUT_OF_RANGE: Int32 = -2147207623
FTE_E_CORRUPT_PROPERTY_STORE: Int32 = -2147207622
FTE_E_PROPERTY_STORE_WORKID_NOTVALID: Int32 = -2147207621
FTE_S_PROPERTY_STORE_END_OF_ENUMERATION: Int32 = 276028
FTE_E_CORRUPT_GATHERER_HASH_MAP: Int32 = -2147207619
FTE_E_KEY_NOT_CACHED: Int32 = -2147207618
FTE_E_UPGRADE_INTERFACE_ALREADY_SHUTDOWN: Int32 = -2147207617
FTE_E_UPGRADE_INTERFACE_ALREADY_INSTANTIATED: Int32 = -2147207616
FTE_E_STACK_CORRUPTED: Int32 = -2147207615
FTE_E_INVALID_PROG_ID: Int32 = -2147207614
FTE_E_SERIAL_STREAM_CORRUPT: Int32 = -2147207613
FTE_E_READONLY_CATALOG: Int32 = -2147207612
FTE_E_PERF_NOT_LOADED: Int32 = -2147207611
FTE_S_READONLY_CATALOG: Int32 = 276038
FTE_E_RETRY_HUGE_DOC: Int32 = -2147207608
FTE_E_UNKNOWN_FD_TYPE: Int32 = -2147207607
FTE_E_DOC_TOO_HUGE: Int32 = -2147207606
FTE_E_DATATYPE_MISALIGNMENT: Int32 = -2147207605
FTE_E_ALREADY_INITIALIZED: Int32 = -2147207604
FTE_E_FD_USED_TOO_MUCH_MEMORY: Int32 = -2147207603
FTE_E_UNEXPECTED_EXIT: Int32 = -2147207602
FTE_E_HIGH_MEMORY_PRESSURE: Int32 = -2147207601
FTE_E_INVALID_ISOLATE_ERROR_BATCH: Int32 = -2147207600
FTE_E_RETRY_SINGLE_DOC_PER_BATCH: Int32 = -2147207599
FTE_E_INVALID_PROJECT_ID: Int32 = -2147207598
FTE_E_FAILURE_TO_POST_SETCOMPLETION_STATUS: Int32 = -2147207597
FTE_E_INVALID_CODEPAGE: Int32 = -2147207596
FTE_E_FD_IDLE: Int32 = -2147207595
FTE_E_FD_UNRESPONSIVE: Int32 = -2147207594
FTE_S_TRY_TO_FLUSH: Int32 = 276055
FTE_S_CATALOG_BLOB_MISMATCHED: Int32 = 276056
FTE_S_PROPERTY_RESET: Int32 = 276057
FTE_E_NO_PROPERTY_STORE: Int32 = -1073465766
FTE_E_CB_OUT_OF_MEMORY: Int32 = -2147169536
FTE_E_CB_CBID_OUT_OF_BOUND: Int32 = -2147169535
FTE_E_CB_NOT_ENOUGH_AVAIL_PHY_MEM: Int32 = -2147169534
FTE_E_CB_NOT_ENOUGH_OCC_BUFFER: Int32 = -2147169533
FTE_E_CORRUPT_WORDLIST: Int32 = -2147169532
FTE_E_FD_NO_IPERSIST_INTERFACE: Int32 = -2147156736
FTE_E_FD_IFILTER_INIT_FAILED: Int32 = -2147156735
FTE_E_FD_FAILED_TO_LOAD_IFILTER: Int32 = -2147156734
FTE_E_FD_DOC_TIMEOUT: Int32 = -2147156733
FTE_E_FD_UNEXPECTED_EXIT: Int32 = -2147156732
FTE_E_FD_DOC_UNEXPECTED_EXIT: Int32 = -2147156731
FTE_E_FD_NOISE_NO_TEXT_FILTER: Int32 = -2147156730
FTE_E_FD_NOISE_NO_IPERSISTSTREAM_ON_TEXT_FILTER: Int32 = -2147156729
FTE_E_FD_NOISE_TEXT_FILTER_LOAD_FAILED: Int32 = -2147156728
FTE_E_FD_NOISE_TEXT_FILTER_INIT_FAILED: Int32 = -2147156727
FTE_E_FD_OCCURRENCE_OVERFLOW: Int32 = -2147156726
FTE_E_FD_FILTER_CAUSED_SHARING_VIOLATION: Int32 = -2147156725
ERROR_SOURCE_PROTHNDLR: UInt32 = 4608
PRTH_E_COMM_ERROR: UInt32 = 2147750400
PRTH_E_OBJ_NOT_FOUND: UInt32 = 2147750401
PRTH_E_REQUEST_ERROR: UInt32 = 2147750402
PRTH_S_NOT_MODIFIED: UInt32 = 266755
PRTH_E_ACCESS_DENIED: UInt32 = 2147750405
PRTH_E_SERVER_ERROR: UInt32 = 2147750406
PRTH_E_NOT_REDIRECTED: UInt32 = 2147750407
PRTH_E_BAD_REQUEST: UInt32 = 2147750408
PRTH_E_HTTP_CANNOT_CONNECT: UInt32 = 2147750409
PRTH_S_ACL_IS_READ_EVERYONE: UInt32 = 266768
PRTH_E_ACL_IS_READ_NONE: UInt32 = 2147750417
PRTH_E_ACL_TOO_BIG: UInt32 = 2147750418
PRTH_S_NOT_ALL_PARTS: UInt32 = 266779
QUERY_E_ALLNOISE_AND_NO_RELDOC: win32more.Windows.Win32.Foundation.HRESULT = -2147215859
QUERY_E_NO_RELDOC: win32more.Windows.Win32.Foundation.HRESULT = -2147215858
QUERY_E_ALLNOISE_AND_NO_RELPROP: win32more.Windows.Win32.Foundation.HRESULT = -2147215857
QUERY_E_NO_RELPROP: win32more.Windows.Win32.Foundation.HRESULT = -2147215856
QUERY_E_REPEATED_RELDOC: win32more.Windows.Win32.Foundation.HRESULT = -2147215855
QUERY_E_RELDOC_SYNTAX_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147215854
QUERY_E_INVALID_DOCUMENT_IDENTIFIER: win32more.Windows.Win32.Foundation.HRESULT = -2147215853
QUERY_E_INCORRECT_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2147215852
QUERY_E_INVALIDSCOPE_COALESCE: win32more.Windows.Win32.Foundation.HRESULT = -2147215851
QUERY_E_INVALIDSORT_COALESCE: win32more.Windows.Win32.Foundation.HRESULT = -2147215850
QUERY_E_INVALIDCOALESCE: win32more.Windows.Win32.Foundation.HRESULT = -2147215849
QUERY_E_UPGRADEINPROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2147215848
QUERY_E_AGGREGATE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147215847
QUERY_E_TOP_LEVEL_IN_GROUP: win32more.Windows.Win32.Foundation.HRESULT = -2147215846
QUERY_E_DUPLICATE_RANGE_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2147215845
CI_S_NEW_AUXMETADATA: win32more.Windows.Win32.Foundation.HRESULT = 268329
CI_E_NO_AUXMETADATA: win32more.Windows.Win32.Foundation.HRESULT = -2147215318
CI_S_CLIENT_REQUESTED_ABORT: win32more.Windows.Win32.Foundation.HRESULT = 268331
CI_S_RETRY_DOCUMENT: win32more.Windows.Win32.Foundation.HRESULT = 268332
CI_E_CORRUPT_FWIDX: win32more.Windows.Win32.Foundation.HRESULT = -1073473491
CI_E_DIACRITIC_SETTINGS_DIFFER: win32more.Windows.Win32.Foundation.HRESULT = -1073473490
CI_E_INVALID_CATALOG_LIST_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2147215313
CI_S_CATALOG_RESET: win32more.Windows.Win32.Foundation.HRESULT = 268336
CI_E_NO_CATALOG_MANAGER: win32more.Windows.Win32.Foundation.HRESULT = -1073473487
CI_E_INCONSISTENT_TRANSACTION: win32more.Windows.Win32.Foundation.HRESULT = -1073473486
CI_E_PROTECTED_CATALOG_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1073473485
CI_E_NO_PROTECTED_USER: win32more.Windows.Win32.Foundation.HRESULT = -1073473484
CI_E_MULTIPLE_PROTECTED_USERS_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1073473483
CI_E_PROTECTED_CATALOG_SID_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1073473482
CI_E_PROTECTED_CATALOG_NON_INTERACTIVE_USER: win32more.Windows.Win32.Foundation.HRESULT = -1073473481
MSG_CI_MASTER_MERGE_STARTED: win32more.Windows.Win32.Foundation.HRESULT = 1073745926
MSG_CI_MASTER_MERGE_COMPLETED: win32more.Windows.Win32.Foundation.HRESULT = 1073745927
MSG_CI_MASTER_MERGE_ABORTED: win32more.Windows.Win32.Foundation.HRESULT = 1073745928
MSG_CI_MASTER_MERGE_CANT_START: win32more.Windows.Win32.Foundation.HRESULT = -1073737719
MSG_CI_MASTER_MERGE_CANT_RESTART: win32more.Windows.Win32.Foundation.HRESULT = -1073737718
MSG_CI_MASTER_MERGE_RESTARTED: win32more.Windows.Win32.Foundation.HRESULT = 1073745945
MSG_CI_CORRUPT_INDEX_COMPONENT: win32more.Windows.Win32.Foundation.HRESULT = 1073745962
MSG_CI_MASTER_MERGE_ABORTED_LOW_DISK: win32more.Windows.Win32.Foundation.HRESULT = 1073745987
MSG_CI_MASTER_MERGE_REASON_EXTERNAL: win32more.Windows.Win32.Foundation.HRESULT = 1073745988
MSG_CI_MASTER_MERGE_REASON_INDEX_LIMIT: win32more.Windows.Win32.Foundation.HRESULT = 1073745989
MSG_CI_MASTER_MERGE_REASON_EXPECTED_DOCS: win32more.Windows.Win32.Foundation.HRESULT = 1073745990
MSG_CI_MASTER_MERGE_REASON_NUMBER: win32more.Windows.Win32.Foundation.HRESULT = 1073745991
MSG_CI_CREATE_SEVER_ITEM_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147479480
NOT_N_PARSE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = 526638
IDS_MON_DEFAULT_ERROR: win32more.Windows.Win32.Foundation.HRESULT = 264495
IDS_MON_ILLEGAL_PASSTHROUGH: win32more.Windows.Win32.Foundation.HRESULT = 264496
IDS_MON_PARSE_ERR_1_PARAM: win32more.Windows.Win32.Foundation.HRESULT = 264497
IDS_MON_PARSE_ERR_2_PARAM: win32more.Windows.Win32.Foundation.HRESULT = 264498
IDS_MON_SEMI_COLON: win32more.Windows.Win32.Foundation.HRESULT = 264499
IDS_MON_ORDINAL_OUT_OF_RANGE: win32more.Windows.Win32.Foundation.HRESULT = 264500
IDS_MON_VIEW_NOT_DEFINED: win32more.Windows.Win32.Foundation.HRESULT = 264501
IDS_MON_COLUMN_NOT_DEFINED: win32more.Windows.Win32.Foundation.HRESULT = 264502
IDS_MON_BUILTIN_VIEW: win32more.Windows.Win32.Foundation.HRESULT = 264503
IDS_MON_OUT_OF_MEMORY: win32more.Windows.Win32.Foundation.HRESULT = 264504
IDS_MON_SELECT_STAR: win32more.Windows.Win32.Foundation.HRESULT = 264505
IDS_MON_OR_NOT: win32more.Windows.Win32.Foundation.HRESULT = 264506
IDS_MON_CANNOT_CONVERT: win32more.Windows.Win32.Foundation.HRESULT = 264507
IDS_MON_OUT_OF_RANGE: win32more.Windows.Win32.Foundation.HRESULT = 264508
IDS_MON_RELATIVE_INTERVAL: win32more.Windows.Win32.Foundation.HRESULT = 264509
IDS_MON_NOT_COLUMN_OF_VIEW: win32more.Windows.Win32.Foundation.HRESULT = 264510
IDS_MON_BUILTIN_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = 264511
IDS_MON_WEIGHT_OUT_OF_RANGE: win32more.Windows.Win32.Foundation.HRESULT = 264512
IDS_MON_MATCH_STRING: win32more.Windows.Win32.Foundation.HRESULT = 264513
IDS_MON_PROPERTY_NAME_IN_VIEW: win32more.Windows.Win32.Foundation.HRESULT = 264514
IDS_MON_VIEW_ALREADY_DEFINED: win32more.Windows.Win32.Foundation.HRESULT = 264515
IDS_MON_INVALID_CATALOG: win32more.Windows.Win32.Foundation.HRESULT = 264516
IDS_MON_INVALIDSELECT_COALESCE: win32more.Windows.Win32.Foundation.HRESULT = 264517
IDS_MON_CANNOT_CAST: win32more.Windows.Win32.Foundation.HRESULT = 264518
IDS_MON_DATE_OUT_OF_RANGE: win32more.Windows.Win32.Foundation.HRESULT = 264519
IDS_MON_INVALID_IN_GROUP_CLAUSE: win32more.Windows.Win32.Foundation.HRESULT = 264520
DBPROPSET_MSDAORA_ROWSET: Guid = Guid('{e8cc4cbd-fdff-11d0-b865-00a0c9081c1d}')
DBPROPSET_MSDAORA8_ROWSET: Guid = Guid('{7f06a375-dd6a-43db-b4e0-1fc121e5e62b}')
CLSID_MSDASQL: Guid = Guid('{c8b522cb-5cf3-11ce-ade5-00aa0044773d}')
CLSID_MSDASQL_ENUMERATOR: Guid = Guid('{c8b522cd-5cf3-11ce-ade5-00aa0044773d}')
DBPROPSET_PROVIDERDATASOURCEINFO: Guid = Guid('{497c60e0-7123-11cf-b171-00aa0057599e}')
DBPROPSET_PROVIDERROWSET: Guid = Guid('{497c60e1-7123-11cf-b171-00aa0057599e}')
DBPROPSET_PROVIDERDBINIT: Guid = Guid('{497c60e2-7123-11cf-b171-00aa0057599e}')
DBPROPSET_PROVIDERSTMTATTR: Guid = Guid('{497c60e3-7123-11cf-b171-00aa0057599e}')
DBPROPSET_PROVIDERCONNATTR: Guid = Guid('{497c60e4-7123-11cf-b171-00aa0057599e}')
CLSID_DataShapeProvider: Guid = Guid('{3449a1c8-c56c-11d0-ad72-00c04fc29863}')
DBPROPSET_MSDSDBINIT: Guid = Guid('{55cb91a8-5c7a-11d1-adad-00c04fc29863}')
DBPROPSET_MSDSSESSION: Guid = Guid('{edf17536-afbf-11d1-8847-0000f879f98c}')
CLSID_MSPersist: Guid = Guid('{7c07e0d0-4418-11d2-9212-00c04fbbbfb3}')
DBPROPSET_PERSIST: Guid = Guid('{4d7839a0-5b8e-11d1-a6b3-00a0c9138c66}')
PROGID_MSPersist_W: String = 'MSPersist'
PROGID_MSPersist_Version_W: String = 'MSPersist.1'
CLSID_SQLOLEDB: Guid = Guid('{0c7ff16c-38e3-11d0-97ab-00c04fc2ad98}')
CLSID_SQLOLEDB_ERROR: Guid = Guid('{c0932c62-38e5-11d0-97ab-00c04fc2ad98}')
CLSID_SQLOLEDB_ENUMERATOR: Guid = Guid('{dfa22b8e-e68d-11d0-97e4-00c04fc2ad98}')
DBGUID_MSSQLXML: Guid = Guid('{5d531cb2-e6ed-11d2-b252-00c04f681b71}')
DBGUID_XPATH: Guid = Guid('{ec2a4293-e898-11d2-b1b7-00c04f680c56}')
DBSCHEMA_LINKEDSERVERS: Guid = Guid('{9093caf4-2eac-11d1-9809-00c04fc2ad98}')
DBPROPSET_SQLSERVERDATASOURCE: Guid = Guid('{28efaee4-2d2c-11d1-9807-00c04fc2ad98}')
DBPROPSET_SQLSERVERDATASOURCEINFO: Guid = Guid('{df10cb94-35f6-11d2-9c54-00c04f7971d3}')
DBPROPSET_SQLSERVERDBINIT: Guid = Guid('{5cf4ca10-ef21-11d0-97e7-00c04fc2ad98}')
DBPROPSET_SQLSERVERROWSET: Guid = Guid('{5cf4ca11-ef21-11d0-97e7-00c04fc2ad98}')
DBPROPSET_SQLSERVERSESSION: Guid = Guid('{28efaee5-2d2c-11d1-9807-00c04fc2ad98}')
DBPROPSET_SQLSERVERCOLUMN: Guid = Guid('{3b63fb5e-3fbb-11d3-9f29-00c04f8ee9dc}')
DBPROPSET_SQLSERVERSTREAM: Guid = Guid('{9f79c073-8a6d-4bca-a8a8-c9b79a9b962d}')
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLBindCol(StatementHandle: VoidPtr, ColumnNumber: UInt16, TargetType: Int16, TargetValue: VoidPtr, BufferLength: Int64, StrLen_or_Ind: POINTER(Int64)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLBindCol(StatementHandle: VoidPtr, ColumnNumber: UInt16, TargetType: Int16, TargetValue: VoidPtr, BufferLength: Int32, StrLen_or_Ind: POINTER(Int32)) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLBindParam(StatementHandle: VoidPtr, ParameterNumber: UInt16, ValueType: Int16, ParameterType: Int16, LengthPrecision: UInt64, ParameterScale: Int16, ParameterValue: VoidPtr, StrLen_or_Ind: POINTER(Int64)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLBindParam(StatementHandle: VoidPtr, ParameterNumber: UInt16, ValueType: Int16, ParameterType: Int16, LengthPrecision: UInt32, ParameterScale: Int16, ParameterValue: VoidPtr, StrLen_or_Ind: POINTER(Int32)) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLFetchScroll(StatementHandle: VoidPtr, FetchOrientation: Int16, FetchOffset: Int64) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLFetchScroll(StatementHandle: VoidPtr, FetchOrientation: Int16, FetchOffset: Int32) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLGetData(StatementHandle: VoidPtr, ColumnNumber: UInt16, TargetType: Int16, TargetValue: VoidPtr, BufferLength: Int64, StrLen_or_IndPtr: POINTER(Int64)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLGetData(StatementHandle: VoidPtr, ColumnNumber: UInt16, TargetType: Int16, TargetValue: VoidPtr, BufferLength: Int32, StrLen_or_IndPtr: POINTER(Int32)) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLPutData(StatementHandle: VoidPtr, Data: VoidPtr, StrLen_or_Ind: Int64) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLPutData(StatementHandle: VoidPtr, Data: VoidPtr, StrLen_or_Ind: Int32) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLRowCount(StatementHandle: VoidPtr, RowCount: POINTER(Int64)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLRowCount(StatementHandle: VoidPtr, RowCount: POINTER(Int32)) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLSetDescRec(DescriptorHandle: VoidPtr, RecNumber: Int16, Type: Int16, SubType: Int16, Length: Int64, Precision: Int16, Scale: Int16, Data: VoidPtr, StringLength: POINTER(Int64), Indicator: POINTER(Int64)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLSetDescRec(DescriptorHandle: VoidPtr, RecNumber: Int16, Type: Int16, SubType: Int16, Length: Int32, Precision: Int16, Scale: Int16, Data: VoidPtr, StringLength: POINTER(Int32), Indicator: POINTER(Int32)) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLSetParam(StatementHandle: VoidPtr, ParameterNumber: UInt16, ValueType: Int16, ParameterType: Int16, LengthPrecision: UInt64, ParameterScale: Int16, ParameterValue: VoidPtr, StrLen_or_Ind: POINTER(Int64)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLSetParam(StatementHandle: VoidPtr, ParameterNumber: UInt16, ValueType: Int16, ParameterType: Int16, LengthPrecision: UInt32, ParameterScale: Int16, ParameterValue: VoidPtr, StrLen_or_Ind: POINTER(Int32)) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLSetStmtOption(StatementHandle: VoidPtr, Option: UInt16, Value: UInt64) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLSetStmtOption(StatementHandle: VoidPtr, Option: UInt16, Value: UInt32) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLDescribeParam(hstmt: VoidPtr, ipar: UInt16, pfSqlType: POINTER(Int16), pcbParamDef: POINTER(UInt64), pibScale: POINTER(Int16), pfNullable: POINTER(Int16)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLDescribeParam(hstmt: VoidPtr, ipar: UInt16, pfSqlType: POINTER(Int16), pcbParamDef: POINTER(UInt32), pibScale: POINTER(Int16), pfNullable: POINTER(Int16)) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLExtendedFetch(hstmt: VoidPtr, fFetchType: UInt16, irow: Int64, pcrow: POINTER(UInt64), rgfRowStatus: POINTER(UInt16)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLExtendedFetch(hstmt: VoidPtr, fFetchType: UInt16, irow: Int32, pcrow: POINTER(UInt32), rgfRowStatus: POINTER(UInt16)) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLParamOptions(hstmt: VoidPtr, crow: UInt64, pirow: POINTER(UInt64)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLParamOptions(hstmt: VoidPtr, crow: UInt32, pirow: POINTER(UInt32)) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLSetPos(hstmt: VoidPtr, irow: UInt64, fOption: UInt16, fLock: UInt16) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLSetPos(hstmt: VoidPtr, irow: UInt16, fOption: UInt16, fLock: UInt16) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLBindParameter(hstmt: VoidPtr, ipar: UInt16, fParamType: Int16, fCType: Int16, fSqlType: Int16, cbColDef: UInt64, ibScale: Int16, rgbValue: VoidPtr, cbValueMax: Int64, pcbValue: POINTER(Int64)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLBindParameter(hstmt: VoidPtr, ipar: UInt16, fParamType: Int16, fCType: Int16, fSqlType: Int16, cbColDef: UInt32, ibScale: Int16, rgbValue: VoidPtr, cbValueMax: Int32, pcbValue: POINTER(Int32)) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLSetScrollOptions(hstmt: VoidPtr, fConcurrency: UInt16, crowKeyset: Int64, crowRowset: UInt16) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLSetScrollOptions(hstmt: VoidPtr, fConcurrency: UInt16, crowKeyset: Int32, crowRowset: UInt16) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLColAttributeW(hstmt: VoidPtr, iCol: UInt16, iField: UInt16, pCharAttr: VoidPtr, cbDescMax: Int16, pcbCharAttr: POINTER(Int16), pNumAttr: POINTER(Int64)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLColAttributeW(hstmt: VoidPtr, iCol: UInt16, iField: UInt16, pCharAttr: VoidPtr, cbDescMax: Int16, pcbCharAttr: POINTER(Int16), pNumAttr: VoidPtr) -> Int16: ...
if ARCH in 'X64,ARM64':
    SQLColAttribute = UnicodeAlias('SQLColAttributeW')
elif ARCH in 'X86':
    SQLColAttribute = UnicodeAlias('SQLColAttributeW')
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLColAttributesW(hstmt: VoidPtr, icol: UInt16, fDescType: UInt16, rgbDesc: VoidPtr, cbDescMax: Int16, pcbDesc: POINTER(Int16), pfDesc: POINTER(Int64)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLColAttributesW(hstmt: VoidPtr, icol: UInt16, fDescType: UInt16, rgbDesc: VoidPtr, cbDescMax: Int16, pcbDesc: POINTER(Int16), pfDesc: POINTER(Int32)) -> Int16: ...
if ARCH in 'X64,ARM64':
    SQLColAttributes = UnicodeAlias('SQLColAttributesW')
elif ARCH in 'X86':
    SQLColAttributes = UnicodeAlias('SQLColAttributesW')
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLDescribeColW(hstmt: VoidPtr, icol: UInt16, szColName: POINTER(UInt16), cchColNameMax: Int16, pcchColName: POINTER(Int16), pfSqlType: POINTER(Int16), pcbColDef: POINTER(UInt64), pibScale: POINTER(Int16), pfNullable: POINTER(Int16)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLDescribeColW(hstmt: VoidPtr, icol: UInt16, szColName: POINTER(UInt16), cchColNameMax: Int16, pcchColName: POINTER(Int16), pfSqlType: POINTER(Int16), pcbColDef: POINTER(UInt32), pibScale: POINTER(Int16), pfNullable: POINTER(Int16)) -> Int16: ...
if ARCH in 'X64,ARM64':
    SQLDescribeCol = UnicodeAlias('SQLDescribeColW')
elif ARCH in 'X86':
    SQLDescribeCol = UnicodeAlias('SQLDescribeColW')
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLGetDescRecW(hdesc: VoidPtr, iRecord: Int16, szName: POINTER(UInt16), cchNameMax: Int16, pcchName: POINTER(Int16), pfType: POINTER(Int16), pfSubType: POINTER(Int16), pLength: POINTER(Int64), pPrecision: POINTER(Int16), pScale: POINTER(Int16), pNullable: POINTER(Int16)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLGetDescRecW(hdesc: VoidPtr, iRecord: Int16, szName: POINTER(UInt16), cchNameMax: Int16, pcchName: POINTER(Int16), pfType: POINTER(Int16), pfSubType: POINTER(Int16), pLength: POINTER(Int32), pPrecision: POINTER(Int16), pScale: POINTER(Int16), pNullable: POINTER(Int16)) -> Int16: ...
if ARCH in 'X64,ARM64':
    SQLGetDescRec = UnicodeAlias('SQLGetDescRecW')
elif ARCH in 'X86':
    SQLGetDescRec = UnicodeAlias('SQLGetDescRecW')
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLSetConnectOptionW(hdbc: VoidPtr, fOption: UInt16, vParam: UInt64) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLSetConnectOptionW(hdbc: VoidPtr, fOption: UInt16, vParam: UInt32) -> Int16: ...
if ARCH in 'X64,ARM64':
    SQLSetConnectOption = UnicodeAlias('SQLSetConnectOptionW')
elif ARCH in 'X86':
    SQLSetConnectOption = UnicodeAlias('SQLSetConnectOptionW')
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLColAttributeA(hstmt: VoidPtr, iCol: Int16, iField: Int16, pCharAttr: VoidPtr, cbCharAttrMax: Int16, pcbCharAttr: POINTER(Int16), pNumAttr: POINTER(Int64)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLColAttributeA(hstmt: VoidPtr, iCol: Int16, iField: Int16, pCharAttr: VoidPtr, cbCharAttrMax: Int16, pcbCharAttr: POINTER(Int16), pNumAttr: VoidPtr) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLColAttributesA(hstmt: VoidPtr, icol: UInt16, fDescType: UInt16, rgbDesc: VoidPtr, cbDescMax: Int16, pcbDesc: POINTER(Int16), pfDesc: POINTER(Int64)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLColAttributesA(hstmt: VoidPtr, icol: UInt16, fDescType: UInt16, rgbDesc: VoidPtr, cbDescMax: Int16, pcbDesc: POINTER(Int16), pfDesc: POINTER(Int32)) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLDescribeColA(hstmt: VoidPtr, icol: UInt16, szColName: POINTER(Byte), cbColNameMax: Int16, pcbColName: POINTER(Int16), pfSqlType: POINTER(Int16), pcbColDef: POINTER(UInt64), pibScale: POINTER(Int16), pfNullable: POINTER(Int16)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLDescribeColA(hstmt: VoidPtr, icol: UInt16, szColName: POINTER(Byte), cbColNameMax: Int16, pcbColName: POINTER(Int16), pfSqlType: POINTER(Int16), pcbColDef: POINTER(UInt32), pibScale: POINTER(Int16), pfNullable: POINTER(Int16)) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLGetDescRecA(hdesc: VoidPtr, iRecord: Int16, szName: POINTER(Byte), cbNameMax: Int16, pcbName: POINTER(Int16), pfType: POINTER(Int16), pfSubType: POINTER(Int16), pLength: POINTER(Int64), pPrecision: POINTER(Int16), pScale: POINTER(Int16), pNullable: POINTER(Int16)) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLGetDescRecA(hdesc: VoidPtr, iRecord: Int16, szName: POINTER(Byte), cbNameMax: Int16, pcbName: POINTER(Int16), pfType: POINTER(Int16), pfSubType: POINTER(Int16), pLength: POINTER(Int32), pPrecision: POINTER(Int16), pScale: POINTER(Int16), pNullable: POINTER(Int16)) -> Int16: ...
if ARCH in 'X64,ARM64':
    @winfunctype('ODBC32.dll')
    def SQLSetConnectOptionA(hdbc: VoidPtr, fOption: UInt16, vParam: UInt64) -> Int16: ...
elif ARCH in 'X86':
    @winfunctype('ODBC32.dll')
    def SQLSetConnectOptionA(hdbc: VoidPtr, fOption: UInt16, vParam: UInt32) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLAllocConnect(EnvironmentHandle: VoidPtr, ConnectionHandle: POINTER(VoidPtr)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLAllocEnv(EnvironmentHandle: POINTER(VoidPtr)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLAllocHandle(HandleType: Int16, InputHandle: VoidPtr, OutputHandle: POINTER(VoidPtr)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLAllocStmt(ConnectionHandle: VoidPtr, StatementHandle: POINTER(VoidPtr)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLCancel(StatementHandle: VoidPtr) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLCancelHandle(HandleType: Int16, InputHandle: VoidPtr) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLCloseCursor(StatementHandle: VoidPtr) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLCompleteAsync(HandleType: Int16, Handle: VoidPtr, AsyncRetCodePtr: POINTER(Int16)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLCopyDesc(SourceDescHandle: VoidPtr, TargetDescHandle: VoidPtr) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLDisconnect(ConnectionHandle: VoidPtr) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLEndTran(HandleType: Int16, Handle: VoidPtr, CompletionType: Int16) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLExecute(StatementHandle: VoidPtr) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLFetch(StatementHandle: VoidPtr) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLFreeConnect(ConnectionHandle: VoidPtr) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLFreeEnv(EnvironmentHandle: VoidPtr) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLFreeHandle(HandleType: Int16, Handle: VoidPtr) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLFreeStmt(StatementHandle: VoidPtr, Option: UInt16) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLGetEnvAttr(EnvironmentHandle: VoidPtr, Attribute: Int32, Value: VoidPtr, BufferLength: Int32, StringLength: POINTER(Int32)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLGetFunctions(ConnectionHandle: VoidPtr, FunctionId: UInt16, Supported: POINTER(UInt16)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLGetStmtOption(StatementHandle: VoidPtr, Option: UInt16, Value: VoidPtr) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLNumResultCols(StatementHandle: VoidPtr, ColumnCount: POINTER(Int16)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLParamData(StatementHandle: VoidPtr, Value: POINTER(VoidPtr)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLSetEnvAttr(EnvironmentHandle: VoidPtr, Attribute: Int32, Value: VoidPtr, StringLength: Int32) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLTransact(EnvironmentHandle: VoidPtr, ConnectionHandle: VoidPtr, CompletionType: UInt16) -> Int16: ...
@winfunctype('odbcbcp.dll')
def bcp_batch(param0: VoidPtr) -> Int32: ...
@winfunctype('odbcbcp.dll')
def bcp_bind(param0: VoidPtr, param1: POINTER(Byte), param2: Int32, param3: Int32, param4: POINTER(Byte), param5: Int32, param6: Int32, param7: Int32) -> Int16: ...
@winfunctype('odbcbcp.dll')
def bcp_colfmt(param0: VoidPtr, param1: Int32, param2: Byte, param3: Int32, param4: Int32, param5: POINTER(Byte), param6: Int32, param7: Int32) -> Int16: ...
@winfunctype('odbcbcp.dll')
def bcp_collen(param0: VoidPtr, param1: Int32, param2: Int32) -> Int16: ...
@winfunctype('odbcbcp.dll')
def bcp_colptr(param0: VoidPtr, param1: POINTER(Byte), param2: Int32) -> Int16: ...
@winfunctype('odbcbcp.dll')
def bcp_columns(param0: VoidPtr, param1: Int32) -> Int16: ...
@winfunctype('odbcbcp.dll')
def bcp_control(param0: VoidPtr, param1: Int32, param2: VoidPtr) -> Int16: ...
@winfunctype('odbcbcp.dll')
def bcp_done(param0: VoidPtr) -> Int32: ...
@winfunctype('odbcbcp.dll')
def bcp_exec(param0: VoidPtr, param1: POINTER(Int32)) -> Int16: ...
@winfunctype('odbcbcp.dll')
def bcp_getcolfmt(param0: VoidPtr, param1: Int32, param2: Int32, param3: VoidPtr, param4: Int32, param5: POINTER(Int32)) -> Int16: ...
@winfunctype('odbcbcp.dll')
def bcp_initA(param0: VoidPtr, param1: win32more.Windows.Win32.Foundation.PSTR, param2: win32more.Windows.Win32.Foundation.PSTR, param3: win32more.Windows.Win32.Foundation.PSTR, param4: Int32) -> Int16: ...
@winfunctype('odbcbcp.dll')
def bcp_initW(param0: VoidPtr, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: win32more.Windows.Win32.Foundation.PWSTR, param3: win32more.Windows.Win32.Foundation.PWSTR, param4: Int32) -> Int16: ...
bcp_init = UnicodeAlias('bcp_initW')
@winfunctype('odbcbcp.dll')
def bcp_moretext(param0: VoidPtr, param1: Int32, param2: POINTER(Byte)) -> Int16: ...
@winfunctype('odbcbcp.dll')
def bcp_readfmtA(param0: VoidPtr, param1: win32more.Windows.Win32.Foundation.PSTR) -> Int16: ...
@winfunctype('odbcbcp.dll')
def bcp_readfmtW(param0: VoidPtr, param1: win32more.Windows.Win32.Foundation.PWSTR) -> Int16: ...
bcp_readfmt = UnicodeAlias('bcp_readfmtW')
@winfunctype('odbcbcp.dll')
def bcp_sendrow(param0: VoidPtr) -> Int16: ...
@winfunctype('odbcbcp.dll')
def bcp_setcolfmt(param0: VoidPtr, param1: Int32, param2: Int32, param3: VoidPtr, param4: Int32) -> Int16: ...
@winfunctype('odbcbcp.dll')
def bcp_writefmtA(param0: VoidPtr, param1: win32more.Windows.Win32.Foundation.PSTR) -> Int16: ...
@winfunctype('odbcbcp.dll')
def bcp_writefmtW(param0: VoidPtr, param1: win32more.Windows.Win32.Foundation.PWSTR) -> Int16: ...
bcp_writefmt = UnicodeAlias('bcp_writefmtW')
@winfunctype('odbcbcp.dll')
def dbprtypeA(param0: Int32) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('odbcbcp.dll')
def dbprtypeW(param0: Int32) -> win32more.Windows.Win32.Foundation.PWSTR: ...
dbprtype = UnicodeAlias('dbprtypeW')
@winfunctype('odbcbcp.dll')
def SQLLinkedServers(param0: VoidPtr) -> Int16: ...
@winfunctype('odbcbcp.dll')
def SQLLinkedCatalogsA(param0: VoidPtr, param1: win32more.Windows.Win32.Foundation.PSTR, param2: Int16) -> Int16: ...
@winfunctype('odbcbcp.dll')
def SQLLinkedCatalogsW(param0: VoidPtr, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: Int16) -> Int16: ...
SQLLinkedCatalogs = UnicodeAlias('SQLLinkedCatalogsW')
@winfunctype('odbcbcp.dll')
def SQLInitEnumServers(pwchServerName: win32more.Windows.Win32.Foundation.PWSTR, pwchInstanceName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('odbcbcp.dll')
def SQLGetNextEnumeration(hEnumHandle: win32more.Windows.Win32.Foundation.HANDLE, prgEnumData: POINTER(Byte), piEnumLength: POINTER(Int32)) -> Int16: ...
@winfunctype('odbcbcp.dll')
def SQLCloseEnumServers(hEnumHandle: win32more.Windows.Win32.Foundation.HANDLE) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLBulkOperations(StatementHandle: VoidPtr, Operation: Int16) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLMoreResults(hstmt: VoidPtr) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLNumParams(hstmt: VoidPtr, pcpar: POINTER(Int16)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLAllocHandleStd(fHandleType: Int16, hInput: VoidPtr, phOutput: POINTER(VoidPtr)) -> Int16: ...
@winfunctype('ODBC32.dll')
def ODBCSetTryWaitValue(dwValue: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ODBC32.dll')
def ODBCGetTryWaitValue() -> UInt32: ...
@winfunctype('ODBC32.dll')
def SQLConnectW(hdbc: VoidPtr, szDSN: POINTER(UInt16), cchDSN: Int16, szUID: POINTER(UInt16), cchUID: Int16, szAuthStr: POINTER(UInt16), cchAuthStr: Int16) -> Int16: ...
SQLConnect = UnicodeAlias('SQLConnectW')
@winfunctype('ODBC32.dll')
def SQLErrorW(henv: VoidPtr, hdbc: VoidPtr, hstmt: VoidPtr, wszSqlState: POINTER(UInt16), pfNativeError: POINTER(Int32), wszErrorMsg: POINTER(UInt16), cchErrorMsgMax: Int16, pcchErrorMsg: POINTER(Int16)) -> Int16: ...
SQLError = UnicodeAlias('SQLErrorW')
@winfunctype('ODBC32.dll')
def SQLExecDirectW(hstmt: VoidPtr, szSqlStr: POINTER(UInt16), TextLength: Int32) -> Int16: ...
SQLExecDirect = UnicodeAlias('SQLExecDirectW')
@winfunctype('ODBC32.dll')
def SQLGetConnectAttrW(hdbc: VoidPtr, fAttribute: Int32, rgbValue: VoidPtr, cbValueMax: Int32, pcbValue: POINTER(Int32)) -> Int16: ...
SQLGetConnectAttr = UnicodeAlias('SQLGetConnectAttrW')
@winfunctype('ODBC32.dll')
def SQLGetCursorNameW(hstmt: VoidPtr, szCursor: POINTER(UInt16), cchCursorMax: Int16, pcchCursor: POINTER(Int16)) -> Int16: ...
SQLGetCursorName = UnicodeAlias('SQLGetCursorNameW')
@winfunctype('ODBC32.dll')
def SQLSetDescFieldW(DescriptorHandle: VoidPtr, RecNumber: Int16, FieldIdentifier: Int16, Value: VoidPtr, BufferLength: Int32) -> Int16: ...
SQLSetDescField = UnicodeAlias('SQLSetDescFieldW')
@winfunctype('ODBC32.dll')
def SQLGetDescFieldW(hdesc: VoidPtr, iRecord: Int16, iField: Int16, rgbValue: VoidPtr, cbBufferLength: Int32, StringLength: POINTER(Int32)) -> Int16: ...
SQLGetDescField = UnicodeAlias('SQLGetDescFieldW')
@winfunctype('ODBC32.dll')
def SQLGetDiagFieldW(fHandleType: Int16, handle: VoidPtr, iRecord: Int16, fDiagField: Int16, rgbDiagInfo: VoidPtr, cbBufferLength: Int16, pcbStringLength: POINTER(Int16)) -> Int16: ...
SQLGetDiagField = UnicodeAlias('SQLGetDiagFieldW')
@winfunctype('ODBC32.dll')
def SQLGetDiagRecW(fHandleType: Int16, handle: VoidPtr, iRecord: Int16, szSqlState: POINTER(UInt16), pfNativeError: POINTER(Int32), szErrorMsg: POINTER(UInt16), cchErrorMsgMax: Int16, pcchErrorMsg: POINTER(Int16)) -> Int16: ...
SQLGetDiagRec = UnicodeAlias('SQLGetDiagRecW')
@winfunctype('ODBC32.dll')
def SQLPrepareW(hstmt: VoidPtr, szSqlStr: POINTER(UInt16), cchSqlStr: Int32) -> Int16: ...
SQLPrepare = UnicodeAlias('SQLPrepareW')
@winfunctype('ODBC32.dll')
def SQLSetConnectAttrW(hdbc: VoidPtr, fAttribute: Int32, rgbValue: VoidPtr, cbValue: Int32) -> Int16: ...
SQLSetConnectAttr = UnicodeAlias('SQLSetConnectAttrW')
@winfunctype('ODBC32.dll')
def SQLSetCursorNameW(hstmt: VoidPtr, szCursor: POINTER(UInt16), cchCursor: Int16) -> Int16: ...
SQLSetCursorName = UnicodeAlias('SQLSetCursorNameW')
@winfunctype('ODBC32.dll')
def SQLColumnsW(hstmt: VoidPtr, szCatalogName: POINTER(UInt16), cchCatalogName: Int16, szSchemaName: POINTER(UInt16), cchSchemaName: Int16, szTableName: POINTER(UInt16), cchTableName: Int16, szColumnName: POINTER(UInt16), cchColumnName: Int16) -> Int16: ...
SQLColumns = UnicodeAlias('SQLColumnsW')
@winfunctype('ODBC32.dll')
def SQLGetConnectOptionW(hdbc: VoidPtr, fOption: UInt16, pvParam: VoidPtr) -> Int16: ...
SQLGetConnectOption = UnicodeAlias('SQLGetConnectOptionW')
@winfunctype('ODBC32.dll')
def SQLGetInfoW(hdbc: VoidPtr, fInfoType: UInt16, rgbInfoValue: VoidPtr, cbInfoValueMax: Int16, pcbInfoValue: POINTER(Int16)) -> Int16: ...
SQLGetInfo = UnicodeAlias('SQLGetInfoW')
@winfunctype('ODBC32.dll')
def SQLGetTypeInfoW(StatementHandle: VoidPtr, DataType: Int16) -> Int16: ...
SQLGetTypeInfo = UnicodeAlias('SQLGetTypeInfoW')
@winfunctype('ODBC32.dll')
def SQLSpecialColumnsW(hstmt: VoidPtr, fColType: UInt16, szCatalogName: POINTER(UInt16), cchCatalogName: Int16, szSchemaName: POINTER(UInt16), cchSchemaName: Int16, szTableName: POINTER(UInt16), cchTableName: Int16, fScope: UInt16, fNullable: UInt16) -> Int16: ...
SQLSpecialColumns = UnicodeAlias('SQLSpecialColumnsW')
@winfunctype('ODBC32.dll')
def SQLStatisticsW(hstmt: VoidPtr, szCatalogName: POINTER(UInt16), cchCatalogName: Int16, szSchemaName: POINTER(UInt16), cchSchemaName: Int16, szTableName: POINTER(UInt16), cchTableName: Int16, fUnique: UInt16, fAccuracy: UInt16) -> Int16: ...
SQLStatistics = UnicodeAlias('SQLStatisticsW')
@winfunctype('ODBC32.dll')
def SQLTablesW(hstmt: VoidPtr, szCatalogName: POINTER(UInt16), cchCatalogName: Int16, szSchemaName: POINTER(UInt16), cchSchemaName: Int16, szTableName: POINTER(UInt16), cchTableName: Int16, szTableType: POINTER(UInt16), cchTableType: Int16) -> Int16: ...
SQLTables = UnicodeAlias('SQLTablesW')
@winfunctype('ODBC32.dll')
def SQLDataSourcesW(henv: VoidPtr, fDirection: UInt16, szDSN: POINTER(UInt16), cchDSNMax: Int16, pcchDSN: POINTER(Int16), wszDescription: POINTER(UInt16), cchDescriptionMax: Int16, pcchDescription: POINTER(Int16)) -> Int16: ...
SQLDataSources = UnicodeAlias('SQLDataSourcesW')
@winfunctype('ODBC32.dll')
def SQLDriverConnectW(hdbc: VoidPtr, hwnd: IntPtr, szConnStrIn: POINTER(UInt16), cchConnStrIn: Int16, szConnStrOut: POINTER(UInt16), cchConnStrOutMax: Int16, pcchConnStrOut: POINTER(Int16), fDriverCompletion: UInt16) -> Int16: ...
SQLDriverConnect = UnicodeAlias('SQLDriverConnectW')
@winfunctype('ODBC32.dll')
def SQLBrowseConnectW(hdbc: VoidPtr, szConnStrIn: POINTER(UInt16), cchConnStrIn: Int16, szConnStrOut: POINTER(UInt16), cchConnStrOutMax: Int16, pcchConnStrOut: POINTER(Int16)) -> Int16: ...
SQLBrowseConnect = UnicodeAlias('SQLBrowseConnectW')
@winfunctype('ODBC32.dll')
def SQLColumnPrivilegesW(hstmt: VoidPtr, szCatalogName: POINTER(UInt16), cchCatalogName: Int16, szSchemaName: POINTER(UInt16), cchSchemaName: Int16, szTableName: POINTER(UInt16), cchTableName: Int16, szColumnName: POINTER(UInt16), cchColumnName: Int16) -> Int16: ...
SQLColumnPrivileges = UnicodeAlias('SQLColumnPrivilegesW')
@winfunctype('ODBC32.dll')
def SQLGetStmtAttrW(hstmt: VoidPtr, fAttribute: Int32, rgbValue: VoidPtr, cbValueMax: Int32, pcbValue: POINTER(Int32)) -> Int16: ...
SQLGetStmtAttr = UnicodeAlias('SQLGetStmtAttrW')
@winfunctype('ODBC32.dll')
def SQLSetStmtAttrW(hstmt: VoidPtr, fAttribute: Int32, rgbValue: VoidPtr, cbValueMax: Int32) -> Int16: ...
SQLSetStmtAttr = UnicodeAlias('SQLSetStmtAttrW')
@winfunctype('ODBC32.dll')
def SQLForeignKeysW(hstmt: VoidPtr, szPkCatalogName: POINTER(UInt16), cchPkCatalogName: Int16, szPkSchemaName: POINTER(UInt16), cchPkSchemaName: Int16, szPkTableName: POINTER(UInt16), cchPkTableName: Int16, szFkCatalogName: POINTER(UInt16), cchFkCatalogName: Int16, szFkSchemaName: POINTER(UInt16), cchFkSchemaName: Int16, szFkTableName: POINTER(UInt16), cchFkTableName: Int16) -> Int16: ...
SQLForeignKeys = UnicodeAlias('SQLForeignKeysW')
@winfunctype('ODBC32.dll')
def SQLNativeSqlW(hdbc: VoidPtr, szSqlStrIn: POINTER(UInt16), cchSqlStrIn: Int32, szSqlStr: POINTER(UInt16), cchSqlStrMax: Int32, pcchSqlStr: POINTER(Int32)) -> Int16: ...
SQLNativeSql = UnicodeAlias('SQLNativeSqlW')
@winfunctype('ODBC32.dll')
def SQLPrimaryKeysW(hstmt: VoidPtr, szCatalogName: POINTER(UInt16), cchCatalogName: Int16, szSchemaName: POINTER(UInt16), cchSchemaName: Int16, szTableName: POINTER(UInt16), cchTableName: Int16) -> Int16: ...
SQLPrimaryKeys = UnicodeAlias('SQLPrimaryKeysW')
@winfunctype('ODBC32.dll')
def SQLProcedureColumnsW(hstmt: VoidPtr, szCatalogName: POINTER(UInt16), cchCatalogName: Int16, szSchemaName: POINTER(UInt16), cchSchemaName: Int16, szProcName: POINTER(UInt16), cchProcName: Int16, szColumnName: POINTER(UInt16), cchColumnName: Int16) -> Int16: ...
SQLProcedureColumns = UnicodeAlias('SQLProcedureColumnsW')
@winfunctype('ODBC32.dll')
def SQLProceduresW(hstmt: VoidPtr, szCatalogName: POINTER(UInt16), cchCatalogName: Int16, szSchemaName: POINTER(UInt16), cchSchemaName: Int16, szProcName: POINTER(UInt16), cchProcName: Int16) -> Int16: ...
SQLProcedures = UnicodeAlias('SQLProceduresW')
@winfunctype('ODBC32.dll')
def SQLTablePrivilegesW(hstmt: VoidPtr, szCatalogName: POINTER(UInt16), cchCatalogName: Int16, szSchemaName: POINTER(UInt16), cchSchemaName: Int16, szTableName: POINTER(UInt16), cchTableName: Int16) -> Int16: ...
SQLTablePrivileges = UnicodeAlias('SQLTablePrivilegesW')
@winfunctype('ODBC32.dll')
def SQLDriversW(henv: VoidPtr, fDirection: UInt16, szDriverDesc: POINTER(UInt16), cchDriverDescMax: Int16, pcchDriverDesc: POINTER(Int16), szDriverAttributes: POINTER(UInt16), cchDrvrAttrMax: Int16, pcchDrvrAttr: POINTER(Int16)) -> Int16: ...
SQLDrivers = UnicodeAlias('SQLDriversW')
@winfunctype('ODBC32.dll')
def SQLConnectA(hdbc: VoidPtr, szDSN: POINTER(Byte), cbDSN: Int16, szUID: POINTER(Byte), cbUID: Int16, szAuthStr: POINTER(Byte), cbAuthStr: Int16) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLErrorA(henv: VoidPtr, hdbc: VoidPtr, hstmt: VoidPtr, szSqlState: POINTER(Byte), pfNativeError: POINTER(Int32), szErrorMsg: POINTER(Byte), cbErrorMsgMax: Int16, pcbErrorMsg: POINTER(Int16)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLExecDirectA(hstmt: VoidPtr, szSqlStr: POINTER(Byte), cbSqlStr: Int32) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLGetConnectAttrA(hdbc: VoidPtr, fAttribute: Int32, rgbValue: VoidPtr, cbValueMax: Int32, pcbValue: POINTER(Int32)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLGetCursorNameA(hstmt: VoidPtr, szCursor: POINTER(Byte), cbCursorMax: Int16, pcbCursor: POINTER(Int16)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLGetDescFieldA(hdesc: VoidPtr, iRecord: Int16, iField: Int16, rgbValue: VoidPtr, cbBufferLength: Int32, StringLength: POINTER(Int32)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLGetDiagFieldA(fHandleType: Int16, handle: VoidPtr, iRecord: Int16, fDiagField: Int16, rgbDiagInfo: VoidPtr, cbDiagInfoMax: Int16, pcbDiagInfo: POINTER(Int16)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLGetDiagRecA(fHandleType: Int16, handle: VoidPtr, iRecord: Int16, szSqlState: POINTER(Byte), pfNativeError: POINTER(Int32), szErrorMsg: POINTER(Byte), cbErrorMsgMax: Int16, pcbErrorMsg: POINTER(Int16)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLGetStmtAttrA(hstmt: VoidPtr, fAttribute: Int32, rgbValue: VoidPtr, cbValueMax: Int32, pcbValue: POINTER(Int32)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLGetTypeInfoA(StatementHandle: VoidPtr, DataType: Int16) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLPrepareA(hstmt: VoidPtr, szSqlStr: POINTER(Byte), cbSqlStr: Int32) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLSetConnectAttrA(hdbc: VoidPtr, fAttribute: Int32, rgbValue: VoidPtr, cbValue: Int32) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLSetCursorNameA(hstmt: VoidPtr, szCursor: POINTER(Byte), cbCursor: Int16) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLColumnsA(hstmt: VoidPtr, szCatalogName: POINTER(Byte), cbCatalogName: Int16, szSchemaName: POINTER(Byte), cbSchemaName: Int16, szTableName: POINTER(Byte), cbTableName: Int16, szColumnName: POINTER(Byte), cbColumnName: Int16) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLGetConnectOptionA(hdbc: VoidPtr, fOption: UInt16, pvParam: VoidPtr) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLGetInfoA(hdbc: VoidPtr, fInfoType: UInt16, rgbInfoValue: VoidPtr, cbInfoValueMax: Int16, pcbInfoValue: POINTER(Int16)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLSpecialColumnsA(hstmt: VoidPtr, fColType: UInt16, szCatalogName: POINTER(Byte), cbCatalogName: Int16, szSchemaName: POINTER(Byte), cbSchemaName: Int16, szTableName: POINTER(Byte), cbTableName: Int16, fScope: UInt16, fNullable: UInt16) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLStatisticsA(hstmt: VoidPtr, szCatalogName: POINTER(Byte), cbCatalogName: Int16, szSchemaName: POINTER(Byte), cbSchemaName: Int16, szTableName: POINTER(Byte), cbTableName: Int16, fUnique: UInt16, fAccuracy: UInt16) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLTablesA(hstmt: VoidPtr, szCatalogName: POINTER(Byte), cbCatalogName: Int16, szSchemaName: POINTER(Byte), cbSchemaName: Int16, szTableName: POINTER(Byte), cbTableName: Int16, szTableType: POINTER(Byte), cbTableType: Int16) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLDataSourcesA(henv: VoidPtr, fDirection: UInt16, szDSN: POINTER(Byte), cbDSNMax: Int16, pcbDSN: POINTER(Int16), szDescription: POINTER(Byte), cbDescriptionMax: Int16, pcbDescription: POINTER(Int16)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLDriverConnectA(hdbc: VoidPtr, hwnd: IntPtr, szConnStrIn: POINTER(Byte), cbConnStrIn: Int16, szConnStrOut: POINTER(Byte), cbConnStrOutMax: Int16, pcbConnStrOut: POINTER(Int16), fDriverCompletion: UInt16) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLBrowseConnectA(hdbc: VoidPtr, szConnStrIn: POINTER(Byte), cbConnStrIn: Int16, szConnStrOut: POINTER(Byte), cbConnStrOutMax: Int16, pcbConnStrOut: POINTER(Int16)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLColumnPrivilegesA(hstmt: VoidPtr, szCatalogName: POINTER(Byte), cbCatalogName: Int16, szSchemaName: POINTER(Byte), cbSchemaName: Int16, szTableName: POINTER(Byte), cbTableName: Int16, szColumnName: POINTER(Byte), cbColumnName: Int16) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLForeignKeysA(hstmt: VoidPtr, szPkCatalogName: POINTER(Byte), cbPkCatalogName: Int16, szPkSchemaName: POINTER(Byte), cbPkSchemaName: Int16, szPkTableName: POINTER(Byte), cbPkTableName: Int16, szFkCatalogName: POINTER(Byte), cbFkCatalogName: Int16, szFkSchemaName: POINTER(Byte), cbFkSchemaName: Int16, szFkTableName: POINTER(Byte), cbFkTableName: Int16) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLNativeSqlA(hdbc: VoidPtr, szSqlStrIn: POINTER(Byte), cbSqlStrIn: Int32, szSqlStr: POINTER(Byte), cbSqlStrMax: Int32, pcbSqlStr: POINTER(Int32)) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLPrimaryKeysA(hstmt: VoidPtr, szCatalogName: POINTER(Byte), cbCatalogName: Int16, szSchemaName: POINTER(Byte), cbSchemaName: Int16, szTableName: POINTER(Byte), cbTableName: Int16) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLProcedureColumnsA(hstmt: VoidPtr, szCatalogName: POINTER(Byte), cbCatalogName: Int16, szSchemaName: POINTER(Byte), cbSchemaName: Int16, szProcName: POINTER(Byte), cbProcName: Int16, szColumnName: POINTER(Byte), cbColumnName: Int16) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLProceduresA(hstmt: VoidPtr, szCatalogName: POINTER(Byte), cbCatalogName: Int16, szSchemaName: POINTER(Byte), cbSchemaName: Int16, szProcName: POINTER(Byte), cbProcName: Int16) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLTablePrivilegesA(hstmt: VoidPtr, szCatalogName: POINTER(Byte), cbCatalogName: Int16, szSchemaName: POINTER(Byte), cbSchemaName: Int16, szTableName: POINTER(Byte), cbTableName: Int16) -> Int16: ...
@winfunctype('ODBC32.dll')
def SQLDriversA(henv: VoidPtr, fDirection: UInt16, szDriverDesc: POINTER(Byte), cbDriverDescMax: Int16, pcbDriverDesc: POINTER(Int16), szDriverAttributes: POINTER(Byte), cbDrvrAttrMax: Int16, pcbDrvrAttr: POINTER(Int16)) -> Int16: ...
class BUCKETCATEGORIZE(Structure):
    cBuckets: UInt32
    Distribution: UInt32
CASE_REQUIREMENT = Int32
CASE_REQUIREMENT_ANY: win32more.Windows.Win32.System.Search.CASE_REQUIREMENT = 0
CASE_REQUIREMENT_UPPER_IF_AQS: win32more.Windows.Win32.System.Search.CASE_REQUIREMENT = 1
class CATEGORIZATION(Structure):
    ulCatType: UInt32
    Anonymous: _Anonymous_e__Union
    csColumns: win32more.Windows.Win32.System.Search.COLUMNSET
    class _Anonymous_e__Union(Union):
        cClusters: UInt32
        bucket: win32more.Windows.Win32.System.Search.BUCKETCATEGORIZE
        range: win32more.Windows.Win32.System.Search.RANGECATEGORIZE
class CATEGORIZATIONSET(Structure):
    cCat: UInt32
    aCat: POINTER(win32more.Windows.Win32.System.Search.CATEGORIZATION)
CHANNEL_AGENT_FLAGS = Int32
CHANNEL_AGENT_DYNAMIC_SCHEDULE: win32more.Windows.Win32.System.Search.CHANNEL_AGENT_FLAGS = 1
CHANNEL_AGENT_PRECACHE_SOME: win32more.Windows.Win32.System.Search.CHANNEL_AGENT_FLAGS = 2
CHANNEL_AGENT_PRECACHE_ALL: win32more.Windows.Win32.System.Search.CHANNEL_AGENT_FLAGS = 4
CHANNEL_AGENT_PRECACHE_SCRNSAVER: win32more.Windows.Win32.System.Search.CHANNEL_AGENT_FLAGS = 8
CLUSION_REASON = Int32
CLUSIONREASON_UNKNOWNSCOPE: win32more.Windows.Win32.System.Search.CLUSION_REASON = 0
CLUSIONREASON_DEFAULT: win32more.Windows.Win32.System.Search.CLUSION_REASON = 1
CLUSIONREASON_USER: win32more.Windows.Win32.System.Search.CLUSION_REASON = 2
CLUSIONREASON_GROUPPOLICY: win32more.Windows.Win32.System.Search.CLUSION_REASON = 3
class COLUMNSET(Structure):
    cCol: UInt32
    aCol: POINTER(win32more.Windows.Win32.Storage.IndexServer.FULLPROPSPEC)
CONDITION_CREATION_OPTIONS = Int32
CONDITION_CREATION_DEFAULT: win32more.Windows.Win32.System.Search.CONDITION_CREATION_OPTIONS = 0
CONDITION_CREATION_NONE: win32more.Windows.Win32.System.Search.CONDITION_CREATION_OPTIONS = 0
CONDITION_CREATION_SIMPLIFY: win32more.Windows.Win32.System.Search.CONDITION_CREATION_OPTIONS = 1
CONDITION_CREATION_VECTOR_AND: win32more.Windows.Win32.System.Search.CONDITION_CREATION_OPTIONS = 2
CONDITION_CREATION_VECTOR_OR: win32more.Windows.Win32.System.Search.CONDITION_CREATION_OPTIONS = 4
CONDITION_CREATION_VECTOR_LEAF: win32more.Windows.Win32.System.Search.CONDITION_CREATION_OPTIONS = 8
CONDITION_CREATION_USE_CONTENT_LOCALE: win32more.Windows.Win32.System.Search.CONDITION_CREATION_OPTIONS = 16
class CONTENTRESTRICTION(Structure):
    prop: win32more.Windows.Win32.Storage.IndexServer.FULLPROPSPEC
    pwcsPhrase: win32more.Windows.Win32.Foundation.PWSTR
    lcid: UInt32
    ulGenerateMethod: UInt32
CREATESUBSCRIPTIONFLAGS = Int32
CREATESUBS_ADDTOFAVORITES: win32more.Windows.Win32.System.Search.CREATESUBSCRIPTIONFLAGS = 1
CREATESUBS_FROMFAVORITES: win32more.Windows.Win32.System.Search.CREATESUBSCRIPTIONFLAGS = 2
CREATESUBS_NOUI: win32more.Windows.Win32.System.Search.CREATESUBSCRIPTIONFLAGS = 4
CREATESUBS_NOSAVE: win32more.Windows.Win32.System.Search.CREATESUBSCRIPTIONFLAGS = 8
CREATESUBS_SOFTWAREUPDATE: win32more.Windows.Win32.System.Search.CREATESUBSCRIPTIONFLAGS = 16
CSearchLanguageSupport = Guid('{6a68cc80-4337-4dbc-bd27-fbfb1053820b}')
CSearchManager = Guid('{7d096c5f-ac08-4f1f-beb7-5c22c517ce39}')
CSearchRoot = Guid('{30766bd2-ea1c-4f28-bf27-0b44e2f68db7}')
CSearchScopeRule = Guid('{e63de750-3bd7-4be5-9c84-6b4281988c44}')
CatalogPausedReason = Int32
CATALOG_PAUSED_REASON_NONE: win32more.Windows.Win32.System.Search.CatalogPausedReason = 0
CATALOG_PAUSED_REASON_HIGH_IO: win32more.Windows.Win32.System.Search.CatalogPausedReason = 1
CATALOG_PAUSED_REASON_HIGH_CPU: win32more.Windows.Win32.System.Search.CatalogPausedReason = 2
CATALOG_PAUSED_REASON_HIGH_NTF_RATE: win32more.Windows.Win32.System.Search.CatalogPausedReason = 3
CATALOG_PAUSED_REASON_LOW_BATTERY: win32more.Windows.Win32.System.Search.CatalogPausedReason = 4
CATALOG_PAUSED_REASON_LOW_MEMORY: win32more.Windows.Win32.System.Search.CatalogPausedReason = 5
CATALOG_PAUSED_REASON_LOW_DISK: win32more.Windows.Win32.System.Search.CatalogPausedReason = 6
CATALOG_PAUSED_REASON_DELAYED_RECOVERY: win32more.Windows.Win32.System.Search.CatalogPausedReason = 7
CATALOG_PAUSED_REASON_USER_ACTIVE: win32more.Windows.Win32.System.Search.CatalogPausedReason = 8
CATALOG_PAUSED_REASON_EXTERNAL: win32more.Windows.Win32.System.Search.CatalogPausedReason = 9
CATALOG_PAUSED_REASON_UPGRADING: win32more.Windows.Win32.System.Search.CatalogPausedReason = 10
CatalogStatus = Int32
CATALOG_STATUS_IDLE: win32more.Windows.Win32.System.Search.CatalogStatus = 0
CATALOG_STATUS_PAUSED: win32more.Windows.Win32.System.Search.CatalogStatus = 1
CATALOG_STATUS_RECOVERING: win32more.Windows.Win32.System.Search.CatalogStatus = 2
CATALOG_STATUS_FULL_CRAWL: win32more.Windows.Win32.System.Search.CatalogStatus = 3
CATALOG_STATUS_INCREMENTAL_CRAWL: win32more.Windows.Win32.System.Search.CatalogStatus = 4
CATALOG_STATUS_PROCESSING_NOTIFICATIONS: win32more.Windows.Win32.System.Search.CatalogStatus = 5
CATALOG_STATUS_SHUTTING_DOWN: win32more.Windows.Win32.System.Search.CatalogStatus = 6
CompoundCondition = Guid('{116f8d13-101e-4fa5-84d4-ff8279381935}')
ConditionFactory = Guid('{e03e85b0-7be3-4000-ba98-6c13de9fa486}')
class DATE_STRUCT(Structure):
    year: Int16
    month: UInt16
    day: UInt16
DBACCESSORFLAGSENUM = Int32
DBACCESSOR_INVALID: win32more.Windows.Win32.System.Search.DBACCESSORFLAGSENUM = 0
DBACCESSOR_PASSBYREF: win32more.Windows.Win32.System.Search.DBACCESSORFLAGSENUM = 1
DBACCESSOR_ROWDATA: win32more.Windows.Win32.System.Search.DBACCESSORFLAGSENUM = 2
DBACCESSOR_PARAMETERDATA: win32more.Windows.Win32.System.Search.DBACCESSORFLAGSENUM = 4
DBACCESSOR_OPTIMIZED: win32more.Windows.Win32.System.Search.DBACCESSORFLAGSENUM = 8
DBACCESSOR_INHERITED: win32more.Windows.Win32.System.Search.DBACCESSORFLAGSENUM = 16
DBASYNCHOPENUM = Int32
DBASYNCHOP_OPEN: win32more.Windows.Win32.System.Search.DBASYNCHOPENUM = 0
DBASYNCHPHASEENUM = Int32
DBASYNCHPHASE_INITIALIZATION: win32more.Windows.Win32.System.Search.DBASYNCHPHASEENUM = 0
DBASYNCHPHASE_POPULATION: win32more.Windows.Win32.System.Search.DBASYNCHPHASEENUM = 1
DBASYNCHPHASE_COMPLETE: win32more.Windows.Win32.System.Search.DBASYNCHPHASEENUM = 2
DBASYNCHPHASE_CANCELED: win32more.Windows.Win32.System.Search.DBASYNCHPHASEENUM = 3
if ARCH in 'X64,ARM64':
    class DBBINDEXT(Structure):
        pExtension: POINTER(Byte)
        ulExtension: UIntPtr
elif ARCH in 'X86':
    class DBBINDEXT(Structure):
        pExtension: POINTER(Byte)
        ulExtension: UIntPtr
        _pack_ = 2
DBBINDFLAGENUM = Int32
DBBINDFLAG_HTML: win32more.Windows.Win32.System.Search.DBBINDFLAGENUM = 1
if ARCH in 'X64,ARM64':
    class DBBINDING(Structure):
        iOrdinal: UIntPtr
        obValue: UIntPtr
        obLength: UIntPtr
        obStatus: UIntPtr
        pTypeInfo: win32more.Windows.Win32.System.Com.ITypeInfo
        pObject: POINTER(win32more.Windows.Win32.System.Search.DBOBJECT)
        pBindExt: POINTER(win32more.Windows.Win32.System.Search.DBBINDEXT)
        dwPart: UInt32
        dwMemOwner: UInt32
        eParamIO: UInt32
        cbMaxLen: UIntPtr
        dwFlags: UInt32
        wType: UInt16
        bPrecision: Byte
        bScale: Byte
elif ARCH in 'X86':
    class DBBINDING(Structure):
        iOrdinal: UIntPtr
        obValue: UIntPtr
        obLength: UIntPtr
        obStatus: UIntPtr
        pTypeInfo: win32more.Windows.Win32.System.Com.ITypeInfo
        pObject: POINTER(win32more.Windows.Win32.System.Search.DBOBJECT)
        pBindExt: POINTER(win32more.Windows.Win32.System.Search.DBBINDEXT)
        dwPart: UInt32
        dwMemOwner: UInt32
        eParamIO: UInt32
        cbMaxLen: UIntPtr
        dwFlags: UInt32
        wType: UInt16
        bPrecision: Byte
        bScale: Byte
        _pack_ = 2
DBBINDSTATUSENUM = Int32
DBBINDSTATUS_OK: win32more.Windows.Win32.System.Search.DBBINDSTATUSENUM = 0
DBBINDSTATUS_BADORDINAL: win32more.Windows.Win32.System.Search.DBBINDSTATUSENUM = 1
DBBINDSTATUS_UNSUPPORTEDCONVERSION: win32more.Windows.Win32.System.Search.DBBINDSTATUSENUM = 2
DBBINDSTATUS_BADBINDINFO: win32more.Windows.Win32.System.Search.DBBINDSTATUSENUM = 3
DBBINDSTATUS_BADSTORAGEFLAGS: win32more.Windows.Win32.System.Search.DBBINDSTATUSENUM = 4
DBBINDSTATUS_NOINTERFACE: win32more.Windows.Win32.System.Search.DBBINDSTATUSENUM = 5
DBBINDSTATUS_MULTIPLESTORAGE: win32more.Windows.Win32.System.Search.DBBINDSTATUSENUM = 6
DBBINDURLFLAGENUM = Int32
DBBINDURLFLAG_READ: win32more.Windows.Win32.System.Search.DBBINDURLFLAGENUM = 1
DBBINDURLFLAG_WRITE: win32more.Windows.Win32.System.Search.DBBINDURLFLAGENUM = 2
DBBINDURLFLAG_READWRITE: win32more.Windows.Win32.System.Search.DBBINDURLFLAGENUM = 3
DBBINDURLFLAG_SHARE_DENY_READ: win32more.Windows.Win32.System.Search.DBBINDURLFLAGENUM = 4
DBBINDURLFLAG_SHARE_DENY_WRITE: win32more.Windows.Win32.System.Search.DBBINDURLFLAGENUM = 8
DBBINDURLFLAG_SHARE_EXCLUSIVE: win32more.Windows.Win32.System.Search.DBBINDURLFLAGENUM = 12
DBBINDURLFLAG_SHARE_DENY_NONE: win32more.Windows.Win32.System.Search.DBBINDURLFLAGENUM = 16
DBBINDURLFLAG_ASYNCHRONOUS: win32more.Windows.Win32.System.Search.DBBINDURLFLAGENUM = 4096
DBBINDURLFLAG_COLLECTION: win32more.Windows.Win32.System.Search.DBBINDURLFLAGENUM = 8192
DBBINDURLFLAG_DELAYFETCHSTREAM: win32more.Windows.Win32.System.Search.DBBINDURLFLAGENUM = 16384
DBBINDURLFLAG_DELAYFETCHCOLUMNS: win32more.Windows.Win32.System.Search.DBBINDURLFLAGENUM = 32768
DBBINDURLFLAG_RECURSIVE: win32more.Windows.Win32.System.Search.DBBINDURLFLAGENUM = 4194304
DBBINDURLFLAG_OUTPUT: win32more.Windows.Win32.System.Search.DBBINDURLFLAGENUM = 8388608
DBBINDURLFLAG_WAITFORINIT: win32more.Windows.Win32.System.Search.DBBINDURLFLAGENUM = 16777216
DBBINDURLFLAG_OPENIFEXISTS: win32more.Windows.Win32.System.Search.DBBINDURLFLAGENUM = 33554432
DBBINDURLFLAG_OVERWRITE: win32more.Windows.Win32.System.Search.DBBINDURLFLAGENUM = 67108864
DBBINDURLFLAG_ISSTRUCTUREDDOCUMENT: win32more.Windows.Win32.System.Search.DBBINDURLFLAGENUM = 134217728
DBBINDURLSTATUSENUM = Int32
DBBINDURLSTATUS_S_OK: win32more.Windows.Win32.System.Search.DBBINDURLSTATUSENUM = 0
DBBINDURLSTATUS_S_DENYNOTSUPPORTED: win32more.Windows.Win32.System.Search.DBBINDURLSTATUSENUM = 1
DBBINDURLSTATUS_S_DENYTYPENOTSUPPORTED: win32more.Windows.Win32.System.Search.DBBINDURLSTATUSENUM = 4
DBBINDURLSTATUS_S_REDIRECTED: win32more.Windows.Win32.System.Search.DBBINDURLSTATUSENUM = 8
DBBOOKMARK = Int32
DBBMK_INVALID: win32more.Windows.Win32.System.Search.DBBOOKMARK = 0
DBBMK_FIRST: win32more.Windows.Win32.System.Search.DBBOOKMARK = 1
DBBMK_LAST: win32more.Windows.Win32.System.Search.DBBOOKMARK = 2
if ARCH in 'X64,ARM64':
    class DBCOLUMNACCESS(Structure):
        pData: VoidPtr
        columnid: win32more.Windows.Win32.Storage.IndexServer.DBID
        cbDataLen: UIntPtr
        dwStatus: UInt32
        cbMaxLen: UIntPtr
        dwReserved: UIntPtr
        wType: UInt16
        bPrecision: Byte
        bScale: Byte
elif ARCH in 'X86':
    class DBCOLUMNACCESS(Structure):
        pData: VoidPtr
        columnid: win32more.Windows.Win32.Storage.IndexServer.DBID
        cbDataLen: UIntPtr
        dwStatus: UInt32
        cbMaxLen: UIntPtr
        dwReserved: UIntPtr
        wType: UInt16
        bPrecision: Byte
        bScale: Byte
        _pack_ = 2
if ARCH in 'X64,ARM64':
    class DBCOLUMNDESC(Structure):
        pwszTypeName: win32more.Windows.Win32.Foundation.PWSTR
        pTypeInfo: win32more.Windows.Win32.System.Com.ITypeInfo
        rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET)
        pclsid: POINTER(Guid)
        cPropertySets: UInt32
        ulColumnSize: UIntPtr
        dbcid: win32more.Windows.Win32.Storage.IndexServer.DBID
        wType: UInt16
        bPrecision: Byte
        bScale: Byte
elif ARCH in 'X86':
    class DBCOLUMNDESC(Structure):
        pwszTypeName: win32more.Windows.Win32.Foundation.PWSTR
        pTypeInfo: win32more.Windows.Win32.System.Com.ITypeInfo
        rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET)
        pclsid: POINTER(Guid)
        cPropertySets: UInt32
        ulColumnSize: UIntPtr
        dbcid: win32more.Windows.Win32.Storage.IndexServer.DBID
        wType: UInt16
        bPrecision: Byte
        bScale: Byte
        _pack_ = 2
DBCOLUMNDESCFLAGSENUM = Int32
DBCOLUMNDESCFLAGS_TYPENAME: win32more.Windows.Win32.System.Search.DBCOLUMNDESCFLAGSENUM = 1
DBCOLUMNDESCFLAGS_ITYPEINFO: win32more.Windows.Win32.System.Search.DBCOLUMNDESCFLAGSENUM = 2
DBCOLUMNDESCFLAGS_PROPERTIES: win32more.Windows.Win32.System.Search.DBCOLUMNDESCFLAGSENUM = 4
DBCOLUMNDESCFLAGS_CLSID: win32more.Windows.Win32.System.Search.DBCOLUMNDESCFLAGSENUM = 8
DBCOLUMNDESCFLAGS_COLSIZE: win32more.Windows.Win32.System.Search.DBCOLUMNDESCFLAGSENUM = 16
DBCOLUMNDESCFLAGS_DBCID: win32more.Windows.Win32.System.Search.DBCOLUMNDESCFLAGSENUM = 32
DBCOLUMNDESCFLAGS_WTYPE: win32more.Windows.Win32.System.Search.DBCOLUMNDESCFLAGSENUM = 64
DBCOLUMNDESCFLAGS_PRECISION: win32more.Windows.Win32.System.Search.DBCOLUMNDESCFLAGSENUM = 128
DBCOLUMNDESCFLAGS_SCALE: win32more.Windows.Win32.System.Search.DBCOLUMNDESCFLAGSENUM = 256
DBCOLUMNFLAGS15ENUM = Int32
DBCOLUMNFLAGS_ISCHAPTER: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGS15ENUM = 8192
DBCOLUMNFLAGSDEPRECATED = Int32
DBCOLUMNFLAGS_KEYCOLUMN: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSDEPRECATED = 32768
DBCOLUMNFLAGSENUM = Int32
DBCOLUMNFLAGS_ISBOOKMARK: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM = 1
DBCOLUMNFLAGS_MAYDEFER: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM = 2
DBCOLUMNFLAGS_WRITE: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM = 4
DBCOLUMNFLAGS_WRITEUNKNOWN: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM = 8
DBCOLUMNFLAGS_ISFIXEDLENGTH: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM = 16
DBCOLUMNFLAGS_ISNULLABLE: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM = 32
DBCOLUMNFLAGS_MAYBENULL: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM = 64
DBCOLUMNFLAGS_ISLONG: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM = 128
DBCOLUMNFLAGS_ISROWID: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM = 256
DBCOLUMNFLAGS_ISROWVER: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM = 512
DBCOLUMNFLAGS_CACHEDEFERRED: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM = 4096
DBCOLUMNFLAGSENUM20 = Int32
DBCOLUMNFLAGS_SCALEISNEGATIVE: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM20 = 16384
DBCOLUMNFLAGS_RESERVED: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM20 = 32768
DBCOLUMNFLAGSENUM21 = Int32
DBCOLUMNFLAGS_ISROWURL: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM21 = 65536
DBCOLUMNFLAGS_ISDEFAULTSTREAM: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM21 = 131072
DBCOLUMNFLAGS_ISCOLLECTION: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM21 = 262144
DBCOLUMNFLAGSENUM26 = Int32
DBCOLUMNFLAGS_ISSTREAM: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM26 = 524288
DBCOLUMNFLAGS_ISROWSET: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM26 = 1048576
DBCOLUMNFLAGS_ISROW: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM26 = 2097152
DBCOLUMNFLAGS_ROWSPECIFICCOLUMN: win32more.Windows.Win32.System.Search.DBCOLUMNFLAGSENUM26 = 4194304
if ARCH in 'X64,ARM64':
    class DBCOLUMNINFO(Structure):
        pwszName: win32more.Windows.Win32.Foundation.PWSTR
        pTypeInfo: win32more.Windows.Win32.System.Com.ITypeInfo
        iOrdinal: UIntPtr
        dwFlags: UInt32
        ulColumnSize: UIntPtr
        wType: UInt16
        bPrecision: Byte
        bScale: Byte
        columnid: win32more.Windows.Win32.Storage.IndexServer.DBID
elif ARCH in 'X86':
    class DBCOLUMNINFO(Structure):
        pwszName: win32more.Windows.Win32.Foundation.PWSTR
        pTypeInfo: win32more.Windows.Win32.System.Com.ITypeInfo
        iOrdinal: UIntPtr
        dwFlags: UInt32
        ulColumnSize: UIntPtr
        wType: UInt16
        bPrecision: Byte
        bScale: Byte
        columnid: win32more.Windows.Win32.Storage.IndexServer.DBID
        _pack_ = 2
DBCOMMANDPERSISTFLAGENUM = Int32
DBCOMMANDPERSISTFLAG_NOSAVE: win32more.Windows.Win32.System.Search.DBCOMMANDPERSISTFLAGENUM = 1
DBCOMMANDPERSISTFLAGENUM21 = Int32
DBCOMMANDPERSISTFLAG_DEFAULT: win32more.Windows.Win32.System.Search.DBCOMMANDPERSISTFLAGENUM21 = 0
DBCOMMANDPERSISTFLAG_PERSISTVIEW: win32more.Windows.Win32.System.Search.DBCOMMANDPERSISTFLAGENUM21 = 2
DBCOMMANDPERSISTFLAG_PERSISTPROCEDURE: win32more.Windows.Win32.System.Search.DBCOMMANDPERSISTFLAGENUM21 = 4
DBCOMPAREENUM = Int32
DBCOMPARE_LT: win32more.Windows.Win32.System.Search.DBCOMPAREENUM = 0
DBCOMPARE_EQ: win32more.Windows.Win32.System.Search.DBCOMPAREENUM = 1
DBCOMPARE_GT: win32more.Windows.Win32.System.Search.DBCOMPAREENUM = 2
DBCOMPARE_NE: win32more.Windows.Win32.System.Search.DBCOMPAREENUM = 3
DBCOMPARE_NOTCOMPARABLE: win32more.Windows.Win32.System.Search.DBCOMPAREENUM = 4
DBCOMPAREOPSENUM = Int32
DBCOMPAREOPS_LT: win32more.Windows.Win32.System.Search.DBCOMPAREOPSENUM = 0
DBCOMPAREOPS_LE: win32more.Windows.Win32.System.Search.DBCOMPAREOPSENUM = 1
DBCOMPAREOPS_EQ: win32more.Windows.Win32.System.Search.DBCOMPAREOPSENUM = 2
DBCOMPAREOPS_GE: win32more.Windows.Win32.System.Search.DBCOMPAREOPSENUM = 3
DBCOMPAREOPS_GT: win32more.Windows.Win32.System.Search.DBCOMPAREOPSENUM = 4
DBCOMPAREOPS_BEGINSWITH: win32more.Windows.Win32.System.Search.DBCOMPAREOPSENUM = 5
DBCOMPAREOPS_CONTAINS: win32more.Windows.Win32.System.Search.DBCOMPAREOPSENUM = 6
DBCOMPAREOPS_NE: win32more.Windows.Win32.System.Search.DBCOMPAREOPSENUM = 7
DBCOMPAREOPS_IGNORE: win32more.Windows.Win32.System.Search.DBCOMPAREOPSENUM = 8
DBCOMPAREOPS_CASESENSITIVE: win32more.Windows.Win32.System.Search.DBCOMPAREOPSENUM = 4096
DBCOMPAREOPS_CASEINSENSITIVE: win32more.Windows.Win32.System.Search.DBCOMPAREOPSENUM = 8192
DBCOMPAREOPSENUM20 = Int32
DBCOMPAREOPS_NOTBEGINSWITH: win32more.Windows.Win32.System.Search.DBCOMPAREOPSENUM20 = 9
DBCOMPAREOPS_NOTCONTAINS: win32more.Windows.Win32.System.Search.DBCOMPAREOPSENUM20 = 10
if ARCH in 'X64,ARM64':
    class DBCONSTRAINTDESC(Structure):
        pConstraintID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)
        ConstraintType: UInt32
        cColumns: UIntPtr
        rgColumnList: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)
        pReferencedTableID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)
        cForeignKeyColumns: UIntPtr
        rgForeignKeyColumnList: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)
        pwszConstraintText: win32more.Windows.Win32.Foundation.PWSTR
        UpdateRule: UInt32
        DeleteRule: UInt32
        MatchType: UInt32
        Deferrability: UInt32
        cReserved: UIntPtr
        rgReserved: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET)
elif ARCH in 'X86':
    class DBCONSTRAINTDESC(Structure):
        pConstraintID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)
        ConstraintType: UInt32
        cColumns: UIntPtr
        rgColumnList: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)
        pReferencedTableID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)
        cForeignKeyColumns: UIntPtr
        rgForeignKeyColumnList: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)
        pwszConstraintText: win32more.Windows.Win32.Foundation.PWSTR
        UpdateRule: UInt32
        DeleteRule: UInt32
        MatchType: UInt32
        Deferrability: UInt32
        cReserved: UIntPtr
        rgReserved: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET)
        _pack_ = 2
DBCONSTRAINTTYPEENUM = Int32
DBCONSTRAINTTYPE_UNIQUE: win32more.Windows.Win32.System.Search.DBCONSTRAINTTYPEENUM = 0
DBCONSTRAINTTYPE_FOREIGNKEY: win32more.Windows.Win32.System.Search.DBCONSTRAINTTYPEENUM = 1
DBCONSTRAINTTYPE_PRIMARYKEY: win32more.Windows.Win32.System.Search.DBCONSTRAINTTYPEENUM = 2
DBCONSTRAINTTYPE_CHECK: win32more.Windows.Win32.System.Search.DBCONSTRAINTTYPEENUM = 3
DBCONVERTFLAGSENUM = Int32
DBCONVERTFLAGS_COLUMN: win32more.Windows.Win32.System.Search.DBCONVERTFLAGSENUM = 0
DBCONVERTFLAGS_PARAMETER: win32more.Windows.Win32.System.Search.DBCONVERTFLAGSENUM = 1
DBCONVERTFLAGSENUM20 = Int32
DBCONVERTFLAGS_ISLONG: win32more.Windows.Win32.System.Search.DBCONVERTFLAGSENUM20 = 2
DBCONVERTFLAGS_ISFIXEDLENGTH: win32more.Windows.Win32.System.Search.DBCONVERTFLAGSENUM20 = 4
DBCONVERTFLAGS_FROMVARIANT: win32more.Windows.Win32.System.Search.DBCONVERTFLAGSENUM20 = 8
DBCOPYFLAGSENUM = Int32
DBCOPY_ASYNC: win32more.Windows.Win32.System.Search.DBCOPYFLAGSENUM = 256
DBCOPY_REPLACE_EXISTING: win32more.Windows.Win32.System.Search.DBCOPYFLAGSENUM = 512
DBCOPY_ALLOW_EMULATION: win32more.Windows.Win32.System.Search.DBCOPYFLAGSENUM = 1024
DBCOPY_NON_RECURSIVE: win32more.Windows.Win32.System.Search.DBCOPYFLAGSENUM = 2048
DBCOPY_ATOMIC: win32more.Windows.Win32.System.Search.DBCOPYFLAGSENUM = 4096
if ARCH in 'X64,ARM64':
    class DBCOST(Structure):
        eKind: UInt32
        dwUnits: UInt32
        lValue: Int32
elif ARCH in 'X86':
    class DBCOST(Structure):
        eKind: UInt32
        dwUnits: UInt32
        lValue: Int32
        _pack_ = 2
DBCOSTUNITENUM = Int32
DBUNIT_INVALID: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 0
DBUNIT_WEIGHT: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 1
DBUNIT_PERCENT: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 2
DBUNIT_MAXIMUM: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 4
DBUNIT_MINIMUM: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 8
DBUNIT_MICRO_SECOND: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 16
DBUNIT_MILLI_SECOND: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 32
DBUNIT_SECOND: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 64
DBUNIT_MINUTE: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 128
DBUNIT_HOUR: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 256
DBUNIT_BYTE: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 512
DBUNIT_KILO_BYTE: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 1024
DBUNIT_MEGA_BYTE: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 2048
DBUNIT_GIGA_BYTE: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 4096
DBUNIT_NUM_MSGS: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 8192
DBUNIT_NUM_LOCKS: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 16384
DBUNIT_NUM_ROWS: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 32768
DBUNIT_OTHER: win32more.Windows.Win32.System.Search.DBCOSTUNITENUM = 65536
DBDATACONVERTENUM = Int32
DBDATACONVERT_DEFAULT: win32more.Windows.Win32.System.Search.DBDATACONVERTENUM = 0
DBDATACONVERT_SETDATABEHAVIOR: win32more.Windows.Win32.System.Search.DBDATACONVERTENUM = 1
DBDATACONVERT_LENGTHFROMNTS: win32more.Windows.Win32.System.Search.DBDATACONVERTENUM = 2
DBDATACONVERT_DSTISFIXEDLENGTH: win32more.Windows.Win32.System.Search.DBDATACONVERTENUM = 4
DBDATACONVERT_DECIMALSCALE: win32more.Windows.Win32.System.Search.DBDATACONVERTENUM = 8
class DBDATE(Structure):
    year: Int16
    month: UInt16
    day: UInt16
class DBDATETIM4(Structure):
    numdays: UInt16
    nummins: UInt16
class DBDATETIME(Structure):
    dtdays: Int32
    dttime: UInt32
DBDEFERRABILITYENUM = Int32
DBDEFERRABILITY_DEFERRED: win32more.Windows.Win32.System.Search.DBDEFERRABILITYENUM = 1
DBDEFERRABILITY_DEFERRABLE: win32more.Windows.Win32.System.Search.DBDEFERRABILITYENUM = 2
DBDELETEFLAGSENUM = Int32
DBDELETE_ASYNC: win32more.Windows.Win32.System.Search.DBDELETEFLAGSENUM = 256
DBDELETE_ATOMIC: win32more.Windows.Win32.System.Search.DBDELETEFLAGSENUM = 4096
DBEVENTPHASEENUM = Int32
DBEVENTPHASE_OKTODO: win32more.Windows.Win32.System.Search.DBEVENTPHASEENUM = 0
DBEVENTPHASE_ABOUTTODO: win32more.Windows.Win32.System.Search.DBEVENTPHASEENUM = 1
DBEVENTPHASE_SYNCHAFTER: win32more.Windows.Win32.System.Search.DBEVENTPHASEENUM = 2
DBEVENTPHASE_FAILEDTODO: win32more.Windows.Win32.System.Search.DBEVENTPHASEENUM = 3
DBEVENTPHASE_DIDEVENT: win32more.Windows.Win32.System.Search.DBEVENTPHASEENUM = 4
DBEXECLIMITSENUM = Int32
DBEXECLIMITS_ABORT: win32more.Windows.Win32.System.Search.DBEXECLIMITSENUM = 1
DBEXECLIMITS_STOP: win32more.Windows.Win32.System.Search.DBEXECLIMITSENUM = 2
DBEXECLIMITS_SUSPEND: win32more.Windows.Win32.System.Search.DBEXECLIMITSENUM = 3
if ARCH in 'X64,ARM64':
    class DBFAILUREINFO(Structure):
        hRow: UIntPtr
        iColumn: UIntPtr
        failure: win32more.Windows.Win32.Foundation.HRESULT
elif ARCH in 'X86':
    class DBFAILUREINFO(Structure):
        hRow: UIntPtr
        iColumn: UIntPtr
        failure: win32more.Windows.Win32.Foundation.HRESULT
        _pack_ = 2
if ARCH in 'X64,ARM64':
    class DBIMPLICITSESSION(Structure):
        pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown
        piid: POINTER(Guid)
        pSession: win32more.Windows.Win32.System.Com.IUnknown
elif ARCH in 'X86':
    class DBIMPLICITSESSION(Structure):
        pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown
        piid: POINTER(Guid)
        pSession: win32more.Windows.Win32.System.Com.IUnknown
        _pack_ = 2
if ARCH in 'X64,ARM64':
    class DBINDEXCOLUMNDESC(Structure):
        pColumnID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)
        eIndexColOrder: UInt32
elif ARCH in 'X86':
    class DBINDEXCOLUMNDESC(Structure):
        pColumnID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)
        eIndexColOrder: UInt32
        _pack_ = 2
DBINDEX_COL_ORDERENUM = Int32
DBINDEX_COL_ORDER_ASC: win32more.Windows.Win32.System.Search.DBINDEX_COL_ORDERENUM = 0
DBINDEX_COL_ORDER_DESC: win32more.Windows.Win32.System.Search.DBINDEX_COL_ORDERENUM = 1
DBLITERALENUM = Int32
DBLITERAL_INVALID: win32more.Windows.Win32.System.Search.DBLITERALENUM = 0
DBLITERAL_BINARY_LITERAL: win32more.Windows.Win32.System.Search.DBLITERALENUM = 1
DBLITERAL_CATALOG_NAME: win32more.Windows.Win32.System.Search.DBLITERALENUM = 2
DBLITERAL_CATALOG_SEPARATOR: win32more.Windows.Win32.System.Search.DBLITERALENUM = 3
DBLITERAL_CHAR_LITERAL: win32more.Windows.Win32.System.Search.DBLITERALENUM = 4
DBLITERAL_COLUMN_ALIAS: win32more.Windows.Win32.System.Search.DBLITERALENUM = 5
DBLITERAL_COLUMN_NAME: win32more.Windows.Win32.System.Search.DBLITERALENUM = 6
DBLITERAL_CORRELATION_NAME: win32more.Windows.Win32.System.Search.DBLITERALENUM = 7
DBLITERAL_CURSOR_NAME: win32more.Windows.Win32.System.Search.DBLITERALENUM = 8
DBLITERAL_ESCAPE_PERCENT: win32more.Windows.Win32.System.Search.DBLITERALENUM = 9
DBLITERAL_ESCAPE_UNDERSCORE: win32more.Windows.Win32.System.Search.DBLITERALENUM = 10
DBLITERAL_INDEX_NAME: win32more.Windows.Win32.System.Search.DBLITERALENUM = 11
DBLITERAL_LIKE_PERCENT: win32more.Windows.Win32.System.Search.DBLITERALENUM = 12
DBLITERAL_LIKE_UNDERSCORE: win32more.Windows.Win32.System.Search.DBLITERALENUM = 13
DBLITERAL_PROCEDURE_NAME: win32more.Windows.Win32.System.Search.DBLITERALENUM = 14
DBLITERAL_QUOTE: win32more.Windows.Win32.System.Search.DBLITERALENUM = 15
DBLITERAL_SCHEMA_NAME: win32more.Windows.Win32.System.Search.DBLITERALENUM = 16
DBLITERAL_TABLE_NAME: win32more.Windows.Win32.System.Search.DBLITERALENUM = 17
DBLITERAL_TEXT_COMMAND: win32more.Windows.Win32.System.Search.DBLITERALENUM = 18
DBLITERAL_USER_NAME: win32more.Windows.Win32.System.Search.DBLITERALENUM = 19
DBLITERAL_VIEW_NAME: win32more.Windows.Win32.System.Search.DBLITERALENUM = 20
DBLITERALENUM20 = Int32
DBLITERAL_CUBE_NAME: win32more.Windows.Win32.System.Search.DBLITERALENUM20 = 21
DBLITERAL_DIMENSION_NAME: win32more.Windows.Win32.System.Search.DBLITERALENUM20 = 22
DBLITERAL_HIERARCHY_NAME: win32more.Windows.Win32.System.Search.DBLITERALENUM20 = 23
DBLITERAL_LEVEL_NAME: win32more.Windows.Win32.System.Search.DBLITERALENUM20 = 24
DBLITERAL_MEMBER_NAME: win32more.Windows.Win32.System.Search.DBLITERALENUM20 = 25
DBLITERAL_PROPERTY_NAME: win32more.Windows.Win32.System.Search.DBLITERALENUM20 = 26
DBLITERAL_SCHEMA_SEPARATOR: win32more.Windows.Win32.System.Search.DBLITERALENUM20 = 27
DBLITERAL_QUOTE_SUFFIX: win32more.Windows.Win32.System.Search.DBLITERALENUM20 = 28
DBLITERALENUM21 = Int32
DBLITERAL_ESCAPE_PERCENT_SUFFIX: win32more.Windows.Win32.System.Search.DBLITERALENUM21 = 29
DBLITERAL_ESCAPE_UNDERSCORE_SUFFIX: win32more.Windows.Win32.System.Search.DBLITERALENUM21 = 30
if ARCH in 'X64,ARM64':
    class DBLITERALINFO(Structure):
        pwszLiteralValue: win32more.Windows.Win32.Foundation.PWSTR
        pwszInvalidChars: win32more.Windows.Win32.Foundation.PWSTR
        pwszInvalidStartingChars: win32more.Windows.Win32.Foundation.PWSTR
        lt: UInt32
        fSupported: win32more.Windows.Win32.Foundation.BOOL
        cchMaxLen: UInt32
elif ARCH in 'X86':
    class DBLITERALINFO(Structure):
        pwszLiteralValue: win32more.Windows.Win32.Foundation.PWSTR
        pwszInvalidChars: win32more.Windows.Win32.Foundation.PWSTR
        pwszInvalidStartingChars: win32more.Windows.Win32.Foundation.PWSTR
        lt: UInt32
        fSupported: win32more.Windows.Win32.Foundation.BOOL
        cchMaxLen: UInt32
        _pack_ = 2
DBMATCHTYPEENUM = Int32
DBMATCHTYPE_FULL: win32more.Windows.Win32.System.Search.DBMATCHTYPEENUM = 0
DBMATCHTYPE_NONE: win32more.Windows.Win32.System.Search.DBMATCHTYPEENUM = 1
DBMATCHTYPE_PARTIAL: win32more.Windows.Win32.System.Search.DBMATCHTYPEENUM = 2
DBMEMOWNERENUM = Int32
DBMEMOWNER_CLIENTOWNED: win32more.Windows.Win32.System.Search.DBMEMOWNERENUM = 0
DBMEMOWNER_PROVIDEROWNED: win32more.Windows.Win32.System.Search.DBMEMOWNERENUM = 1
class DBMONEY(Structure):
    mnyhigh: Int32
    mnylow: UInt32
DBMOVEFLAGSENUM = Int32
DBMOVE_REPLACE_EXISTING: win32more.Windows.Win32.System.Search.DBMOVEFLAGSENUM = 1
DBMOVE_ASYNC: win32more.Windows.Win32.System.Search.DBMOVEFLAGSENUM = 256
DBMOVE_DONT_UPDATE_LINKS: win32more.Windows.Win32.System.Search.DBMOVEFLAGSENUM = 512
DBMOVE_ALLOW_EMULATION: win32more.Windows.Win32.System.Search.DBMOVEFLAGSENUM = 1024
DBMOVE_ATOMIC: win32more.Windows.Win32.System.Search.DBMOVEFLAGSENUM = 4096
if ARCH in 'X64,ARM64':
    class DBOBJECT(Structure):
        dwFlags: UInt32
        iid: Guid
elif ARCH in 'X86':
    class DBOBJECT(Structure):
        dwFlags: UInt32
        iid: Guid
        _pack_ = 2
if ARCH in 'X64,ARM64':
    class DBPARAMBINDINFO(Structure):
        pwszDataSourceType: win32more.Windows.Win32.Foundation.PWSTR
        pwszName: win32more.Windows.Win32.Foundation.PWSTR
        ulParamSize: UIntPtr
        dwFlags: UInt32
        bPrecision: Byte
        bScale: Byte
elif ARCH in 'X86':
    class DBPARAMBINDINFO(Structure):
        pwszDataSourceType: win32more.Windows.Win32.Foundation.PWSTR
        pwszName: win32more.Windows.Win32.Foundation.PWSTR
        ulParamSize: UIntPtr
        dwFlags: UInt32
        bPrecision: Byte
        bScale: Byte
        _pack_ = 2
DBPARAMFLAGSENUM = Int32
DBPARAMFLAGS_ISINPUT: win32more.Windows.Win32.System.Search.DBPARAMFLAGSENUM = 1
DBPARAMFLAGS_ISOUTPUT: win32more.Windows.Win32.System.Search.DBPARAMFLAGSENUM = 2
DBPARAMFLAGS_ISSIGNED: win32more.Windows.Win32.System.Search.DBPARAMFLAGSENUM = 16
DBPARAMFLAGS_ISNULLABLE: win32more.Windows.Win32.System.Search.DBPARAMFLAGSENUM = 64
DBPARAMFLAGS_ISLONG: win32more.Windows.Win32.System.Search.DBPARAMFLAGSENUM = 128
DBPARAMFLAGSENUM20 = Int32
DBPARAMFLAGS_SCALEISNEGATIVE: win32more.Windows.Win32.System.Search.DBPARAMFLAGSENUM20 = 256
if ARCH in 'X64,ARM64':
    class DBPARAMINFO(Structure):
        dwFlags: UInt32
        iOrdinal: UIntPtr
        pwszName: win32more.Windows.Win32.Foundation.PWSTR
        pTypeInfo: win32more.Windows.Win32.System.Com.ITypeInfo
        ulParamSize: UIntPtr
        wType: UInt16
        bPrecision: Byte
        bScale: Byte
elif ARCH in 'X86':
    class DBPARAMINFO(Structure):
        dwFlags: UInt32
        iOrdinal: UIntPtr
        pwszName: win32more.Windows.Win32.Foundation.PWSTR
        pTypeInfo: win32more.Windows.Win32.System.Com.ITypeInfo
        ulParamSize: UIntPtr
        wType: UInt16
        bPrecision: Byte
        bScale: Byte
        _pack_ = 2
DBPARAMIOENUM = Int32
DBPARAMIO_NOTPARAM: win32more.Windows.Win32.System.Search.DBPARAMIOENUM = 0
DBPARAMIO_INPUT: win32more.Windows.Win32.System.Search.DBPARAMIOENUM = 1
DBPARAMIO_OUTPUT: win32more.Windows.Win32.System.Search.DBPARAMIOENUM = 2
if ARCH in 'X64,ARM64':
    class DBPARAMS(Structure):
        pData: VoidPtr
        cParamSets: UIntPtr
        hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR
elif ARCH in 'X86':
    class DBPARAMS(Structure):
        pData: VoidPtr
        cParamSets: UIntPtr
        hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR
        _pack_ = 2
DBPARTENUM = Int32
DBPART_INVALID: win32more.Windows.Win32.System.Search.DBPARTENUM = 0
DBPART_VALUE: win32more.Windows.Win32.System.Search.DBPARTENUM = 1
DBPART_LENGTH: win32more.Windows.Win32.System.Search.DBPARTENUM = 2
DBPART_STATUS: win32more.Windows.Win32.System.Search.DBPARTENUM = 4
DBPENDINGSTATUSENUM = Int32
DBPENDINGSTATUS_NEW: win32more.Windows.Win32.System.Search.DBPENDINGSTATUSENUM = 1
DBPENDINGSTATUS_CHANGED: win32more.Windows.Win32.System.Search.DBPENDINGSTATUSENUM = 2
DBPENDINGSTATUS_DELETED: win32more.Windows.Win32.System.Search.DBPENDINGSTATUSENUM = 4
DBPENDINGSTATUS_UNCHANGED: win32more.Windows.Win32.System.Search.DBPENDINGSTATUSENUM = 8
DBPENDINGSTATUS_INVALIDROW: win32more.Windows.Win32.System.Search.DBPENDINGSTATUSENUM = 16
DBPOSITIONFLAGSENUM = Int32
DBPOSITION_OK: win32more.Windows.Win32.System.Search.DBPOSITIONFLAGSENUM = 0
DBPOSITION_NOROW: win32more.Windows.Win32.System.Search.DBPOSITIONFLAGSENUM = 1
DBPOSITION_BOF: win32more.Windows.Win32.System.Search.DBPOSITIONFLAGSENUM = 2
DBPOSITION_EOF: win32more.Windows.Win32.System.Search.DBPOSITIONFLAGSENUM = 3
DBPROMPTOPTIONSENUM = Int32
DBPROMPTOPTIONS_NONE: win32more.Windows.Win32.System.Search.DBPROMPTOPTIONSENUM = 0
DBPROMPTOPTIONS_WIZARDSHEET: win32more.Windows.Win32.System.Search.DBPROMPTOPTIONSENUM = 1
DBPROMPTOPTIONS_PROPERTYSHEET: win32more.Windows.Win32.System.Search.DBPROMPTOPTIONSENUM = 2
DBPROMPTOPTIONS_BROWSEONLY: win32more.Windows.Win32.System.Search.DBPROMPTOPTIONSENUM = 8
DBPROMPTOPTIONS_DISABLE_PROVIDER_SELECTION: win32more.Windows.Win32.System.Search.DBPROMPTOPTIONSENUM = 16
DBPROMPTOPTIONS_DISABLESAVEPASSWORD: win32more.Windows.Win32.System.Search.DBPROMPTOPTIONSENUM = 32
if ARCH in 'X64,ARM64':
    class DBPROP(Structure):
        dwPropertyID: UInt32
        dwOptions: UInt32
        dwStatus: UInt32
        colid: win32more.Windows.Win32.Storage.IndexServer.DBID
        vValue: win32more.Windows.Win32.System.Variant.VARIANT
elif ARCH in 'X86':
    class DBPROP(Structure):
        dwPropertyID: UInt32
        dwOptions: UInt32
        dwStatus: UInt32
        colid: win32more.Windows.Win32.Storage.IndexServer.DBID
        vValue: win32more.Windows.Win32.System.Variant.VARIANT
        _pack_ = 2
DBPROPENUM = Int32
DBPROP_ABORTPRESERVE: win32more.Windows.Win32.System.Search.DBPROPENUM = 2
DBPROP_ACTIVESESSIONS: win32more.Windows.Win32.System.Search.DBPROPENUM = 3
DBPROP_APPENDONLY: win32more.Windows.Win32.System.Search.DBPROPENUM = 187
DBPROP_ASYNCTXNABORT: win32more.Windows.Win32.System.Search.DBPROPENUM = 168
DBPROP_ASYNCTXNCOMMIT: win32more.Windows.Win32.System.Search.DBPROPENUM = 4
DBPROP_AUTH_CACHE_AUTHINFO: win32more.Windows.Win32.System.Search.DBPROPENUM = 5
DBPROP_AUTH_ENCRYPT_PASSWORD: win32more.Windows.Win32.System.Search.DBPROPENUM = 6
DBPROP_AUTH_INTEGRATED: win32more.Windows.Win32.System.Search.DBPROPENUM = 7
DBPROP_AUTH_MASK_PASSWORD: win32more.Windows.Win32.System.Search.DBPROPENUM = 8
DBPROP_AUTH_PASSWORD: win32more.Windows.Win32.System.Search.DBPROPENUM = 9
DBPROP_AUTH_PERSIST_ENCRYPTED: win32more.Windows.Win32.System.Search.DBPROPENUM = 10
DBPROP_AUTH_PERSIST_SENSITIVE_AUTHINFO: win32more.Windows.Win32.System.Search.DBPROPENUM = 11
DBPROP_AUTH_USERID: win32more.Windows.Win32.System.Search.DBPROPENUM = 12
DBPROP_BLOCKINGSTORAGEOBJECTS: win32more.Windows.Win32.System.Search.DBPROPENUM = 13
DBPROP_BOOKMARKS: win32more.Windows.Win32.System.Search.DBPROPENUM = 14
DBPROP_BOOKMARKSKIPPED: win32more.Windows.Win32.System.Search.DBPROPENUM = 15
DBPROP_BOOKMARKTYPE: win32more.Windows.Win32.System.Search.DBPROPENUM = 16
DBPROP_BYREFACCESSORS: win32more.Windows.Win32.System.Search.DBPROPENUM = 120
DBPROP_CACHEDEFERRED: win32more.Windows.Win32.System.Search.DBPROPENUM = 17
DBPROP_CANFETCHBACKWARDS: win32more.Windows.Win32.System.Search.DBPROPENUM = 18
DBPROP_CANHOLDROWS: win32more.Windows.Win32.System.Search.DBPROPENUM = 19
DBPROP_CANSCROLLBACKWARDS: win32more.Windows.Win32.System.Search.DBPROPENUM = 21
DBPROP_CATALOGLOCATION: win32more.Windows.Win32.System.Search.DBPROPENUM = 22
DBPROP_CATALOGTERM: win32more.Windows.Win32.System.Search.DBPROPENUM = 23
DBPROP_CATALOGUSAGE: win32more.Windows.Win32.System.Search.DBPROPENUM = 24
DBPROP_CHANGEINSERTEDROWS: win32more.Windows.Win32.System.Search.DBPROPENUM = 188
DBPROP_COL_AUTOINCREMENT: win32more.Windows.Win32.System.Search.DBPROPENUM = 26
DBPROP_COL_DEFAULT: win32more.Windows.Win32.System.Search.DBPROPENUM = 27
DBPROP_COL_DESCRIPTION: win32more.Windows.Win32.System.Search.DBPROPENUM = 28
DBPROP_COL_FIXEDLENGTH: win32more.Windows.Win32.System.Search.DBPROPENUM = 167
DBPROP_COL_NULLABLE: win32more.Windows.Win32.System.Search.DBPROPENUM = 29
DBPROP_COL_PRIMARYKEY: win32more.Windows.Win32.System.Search.DBPROPENUM = 30
DBPROP_COL_UNIQUE: win32more.Windows.Win32.System.Search.DBPROPENUM = 31
DBPROP_COLUMNDEFINITION: win32more.Windows.Win32.System.Search.DBPROPENUM = 32
DBPROP_COLUMNRESTRICT: win32more.Windows.Win32.System.Search.DBPROPENUM = 33
DBPROP_COMMANDTIMEOUT: win32more.Windows.Win32.System.Search.DBPROPENUM = 34
DBPROP_COMMITPRESERVE: win32more.Windows.Win32.System.Search.DBPROPENUM = 35
DBPROP_CONCATNULLBEHAVIOR: win32more.Windows.Win32.System.Search.DBPROPENUM = 36
DBPROP_CURRENTCATALOG: win32more.Windows.Win32.System.Search.DBPROPENUM = 37
DBPROP_DATASOURCENAME: win32more.Windows.Win32.System.Search.DBPROPENUM = 38
DBPROP_DATASOURCEREADONLY: win32more.Windows.Win32.System.Search.DBPROPENUM = 39
DBPROP_DBMSNAME: win32more.Windows.Win32.System.Search.DBPROPENUM = 40
DBPROP_DBMSVER: win32more.Windows.Win32.System.Search.DBPROPENUM = 41
DBPROP_DEFERRED: win32more.Windows.Win32.System.Search.DBPROPENUM = 42
DBPROP_DELAYSTORAGEOBJECTS: win32more.Windows.Win32.System.Search.DBPROPENUM = 43
DBPROP_DSOTHREADMODEL: win32more.Windows.Win32.System.Search.DBPROPENUM = 169
DBPROP_GROUPBY: win32more.Windows.Win32.System.Search.DBPROPENUM = 44
DBPROP_HETEROGENEOUSTABLES: win32more.Windows.Win32.System.Search.DBPROPENUM = 45
DBPROP_IAccessor: win32more.Windows.Win32.System.Search.DBPROPENUM = 121
DBPROP_IColumnsInfo: win32more.Windows.Win32.System.Search.DBPROPENUM = 122
DBPROP_IColumnsRowset: win32more.Windows.Win32.System.Search.DBPROPENUM = 123
DBPROP_IConnectionPointContainer: win32more.Windows.Win32.System.Search.DBPROPENUM = 124
DBPROP_IConvertType: win32more.Windows.Win32.System.Search.DBPROPENUM = 194
DBPROP_IRowset: win32more.Windows.Win32.System.Search.DBPROPENUM = 126
DBPROP_IRowsetChange: win32more.Windows.Win32.System.Search.DBPROPENUM = 127
DBPROP_IRowsetIdentity: win32more.Windows.Win32.System.Search.DBPROPENUM = 128
DBPROP_IRowsetIndex: win32more.Windows.Win32.System.Search.DBPROPENUM = 159
DBPROP_IRowsetInfo: win32more.Windows.Win32.System.Search.DBPROPENUM = 129
DBPROP_IRowsetLocate: win32more.Windows.Win32.System.Search.DBPROPENUM = 130
DBPROP_IRowsetResynch: win32more.Windows.Win32.System.Search.DBPROPENUM = 132
DBPROP_IRowsetScroll: win32more.Windows.Win32.System.Search.DBPROPENUM = 133
DBPROP_IRowsetUpdate: win32more.Windows.Win32.System.Search.DBPROPENUM = 134
DBPROP_ISupportErrorInfo: win32more.Windows.Win32.System.Search.DBPROPENUM = 135
DBPROP_ILockBytes: win32more.Windows.Win32.System.Search.DBPROPENUM = 136
DBPROP_ISequentialStream: win32more.Windows.Win32.System.Search.DBPROPENUM = 137
DBPROP_IStorage: win32more.Windows.Win32.System.Search.DBPROPENUM = 138
DBPROP_IStream: win32more.Windows.Win32.System.Search.DBPROPENUM = 139
DBPROP_IDENTIFIERCASE: win32more.Windows.Win32.System.Search.DBPROPENUM = 46
DBPROP_IMMOBILEROWS: win32more.Windows.Win32.System.Search.DBPROPENUM = 47
DBPROP_INDEX_AUTOUPDATE: win32more.Windows.Win32.System.Search.DBPROPENUM = 48
DBPROP_INDEX_CLUSTERED: win32more.Windows.Win32.System.Search.DBPROPENUM = 49
DBPROP_INDEX_FILLFACTOR: win32more.Windows.Win32.System.Search.DBPROPENUM = 50
DBPROP_INDEX_INITIALSIZE: win32more.Windows.Win32.System.Search.DBPROPENUM = 51
DBPROP_INDEX_NULLCOLLATION: win32more.Windows.Win32.System.Search.DBPROPENUM = 52
DBPROP_INDEX_NULLS: win32more.Windows.Win32.System.Search.DBPROPENUM = 53
DBPROP_INDEX_PRIMARYKEY: win32more.Windows.Win32.System.Search.DBPROPENUM = 54
DBPROP_INDEX_SORTBOOKMARKS: win32more.Windows.Win32.System.Search.DBPROPENUM = 55
DBPROP_INDEX_TEMPINDEX: win32more.Windows.Win32.System.Search.DBPROPENUM = 163
DBPROP_INDEX_TYPE: win32more.Windows.Win32.System.Search.DBPROPENUM = 56
DBPROP_INDEX_UNIQUE: win32more.Windows.Win32.System.Search.DBPROPENUM = 57
DBPROP_INIT_DATASOURCE: win32more.Windows.Win32.System.Search.DBPROPENUM = 59
DBPROP_INIT_HWND: win32more.Windows.Win32.System.Search.DBPROPENUM = 60
DBPROP_INIT_IMPERSONATION_LEVEL: win32more.Windows.Win32.System.Search.DBPROPENUM = 61
DBPROP_INIT_LCID: win32more.Windows.Win32.System.Search.DBPROPENUM = 186
DBPROP_INIT_LOCATION: win32more.Windows.Win32.System.Search.DBPROPENUM = 62
DBPROP_INIT_MODE: win32more.Windows.Win32.System.Search.DBPROPENUM = 63
DBPROP_INIT_PROMPT: win32more.Windows.Win32.System.Search.DBPROPENUM = 64
DBPROP_INIT_PROTECTION_LEVEL: win32more.Windows.Win32.System.Search.DBPROPENUM = 65
DBPROP_INIT_PROVIDERSTRING: win32more.Windows.Win32.System.Search.DBPROPENUM = 160
DBPROP_INIT_TIMEOUT: win32more.Windows.Win32.System.Search.DBPROPENUM = 66
DBPROP_LITERALBOOKMARKS: win32more.Windows.Win32.System.Search.DBPROPENUM = 67
DBPROP_LITERALIDENTITY: win32more.Windows.Win32.System.Search.DBPROPENUM = 68
DBPROP_MAXINDEXSIZE: win32more.Windows.Win32.System.Search.DBPROPENUM = 70
DBPROP_MAXOPENROWS: win32more.Windows.Win32.System.Search.DBPROPENUM = 71
DBPROP_MAXPENDINGROWS: win32more.Windows.Win32.System.Search.DBPROPENUM = 72
DBPROP_MAXROWS: win32more.Windows.Win32.System.Search.DBPROPENUM = 73
DBPROP_MAXROWSIZE: win32more.Windows.Win32.System.Search.DBPROPENUM = 74
DBPROP_MAXROWSIZEINCLUDESBLOB: win32more.Windows.Win32.System.Search.DBPROPENUM = 75
DBPROP_MAXTABLESINSELECT: win32more.Windows.Win32.System.Search.DBPROPENUM = 76
DBPROP_MAYWRITECOLUMN: win32more.Windows.Win32.System.Search.DBPROPENUM = 77
DBPROP_MEMORYUSAGE: win32more.Windows.Win32.System.Search.DBPROPENUM = 78
DBPROP_MULTIPLEPARAMSETS: win32more.Windows.Win32.System.Search.DBPROPENUM = 191
DBPROP_MULTIPLERESULTS: win32more.Windows.Win32.System.Search.DBPROPENUM = 196
DBPROP_MULTIPLESTORAGEOBJECTS: win32more.Windows.Win32.System.Search.DBPROPENUM = 80
DBPROP_MULTITABLEUPDATE: win32more.Windows.Win32.System.Search.DBPROPENUM = 81
DBPROP_NOTIFICATIONGRANULARITY: win32more.Windows.Win32.System.Search.DBPROPENUM = 198
DBPROP_NOTIFICATIONPHASES: win32more.Windows.Win32.System.Search.DBPROPENUM = 82
DBPROP_NOTIFYCOLUMNSET: win32more.Windows.Win32.System.Search.DBPROPENUM = 171
DBPROP_NOTIFYROWDELETE: win32more.Windows.Win32.System.Search.DBPROPENUM = 173
DBPROP_NOTIFYROWFIRSTCHANGE: win32more.Windows.Win32.System.Search.DBPROPENUM = 174
DBPROP_NOTIFYROWINSERT: win32more.Windows.Win32.System.Search.DBPROPENUM = 175
DBPROP_NOTIFYROWRESYNCH: win32more.Windows.Win32.System.Search.DBPROPENUM = 177
DBPROP_NOTIFYROWSETCHANGED: win32more.Windows.Win32.System.Search.DBPROPENUM = 211
DBPROP_NOTIFYROWSETRELEASE: win32more.Windows.Win32.System.Search.DBPROPENUM = 178
DBPROP_NOTIFYROWSETFETCHPOSITIONCHANGE: win32more.Windows.Win32.System.Search.DBPROPENUM = 179
DBPROP_NOTIFYROWUNDOCHANGE: win32more.Windows.Win32.System.Search.DBPROPENUM = 180
DBPROP_NOTIFYROWUNDODELETE: win32more.Windows.Win32.System.Search.DBPROPENUM = 181
DBPROP_NOTIFYROWUNDOINSERT: win32more.Windows.Win32.System.Search.DBPROPENUM = 182
DBPROP_NOTIFYROWUPDATE: win32more.Windows.Win32.System.Search.DBPROPENUM = 183
DBPROP_NULLCOLLATION: win32more.Windows.Win32.System.Search.DBPROPENUM = 83
DBPROP_OLEOBJECTS: win32more.Windows.Win32.System.Search.DBPROPENUM = 84
DBPROP_ORDERBYCOLUMNSINSELECT: win32more.Windows.Win32.System.Search.DBPROPENUM = 85
DBPROP_ORDEREDBOOKMARKS: win32more.Windows.Win32.System.Search.DBPROPENUM = 86
DBPROP_OTHERINSERT: win32more.Windows.Win32.System.Search.DBPROPENUM = 87
DBPROP_OTHERUPDATEDELETE: win32more.Windows.Win32.System.Search.DBPROPENUM = 88
DBPROP_OUTPUTPARAMETERAVAILABILITY: win32more.Windows.Win32.System.Search.DBPROPENUM = 184
DBPROP_OWNINSERT: win32more.Windows.Win32.System.Search.DBPROPENUM = 89
DBPROP_OWNUPDATEDELETE: win32more.Windows.Win32.System.Search.DBPROPENUM = 90
DBPROP_PERSISTENTIDTYPE: win32more.Windows.Win32.System.Search.DBPROPENUM = 185
DBPROP_PREPAREABORTBEHAVIOR: win32more.Windows.Win32.System.Search.DBPROPENUM = 91
DBPROP_PREPARECOMMITBEHAVIOR: win32more.Windows.Win32.System.Search.DBPROPENUM = 92
DBPROP_PROCEDURETERM: win32more.Windows.Win32.System.Search.DBPROPENUM = 93
DBPROP_PROVIDERNAME: win32more.Windows.Win32.System.Search.DBPROPENUM = 96
DBPROP_PROVIDEROLEDBVER: win32more.Windows.Win32.System.Search.DBPROPENUM = 97
DBPROP_PROVIDERVER: win32more.Windows.Win32.System.Search.DBPROPENUM = 98
DBPROP_QUICKRESTART: win32more.Windows.Win32.System.Search.DBPROPENUM = 99
DBPROP_QUOTEDIDENTIFIERCASE: win32more.Windows.Win32.System.Search.DBPROPENUM = 100
DBPROP_REENTRANTEVENTS: win32more.Windows.Win32.System.Search.DBPROPENUM = 101
DBPROP_REMOVEDELETED: win32more.Windows.Win32.System.Search.DBPROPENUM = 102
DBPROP_REPORTMULTIPLECHANGES: win32more.Windows.Win32.System.Search.DBPROPENUM = 103
DBPROP_RETURNPENDINGINSERTS: win32more.Windows.Win32.System.Search.DBPROPENUM = 189
DBPROP_ROWRESTRICT: win32more.Windows.Win32.System.Search.DBPROPENUM = 104
DBPROP_ROWSETCONVERSIONSONCOMMAND: win32more.Windows.Win32.System.Search.DBPROPENUM = 192
DBPROP_ROWTHREADMODEL: win32more.Windows.Win32.System.Search.DBPROPENUM = 105
DBPROP_SCHEMATERM: win32more.Windows.Win32.System.Search.DBPROPENUM = 106
DBPROP_SCHEMAUSAGE: win32more.Windows.Win32.System.Search.DBPROPENUM = 107
DBPROP_SERVERCURSOR: win32more.Windows.Win32.System.Search.DBPROPENUM = 108
DBPROP_SESS_AUTOCOMMITISOLEVELS: win32more.Windows.Win32.System.Search.DBPROPENUM = 190
DBPROP_SQLSUPPORT: win32more.Windows.Win32.System.Search.DBPROPENUM = 109
DBPROP_STRONGIDENTITY: win32more.Windows.Win32.System.Search.DBPROPENUM = 119
DBPROP_STRUCTUREDSTORAGE: win32more.Windows.Win32.System.Search.DBPROPENUM = 111
DBPROP_SUBQUERIES: win32more.Windows.Win32.System.Search.DBPROPENUM = 112
DBPROP_SUPPORTEDTXNDDL: win32more.Windows.Win32.System.Search.DBPROPENUM = 161
DBPROP_SUPPORTEDTXNISOLEVELS: win32more.Windows.Win32.System.Search.DBPROPENUM = 113
DBPROP_SUPPORTEDTXNISORETAIN: win32more.Windows.Win32.System.Search.DBPROPENUM = 114
DBPROP_TABLETERM: win32more.Windows.Win32.System.Search.DBPROPENUM = 115
DBPROP_TBL_TEMPTABLE: win32more.Windows.Win32.System.Search.DBPROPENUM = 140
DBPROP_TRANSACTEDOBJECT: win32more.Windows.Win32.System.Search.DBPROPENUM = 116
DBPROP_UPDATABILITY: win32more.Windows.Win32.System.Search.DBPROPENUM = 117
DBPROP_USERNAME: win32more.Windows.Win32.System.Search.DBPROPENUM = 118
DBPROPENUM15 = Int32
DBPROP_FILTERCOMPAREOPS: win32more.Windows.Win32.System.Search.DBPROPENUM15 = 209
DBPROP_FINDCOMPAREOPS: win32more.Windows.Win32.System.Search.DBPROPENUM15 = 210
DBPROP_IChapteredRowset: win32more.Windows.Win32.System.Search.DBPROPENUM15 = 202
DBPROP_IDBAsynchStatus: win32more.Windows.Win32.System.Search.DBPROPENUM15 = 203
DBPROP_IRowsetFind: win32more.Windows.Win32.System.Search.DBPROPENUM15 = 204
DBPROP_IRowsetView: win32more.Windows.Win32.System.Search.DBPROPENUM15 = 212
DBPROP_IViewChapter: win32more.Windows.Win32.System.Search.DBPROPENUM15 = 213
DBPROP_IViewFilter: win32more.Windows.Win32.System.Search.DBPROPENUM15 = 214
DBPROP_IViewRowset: win32more.Windows.Win32.System.Search.DBPROPENUM15 = 215
DBPROP_IViewSort: win32more.Windows.Win32.System.Search.DBPROPENUM15 = 216
DBPROP_INIT_ASYNCH: win32more.Windows.Win32.System.Search.DBPROPENUM15 = 200
DBPROP_MAXOPENCHAPTERS: win32more.Windows.Win32.System.Search.DBPROPENUM15 = 199
DBPROP_MAXORSINFILTER: win32more.Windows.Win32.System.Search.DBPROPENUM15 = 205
DBPROP_MAXSORTCOLUMNS: win32more.Windows.Win32.System.Search.DBPROPENUM15 = 206
DBPROP_ROWSET_ASYNCH: win32more.Windows.Win32.System.Search.DBPROPENUM15 = 201
DBPROP_SORTONINDEX: win32more.Windows.Win32.System.Search.DBPROPENUM15 = 207
DBPROPENUM20 = Int32
DBPROP_IMultipleResults: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 217
DBPROP_DATASOURCE_TYPE: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 251
MDPROP_AXES: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 252
MDPROP_FLATTENING_SUPPORT: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 253
MDPROP_MDX_JOINCUBES: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 254
MDPROP_NAMED_LEVELS: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 255
MDPROP_RANGEROWSET: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 256
MDPROP_MDX_SLICER: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 218
MDPROP_MDX_CUBEQUALIFICATION: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 219
MDPROP_MDX_OUTERREFERENCE: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 220
MDPROP_MDX_QUERYBYPROPERTY: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 221
MDPROP_MDX_CASESUPPORT: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 222
MDPROP_MDX_STRING_COMPOP: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 224
MDPROP_MDX_DESCFLAGS: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 225
MDPROP_MDX_SET_FUNCTIONS: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 226
MDPROP_MDX_MEMBER_FUNCTIONS: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 227
MDPROP_MDX_NUMERIC_FUNCTIONS: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 228
MDPROP_MDX_FORMULAS: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 229
MDPROP_AGGREGATECELL_UPDATE: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 230
MDPROP_MDX_AGGREGATECELL_UPDATE: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 230
MDPROP_MDX_OBJQUALIFICATION: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 261
MDPROP_MDX_NONMEASURE_EXPRESSIONS: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 262
DBPROP_ACCESSORDER: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 231
DBPROP_BOOKMARKINFO: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 232
DBPROP_INIT_CATALOG: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 233
DBPROP_ROW_BULKOPS: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 234
DBPROP_PROVIDERFRIENDLYNAME: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 235
DBPROP_LOCKMODE: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 236
DBPROP_MULTIPLECONNECTIONS: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 237
DBPROP_UNIQUEROWS: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 238
DBPROP_SERVERDATAONINSERT: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 239
DBPROP_STORAGEFLAGS: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 240
DBPROP_CONNECTIONSTATUS: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 244
DBPROP_ALTERCOLUMN: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 245
DBPROP_COLUMNLCID: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 246
DBPROP_RESETDATASOURCE: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 247
DBPROP_INIT_OLEDBSERVICES: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 248
DBPROP_IRowsetRefresh: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 249
DBPROP_SERVERNAME: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 250
DBPROP_IParentRowset: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 257
DBPROP_HIDDENCOLUMNS: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 258
DBPROP_PROVIDERMEMORY: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 259
DBPROP_CLIENTCURSOR: win32more.Windows.Win32.System.Search.DBPROPENUM20 = 260
DBPROPENUM21 = Int32
DBPROP_TRUSTEE_USERNAME: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 241
DBPROP_TRUSTEE_AUTHENTICATION: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 242
DBPROP_TRUSTEE_NEWAUTHENTICATION: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 243
DBPROP_IRow: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 263
DBPROP_IRowChange: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 264
DBPROP_IRowSchemaChange: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 265
DBPROP_IGetRow: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 266
DBPROP_IScopedOperations: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 267
DBPROP_IBindResource: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 268
DBPROP_ICreateRow: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 269
DBPROP_INIT_BINDFLAGS: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 270
DBPROP_INIT_LOCKOWNER: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 271
DBPROP_GENERATEURL: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 273
DBPROP_IDBBinderProperties: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 274
DBPROP_IColumnsInfo2: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 275
DBPROP_IRegisterProvider: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 276
DBPROP_IGetSession: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 277
DBPROP_IGetSourceRow: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 278
DBPROP_IRowsetCurrentIndex: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 279
DBPROP_OPENROWSETSUPPORT: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 280
DBPROP_COL_ISLONG: win32more.Windows.Win32.System.Search.DBPROPENUM21 = 281
DBPROPENUM25 = Int32
DBPROP_COL_SEED: win32more.Windows.Win32.System.Search.DBPROPENUM25 = 282
DBPROP_COL_INCREMENT: win32more.Windows.Win32.System.Search.DBPROPENUM25 = 283
DBPROP_INIT_GENERALTIMEOUT: win32more.Windows.Win32.System.Search.DBPROPENUM25 = 284
DBPROP_COMSERVICES: win32more.Windows.Win32.System.Search.DBPROPENUM25 = 285
DBPROPENUM25_DEPRECATED = Int32
DBPROP_ICommandCost: win32more.Windows.Win32.System.Search.DBPROPENUM25_DEPRECATED = 141
DBPROP_ICommandTree: win32more.Windows.Win32.System.Search.DBPROPENUM25_DEPRECATED = 142
DBPROP_ICommandValidate: win32more.Windows.Win32.System.Search.DBPROPENUM25_DEPRECATED = 143
DBPROP_IDBSchemaCommand: win32more.Windows.Win32.System.Search.DBPROPENUM25_DEPRECATED = 144
DBPROP_IProvideMoniker: win32more.Windows.Win32.System.Search.DBPROPENUM25_DEPRECATED = 125
DBPROP_IQuery: win32more.Windows.Win32.System.Search.DBPROPENUM25_DEPRECATED = 146
DBPROP_IReadData: win32more.Windows.Win32.System.Search.DBPROPENUM25_DEPRECATED = 147
DBPROP_IRowsetAsynch: win32more.Windows.Win32.System.Search.DBPROPENUM25_DEPRECATED = 148
DBPROP_IRowsetCopyRows: win32more.Windows.Win32.System.Search.DBPROPENUM25_DEPRECATED = 149
DBPROP_IRowsetKeys: win32more.Windows.Win32.System.Search.DBPROPENUM25_DEPRECATED = 151
DBPROP_IRowsetNewRowAfter: win32more.Windows.Win32.System.Search.DBPROPENUM25_DEPRECATED = 152
DBPROP_IRowsetNextRowset: win32more.Windows.Win32.System.Search.DBPROPENUM25_DEPRECATED = 153
DBPROP_IRowsetWatchAll: win32more.Windows.Win32.System.Search.DBPROPENUM25_DEPRECATED = 155
DBPROP_IRowsetWatchNotify: win32more.Windows.Win32.System.Search.DBPROPENUM25_DEPRECATED = 156
DBPROP_IRowsetWatchRegion: win32more.Windows.Win32.System.Search.DBPROPENUM25_DEPRECATED = 157
DBPROP_IRowsetWithParameters: win32more.Windows.Win32.System.Search.DBPROPENUM25_DEPRECATED = 158
DBPROPENUM26 = Int32
DBPROP_OUTPUTSTREAM: win32more.Windows.Win32.System.Search.DBPROPENUM26 = 286
DBPROP_OUTPUTENCODING: win32more.Windows.Win32.System.Search.DBPROPENUM26 = 287
DBPROP_TABLESTATISTICS: win32more.Windows.Win32.System.Search.DBPROPENUM26 = 288
DBPROP_SKIPROWCOUNTRESULTS: win32more.Windows.Win32.System.Search.DBPROPENUM26 = 291
DBPROP_IRowsetBookmark: win32more.Windows.Win32.System.Search.DBPROPENUM26 = 292
MDPROP_VISUALMODE: win32more.Windows.Win32.System.Search.DBPROPENUM26 = 293
DBPROPENUMDEPRECATED = Int32
DBPROP_IRowsetExactScroll: win32more.Windows.Win32.System.Search.DBPROPENUMDEPRECATED = 154
DBPROP_MARSHALLABLE: win32more.Windows.Win32.System.Search.DBPROPENUMDEPRECATED = 197
DBPROP_FILTEROPS: win32more.Windows.Win32.System.Search.DBPROPENUMDEPRECATED = 208
DBPROPFLAGSENUM = Int32
DBPROPFLAGS_NOTSUPPORTED: win32more.Windows.Win32.System.Search.DBPROPFLAGSENUM = 0
DBPROPFLAGS_COLUMN: win32more.Windows.Win32.System.Search.DBPROPFLAGSENUM = 1
DBPROPFLAGS_DATASOURCE: win32more.Windows.Win32.System.Search.DBPROPFLAGSENUM = 2
DBPROPFLAGS_DATASOURCECREATE: win32more.Windows.Win32.System.Search.DBPROPFLAGSENUM = 4
DBPROPFLAGS_DATASOURCEINFO: win32more.Windows.Win32.System.Search.DBPROPFLAGSENUM = 8
DBPROPFLAGS_DBINIT: win32more.Windows.Win32.System.Search.DBPROPFLAGSENUM = 16
DBPROPFLAGS_INDEX: win32more.Windows.Win32.System.Search.DBPROPFLAGSENUM = 32
DBPROPFLAGS_ROWSET: win32more.Windows.Win32.System.Search.DBPROPFLAGSENUM = 64
DBPROPFLAGS_TABLE: win32more.Windows.Win32.System.Search.DBPROPFLAGSENUM = 128
DBPROPFLAGS_COLUMNOK: win32more.Windows.Win32.System.Search.DBPROPFLAGSENUM = 256
DBPROPFLAGS_READ: win32more.Windows.Win32.System.Search.DBPROPFLAGSENUM = 512
DBPROPFLAGS_WRITE: win32more.Windows.Win32.System.Search.DBPROPFLAGSENUM = 1024
DBPROPFLAGS_REQUIRED: win32more.Windows.Win32.System.Search.DBPROPFLAGSENUM = 2048
DBPROPFLAGS_SESSION: win32more.Windows.Win32.System.Search.DBPROPFLAGSENUM = 4096
DBPROPFLAGSENUM21 = Int32
DBPROPFLAGS_TRUSTEE: win32more.Windows.Win32.System.Search.DBPROPFLAGSENUM21 = 8192
DBPROPFLAGSENUM25 = Int32
DBPROPFLAGS_VIEW: win32more.Windows.Win32.System.Search.DBPROPFLAGSENUM25 = 16384
DBPROPFLAGSENUM26 = Int32
DBPROPFLAGS_STREAM: win32more.Windows.Win32.System.Search.DBPROPFLAGSENUM26 = 32768
if ARCH in 'X64,ARM64':
    class DBPROPIDSET(Structure):
        rgPropertyIDs: POINTER(UInt32)
        cPropertyIDs: UInt32
        guidPropertySet: Guid
elif ARCH in 'X86':
    class DBPROPIDSET(Structure):
        rgPropertyIDs: POINTER(UInt32)
        cPropertyIDs: UInt32
        guidPropertySet: Guid
        _pack_ = 2
if ARCH in 'X64,ARM64':
    class DBPROPINFO(Structure):
        pwszDescription: win32more.Windows.Win32.Foundation.PWSTR
        dwPropertyID: UInt32
        dwFlags: UInt32
        vtType: win32more.Windows.Win32.System.Variant.VARENUM
        vValues: win32more.Windows.Win32.System.Variant.VARIANT
elif ARCH in 'X86':
    class DBPROPINFO(Structure):
        pwszDescription: win32more.Windows.Win32.Foundation.PWSTR
        dwPropertyID: UInt32
        dwFlags: UInt32
        vtType: win32more.Windows.Win32.System.Variant.VARENUM
        vValues: win32more.Windows.Win32.System.Variant.VARIANT
        _pack_ = 2
if ARCH in 'X64,ARM64':
    class DBPROPINFOSET(Structure):
        rgPropertyInfos: POINTER(win32more.Windows.Win32.System.Search.DBPROPINFO)
        cPropertyInfos: UInt32
        guidPropertySet: Guid
elif ARCH in 'X86':
    class DBPROPINFOSET(Structure):
        rgPropertyInfos: POINTER(win32more.Windows.Win32.System.Search.DBPROPINFO)
        cPropertyInfos: UInt32
        guidPropertySet: Guid
        _pack_ = 2
DBPROPOPTIONSENUM = Int32
DBPROPOPTIONS_REQUIRED: win32more.Windows.Win32.System.Search.DBPROPOPTIONSENUM = 0
DBPROPOPTIONS_SETIFCHEAP: win32more.Windows.Win32.System.Search.DBPROPOPTIONSENUM = 1
DBPROPOPTIONS_OPTIONAL: win32more.Windows.Win32.System.Search.DBPROPOPTIONSENUM = 1
if ARCH in 'X64,ARM64':
    class DBPROPSET(Structure):
        rgProperties: POINTER(win32more.Windows.Win32.System.Search.DBPROP)
        cProperties: UInt32
        guidPropertySet: Guid
elif ARCH in 'X86':
    class DBPROPSET(Structure):
        rgProperties: POINTER(win32more.Windows.Win32.System.Search.DBPROP)
        cProperties: UInt32
        guidPropertySet: Guid
        _pack_ = 2
DBPROPSTATUSENUM = Int32
DBPROPSTATUS_OK: win32more.Windows.Win32.System.Search.DBPROPSTATUSENUM = 0
DBPROPSTATUS_NOTSUPPORTED: win32more.Windows.Win32.System.Search.DBPROPSTATUSENUM = 1
DBPROPSTATUS_BADVALUE: win32more.Windows.Win32.System.Search.DBPROPSTATUSENUM = 2
DBPROPSTATUS_BADOPTION: win32more.Windows.Win32.System.Search.DBPROPSTATUSENUM = 3
DBPROPSTATUS_BADCOLUMN: win32more.Windows.Win32.System.Search.DBPROPSTATUSENUM = 4
DBPROPSTATUS_NOTALLSETTABLE: win32more.Windows.Win32.System.Search.DBPROPSTATUSENUM = 5
DBPROPSTATUS_NOTSETTABLE: win32more.Windows.Win32.System.Search.DBPROPSTATUSENUM = 6
DBPROPSTATUS_NOTSET: win32more.Windows.Win32.System.Search.DBPROPSTATUSENUM = 7
DBPROPSTATUS_CONFLICTING: win32more.Windows.Win32.System.Search.DBPROPSTATUSENUM = 8
DBPROPSTATUSENUM21 = Int32
DBPROPSTATUS_NOTAVAILABLE: win32more.Windows.Win32.System.Search.DBPROPSTATUSENUM21 = 9
DBRANGEENUM = Int32
DBRANGE_INCLUSIVESTART: win32more.Windows.Win32.System.Search.DBRANGEENUM = 0
DBRANGE_INCLUSIVEEND: win32more.Windows.Win32.System.Search.DBRANGEENUM = 0
DBRANGE_EXCLUSIVESTART: win32more.Windows.Win32.System.Search.DBRANGEENUM = 1
DBRANGE_EXCLUSIVEEND: win32more.Windows.Win32.System.Search.DBRANGEENUM = 2
DBRANGE_EXCLUDENULLS: win32more.Windows.Win32.System.Search.DBRANGEENUM = 4
DBRANGE_PREFIX: win32more.Windows.Win32.System.Search.DBRANGEENUM = 8
DBRANGE_MATCH: win32more.Windows.Win32.System.Search.DBRANGEENUM = 16
DBRANGEENUM20 = Int32
DBRANGE_MATCH_N_SHIFT: win32more.Windows.Win32.System.Search.DBRANGEENUM20 = 24
DBRANGE_MATCH_N_MASK: win32more.Windows.Win32.System.Search.DBRANGEENUM20 = 255
DBREASONENUM = Int32
DBREASON_ROWSET_FETCHPOSITIONCHANGE: win32more.Windows.Win32.System.Search.DBREASONENUM = 0
DBREASON_ROWSET_RELEASE: win32more.Windows.Win32.System.Search.DBREASONENUM = 1
DBREASON_COLUMN_SET: win32more.Windows.Win32.System.Search.DBREASONENUM = 2
DBREASON_COLUMN_RECALCULATED: win32more.Windows.Win32.System.Search.DBREASONENUM = 3
DBREASON_ROW_ACTIVATE: win32more.Windows.Win32.System.Search.DBREASONENUM = 4
DBREASON_ROW_RELEASE: win32more.Windows.Win32.System.Search.DBREASONENUM = 5
DBREASON_ROW_DELETE: win32more.Windows.Win32.System.Search.DBREASONENUM = 6
DBREASON_ROW_FIRSTCHANGE: win32more.Windows.Win32.System.Search.DBREASONENUM = 7
DBREASON_ROW_INSERT: win32more.Windows.Win32.System.Search.DBREASONENUM = 8
DBREASON_ROW_RESYNCH: win32more.Windows.Win32.System.Search.DBREASONENUM = 9
DBREASON_ROW_UNDOCHANGE: win32more.Windows.Win32.System.Search.DBREASONENUM = 10
DBREASON_ROW_UNDOINSERT: win32more.Windows.Win32.System.Search.DBREASONENUM = 11
DBREASON_ROW_UNDODELETE: win32more.Windows.Win32.System.Search.DBREASONENUM = 12
DBREASON_ROW_UPDATE: win32more.Windows.Win32.System.Search.DBREASONENUM = 13
DBREASON_ROWSET_CHANGED: win32more.Windows.Win32.System.Search.DBREASONENUM = 14
DBREASONENUM15 = Int32
DBREASON_ROWPOSITION_CHANGED: win32more.Windows.Win32.System.Search.DBREASONENUM15 = 15
DBREASON_ROWPOSITION_CHAPTERCHANGED: win32more.Windows.Win32.System.Search.DBREASONENUM15 = 16
DBREASON_ROWPOSITION_CLEARED: win32more.Windows.Win32.System.Search.DBREASONENUM15 = 17
DBREASON_ROW_ASYNCHINSERT: win32more.Windows.Win32.System.Search.DBREASONENUM15 = 18
DBREASONENUM25 = Int32
DBREASON_ROWSET_ROWSADDED: win32more.Windows.Win32.System.Search.DBREASONENUM25 = 19
DBREASON_ROWSET_POPULATIONCOMPLETE: win32more.Windows.Win32.System.Search.DBREASONENUM25 = 20
DBREASON_ROWSET_POPULATIONSTOPPED: win32more.Windows.Win32.System.Search.DBREASONENUM25 = 21
DBRESOURCEKINDENUM = Int32
DBRESOURCE_INVALID: win32more.Windows.Win32.System.Search.DBRESOURCEKINDENUM = 0
DBRESOURCE_TOTAL: win32more.Windows.Win32.System.Search.DBRESOURCEKINDENUM = 1
DBRESOURCE_CPU: win32more.Windows.Win32.System.Search.DBRESOURCEKINDENUM = 2
DBRESOURCE_MEMORY: win32more.Windows.Win32.System.Search.DBRESOURCEKINDENUM = 3
DBRESOURCE_DISK: win32more.Windows.Win32.System.Search.DBRESOURCEKINDENUM = 4
DBRESOURCE_NETWORK: win32more.Windows.Win32.System.Search.DBRESOURCEKINDENUM = 5
DBRESOURCE_RESPONSE: win32more.Windows.Win32.System.Search.DBRESOURCEKINDENUM = 6
DBRESOURCE_ROWS: win32more.Windows.Win32.System.Search.DBRESOURCEKINDENUM = 7
DBRESOURCE_OTHER: win32more.Windows.Win32.System.Search.DBRESOURCEKINDENUM = 8
DBRESULTFLAGENUM = Int32
DBRESULTFLAG_DEFAULT: win32more.Windows.Win32.System.Search.DBRESULTFLAGENUM = 0
DBRESULTFLAG_ROWSET: win32more.Windows.Win32.System.Search.DBRESULTFLAGENUM = 1
DBRESULTFLAG_ROW: win32more.Windows.Win32.System.Search.DBRESULTFLAGENUM = 2
DBROWCHANGEKINDENUM = Int32
DBROWCHANGEKIND_INSERT: win32more.Windows.Win32.System.Search.DBROWCHANGEKINDENUM = 0
DBROWCHANGEKIND_DELETE: win32more.Windows.Win32.System.Search.DBROWCHANGEKINDENUM = 1
DBROWCHANGEKIND_UPDATE: win32more.Windows.Win32.System.Search.DBROWCHANGEKINDENUM = 2
DBROWCHANGEKIND_COUNT: win32more.Windows.Win32.System.Search.DBROWCHANGEKINDENUM = 3
DBROWSTATUSENUM = Int32
DBROWSTATUS_S_OK: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 0
DBROWSTATUS_S_MULTIPLECHANGES: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 2
DBROWSTATUS_S_PENDINGCHANGES: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 3
DBROWSTATUS_E_CANCELED: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 4
DBROWSTATUS_E_CANTRELEASE: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 6
DBROWSTATUS_E_CONCURRENCYVIOLATION: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 7
DBROWSTATUS_E_DELETED: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 8
DBROWSTATUS_E_PENDINGINSERT: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 9
DBROWSTATUS_E_NEWLYINSERTED: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 10
DBROWSTATUS_E_INTEGRITYVIOLATION: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 11
DBROWSTATUS_E_INVALID: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 12
DBROWSTATUS_E_MAXPENDCHANGESEXCEEDED: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 13
DBROWSTATUS_E_OBJECTOPEN: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 14
DBROWSTATUS_E_OUTOFMEMORY: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 15
DBROWSTATUS_E_PERMISSIONDENIED: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 16
DBROWSTATUS_E_LIMITREACHED: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 17
DBROWSTATUS_E_SCHEMAVIOLATION: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 18
DBROWSTATUS_E_FAIL: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM = 19
DBROWSTATUSENUM20 = Int32
DBROWSTATUS_S_NOCHANGE: win32more.Windows.Win32.System.Search.DBROWSTATUSENUM20 = 20
if ARCH in 'X64,ARM64':
    class DBROWWATCHCHANGE(Structure):
        hRegion: UIntPtr
        eChangeKind: UInt32
        hRow: UIntPtr
        iRow: UIntPtr
elif ARCH in 'X86':
    class DBROWWATCHCHANGE(Structure):
        hRegion: UIntPtr
        eChangeKind: UInt32
        hRow: UIntPtr
        iRow: UIntPtr
        _pack_ = 2
DBSEEKENUM = Int32
DBSEEK_INVALID: win32more.Windows.Win32.System.Search.DBSEEKENUM = 0
DBSEEK_FIRSTEQ: win32more.Windows.Win32.System.Search.DBSEEKENUM = 1
DBSEEK_LASTEQ: win32more.Windows.Win32.System.Search.DBSEEKENUM = 2
DBSEEK_AFTEREQ: win32more.Windows.Win32.System.Search.DBSEEKENUM = 4
DBSEEK_AFTER: win32more.Windows.Win32.System.Search.DBSEEKENUM = 8
DBSEEK_BEFOREEQ: win32more.Windows.Win32.System.Search.DBSEEKENUM = 16
DBSEEK_BEFORE: win32more.Windows.Win32.System.Search.DBSEEKENUM = 32
DBSORTENUM = Int32
DBSORT_ASCENDING: win32more.Windows.Win32.System.Search.DBSORTENUM = 0
DBSORT_DESCENDING: win32more.Windows.Win32.System.Search.DBSORTENUM = 1
DBSOURCETYPEENUM = Int32
DBSOURCETYPE_DATASOURCE: win32more.Windows.Win32.System.Search.DBSOURCETYPEENUM = 1
DBSOURCETYPE_ENUMERATOR: win32more.Windows.Win32.System.Search.DBSOURCETYPEENUM = 2
DBSOURCETYPEENUM20 = Int32
DBSOURCETYPE_DATASOURCE_TDP: win32more.Windows.Win32.System.Search.DBSOURCETYPEENUM20 = 1
DBSOURCETYPE_DATASOURCE_MDP: win32more.Windows.Win32.System.Search.DBSOURCETYPEENUM20 = 3
DBSOURCETYPEENUM25 = Int32
DBSOURCETYPE_BINDER: win32more.Windows.Win32.System.Search.DBSOURCETYPEENUM25 = 4
DBSTATUSENUM = Int32
DBSTATUS_S_OK: win32more.Windows.Win32.System.Search.DBSTATUSENUM = 0
DBSTATUS_E_BADACCESSOR: win32more.Windows.Win32.System.Search.DBSTATUSENUM = 1
DBSTATUS_E_CANTCONVERTVALUE: win32more.Windows.Win32.System.Search.DBSTATUSENUM = 2
DBSTATUS_S_ISNULL: win32more.Windows.Win32.System.Search.DBSTATUSENUM = 3
DBSTATUS_S_TRUNCATED: win32more.Windows.Win32.System.Search.DBSTATUSENUM = 4
DBSTATUS_E_SIGNMISMATCH: win32more.Windows.Win32.System.Search.DBSTATUSENUM = 5
DBSTATUS_E_DATAOVERFLOW: win32more.Windows.Win32.System.Search.DBSTATUSENUM = 6
DBSTATUS_E_CANTCREATE: win32more.Windows.Win32.System.Search.DBSTATUSENUM = 7
DBSTATUS_E_UNAVAILABLE: win32more.Windows.Win32.System.Search.DBSTATUSENUM = 8
DBSTATUS_E_PERMISSIONDENIED: win32more.Windows.Win32.System.Search.DBSTATUSENUM = 9
DBSTATUS_E_INTEGRITYVIOLATION: win32more.Windows.Win32.System.Search.DBSTATUSENUM = 10
DBSTATUS_E_SCHEMAVIOLATION: win32more.Windows.Win32.System.Search.DBSTATUSENUM = 11
DBSTATUS_E_BADSTATUS: win32more.Windows.Win32.System.Search.DBSTATUSENUM = 12
DBSTATUS_S_DEFAULT: win32more.Windows.Win32.System.Search.DBSTATUSENUM = 13
DBSTATUSENUM20 = Int32
MDSTATUS_S_CELLEMPTY: win32more.Windows.Win32.System.Search.DBSTATUSENUM20 = 14
DBSTATUS_S_IGNORE: win32more.Windows.Win32.System.Search.DBSTATUSENUM20 = 15
DBSTATUSENUM21 = Int32
DBSTATUS_E_DOESNOTEXIST: win32more.Windows.Win32.System.Search.DBSTATUSENUM21 = 16
DBSTATUS_E_INVALIDURL: win32more.Windows.Win32.System.Search.DBSTATUSENUM21 = 17
DBSTATUS_E_RESOURCELOCKED: win32more.Windows.Win32.System.Search.DBSTATUSENUM21 = 18
DBSTATUS_E_RESOURCEEXISTS: win32more.Windows.Win32.System.Search.DBSTATUSENUM21 = 19
DBSTATUS_E_CANNOTCOMPLETE: win32more.Windows.Win32.System.Search.DBSTATUSENUM21 = 20
DBSTATUS_E_VOLUMENOTFOUND: win32more.Windows.Win32.System.Search.DBSTATUSENUM21 = 21
DBSTATUS_E_OUTOFSPACE: win32more.Windows.Win32.System.Search.DBSTATUSENUM21 = 22
DBSTATUS_S_CANNOTDELETESOURCE: win32more.Windows.Win32.System.Search.DBSTATUSENUM21 = 23
DBSTATUS_E_READONLY: win32more.Windows.Win32.System.Search.DBSTATUSENUM21 = 24
DBSTATUS_E_RESOURCEOUTOFSCOPE: win32more.Windows.Win32.System.Search.DBSTATUSENUM21 = 25
DBSTATUS_S_ALREADYEXISTS: win32more.Windows.Win32.System.Search.DBSTATUSENUM21 = 26
DBSTATUSENUM25 = Int32
DBSTATUS_E_CANCELED: win32more.Windows.Win32.System.Search.DBSTATUSENUM25 = 27
DBSTATUS_E_NOTCOLLECTION: win32more.Windows.Win32.System.Search.DBSTATUSENUM25 = 28
DBSTATUSENUM26 = Int32
DBSTATUS_S_ROWSETCOLUMN: win32more.Windows.Win32.System.Search.DBSTATUSENUM26 = 29
DBTABLESTATISTICSTYPE26 = Int32
DBSTAT_HISTOGRAM: win32more.Windows.Win32.System.Search.DBTABLESTATISTICSTYPE26 = 1
DBSTAT_COLUMN_CARDINALITY: win32more.Windows.Win32.System.Search.DBTABLESTATISTICSTYPE26 = 2
DBSTAT_TUPLE_CARDINALITY: win32more.Windows.Win32.System.Search.DBTABLESTATISTICSTYPE26 = 4
class DBTIME(Structure):
    hour: UInt16
    minute: UInt16
    second: UInt16
if ARCH in 'X64,ARM64':
    class DBTIMESTAMP(Structure):
        year: Int16
        month: UInt16
        day: UInt16
        hour: UInt16
        minute: UInt16
        second: UInt16
        fraction: UInt32
elif ARCH in 'X86':
    class DBTIMESTAMP(Structure):
        year: Int16
        month: UInt16
        day: UInt16
        hour: UInt16
        minute: UInt16
        second: UInt16
        fraction: UInt32
        _pack_ = 2
DBTYPEENUM = Int32
DBTYPE_EMPTY: win32more.Windows.Win32.System.Search.DBTYPEENUM = 0
DBTYPE_NULL: win32more.Windows.Win32.System.Search.DBTYPEENUM = 1
DBTYPE_I2: win32more.Windows.Win32.System.Search.DBTYPEENUM = 2
DBTYPE_I4: win32more.Windows.Win32.System.Search.DBTYPEENUM = 3
DBTYPE_R4: win32more.Windows.Win32.System.Search.DBTYPEENUM = 4
DBTYPE_R8: win32more.Windows.Win32.System.Search.DBTYPEENUM = 5
DBTYPE_CY: win32more.Windows.Win32.System.Search.DBTYPEENUM = 6
DBTYPE_DATE: win32more.Windows.Win32.System.Search.DBTYPEENUM = 7
DBTYPE_BSTR: win32more.Windows.Win32.System.Search.DBTYPEENUM = 8
DBTYPE_IDISPATCH: win32more.Windows.Win32.System.Search.DBTYPEENUM = 9
DBTYPE_ERROR: win32more.Windows.Win32.System.Search.DBTYPEENUM = 10
DBTYPE_BOOL: win32more.Windows.Win32.System.Search.DBTYPEENUM = 11
DBTYPE_VARIANT: win32more.Windows.Win32.System.Search.DBTYPEENUM = 12
DBTYPE_IUNKNOWN: win32more.Windows.Win32.System.Search.DBTYPEENUM = 13
DBTYPE_DECIMAL: win32more.Windows.Win32.System.Search.DBTYPEENUM = 14
DBTYPE_UI1: win32more.Windows.Win32.System.Search.DBTYPEENUM = 17
DBTYPE_ARRAY: win32more.Windows.Win32.System.Search.DBTYPEENUM = 8192
DBTYPE_BYREF: win32more.Windows.Win32.System.Search.DBTYPEENUM = 16384
DBTYPE_I1: win32more.Windows.Win32.System.Search.DBTYPEENUM = 16
DBTYPE_UI2: win32more.Windows.Win32.System.Search.DBTYPEENUM = 18
DBTYPE_UI4: win32more.Windows.Win32.System.Search.DBTYPEENUM = 19
DBTYPE_I8: win32more.Windows.Win32.System.Search.DBTYPEENUM = 20
DBTYPE_UI8: win32more.Windows.Win32.System.Search.DBTYPEENUM = 21
DBTYPE_GUID: win32more.Windows.Win32.System.Search.DBTYPEENUM = 72
DBTYPE_VECTOR: win32more.Windows.Win32.System.Search.DBTYPEENUM = 4096
DBTYPE_RESERVED: win32more.Windows.Win32.System.Search.DBTYPEENUM = 32768
DBTYPE_BYTES: win32more.Windows.Win32.System.Search.DBTYPEENUM = 128
DBTYPE_STR: win32more.Windows.Win32.System.Search.DBTYPEENUM = 129
DBTYPE_WSTR: win32more.Windows.Win32.System.Search.DBTYPEENUM = 130
DBTYPE_NUMERIC: win32more.Windows.Win32.System.Search.DBTYPEENUM = 131
DBTYPE_UDT: win32more.Windows.Win32.System.Search.DBTYPEENUM = 132
DBTYPE_DBDATE: win32more.Windows.Win32.System.Search.DBTYPEENUM = 133
DBTYPE_DBTIME: win32more.Windows.Win32.System.Search.DBTYPEENUM = 134
DBTYPE_DBTIMESTAMP: win32more.Windows.Win32.System.Search.DBTYPEENUM = 135
DBTYPEENUM15 = Int32
DBTYPE_HCHAPTER: win32more.Windows.Win32.System.Search.DBTYPEENUM15 = 136
DBTYPEENUM20 = Int32
DBTYPE_FILETIME: win32more.Windows.Win32.System.Search.DBTYPEENUM20 = 64
DBTYPE_PROPVARIANT: win32more.Windows.Win32.System.Search.DBTYPEENUM20 = 138
DBTYPE_VARNUMERIC: win32more.Windows.Win32.System.Search.DBTYPEENUM20 = 139
DBUPDELRULEENUM = Int32
DBUPDELRULE_NOACTION: win32more.Windows.Win32.System.Search.DBUPDELRULEENUM = 0
DBUPDELRULE_CASCADE: win32more.Windows.Win32.System.Search.DBUPDELRULEENUM = 1
DBUPDELRULE_SETNULL: win32more.Windows.Win32.System.Search.DBUPDELRULEENUM = 2
DBUPDELRULE_SETDEFAULT: win32more.Windows.Win32.System.Search.DBUPDELRULEENUM = 3
class DBVARYBIN(Structure):
    len: Int16
    array: Byte * 8001
class DBVARYCHAR(Structure):
    len: Int16
    str: SByte * 8001
if ARCH in 'X64,ARM64':
    class DBVECTOR(Structure):
        size: UIntPtr
        ptr: VoidPtr
elif ARCH in 'X86':
    class DBVECTOR(Structure):
        size: UIntPtr
        ptr: VoidPtr
        _pack_ = 2
DBWATCHMODEENUM = Int32
DBWATCHMODE_ALL: win32more.Windows.Win32.System.Search.DBWATCHMODEENUM = 1
DBWATCHMODE_EXTEND: win32more.Windows.Win32.System.Search.DBWATCHMODEENUM = 2
DBWATCHMODE_MOVE: win32more.Windows.Win32.System.Search.DBWATCHMODEENUM = 4
DBWATCHMODE_COUNT: win32more.Windows.Win32.System.Search.DBWATCHMODEENUM = 8
DBWATCHNOTIFYENUM = Int32
DBWATCHNOTIFY_ROWSCHANGED: win32more.Windows.Win32.System.Search.DBWATCHNOTIFYENUM = 1
DBWATCHNOTIFY_QUERYDONE: win32more.Windows.Win32.System.Search.DBWATCHNOTIFYENUM = 2
DBWATCHNOTIFY_QUERYREEXECUTED: win32more.Windows.Win32.System.Search.DBWATCHNOTIFYENUM = 3
class DB_NUMERIC(Structure):
    precision: Byte
    scale: Byte
    sign: Byte
    val: Byte * 16
class DB_VARNUMERIC(Structure):
    precision: Byte
    scale: SByte
    sign: Byte
    val: Byte * 1
class DCINFO(Structure):
    eInfoType: UInt32
    vData: win32more.Windows.Win32.System.Variant.VARIANT
DCINFOTYPEENUM = Int32
DCINFOTYPE_VERSION: win32more.Windows.Win32.System.Search.DCINFOTYPEENUM = 1
DELIVERY_AGENT_FLAGS = Int32
DELIVERY_AGENT_FLAG_NO_BROADCAST: win32more.Windows.Win32.System.Search.DELIVERY_AGENT_FLAGS = 4
DELIVERY_AGENT_FLAG_NO_RESTRICTIONS: win32more.Windows.Win32.System.Search.DELIVERY_AGENT_FLAGS = 8
DELIVERY_AGENT_FLAG_SILENT_DIAL: win32more.Windows.Win32.System.Search.DELIVERY_AGENT_FLAGS = 16
DataLinks = Guid('{2206cdb2-19c1-11d1-89e0-00c04fd7a829}')
class DataSource(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7c0ffab3-cd84-11d0-949a-00a0c91110ed}')
    @commethod(3)
    def getDataMember(self, bstrDM: POINTER(UInt16), riid: POINTER(Guid), ppunk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def getDataMemberName(self, lIndex: Int32, pbstrDM: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def getDataMemberCount(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def addDataSourceListener(self, pDSL: win32more.Windows.Win32.System.Search.DataSourceListener) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def removeDataSourceListener(self, pDSL: win32more.Windows.Win32.System.Search.DataSourceListener) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class DataSourceListener(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7c0ffab2-cd84-11d0-949a-00a0c91110ed}')
    @commethod(3)
    def dataMemberChanged(self, bstrDM: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def dataMemberAdded(self, bstrDM: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def dataMemberRemoved(self, bstrDM: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class DataSourceObject(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{0ae9a4e4-18d4-11d1-b3b3-00aa00c1a924}')
EBindInfoOptions = Int32
BIO_BINDER: win32more.Windows.Win32.System.Search.EBindInfoOptions = 1
if ARCH in 'X64,ARM64':
    class ERRORINFO(Structure):
        hrError: win32more.Windows.Win32.Foundation.HRESULT
        dwMinor: UInt32
        clsid: Guid
        iid: Guid
        dispid: Int32
elif ARCH in 'X86':
    class ERRORINFO(Structure):
        hrError: win32more.Windows.Win32.Foundation.HRESULT
        dwMinor: UInt32
        clsid: Guid
        iid: Guid
        dispid: Int32
        _pack_ = 2
class FILTERED_DATA_SOURCES(Structure):
    pwcsExtension: win32more.Windows.Win32.Foundation.PWSTR
    pwcsMime: win32more.Windows.Win32.Foundation.PWSTR
    pClsid: POINTER(Guid)
    pwcsOverride: win32more.Windows.Win32.Foundation.PWSTR
FOLLOW_FLAGS = Int32
FF_INDEXCOMPLEXURLS: win32more.Windows.Win32.System.Search.FOLLOW_FLAGS = 1
FF_SUPPRESSINDEXING: win32more.Windows.Win32.System.Search.FOLLOW_FLAGS = 2
FilterRegistration = Guid('{9e175b8d-f52a-11d8-b9a5-505054503030}')
HACCESSOR = UIntPtr
class HITRANGE(Structure):
    iPosition: UInt32
    cLength: UInt32
class IAccessor(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a8c-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def AddRefAccessor(self, hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, pcRefCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateAccessor(self, dwAccessorFlags: UInt32, cBindings: UIntPtr, rgBindings: POINTER(win32more.Windows.Win32.System.Search.DBBINDING), cbRowSize: UIntPtr, phAccessor: POINTER(win32more.Windows.Win32.System.Search.HACCESSOR), rgStatus: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetBindings(self, hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, pdwAccessorFlags: POINTER(UInt32), pcBindings: POINTER(UIntPtr), prgBindings: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBBINDING))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def ReleaseAccessor(self, hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, pcRefCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAlterIndex(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733aa6-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def AlterIndex(self, pTableId: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pIndexId: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pNewIndexId: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAlterTable(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733aa5-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def AlterColumn(self, pTableId: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pColumnId: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), dwColumnDescFlags: UInt32, pColumnDesc: POINTER(win32more.Windows.Win32.System.Search.DBCOLUMNDESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AlterTable(self, pTableId: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pNewTableId: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IBindResource(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733ab1-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def Bind(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, pwszURL: win32more.Windows.Win32.Foundation.PWSTR, dwBindURLFlags: UInt32, rguid: POINTER(Guid), riid: POINTER(Guid), pAuthenticate: win32more.Windows.Win32.System.Com.IAuthenticate, pImplSession: POINTER(win32more.Windows.Win32.System.Search.DBIMPLICITSESSION), pdwBindStatus: POINTER(UInt32), ppUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IChapteredRowset(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a93-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def AddRefChapter(self, hChapter: UIntPtr, pcRefCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ReleaseChapter(self, hChapter: UIntPtr, pcRefCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IColumnMapper(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0b63e37a-9ccc-11d0-bcdb-00805fccce04}')
    @commethod(3)
    def GetPropInfoFromName(self, wcsPropName: win32more.Windows.Win32.Foundation.PWSTR, ppPropId: POINTER(POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)), pPropType: POINTER(UInt16), puiWidth: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetPropInfoFromId(self, pPropId: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pwcsName: POINTER(POINTER(UInt16)), pPropType: POINTER(UInt16), puiWidth: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def EnumPropInfo(self, iEntry: UInt32, pwcsName: POINTER(POINTER(UInt16)), ppPropId: POINTER(POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)), pPropType: POINTER(UInt16), puiWidth: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def IsMapUpToDate(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IColumnMapperCreator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0b63e37b-9ccc-11d0-bcdb-00805fccce04}')
    @commethod(3)
    def GetColumnMapper(self, wcsMachineName: win32more.Windows.Win32.Foundation.PWSTR, wcsCatalogName: win32more.Windows.Win32.Foundation.PWSTR, ppColumnMapper: POINTER(win32more.Windows.Win32.System.Search.IColumnMapper)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IColumnsInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a11-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetColumnInfo(self, pcColumns: POINTER(UIntPtr), prgInfo: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBCOLUMNINFO)), ppStringsBuffer: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MapColumnIDs(self, cColumnIDs: UIntPtr, rgColumnIDs: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), rgColumns: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IColumnsInfo2(ComPtr):
    extends: win32more.Windows.Win32.System.Search.IColumnsInfo
    _iid_ = Guid('{0c733ab8-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(5)
    def GetRestrictedColumnInfo(self, cColumnIDMasks: UIntPtr, rgColumnIDMasks: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), dwFlags: UInt32, pcColumns: POINTER(UIntPtr), prgColumnIDs: POINTER(POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)), prgColumnInfo: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBCOLUMNINFO)), ppStringsBuffer: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IColumnsRowset(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a10-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetAvailableColumns(self, pcOptColumns: POINTER(UIntPtr), prgOptColumns: POINTER(POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetColumnsRowset(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, cOptColumns: UIntPtr, rgOptColumns: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), riid: POINTER(Guid), cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET), ppColRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICommand(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a63-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def Cancel(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Execute(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, riid: POINTER(Guid), pParams: POINTER(win32more.Windows.Win32.System.Search.DBPARAMS), pcRowsAffected: POINTER(IntPtr), ppRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetDBSession(self, riid: POINTER(Guid), ppSession: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICommandCost(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a4e-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetAccumulatedCost(self, pwszRowsetName: win32more.Windows.Win32.Foundation.PWSTR, pcCostLimits: POINTER(UInt32), prgCostLimits: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBCOST))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetCostEstimate(self, pwszRowsetName: win32more.Windows.Win32.Foundation.PWSTR, pcCostEstimates: POINTER(UInt32), prgCostEstimates: POINTER(win32more.Windows.Win32.System.Search.DBCOST)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCostGoals(self, pwszRowsetName: win32more.Windows.Win32.Foundation.PWSTR, pcCostGoals: POINTER(UInt32), prgCostGoals: POINTER(win32more.Windows.Win32.System.Search.DBCOST)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetCostLimits(self, pwszRowsetName: win32more.Windows.Win32.Foundation.PWSTR, pcCostLimits: POINTER(UInt32), prgCostLimits: POINTER(win32more.Windows.Win32.System.Search.DBCOST)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetCostGoals(self, pwszRowsetName: win32more.Windows.Win32.Foundation.PWSTR, cCostGoals: UInt32, rgCostGoals: POINTER(win32more.Windows.Win32.System.Search.DBCOST)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetCostLimits(self, pwszRowsetName: win32more.Windows.Win32.Foundation.PWSTR, cCostLimits: UInt32, prgCostLimits: POINTER(win32more.Windows.Win32.System.Search.DBCOST), dwExecutionFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICommandPersist(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733aa7-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def DeleteCommand(self, pCommandID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetCurrentCommand(self, ppCommandID: POINTER(POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def LoadCommand(self, pCommandID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SaveCommand(self, pCommandID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICommandPrepare(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a26-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def Prepare(self, cExpectedRuns: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Unprepare(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICommandProperties(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a79-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetProperties(self, cPropertyIDSets: UInt32, rgPropertyIDSets: POINTER(win32more.Windows.Win32.System.Search.DBPROPIDSET), pcPropertySets: POINTER(UInt32), prgPropertySets: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBPROPSET))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetProperties(self, cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICommandStream(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733abf-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetCommandStream(self, piid: POINTER(Guid), pguidDialect: POINTER(Guid), ppCommandStream: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetCommandStream(self, riid: POINTER(Guid), rguidDialect: POINTER(Guid), pCommandStream: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICommandText(ComPtr):
    extends: win32more.Windows.Win32.System.Search.ICommand
    _iid_ = Guid('{0c733a27-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(6)
    def GetCommandText(self, pguidDialect: POINTER(Guid), ppwszCommand: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetCommandText(self, rguidDialect: POINTER(Guid), pwszCommand: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICommandValidate(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a18-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def ValidateCompletely(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ValidateSyntax(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICommandWithParameters(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a64-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetParameterInfo(self, pcParams: POINTER(UIntPtr), prgParamInfo: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBPARAMINFO)), ppNamesBuffer: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MapParameterNames(self, cParamNames: UIntPtr, rgParamNames: POINTER(win32more.Windows.Win32.Foundation.PWSTR), rgParamOrdinals: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetParameterInfo(self, cParams: UIntPtr, rgParamOrdinals: POINTER(UIntPtr), rgParamBindInfo: POINTER(win32more.Windows.Win32.System.Search.DBPARAMBINDINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICondition(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IPersistStream
    _iid_ = Guid('{0fc988d4-c935-4b97-a973-46282ea175c8}')
    @commethod(8)
    def GetConditionType(self, pNodeType: POINTER(win32more.Windows.Win32.System.Search.Common.CONDITION_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetSubConditions(self, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetComparisonInfo(self, ppszPropertyName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pcop: POINTER(win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION), ppropvar: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetValueType(self, ppszValueTypeName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetValueNormalization(self, ppszNormalization: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetInputTerms(self, ppPropertyTerm: POINTER(win32more.Windows.Win32.System.Search.IRichChunk), ppOperationTerm: POINTER(win32more.Windows.Win32.System.Search.IRichChunk), ppValueTerm: POINTER(win32more.Windows.Win32.System.Search.IRichChunk)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Clone(self, ppc: POINTER(win32more.Windows.Win32.System.Search.ICondition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICondition2(ComPtr):
    extends: win32more.Windows.Win32.System.Search.ICondition
    _iid_ = Guid('{0db8851d-2e5b-47eb-9208-d28c325a01d7}')
    @commethod(15)
    def GetLocale(self, ppszLocaleName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetLeafConditionInfo(self, ppropkey: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), pcop: POINTER(win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION), ppropvar: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IConditionFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a5efe073-b16f-474f-9f3e-9f8b497a3e08}')
    @commethod(3)
    def MakeNot(self, pcSub: win32more.Windows.Win32.System.Search.ICondition, fSimplify: win32more.Windows.Win32.Foundation.BOOL, ppcResult: POINTER(win32more.Windows.Win32.System.Search.ICondition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MakeAndOr(self, ct: win32more.Windows.Win32.System.Search.Common.CONDITION_TYPE, peuSubs: win32more.Windows.Win32.System.Com.IEnumUnknown, fSimplify: win32more.Windows.Win32.Foundation.BOOL, ppcResult: POINTER(win32more.Windows.Win32.System.Search.ICondition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def MakeLeaf(self, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, cop: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION, pszValueType: win32more.Windows.Win32.Foundation.PWSTR, ppropvar: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT), pPropertyNameTerm: win32more.Windows.Win32.System.Search.IRichChunk, pOperationTerm: win32more.Windows.Win32.System.Search.IRichChunk, pValueTerm: win32more.Windows.Win32.System.Search.IRichChunk, fExpand: win32more.Windows.Win32.Foundation.BOOL, ppcResult: POINTER(win32more.Windows.Win32.System.Search.ICondition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Resolve(self, pc: win32more.Windows.Win32.System.Search.ICondition, sqro: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_RESOLVE_OPTION, pstReferenceTime: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), ppcResolved: POINTER(win32more.Windows.Win32.System.Search.ICondition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IConditionFactory2(ComPtr):
    extends: win32more.Windows.Win32.System.Search.IConditionFactory
    _iid_ = Guid('{71d222e1-432f-429e-8c13-b6dafde5077a}')
    @commethod(7)
    def CreateTrueFalse(self, fVal: win32more.Windows.Win32.Foundation.BOOL, cco: win32more.Windows.Win32.System.Search.CONDITION_CREATION_OPTIONS, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateNegation(self, pcSub: win32more.Windows.Win32.System.Search.ICondition, cco: win32more.Windows.Win32.System.Search.CONDITION_CREATION_OPTIONS, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CreateCompoundFromObjectArray(self, ct: win32more.Windows.Win32.System.Search.Common.CONDITION_TYPE, poaSubs: win32more.Windows.Win32.UI.Shell.Common.IObjectArray, cco: win32more.Windows.Win32.System.Search.CONDITION_CREATION_OPTIONS, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CreateCompoundFromArray(self, ct: win32more.Windows.Win32.System.Search.Common.CONDITION_TYPE, ppcondSubs: POINTER(win32more.Windows.Win32.System.Search.ICondition), cSubs: UInt32, cco: win32more.Windows.Win32.System.Search.CONDITION_CREATION_OPTIONS, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateStringLeaf(self, propkey: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), cop: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION, pszValue: win32more.Windows.Win32.Foundation.PWSTR, pszLocaleName: win32more.Windows.Win32.Foundation.PWSTR, cco: win32more.Windows.Win32.System.Search.CONDITION_CREATION_OPTIONS, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def CreateIntegerLeaf(self, propkey: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), cop: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION, lValue: Int32, cco: win32more.Windows.Win32.System.Search.CONDITION_CREATION_OPTIONS, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateBooleanLeaf(self, propkey: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), cop: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION, fValue: win32more.Windows.Win32.Foundation.BOOL, cco: win32more.Windows.Win32.System.Search.CONDITION_CREATION_OPTIONS, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateLeaf(self, propkey: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), cop: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION, propvar: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT), pszSemanticType: win32more.Windows.Win32.Foundation.PWSTR, pszLocaleName: win32more.Windows.Win32.Foundation.PWSTR, pPropertyNameTerm: win32more.Windows.Win32.System.Search.IRichChunk, pOperationTerm: win32more.Windows.Win32.System.Search.IRichChunk, pValueTerm: win32more.Windows.Win32.System.Search.IRichChunk, cco: win32more.Windows.Win32.System.Search.CONDITION_CREATION_OPTIONS, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def ResolveCondition(self, pc: win32more.Windows.Win32.System.Search.ICondition, sqro: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_RESOLVE_OPTION, pstReferenceTime: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IConditionGenerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{92d2cc58-4386-45a3-b98c-7e0ce64a4117}')
    @commethod(3)
    def Initialize(self, pSchemaProvider: win32more.Windows.Win32.System.Search.ISchemaProvider) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def RecognizeNamedEntities(self, pszInputString: win32more.Windows.Win32.Foundation.PWSTR, lcidUserLocale: UInt32, pTokenCollection: win32more.Windows.Win32.System.Search.ITokenCollection, pNamedEntities: win32more.Windows.Win32.System.Search.INamedEntityCollector) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GenerateForLeaf(self, pConditionFactory: win32more.Windows.Win32.System.Search.IConditionFactory, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, cop: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION, pszValueType: win32more.Windows.Win32.Foundation.PWSTR, pszValue: win32more.Windows.Win32.Foundation.PWSTR, pszValue2: win32more.Windows.Win32.Foundation.PWSTR, pPropertyNameTerm: win32more.Windows.Win32.System.Search.IRichChunk, pOperationTerm: win32more.Windows.Win32.System.Search.IRichChunk, pValueTerm: win32more.Windows.Win32.System.Search.IRichChunk, automaticWildcard: win32more.Windows.Win32.Foundation.BOOL, pNoStringQuery: POINTER(win32more.Windows.Win32.Foundation.BOOL), ppQueryExpression: POINTER(win32more.Windows.Win32.System.Search.ICondition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def DefaultPhrase(self, pszValueType: win32more.Windows.Win32.Foundation.PWSTR, ppropvar: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT), fUseEnglish: win32more.Windows.Win32.Foundation.BOOL, ppszPhrase: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IConvertType(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a88-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def CanConvert(self, wFromType: UInt16, wToType: UInt16, dwConvertFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICreateRow(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733ab2-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def CreateRow(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, pwszURL: win32more.Windows.Win32.Foundation.PWSTR, dwBindURLFlags: UInt32, rguid: POINTER(Guid), riid: POINTER(Guid), pAuthenticate: win32more.Windows.Win32.System.Com.IAuthenticate, pImplSession: POINTER(win32more.Windows.Win32.System.Search.DBIMPLICITSESSION), pdwBindStatus: POINTER(UInt32), ppwszNewURL: POINTER(win32more.Windows.Win32.Foundation.PWSTR), ppUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDBAsynchNotify(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a96-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def OnLowResource(self, dwReserved: UIntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnProgress(self, hChapter: UIntPtr, eOperation: UInt32, ulProgress: UIntPtr, ulProgressMax: UIntPtr, eAsynchPhase: UInt32, pwszStatusText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def OnStop(self, hChapter: UIntPtr, eOperation: UInt32, hrStatus: win32more.Windows.Win32.Foundation.HRESULT, pwszStatusText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDBAsynchStatus(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a95-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def Abort(self, hChapter: UIntPtr, eOperation: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetStatus(self, hChapter: UIntPtr, eOperation: UInt32, pulProgress: POINTER(UIntPtr), pulProgressMax: POINTER(UIntPtr), peAsynchPhase: POINTER(UInt32), ppwszStatusText: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDBBinderProperties(ComPtr):
    extends: win32more.Windows.Win32.System.Search.IDBProperties
    _iid_ = Guid('{0c733ab3-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(6)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDBCreateCommand(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a1d-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def CreateCommand(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, riid: POINTER(Guid), ppCommand: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDBCreateSession(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a5d-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def CreateSession(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, riid: POINTER(Guid), ppDBSession: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDBDataSourceAdmin(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a7a-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def CreateDataSource(self, cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET), pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, riid: POINTER(Guid), ppDBSession: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DestroyDataSource(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCreationProperties(self, cPropertyIDSets: UInt32, rgPropertyIDSets: POINTER(win32more.Windows.Win32.System.Search.DBPROPIDSET), pcPropertyInfoSets: POINTER(UInt32), prgPropertyInfoSets: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBPROPINFOSET)), ppDescBuffer: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def ModifyDataSource(self, cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDBInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a89-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetKeywords(self, ppwszKeywords: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetLiteralInfo(self, cLiterals: UInt32, rgLiterals: POINTER(UInt32), pcLiteralInfo: POINTER(UInt32), prgLiteralInfo: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBLITERALINFO)), ppCharBuffer: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDBInitialize(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a8b-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def Initialize(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Uninitialize(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDBPromptInitialize(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{2206ccb0-19c1-11d1-89e0-00c04fd7a829}')
    @commethod(3)
    def PromptDataSource(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, hWndParent: win32more.Windows.Win32.Foundation.HWND, dwPromptOptions: UInt32, cSourceTypeFilter: UInt32, rgSourceTypeFilter: POINTER(UInt32), pwszszzProviderFilter: win32more.Windows.Win32.Foundation.PWSTR, riid: POINTER(Guid), ppDataSource: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def PromptFileName(self, hWndParent: win32more.Windows.Win32.Foundation.HWND, dwPromptOptions: UInt32, pwszInitialDirectory: win32more.Windows.Win32.Foundation.PWSTR, pwszInitialFile: win32more.Windows.Win32.Foundation.PWSTR, ppwszSelectedFile: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDBProperties(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a8a-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetProperties(self, cPropertyIDSets: UInt32, rgPropertyIDSets: POINTER(win32more.Windows.Win32.System.Search.DBPROPIDSET), pcPropertySets: POINTER(UInt32), prgPropertySets: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBPROPSET))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetPropertyInfo(self, cPropertyIDSets: UInt32, rgPropertyIDSets: POINTER(win32more.Windows.Win32.System.Search.DBPROPIDSET), pcPropertyInfoSets: POINTER(UInt32), prgPropertyInfoSets: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBPROPINFOSET)), ppDescBuffer: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetProperties(self, cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDBSchemaCommand(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a50-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetCommand(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, rguidSchema: POINTER(Guid), ppCommand: POINTER(win32more.Windows.Win32.System.Search.ICommand)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetSchemas(self, pcSchemas: POINTER(UInt32), prgSchemas: POINTER(POINTER(Guid))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDBSchemaRowset(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a7b-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetRowset(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, rguidSchema: POINTER(Guid), cRestrictions: UInt32, rgRestrictions: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), riid: POINTER(Guid), cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET), ppRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetSchemas(self, pcSchemas: POINTER(UInt32), prgSchemas: POINTER(POINTER(Guid)), prgRestrictionSupport: POINTER(POINTER(UInt32))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a9c-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetInfo(self, cInfo: UInt32, rgeInfoType: POINTER(UInt32), prgInfo: POINTER(POINTER(win32more.Windows.Win32.System.Search.DCINFO))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetInfo(self, cInfo: UInt32, rgInfo: POINTER(win32more.Windows.Win32.System.Search.DCINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataConvert(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a8d-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def DataConvert(self, wSrcType: UInt16, wDstType: UInt16, cbSrcLength: UIntPtr, pcbDstLength: POINTER(UIntPtr), pSrc: VoidPtr, pDst: VoidPtr, cbDstMaxLength: UIntPtr, dbsSrcStatus: UInt32, pdbsStatus: POINTER(UInt32), bPrecision: Byte, bScale: Byte, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CanConvert(self, wSrcType: UInt16, wDstType: UInt16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetConversionSize(self, wSrcType: UInt16, wDstType: UInt16, pcbSrcLength: POINTER(UIntPtr), pcbDstLength: POINTER(UIntPtr), pSrc: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataInitialize(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{2206ccb1-19c1-11d1-89e0-00c04fd7a829}')
    @commethod(3)
    def GetDataSource(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, dwClsCtx: UInt32, pwszInitializationString: win32more.Windows.Win32.Foundation.PWSTR, riid: POINTER(Guid), ppDataSource: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetInitializationString(self, pDataSource: win32more.Windows.Win32.System.Com.IUnknown, fIncludePassword: Byte, ppwszInitString: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateDBInstance(self, clsidProvider: POINTER(Guid), pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, dwClsCtx: UInt32, pwszReserved: win32more.Windows.Win32.Foundation.PWSTR, riid: POINTER(Guid), ppDataSource: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateDBInstanceEx(self, clsidProvider: POINTER(Guid), pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, dwClsCtx: UInt32, pwszReserved: win32more.Windows.Win32.Foundation.PWSTR, pServerInfo: POINTER(win32more.Windows.Win32.System.Com.COSERVERINFO), cmq: UInt32, rgmqResults: POINTER(win32more.Windows.Win32.System.Com.MULTI_QI)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def LoadStringFromStorage(self, pwszFileName: win32more.Windows.Win32.Foundation.PWSTR, ppwszInitializationString: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def WriteStringToStorage(self, pwszFileName: win32more.Windows.Win32.Foundation.PWSTR, pwszInitializationString: win32more.Windows.Win32.Foundation.PWSTR, dwCreationDisposition: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDataSourceLocator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{2206ccb2-19c1-11d1-89e0-00c04fd7a829}')
    @commethod(7)
    def get_hWnd(self, phwndParent: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_hWnd(self, hwndParent: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def PromptNew(self, ppADOConnection: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def PromptEdit(self, ppADOConnection: POINTER(win32more.Windows.Win32.System.Com.IDispatch), pbSuccess: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEntity(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{24264891-e80b-4fd3-b7ce-4ff2fae8931f}')
    @commethod(3)
    def Name(self, ppszName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Base(self, pBaseEntity: POINTER(win32more.Windows.Win32.System.Search.IEntity)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Relationships(self, riid: POINTER(Guid), pRelationships: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetRelationship(self, pszRelationName: win32more.Windows.Win32.Foundation.PWSTR, pRelationship: POINTER(win32more.Windows.Win32.System.Search.IRelationship)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def MetaData(self, riid: POINTER(Guid), pMetaData: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def NamedEntities(self, riid: POINTER(Guid), pNamedEntities: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetNamedEntity(self, pszValue: win32more.Windows.Win32.Foundation.PWSTR, ppNamedEntity: POINTER(win32more.Windows.Win32.System.Search.INamedEntity)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def DefaultPhrase(self, ppszPhrase: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumItemProperties(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f72c8d96-6dbd-11d1-a1e8-00c04fc2fbe1}')
    @commethod(3)
    def Next(self, celt: UInt32, rgelt: POINTER(win32more.Windows.Win32.System.Search.ITEMPROP), pceltFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Skip(self, celt: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, ppenum: POINTER(win32more.Windows.Win32.System.Search.IEnumItemProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetCount(self, pnCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumSearchRoots(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ab310581-ac80-11d1-8df3-00c04fb6ef52}')
    @commethod(3)
    def Next(self, celt: UInt32, rgelt: POINTER(win32more.Windows.Win32.System.Search.ISearchRoot), pceltFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Skip(self, celt: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, ppenum: POINTER(win32more.Windows.Win32.System.Search.IEnumSearchRoots)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumSearchScopeRules(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ab310581-ac80-11d1-8df3-00c04fb6ef54}')
    @commethod(3)
    def Next(self, celt: UInt32, pprgelt: POINTER(win32more.Windows.Win32.System.Search.ISearchScopeRule), pceltFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Skip(self, celt: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, ppenum: POINTER(win32more.Windows.Win32.System.Search.IEnumSearchScopeRules)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumSubscription(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f72c8d97-6dbd-11d1-a1e8-00c04fc2fbe1}')
    @commethod(3)
    def Next(self, celt: UInt32, rgelt: POINTER(Guid), pceltFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Skip(self, celt: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, ppenum: POINTER(win32more.Windows.Win32.System.Search.IEnumSubscription)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetCount(self, pnCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IErrorLookup(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a66-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetErrorDescription(self, hrError: win32more.Windows.Win32.Foundation.HRESULT, dwLookupID: UInt32, pdispparams: POINTER(win32more.Windows.Win32.System.Com.DISPPARAMS), lcid: UInt32, pbstrSource: POINTER(win32more.Windows.Win32.Foundation.BSTR), pbstrDescription: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetHelpInfo(self, hrError: win32more.Windows.Win32.Foundation.HRESULT, dwLookupID: UInt32, lcid: UInt32, pbstrHelpFile: POINTER(win32more.Windows.Win32.Foundation.BSTR), pdwHelpContext: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def ReleaseErrors(self, dwDynamicErrorID: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IErrorRecords(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a67-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def AddErrorRecord(self, pErrorInfo: POINTER(win32more.Windows.Win32.System.Search.ERRORINFO), dwLookupID: UInt32, pdispparams: POINTER(win32more.Windows.Win32.System.Com.DISPPARAMS), punkCustomError: win32more.Windows.Win32.System.Com.IUnknown, dwDynamicErrorID: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetBasicErrorInfo(self, ulRecordNum: UInt32, pErrorInfo: POINTER(win32more.Windows.Win32.System.Search.ERRORINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCustomErrorObject(self, ulRecordNum: UInt32, riid: POINTER(Guid), ppObject: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetErrorInfo(self, ulRecordNum: UInt32, lcid: UInt32, ppErrorInfo: POINTER(win32more.Windows.Win32.System.Com.IErrorInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetErrorParameters(self, ulRecordNum: UInt32, pdispparams: POINTER(win32more.Windows.Win32.System.Com.DISPPARAMS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetRecordCount(self, pcRecords: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IGetDataSource(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a75-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetDataSource(self, riid: POINTER(Guid), ppDataSource: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IGetRow(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733aaf-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetRowFromHROW(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, hRow: UIntPtr, riid: POINTER(Guid), ppUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetURLFromHROW(self, hRow: UIntPtr, ppwszURL: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IGetSession(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733aba-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetSession(self, riid: POINTER(Guid), ppSession: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IGetSourceRow(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733abb-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetSourceRow(self, riid: POINTER(Guid), ppRow: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IIndexDefinition(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a68-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def CreateIndex(self, pTableID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pIndexID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), cIndexColumnDescs: UIntPtr, rgIndexColumnDescs: POINTER(win32more.Windows.Win32.System.Search.DBINDEXCOLUMNDESC), cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET), ppIndexID: POINTER(POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DropIndex(self, pTableID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pIndexID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IInterval(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6bf0a714-3c18-430b-8b5d-83b1c234d3db}')
    @commethod(3)
    def GetLimits(self, pilkLower: POINTER(win32more.Windows.Win32.System.Search.INTERVAL_LIMIT_KIND), ppropvarLower: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT), pilkUpper: POINTER(win32more.Windows.Win32.System.Search.INTERVAL_LIMIT_KIND), ppropvarUpper: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ILoadFilter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c7310722-ac80-11d1-8df3-00c04fb6ef4f}')
    @commethod(3)
    def LoadIFilter(self, pwcsPath: win32more.Windows.Win32.Foundation.PWSTR, pFilteredSources: POINTER(win32more.Windows.Win32.System.Search.FILTERED_DATA_SOURCES), pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, fUseDefault: win32more.Windows.Win32.Foundation.BOOL, pFilterClsid: POINTER(Guid), SearchDecSize: POINTER(Int32), pwcsSearchDesc: POINTER(POINTER(UInt16)), ppIFilt: POINTER(win32more.Windows.Win32.Storage.IndexServer.IFilter)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def LoadIFilterFromStorage(self, pStg: win32more.Windows.Win32.System.Com.StructuredStorage.IStorage, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, pwcsOverride: win32more.Windows.Win32.Foundation.PWSTR, fUseDefault: win32more.Windows.Win32.Foundation.BOOL, pFilterClsid: POINTER(Guid), SearchDecSize: POINTER(Int32), pwcsSearchDesc: POINTER(POINTER(UInt16)), ppIFilt: POINTER(win32more.Windows.Win32.Storage.IndexServer.IFilter)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def LoadIFilterFromStream(self, pStm: win32more.Windows.Win32.System.Com.IStream, pFilteredSources: POINTER(win32more.Windows.Win32.System.Search.FILTERED_DATA_SOURCES), pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, fUseDefault: win32more.Windows.Win32.Foundation.BOOL, pFilterClsid: POINTER(Guid), SearchDecSize: POINTER(Int32), pwcsSearchDesc: POINTER(POINTER(UInt16)), ppIFilt: POINTER(win32more.Windows.Win32.Storage.IndexServer.IFilter)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ILoadFilterWithPrivateComActivation(ComPtr):
    extends: win32more.Windows.Win32.System.Search.ILoadFilter
    _iid_ = Guid('{40bdbd34-780b-48d3-9bb6-12ebd4ad2e75}')
    @commethod(6)
    def LoadIFilterWithPrivateComActivation(self, filteredSources: POINTER(win32more.Windows.Win32.System.Search.FILTERED_DATA_SOURCES), useDefault: win32more.Windows.Win32.Foundation.BOOL, filterClsid: POINTER(Guid), isFilterPrivateComActivated: POINTER(win32more.Windows.Win32.Foundation.BOOL), filterObj: POINTER(win32more.Windows.Win32.Storage.IndexServer.IFilter)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMDDataset(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a07cccd1-8148-11d0-87bb-00c04fc33942}')
    @commethod(3)
    def FreeAxisInfo(self, cAxes: UIntPtr, rgAxisInfo: POINTER(win32more.Windows.Win32.System.Search.MDAXISINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetAxisInfo(self, pcAxes: POINTER(UIntPtr), prgAxisInfo: POINTER(POINTER(win32more.Windows.Win32.System.Search.MDAXISINFO))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetAxisRowset(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, iAxis: UIntPtr, riid: POINTER(Guid), cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET), ppRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetCellData(self, hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, ulStartCell: UIntPtr, ulEndCell: UIntPtr, pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetSpecification(self, riid: POINTER(Guid), ppSpecification: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMDFind(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a07cccd2-8148-11d0-87bb-00c04fc33942}')
    @commethod(3)
    def FindCell(self, ulStartingOrdinal: UIntPtr, cMembers: UIntPtr, rgpwszMember: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pulCellOrdinal: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def FindTuple(self, ulAxisIdentifier: UInt32, ulStartingOrdinal: UIntPtr, cMembers: UIntPtr, rgpwszMember: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pulTupleOrdinal: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMDRangeRowset(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733aa0-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetRangeRowset(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, ulStartCell: UIntPtr, ulEndCell: UIntPtr, riid: POINTER(Guid), cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET), ppRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMetaData(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{780102b0-c43b-4876-bc7b-5e9ba5c88794}')
    @commethod(3)
    def GetData(self, ppszKey: POINTER(win32more.Windows.Win32.Foundation.PWSTR), ppszValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMultipleResults(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a90-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetResult(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, lResultFlag: IntPtr, riid: POINTER(Guid), pcRowsAffected: POINTER(IntPtr), ppRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INCREMENTAL_ACCESS_INFO(Structure):
    dwSize: UInt32
    ftLastModifiedTime: win32more.Windows.Win32.Foundation.FILETIME
INTERVAL_LIMIT_KIND = Int32
ILK_EXPLICIT_INCLUDED: win32more.Windows.Win32.System.Search.INTERVAL_LIMIT_KIND = 0
ILK_EXPLICIT_EXCLUDED: win32more.Windows.Win32.System.Search.INTERVAL_LIMIT_KIND = 1
ILK_NEGATIVE_INFINITY: win32more.Windows.Win32.System.Search.INTERVAL_LIMIT_KIND = 2
ILK_POSITIVE_INFINITY: win32more.Windows.Win32.System.Search.INTERVAL_LIMIT_KIND = 3
class INamedEntity(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{abdbd0b1-7d54-49fb-ab5c-bff4130004cd}')
    @commethod(3)
    def GetValue(self, ppszValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DefaultPhrase(self, ppszPhrase: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INamedEntityCollector(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{af2440f6-8afc-47d0-9a7f-396a0acfb43d}')
    @commethod(3)
    def Add(self, beginSpan: UInt32, endSpan: UInt32, beginActual: UInt32, endActual: UInt32, pType: win32more.Windows.Win32.System.Search.IEntity, pszValue: win32more.Windows.Win32.Foundation.PWSTR, certainty: win32more.Windows.Win32.System.Search.NAMED_ENTITY_CERTAINTY) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IObjectAccessControl(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733aa3-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetObjectAccessRights(self, pObject: POINTER(win32more.Windows.Win32.System.Search.SEC_OBJECT), pcAccessEntries: POINTER(UInt32), prgAccessEntries: POINTER(POINTER(win32more.Windows.Win32.Security.Authorization.EXPLICIT_ACCESS_W))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetObjectOwner(self, pObject: POINTER(win32more.Windows.Win32.System.Search.SEC_OBJECT), ppOwner: POINTER(POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def IsObjectAccessAllowed(self, pObject: POINTER(win32more.Windows.Win32.System.Search.SEC_OBJECT), pAccessEntry: POINTER(win32more.Windows.Win32.Security.Authorization.EXPLICIT_ACCESS_W), pfResult: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetObjectAccessRights(self, pObject: POINTER(win32more.Windows.Win32.System.Search.SEC_OBJECT), cAccessEntries: UInt32, prgAccessEntries: POINTER(win32more.Windows.Win32.Security.Authorization.EXPLICIT_ACCESS_W)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetObjectOwner(self, pObject: POINTER(win32more.Windows.Win32.System.Search.SEC_OBJECT), pOwner: POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpLockStatus(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c731065d-ac80-11d1-8df3-00c04fb6ef4f}')
    @commethod(3)
    def IsOplockValid(self, pfIsOplockValid: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def IsOplockBroken(self, pfIsOplockBroken: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetOplockEventHandle(self, phOplockEv: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpenRowset(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a69-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def OpenRowset(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, pTableID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pIndexID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), riid: POINTER(Guid), cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET), ppRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IParentRowset(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733aaa-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetChildRowset(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, iOrdinal: UIntPtr, riid: POINTER(Guid), ppRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IProtocolHandlerSite(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0b63e385-9ccc-11d0-bcdb-00805fccce04}')
    @commethod(3)
    def GetFilter(self, pclsidObj: POINTER(Guid), pcwszContentType: win32more.Windows.Win32.Foundation.PWSTR, pcwszExtension: win32more.Windows.Win32.Foundation.PWSTR, ppFilter: POINTER(win32more.Windows.Win32.Storage.IndexServer.IFilter)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IProvideMoniker(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a4d-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetMoniker(self, ppIMoniker: POINTER(win32more.Windows.Win32.System.Com.IMoniker)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IQueryParser(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{2ebdee67-3505-43f8-9946-ea44abc8e5b0}')
    @commethod(3)
    def Parse(self, pszInputString: win32more.Windows.Win32.Foundation.PWSTR, pCustomProperties: win32more.Windows.Win32.System.Com.IEnumUnknown, ppSolution: POINTER(win32more.Windows.Win32.System.Search.IQuerySolution)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetOption(self, option: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_SINGLE_OPTION, pOptionValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetOption(self, option: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_SINGLE_OPTION, pOptionValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetMultiOption(self, option: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_MULTIOPTION, pszOptionKey: win32more.Windows.Win32.Foundation.PWSTR, pOptionValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetSchemaProvider(self, ppSchemaProvider: POINTER(win32more.Windows.Win32.System.Search.ISchemaProvider)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def RestateToString(self, pCondition: win32more.Windows.Win32.System.Search.ICondition, fUseEnglish: win32more.Windows.Win32.Foundation.BOOL, ppszQueryString: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def ParsePropertyValue(self, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, pszInputString: win32more.Windows.Win32.Foundation.PWSTR, ppSolution: POINTER(win32more.Windows.Win32.System.Search.IQuerySolution)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def RestatePropertyValueToString(self, pCondition: win32more.Windows.Win32.System.Search.ICondition, fUseEnglish: win32more.Windows.Win32.Foundation.BOOL, ppszPropertyName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), ppszQueryString: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IQueryParserManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a879e3c4-af77-44fb-8f37-ebd1487cf920}')
    @commethod(3)
    def CreateLoadedParser(self, pszCatalog: win32more.Windows.Win32.Foundation.PWSTR, langidForKeywords: UInt16, riid: POINTER(Guid), ppQueryParser: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def InitializeOptions(self, fUnderstandNQS: win32more.Windows.Win32.Foundation.BOOL, fAutoWildCard: win32more.Windows.Win32.Foundation.BOOL, pQueryParser: win32more.Windows.Win32.System.Search.IQueryParser) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetOption(self, option: win32more.Windows.Win32.System.Search.QUERY_PARSER_MANAGER_OPTION, pOptionValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IQuerySolution(ComPtr):
    extends: win32more.Windows.Win32.System.Search.IConditionFactory
    _iid_ = Guid('{d6ebc66b-8921-4193-afdd-a1789fb7ff57}')
    @commethod(7)
    def GetQuery(self, ppQueryNode: POINTER(win32more.Windows.Win32.System.Search.ICondition), ppMainType: POINTER(win32more.Windows.Win32.System.Search.IEntity)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetErrors(self, riid: POINTER(Guid), ppParseErrors: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetLexicalData(self, ppszInputString: POINTER(win32more.Windows.Win32.Foundation.PWSTR), ppTokens: POINTER(win32more.Windows.Win32.System.Search.ITokenCollection), plcid: POINTER(UInt32), ppWordBreaker: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IReadData(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a6a-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def ReadData(self, hChapter: UIntPtr, cbBookmark: UIntPtr, pBookmark: POINTER(Byte), lRowsOffset: IntPtr, hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, cRows: IntPtr, pcRowsObtained: POINTER(UIntPtr), ppFixedData: POINTER(POINTER(Byte)), pcbVariableTotal: POINTER(UIntPtr), ppVariableData: POINTER(POINTER(Byte))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ReleaseChapter(self, hChapter: UIntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRegisterProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733ab9-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetURLMapping(self, pwszURL: win32more.Windows.Win32.Foundation.PWSTR, dwReserved: UIntPtr, pclsidProvider: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetURLMapping(self, pwszURL: win32more.Windows.Win32.Foundation.PWSTR, dwReserved: UIntPtr, rclsidProvider: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def UnregisterProvider(self, pwszURL: win32more.Windows.Win32.Foundation.PWSTR, dwReserved: UIntPtr, rclsidProvider: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRelationship(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{2769280b-5108-498c-9c7f-a51239b63147}')
    @commethod(3)
    def Name(self, ppszName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def IsReal(self, pIsReal: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Destination(self, pDestinationEntity: POINTER(win32more.Windows.Win32.System.Search.IEntity)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def MetaData(self, riid: POINTER(Guid), pMetaData: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def DefaultPhrase(self, ppszPhrase: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRichChunk(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4fdef69c-dbc9-454e-9910-b34f3c64b510}')
    @commethod(3)
    def GetData(self, pFirstPos: POINTER(UInt32), pLength: POINTER(UInt32), ppsz: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRow(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733ab4-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetColumns(self, cColumns: UIntPtr, rgColumns: POINTER(win32more.Windows.Win32.System.Search.DBCOLUMNACCESS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetSourceRowset(self, riid: POINTER(Guid), ppRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown), phRow: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Open(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, pColumnID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), rguidColumnType: POINTER(Guid), dwBindFlags: UInt32, riid: POINTER(Guid), ppUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowChange(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733ab5-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def SetColumns(self, cColumns: UIntPtr, rgColumns: POINTER(win32more.Windows.Win32.System.Search.DBCOLUMNACCESS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowPosition(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a94-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def ClearRowPosition(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetRowPosition(self, phChapter: POINTER(UIntPtr), phRow: POINTER(UIntPtr), pdwPositionFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetRowset(self, riid: POINTER(Guid), ppRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Initialize(self, pRowset: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetRowPosition(self, hChapter: UIntPtr, hRow: UIntPtr, dwPositionFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowPositionChange(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0997a571-126e-11d0-9f8a-00a0c9a0631e}')
    @commethod(3)
    def OnRowPositionChange(self, eReason: UInt32, ePhase: UInt32, fCantDeny: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowSchemaChange(ComPtr):
    extends: win32more.Windows.Win32.System.Search.IRowChange
    _iid_ = Guid('{0c733aae-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(4)
    def DeleteColumns(self, cColumns: UIntPtr, rgColumnIDs: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), rgdwStatus: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def AddColumns(self, cColumns: UIntPtr, rgNewColumnInfo: POINTER(win32more.Windows.Win32.System.Search.DBCOLUMNINFO), rgColumns: POINTER(win32more.Windows.Win32.System.Search.DBCOLUMNACCESS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowset(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a7c-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def AddRefRows(self, cRows: UIntPtr, rghRows: POINTER(UIntPtr), rgRefCounts: POINTER(UInt32), rgRowStatus: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetData(self, hRow: UIntPtr, hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetNextRows(self, hReserved: UIntPtr, lRowsOffset: IntPtr, cRows: IntPtr, pcRowsObtained: POINTER(UIntPtr), prghRows: POINTER(POINTER(UIntPtr))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def ReleaseRows(self, cRows: UIntPtr, rghRows: POINTER(UIntPtr), rgRowOptions: POINTER(UInt32), rgRefCounts: POINTER(UInt32), rgRowStatus: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def RestartPosition(self, hReserved: UIntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetAsynch(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a0f-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def RatioFinished(self, pulDenominator: POINTER(UIntPtr), pulNumerator: POINTER(UIntPtr), pcRows: POINTER(UIntPtr), pfNewRows: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Stop(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetBookmark(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733ac2-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def PositionOnBookmark(self, hChapter: UIntPtr, cbBookmark: UIntPtr, pBookmark: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetChange(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a05-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def DeleteRows(self, hReserved: UIntPtr, cRows: UIntPtr, rghRows: POINTER(UIntPtr), rgRowStatus: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetData(self, hRow: UIntPtr, hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def InsertRow(self, hReserved: UIntPtr, hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, pData: VoidPtr, phRow: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetChangeExtInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a8f-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetOriginalRow(self, hReserved: UIntPtr, hRow: UIntPtr, phRowOriginal: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetPendingColumns(self, hReserved: UIntPtr, hRow: UIntPtr, cColumnOrdinals: UInt32, rgiOrdinals: POINTER(UInt32), rgColumnStatus: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetChapterMember(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733aa8-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def IsRowInChapter(self, hChapter: UIntPtr, hRow: UIntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetCopyRows(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a6b-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def CloseSource(self, hSourceID: UInt16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CopyByHROWS(self, hSourceID: UInt16, hReserved: UIntPtr, cRows: IntPtr, rghRows: POINTER(UIntPtr), bFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CopyRows(self, hSourceID: UInt16, hReserved: UIntPtr, cRows: IntPtr, bFlags: UInt32, pcRowsCopied: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def DefineSource(self, pRowsetSource: win32more.Windows.Win32.System.Search.IRowset, cColIds: UIntPtr, rgSourceColumns: POINTER(IntPtr), rgTargetColumns: POINTER(IntPtr), phSourceID: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetCurrentIndex(ComPtr):
    extends: win32more.Windows.Win32.System.Search.IRowsetIndex
    _iid_ = Guid('{0c733abd-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(6)
    def GetIndex(self, ppIndexID: POINTER(POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetIndex(self, pIndexID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1551aea5-5d66-4b11-86f5-d5634cb211b9}')
    @commethod(3)
    def OnNewItem(self, itemID: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT), newItemState: win32more.Windows.Win32.System.Search.ROWSETEVENT_ITEMSTATE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnChangedItem(self, itemID: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT), rowsetItemState: win32more.Windows.Win32.System.Search.ROWSETEVENT_ITEMSTATE, changedItemState: win32more.Windows.Win32.System.Search.ROWSETEVENT_ITEMSTATE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def OnDeletedItem(self, itemID: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT), deletedItemState: win32more.Windows.Win32.System.Search.ROWSETEVENT_ITEMSTATE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def OnRowsetEvent(self, eventType: win32more.Windows.Win32.System.Search.ROWSETEVENT_TYPE, eventData: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetExactScroll(ComPtr):
    extends: win32more.Windows.Win32.System.Search.IRowsetScroll
    _iid_ = Guid('{0c733a7f-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(14)
    def GetExactPosition(self, hChapter: UIntPtr, cbBookmark: UIntPtr, pBookmark: POINTER(Byte), pulPosition: POINTER(UIntPtr), pcRows: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetFastLoad(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5cf4ca13-ef21-11d0-97e7-00c04fc2ad98}')
    @commethod(3)
    def InsertRow(self, hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Commit(self, fDone: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetFind(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a9d-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def FindNextRow(self, hChapter: UIntPtr, hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, pFindValue: VoidPtr, CompareOp: UInt32, cbBookmark: UIntPtr, pBookmark: POINTER(Byte), lRowsOffset: IntPtr, cRows: IntPtr, pcRowsObtained: POINTER(UIntPtr), prghRows: POINTER(POINTER(UIntPtr))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetIdentity(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a09-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def IsSameRow(self, hThisRow: UIntPtr, hThatRow: UIntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetIndex(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a82-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetIndexInfo(self, pcKeyColumns: POINTER(UIntPtr), prgIndexColumnDesc: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBINDEXCOLUMNDESC)), pcIndexPropertySets: POINTER(UInt32), prgIndexPropertySets: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBPROPSET))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Seek(self, hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, cKeyValues: UIntPtr, pData: VoidPtr, dwSeekOptions: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetRange(self, hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, cStartKeyColumns: UIntPtr, pStartData: VoidPtr, cEndKeyColumns: UIntPtr, pEndData: VoidPtr, dwRangeOptions: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a55-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetProperties(self, cPropertyIDSets: UInt32, rgPropertyIDSets: POINTER(win32more.Windows.Win32.System.Search.DBPROPIDSET), pcPropertySets: POINTER(UInt32), prgPropertySets: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBPROPSET))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetReferencedRowset(self, iOrdinal: UIntPtr, riid: POINTER(Guid), ppReferencedRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetSpecification(self, riid: POINTER(Guid), ppSpecification: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetKeys(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a12-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def ListKeys(self, pcColumns: POINTER(UIntPtr), prgColumns: POINTER(POINTER(UIntPtr))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetLocate(ComPtr):
    extends: win32more.Windows.Win32.System.Search.IRowset
    _iid_ = Guid('{0c733a7d-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(8)
    def Compare(self, hReserved: UIntPtr, cbBookmark1: UIntPtr, pBookmark1: POINTER(Byte), cbBookmark2: UIntPtr, pBookmark2: POINTER(Byte), pComparison: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetRowsAt(self, hReserved1: UIntPtr, hReserved2: UIntPtr, cbBookmark: UIntPtr, pBookmark: POINTER(Byte), lRowsOffset: IntPtr, cRows: IntPtr, pcRowsObtained: POINTER(UIntPtr), prghRows: POINTER(POINTER(UIntPtr))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetRowsByBookmark(self, hReserved: UIntPtr, cRows: UIntPtr, rgcbBookmarks: POINTER(UIntPtr), rgpBookmarks: POINTER(POINTER(Byte)), rghRows: POINTER(UIntPtr), rgRowStatus: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Hash(self, hReserved: UIntPtr, cBookmarks: UIntPtr, rgcbBookmarks: POINTER(UIntPtr), rgpBookmarks: POINTER(POINTER(Byte)), rgHashedValues: POINTER(UIntPtr), rgBookmarkStatus: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetNewRowAfter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a71-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def SetNewDataAfter(self, hChapter: UIntPtr, cbbmPrevious: UInt32, pbmPrevious: POINTER(Byte), hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, pData: POINTER(Byte), phRow: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetNextRowset(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a72-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetNextRowset(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, riid: POINTER(Guid), ppNextRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetNotify(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a83-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def OnFieldChange(self, pRowset: win32more.Windows.Win32.System.Search.IRowset, hRow: UIntPtr, cColumns: UIntPtr, rgColumns: POINTER(UIntPtr), eReason: UInt32, ePhase: UInt32, fCantDeny: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnRowChange(self, pRowset: win32more.Windows.Win32.System.Search.IRowset, cRows: UIntPtr, rghRows: POINTER(UIntPtr), eReason: UInt32, ePhase: UInt32, fCantDeny: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def OnRowsetChange(self, pRowset: win32more.Windows.Win32.System.Search.IRowset, eReason: UInt32, ePhase: UInt32, fCantDeny: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetPrioritization(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{42811652-079d-481b-87a2-09a69ecc5f44}')
    @commethod(3)
    def SetScopePriority(self, priority: win32more.Windows.Win32.System.Search.PRIORITY_LEVEL, scopeStatisticsEventFrequency: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetScopePriority(self, priority: POINTER(win32more.Windows.Win32.System.Search.PRIORITY_LEVEL), scopeStatisticsEventFrequency: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetScopeStatistics(self, indexedDocumentCount: POINTER(UInt32), oustandingAddCount: POINTER(UInt32), oustandingModifyCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetQueryStatus(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a7ac77ed-f8d7-11ce-a798-0020f8008024}')
    @commethod(3)
    def GetStatus(self, pdwStatus: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetStatusEx(self, pdwStatus: POINTER(UInt32), pcFilteredDocuments: POINTER(UInt32), pcDocumentsToFilter: POINTER(UInt32), pdwRatioFinishedDenominator: POINTER(UIntPtr), pdwRatioFinishedNumerator: POINTER(UIntPtr), cbBmk: UIntPtr, pBmk: POINTER(Byte), piRowBmk: POINTER(UIntPtr), pcRowsTotal: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetRefresh(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733aa9-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def RefreshVisibleData(self, hChapter: UIntPtr, cRows: UIntPtr, rghRows: POINTER(UIntPtr), fOverWrite: win32more.Windows.Win32.Foundation.BOOL, pcRowsRefreshed: POINTER(UIntPtr), prghRowsRefreshed: POINTER(POINTER(UIntPtr)), prgRowStatus: POINTER(POINTER(UInt32))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetLastVisibleData(self, hRow: UIntPtr, hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetResynch(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a84-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetVisibleData(self, hRow: UIntPtr, hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ResynchRows(self, cRows: UIntPtr, rghRows: POINTER(UIntPtr), pcRowsResynched: POINTER(UIntPtr), prghRowsResynched: POINTER(POINTER(UIntPtr)), prgRowStatus: POINTER(POINTER(UInt32))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetScroll(ComPtr):
    extends: win32more.Windows.Win32.System.Search.IRowsetLocate
    _iid_ = Guid('{0c733a7e-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(12)
    def GetApproximatePosition(self, hReserved: UIntPtr, cbBookmark: UIntPtr, pBookmark: POINTER(Byte), pulPosition: POINTER(UIntPtr), pcRows: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetRowsAtRatio(self, hReserved1: UIntPtr, hReserved2: UIntPtr, ulNumerator: UIntPtr, ulDenominator: UIntPtr, cRows: IntPtr, pcRowsObtained: POINTER(UIntPtr), prghRows: POINTER(POINTER(UIntPtr))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetUpdate(ComPtr):
    extends: win32more.Windows.Win32.System.Search.IRowsetChange
    _iid_ = Guid('{0c733a6d-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(6)
    def GetOriginalData(self, hRow: UIntPtr, hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetPendingRows(self, hReserved: UIntPtr, dwRowStatus: UInt32, pcPendingRows: POINTER(UIntPtr), prgPendingRows: POINTER(POINTER(UIntPtr)), prgPendingStatus: POINTER(POINTER(UInt32))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetRowStatus(self, hReserved: UIntPtr, cRows: UIntPtr, rghRows: POINTER(UIntPtr), rgPendingStatus: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Undo(self, hReserved: UIntPtr, cRows: UIntPtr, rghRows: POINTER(UIntPtr), pcRowsUndone: POINTER(UIntPtr), prgRowsUndone: POINTER(POINTER(UIntPtr)), prgRowStatus: POINTER(POINTER(UInt32))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def Update(self, hReserved: UIntPtr, cRows: UIntPtr, rghRows: POINTER(UIntPtr), pcRows: POINTER(UIntPtr), prgRows: POINTER(POINTER(UIntPtr)), prgRowStatus: POINTER(POINTER(UInt32))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetView(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a99-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def CreateView(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, riid: POINTER(Guid), ppView: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetView(self, hChapter: UIntPtr, riid: POINTER(Guid), phChapterSource: POINTER(UIntPtr), ppView: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetWatchAll(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a73-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def Acknowledge(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Start(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def StopWatching(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetWatchNotify(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a44-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def OnChange(self, pRowset: win32more.Windows.Win32.System.Search.IRowset, eChangeReason: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetWatchRegion(ComPtr):
    extends: win32more.Windows.Win32.System.Search.IRowsetWatchAll
    _iid_ = Guid('{0c733a45-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(6)
    def CreateWatchRegion(self, dwWatchMode: UInt32, phRegion: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ChangeWatchMode(self, hRegion: UIntPtr, dwWatchMode: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DeleteWatchRegion(self, hRegion: UIntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetWatchRegionInfo(self, hRegion: UIntPtr, pdwWatchMode: POINTER(UInt32), phChapter: POINTER(UIntPtr), pcbBookmark: POINTER(UIntPtr), ppBookmark: POINTER(POINTER(Byte)), pcRows: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def Refresh(self, pcChangesObtained: POINTER(UIntPtr), prgChanges: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBROWWATCHCHANGE))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def ShrinkWatchRegion(self, hRegion: UIntPtr, hChapter: UIntPtr, cbBookmark: UIntPtr, pBookmark: POINTER(Byte), cRows: IntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRowsetWithParameters(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a6e-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetParameterInfo(self, pcParams: POINTER(UIntPtr), prgParamInfo: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBPARAMINFO)), ppNamesBuffer: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Requery(self, pParams: POINTER(win32more.Windows.Win32.System.Search.DBPARAMS), pulErrorParam: POINTER(UInt32), phReserved: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISQLErrorInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a74-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetSQLInfo(self, pbstrSQLState: POINTER(win32more.Windows.Win32.Foundation.BSTR), plNativeError: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISQLGetDiagField(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{228972f1-b5ff-11d0-8a80-00c04fd611cd}')
    @commethod(3)
    def GetDiagField(self, pDiagInfo: POINTER(win32more.Windows.Win32.System.Search.KAGGETDIAG)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISQLRequestDiagFields(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{228972f0-b5ff-11d0-8a80-00c04fd611cd}')
    @commethod(3)
    def RequestDiagFields(self, cDiagFields: UInt32, rgDiagFields: POINTER(win32more.Windows.Win32.System.Search.KAGREQDIAG)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISQLServerErrorInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5cf4ca12-ef21-11d0-97e7-00c04fc2ad98}')
    @commethod(3)
    def GetErrorInfo(self, ppErrorInfo: POINTER(POINTER(win32more.Windows.Win32.System.Search.SSERRORINFO)), ppStringsBuffer: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISchemaLocalizerSupport(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ca3fdca2-bfbe-4eed-90d7-0caef0a1bda1}')
    @commethod(3)
    def Localize(self, pszGlobalString: win32more.Windows.Win32.Foundation.PWSTR, ppszLocalString: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISchemaLock(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4c2389fb-2511-11d4-b258-00c04f7971ce}')
    @commethod(3)
    def GetSchemaLock(self, pTableID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), lmMode: UInt32, phLockHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE), pTableVersion: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ReleaseSchemaLock(self, hLockHandle: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISchemaProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8cf89bcb-394c-49b2-ae28-a59dd4ed7f68}')
    @commethod(3)
    def Entities(self, riid: POINTER(Guid), pEntities: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def RootEntity(self, pRootEntity: POINTER(win32more.Windows.Win32.System.Search.IEntity)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetEntity(self, pszEntityName: win32more.Windows.Win32.Foundation.PWSTR, pEntity: POINTER(win32more.Windows.Win32.System.Search.IEntity)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def MetaData(self, riid: POINTER(Guid), pMetaData: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Localize(self, lcid: UInt32, pSchemaLocalizerSupport: win32more.Windows.Win32.System.Search.ISchemaLocalizerSupport) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SaveBinary(self, pszSchemaBinaryPath: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def LookupAuthoredNamedEntity(self, pEntity: win32more.Windows.Win32.System.Search.IEntity, pszInputString: win32more.Windows.Win32.Foundation.PWSTR, pTokenCollection: win32more.Windows.Win32.System.Search.ITokenCollection, cTokensBegin: UInt32, pcTokensLength: POINTER(UInt32), ppszValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IScopedOperations(ComPtr):
    extends: win32more.Windows.Win32.System.Search.IBindResource
    _iid_ = Guid('{0c733ab0-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(4)
    def Copy(self, cRows: UIntPtr, rgpwszSourceURLs: POINTER(win32more.Windows.Win32.Foundation.PWSTR), rgpwszDestURLs: POINTER(win32more.Windows.Win32.Foundation.PWSTR), dwCopyFlags: UInt32, pAuthenticate: win32more.Windows.Win32.System.Com.IAuthenticate, rgdwStatus: POINTER(UInt32), rgpwszNewURLs: POINTER(win32more.Windows.Win32.Foundation.PWSTR), ppStringsBuffer: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Move(self, cRows: UIntPtr, rgpwszSourceURLs: POINTER(win32more.Windows.Win32.Foundation.PWSTR), rgpwszDestURLs: POINTER(win32more.Windows.Win32.Foundation.PWSTR), dwMoveFlags: UInt32, pAuthenticate: win32more.Windows.Win32.System.Com.IAuthenticate, rgdwStatus: POINTER(UInt32), rgpwszNewURLs: POINTER(win32more.Windows.Win32.Foundation.PWSTR), ppStringsBuffer: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Delete(self, cRows: UIntPtr, rgpwszURLs: POINTER(win32more.Windows.Win32.Foundation.PWSTR), dwDeleteFlags: UInt32, rgdwStatus: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def OpenRowset(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, pTableID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pIndexID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), riid: POINTER(Guid), cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET), ppRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchCatalogManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ab310581-ac80-11d1-8df3-00c04fb6ef50}')
    @commethod(3)
    def get_Name(self, pszName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetParameter(self, pszName: win32more.Windows.Win32.Foundation.PWSTR, ppValue: POINTER(POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetParameter(self, pszName: win32more.Windows.Win32.Foundation.PWSTR, pValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetCatalogStatus(self, pStatus: POINTER(win32more.Windows.Win32.System.Search.CatalogStatus), pPausedReason: POINTER(win32more.Windows.Win32.System.Search.CatalogPausedReason)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Reindex(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def ReindexMatchingURLs(self, pszPattern: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def ReindexSearchRoot(self, pszRootURL: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_ConnectTimeout(self, dwConnectTimeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_ConnectTimeout(self, pdwConnectTimeout: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_DataTimeout(self, dwDataTimeout: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_DataTimeout(self, pdwDataTimeout: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def NumberOfItems(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def NumberOfItemsToIndex(self, plIncrementalCount: POINTER(Int32), plNotificationQueue: POINTER(Int32), plHighPriorityQueue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def URLBeingIndexed(self, pszUrl: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetURLIndexingState(self, pszURL: win32more.Windows.Win32.Foundation.PWSTR, pdwState: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetPersistentItemsChangedSink(self, ppISearchPersistentItemsChangedSink: POINTER(win32more.Windows.Win32.System.Search.ISearchPersistentItemsChangedSink)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def RegisterViewForNotification(self, pszView: win32more.Windows.Win32.Foundation.PWSTR, pViewChangedSink: win32more.Windows.Win32.System.Search.ISearchViewChangedSink, pdwCookie: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetItemsChangedSink(self, pISearchNotifyInlineSite: win32more.Windows.Win32.System.Search.ISearchNotifyInlineSite, riid: POINTER(Guid), ppv: POINTER(VoidPtr), pGUIDCatalogResetSignature: POINTER(Guid), pGUIDCheckPointSignature: POINTER(Guid), pdwLastCheckPointNumber: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def UnregisterViewForNotification(self, dwCookie: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def SetExtensionClusion(self, pszExtension: win32more.Windows.Win32.Foundation.PWSTR, fExclude: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def EnumerateExcludedExtensions(self, ppExtensions: POINTER(win32more.Windows.Win32.System.Com.IEnumString)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def GetQueryHelper(self, ppSearchQueryHelper: POINTER(win32more.Windows.Win32.System.Search.ISearchQueryHelper)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_DiacriticSensitivity(self, fDiacriticSensitive: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_DiacriticSensitivity(self, pfDiacriticSensitive: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def GetCrawlScopeManager(self, ppCrawlScopeManager: POINTER(win32more.Windows.Win32.System.Search.ISearchCrawlScopeManager)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchCatalogManager2(ComPtr):
    extends: win32more.Windows.Win32.System.Search.ISearchCatalogManager
    _iid_ = Guid('{7ac3286d-4d1d-4817-84fc-c1c85e3af0d9}')
    @commethod(29)
    def PrioritizeMatchingURLs(self, pszPattern: win32more.Windows.Win32.Foundation.PWSTR, dwPrioritizeFlags: win32more.Windows.Win32.System.Search.PRIORITIZE_FLAGS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchCrawlScopeManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ab310581-ac80-11d1-8df3-00c04fb6ef55}')
    @commethod(3)
    def AddDefaultScopeRule(self, pszURL: win32more.Windows.Win32.Foundation.PWSTR, fInclude: win32more.Windows.Win32.Foundation.BOOL, fFollowFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddRoot(self, pSearchRoot: win32more.Windows.Win32.System.Search.ISearchRoot) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RemoveRoot(self, pszURL: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def EnumerateRoots(self, ppSearchRoots: POINTER(win32more.Windows.Win32.System.Search.IEnumSearchRoots)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def AddHierarchicalScope(self, pszURL: win32more.Windows.Win32.Foundation.PWSTR, fInclude: win32more.Windows.Win32.Foundation.BOOL, fDefault: win32more.Windows.Win32.Foundation.BOOL, fOverrideChildren: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def AddUserScopeRule(self, pszURL: win32more.Windows.Win32.Foundation.PWSTR, fInclude: win32more.Windows.Win32.Foundation.BOOL, fOverrideChildren: win32more.Windows.Win32.Foundation.BOOL, fFollowFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def RemoveScopeRule(self, pszRule: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def EnumerateScopeRules(self, ppSearchScopeRules: POINTER(win32more.Windows.Win32.System.Search.IEnumSearchScopeRules)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def HasParentScopeRule(self, pszURL: win32more.Windows.Win32.Foundation.PWSTR, pfHasParentRule: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def HasChildScopeRule(self, pszURL: win32more.Windows.Win32.Foundation.PWSTR, pfHasChildRule: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def IncludedInCrawlScope(self, pszURL: win32more.Windows.Win32.Foundation.PWSTR, pfIsIncluded: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def IncludedInCrawlScopeEx(self, pszURL: win32more.Windows.Win32.Foundation.PWSTR, pfIsIncluded: POINTER(win32more.Windows.Win32.Foundation.BOOL), pReason: POINTER(win32more.Windows.Win32.System.Search.CLUSION_REASON)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def RevertToDefaultScopes(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def SaveAll(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetParentScopeVersionId(self, pszURL: win32more.Windows.Win32.Foundation.PWSTR, plScopeId: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def RemoveDefaultScopeRule(self, pszURL: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchCrawlScopeManager2(ComPtr):
    extends: win32more.Windows.Win32.System.Search.ISearchCrawlScopeManager
    _iid_ = Guid('{6292f7ad-4e19-4717-a534-8fc22bcd5ccd}')
    @commethod(19)
    def GetVersion(self, plVersion: POINTER(POINTER(Int32)), phFileMapping: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchItemsChangedSink(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ab310581-ac80-11d1-8df3-00c04fb6ef58}')
    @commethod(3)
    def StartedMonitoringScope(self, pszURL: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def StoppedMonitoringScope(self, pszURL: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def OnItemsChanged(self, dwNumberOfChanges: UInt32, rgDataChangeEntries: POINTER(win32more.Windows.Win32.System.Search.SEARCH_ITEM_CHANGE), rgdwDocIds: POINTER(UInt32), rghrCompletionCodes: POINTER(win32more.Windows.Win32.Foundation.HRESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchLanguageSupport(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{24c3cbaa-ebc1-491a-9ef1-9f6d8deb1b8f}')
    @commethod(3)
    def SetDiacriticSensitivity(self, fDiacriticSensitive: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDiacriticSensitivity(self, pfDiacriticSensitive: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def LoadWordBreaker(self, lcid: UInt32, riid: POINTER(Guid), ppWordBreaker: POINTER(VoidPtr), pLcidUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def LoadStemmer(self, lcid: UInt32, riid: POINTER(Guid), ppStemmer: POINTER(VoidPtr), pLcidUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def IsPrefixNormalized(self, pwcsQueryToken: win32more.Windows.Win32.Foundation.PWSTR, cwcQueryToken: UInt32, pwcsDocumentToken: win32more.Windows.Win32.Foundation.PWSTR, cwcDocumentToken: UInt32, pulPrefixLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ab310581-ac80-11d1-8df3-00c04fb6ef69}')
    @commethod(3)
    def GetIndexerVersionStr(self, ppszVersionString: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetIndexerVersion(self, pdwMajor: POINTER(UInt32), pdwMinor: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetParameter(self, pszName: win32more.Windows.Win32.Foundation.PWSTR, ppValue: POINTER(POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetParameter(self, pszName: win32more.Windows.Win32.Foundation.PWSTR, pValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def get_ProxyName(self, ppszProxyName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_BypassList(self, ppszBypassList: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetProxy(self, sUseProxy: win32more.Windows.Win32.System.Search.PROXY_ACCESS, fLocalByPassProxy: win32more.Windows.Win32.Foundation.BOOL, dwPortNumber: UInt32, pszProxyName: win32more.Windows.Win32.Foundation.PWSTR, pszByPassList: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetCatalog(self, pszCatalog: win32more.Windows.Win32.Foundation.PWSTR, ppCatalogManager: POINTER(win32more.Windows.Win32.System.Search.ISearchCatalogManager)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_UserAgent(self, ppszUserAgent: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_UserAgent(self, pszUserAgent: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_UseProxy(self, pUseProxy: POINTER(win32more.Windows.Win32.System.Search.PROXY_ACCESS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_LocalBypass(self, pfLocalBypass: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_PortNumber(self, pdwPortNumber: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchManager2(ComPtr):
    extends: win32more.Windows.Win32.System.Search.ISearchManager
    _iid_ = Guid('{dbab3f73-db19-4a79-bfc0-a61a93886ddf}')
    @commethod(16)
    def CreateCatalog(self, pszCatalog: win32more.Windows.Win32.Foundation.PWSTR, ppCatalogManager: POINTER(win32more.Windows.Win32.System.Search.ISearchCatalogManager)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def DeleteCatalog(self, pszCatalog: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchNotifyInlineSite(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b5702e61-e75c-4b64-82a1-6cb4f832fccf}')
    @commethod(3)
    def OnItemIndexedStatusChange(self, sipStatus: win32more.Windows.Win32.System.Search.SEARCH_INDEXING_PHASE, dwNumEntries: UInt32, rgItemStatusEntries: POINTER(win32more.Windows.Win32.System.Search.SEARCH_ITEM_INDEXING_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnCatalogStatusChange(self, guidCatalogResetSignature: POINTER(Guid), guidCheckPointSignature: POINTER(Guid), dwLastCheckPointNumber: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchPersistentItemsChangedSink(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a2ffdf9b-4758-4f84-b729-df81a1a0612f}')
    @commethod(3)
    def StartedMonitoringScope(self, pszURL: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def StoppedMonitoringScope(self, pszURL: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def OnItemsChanged(self, dwNumberOfChanges: UInt32, DataChangeEntries: POINTER(win32more.Windows.Win32.System.Search.SEARCH_ITEM_PERSISTENT_CHANGE), hrCompletionCodes: POINTER(win32more.Windows.Win32.Foundation.HRESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchProtocol(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c73106ba-ac80-11d1-8df3-00c04fb6ef4f}')
    @commethod(3)
    def Init(self, pTimeoutInfo: POINTER(win32more.Windows.Win32.System.Search.TIMEOUT_INFO), pProtocolHandlerSite: win32more.Windows.Win32.System.Search.IProtocolHandlerSite, pProxyInfo: POINTER(win32more.Windows.Win32.System.Search.PROXY_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateAccessor(self, pcwszURL: win32more.Windows.Win32.Foundation.PWSTR, pAuthenticationInfo: POINTER(win32more.Windows.Win32.System.Search.AUTHENTICATION_INFO), pIncrementalAccessInfo: POINTER(win32more.Windows.Win32.System.Search.INCREMENTAL_ACCESS_INFO), pItemInfo: POINTER(win32more.Windows.Win32.System.Search.ITEM_INFO), ppAccessor: POINTER(win32more.Windows.Win32.System.Search.IUrlAccessor)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CloseAccessor(self, pAccessor: win32more.Windows.Win32.System.Search.IUrlAccessor) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def ShutDown(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchProtocol2(ComPtr):
    extends: win32more.Windows.Win32.System.Search.ISearchProtocol
    _iid_ = Guid('{7789f0b2-b5b2-4722-8b65-5dbd150697a9}')
    @commethod(7)
    def CreateAccessorEx(self, pcwszURL: win32more.Windows.Win32.Foundation.PWSTR, pAuthenticationInfo: POINTER(win32more.Windows.Win32.System.Search.AUTHENTICATION_INFO), pIncrementalAccessInfo: POINTER(win32more.Windows.Win32.System.Search.INCREMENTAL_ACCESS_INFO), pItemInfo: POINTER(win32more.Windows.Win32.System.Search.ITEM_INFO), pUserData: POINTER(win32more.Windows.Win32.System.Com.BLOB), ppAccessor: POINTER(win32more.Windows.Win32.System.Search.IUrlAccessor)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchProtocolThreadContext(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c73106e1-ac80-11d1-8df3-00c04fb6ef4f}')
    @commethod(3)
    def ThreadInit(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ThreadShutdown(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def ThreadIdle(self, dwTimeElaspedSinceLastCallInMS: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchQueryHelper(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ab310581-ac80-11d1-8df3-00c04fb6ef63}')
    @commethod(3)
    def get_ConnectionString(self, pszConnectionString: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def put_QueryContentLocale(self, lcid: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_QueryContentLocale(self, plcid: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def put_QueryKeywordLocale(self, lcid: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def get_QueryKeywordLocale(self, plcid: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_QueryTermExpansion(self, expandTerms: win32more.Windows.Win32.System.Search.SEARCH_TERM_EXPANSION) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_QueryTermExpansion(self, pExpandTerms: POINTER(win32more.Windows.Win32.System.Search.SEARCH_TERM_EXPANSION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_QuerySyntax(self, querySyntax: win32more.Windows.Win32.System.Search.SEARCH_QUERY_SYNTAX) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_QuerySyntax(self, pQuerySyntax: POINTER(win32more.Windows.Win32.System.Search.SEARCH_QUERY_SYNTAX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_QueryContentProperties(self, pszContentProperties: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_QueryContentProperties(self, ppszContentProperties: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_QuerySelectColumns(self, pszSelectColumns: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_QuerySelectColumns(self, ppszSelectColumns: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_QueryWhereRestrictions(self, pszRestrictions: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_QueryWhereRestrictions(self, ppszRestrictions: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_QuerySorting(self, pszSorting: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_QuerySorting(self, ppszSorting: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GenerateSQLFromUserQuery(self, pszQuery: win32more.Windows.Win32.Foundation.PWSTR, ppszSQL: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def WriteProperties(self, itemID: Int32, dwNumberOfColumns: UInt32, pColumns: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), pValues: POINTER(win32more.Windows.Win32.System.Search.SEARCH_COLUMN_PROPERTIES), pftGatherModifiedTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_QueryMaxResults(self, cMaxResults: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_QueryMaxResults(self, pcMaxResults: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchQueryHits(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ed8ce7e0-106c-11ce-84e2-00aa004b9986}')
    @commethod(3)
    def Init(self, pflt: win32more.Windows.Win32.Storage.IndexServer.IFilter, ulFlags: UInt32) -> Int32: ...
    @commethod(4)
    def NextHitMoniker(self, pcMnk: POINTER(UInt32), papMnk: POINTER(POINTER(win32more.Windows.Win32.System.Com.IMoniker))) -> Int32: ...
    @commethod(5)
    def NextHitOffset(self, pcRegion: POINTER(UInt32), paRegion: POINTER(POINTER(win32more.Windows.Win32.Storage.IndexServer.FILTERREGION))) -> Int32: ...
class ISearchRoot(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{04c18ccf-1f57-4cbd-88cc-3900f5195ce3}')
    @commethod(3)
    def put_Schedule(self, pszTaskArg: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_Schedule(self, ppszTaskArg: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def put_RootURL(self, pszURL: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def get_RootURL(self, ppszURL: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def put_IsHierarchical(self, fIsHierarchical: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_IsHierarchical(self, pfIsHierarchical: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_ProvidesNotifications(self, fProvidesNotifications: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_ProvidesNotifications(self, pfProvidesNotifications: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_UseNotificationsOnly(self, fUseNotificationsOnly: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_UseNotificationsOnly(self, pfUseNotificationsOnly: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_EnumerationDepth(self, dwDepth: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_EnumerationDepth(self, pdwDepth: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_HostDepth(self, dwDepth: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_HostDepth(self, pdwDepth: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_FollowDirectories(self, fFollowDirectories: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_FollowDirectories(self, pfFollowDirectories: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_AuthenticationType(self, authType: win32more.Windows.Win32.System.Search.AUTH_TYPE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_AuthenticationType(self, pAuthType: POINTER(win32more.Windows.Win32.System.Search.AUTH_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_User(self, pszUser: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_User(self, ppszUser: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_Password(self, pszPassword: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_Password(self, ppszPassword: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchScopeRule(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ab310581-ac80-11d1-8df3-00c04fb6ef53}')
    @commethod(3)
    def get_PatternOrURL(self, ppszPatternOrURL: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_IsIncluded(self, pfIsIncluded: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_IsDefault(self, pfIsDefault: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def get_FollowFlags(self, pFollowFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchViewChangedSink(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ab310581-ac80-11d1-8df3-00c04fb6ef65}')
    @commethod(3)
    def OnChange(self, pdwDocID: POINTER(Int32), pChange: POINTER(win32more.Windows.Win32.System.Search.SEARCH_ITEM_CHANGE), pfInView: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISecurityInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733aa4-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetCurrentTrustee(self, ppTrustee: POINTER(POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetObjectTypes(self, cObjectTypes: POINTER(UInt32), rgObjectTypes: POINTER(POINTER(Guid))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetPermissions(self, ObjectType: Guid, pPermissions: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IService(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{06210e88-01f5-11d1-b512-0080c781c384}')
    @commethod(3)
    def InvokeService(self, pUnkInner: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISessionProperties(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a85-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetProperties(self, cPropertyIDSets: UInt32, rgPropertyIDSets: POINTER(win32more.Windows.Win32.System.Search.DBPROPIDSET), pcPropertySets: POINTER(UInt32), prgPropertySets: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBPROPSET))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetProperties(self, cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISimpleCommandCreator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5e341ab7-02d0-11d1-900c-00a0c9063796}')
    @commethod(3)
    def CreateICommand(self, ppIUnknown: POINTER(win32more.Windows.Win32.System.Com.IUnknown), pOuterUnk: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def VerifyCatalog(self, pwszMachine: win32more.Windows.Win32.Foundation.PWSTR, pwszCatalogName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetDefaultCatalog(self, pwszCatalogName: win32more.Windows.Win32.Foundation.PWSTR, cwcIn: UInt32, pcwcOut: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISourcesRowset(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a1e-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetSourcesRowset(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, riid: POINTER(Guid), cPropertySets: UInt32, rgProperties: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET), ppSourcesRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IStemmer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{efbaf140-7f42-11ce-be57-00aa0051fe20}')
    @commethod(3)
    def Init(self, ulMaxTokenSize: UInt32, pfLicense: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GenerateWordForms(self, pwcInBuf: win32more.Windows.Win32.Foundation.PWSTR, cwc: UInt32, pStemSink: win32more.Windows.Win32.System.Search.IWordFormSink) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetLicenseToUse(self, ppwcsLicense: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISubscriptionItem(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a97559f8-6c4a-11d1-a1e8-00c04fc2fbe1}')
    @commethod(3)
    def GetCookie(self, pCookie: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetSubscriptionItemInfo(self, pSubscriptionItemInfo: POINTER(win32more.Windows.Win32.System.Search.SUBSCRIPTIONITEMINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetSubscriptionItemInfo(self, pSubscriptionItemInfo: POINTER(win32more.Windows.Win32.System.Search.SUBSCRIPTIONITEMINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def ReadProperties(self, nCount: UInt32, rgwszName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), rgValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def WriteProperties(self, nCount: UInt32, rgwszName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), rgValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def EnumProperties(self, ppEnumItemProperties: POINTER(win32more.Windows.Win32.System.Search.IEnumItemProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def NotifyChanged(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISubscriptionMgr(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{085fb2c0-0df8-11d1-8f4b-00a0c905413f}')
    @commethod(3)
    def DeleteSubscription(self, pwszURL: win32more.Windows.Win32.Foundation.PWSTR, hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def UpdateSubscription(self, pwszURL: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def UpdateAll(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def IsSubscribed(self, pwszURL: win32more.Windows.Win32.Foundation.PWSTR, pfSubscribed: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetSubscriptionInfo(self, pwszURL: win32more.Windows.Win32.Foundation.PWSTR, pInfo: POINTER(win32more.Windows.Win32.System.Search.SUBSCRIPTIONINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetDefaultInfo(self, subType: win32more.Windows.Win32.System.Search.SUBSCRIPTIONTYPE, pInfo: POINTER(win32more.Windows.Win32.System.Search.SUBSCRIPTIONINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def ShowSubscriptionProperties(self, pwszURL: win32more.Windows.Win32.Foundation.PWSTR, hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CreateSubscription(self, hwnd: win32more.Windows.Win32.Foundation.HWND, pwszURL: win32more.Windows.Win32.Foundation.PWSTR, pwszFriendlyName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, subsType: win32more.Windows.Win32.System.Search.SUBSCRIPTIONTYPE, pInfo: POINTER(win32more.Windows.Win32.System.Search.SUBSCRIPTIONINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISubscriptionMgr2(ComPtr):
    extends: win32more.Windows.Win32.System.Search.ISubscriptionMgr
    _iid_ = Guid('{614bc270-aedf-11d1-a1f9-00c04fc2fbe1}')
    @commethod(11)
    def GetItemFromURL(self, pwszURL: win32more.Windows.Win32.Foundation.PWSTR, ppSubscriptionItem: POINTER(win32more.Windows.Win32.System.Search.ISubscriptionItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetItemFromCookie(self, pSubscriptionCookie: POINTER(Guid), ppSubscriptionItem: POINTER(win32more.Windows.Win32.System.Search.ISubscriptionItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetSubscriptionRunState(self, dwNumCookies: UInt32, pCookies: POINTER(Guid), pdwRunState: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def EnumSubscriptions(self, dwFlags: UInt32, ppEnumSubscriptions: POINTER(win32more.Windows.Win32.System.Search.IEnumSubscription)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def UpdateItems(self, dwFlags: UInt32, dwNumCookies: UInt32, pCookies: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def AbortItems(self, dwNumCookies: UInt32, pCookies: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def AbortAll(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITEMPROP(Structure):
    variantValue: win32more.Windows.Win32.System.Variant.VARIANT
    pwszName: win32more.Windows.Win32.Foundation.PWSTR
class ITEM_INFO(Structure):
    dwSize: UInt32
    pcwszFromEMail: win32more.Windows.Win32.Foundation.PWSTR
    pcwszApplicationName: win32more.Windows.Win32.Foundation.PWSTR
    pcwszCatalogName: win32more.Windows.Win32.Foundation.PWSTR
    pcwszContentClass: win32more.Windows.Win32.Foundation.PWSTR
class ITableCreation(ComPtr):
    extends: win32more.Windows.Win32.System.Search.ITableDefinition
    _iid_ = Guid('{0c733abc-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(7)
    def GetTableDefinition(self, pTableID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pcColumnDescs: POINTER(UIntPtr), prgColumnDescs: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBCOLUMNDESC)), pcPropertySets: POINTER(UInt32), prgPropertySets: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBPROPSET)), pcConstraintDescs: POINTER(UInt32), prgConstraintDescs: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBCONSTRAINTDESC)), ppwszStringBuffer: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITableDefinition(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a86-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def CreateTable(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, pTableID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), cColumnDescs: UIntPtr, rgColumnDescs: POINTER(win32more.Windows.Win32.System.Search.DBCOLUMNDESC), riid: POINTER(Guid), cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET), ppTableID: POINTER(POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)), ppRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DropTable(self, pTableID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def AddColumn(self, pTableID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pColumnDesc: POINTER(win32more.Windows.Win32.System.Search.DBCOLUMNDESC), ppColumnID: POINTER(POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def DropColumn(self, pTableID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pColumnID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITableDefinitionWithConstraints(ComPtr):
    extends: win32more.Windows.Win32.System.Search.ITableCreation
    _iid_ = Guid('{0c733aab-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(8)
    def AddConstraint(self, pTableID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pConstraintDesc: POINTER(win32more.Windows.Win32.System.Search.DBCONSTRAINTDESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CreateTableWithConstraints(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, pTableID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), cColumnDescs: UIntPtr, rgColumnDescs: POINTER(win32more.Windows.Win32.System.Search.DBCOLUMNDESC), cConstraintDescs: UInt32, rgConstraintDescs: POINTER(win32more.Windows.Win32.System.Search.DBCONSTRAINTDESC), riid: POINTER(Guid), cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET), ppTableID: POINTER(POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)), ppRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def DropConstraint(self, pTableID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pConstraintID: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITableRename(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a77-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def RenameColumn(self, pTableId: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pOldColumnId: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pNewColumnId: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def RenameTable(self, pOldTableId: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pOldIndexId: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pNewTableId: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID), pNewIndexId: POINTER(win32more.Windows.Win32.Storage.IndexServer.DBID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITokenCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{22d8b4f2-f577-4adb-a335-c2ae88416fab}')
    @commethod(3)
    def NumberOfTokens(self, pCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetToken(self, i: UInt32, pBegin: POINTER(UInt32), pLength: POINTER(UInt32), ppsz: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITransactionJoin(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a5e-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetOptionsObject(self, ppOptions: POINTER(win32more.Windows.Win32.System.DistributedTransactionCoordinator.ITransactionOptions)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def JoinTransaction(self, punkTransactionCoord: win32more.Windows.Win32.System.Com.IUnknown, isoLevel: Int32, isoFlags: UInt32, pOtherOptions: win32more.Windows.Win32.System.DistributedTransactionCoordinator.ITransactionOptions) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITransactionLocal(ComPtr):
    extends: win32more.Windows.Win32.System.DistributedTransactionCoordinator.ITransaction
    _iid_ = Guid('{0c733a5f-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(6)
    def GetOptionsObject(self, ppOptions: POINTER(win32more.Windows.Win32.System.DistributedTransactionCoordinator.ITransactionOptions)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def StartTransaction(self, isoLevel: Int32, isoFlags: UInt32, pOtherOptions: win32more.Windows.Win32.System.DistributedTransactionCoordinator.ITransactionOptions, pulTransactionLevel: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITransactionObject(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a60-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetTransactionObject(self, ulTransactionLevel: UInt32, ppTransactionObject: POINTER(win32more.Windows.Win32.System.DistributedTransactionCoordinator.ITransaction)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITrusteeAdmin(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733aa1-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def CompareTrustees(self, pTrustee1: POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W), pTrustee2: POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateTrustee(self, pTrustee: POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W), cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def DeleteTrustee(self, pTrustee: POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetTrusteeProperties(self, pTrustee: POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W), cPropertySets: UInt32, rgPropertySets: POINTER(win32more.Windows.Win32.System.Search.DBPROPSET)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetTrusteeProperties(self, pTrustee: POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W), cPropertyIDSets: UInt32, rgPropertyIDSets: POINTER(win32more.Windows.Win32.System.Search.DBPROPIDSET), pcPropertySets: POINTER(UInt32), prgPropertySets: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBPROPSET))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITrusteeGroupAdmin(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733aa2-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def AddMember(self, pMembershipTrustee: POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W), pMemberTrustee: POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DeleteMember(self, pMembershipTrustee: POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W), pMemberTrustee: POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def IsMember(self, pMembershipTrustee: POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W), pMemberTrustee: POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W), pfStatus: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetMembers(self, pMembershipTrustee: POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W), pcMembers: POINTER(UInt32), prgMembers: POINTER(POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetMemberships(self, pTrustee: POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W), pcMemberships: POINTER(UInt32), prgMemberships: POINTER(POINTER(win32more.Windows.Win32.Security.Authorization.TRUSTEE_W))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUMS(ComPtr):
    extends: None
    @commethod(0)
    def SqlUmsSuspend(self, ticks: UInt32) -> Void: ...
    @commethod(1)
    def SqlUmsYield(self, ticks: UInt32) -> Void: ...
    @commethod(2)
    def SqlUmsSwitchPremptive(self) -> Void: ...
    @commethod(3)
    def SqlUmsSwitchNonPremptive(self) -> Void: ...
    @commethod(4)
    def SqlUmsFIsPremptive(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
class IUMSInitialize(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5cf4ca14-ef21-11d0-97e7-00c04fc2ad98}')
    @commethod(3)
    def Initialize(self, pUMS: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUrlAccessor(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0b63e318-9ccc-11d0-bcdb-00805fccce04}')
    @commethod(3)
    def AddRequestParameter(self, pSpec: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPSPEC), pVar: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDocFormat(self, wszDocFormat: win32more.Windows.Win32.Foundation.PWSTR, dwSize: UInt32, pdwLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCLSID(self, pClsid: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetHost(self, wszHost: win32more.Windows.Win32.Foundation.PWSTR, dwSize: UInt32, pdwLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def IsDirectory(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetSize(self, pllSize: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetLastModified(self, pftLastModified: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetFileName(self, wszFileName: win32more.Windows.Win32.Foundation.PWSTR, dwSize: UInt32, pdwLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetSecurityDescriptor(self, pSD: POINTER(Byte), dwSize: UInt32, pdwLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetRedirectedURL(self, wszRedirectedURL: win32more.Windows.Win32.Foundation.PWSTR, dwSize: UInt32, pdwLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetSecurityProvider(self, pSPClsid: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def BindToStream(self, ppStream: POINTER(win32more.Windows.Win32.System.Com.IStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def BindToFilter(self, ppFilter: POINTER(win32more.Windows.Win32.Storage.IndexServer.IFilter)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUrlAccessor2(ComPtr):
    extends: win32more.Windows.Win32.System.Search.IUrlAccessor
    _iid_ = Guid('{c7310734-ac80-11d1-8df3-00c04fb6ef4f}')
    @commethod(16)
    def GetDisplayUrl(self, wszDocUrl: win32more.Windows.Win32.Foundation.PWSTR, dwSize: UInt32, pdwLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def IsDocument(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetCodePage(self, wszCodePage: win32more.Windows.Win32.Foundation.PWSTR, dwSize: UInt32, pdwLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUrlAccessor3(ComPtr):
    extends: win32more.Windows.Win32.System.Search.IUrlAccessor2
    _iid_ = Guid('{6fbc7005-0455-4874-b8ff-7439450241a3}')
    @commethod(19)
    def GetImpersonationSidBlobs(self, pcwszURL: win32more.Windows.Win32.Foundation.PWSTR, pcSidCount: POINTER(UInt32), ppSidBlobs: POINTER(POINTER(win32more.Windows.Win32.System.Com.BLOB))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUrlAccessor4(ComPtr):
    extends: win32more.Windows.Win32.System.Search.IUrlAccessor3
    _iid_ = Guid('{5cc51041-c8d2-41d7-bca3-9e9e286297dc}')
    @commethod(20)
    def ShouldIndexItemContent(self, pfIndexContent: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def ShouldIndexProperty(self, key: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), pfIndexProperty: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IViewChapter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a98-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetSpecification(self, riid: POINTER(Guid), ppRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OpenViewChapter(self, hSource: UIntPtr, phViewChapter: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IViewFilter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a9b-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetFilter(self, hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, pcRows: POINTER(UIntPtr), pCompareOps: POINTER(POINTER(UInt32)), pCriteriaData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetFilterBindings(self, pcBindings: POINTER(UIntPtr), prgBindings: POINTER(POINTER(win32more.Windows.Win32.System.Search.DBBINDING))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetFilter(self, hAccessor: win32more.Windows.Win32.System.Search.HACCESSOR, cRows: UIntPtr, CompareOps: POINTER(UInt32), pCriteriaData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IViewRowset(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a97-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetSpecification(self, riid: POINTER(Guid), ppObject: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OpenViewRowset(self, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, riid: POINTER(Guid), ppRowset: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IViewSort(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c733a9a-2a1c-11ce-ade5-00aa0044773d}')
    @commethod(3)
    def GetSortOrder(self, pcValues: POINTER(UIntPtr), prgColumns: POINTER(POINTER(UIntPtr)), prgOrders: POINTER(POINTER(UInt32))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetSortOrder(self, cValues: UIntPtr, rgColumns: POINTER(UIntPtr), rgOrders: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWordBreaker(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d53552c8-77e3-101a-b552-08002b33b0e6}')
    @commethod(3)
    def Init(self, fQuery: win32more.Windows.Win32.Foundation.BOOL, ulMaxTokenSize: UInt32, pfLicense: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def BreakText(self, pTextSource: POINTER(win32more.Windows.Win32.System.Search.TEXT_SOURCE), pWordSink: win32more.Windows.Win32.System.Search.IWordSink, pPhraseSink: win32more.Windows.Win32.Storage.IndexServer.IPhraseSink) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def ComposePhrase(self, pwcNoun: win32more.Windows.Win32.Foundation.PWSTR, cwcNoun: UInt32, pwcModifier: win32more.Windows.Win32.Foundation.PWSTR, cwcModifier: UInt32, ulAttachmentType: UInt32, pwcPhrase: win32more.Windows.Win32.Foundation.PWSTR, pcwcPhrase: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetLicenseToUse(self, ppwcsLicense: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWordFormSink(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{fe77c330-7f42-11ce-be57-00aa0051fe20}')
    @commethod(3)
    def PutAltWord(self, pwcInBuf: win32more.Windows.Win32.Foundation.PWSTR, cwc: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def PutWord(self, pwcInBuf: win32more.Windows.Win32.Foundation.PWSTR, cwc: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWordSink(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{cc907054-c058-101a-b554-08002b33b0e6}')
    @commethod(3)
    def PutWord(self, cwc: UInt32, pwcInBuf: win32more.Windows.Win32.Foundation.PWSTR, cwcSrcLen: UInt32, cwcSrcPos: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def PutAltWord(self, cwc: UInt32, pwcInBuf: win32more.Windows.Win32.Foundation.PWSTR, cwcSrcLen: UInt32, cwcSrcPos: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def StartAltPhrase(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def EndAltPhrase(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def PutBreak(self, breakType: win32more.Windows.Win32.Storage.IndexServer.WORDREP_BREAK_TYPE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
Interval = Guid('{d957171f-4bf9-4de2-bcd5-c70a7ca55836}')
class KAGGETDIAG(Structure):
    ulSize: UInt32
    vDiagInfo: win32more.Windows.Win32.System.Variant.VARIANT
    sDiagField: Int16
class KAGREQDIAG(Structure):
    ulDiagFlags: UInt32
    vt: win32more.Windows.Win32.System.Variant.VARENUM
    sDiagField: Int16
KAGREQDIAGFLAGSENUM = Int32
KAGREQDIAGFLAGS_HEADER: win32more.Windows.Win32.System.Search.KAGREQDIAGFLAGSENUM = 1
KAGREQDIAGFLAGS_RECORD: win32more.Windows.Win32.System.Search.KAGREQDIAGFLAGSENUM = 2
LOCKMODEENUM = Int32
LOCKMODE_INVALID: win32more.Windows.Win32.System.Search.LOCKMODEENUM = 0
LOCKMODE_EXCLUSIVE: win32more.Windows.Win32.System.Search.LOCKMODEENUM = 1
LOCKMODE_SHARED: win32more.Windows.Win32.System.Search.LOCKMODEENUM = 2
LeafCondition = Guid('{52f15c89-5a17-48e1-bbcd-46a3f89c7cc2}')
if ARCH in 'X64,ARM64':
    class MDAXISINFO(Structure):
        cbSize: UIntPtr
        iAxis: UIntPtr
        cDimensions: UIntPtr
        cCoordinates: UIntPtr
        rgcColumns: POINTER(UIntPtr)
        rgpwszDimensionNames: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
elif ARCH in 'X86':
    class MDAXISINFO(Structure):
        cbSize: UIntPtr
        iAxis: UIntPtr
        cDimensions: UIntPtr
        cCoordinates: UIntPtr
        rgcColumns: POINTER(UIntPtr)
        rgpwszDimensionNames: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
        _pack_ = 2
MSDAINITIALIZE = Guid('{2206cdb0-19c1-11d1-89e0-00c04fd7a829}')
MSDAORA = Guid('{e8cc4cbe-fdff-11d0-b865-00a0c9081c1d}')
MSDAORA8 = Guid('{7f06a373-dd6a-43db-b4e0-1fc121e5e62b}')
MSDAORA8_ERROR = Guid('{7f06a374-dd6a-43db-b4e0-1fc121e5e62b}')
MSDAORA_ERROR = Guid('{e8cc4cbf-fdff-11d0-b865-00a0c9081c1d}')
MSDSDBINITPROPENUM = Int32
DBPROP_MSDS_DBINIT_DATAPROVIDER: win32more.Windows.Win32.System.Search.MSDSDBINITPROPENUM = 2
MSDSSESSIONPROPENUM = Int32
DBPROP_MSDS_SESS_UNIQUENAMES: win32more.Windows.Win32.System.Search.MSDSSESSIONPROPENUM = 2
NAMED_ENTITY_CERTAINTY = Int32
NEC_LOW: win32more.Windows.Win32.System.Search.NAMED_ENTITY_CERTAINTY = 0
NEC_MEDIUM: win32more.Windows.Win32.System.Search.NAMED_ENTITY_CERTAINTY = 1
NEC_HIGH: win32more.Windows.Win32.System.Search.NAMED_ENTITY_CERTAINTY = 2
class NATLANGUAGERESTRICTION(Structure):
    prop: win32more.Windows.Win32.Storage.IndexServer.FULLPROPSPEC
    pwcsPhrase: win32more.Windows.Win32.Foundation.PWSTR
    lcid: UInt32
class NODERESTRICTION(Structure):
    cRes: UInt32
    paRes: POINTER(POINTER(win32more.Windows.Win32.System.Search.RESTRICTION))
    reserved: UInt32
class NOTRESTRICTION(Structure):
    pRes: POINTER(win32more.Windows.Win32.System.Search.RESTRICTION)
NegationCondition = Guid('{8de9c74c-605a-4acd-bee3-2b222aa2d23d}')
class ODBC_VS_ARGS(Structure):
    pguidEvent: POINTER(Guid)
    dwFlags: UInt32
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    RetCode: Int16
    class _Anonymous1_e__Union(Union):
        wszArg: win32more.Windows.Win32.Foundation.PWSTR
        szArg: win32more.Windows.Win32.Foundation.PSTR
    class _Anonymous2_e__Union(Union):
        wszCorrelation: win32more.Windows.Win32.Foundation.PWSTR
        szCorrelation: win32more.Windows.Win32.Foundation.PSTR
class OLEDBSimpleProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e0e270c0-c0be-11d0-8fe4-00a0c90a6341}')
    @commethod(3)
    def getRowCount(self, pcRows: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def getColumnCount(self, pcColumns: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def getRWStatus(self, iRow: IntPtr, iColumn: IntPtr, prwStatus: POINTER(win32more.Windows.Win32.System.Search.OSPRW)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def getVariant(self, iRow: IntPtr, iColumn: IntPtr, format: win32more.Windows.Win32.System.Search.OSPFORMAT, pVar: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def setVariant(self, iRow: IntPtr, iColumn: IntPtr, format: win32more.Windows.Win32.System.Search.OSPFORMAT, Var: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def getLocale(self, pbstrLocale: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def deleteRows(self, iRow: IntPtr, cRows: IntPtr, pcRowsDeleted: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def insertRows(self, iRow: IntPtr, cRows: IntPtr, pcRowsInserted: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def find(self, iRowStart: IntPtr, iColumn: IntPtr, val: win32more.Windows.Win32.System.Variant.VARIANT, findFlags: win32more.Windows.Win32.System.Search.OSPFIND, compType: win32more.Windows.Win32.System.Search.OSPCOMP, piRowFound: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def addOLEDBSimpleProviderListener(self, pospIListener: win32more.Windows.Win32.System.Search.OLEDBSimpleProviderListener) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def removeOLEDBSimpleProviderListener(self, pospIListener: win32more.Windows.Win32.System.Search.OLEDBSimpleProviderListener) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def isAsync(self, pbAsynch: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def getEstimatedRows(self, piRows: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def stopTransfer(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class OLEDBSimpleProviderListener(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e0e270c1-c0be-11d0-8fe4-00a0c90a6341}')
    @commethod(3)
    def aboutToChangeCell(self, iRow: IntPtr, iColumn: IntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def cellChanged(self, iRow: IntPtr, iColumn: IntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def aboutToDeleteRows(self, iRow: IntPtr, cRows: IntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def deletedRows(self, iRow: IntPtr, cRows: IntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def aboutToInsertRows(self, iRow: IntPtr, cRows: IntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def insertedRows(self, iRow: IntPtr, cRows: IntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def rowsAvailable(self, iRow: IntPtr, cRows: IntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def transferComplete(self, xfer: win32more.Windows.Win32.System.Search.OSPXFER) -> win32more.Windows.Win32.Foundation.HRESULT: ...
OSPCOMP = Int32
OSPCOMP_EQ: win32more.Windows.Win32.System.Search.OSPCOMP = 1
OSPCOMP_DEFAULT: win32more.Windows.Win32.System.Search.OSPCOMP = 1
OSPCOMP_LT: win32more.Windows.Win32.System.Search.OSPCOMP = 2
OSPCOMP_LE: win32more.Windows.Win32.System.Search.OSPCOMP = 3
OSPCOMP_GE: win32more.Windows.Win32.System.Search.OSPCOMP = 4
OSPCOMP_GT: win32more.Windows.Win32.System.Search.OSPCOMP = 5
OSPCOMP_NE: win32more.Windows.Win32.System.Search.OSPCOMP = 6
OSPFIND = Int32
OSPFIND_DEFAULT: win32more.Windows.Win32.System.Search.OSPFIND = 0
OSPFIND_UP: win32more.Windows.Win32.System.Search.OSPFIND = 1
OSPFIND_CASESENSITIVE: win32more.Windows.Win32.System.Search.OSPFIND = 2
OSPFIND_UPCASESENSITIVE: win32more.Windows.Win32.System.Search.OSPFIND = 3
OSPFORMAT = Int32
OSPFORMAT_RAW: win32more.Windows.Win32.System.Search.OSPFORMAT = 0
OSPFORMAT_DEFAULT: win32more.Windows.Win32.System.Search.OSPFORMAT = 0
OSPFORMAT_FORMATTED: win32more.Windows.Win32.System.Search.OSPFORMAT = 1
OSPFORMAT_HTML: win32more.Windows.Win32.System.Search.OSPFORMAT = 2
OSPRW = Int32
OSPRW_DEFAULT: win32more.Windows.Win32.System.Search.OSPRW = 1
OSPRW_READONLY: win32more.Windows.Win32.System.Search.OSPRW = 0
OSPRW_READWRITE: win32more.Windows.Win32.System.Search.OSPRW = 1
OSPRW_MIXED: win32more.Windows.Win32.System.Search.OSPRW = 2
OSPXFER = Int32
OSPXFER_COMPLETE: win32more.Windows.Win32.System.Search.OSPXFER = 0
OSPXFER_ABORT: win32more.Windows.Win32.System.Search.OSPXFER = 1
OSPXFER_ERROR: win32more.Windows.Win32.System.Search.OSPXFER = 2
PDPO = Guid('{ccb4ec60-b9dc-11d1-ac80-00a0c9034873}')
@winfunctype_pointer
def PFNFILLTEXTBUFFER(pTextSource: POINTER(win32more.Windows.Win32.System.Search.TEXT_SOURCE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
PRIORITIZE_FLAGS = Int32
PRIORITIZE_FLAG_RETRYFAILEDITEMS: win32more.Windows.Win32.System.Search.PRIORITIZE_FLAGS = 1
PRIORITIZE_FLAG_IGNOREFAILURECOUNT: win32more.Windows.Win32.System.Search.PRIORITIZE_FLAGS = 2
PRIORITY_LEVEL = Int32
PRIORITY_LEVEL_FOREGROUND: win32more.Windows.Win32.System.Search.PRIORITY_LEVEL = 0
PRIORITY_LEVEL_HIGH: win32more.Windows.Win32.System.Search.PRIORITY_LEVEL = 1
PRIORITY_LEVEL_LOW: win32more.Windows.Win32.System.Search.PRIORITY_LEVEL = 2
PRIORITY_LEVEL_DEFAULT: win32more.Windows.Win32.System.Search.PRIORITY_LEVEL = 3
class PROPERTYRESTRICTION(Structure):
    rel: UInt32
    prop: win32more.Windows.Win32.Storage.IndexServer.FULLPROPSPEC
    prval: win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT
PROXY_ACCESS = Int32
PROXY_ACCESS_PRECONFIG: win32more.Windows.Win32.System.Search.PROXY_ACCESS = 0
PROXY_ACCESS_DIRECT: win32more.Windows.Win32.System.Search.PROXY_ACCESS = 1
PROXY_ACCESS_PROXY: win32more.Windows.Win32.System.Search.PROXY_ACCESS = 2
class PROXY_INFO(Structure):
    dwSize: UInt32
    pcwszUserAgent: win32more.Windows.Win32.Foundation.PWSTR
    paUseProxy: win32more.Windows.Win32.System.Search.PROXY_ACCESS
    fLocalBypass: win32more.Windows.Win32.Foundation.BOOL
    dwPortNumber: UInt32
    pcwszProxyName: win32more.Windows.Win32.Foundation.PWSTR
    pcwszBypassList: win32more.Windows.Win32.Foundation.PWSTR
QUERY_PARSER_MANAGER_OPTION = Int32
QPMO_SCHEMA_BINARY_NAME: win32more.Windows.Win32.System.Search.QUERY_PARSER_MANAGER_OPTION = 0
QPMO_PRELOCALIZED_SCHEMA_BINARY_PATH: win32more.Windows.Win32.System.Search.QUERY_PARSER_MANAGER_OPTION = 1
QPMO_UNLOCALIZED_SCHEMA_BINARY_PATH: win32more.Windows.Win32.System.Search.QUERY_PARSER_MANAGER_OPTION = 2
QPMO_LOCALIZED_SCHEMA_BINARY_PATH: win32more.Windows.Win32.System.Search.QUERY_PARSER_MANAGER_OPTION = 3
QPMO_APPEND_LCID_TO_LOCALIZED_PATH: win32more.Windows.Win32.System.Search.QUERY_PARSER_MANAGER_OPTION = 4
QPMO_LOCALIZER_SUPPORT: win32more.Windows.Win32.System.Search.QUERY_PARSER_MANAGER_OPTION = 5
QueryParser = Guid('{b72f8fd8-0fab-4dd9-bdbf-245a6ce1485b}')
QueryParserManager = Guid('{5088b39a-29b4-4d9d-8245-4ee289222f66}')
class RANGECATEGORIZE(Structure):
    cRange: UInt32
    aRangeBegin: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)
class RESTRICTION(Structure):
    rt: UInt32
    weight: UInt32
    res: _URes
    class _URes(Union):
        ar: win32more.Windows.Win32.System.Search.NODERESTRICTION
        orRestriction: win32more.Windows.Win32.System.Search.NODERESTRICTION
        pxr: win32more.Windows.Win32.System.Search.NODERESTRICTION
        vr: win32more.Windows.Win32.System.Search.VECTORRESTRICTION
        nr: win32more.Windows.Win32.System.Search.NOTRESTRICTION
        cr: win32more.Windows.Win32.System.Search.CONTENTRESTRICTION
        nlr: win32more.Windows.Win32.System.Search.NATLANGUAGERESTRICTION
        pr: win32more.Windows.Win32.System.Search.PROPERTYRESTRICTION
if ARCH in 'X64,ARM64':
    class RMTPACK(Structure):
        pISeqStream: win32more.Windows.Win32.System.Com.ISequentialStream
        cbData: UInt32
        cBSTR: UInt32
        rgBSTR: POINTER(win32more.Windows.Win32.Foundation.BSTR)
        cVARIANT: UInt32
        rgVARIANT: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)
        cIDISPATCH: UInt32
        rgIDISPATCH: POINTER(win32more.Windows.Win32.System.Com.IDispatch)
        cIUNKNOWN: UInt32
        rgIUNKNOWN: POINTER(win32more.Windows.Win32.System.Com.IUnknown)
        cPROPVARIANT: UInt32
        rgPROPVARIANT: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)
        cArray: UInt32
        rgArray: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)
elif ARCH in 'X86':
    class RMTPACK(Structure):
        pISeqStream: win32more.Windows.Win32.System.Com.ISequentialStream
        cbData: UInt32
        cBSTR: UInt32
        rgBSTR: POINTER(win32more.Windows.Win32.Foundation.BSTR)
        cVARIANT: UInt32
        rgVARIANT: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)
        cIDISPATCH: UInt32
        rgIDISPATCH: POINTER(win32more.Windows.Win32.System.Com.IDispatch)
        cIUNKNOWN: UInt32
        rgIUNKNOWN: POINTER(win32more.Windows.Win32.System.Com.IUnknown)
        cPROPVARIANT: UInt32
        rgPROPVARIANT: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)
        cArray: UInt32
        rgArray: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)
        _pack_ = 2
ROWSETEVENT_ITEMSTATE = Int32
ROWSETEVENT_ITEMSTATE_NOTINROWSET: win32more.Windows.Win32.System.Search.ROWSETEVENT_ITEMSTATE = 0
ROWSETEVENT_ITEMSTATE_INROWSET: win32more.Windows.Win32.System.Search.ROWSETEVENT_ITEMSTATE = 1
ROWSETEVENT_ITEMSTATE_UNKNOWN: win32more.Windows.Win32.System.Search.ROWSETEVENT_ITEMSTATE = 2
ROWSETEVENT_TYPE = Int32
ROWSETEVENT_TYPE_DATAEXPIRED: win32more.Windows.Win32.System.Search.ROWSETEVENT_TYPE = 0
ROWSETEVENT_TYPE_FOREGROUNDLOST: win32more.Windows.Win32.System.Search.ROWSETEVENT_TYPE = 1
ROWSETEVENT_TYPE_SCOPESTATISTICS: win32more.Windows.Win32.System.Search.ROWSETEVENT_TYPE = 2
RootBinder = Guid('{ff151822-b0bf-11d1-a80d-000000000000}')
class SEARCH_COLUMN_PROPERTIES(Structure):
    Value: win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT
    lcid: UInt32
SEARCH_INDEXING_PHASE = Int32
SEARCH_INDEXING_PHASE_GATHERER: win32more.Windows.Win32.System.Search.SEARCH_INDEXING_PHASE = 0
SEARCH_INDEXING_PHASE_QUERYABLE: win32more.Windows.Win32.System.Search.SEARCH_INDEXING_PHASE = 1
SEARCH_INDEXING_PHASE_PERSISTED: win32more.Windows.Win32.System.Search.SEARCH_INDEXING_PHASE = 2
class SEARCH_ITEM_CHANGE(Structure):
    Change: win32more.Windows.Win32.System.Search.SEARCH_KIND_OF_CHANGE
    Priority: win32more.Windows.Win32.System.Search.SEARCH_NOTIFICATION_PRIORITY
    pUserData: POINTER(win32more.Windows.Win32.System.Com.BLOB)
    lpwszURL: win32more.Windows.Win32.Foundation.PWSTR
    lpwszOldURL: win32more.Windows.Win32.Foundation.PWSTR
class SEARCH_ITEM_INDEXING_STATUS(Structure):
    dwDocID: UInt32
    hrIndexingStatus: win32more.Windows.Win32.Foundation.HRESULT
class SEARCH_ITEM_PERSISTENT_CHANGE(Structure):
    Change: win32more.Windows.Win32.System.Search.SEARCH_KIND_OF_CHANGE
    URL: win32more.Windows.Win32.Foundation.PWSTR
    OldURL: win32more.Windows.Win32.Foundation.PWSTR
    Priority: win32more.Windows.Win32.System.Search.SEARCH_NOTIFICATION_PRIORITY
SEARCH_KIND_OF_CHANGE = Int32
SEARCH_CHANGE_ADD: win32more.Windows.Win32.System.Search.SEARCH_KIND_OF_CHANGE = 0
SEARCH_CHANGE_DELETE: win32more.Windows.Win32.System.Search.SEARCH_KIND_OF_CHANGE = 1
SEARCH_CHANGE_MODIFY: win32more.Windows.Win32.System.Search.SEARCH_KIND_OF_CHANGE = 2
SEARCH_CHANGE_MOVE_RENAME: win32more.Windows.Win32.System.Search.SEARCH_KIND_OF_CHANGE = 3
SEARCH_CHANGE_SEMANTICS_DIRECTORY: win32more.Windows.Win32.System.Search.SEARCH_KIND_OF_CHANGE = 262144
SEARCH_CHANGE_SEMANTICS_SHALLOW: win32more.Windows.Win32.System.Search.SEARCH_KIND_OF_CHANGE = 524288
SEARCH_CHANGE_SEMANTICS_UPDATE_SECURITY: win32more.Windows.Win32.System.Search.SEARCH_KIND_OF_CHANGE = 4194304
SEARCH_NOTIFICATION_PRIORITY = Int32
SEARCH_NORMAL_PRIORITY: win32more.Windows.Win32.System.Search.SEARCH_NOTIFICATION_PRIORITY = 0
SEARCH_HIGH_PRIORITY: win32more.Windows.Win32.System.Search.SEARCH_NOTIFICATION_PRIORITY = 1
SEARCH_QUERY_SYNTAX = Int32
SEARCH_NO_QUERY_SYNTAX: win32more.Windows.Win32.System.Search.SEARCH_QUERY_SYNTAX = 0
SEARCH_ADVANCED_QUERY_SYNTAX: win32more.Windows.Win32.System.Search.SEARCH_QUERY_SYNTAX = 1
SEARCH_NATURAL_QUERY_SYNTAX: win32more.Windows.Win32.System.Search.SEARCH_QUERY_SYNTAX = 2
SEARCH_TERM_EXPANSION = Int32
SEARCH_TERM_NO_EXPANSION: win32more.Windows.Win32.System.Search.SEARCH_TERM_EXPANSION = 0
SEARCH_TERM_PREFIX_ALL: win32more.Windows.Win32.System.Search.SEARCH_TERM_EXPANSION = 1
SEARCH_TERM_STEM_ALL: win32more.Windows.Win32.System.Search.SEARCH_TERM_EXPANSION = 2
if ARCH in 'X64,ARM64':
    class SEC_OBJECT(Structure):
        cObjects: UInt32
        prgObjects: POINTER(win32more.Windows.Win32.System.Search.SEC_OBJECT_ELEMENT)
elif ARCH in 'X86':
    class SEC_OBJECT(Structure):
        cObjects: UInt32
        prgObjects: POINTER(win32more.Windows.Win32.System.Search.SEC_OBJECT_ELEMENT)
        _pack_ = 2
if ARCH in 'X64,ARM64':
    class SEC_OBJECT_ELEMENT(Structure):
        guidObjectType: Guid
        ObjectID: win32more.Windows.Win32.Storage.IndexServer.DBID
elif ARCH in 'X86':
    class SEC_OBJECT_ELEMENT(Structure):
        guidObjectType: Guid
        ObjectID: win32more.Windows.Win32.Storage.IndexServer.DBID
        _pack_ = 2
class SORTKEY(Structure):
    propColumn: win32more.Windows.Win32.Storage.IndexServer.FULLPROPSPEC
    dwOrder: UInt32
    locale: UInt32
class SORTSET(Structure):
    cCol: UInt32
    aCol: POINTER(win32more.Windows.Win32.System.Search.SORTKEY)
SQLINTERVAL = Int32
SQL_IS_YEAR: win32more.Windows.Win32.System.Search.SQLINTERVAL = 1
SQL_IS_MONTH: win32more.Windows.Win32.System.Search.SQLINTERVAL = 2
SQL_IS_DAY: win32more.Windows.Win32.System.Search.SQLINTERVAL = 3
SQL_IS_HOUR: win32more.Windows.Win32.System.Search.SQLINTERVAL = 4
SQL_IS_MINUTE: win32more.Windows.Win32.System.Search.SQLINTERVAL = 5
SQL_IS_SECOND: win32more.Windows.Win32.System.Search.SQLINTERVAL = 6
SQL_IS_YEAR_TO_MONTH: win32more.Windows.Win32.System.Search.SQLINTERVAL = 7
SQL_IS_DAY_TO_HOUR: win32more.Windows.Win32.System.Search.SQLINTERVAL = 8
SQL_IS_DAY_TO_MINUTE: win32more.Windows.Win32.System.Search.SQLINTERVAL = 9
SQL_IS_DAY_TO_SECOND: win32more.Windows.Win32.System.Search.SQLINTERVAL = 10
SQL_IS_HOUR_TO_MINUTE: win32more.Windows.Win32.System.Search.SQLINTERVAL = 11
SQL_IS_HOUR_TO_SECOND: win32more.Windows.Win32.System.Search.SQLINTERVAL = 12
SQL_IS_MINUTE_TO_SECOND: win32more.Windows.Win32.System.Search.SQLINTERVAL = 13
class SQLPERF(Structure):
    TimerResolution: UInt32
    SQLidu: UInt32
    SQLiduRows: UInt32
    SQLSelects: UInt32
    SQLSelectRows: UInt32
    Transactions: UInt32
    SQLPrepares: UInt32
    ExecDirects: UInt32
    SQLExecutes: UInt32
    CursorOpens: UInt32
    CursorSize: UInt32
    CursorUsed: UInt32
    PercentCursorUsed: Double
    AvgFetchTime: Double
    AvgCursorSize: Double
    AvgCursorUsed: Double
    SQLFetchTime: UInt32
    SQLFetchCount: UInt32
    CurrentStmtCount: UInt32
    MaxOpenStmt: UInt32
    SumOpenStmt: UInt32
    CurrentConnectionCount: UInt32
    MaxConnectionsOpened: UInt32
    SumConnectionsOpened: UInt32
    SumConnectiontime: UInt32
    AvgTimeOpened: Double
    ServerRndTrips: UInt32
    BuffersSent: UInt32
    BuffersRec: UInt32
    BytesSent: UInt32
    BytesRec: UInt32
    msExecutionTime: UInt32
    msNetWorkServerTime: UInt32
SQLVARENUM = Int32
VT_SS_EMPTY: win32more.Windows.Win32.System.Search.SQLVARENUM = 0
VT_SS_NULL: win32more.Windows.Win32.System.Search.SQLVARENUM = 1
VT_SS_UI1: win32more.Windows.Win32.System.Search.SQLVARENUM = 17
VT_SS_I2: win32more.Windows.Win32.System.Search.SQLVARENUM = 2
VT_SS_I4: win32more.Windows.Win32.System.Search.SQLVARENUM = 3
VT_SS_I8: win32more.Windows.Win32.System.Search.SQLVARENUM = 20
VT_SS_R4: win32more.Windows.Win32.System.Search.SQLVARENUM = 4
VT_SS_R8: win32more.Windows.Win32.System.Search.SQLVARENUM = 5
VT_SS_MONEY: win32more.Windows.Win32.System.Search.SQLVARENUM = 6
VT_SS_SMALLMONEY: win32more.Windows.Win32.System.Search.SQLVARENUM = 200
VT_SS_WSTRING: win32more.Windows.Win32.System.Search.SQLVARENUM = 201
VT_SS_WVARSTRING: win32more.Windows.Win32.System.Search.SQLVARENUM = 202
VT_SS_STRING: win32more.Windows.Win32.System.Search.SQLVARENUM = 203
VT_SS_VARSTRING: win32more.Windows.Win32.System.Search.SQLVARENUM = 204
VT_SS_BIT: win32more.Windows.Win32.System.Search.SQLVARENUM = 11
VT_SS_GUID: win32more.Windows.Win32.System.Search.SQLVARENUM = 72
VT_SS_NUMERIC: win32more.Windows.Win32.System.Search.SQLVARENUM = 131
VT_SS_DECIMAL: win32more.Windows.Win32.System.Search.SQLVARENUM = 205
VT_SS_DATETIME: win32more.Windows.Win32.System.Search.SQLVARENUM = 135
VT_SS_SMALLDATETIME: win32more.Windows.Win32.System.Search.SQLVARENUM = 206
VT_SS_BINARY: win32more.Windows.Win32.System.Search.SQLVARENUM = 207
VT_SS_VARBINARY: win32more.Windows.Win32.System.Search.SQLVARENUM = 208
VT_SS_UNKNOWN: win32more.Windows.Win32.System.Search.SQLVARENUM = 209
@winfunctype_pointer
def SQL_ASYNC_NOTIFICATION_CALLBACK(pContext: VoidPtr, fLast: win32more.Windows.Win32.Foundation.BOOL) -> Int16: ...
class SQL_DAY_SECOND_STRUCT(Structure):
    day: UInt32
    hour: UInt32
    minute: UInt32
    second: UInt32
    fraction: UInt32
class SQL_INTERVAL_STRUCT(Structure):
    interval_type: win32more.Windows.Win32.System.Search.SQLINTERVAL
    interval_sign: Int16
    intval: _intval_e__Union
    class _intval_e__Union(Union):
        year_month: win32more.Windows.Win32.System.Search.SQL_YEAR_MONTH_STRUCT
        day_second: win32more.Windows.Win32.System.Search.SQL_DAY_SECOND_STRUCT
class SQL_NUMERIC_STRUCT(Structure):
    precision: Byte
    scale: SByte
    sign: Byte
    val: Byte * 16
class SQL_YEAR_MONTH_STRUCT(Structure):
    year: UInt32
    month: UInt32
class SSERRORINFO(Structure):
    pwszMessage: win32more.Windows.Win32.Foundation.PWSTR
    pwszServer: win32more.Windows.Win32.Foundation.PWSTR
    pwszProcedure: win32more.Windows.Win32.Foundation.PWSTR
    lNative: Int32
    bState: Byte
    bClass: Byte
    wLineNumber: UInt16
class SSVARIANT(Structure):
    vt: UInt16
    dwReserved1: UInt32
    dwReserved2: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        bTinyIntVal: Byte
        sShortIntVal: Int16
        lIntVal: Int32
        llBigIntVal: Int64
        fltRealVal: Single
        dblFloatVal: Double
        cyMoneyVal: win32more.Windows.Win32.System.Com.CY
        NCharVal: _NCharVal
        CharVal: _CharVal
        fBitVal: win32more.Windows.Win32.Foundation.VARIANT_BOOL
        rgbGuidVal: Byte * 16
        numNumericVal: win32more.Windows.Win32.System.Search.DB_NUMERIC
        BinaryVal: _BinaryVal
        tsDateTimeVal: win32more.Windows.Win32.System.Search.DBTIMESTAMP
        UnknownType: _UnknownType
        BLOBType: _BLOBType
        class _NCharVal(Structure):
            sActualLength: Int16
            sMaxLength: Int16
            pwchNCharVal: win32more.Windows.Win32.Foundation.PWSTR
            rgbReserved: Byte * 5
            dwReserved: UInt32
            pwchReserved: win32more.Windows.Win32.Foundation.PWSTR
        class _CharVal(Structure):
            sActualLength: Int16
            sMaxLength: Int16
            pchCharVal: win32more.Windows.Win32.Foundation.PSTR
            rgbReserved: Byte * 5
            dwReserved: UInt32
            pwchReserved: win32more.Windows.Win32.Foundation.PWSTR
        class _BinaryVal(Structure):
            sActualLength: Int16
            sMaxLength: Int16
            prgbBinaryVal: POINTER(Byte)
            dwReserved: UInt32
        class _UnknownType(Structure):
            dwActualLength: UInt32
            rgMetadata: Byte * 16
            pUnknownData: POINTER(Byte)
        class _BLOBType(Structure):
            dbobj: win32more.Windows.Win32.System.Search.DBOBJECT
            pUnk: win32more.Windows.Win32.System.Com.IUnknown
STRUCTURED_QUERY_MULTIOPTION = Int32
SQMO_VIRTUAL_PROPERTY: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_MULTIOPTION = 0
SQMO_DEFAULT_PROPERTY: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_MULTIOPTION = 1
SQMO_GENERATOR_FOR_TYPE: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_MULTIOPTION = 2
SQMO_MAP_PROPERTY: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_MULTIOPTION = 3
STRUCTURED_QUERY_PARSE_ERROR = Int32
SQPE_NONE: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_PARSE_ERROR = 0
SQPE_EXTRA_OPENING_PARENTHESIS: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_PARSE_ERROR = 1
SQPE_EXTRA_CLOSING_PARENTHESIS: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_PARSE_ERROR = 2
SQPE_IGNORED_MODIFIER: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_PARSE_ERROR = 3
SQPE_IGNORED_CONNECTOR: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_PARSE_ERROR = 4
SQPE_IGNORED_KEYWORD: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_PARSE_ERROR = 5
SQPE_UNHANDLED: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_PARSE_ERROR = 6
STRUCTURED_QUERY_RESOLVE_OPTION = Int32
SQRO_DEFAULT: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_RESOLVE_OPTION = 0
SQRO_DONT_RESOLVE_DATETIME: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_RESOLVE_OPTION = 1
SQRO_ALWAYS_ONE_INTERVAL: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_RESOLVE_OPTION = 2
SQRO_DONT_SIMPLIFY_CONDITION_TREES: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_RESOLVE_OPTION = 4
SQRO_DONT_MAP_RELATIONS: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_RESOLVE_OPTION = 8
SQRO_DONT_RESOLVE_RANGES: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_RESOLVE_OPTION = 16
SQRO_DONT_REMOVE_UNRESTRICTED_KEYWORDS: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_RESOLVE_OPTION = 32
SQRO_DONT_SPLIT_WORDS: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_RESOLVE_OPTION = 64
SQRO_IGNORE_PHRASE_ORDER: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_RESOLVE_OPTION = 128
SQRO_ADD_VALUE_TYPE_FOR_PLAIN_VALUES: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_RESOLVE_OPTION = 256
SQRO_ADD_ROBUST_ITEM_NAME: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_RESOLVE_OPTION = 512
STRUCTURED_QUERY_SINGLE_OPTION = Int32
SQSO_SCHEMA: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_SINGLE_OPTION = 0
SQSO_LOCALE_WORD_BREAKING: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_SINGLE_OPTION = 1
SQSO_WORD_BREAKER: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_SINGLE_OPTION = 2
SQSO_NATURAL_SYNTAX: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_SINGLE_OPTION = 3
SQSO_AUTOMATIC_WILDCARD: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_SINGLE_OPTION = 4
SQSO_TRACE_LEVEL: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_SINGLE_OPTION = 5
SQSO_LANGUAGE_KEYWORDS: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_SINGLE_OPTION = 6
SQSO_SYNTAX: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_SINGLE_OPTION = 7
SQSO_TIME_ZONE: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_SINGLE_OPTION = 8
SQSO_IMPLICIT_CONNECTOR: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_SINGLE_OPTION = 9
SQSO_CONNECTOR_CASE: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_SINGLE_OPTION = 10
STRUCTURED_QUERY_SYNTAX = Int32
SQS_NO_SYNTAX: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_SYNTAX = 0
SQS_ADVANCED_QUERY_SYNTAX: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_SYNTAX = 1
SQS_NATURAL_QUERY_SYNTAX: win32more.Windows.Win32.System.Search.STRUCTURED_QUERY_SYNTAX = 2
class SUBSCRIPTIONINFO(Structure):
    cbSize: UInt32
    fUpdateFlags: UInt32
    schedule: win32more.Windows.Win32.System.Search.SUBSCRIPTIONSCHEDULE
    customGroupCookie: Guid
    pTrigger: VoidPtr
    dwRecurseLevels: UInt32
    fWebcrawlerFlags: UInt32
    bMailNotification: win32more.Windows.Win32.Foundation.BOOL
    bGleam: win32more.Windows.Win32.Foundation.BOOL
    bChangesOnly: win32more.Windows.Win32.Foundation.BOOL
    bNeedPassword: win32more.Windows.Win32.Foundation.BOOL
    fChannelFlags: UInt32
    bstrUserName: win32more.Windows.Win32.Foundation.BSTR
    bstrPassword: win32more.Windows.Win32.Foundation.BSTR
    bstrFriendlyName: win32more.Windows.Win32.Foundation.BSTR
    dwMaxSizeKB: UInt32
    subType: win32more.Windows.Win32.System.Search.SUBSCRIPTIONTYPE
    fTaskFlags: UInt32
    dwReserved: UInt32
SUBSCRIPTIONINFOFLAGS = Int32
SUBSINFO_SCHEDULE: win32more.Windows.Win32.System.Search.SUBSCRIPTIONINFOFLAGS = 1
SUBSINFO_RECURSE: win32more.Windows.Win32.System.Search.SUBSCRIPTIONINFOFLAGS = 2
SUBSINFO_WEBCRAWL: win32more.Windows.Win32.System.Search.SUBSCRIPTIONINFOFLAGS = 4
SUBSINFO_MAILNOT: win32more.Windows.Win32.System.Search.SUBSCRIPTIONINFOFLAGS = 8
SUBSINFO_MAXSIZEKB: win32more.Windows.Win32.System.Search.SUBSCRIPTIONINFOFLAGS = 16
SUBSINFO_USER: win32more.Windows.Win32.System.Search.SUBSCRIPTIONINFOFLAGS = 32
SUBSINFO_PASSWORD: win32more.Windows.Win32.System.Search.SUBSCRIPTIONINFOFLAGS = 64
SUBSINFO_TASKFLAGS: win32more.Windows.Win32.System.Search.SUBSCRIPTIONINFOFLAGS = 256
SUBSINFO_GLEAM: win32more.Windows.Win32.System.Search.SUBSCRIPTIONINFOFLAGS = 512
SUBSINFO_CHANGESONLY: win32more.Windows.Win32.System.Search.SUBSCRIPTIONINFOFLAGS = 1024
SUBSINFO_CHANNELFLAGS: win32more.Windows.Win32.System.Search.SUBSCRIPTIONINFOFLAGS = 2048
SUBSINFO_FRIENDLYNAME: win32more.Windows.Win32.System.Search.SUBSCRIPTIONINFOFLAGS = 8192
SUBSINFO_NEEDPASSWORD: win32more.Windows.Win32.System.Search.SUBSCRIPTIONINFOFLAGS = 16384
SUBSINFO_TYPE: win32more.Windows.Win32.System.Search.SUBSCRIPTIONINFOFLAGS = 32768
class SUBSCRIPTIONITEMINFO(Structure):
    cbSize: UInt32
    dwFlags: UInt32
    dwPriority: UInt32
    ScheduleGroup: Guid
    clsidAgent: Guid
SUBSCRIPTIONSCHEDULE = Int32
SUBSSCHED_AUTO: win32more.Windows.Win32.System.Search.SUBSCRIPTIONSCHEDULE = 0
SUBSSCHED_DAILY: win32more.Windows.Win32.System.Search.SUBSCRIPTIONSCHEDULE = 1
SUBSSCHED_WEEKLY: win32more.Windows.Win32.System.Search.SUBSCRIPTIONSCHEDULE = 2
SUBSSCHED_CUSTOM: win32more.Windows.Win32.System.Search.SUBSCRIPTIONSCHEDULE = 3
SUBSSCHED_MANUAL: win32more.Windows.Win32.System.Search.SUBSCRIPTIONSCHEDULE = 4
SUBSCRIPTIONTYPE = Int32
SUBSTYPE_URL: win32more.Windows.Win32.System.Search.SUBSCRIPTIONTYPE = 0
SUBSTYPE_CHANNEL: win32more.Windows.Win32.System.Search.SUBSCRIPTIONTYPE = 1
SUBSTYPE_DESKTOPURL: win32more.Windows.Win32.System.Search.SUBSCRIPTIONTYPE = 2
SUBSTYPE_EXTERNAL: win32more.Windows.Win32.System.Search.SUBSCRIPTIONTYPE = 3
SUBSTYPE_DESKTOPCHANNEL: win32more.Windows.Win32.System.Search.SUBSCRIPTIONTYPE = 4
SubscriptionMgr = Guid('{abbe31d0-6dae-11d0-beca-00c04fd940be}')
class TEXT_SOURCE(Structure):
    pfnFillTextBuffer: win32more.Windows.Win32.System.Search.PFNFILLTEXTBUFFER
    awcBuffer: win32more.Windows.Win32.Foundation.PWSTR
    iEnd: UInt32
    iCur: UInt32
class TIMEOUT_INFO(Structure):
    dwSize: UInt32
    dwConnectTimeout: UInt32
    dwDataTimeout: UInt32
class TIMESTAMP_STRUCT(Structure):
    year: Int16
    month: UInt16
    day: UInt16
    hour: UInt16
    minute: UInt16
    second: UInt16
    fraction: UInt32
class TIME_STRUCT(Structure):
    hour: UInt16
    minute: UInt16
    second: UInt16
class VECTORRESTRICTION(Structure):
    Node: win32more.Windows.Win32.System.Search.NODERESTRICTION
    RankMethod: UInt32
WEBCRAWL_RECURSEFLAGS = Int32
WEBCRAWL_DONT_MAKE_STICKY: win32more.Windows.Win32.System.Search.WEBCRAWL_RECURSEFLAGS = 1
WEBCRAWL_GET_IMAGES: win32more.Windows.Win32.System.Search.WEBCRAWL_RECURSEFLAGS = 2
WEBCRAWL_GET_VIDEOS: win32more.Windows.Win32.System.Search.WEBCRAWL_RECURSEFLAGS = 4
WEBCRAWL_GET_BGSOUNDS: win32more.Windows.Win32.System.Search.WEBCRAWL_RECURSEFLAGS = 8
WEBCRAWL_GET_CONTROLS: win32more.Windows.Win32.System.Search.WEBCRAWL_RECURSEFLAGS = 16
WEBCRAWL_LINKS_ELSEWHERE: win32more.Windows.Win32.System.Search.WEBCRAWL_RECURSEFLAGS = 32
WEBCRAWL_IGNORE_ROBOTSTXT: win32more.Windows.Win32.System.Search.WEBCRAWL_RECURSEFLAGS = 128
WEBCRAWL_ONLY_LINKS_TO_HTML: win32more.Windows.Win32.System.Search.WEBCRAWL_RECURSEFLAGS = 256


make_ready(__name__)
