from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Data.Xml.MsXml
import win32more.Windows.Win32.Devices.Communication
import win32more.Windows.Win32.Devices.Display
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Dxgi
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.Graphics.Imaging
import win32more.Windows.Win32.Graphics.Printing
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.Storage.Xps
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Ole
import win32more.Windows.Win32.System.Power
import win32more.Windows.Win32.System.Registry
import win32more.Windows.Win32.System.Variant
import win32more.Windows.Win32.UI.WindowsAndMessaging
class ADDJOB_INFO_1A(Structure):
    Path: win32more.Windows.Win32.Foundation.PSTR
    JobId: UInt32
class ADDJOB_INFO_1W(Structure):
    Path: win32more.Windows.Win32.Foundation.PWSTR
    JobId: UInt32
ADDJOB_INFO_1 = UnicodeAlias('ADDJOB_INFO_1W')
class ATTRIBUTE_INFO_1(Structure):
    dwJobNumberOfPagesPerSide: UInt32
    dwDrvNumberOfPagesPerSide: UInt32
    dwNupBorderFlags: UInt32
    dwJobPageOrderFlags: UInt32
    dwDrvPageOrderFlags: UInt32
    dwJobNumberOfCopies: UInt32
    dwDrvNumberOfCopies: UInt32
class ATTRIBUTE_INFO_2(Structure):
    dwJobNumberOfPagesPerSide: UInt32
    dwDrvNumberOfPagesPerSide: UInt32
    dwNupBorderFlags: UInt32
    dwJobPageOrderFlags: UInt32
    dwDrvPageOrderFlags: UInt32
    dwJobNumberOfCopies: UInt32
    dwDrvNumberOfCopies: UInt32
    dwColorOptimization: UInt32
class ATTRIBUTE_INFO_3(Structure):
    dwJobNumberOfPagesPerSide: UInt32
    dwDrvNumberOfPagesPerSide: UInt32
    dwNupBorderFlags: UInt32
    dwJobPageOrderFlags: UInt32
    dwDrvPageOrderFlags: UInt32
    dwJobNumberOfCopies: UInt32
    dwDrvNumberOfCopies: UInt32
    dwColorOptimization: UInt32
    dmPrintQuality: Int16
    dmYResolution: Int16
class ATTRIBUTE_INFO_4(Structure):
    dwJobNumberOfPagesPerSide: UInt32
    dwDrvNumberOfPagesPerSide: UInt32
    dwNupBorderFlags: UInt32
    dwJobPageOrderFlags: UInt32
    dwDrvPageOrderFlags: UInt32
    dwJobNumberOfCopies: UInt32
    dwDrvNumberOfCopies: UInt32
    dwColorOptimization: UInt32
    dmPrintQuality: Int16
    dmYResolution: Int16
    dwDuplexFlags: UInt32
    dwNupDirection: UInt32
    dwBookletFlags: UInt32
    dwScalingPercentX: UInt32
    dwScalingPercentY: UInt32
USB_PRINTER_INTERFACE_CLASSIC: UInt32 = 1
USB_PRINTER_INTERFACE_IPP: UInt32 = 2
USB_PRINTER_INTERFACE_DUAL: UInt32 = 3
USBPRINT_IOCTL_INDEX: UInt32 = 0
IOCTL_USBPRINT_GET_LPT_STATUS: UInt32 = 2228272
IOCTL_USBPRINT_GET_1284_ID: UInt32 = 2228276
IOCTL_USBPRINT_VENDOR_SET_COMMAND: UInt32 = 2228280
IOCTL_USBPRINT_VENDOR_GET_COMMAND: UInt32 = 2228284
IOCTL_USBPRINT_SOFT_RESET: UInt32 = 2228288
IOCTL_USBPRINT_GET_PROTOCOL: UInt32 = 2228292
IOCTL_USBPRINT_SET_PROTOCOL: UInt32 = 2228296
IOCTL_USBPRINT_GET_INTERFACE_TYPE: UInt32 = 2228300
IOCTL_USBPRINT_SET_PORT_NUMBER: UInt32 = 2228304
IOCTL_USBPRINT_ADD_MSIPP_COMPAT_ID: UInt32 = 2228308
IOCTL_USBPRINT_SET_DEVICE_ID: UInt32 = 2228312
IOCTL_USBPRINT_ADD_CHILD_DEVICE: UInt32 = 2228316
IOCTL_USBPRINT_CYCLE_PORT: UInt32 = 2228320
TVOT_2STATES: UInt32 = 0
TVOT_3STATES: UInt32 = 1
TVOT_UDARROW: UInt32 = 2
TVOT_TRACKBAR: UInt32 = 3
TVOT_SCROLLBAR: UInt32 = 4
TVOT_LISTBOX: UInt32 = 5
TVOT_COMBOBOX: UInt32 = 6
TVOT_EDITBOX: UInt32 = 7
TVOT_PUSHBUTTON: UInt32 = 8
TVOT_CHKBOX: UInt32 = 9
TVOT_NSTATES_EX: UInt32 = 10
CHKBOXS_FALSE_TRUE: UInt32 = 0
CHKBOXS_NO_YES: UInt32 = 1
CHKBOXS_OFF_ON: UInt32 = 2
CHKBOXS_FALSE_PDATA: UInt32 = 3
CHKBOXS_NO_PDATA: UInt32 = 4
CHKBOXS_OFF_PDATA: UInt32 = 5
CHKBOXS_NONE_PDATA: UInt32 = 6
PUSHBUTTON_TYPE_DLGPROC: UInt32 = 0
PUSHBUTTON_TYPE_CALLBACK: UInt32 = 1
PUSHBUTTON_TYPE_HTCLRADJ: UInt32 = 2
PUSHBUTTON_TYPE_HTSETUP: UInt32 = 3
MAX_RES_STR_CHARS: UInt32 = 160
OPTPF_HIDE: UInt32 = 1
OPTPF_DISABLED: UInt32 = 2
OPTPF_ICONID_AS_HICON: UInt32 = 4
OPTPF_OVERLAY_WARNING_ICON: UInt32 = 8
OPTPF_OVERLAY_STOP_ICON: UInt32 = 16
OPTPF_OVERLAY_NO_ICON: UInt32 = 32
OPTPF_USE_HDLGTEMPLATE: UInt32 = 64
OPTPF_MASK: UInt32 = 127
OPTCF_HIDE: UInt32 = 1
OPTCF_MASK: UInt32 = 1
OPTTF_TYPE_DISABLED: UInt32 = 1
OPTTF_NOSPACE_BEFORE_POSTFIX: UInt32 = 2
OPTTF_MASK: UInt32 = 3
OTS_LBCB_SORT: UInt32 = 1
OTS_LBCB_PROPPAGE_LBUSECB: UInt32 = 2
OTS_LBCB_PROPPAGE_CBUSELB: UInt32 = 4
OTS_LBCB_INCL_ITEM_NONE: UInt32 = 8
OTS_LBCB_NO_ICON16_IN_ITEM: UInt32 = 16
OTS_PUSH_INCL_SETUP_TITLE: UInt32 = 32
OTS_PUSH_NO_DOT_DOT_DOT: UInt32 = 64
OTS_PUSH_ENABLE_ALWAYS: UInt32 = 128
OTS_MASK: UInt32 = 255
EPF_PUSH_TYPE_DLGPROC: UInt32 = 1
EPF_INCL_SETUP_TITLE: UInt32 = 2
EPF_NO_DOT_DOT_DOT: UInt32 = 4
EPF_ICONID_AS_HICON: UInt32 = 8
EPF_OVERLAY_WARNING_ICON: UInt32 = 16
EPF_OVERLAY_STOP_ICON: UInt32 = 32
EPF_OVERLAY_NO_ICON: UInt32 = 64
EPF_USE_HDLGTEMPLATE: UInt32 = 128
EPF_MASK: UInt32 = 255
ECBF_CHECKNAME_AT_FRONT: UInt32 = 1
ECBF_CHECKNAME_ONLY_ENABLED: UInt32 = 2
ECBF_ICONID_AS_HICON: UInt32 = 4
ECBF_OVERLAY_WARNING_ICON: UInt32 = 8
ECBF_OVERLAY_ECBICON_IF_CHECKED: UInt32 = 16
ECBF_OVERLAY_STOP_ICON: UInt32 = 32
ECBF_OVERLAY_NO_ICON: UInt32 = 64
ECBF_CHECKNAME_ONLY: UInt32 = 128
ECBF_MASK: UInt32 = 255
OPTIF_COLLAPSE: Int32 = 1
OPTIF_HIDE: Int32 = 2
OPTIF_CALLBACK: Int32 = 4
OPTIF_CHANGED: Int32 = 8
OPTIF_CHANGEONCE: Int32 = 16
OPTIF_DISABLED: Int32 = 32
OPTIF_ECB_CHECKED: Int32 = 64
OPTIF_EXT_HIDE: Int32 = 128
OPTIF_EXT_DISABLED: Int32 = 256
OPTIF_SEL_AS_HICON: Int32 = 512
OPTIF_EXT_IS_EXTPUSH: Int32 = 1024
OPTIF_NO_GROUPBOX_NAME: Int32 = 2048
OPTIF_OVERLAY_WARNING_ICON: Int32 = 4096
OPTIF_OVERLAY_STOP_ICON: Int32 = 8192
OPTIF_OVERLAY_NO_ICON: Int32 = 16384
OPTIF_INITIAL_TVITEM: Int32 = 32768
OPTIF_HAS_POIEXT: Int32 = 65536
OPTIF_MASK: Int32 = 131071
DMPUB_NONE: UInt32 = 0
DMPUB_FIRST: UInt32 = 1
DMPUB_ORIENTATION: UInt32 = 1
DMPUB_SCALE: UInt32 = 2
DMPUB_COPIES_COLLATE: UInt32 = 3
DMPUB_DEFSOURCE: UInt32 = 4
DMPUB_PRINTQUALITY: UInt32 = 5
DMPUB_COLOR: UInt32 = 6
DMPUB_DUPLEX: UInt32 = 7
DMPUB_TTOPTION: UInt32 = 8
DMPUB_FORMNAME: UInt32 = 9
DMPUB_ICMMETHOD: UInt32 = 10
DMPUB_ICMINTENT: UInt32 = 11
DMPUB_MEDIATYPE: UInt32 = 12
DMPUB_DITHERTYPE: UInt32 = 13
DMPUB_OUTPUTBIN: UInt32 = 14
DMPUB_QUALITY: UInt32 = 15
DMPUB_NUP: UInt32 = 16
DMPUB_PAGEORDER: UInt32 = 17
DMPUB_NUP_DIRECTION: UInt32 = 18
DMPUB_MANUAL_DUPLEX: UInt32 = 19
DMPUB_STAPLE: UInt32 = 20
DMPUB_BOOKLET_EDGE: UInt32 = 21
DMPUB_LAST: UInt32 = 21
DMPUB_OEM_PAPER_ITEM: UInt32 = 97
DMPUB_OEM_GRAPHIC_ITEM: UInt32 = 98
DMPUB_OEM_ROOT_ITEM: UInt32 = 99
DMPUB_USER: UInt32 = 100
OIEXTF_ANSI_STRING: UInt32 = 1
CPSUICB_REASON_SEL_CHANGED: UInt32 = 0
CPSUICB_REASON_PUSHBUTTON: UInt32 = 1
CPSUICB_REASON_ECB_CHANGED: UInt32 = 2
CPSUICB_REASON_DLGPROC: UInt32 = 3
CPSUICB_REASON_UNDO_CHANGES: UInt32 = 4
CPSUICB_REASON_EXTPUSH: UInt32 = 5
CPSUICB_REASON_APPLYNOW: UInt32 = 6
CPSUICB_REASON_OPTITEM_SETFOCUS: UInt32 = 7
CPSUICB_REASON_ITEMS_REVERTED: UInt32 = 8
CPSUICB_REASON_ABOUT: UInt32 = 9
CPSUICB_REASON_SETACTIVE: UInt32 = 10
CPSUICB_REASON_KILLACTIVE: UInt32 = 11
CPSUICB_ACTION_NONE: UInt32 = 0
CPSUICB_ACTION_OPTIF_CHANGED: UInt32 = 1
CPSUICB_ACTION_REINIT_ITEMS: UInt32 = 2
CPSUICB_ACTION_NO_APPLY_EXIT: UInt32 = 3
CPSUICB_ACTION_ITEMS_APPLIED: UInt32 = 4
DP_STD_TREEVIEWPAGE: UInt32 = 65535
DP_STD_DOCPROPPAGE2: UInt32 = 65534
DP_STD_DOCPROPPAGE1: UInt32 = 65533
DP_STD_RESERVED_START: UInt32 = 65520
MAX_DLGPAGE_COUNT: UInt32 = 64
DPF_ICONID_AS_HICON: UInt32 = 1
DPF_USE_HDLGTEMPLATE: UInt32 = 2
CPSUIF_UPDATE_PERMISSION: UInt32 = 1
CPSUIF_ICONID_AS_HICON: UInt32 = 2
CPSUIF_ABOUT_CALLBACK: UInt32 = 4
CPSFUNC_ADD_HPROPSHEETPAGE: UInt32 = 0
CPSFUNC_ADD_PROPSHEETPAGEW: UInt32 = 1
CPSFUNC_ADD_PCOMPROPSHEETUIA: UInt32 = 2
CPSFUNC_ADD_PCOMPROPSHEETUIW: UInt32 = 3
CPSFUNC_ADD_PFNPROPSHEETUIA: UInt32 = 4
CPSFUNC_ADD_PFNPROPSHEETUIW: UInt32 = 5
CPSFUNC_DELETE_HCOMPROPSHEET: UInt32 = 6
CPSFUNC_SET_HSTARTPAGE: UInt32 = 7
CPSFUNC_GET_PAGECOUNT: UInt32 = 8
CPSFUNC_SET_RESULT: UInt32 = 9
CPSFUNC_GET_HPSUIPAGES: UInt32 = 10
CPSFUNC_LOAD_CPSUI_STRINGA: UInt32 = 11
CPSFUNC_LOAD_CPSUI_STRINGW: UInt32 = 12
CPSFUNC_LOAD_CPSUI_ICON: UInt32 = 13
CPSFUNC_GET_PFNPROPSHEETUI_ICON: UInt32 = 14
CPSFUNC_ADD_PROPSHEETPAGEA: UInt32 = 15
CPSFUNC_INSERT_PSUIPAGEA: UInt32 = 16
CPSFUNC_INSERT_PSUIPAGEW: UInt32 = 17
CPSFUNC_SET_PSUIPAGE_TITLEA: UInt32 = 18
CPSFUNC_SET_PSUIPAGE_TITLEW: UInt32 = 19
CPSFUNC_SET_PSUIPAGE_ICON: UInt32 = 20
CPSFUNC_SET_DATABLOCK: UInt32 = 21
CPSFUNC_QUERY_DATABLOCK: UInt32 = 22
CPSFUNC_SET_DMPUB_HIDEBITS: UInt32 = 23
CPSFUNC_IGNORE_CPSUI_PSN_APPLY: UInt32 = 24
CPSFUNC_DO_APPLY_CPSUI: UInt32 = 25
CPSFUNC_SET_FUSION_CONTEXT: UInt32 = 26
MAX_CPSFUNC_INDEX: UInt32 = 26
CPSFUNC_ADD_PCOMPROPSHEETUI: UInt32 = 3
CPSFUNC_ADD_PFNPROPSHEETUI: UInt32 = 5
CPSFUNC_LOAD_CPSUI_STRING: UInt32 = 12
CPSFUNC_ADD_PROPSHEETPAGE: UInt32 = 1
CPSFUNC_INSERT_PSUIPAGE: UInt32 = 17
CPSFUNC_SET_PSUIPAGE_TITLE: UInt32 = 19
SR_OWNER: UInt32 = 0
SR_OWNER_PARENT: UInt32 = 1
PSUIPAGEINSERT_GROUP_PARENT: UInt32 = 0
PSUIPAGEINSERT_PCOMPROPSHEETUI: UInt32 = 1
PSUIPAGEINSERT_PFNPROPSHEETUI: UInt32 = 2
PSUIPAGEINSERT_PROPSHEETPAGE: UInt32 = 3
PSUIPAGEINSERT_HPROPSHEETPAGE: UInt32 = 4
PSUIPAGEINSERT_DLL: UInt32 = 5
MAX_PSUIPAGEINSERT_INDEX: UInt32 = 5
INSPSUIPAGE_MODE_BEFORE: UInt32 = 0
INSPSUIPAGE_MODE_AFTER: UInt32 = 1
INSPSUIPAGE_MODE_FIRST_CHILD: UInt32 = 2
INSPSUIPAGE_MODE_LAST_CHILD: UInt32 = 3
INSPSUIPAGE_MODE_INDEX: UInt32 = 4
SSP_TVPAGE: UInt32 = 10000
SSP_STDPAGE1: UInt32 = 10001
SSP_STDPAGE2: UInt32 = 10002
APPLYCPSUI_NO_NEWDEF: UInt32 = 1
APPLYCPSUI_OK_CANCEL_BUTTON: UInt32 = 2
PROPSHEETUI_REASON_INIT: UInt32 = 0
PROPSHEETUI_REASON_GET_INFO_HEADER: UInt32 = 1
PROPSHEETUI_REASON_DESTROY: UInt32 = 2
PROPSHEETUI_REASON_SET_RESULT: UInt32 = 3
PROPSHEETUI_REASON_GET_ICON: UInt32 = 4
PROPSHEETUI_REASON_BEFORE_INIT: UInt32 = 5
MAX_PROPSHEETUI_REASON_INDEX: UInt32 = 5
PROPSHEETUI_INFO_VERSION: UInt32 = 256
PSUIINFO_UNICODE: UInt32 = 1
PSUIHDRF_OBSOLETE: UInt32 = 1
PSUIHDRF_NOAPPLYNOW: UInt32 = 2
PSUIHDRF_PROPTITLE: UInt32 = 4
PSUIHDRF_USEHICON: UInt32 = 8
PSUIHDRF_DEFTITLE: UInt32 = 16
PSUIHDRF_EXACT_PTITLE: UInt32 = 32
CPSUI_CANCEL: UInt32 = 0
CPSUI_OK: UInt32 = 1
CPSUI_RESTARTWINDOWS: UInt32 = 2
CPSUI_REBOOTSYSTEM: UInt32 = 3
ERR_CPSUI_GETLASTERROR: Int32 = -1
ERR_CPSUI_ALLOCMEM_FAILED: Int32 = -2
ERR_CPSUI_INVALID_PDATA: Int32 = -3
ERR_CPSUI_INVALID_LPARAM: Int32 = -4
ERR_CPSUI_NULL_HINST: Int32 = -5
ERR_CPSUI_NULL_CALLERNAME: Int32 = -6
ERR_CPSUI_NULL_OPTITEMNAME: Int32 = -7
ERR_CPSUI_NO_PROPSHEETPAGE: Int32 = -8
ERR_CPSUI_TOO_MANY_PROPSHEETPAGES: Int32 = -9
ERR_CPSUI_CREATEPROPPAGE_FAILED: Int32 = -10
ERR_CPSUI_MORE_THAN_ONE_TVPAGE: Int32 = -11
ERR_CPSUI_MORE_THAN_ONE_STDPAGE: Int32 = -12
ERR_CPSUI_INVALID_PDLGPAGE: Int32 = -13
ERR_CPSUI_INVALID_DLGPAGE_CBSIZE: Int32 = -14
ERR_CPSUI_TOO_MANY_DLGPAGES: Int32 = -15
ERR_CPSUI_INVALID_DLGPAGEIDX: Int32 = -16
ERR_CPSUI_SUBITEM_DIFF_DLGPAGEIDX: Int32 = -17
ERR_CPSUI_NULL_POPTITEM: Int32 = -18
ERR_CPSUI_INVALID_OPTITEM_CBSIZE: Int32 = -19
ERR_CPSUI_INVALID_OPTTYPE_CBSIZE: Int32 = -20
ERR_CPSUI_INVALID_OPTTYPE_COUNT: Int32 = -21
ERR_CPSUI_NULL_POPTPARAM: Int32 = -22
ERR_CPSUI_INVALID_OPTPARAM_CBSIZE: Int32 = -23
ERR_CPSUI_INVALID_EDITBOX_PSEL: Int32 = -24
ERR_CPSUI_INVALID_EDITBOX_BUF_SIZE: Int32 = -25
ERR_CPSUI_INVALID_ECB_CBSIZE: Int32 = -26
ERR_CPSUI_NULL_ECB_PTITLE: Int32 = -27
ERR_CPSUI_NULL_ECB_PCHECKEDNAME: Int32 = -28
ERR_CPSUI_INVALID_DMPUBID: Int32 = -29
ERR_CPSUI_INVALID_DMPUB_TVOT: Int32 = -30
ERR_CPSUI_CREATE_TRACKBAR_FAILED: Int32 = -31
ERR_CPSUI_CREATE_UDARROW_FAILED: Int32 = -32
ERR_CPSUI_CREATE_IMAGELIST_FAILED: Int32 = -33
ERR_CPSUI_INVALID_TVOT_TYPE: Int32 = -34
ERR_CPSUI_INVALID_LBCB_TYPE: Int32 = -35
ERR_CPSUI_SUBITEM_DIFF_OPTIF_HIDE: Int32 = -36
ERR_CPSUI_INVALID_PUSHBUTTON_TYPE: Int32 = -38
ERR_CPSUI_INVALID_EXTPUSH_CBSIZE: Int32 = -39
ERR_CPSUI_NULL_EXTPUSH_DLGPROC: Int32 = -40
ERR_CPSUI_NO_EXTPUSH_DLGTEMPLATEID: Int32 = -41
ERR_CPSUI_NULL_EXTPUSH_CALLBACK: Int32 = -42
ERR_CPSUI_DMCOPIES_USE_EXTPUSH: Int32 = -43
ERR_CPSUI_ZERO_OPTITEM: Int32 = -44
ERR_CPSUI_FUNCTION_NOT_IMPLEMENTED: Int32 = -9999
ERR_CPSUI_INTERNAL_ERROR: Int32 = -10000
IDI_CPSUI_ICONID_FIRST: UInt32 = 64000
IDI_CPSUI_EMPTY: UInt32 = 64000
IDI_CPSUI_SEL_NONE: UInt32 = 64001
IDI_CPSUI_WARNING: UInt32 = 64002
IDI_CPSUI_NO: UInt32 = 64003
IDI_CPSUI_YES: UInt32 = 64004
IDI_CPSUI_FALSE: UInt32 = 64005
IDI_CPSUI_TRUE: UInt32 = 64006
IDI_CPSUI_OFF: UInt32 = 64007
IDI_CPSUI_ON: UInt32 = 64008
IDI_CPSUI_PAPER_OUTPUT: UInt32 = 64009
IDI_CPSUI_ENVELOPE: UInt32 = 64010
IDI_CPSUI_MEM: UInt32 = 64011
IDI_CPSUI_FONTCARTHDR: UInt32 = 64012
IDI_CPSUI_FONTCART: UInt32 = 64013
IDI_CPSUI_STAPLER_ON: UInt32 = 64014
IDI_CPSUI_STAPLER_OFF: UInt32 = 64015
IDI_CPSUI_HT_HOST: UInt32 = 64016
IDI_CPSUI_HT_DEVICE: UInt32 = 64017
IDI_CPSUI_TT_PRINTASGRAPHIC: UInt32 = 64018
IDI_CPSUI_TT_DOWNLOADSOFT: UInt32 = 64019
IDI_CPSUI_TT_DOWNLOADVECT: UInt32 = 64020
IDI_CPSUI_TT_SUBDEV: UInt32 = 64021
IDI_CPSUI_PORTRAIT: UInt32 = 64022
IDI_CPSUI_LANDSCAPE: UInt32 = 64023
IDI_CPSUI_ROT_LAND: UInt32 = 64024
IDI_CPSUI_AUTOSEL: UInt32 = 64025
IDI_CPSUI_PAPER_TRAY: UInt32 = 64026
IDI_CPSUI_PAPER_TRAY2: UInt32 = 64027
IDI_CPSUI_PAPER_TRAY3: UInt32 = 64028
IDI_CPSUI_TRANSPARENT: UInt32 = 64029
IDI_CPSUI_COLLATE: UInt32 = 64030
IDI_CPSUI_DUPLEX_NONE: UInt32 = 64031
IDI_CPSUI_DUPLEX_HORZ: UInt32 = 64032
IDI_CPSUI_DUPLEX_VERT: UInt32 = 64033
IDI_CPSUI_RES_DRAFT: UInt32 = 64034
IDI_CPSUI_RES_LOW: UInt32 = 64035
IDI_CPSUI_RES_MEDIUM: UInt32 = 64036
IDI_CPSUI_RES_HIGH: UInt32 = 64037
IDI_CPSUI_RES_PRESENTATION: UInt32 = 64038
IDI_CPSUI_MONO: UInt32 = 64039
IDI_CPSUI_COLOR: UInt32 = 64040
IDI_CPSUI_DITHER_NONE: UInt32 = 64041
IDI_CPSUI_DITHER_COARSE: UInt32 = 64042
IDI_CPSUI_DITHER_FINE: UInt32 = 64043
IDI_CPSUI_DITHER_LINEART: UInt32 = 64044
IDI_CPSUI_SCALING: UInt32 = 64045
IDI_CPSUI_COPY: UInt32 = 64046
IDI_CPSUI_HTCLRADJ: UInt32 = 64047
IDI_CPSUI_HALFTONE_SETUP: UInt32 = 64048
IDI_CPSUI_WATERMARK: UInt32 = 64049
IDI_CPSUI_ERROR: UInt32 = 64050
IDI_CPSUI_ICM_OPTION: UInt32 = 64051
IDI_CPSUI_ICM_METHOD: UInt32 = 64052
IDI_CPSUI_ICM_INTENT: UInt32 = 64053
IDI_CPSUI_STD_FORM: UInt32 = 64054
IDI_CPSUI_OUTBIN: UInt32 = 64055
IDI_CPSUI_OUTPUT: UInt32 = 64056
IDI_CPSUI_GRAPHIC: UInt32 = 64057
IDI_CPSUI_ADVANCE: UInt32 = 64058
IDI_CPSUI_DOCUMENT: UInt32 = 64059
IDI_CPSUI_DEVICE: UInt32 = 64060
IDI_CPSUI_DEVICE2: UInt32 = 64061
IDI_CPSUI_PRINTER: UInt32 = 64062
IDI_CPSUI_PRINTER2: UInt32 = 64063
IDI_CPSUI_PRINTER3: UInt32 = 64064
IDI_CPSUI_PRINTER4: UInt32 = 64065
IDI_CPSUI_OPTION: UInt32 = 64066
IDI_CPSUI_OPTION2: UInt32 = 64067
IDI_CPSUI_STOP: UInt32 = 64068
IDI_CPSUI_NOTINSTALLED: UInt32 = 64069
IDI_CPSUI_WARNING_OVERLAY: UInt32 = 64070
IDI_CPSUI_STOP_WARNING_OVERLAY: UInt32 = 64071
IDI_CPSUI_GENERIC_OPTION: UInt32 = 64072
IDI_CPSUI_GENERIC_ITEM: UInt32 = 64073
IDI_CPSUI_RUN_DIALOG: UInt32 = 64074
IDI_CPSUI_QUESTION: UInt32 = 64075
IDI_CPSUI_FORMTRAYASSIGN: UInt32 = 64076
IDI_CPSUI_PRINTER_FOLDER: UInt32 = 64077
IDI_CPSUI_INSTALLABLE_OPTION: UInt32 = 64078
IDI_CPSUI_PRINTER_FEATURE: UInt32 = 64079
IDI_CPSUI_DEVICE_FEATURE: UInt32 = 64080
IDI_CPSUI_FONTSUB: UInt32 = 64081
IDI_CPSUI_POSTSCRIPT: UInt32 = 64082
IDI_CPSUI_TELEPHONE: UInt32 = 64083
IDI_CPSUI_DUPLEX_NONE_L: UInt32 = 64084
IDI_CPSUI_DUPLEX_HORZ_L: UInt32 = 64085
IDI_CPSUI_DUPLEX_VERT_L: UInt32 = 64086
IDI_CPSUI_LF_PEN_PLOTTER: UInt32 = 64087
IDI_CPSUI_SF_PEN_PLOTTER: UInt32 = 64088
IDI_CPSUI_LF_RASTER_PLOTTER: UInt32 = 64089
IDI_CPSUI_SF_RASTER_PLOTTER: UInt32 = 64090
IDI_CPSUI_ROLL_PAPER: UInt32 = 64091
IDI_CPSUI_PEN_CARROUSEL: UInt32 = 64092
IDI_CPSUI_PLOTTER_PEN: UInt32 = 64093
IDI_CPSUI_MANUAL_FEED: UInt32 = 64094
IDI_CPSUI_FAX: UInt32 = 64095
IDI_CPSUI_PAGE_PROTECT: UInt32 = 64096
IDI_CPSUI_ENVELOPE_FEED: UInt32 = 64097
IDI_CPSUI_FONTCART_SLOT: UInt32 = 64098
IDI_CPSUI_LAYOUT_BMP_PORTRAIT: UInt32 = 64099
IDI_CPSUI_LAYOUT_BMP_ARROWL: UInt32 = 64100
IDI_CPSUI_LAYOUT_BMP_ARROWS: UInt32 = 64101
IDI_CPSUI_LAYOUT_BMP_BOOKLETL: UInt32 = 64102
IDI_CPSUI_LAYOUT_BMP_BOOKLETP: UInt32 = 64103
IDI_CPSUI_LAYOUT_BMP_ARROWLR: UInt32 = 64104
IDI_CPSUI_LAYOUT_BMP_ROT_PORT: UInt32 = 64105
IDI_CPSUI_LAYOUT_BMP_BOOKLETL_NB: UInt32 = 64106
IDI_CPSUI_LAYOUT_BMP_BOOKLETP_NB: UInt32 = 64107
IDI_CPSUI_ROT_PORT: UInt32 = 64110
IDI_CPSUI_NUP_BORDER: UInt32 = 64111
IDI_CPSUI_ICONID_LAST: UInt32 = 64111
IDS_CPSUI_STRID_FIRST: UInt32 = 64700
IDS_CPSUI_SETUP: UInt32 = 64700
IDS_CPSUI_MORE: UInt32 = 64701
IDS_CPSUI_CHANGE: UInt32 = 64702
IDS_CPSUI_OPTION: UInt32 = 64703
IDS_CPSUI_OF: UInt32 = 64704
IDS_CPSUI_RANGE_FROM: UInt32 = 64705
IDS_CPSUI_TO: UInt32 = 64706
IDS_CPSUI_COLON_SEP: UInt32 = 64707
IDS_CPSUI_LEFT_ANGLE: UInt32 = 64708
IDS_CPSUI_RIGHT_ANGLE: UInt32 = 64709
IDS_CPSUI_SLASH_SEP: UInt32 = 64710
IDS_CPSUI_PERCENT: UInt32 = 64711
IDS_CPSUI_LBCB_NOSEL: UInt32 = 64712
IDS_CPSUI_PROPERTIES: UInt32 = 64713
IDS_CPSUI_DEFAULTDOCUMENT: UInt32 = 64714
IDS_CPSUI_DOCUMENT: UInt32 = 64715
IDS_CPSUI_ADVANCEDOCUMENT: UInt32 = 64716
IDS_CPSUI_PRINTER: UInt32 = 64717
IDS_CPSUI_AUTOSELECT: UInt32 = 64718
IDS_CPSUI_PAPER_OUTPUT: UInt32 = 64719
IDS_CPSUI_GRAPHIC: UInt32 = 64720
IDS_CPSUI_OPTIONS: UInt32 = 64721
IDS_CPSUI_ADVANCED: UInt32 = 64722
IDS_CPSUI_STDDOCPROPTAB: UInt32 = 64723
IDS_CPSUI_STDDOCPROPTVTAB: UInt32 = 64724
IDS_CPSUI_DEVICEOPTIONS: UInt32 = 64725
IDS_CPSUI_FALSE: UInt32 = 64726
IDS_CPSUI_TRUE: UInt32 = 64727
IDS_CPSUI_NO: UInt32 = 64728
IDS_CPSUI_YES: UInt32 = 64729
IDS_CPSUI_OFF: UInt32 = 64730
IDS_CPSUI_ON: UInt32 = 64731
IDS_CPSUI_DEFAULT: UInt32 = 64732
IDS_CPSUI_ERROR: UInt32 = 64733
IDS_CPSUI_NONE: UInt32 = 64734
IDS_CPSUI_NOT: UInt32 = 64735
IDS_CPSUI_EXIST: UInt32 = 64736
IDS_CPSUI_NOTINSTALLED: UInt32 = 64737
IDS_CPSUI_ORIENTATION: UInt32 = 64738
IDS_CPSUI_SCALING: UInt32 = 64739
IDS_CPSUI_NUM_OF_COPIES: UInt32 = 64740
IDS_CPSUI_SOURCE: UInt32 = 64741
IDS_CPSUI_PRINTQUALITY: UInt32 = 64742
IDS_CPSUI_RESOLUTION: UInt32 = 64743
IDS_CPSUI_COLOR_APPERANCE: UInt32 = 64744
IDS_CPSUI_DUPLEX: UInt32 = 64745
IDS_CPSUI_TTOPTION: UInt32 = 64746
IDS_CPSUI_FORMNAME: UInt32 = 64747
IDS_CPSUI_ICM: UInt32 = 64748
IDS_CPSUI_ICMMETHOD: UInt32 = 64749
IDS_CPSUI_ICMINTENT: UInt32 = 64750
IDS_CPSUI_MEDIA: UInt32 = 64751
IDS_CPSUI_DITHERING: UInt32 = 64752
IDS_CPSUI_PORTRAIT: UInt32 = 64753
IDS_CPSUI_LANDSCAPE: UInt32 = 64754
IDS_CPSUI_ROT_LAND: UInt32 = 64755
IDS_CPSUI_COLLATE: UInt32 = 64756
IDS_CPSUI_COLLATED: UInt32 = 64757
IDS_CPSUI_PRINTFLDSETTING: UInt32 = 64758
IDS_CPSUI_DRAFT: UInt32 = 64759
IDS_CPSUI_LOW: UInt32 = 64760
IDS_CPSUI_MEDIUM: UInt32 = 64761
IDS_CPSUI_HIGH: UInt32 = 64762
IDS_CPSUI_PRESENTATION: UInt32 = 64763
IDS_CPSUI_COLOR: UInt32 = 64764
IDS_CPSUI_GRAYSCALE: UInt32 = 64765
IDS_CPSUI_MONOCHROME: UInt32 = 64766
IDS_CPSUI_SIMPLEX: UInt32 = 64767
IDS_CPSUI_HORIZONTAL: UInt32 = 64768
IDS_CPSUI_VERTICAL: UInt32 = 64769
IDS_CPSUI_LONG_SIDE: UInt32 = 64770
IDS_CPSUI_SHORT_SIDE: UInt32 = 64771
IDS_CPSUI_TT_PRINTASGRAPHIC: UInt32 = 64772
IDS_CPSUI_TT_DOWNLOADSOFT: UInt32 = 64773
IDS_CPSUI_TT_DOWNLOADVECT: UInt32 = 64774
IDS_CPSUI_TT_SUBDEV: UInt32 = 64775
IDS_CPSUI_ICM_BLACKWHITE: UInt32 = 64776
IDS_CPSUI_ICM_NO: UInt32 = 64777
IDS_CPSUI_ICM_YES: UInt32 = 64778
IDS_CPSUI_ICM_SATURATION: UInt32 = 64779
IDS_CPSUI_ICM_CONTRAST: UInt32 = 64780
IDS_CPSUI_ICM_COLORMETRIC: UInt32 = 64781
IDS_CPSUI_STANDARD: UInt32 = 64782
IDS_CPSUI_GLOSSY: UInt32 = 64783
IDS_CPSUI_TRANSPARENCY: UInt32 = 64784
IDS_CPSUI_REGULAR: UInt32 = 64785
IDS_CPSUI_BOND: UInt32 = 64786
IDS_CPSUI_COARSE: UInt32 = 64787
IDS_CPSUI_FINE: UInt32 = 64788
IDS_CPSUI_LINEART: UInt32 = 64789
IDS_CPSUI_ERRDIFFUSE: UInt32 = 64790
IDS_CPSUI_HALFTONE: UInt32 = 64791
IDS_CPSUI_HTCLRADJ: UInt32 = 64792
IDS_CPSUI_USE_HOST_HT: UInt32 = 64793
IDS_CPSUI_USE_DEVICE_HT: UInt32 = 64794
IDS_CPSUI_USE_PRINTER_HT: UInt32 = 64795
IDS_CPSUI_OUTBINASSIGN: UInt32 = 64796
IDS_CPSUI_WATERMARK: UInt32 = 64797
IDS_CPSUI_FORMTRAYASSIGN: UInt32 = 64798
IDS_CPSUI_UPPER_TRAY: UInt32 = 64799
IDS_CPSUI_ONLYONE: UInt32 = 64800
IDS_CPSUI_LOWER_TRAY: UInt32 = 64801
IDS_CPSUI_MIDDLE_TRAY: UInt32 = 64802
IDS_CPSUI_MANUAL_TRAY: UInt32 = 64803
IDS_CPSUI_ENVELOPE_TRAY: UInt32 = 64804
IDS_CPSUI_ENVMANUAL_TRAY: UInt32 = 64805
IDS_CPSUI_TRACTOR_TRAY: UInt32 = 64806
IDS_CPSUI_SMALLFMT_TRAY: UInt32 = 64807
IDS_CPSUI_LARGEFMT_TRAY: UInt32 = 64808
IDS_CPSUI_LARGECAP_TRAY: UInt32 = 64809
IDS_CPSUI_CASSETTE_TRAY: UInt32 = 64810
IDS_CPSUI_DEFAULT_TRAY: UInt32 = 64811
IDS_CPSUI_FORMSOURCE: UInt32 = 64812
IDS_CPSUI_MANUALFEED: UInt32 = 64813
IDS_CPSUI_PRINTERMEM_KB: UInt32 = 64814
IDS_CPSUI_PRINTERMEM_MB: UInt32 = 64815
IDS_CPSUI_PAGEPROTECT: UInt32 = 64816
IDS_CPSUI_HALFTONE_SETUP: UInt32 = 64817
IDS_CPSUI_INSTFONTCART: UInt32 = 64818
IDS_CPSUI_SLOT1: UInt32 = 64819
IDS_CPSUI_SLOT2: UInt32 = 64820
IDS_CPSUI_SLOT3: UInt32 = 64821
IDS_CPSUI_SLOT4: UInt32 = 64822
IDS_CPSUI_LEFT_SLOT: UInt32 = 64823
IDS_CPSUI_RIGHT_SLOT: UInt32 = 64824
IDS_CPSUI_STAPLER: UInt32 = 64825
IDS_CPSUI_STAPLER_ON: UInt32 = 64826
IDS_CPSUI_STAPLER_OFF: UInt32 = 64827
IDS_CPSUI_STACKER: UInt32 = 64828
IDS_CPSUI_MAILBOX: UInt32 = 64829
IDS_CPSUI_COPY: UInt32 = 64830
IDS_CPSUI_COPIES: UInt32 = 64831
IDS_CPSUI_TOTAL: UInt32 = 64832
IDS_CPSUI_MAKE: UInt32 = 64833
IDS_CPSUI_PRINT: UInt32 = 64834
IDS_CPSUI_FAX: UInt32 = 64835
IDS_CPSUI_PLOT: UInt32 = 64836
IDS_CPSUI_SLOW: UInt32 = 64837
IDS_CPSUI_FAST: UInt32 = 64838
IDS_CPSUI_ROTATED: UInt32 = 64839
IDS_CPSUI_RESET: UInt32 = 64840
IDS_CPSUI_ALL: UInt32 = 64841
IDS_CPSUI_DEVICE: UInt32 = 64842
IDS_CPSUI_SETTINGS: UInt32 = 64843
IDS_CPSUI_REVERT: UInt32 = 64844
IDS_CPSUI_CHANGES: UInt32 = 64845
IDS_CPSUI_CHANGED: UInt32 = 64846
IDS_CPSUI_WARNING: UInt32 = 64847
IDS_CPSUI_ABOUT: UInt32 = 64848
IDS_CPSUI_VERSION: UInt32 = 64849
IDS_CPSUI_NO_NAME: UInt32 = 64850
IDS_CPSUI_SETTING: UInt32 = 64851
IDS_CPSUI_DEVICE_SETTINGS: UInt32 = 64852
IDS_CPSUI_STDDOCPROPTAB1: UInt32 = 64853
IDS_CPSUI_STDDOCPROPTAB2: UInt32 = 64854
IDS_CPSUI_PAGEORDER: UInt32 = 64855
IDS_CPSUI_FRONTTOBACK: UInt32 = 64856
IDS_CPSUI_BACKTOFRONT: UInt32 = 64857
IDS_CPSUI_QUALITY_SETTINGS: UInt32 = 64858
IDS_CPSUI_QUALITY_DRAFT: UInt32 = 64859
IDS_CPSUI_QUALITY_BETTER: UInt32 = 64860
IDS_CPSUI_QUALITY_BEST: UInt32 = 64861
IDS_CPSUI_QUALITY_CUSTOM: UInt32 = 64862
IDS_CPSUI_OUTPUTBIN: UInt32 = 64863
IDS_CPSUI_NUP: UInt32 = 64864
IDS_CPSUI_NUP_NORMAL: UInt32 = 64865
IDS_CPSUI_NUP_TWOUP: UInt32 = 64866
IDS_CPSUI_NUP_FOURUP: UInt32 = 64867
IDS_CPSUI_NUP_SIXUP: UInt32 = 64868
IDS_CPSUI_NUP_NINEUP: UInt32 = 64869
IDS_CPSUI_NUP_SIXTEENUP: UInt32 = 64870
IDS_CPSUI_SIDE1: UInt32 = 64871
IDS_CPSUI_SIDE2: UInt32 = 64872
IDS_CPSUI_BOOKLET: UInt32 = 64873
IDS_CPSUI_POSTER: UInt32 = 64874
IDS_CPSUI_POSTER_2x2: UInt32 = 64875
IDS_CPSUI_POSTER_3x3: UInt32 = 64876
IDS_CPSUI_POSTER_4x4: UInt32 = 64877
IDS_CPSUI_NUP_DIRECTION: UInt32 = 64878
IDS_CPSUI_RIGHT_THEN_DOWN: UInt32 = 64879
IDS_CPSUI_DOWN_THEN_RIGHT: UInt32 = 64880
IDS_CPSUI_LEFT_THEN_DOWN: UInt32 = 64881
IDS_CPSUI_DOWN_THEN_LEFT: UInt32 = 64882
IDS_CPSUI_MANUAL_DUPLEX: UInt32 = 64883
IDS_CPSUI_MANUAL_DUPLEX_ON: UInt32 = 64884
IDS_CPSUI_MANUAL_DUPLEX_OFF: UInt32 = 64885
IDS_CPSUI_ROT_PORT: UInt32 = 64886
IDS_CPSUI_STAPLE: UInt32 = 64887
IDS_CPSUI_BOOKLET_EDGE: UInt32 = 64888
IDS_CPSUI_BOOKLET_EDGE_LEFT: UInt32 = 64889
IDS_CPSUI_BOOKLET_EDGE_RIGHT: UInt32 = 64890
IDS_CPSUI_NUP_BORDER: UInt32 = 64891
IDS_CPSUI_NUP_BORDERED: UInt32 = 64892
IDS_CPSUI_STRID_LAST: UInt32 = 64892
XPS_FP_PRINTER_NAME: String = 'PrinterName'
XPS_FP_PROGRESS_REPORT: String = 'ProgressReport'
XPS_FP_PRINTER_HANDLE: String = 'PrinterHandle'
XPS_FP_USER_PRINT_TICKET: String = 'PerUserPrintTicket'
XPS_FP_USER_TOKEN: String = 'UserSecurityToken'
XPS_FP_JOB_ID: String = 'PrintJobId'
XPS_FP_PRINT_CLASS_FACTORY: String = 'PrintClassFactory'
XPS_FP_OUTPUT_FILE: String = 'PrintOutputFileName'
XPS_FP_MS_CONTENT_TYPE: String = 'DriverMultiContentType'
XPS_FP_MS_CONTENT_TYPE_XPS: String = 'XPS'
XPS_FP_MS_CONTENT_TYPE_OPENXPS: String = 'OpenXPS'
XPS_FP_DRIVER_PROPERTY_BAG: String = 'DriverPropertyBag'
XPS_FP_QUEUE_PROPERTY_BAG: String = 'QueuePropertyBag'
XPS_FP_MERGED_DATAFILE_PATH: String = 'MergedDataFilePath'
XPS_FP_RESOURCE_DLL_PATHS: String = 'ResourceDLLPaths'
XPS_FP_JOB_LEVEL_PRINTTICKET: String = 'JobPrintTicket'
XPS_FP_PRINTDEVICECAPABILITIES: String = 'PrintDeviceCapabilities'
MXDC_ESCAPE: UInt32 = 4122
MXDCOP_GET_FILENAME: UInt32 = 14
MXDCOP_PRINTTICKET_FIXED_DOC_SEQ: UInt32 = 22
MXDCOP_PRINTTICKET_FIXED_DOC: UInt32 = 24
MXDCOP_PRINTTICKET_FIXED_PAGE: UInt32 = 26
MXDCOP_SET_S0PAGE: UInt32 = 28
MXDCOP_SET_S0PAGE_RESOURCE: UInt32 = 30
MXDCOP_SET_XPSPASSTHRU_MODE: UInt32 = 32
CLSID_OEMRENDER: Guid = Guid('{6d6abf26-9f38-11d1-882a-00c04fb961ec}')
CLSID_OEMUI: Guid = Guid('{abce80d7-9f46-11d1-882a-00c04fb961ec}')
CLSID_OEMUIMXDC: Guid = Guid('{4e144300-5b43-4288-932a-5e4dd6d82bed}')
CLSID_OEMPTPROVIDER: Guid = Guid('{91723892-45d2-48e2-9ec9-562379daf992}')
S_DEVCAP_OUTPUT_FULL_REPLACEMENT: win32more.Windows.Win32.Foundation.HRESULT = 318465
CLSID_PTPROVIDER: Guid = Guid('{46ac151b-8490-4531-96cc-55bf2bf19e11}')
E_VERSION_NOT_SUPPORTED: UInt32 = 2147745793
S_NO_CONFLICT: UInt32 = 262145
S_CONFLICT_RESOLVED: UInt32 = 262146
PRINTER_EXTENSION_DETAILEDREASON_PRINTER_STATUS: Guid = Guid('{5d5a1704-dfd1-4181-8eee-815c86edad31}')
PRINTER_EXTENSION_REASON_PRINT_PREFERENCES: Guid = Guid('{ec8f261f-267c-469f-b5d6-3933023c29cc}')
PRINTER_EXTENSION_REASON_DRIVER_EVENT: Guid = Guid('{23bb1328-63de-4293-915b-a6a23d929acb}')
FMTID_PrinterPropertyBag: Guid = Guid('{75f9adca-097d-45c3-a6e4-bab29e276f3e}')
PRINTER_OEMINTF_VERSION: UInt32 = 65536
OEM_MODE_PUBLISHER: UInt32 = 1
OEMGI_GETSIGNATURE: UInt32 = 1
OEMGI_GETINTERFACEVERSION: UInt32 = 2
OEMGI_GETVERSION: UInt32 = 3
OEMGI_GETPUBLISHERINFO: UInt32 = 4
OEMGI_GETREQUESTEDHELPERINTERFACES: UInt32 = 5
OEMPUBLISH_DEFAULT: UInt32 = 0
OEMPUBLISH_IPRINTCOREHELPER: UInt32 = 1
OEMDM_SIZE: UInt32 = 1
OEMDM_DEFAULT: UInt32 = 2
OEMDM_CONVERT: UInt32 = 3
OEMDM_MERGE: UInt32 = 4
OEMGDS_MIN_DOCSTICKY: UInt32 = 1
OEMGDS_PSDM_FLAGS: UInt32 = 1
OEMGDS_PSDM_DIALECT: UInt32 = 2
OEMGDS_PSDM_TTDLFMT: UInt32 = 3
OEMGDS_PSDM_NUP: UInt32 = 4
OEMGDS_PSDM_PSLEVEL: UInt32 = 5
OEMGDS_PSDM_CUSTOMSIZE: UInt32 = 6
OEMGDS_UNIDM_GPDVER: UInt32 = 16384
OEMGDS_UNIDM_FLAGS: UInt32 = 16385
OEMGDS_MIN_PRINTERSTICKY: UInt32 = 32768
OEMGDS_PRINTFLAGS: UInt32 = 32768
OEMGDS_FREEMEM: UInt32 = 32769
OEMGDS_JOBTIMEOUT: UInt32 = 32770
OEMGDS_WAITTIMEOUT: UInt32 = 32771
OEMGDS_PROTOCOL: UInt32 = 32772
OEMGDS_MINOUTLINE: UInt32 = 32773
OEMGDS_MAXBITMAP: UInt32 = 32774
OEMGDS_MAX: UInt32 = 65536
GPD_OEMCUSTOMDATA: UInt32 = 1
MV_UPDATE: UInt32 = 1
MV_RELATIVE: UInt32 = 2
MV_GRAPHICS: UInt32 = 4
MV_PHYSICAL: UInt32 = 8
MV_SENDXMOVECMD: UInt32 = 16
MV_SENDYMOVECMD: UInt32 = 32
OEMTTY_INFO_MARGINS: UInt32 = 1
OEMTTY_INFO_CODEPAGE: UInt32 = 2
OEMTTY_INFO_NUM_UFMS: UInt32 = 3
OEMTTY_INFO_UFM_IDS: UInt32 = 4
UFOFLAG_TTFONT: UInt32 = 1
UFOFLAG_TTDOWNLOAD_BITMAP: UInt32 = 2
UFOFLAG_TTDOWNLOAD_TTOUTLINE: UInt32 = 4
UFOFLAG_TTOUTLINE_BOLD_SIM: UInt32 = 8
UFOFLAG_TTOUTLINE_ITALIC_SIM: UInt32 = 16
UFOFLAG_TTOUTLINE_VERTICAL: UInt32 = 32
UFOFLAG_TTSUBSTITUTED: UInt32 = 64
UFO_GETINFO_FONTOBJ: UInt32 = 1
UFO_GETINFO_GLYPHSTRING: UInt32 = 2
UFO_GETINFO_GLYPHBITMAP: UInt32 = 3
UFO_GETINFO_GLYPHWIDTH: UInt32 = 4
UFO_GETINFO_MEMORY: UInt32 = 5
UFO_GETINFO_STDVARIABLE: UInt32 = 6
FNT_INFO_PRINTDIRINCCDEGREES: UInt32 = 0
FNT_INFO_GRAYPERCENTAGE: UInt32 = 1
FNT_INFO_NEXTFONTID: UInt32 = 2
FNT_INFO_NEXTGLYPH: UInt32 = 3
FNT_INFO_FONTHEIGHT: UInt32 = 4
FNT_INFO_FONTWIDTH: UInt32 = 5
FNT_INFO_FONTBOLD: UInt32 = 6
FNT_INFO_FONTITALIC: UInt32 = 7
FNT_INFO_FONTUNDERLINE: UInt32 = 8
FNT_INFO_FONTSTRIKETHRU: UInt32 = 9
FNT_INFO_CURRENTFONTID: UInt32 = 10
FNT_INFO_TEXTYRES: UInt32 = 11
FNT_INFO_TEXTXRES: UInt32 = 12
FNT_INFO_FONTMAXWIDTH: UInt32 = 13
FNT_INFO_MAX: UInt32 = 14
TTDOWNLOAD_DONTCARE: UInt32 = 0
TTDOWNLOAD_GRAPHICS: UInt32 = 1
TTDOWNLOAD_BITMAP: UInt32 = 2
TTDOWNLOAD_TTOUTLINE: UInt32 = 3
TYPE_UNICODE: UInt32 = 1
TYPE_TRANSDATA: UInt32 = 2
TYPE_GLYPHHANDLE: UInt32 = 3
TYPE_GLYPHID: UInt32 = 4
PDEV_ADJUST_PAPER_MARGIN_TYPE: UInt32 = 1
PDEV_HOSTFONT_ENABLED_TYPE: UInt32 = 2
PDEV_USE_TRUE_COLOR_TYPE: UInt32 = 3
OEMCUIP_DOCPROP: UInt32 = 1
OEMCUIP_PRNPROP: UInt32 = 2
CUSTOMPARAM_WIDTH: UInt32 = 0
CUSTOMPARAM_HEIGHT: UInt32 = 1
CUSTOMPARAM_WIDTHOFFSET: UInt32 = 2
CUSTOMPARAM_HEIGHTOFFSET: UInt32 = 3
CUSTOMPARAM_ORIENTATION: UInt32 = 4
CUSTOMPARAM_MAX: UInt32 = 5
SETOPTIONS_FLAG_RESOLVE_CONFLICT: UInt32 = 1
SETOPTIONS_FLAG_KEEP_CONFLICT: UInt32 = 2
SETOPTIONS_RESULT_NO_CONFLICT: UInt32 = 0
SETOPTIONS_RESULT_CONFLICT_RESOLVED: UInt32 = 1
SETOPTIONS_RESULT_CONFLICT_REMAINED: UInt32 = 2
UNIFM_VERSION_1_0: UInt32 = 65536
UFM_SOFT: UInt32 = 1
UFM_CART: UInt32 = 2
UFM_SCALABLE: UInt32 = 4
DF_TYPE_HPINTELLIFONT: UInt32 = 0
DF_TYPE_TRUETYPE: UInt32 = 1
DF_TYPE_PST1: UInt32 = 2
DF_TYPE_CAPSL: UInt32 = 3
DF_TYPE_OEM1: UInt32 = 4
DF_TYPE_OEM2: UInt32 = 5
DF_NOITALIC: UInt32 = 1
DF_NOUNDER: UInt32 = 2
DF_XM_CR: UInt32 = 4
DF_NO_BOLD: UInt32 = 8
DF_NO_DOUBLE_UNDERLINE: UInt32 = 16
DF_NO_STRIKETHRU: UInt32 = 32
DF_BKSP_OK: UInt32 = 64
UNI_GLYPHSETDATA_VERSION_1_0: UInt32 = 65536
MTYPE_FORMAT_MASK: UInt32 = 7
MTYPE_COMPOSE: UInt32 = 1
MTYPE_DIRECT: UInt32 = 2
MTYPE_PAIRED: UInt32 = 4
MTYPE_DOUBLEBYTECHAR_MASK: UInt32 = 24
MTYPE_SINGLE: UInt32 = 8
MTYPE_DOUBLE: UInt32 = 16
MTYPE_PREDEFIN_MASK: UInt32 = 224
MTYPE_REPLACE: UInt32 = 32
MTYPE_ADD: UInt32 = 64
MTYPE_DISABLE: UInt32 = 128
CC_NOPRECNV: UInt32 = 65535
CC_DEFAULT: UInt32 = 0
CC_CP437: Int32 = -1
CC_CP850: Int32 = -2
CC_CP863: Int32 = -3
CC_BIG5: Int32 = -10
CC_ISC: Int32 = -11
CC_JIS: Int32 = -12
CC_JIS_ANK: Int32 = -13
CC_NS86: Int32 = -14
CC_TCA: Int32 = -15
CC_GB2312: Int32 = -16
CC_SJIS: Int32 = -17
CC_WANSUNG: Int32 = -18
UFF_VERSION_NUMBER: UInt32 = 65537
FONT_DIR_SORTED: UInt32 = 1
FONT_FL_UFM: UInt32 = 1
FONT_FL_IFI: UInt32 = 2
FONT_FL_SOFTFONT: UInt32 = 4
FONT_FL_PERMANENT_SF: UInt32 = 8
FONT_FL_DEVICEFONT: UInt32 = 16
FONT_FL_GLYPHSET_GTT: UInt32 = 32
FONT_FL_GLYPHSET_RLE: UInt32 = 64
FONT_FL_RESERVED: UInt32 = 32768
FG_CANCHANGE: UInt32 = 128
WM_FI_FILENAME: UInt32 = 900
UNKNOWN_PROTOCOL: UInt32 = 0
PROTOCOL_UNKNOWN_TYPE: UInt32 = 0
RAWTCP: UInt32 = 1
PROTOCOL_RAWTCP_TYPE: UInt32 = 1
LPR: UInt32 = 2
PROTOCOL_LPR_TYPE: UInt32 = 2
MAX_PORTNAME_LEN: UInt32 = 64
MAX_NETWORKNAME_LEN: UInt32 = 49
MAX_NETWORKNAME2_LEN: UInt32 = 128
MAX_SNMP_COMMUNITY_STR_LEN: UInt32 = 33
MAX_QUEUENAME_LEN: UInt32 = 33
MAX_IPADDR_STR_LEN: UInt32 = 16
MAX_ADDRESS_STR_LEN: UInt32 = 13
MAX_DEVICEDESCRIPTION_STR_LEN: UInt32 = 257
DPS_NOPERMISSION: UInt32 = 1
DM_ADVANCED: UInt32 = 16
DM_NOPERMISSION: UInt32 = 32
DM_USER_DEFAULT: UInt32 = 64
DM_PROMPT_NON_MODAL: UInt32 = 1073741824
DM_INVALIDATE_DRIVER_CACHE: UInt32 = 536870912
DM_RESERVED: UInt32 = 2147483648
CDM_CONVERT: UInt32 = 1
CDM_CONVERT351: UInt32 = 2
CDM_DRIVER_DEFAULT: UInt32 = 4
DOCUMENTEVENT_FIRST: UInt32 = 1
DOCUMENTEVENT_CREATEDCPRE: UInt32 = 1
DOCUMENTEVENT_CREATEDCPOST: UInt32 = 2
DOCUMENTEVENT_RESETDCPRE: UInt32 = 3
DOCUMENTEVENT_RESETDCPOST: UInt32 = 4
DOCUMENTEVENT_STARTDOC: UInt32 = 5
DOCUMENTEVENT_STARTDOCPRE: UInt32 = 5
DOCUMENTEVENT_STARTPAGE: UInt32 = 6
DOCUMENTEVENT_ENDPAGE: UInt32 = 7
DOCUMENTEVENT_ENDDOC: UInt32 = 8
DOCUMENTEVENT_ENDDOCPRE: UInt32 = 8
DOCUMENTEVENT_ABORTDOC: UInt32 = 9
DOCUMENTEVENT_DELETEDC: UInt32 = 10
DOCUMENTEVENT_ESCAPE: UInt32 = 11
DOCUMENTEVENT_ENDDOCPOST: UInt32 = 12
DOCUMENTEVENT_STARTDOCPOST: UInt32 = 13
DOCUMENTEVENT_QUERYFILTER: UInt32 = 14
DOCUMENTEVENT_XPS_ADDFIXEDDOCUMENTSEQUENCEPRE: UInt32 = 1
DOCUMENTEVENT_XPS_ADDFIXEDDOCUMENTPRE: UInt32 = 2
DOCUMENTEVENT_XPS_ADDFIXEDPAGEEPRE: UInt32 = 3
DOCUMENTEVENT_XPS_ADDFIXEDPAGEPOST: UInt32 = 4
DOCUMENTEVENT_XPS_ADDFIXEDDOCUMENTPOST: UInt32 = 5
DOCUMENTEVENT_XPS_CANCELJOB: UInt32 = 6
DOCUMENTEVENT_XPS_ADDFIXEDDOCUMENTSEQUENCEPRINTTICKETPRE: UInt32 = 7
DOCUMENTEVENT_XPS_ADDFIXEDDOCUMENTPRINTTICKETPRE: UInt32 = 8
DOCUMENTEVENT_XPS_ADDFIXEDPAGEPRINTTICKETPRE: UInt32 = 9
DOCUMENTEVENT_XPS_ADDFIXEDPAGEPRINTTICKETPOST: UInt32 = 10
DOCUMENTEVENT_XPS_ADDFIXEDDOCUMENTPRINTTICKETPOST: UInt32 = 11
DOCUMENTEVENT_XPS_ADDFIXEDDOCUMENTSEQUENCEPRINTTICKETPOST: UInt32 = 12
DOCUMENTEVENT_XPS_ADDFIXEDDOCUMENTSEQUENCEPOST: UInt32 = 13
DOCUMENTEVENT_LAST: UInt32 = 15
DOCUMENTEVENT_SPOOLED: UInt32 = 65536
DOCUMENTEVENT_SUCCESS: UInt32 = 1
DOCUMENTEVENT_UNSUPPORTED: UInt32 = 0
DOCUMENTEVENT_FAILURE: Int32 = -1
PRINTER_EVENT_CONFIGURATION_CHANGE: UInt32 = 0
PRINTER_EVENT_ADD_CONNECTION: UInt32 = 1
PRINTER_EVENT_DELETE_CONNECTION: UInt32 = 2
PRINTER_EVENT_INITIALIZE: UInt32 = 3
PRINTER_EVENT_DELETE: UInt32 = 4
PRINTER_EVENT_CACHE_REFRESH: UInt32 = 5
PRINTER_EVENT_CACHE_DELETE: UInt32 = 6
PRINTER_EVENT_ATTRIBUTES_CHANGED: UInt32 = 7
PRINTER_EVENT_CONFIGURATION_UPDATE: UInt32 = 8
PRINTER_EVENT_ADD_CONNECTION_NO_UI: UInt32 = 9
PRINTER_EVENT_DELETE_CONNECTION_NO_UI: UInt32 = 10
PRINTER_EVENT_FLAG_NO_UI: UInt32 = 1
DRIVER_EVENT_INITIALIZE: UInt32 = 1
DRIVER_EVENT_DELETE: UInt32 = 2
BORDER_PRINT: UInt32 = 0
NO_BORDER_PRINT: UInt32 = 1
NORMAL_PRINT: UInt32 = 0
REVERSE_PRINT: UInt32 = 1
BOOKLET_PRINT: UInt32 = 2
NO_COLOR_OPTIMIZATION: UInt32 = 0
COLOR_OPTIMIZATION: UInt32 = 1
REVERSE_PAGES_FOR_REVERSE_DUPLEX: UInt32 = 1
RIGHT_THEN_DOWN: UInt32 = 1
BOOKLET_EDGE_LEFT: UInt32 = 0
BOOKLET_EDGE_RIGHT: UInt32 = 1
QCP_DEVICEPROFILE: UInt32 = 0
QCP_SOURCEPROFILE: UInt32 = 1
QCP_PROFILEMEMORY: UInt32 = 1
QCP_PROFILEDISK: UInt32 = 2
SPLPRINTER_USER_MODE_PRINTER_DRIVER: String = 'SPLUserModePrinterDriver'
EMF_PP_COLOR_OPTIMIZATION: UInt32 = 1
PRINTER_NOTIFY_STATUS_ENDPOINT: UInt32 = 1
PRINTER_NOTIFY_STATUS_POLL: UInt32 = 2
PRINTER_NOTIFY_STATUS_INFO: UInt32 = 4
ROUTER_UNKNOWN: UInt32 = 0
ROUTER_SUCCESS: UInt32 = 1
ROUTER_STOP_ROUTING: UInt32 = 2
DOC_INFO_INTERNAL_LEVEL: UInt32 = 100
SPLCLIENT_INFO_INTERNAL_LEVEL: UInt32 = 100
FILL_WITH_DEFAULTS: UInt32 = 1
PRINTER_NOTIFY_INFO_DATA_COMPACT: UInt32 = 1
COPYFILE_EVENT_SET_PRINTER_DATAEX: UInt32 = 1
COPYFILE_EVENT_DELETE_PRINTER: UInt32 = 2
COPYFILE_EVENT_ADD_PRINTER_CONNECTION: UInt32 = 3
COPYFILE_EVENT_DELETE_PRINTER_CONNECTION: UInt32 = 4
COPYFILE_EVENT_FILES_CHANGED: UInt32 = 5
COPYFILE_FLAG_CLIENT_SPOOLER: UInt32 = 1
COPYFILE_FLAG_SERVER_SPOOLER: UInt32 = 2
DSPRINT_PUBLISH: UInt32 = 1
DSPRINT_UPDATE: UInt32 = 2
DSPRINT_UNPUBLISH: UInt32 = 4
DSPRINT_REPUBLISH: UInt32 = 8
DSPRINT_PENDING: UInt32 = 2147483648
PRINTER_CONTROL_PAUSE: UInt32 = 1
PRINTER_CONTROL_RESUME: UInt32 = 2
PRINTER_CONTROL_PURGE: UInt32 = 3
PRINTER_CONTROL_SET_STATUS: UInt32 = 4
PRINTER_STATUS_PAUSED: UInt32 = 1
PRINTER_STATUS_ERROR: UInt32 = 2
PRINTER_STATUS_PENDING_DELETION: UInt32 = 4
PRINTER_STATUS_PAPER_JAM: UInt32 = 8
PRINTER_STATUS_PAPER_OUT: UInt32 = 16
PRINTER_STATUS_MANUAL_FEED: UInt32 = 32
PRINTER_STATUS_PAPER_PROBLEM: UInt32 = 64
PRINTER_STATUS_OFFLINE: UInt32 = 128
PRINTER_STATUS_IO_ACTIVE: UInt32 = 256
PRINTER_STATUS_BUSY: UInt32 = 512
PRINTER_STATUS_PRINTING: UInt32 = 1024
PRINTER_STATUS_OUTPUT_BIN_FULL: UInt32 = 2048
PRINTER_STATUS_NOT_AVAILABLE: UInt32 = 4096
PRINTER_STATUS_WAITING: UInt32 = 8192
PRINTER_STATUS_PROCESSING: UInt32 = 16384
PRINTER_STATUS_INITIALIZING: UInt32 = 32768
PRINTER_STATUS_WARMING_UP: UInt32 = 65536
PRINTER_STATUS_TONER_LOW: UInt32 = 131072
PRINTER_STATUS_NO_TONER: UInt32 = 262144
PRINTER_STATUS_PAGE_PUNT: UInt32 = 524288
PRINTER_STATUS_USER_INTERVENTION: UInt32 = 1048576
PRINTER_STATUS_OUT_OF_MEMORY: UInt32 = 2097152
PRINTER_STATUS_DOOR_OPEN: UInt32 = 4194304
PRINTER_STATUS_SERVER_UNKNOWN: UInt32 = 8388608
PRINTER_STATUS_POWER_SAVE: UInt32 = 16777216
PRINTER_STATUS_SERVER_OFFLINE: UInt32 = 33554432
PRINTER_STATUS_DRIVER_UPDATE_NEEDED: UInt32 = 67108864
PRINTER_ATTRIBUTE_QUEUED: UInt32 = 1
PRINTER_ATTRIBUTE_DIRECT: UInt32 = 2
PRINTER_ATTRIBUTE_DEFAULT: UInt32 = 4
PRINTER_ATTRIBUTE_SHARED: UInt32 = 8
PRINTER_ATTRIBUTE_NETWORK: UInt32 = 16
PRINTER_ATTRIBUTE_HIDDEN: UInt32 = 32
PRINTER_ATTRIBUTE_LOCAL: UInt32 = 64
PRINTER_ATTRIBUTE_ENABLE_DEVQ: UInt32 = 128
PRINTER_ATTRIBUTE_KEEPPRINTEDJOBS: UInt32 = 256
PRINTER_ATTRIBUTE_DO_COMPLETE_FIRST: UInt32 = 512
PRINTER_ATTRIBUTE_WORK_OFFLINE: UInt32 = 1024
PRINTER_ATTRIBUTE_ENABLE_BIDI: UInt32 = 2048
PRINTER_ATTRIBUTE_RAW_ONLY: UInt32 = 4096
PRINTER_ATTRIBUTE_PUBLISHED: UInt32 = 8192
PRINTER_ATTRIBUTE_FAX: UInt32 = 16384
PRINTER_ATTRIBUTE_TS: UInt32 = 32768
PRINTER_ATTRIBUTE_PUSHED_USER: UInt32 = 131072
PRINTER_ATTRIBUTE_PUSHED_MACHINE: UInt32 = 262144
PRINTER_ATTRIBUTE_MACHINE: UInt32 = 524288
PRINTER_ATTRIBUTE_FRIENDLY_NAME: UInt32 = 1048576
PRINTER_ATTRIBUTE_TS_GENERIC_DRIVER: UInt32 = 2097152
PRINTER_ATTRIBUTE_PER_USER: UInt32 = 4194304
PRINTER_ATTRIBUTE_ENTERPRISE_CLOUD: UInt32 = 8388608
NO_PRIORITY: UInt32 = 0
MAX_PRIORITY: UInt32 = 99
MIN_PRIORITY: UInt32 = 1
DEF_PRIORITY: UInt32 = 1
JOB_CONTROL_PAUSE: UInt32 = 1
JOB_CONTROL_RESUME: UInt32 = 2
JOB_CONTROL_CANCEL: UInt32 = 3
JOB_CONTROL_RESTART: UInt32 = 4
JOB_CONTROL_DELETE: UInt32 = 5
JOB_CONTROL_SENT_TO_PRINTER: UInt32 = 6
JOB_CONTROL_LAST_PAGE_EJECTED: UInt32 = 7
JOB_CONTROL_RETAIN: UInt32 = 8
JOB_CONTROL_RELEASE: UInt32 = 9
JOB_CONTROL_SEND_TOAST: UInt32 = 10
JOB_STATUS_PAUSED: UInt32 = 1
JOB_STATUS_ERROR: UInt32 = 2
JOB_STATUS_DELETING: UInt32 = 4
JOB_STATUS_SPOOLING: UInt32 = 8
JOB_STATUS_PRINTING: UInt32 = 16
JOB_STATUS_OFFLINE: UInt32 = 32
JOB_STATUS_PAPEROUT: UInt32 = 64
JOB_STATUS_PRINTED: UInt32 = 128
JOB_STATUS_DELETED: UInt32 = 256
JOB_STATUS_BLOCKED_DEVQ: UInt32 = 512
JOB_STATUS_USER_INTERVENTION: UInt32 = 1024
JOB_STATUS_RESTART: UInt32 = 2048
JOB_STATUS_COMPLETE: UInt32 = 4096
JOB_STATUS_RETAINED: UInt32 = 8192
JOB_STATUS_RENDERING_LOCALLY: UInt32 = 16384
JOB_POSITION_UNSPECIFIED: UInt32 = 0
PRINTER_DRIVER_PACKAGE_AWARE: UInt32 = 1
PRINTER_DRIVER_XPS: UInt32 = 2
PRINTER_DRIVER_SANDBOX_ENABLED: UInt32 = 4
PRINTER_DRIVER_CLASS: UInt32 = 8
PRINTER_DRIVER_DERIVED: UInt32 = 16
PRINTER_DRIVER_NOT_SHAREABLE: UInt32 = 32
PRINTER_DRIVER_CATEGORY_FAX: UInt32 = 64
PRINTER_DRIVER_CATEGORY_FILE: UInt32 = 128
PRINTER_DRIVER_CATEGORY_VIRTUAL: UInt32 = 256
PRINTER_DRIVER_CATEGORY_SERVICE: UInt32 = 512
PRINTER_DRIVER_SOFT_RESET_REQUIRED: UInt32 = 1024
PRINTER_DRIVER_SANDBOX_DISABLED: UInt32 = 2048
PRINTER_DRIVER_CATEGORY_3D: UInt32 = 4096
PRINTER_DRIVER_CATEGORY_CLOUD: UInt32 = 8192
DRIVER_KERNELMODE: UInt32 = 1
DRIVER_USERMODE: UInt32 = 2
DPD_DELETE_UNUSED_FILES: UInt32 = 1
DPD_DELETE_SPECIFIC_VERSION: UInt32 = 2
DPD_DELETE_ALL_FILES: UInt32 = 4
APD_STRICT_UPGRADE: UInt32 = 1
APD_STRICT_DOWNGRADE: UInt32 = 2
APD_COPY_ALL_FILES: UInt32 = 4
APD_COPY_NEW_FILES: UInt32 = 8
APD_COPY_FROM_DIRECTORY: UInt32 = 16
STRING_NONE: UInt32 = 1
STRING_MUIDLL: UInt32 = 2
STRING_LANGPAIR: UInt32 = 4
MAX_FORM_KEYWORD_LENGTH: UInt32 = 64
DI_CHANNEL: UInt32 = 1
DI_READ_SPOOL_JOB: UInt32 = 3
DI_MEMORYMAP_WRITE: UInt32 = 1
FORM_USER: UInt32 = 0
FORM_BUILTIN: UInt32 = 1
FORM_PRINTER: UInt32 = 2
PPCAPS_RIGHT_THEN_DOWN: UInt32 = 1
PPCAPS_BORDER_PRINT: UInt32 = 1
PPCAPS_BOOKLET_EDGE: UInt32 = 1
PPCAPS_REVERSE_PAGES_FOR_REVERSE_DUPLEX: UInt32 = 1
PPCAPS_SQUARE_SCALING: UInt32 = 1
PORT_TYPE_WRITE: UInt32 = 1
PORT_TYPE_READ: UInt32 = 2
PORT_TYPE_REDIRECTED: UInt32 = 4
PORT_TYPE_NET_ATTACHED: UInt32 = 8
PORT_STATUS_TYPE_ERROR: UInt32 = 1
PORT_STATUS_TYPE_WARNING: UInt32 = 2
PORT_STATUS_TYPE_INFO: UInt32 = 3
PORT_STATUS_OFFLINE: UInt32 = 1
PORT_STATUS_PAPER_JAM: UInt32 = 2
PORT_STATUS_PAPER_OUT: UInt32 = 3
PORT_STATUS_OUTPUT_BIN_FULL: UInt32 = 4
PORT_STATUS_PAPER_PROBLEM: UInt32 = 5
PORT_STATUS_NO_TONER: UInt32 = 6
PORT_STATUS_DOOR_OPEN: UInt32 = 7
PORT_STATUS_USER_INTERVENTION: UInt32 = 8
PORT_STATUS_OUT_OF_MEMORY: UInt32 = 9
PORT_STATUS_TONER_LOW: UInt32 = 10
PORT_STATUS_WARMING_UP: UInt32 = 11
PORT_STATUS_POWER_SAVE: UInt32 = 12
PRINTER_ENUM_DEFAULT: UInt32 = 1
PRINTER_ENUM_LOCAL: UInt32 = 2
PRINTER_ENUM_CONNECTIONS: UInt32 = 4
PRINTER_ENUM_FAVORITE: UInt32 = 4
PRINTER_ENUM_NAME: UInt32 = 8
PRINTER_ENUM_REMOTE: UInt32 = 16
PRINTER_ENUM_SHARED: UInt32 = 32
PRINTER_ENUM_NETWORK: UInt32 = 64
PRINTER_ENUM_EXPAND: UInt32 = 16384
PRINTER_ENUM_CONTAINER: UInt32 = 32768
PRINTER_ENUM_ICONMASK: UInt32 = 16711680
PRINTER_ENUM_ICON1: UInt32 = 65536
PRINTER_ENUM_ICON2: UInt32 = 131072
PRINTER_ENUM_ICON3: UInt32 = 262144
PRINTER_ENUM_ICON4: UInt32 = 524288
PRINTER_ENUM_ICON5: UInt32 = 1048576
PRINTER_ENUM_ICON6: UInt32 = 2097152
PRINTER_ENUM_ICON7: UInt32 = 4194304
PRINTER_ENUM_ICON8: UInt32 = 8388608
PRINTER_ENUM_HIDE: UInt32 = 16777216
PRINTER_ENUM_CATEGORY_ALL: UInt32 = 33554432
PRINTER_ENUM_CATEGORY_3D: UInt32 = 67108864
SPOOL_FILE_PERSISTENT: UInt32 = 1
SPOOL_FILE_TEMPORARY: UInt32 = 2
PRINTER_NOTIFY_TYPE: UInt32 = 0
JOB_NOTIFY_TYPE: UInt32 = 1
SERVER_NOTIFY_TYPE: UInt32 = 2
PRINTER_NOTIFY_FIELD_SERVER_NAME: UInt32 = 0
PRINTER_NOTIFY_FIELD_PRINTER_NAME: UInt32 = 1
PRINTER_NOTIFY_FIELD_SHARE_NAME: UInt32 = 2
PRINTER_NOTIFY_FIELD_PORT_NAME: UInt32 = 3
PRINTER_NOTIFY_FIELD_DRIVER_NAME: UInt32 = 4
PRINTER_NOTIFY_FIELD_COMMENT: UInt32 = 5
PRINTER_NOTIFY_FIELD_LOCATION: UInt32 = 6
PRINTER_NOTIFY_FIELD_DEVMODE: UInt32 = 7
PRINTER_NOTIFY_FIELD_SEPFILE: UInt32 = 8
PRINTER_NOTIFY_FIELD_PRINT_PROCESSOR: UInt32 = 9
PRINTER_NOTIFY_FIELD_PARAMETERS: UInt32 = 10
PRINTER_NOTIFY_FIELD_DATATYPE: UInt32 = 11
PRINTER_NOTIFY_FIELD_SECURITY_DESCRIPTOR: UInt32 = 12
PRINTER_NOTIFY_FIELD_ATTRIBUTES: UInt32 = 13
PRINTER_NOTIFY_FIELD_PRIORITY: UInt32 = 14
PRINTER_NOTIFY_FIELD_DEFAULT_PRIORITY: UInt32 = 15
PRINTER_NOTIFY_FIELD_START_TIME: UInt32 = 16
PRINTER_NOTIFY_FIELD_UNTIL_TIME: UInt32 = 17
PRINTER_NOTIFY_FIELD_STATUS: UInt32 = 18
PRINTER_NOTIFY_FIELD_STATUS_STRING: UInt32 = 19
PRINTER_NOTIFY_FIELD_CJOBS: UInt32 = 20
PRINTER_NOTIFY_FIELD_AVERAGE_PPM: UInt32 = 21
PRINTER_NOTIFY_FIELD_TOTAL_PAGES: UInt32 = 22
PRINTER_NOTIFY_FIELD_PAGES_PRINTED: UInt32 = 23
PRINTER_NOTIFY_FIELD_TOTAL_BYTES: UInt32 = 24
PRINTER_NOTIFY_FIELD_BYTES_PRINTED: UInt32 = 25
PRINTER_NOTIFY_FIELD_OBJECT_GUID: UInt32 = 26
PRINTER_NOTIFY_FIELD_FRIENDLY_NAME: UInt32 = 27
PRINTER_NOTIFY_FIELD_BRANCH_OFFICE_PRINTING: UInt32 = 28
JOB_NOTIFY_FIELD_PRINTER_NAME: UInt32 = 0
JOB_NOTIFY_FIELD_MACHINE_NAME: UInt32 = 1
JOB_NOTIFY_FIELD_PORT_NAME: UInt32 = 2
JOB_NOTIFY_FIELD_USER_NAME: UInt32 = 3
JOB_NOTIFY_FIELD_NOTIFY_NAME: UInt32 = 4
JOB_NOTIFY_FIELD_DATATYPE: UInt32 = 5
JOB_NOTIFY_FIELD_PRINT_PROCESSOR: UInt32 = 6
JOB_NOTIFY_FIELD_PARAMETERS: UInt32 = 7
JOB_NOTIFY_FIELD_DRIVER_NAME: UInt32 = 8
JOB_NOTIFY_FIELD_DEVMODE: UInt32 = 9
JOB_NOTIFY_FIELD_STATUS: UInt32 = 10
JOB_NOTIFY_FIELD_STATUS_STRING: UInt32 = 11
JOB_NOTIFY_FIELD_SECURITY_DESCRIPTOR: UInt32 = 12
JOB_NOTIFY_FIELD_DOCUMENT: UInt32 = 13
JOB_NOTIFY_FIELD_PRIORITY: UInt32 = 14
JOB_NOTIFY_FIELD_POSITION: UInt32 = 15
JOB_NOTIFY_FIELD_SUBMITTED: UInt32 = 16
JOB_NOTIFY_FIELD_START_TIME: UInt32 = 17
JOB_NOTIFY_FIELD_UNTIL_TIME: UInt32 = 18
JOB_NOTIFY_FIELD_TIME: UInt32 = 19
JOB_NOTIFY_FIELD_TOTAL_PAGES: UInt32 = 20
JOB_NOTIFY_FIELD_PAGES_PRINTED: UInt32 = 21
JOB_NOTIFY_FIELD_TOTAL_BYTES: UInt32 = 22
JOB_NOTIFY_FIELD_BYTES_PRINTED: UInt32 = 23
JOB_NOTIFY_FIELD_REMOTE_JOB_ID: UInt32 = 24
SERVER_NOTIFY_FIELD_PRINT_DRIVER_ISOLATION_GROUP: UInt32 = 0
PRINTER_NOTIFY_CATEGORY_ALL: UInt32 = 4096
PRINTER_NOTIFY_CATEGORY_3D: UInt32 = 8192
PRINTER_NOTIFY_OPTIONS_REFRESH: UInt32 = 1
PRINTER_NOTIFY_INFO_DISCARDED: UInt32 = 1
BIDI_ACTION_ENUM_SCHEMA: String = 'EnumSchema'
BIDI_ACTION_GET: String = 'Get'
BIDI_ACTION_SET: String = 'Set'
BIDI_ACTION_GET_ALL: String = 'GetAll'
BIDI_ACTION_GET_WITH_ARGUMENT: String = 'GetWithArgument'
BIDI_ACCESS_ADMINISTRATOR: UInt32 = 1
BIDI_ACCESS_USER: UInt32 = 2
ERROR_BIDI_STATUS_OK: UInt32 = 0
ERROR_BIDI_ERROR_BASE: UInt32 = 13000
ERROR_BIDI_STATUS_WARNING: UInt32 = 13001
ERROR_BIDI_SCHEMA_READ_ONLY: UInt32 = 13002
ERROR_BIDI_SERVER_OFFLINE: UInt32 = 13003
ERROR_BIDI_DEVICE_OFFLINE: UInt32 = 13004
ERROR_BIDI_SCHEMA_NOT_SUPPORTED: UInt32 = 13005
ERROR_BIDI_SET_DIFFERENT_TYPE: UInt32 = 13006
ERROR_BIDI_SET_MULTIPLE_SCHEMAPATH: UInt32 = 13007
ERROR_BIDI_SET_INVALID_SCHEMAPATH: UInt32 = 13008
ERROR_BIDI_SET_UNKNOWN_FAILURE: UInt32 = 13009
ERROR_BIDI_SCHEMA_WRITE_ONLY: UInt32 = 13010
ERROR_BIDI_GET_REQUIRES_ARGUMENT: UInt32 = 13011
ERROR_BIDI_GET_ARGUMENT_NOT_SUPPORTED: UInt32 = 13012
ERROR_BIDI_GET_MISSING_ARGUMENT: UInt32 = 13013
ERROR_BIDI_DEVICE_CONFIG_UNCHANGED: UInt32 = 13014
ERROR_BIDI_NO_LOCALIZED_RESOURCES: UInt32 = 13015
ERROR_BIDI_NO_BIDI_SCHEMA_EXTENSIONS: UInt32 = 13016
ERROR_BIDI_UNSUPPORTED_CLIENT_LANGUAGE: UInt32 = 13017
ERROR_BIDI_UNSUPPORTED_RESOURCE_FORMAT: UInt32 = 13018
PRINTER_CHANGE_ADD_PRINTER: UInt32 = 1
PRINTER_CHANGE_SET_PRINTER: UInt32 = 2
PRINTER_CHANGE_DELETE_PRINTER: UInt32 = 4
PRINTER_CHANGE_FAILED_CONNECTION_PRINTER: UInt32 = 8
PRINTER_CHANGE_PRINTER: UInt32 = 255
PRINTER_CHANGE_ADD_JOB: UInt32 = 256
PRINTER_CHANGE_SET_JOB: UInt32 = 512
PRINTER_CHANGE_DELETE_JOB: UInt32 = 1024
PRINTER_CHANGE_WRITE_JOB: UInt32 = 2048
PRINTER_CHANGE_JOB: UInt32 = 65280
PRINTER_CHANGE_ADD_FORM: UInt32 = 65536
PRINTER_CHANGE_SET_FORM: UInt32 = 131072
PRINTER_CHANGE_DELETE_FORM: UInt32 = 262144
PRINTER_CHANGE_FORM: UInt32 = 458752
PRINTER_CHANGE_ADD_PORT: UInt32 = 1048576
PRINTER_CHANGE_CONFIGURE_PORT: UInt32 = 2097152
PRINTER_CHANGE_DELETE_PORT: UInt32 = 4194304
PRINTER_CHANGE_PORT: UInt32 = 7340032
PRINTER_CHANGE_ADD_PRINT_PROCESSOR: UInt32 = 16777216
PRINTER_CHANGE_DELETE_PRINT_PROCESSOR: UInt32 = 67108864
PRINTER_CHANGE_PRINT_PROCESSOR: UInt32 = 117440512
PRINTER_CHANGE_SERVER: UInt32 = 134217728
PRINTER_CHANGE_ADD_PRINTER_DRIVER: UInt32 = 268435456
PRINTER_CHANGE_SET_PRINTER_DRIVER: UInt32 = 536870912
PRINTER_CHANGE_DELETE_PRINTER_DRIVER: UInt32 = 1073741824
PRINTER_CHANGE_PRINTER_DRIVER: UInt32 = 1879048192
PRINTER_CHANGE_TIMEOUT: UInt32 = 2147483648
PRINTER_CHANGE_ALL: UInt32 = 2138570751
PRINTER_ERROR_INFORMATION: UInt32 = 2147483648
PRINTER_ERROR_WARNING: UInt32 = 1073741824
PRINTER_ERROR_SEVERE: UInt32 = 536870912
PRINTER_ERROR_OUTOFPAPER: UInt32 = 1
PRINTER_ERROR_JAM: UInt32 = 2
PRINTER_ERROR_OUTOFTONER: UInt32 = 4
SPLREG_DEFAULT_SPOOL_DIRECTORY: String = 'DefaultSpoolDirectory'
SPLREG_PORT_THREAD_PRIORITY_DEFAULT: String = 'PortThreadPriorityDefault'
SPLREG_PORT_THREAD_PRIORITY: String = 'PortThreadPriority'
SPLREG_SCHEDULER_THREAD_PRIORITY_DEFAULT: String = 'SchedulerThreadPriorityDefault'
SPLREG_SCHEDULER_THREAD_PRIORITY: String = 'SchedulerThreadPriority'
SPLREG_BEEP_ENABLED: String = 'BeepEnabled'
SPLREG_NET_POPUP: String = 'NetPopup'
SPLREG_RETRY_POPUP: String = 'RetryPopup'
SPLREG_NET_POPUP_TO_COMPUTER: String = 'NetPopupToComputer'
SPLREG_EVENT_LOG: String = 'EventLog'
SPLREG_MAJOR_VERSION: String = 'MajorVersion'
SPLREG_MINOR_VERSION: String = 'MinorVersion'
SPLREG_ARCHITECTURE: String = 'Architecture'
SPLREG_OS_VERSION: String = 'OSVersion'
SPLREG_OS_VERSIONEX: String = 'OSVersionEx'
SPLREG_DS_PRESENT: String = 'DsPresent'
SPLREG_DS_PRESENT_FOR_USER: String = 'DsPresentForUser'
SPLREG_REMOTE_FAX: String = 'RemoteFax'
SPLREG_RESTART_JOB_ON_POOL_ERROR: String = 'RestartJobOnPoolError'
SPLREG_RESTART_JOB_ON_POOL_ENABLED: String = 'RestartJobOnPoolEnabled'
SPLREG_DNS_MACHINE_NAME: String = 'DNSMachineName'
SPLREG_ALLOW_USER_MANAGEFORMS: String = 'AllowUserManageForms'
SPLREG_WEBSHAREMGMT: String = 'WebShareMgmt'
SPLREG_PRINT_DRIVER_ISOLATION_GROUPS: String = 'PrintDriverIsolationGroups'
SPLREG_PRINT_DRIVER_ISOLATION_TIME_BEFORE_RECYCLE: String = 'PrintDriverIsolationTimeBeforeRecycle'
SPLREG_PRINT_DRIVER_ISOLATION_MAX_OBJECTS_BEFORE_RECYCLE: String = 'PrintDriverIsolationMaxobjsBeforeRecycle'
SPLREG_PRINT_DRIVER_ISOLATION_IDLE_TIMEOUT: String = 'PrintDriverIsolationIdleTimeout'
SPLREG_PRINT_DRIVER_ISOLATION_EXECUTION_POLICY: String = 'PrintDriverIsolationExecutionPolicy'
SPLREG_PRINT_DRIVER_ISOLATION_OVERRIDE_POLICY: String = 'PrintDriverIsolationOverrideCompat'
SPLREG_PRINT_QUEUE_V4_DRIVER_DIRECTORY: String = 'PrintQueueV4DriverDirectory'
JOB_ACCESS_ADMINISTER: UInt32 = 16
JOB_ACCESS_READ: UInt32 = 32
SPLDS_SPOOLER_KEY: String = 'DsSpooler'
SPLDS_DRIVER_KEY: String = 'DsDriver'
SPLDS_USER_KEY: String = 'DsUser'
SPLDS_ASSET_NUMBER: String = 'assetNumber'
SPLDS_BYTES_PER_MINUTE: String = 'bytesPerMinute'
SPLDS_DESCRIPTION: String = 'description'
SPLDS_DRIVER_NAME: String = 'driverName'
SPLDS_DRIVER_VERSION: String = 'driverVersion'
SPLDS_LOCATION: String = 'location'
SPLDS_PORT_NAME: String = 'portName'
SPLDS_PRINT_ATTRIBUTES: String = 'printAttributes'
SPLDS_PRINT_BIN_NAMES: String = 'printBinNames'
SPLDS_PRINT_COLLATE: String = 'printCollate'
SPLDS_PRINT_COLOR: String = 'printColor'
SPLDS_PRINT_DUPLEX_SUPPORTED: String = 'printDuplexSupported'
SPLDS_PRINT_END_TIME: String = 'printEndTime'
SPLDS_PRINTER_CLASS: String = 'printQueue'
SPLDS_PRINTER_NAME: String = 'printerName'
SPLDS_PRINT_KEEP_PRINTED_JOBS: String = 'printKeepPrintedJobs'
SPLDS_PRINT_LANGUAGE: String = 'printLanguage'
SPLDS_PRINT_MAC_ADDRESS: String = 'printMACAddress'
SPLDS_PRINT_MAX_X_EXTENT: String = 'printMaxXExtent'
SPLDS_PRINT_MAX_Y_EXTENT: String = 'printMaxYExtent'
SPLDS_PRINT_MAX_RESOLUTION_SUPPORTED: String = 'printMaxResolutionSupported'
SPLDS_PRINT_MEDIA_READY: String = 'printMediaReady'
SPLDS_PRINT_MEDIA_SUPPORTED: String = 'printMediaSupported'
SPLDS_PRINT_MEMORY: String = 'printMemory'
SPLDS_PRINT_MIN_X_EXTENT: String = 'printMinXExtent'
SPLDS_PRINT_MIN_Y_EXTENT: String = 'printMinYExtent'
SPLDS_PRINT_NETWORK_ADDRESS: String = 'printNetworkAddress'
SPLDS_PRINT_NOTIFY: String = 'printNotify'
SPLDS_PRINT_NUMBER_UP: String = 'printNumberUp'
SPLDS_PRINT_ORIENTATIONS_SUPPORTED: String = 'printOrientationsSupported'
SPLDS_PRINT_OWNER: String = 'printOwner'
SPLDS_PRINT_PAGES_PER_MINUTE: String = 'printPagesPerMinute'
SPLDS_PRINT_RATE: String = 'printRate'
SPLDS_PRINT_RATE_UNIT: String = 'printRateUnit'
SPLDS_PRINT_SEPARATOR_FILE: String = 'printSeparatorFile'
SPLDS_PRINT_SHARE_NAME: String = 'printShareName'
SPLDS_PRINT_SPOOLING: String = 'printSpooling'
SPLDS_PRINT_STAPLING_SUPPORTED: String = 'printStaplingSupported'
SPLDS_PRINT_START_TIME: String = 'printStartTime'
SPLDS_PRINT_STATUS: String = 'printStatus'
SPLDS_PRIORITY: String = 'priority'
SPLDS_SERVER_NAME: String = 'serverName'
SPLDS_SHORT_SERVER_NAME: String = 'shortServerName'
SPLDS_UNC_NAME: String = 'uNCName'
SPLDS_URL: String = 'url'
SPLDS_FLAGS: String = 'flags'
SPLDS_VERSION_NUMBER: String = 'versionNumber'
SPLDS_PRINTER_NAME_ALIASES: String = 'printerNameAliases'
SPLDS_PRINTER_LOCATIONS: String = 'printerLocations'
SPLDS_PRINTER_MODEL: String = 'printerModel'
PRINTER_CONNECTION_MISMATCH: UInt32 = 32
PRINTER_CONNECTION_NO_UI: UInt32 = 64
IPDFP_COPY_ALL_FILES: UInt32 = 1
UPDP_SILENT_UPLOAD: UInt32 = 1
UPDP_UPLOAD_ALWAYS: UInt32 = 2
UPDP_CHECK_DRIVERSTORE: UInt32 = 4
MS_PRINT_JOB_OUTPUT_FILE: String = 'MsPrintJobOutputFile'
DISPID_PRINTSCHEMA_ELEMENT: UInt32 = 10000
DISPID_PRINTSCHEMA_ELEMENT_XMLNODE: UInt32 = 10001
DISPID_PRINTSCHEMA_ELEMENT_NAME: UInt32 = 10002
DISPID_PRINTSCHEMA_ELEMENT_NAMESPACEURI: UInt32 = 10003
DISPID_PRINTSCHEMA_DISPLAYABLEELEMENT: UInt32 = 10100
DISPID_PRINTSCHEMA_DISPLAYABLEELEMENT_DISPLAYNAME: UInt32 = 10101
DISPID_PRINTSCHEMA_OPTION: UInt32 = 10200
DISPID_PRINTSCHEMA_OPTION_SELECTED: UInt32 = 10201
DISPID_PRINTSCHEMA_OPTION_CONSTRAINED: UInt32 = 10202
DISPID_PRINTSCHEMA_OPTION_GETPROPERTYVALUE: UInt32 = 10203
DISPID_PRINTSCHEMA_PAGEMEDIASIZEOPTION: UInt32 = 10300
DISPID_PRINTSCHEMA_PAGEMEDIASIZEOPTION_WIDTH: UInt32 = 10301
DISPID_PRINTSCHEMA_PAGEMEDIASIZEOPTION_HEIGHT: UInt32 = 10302
DISPID_PRINTSCHEMA_NUPOPTION: UInt32 = 10400
DISPID_PRINTSCHEMA_NUPOPTION_PAGESPERSHEET: UInt32 = 10401
DISPID_PRINTSCHEMA_OPTIONCOLLECTION: UInt32 = 10500
DISPID_PRINTSCHEMA_OPTIONCOLLECTION_COUNT: UInt32 = 10501
DISPID_PRINTSCHEMA_OPTIONCOLLECTION_GETAT: UInt32 = 10502
DISPID_PRINTSCHEMA_FEATURE: UInt32 = 10600
DISPID_PRINTSCHEMA_FEATURE_SELECTEDOPTION: UInt32 = 10601
DISPID_PRINTSCHEMA_FEATURE_SELECTIONTYPE: UInt32 = 10602
DISPID_PRINTSCHEMA_FEATURE_GETOPTION: UInt32 = 10603
DISPID_PRINTSCHEMA_FEATURE_DISPLAYUI: UInt32 = 10604
DISPID_PRINTSCHEMA_PAGEIMAGEABLESIZE: UInt32 = 10700
DISPID_PRINTSCHEMA_PAGEIMAGEABLESIZE_IMAGEABLE_WIDTH: UInt32 = 10701
DISPID_PRINTSCHEMA_PAGEIMAGEABLESIZE_IMAGEABLE_HEIGHT: UInt32 = 10702
DISPID_PRINTSCHEMA_PAGEIMAGEABLESIZE_ORIGIN_WIDTH: UInt32 = 10703
DISPID_PRINTSCHEMA_PAGEIMAGEABLESIZE_ORIGIN_HEIGHT: UInt32 = 10704
DISPID_PRINTSCHEMA_PAGEIMAGEABLESIZE_EXTENT_WIDTH: UInt32 = 10705
DISPID_PRINTSCHEMA_PAGEIMAGEABLESIZE_EXTENT_HEIGHT: UInt32 = 10706
DISPID_PRINTSCHEMA_CAPABILITIES: UInt32 = 10800
DISPID_PRINTSCHEMA_CAPABILITIES_GETFEATURE_KEYNAME: UInt32 = 10801
DISPID_PRINTSCHEMA_CAPABILITIES_GETFEATURE: UInt32 = 10802
DISPID_PRINTSCHEMA_CAPABILITIES_PAGEIMAGEABLESIZE: UInt32 = 10803
DISPID_PRINTSCHEMA_CAPABILITIES_JOBCOPIESMINVALUE: UInt32 = 10804
DISPID_PRINTSCHEMA_CAPABILITIES_JOBCOPIESMAXVALUE: UInt32 = 10805
DISPID_PRINTSCHEMA_CAPABILITIES_GETSELECTEDOPTION: UInt32 = 10806
DISPID_PRINTSCHEMA_CAPABILITIES_GETOPTIONS: UInt32 = 10807
DISPID_PRINTSCHEMA_CAPABILITIES_GETPARAMETERDEFINITION: UInt32 = 10808
DISPID_PRINTSCHEMA_ASYNCOPERATION: UInt32 = 10900
DISPID_PRINTSCHEMA_ASYNCOPERATION_START: UInt32 = 10901
DISPID_PRINTSCHEMA_ASYNCOPERATION_CANCEL: UInt32 = 10902
DISPID_PRINTSCHEMA_TICKET: UInt32 = 11000
DISPID_PRINTSCHEMA_TICKET_GETFEATURE_KEYNAME: UInt32 = 11001
DISPID_PRINTSCHEMA_TICKET_GETFEATURE: UInt32 = 11002
DISPID_PRINTSCHEMA_TICKET_VALIDATEASYNC: UInt32 = 11003
DISPID_PRINTSCHEMA_TICKET_COMMITASYNC: UInt32 = 11004
DISPID_PRINTSCHEMA_TICKET_NOTIFYXMLCHANGED: UInt32 = 11005
DISPID_PRINTSCHEMA_TICKET_GETCAPABILITIES: UInt32 = 11006
DISPID_PRINTSCHEMA_TICKET_JOBCOPIESALLDOCUMENTS: UInt32 = 11007
DISPID_PRINTSCHEMA_TICKET_GETPARAMETERINITIALIZER: UInt32 = 11008
DISPID_PRINTSCHEMA_ASYNCOPERATIONEVENT: UInt32 = 11100
DISPID_PRINTSCHEMA_ASYNCOPERATIONEVENT_COMPLETED: UInt32 = 11101
DISPID_PRINTERSCRIPTABLESEQUENTIALSTREAM: UInt32 = 11200
DISPID_PRINTERSCRIPTABLESEQUENTIALSTREAM_READ: UInt32 = 11201
DISPID_PRINTERSCRIPTABLESEQUENTIALSTREAM_WRITE: UInt32 = 11202
DISPID_PRINTERSCRIPTABLESTREAM: UInt32 = 11300
DISPID_PRINTERSCRIPTABLESTREAM_COMMIT: UInt32 = 11301
DISPID_PRINTERSCRIPTABLESTREAM_SEEK: UInt32 = 11302
DISPID_PRINTERSCRIPTABLESTREAM_SETSIZE: UInt32 = 11303
DISPID_PRINTERPROPERTYBAG: UInt32 = 11400
DISPID_PRINTERPROPERTYBAG_GETBOOL: UInt32 = 11401
DISPID_PRINTERPROPERTYBAG_SETBOOL: UInt32 = 11402
DISPID_PRINTERPROPERTYBAG_GETINT32: UInt32 = 11403
DISPID_PRINTERPROPERTYBAG_SETINT32: UInt32 = 11404
DISPID_PRINTERPROPERTYBAG_GETSTRING: UInt32 = 11405
DISPID_PRINTERPROPERTYBAG_SETSTRING: UInt32 = 11406
DISPID_PRINTERPROPERTYBAG_GETBYTES: UInt32 = 11407
DISPID_PRINTERPROPERTYBAG_SETBYTES: UInt32 = 11408
DISPID_PRINTERPROPERTYBAG_GETREADSTREAM: UInt32 = 11409
DISPID_PRINTERPROPERTYBAG_GETWRITESTREAM: UInt32 = 11410
DISPID_PRINTERSCRIPTABLEPROPERTYBAG_GETSTREAMASXML: UInt32 = 11411
DISPID_PRINTERSCRIPTABLEPROPERTYBAG: UInt32 = 11500
DISPID_PRINTERSCRIPTABLEPROPERTYBAG_GETBOOL: UInt32 = 11501
DISPID_PRINTERSCRIPTABLEPROPERTYBAG_SETBOOL: UInt32 = 11502
DISPID_PRINTERSCRIPTABLEPROPERTYBAG_GETINT32: UInt32 = 11503
DISPID_PRINTERSCRIPTABLEPROPERTYBAG_SETINT32: UInt32 = 11504
DISPID_PRINTERSCRIPTABLEPROPERTYBAG_GETSTRING: UInt32 = 11505
DISPID_PRINTERSCRIPTABLEPROPERTYBAG_SETSTRING: UInt32 = 11506
DISPID_PRINTERSCRIPTABLEPROPERTYBAG_GETBYTES: UInt32 = 11507
DISPID_PRINTERSCRIPTABLEPROPERTYBAG_SETBYTES: UInt32 = 11508
DISPID_PRINTERSCRIPTABLEPROPERTYBAG_GETREADSTREAM: UInt32 = 11509
DISPID_PRINTERSCRIPTABLEPROPERTYBAG_GETWRITESTREAM: UInt32 = 11510
DISPID_PRINTERQUEUE: UInt32 = 11600
DISPID_PRINTERQUEUE_HANDLE: UInt32 = 11601
DISPID_PRINTERQUEUE_NAME: UInt32 = 11602
DISPID_PRINTERQUEUE_SENDBIDIQUERY: UInt32 = 11603
DISPID_PRINTERQUEUE_GETPROPERTIES: UInt32 = 11604
DISPID_PRINTERQUEUE_SENDBIDISETREQUESTASYNC: UInt32 = 11605
DISPID_PRINTERQUEUE_GETPRINTERQUEUEVIEW: UInt32 = 11606
DISPID_PRINTERQUEUEEVENT: UInt32 = 11700
DISPID_PRINTERQUEUEEVENT_ONBIDIRESPONSERECEIVED: UInt32 = 11701
DISPID_PRINTEREXTENSION_CONTEXT: UInt32 = 11800
DISPID_PRINTEREXTENSION_CONTEXT_PRINTERQUEUE: UInt32 = 11801
DISPID_PRINTEREXTENSION_CONTEXT_PRINTSCHEMATICKET: UInt32 = 11802
DISPID_PRINTEREXTENSION_CONTEXT_DRIVERPROPERTIES: UInt32 = 11803
DISPID_PRINTEREXTENSION_CONTEXT_USERPROPERTIES: UInt32 = 11804
DISPID_PRINTEREXTENSION_REQUEST: UInt32 = 11900
DISPID_PRINTEREXTENSION_REQUEST_CANCEL: UInt32 = 11901
DISPID_PRINTEREXTENSION_REQUEST_COMPLETE: UInt32 = 11902
DISPID_PRINTEREXTENSION_EVENTARGS: UInt32 = 12000
DISPID_PRINTEREXTENSION_EVENTARGS_BIDINOTIFICATION: UInt32 = 12001
DISPID_PRINTEREXTENSION_EVENTARGS_REASONID: UInt32 = 12002
DISPID_PRINTEREXTENSION_EVENTARGS_REQUEST: UInt32 = 12003
DISPID_PRINTEREXTENSION_EVENTARGS_SOURCEAPPLICATION: UInt32 = 12004
DISPID_PRINTEREXTENSION_EVENTARGS_DETAILEDREASONID: UInt32 = 12005
DISPID_PRINTEREXTENSION_EVENTARGS_WINDOWMODAL: UInt32 = 12006
DISPID_PRINTEREXTENSION_EVENTARGS_WINDOWPARENT: UInt32 = 12007
DISPID_PRINTEREXTENSION_CONTEXTCOLLECTION: UInt32 = 12100
DISPID_PRINTEREXTENSION_CONTEXTCOLLECTION_COUNT: UInt32 = 12101
DISPID_PRINTEREXTENSION_CONTEXTCOLLECTION_GETAT: UInt32 = 12102
DISPID_PRINTEREXTENSION_EVENT: UInt32 = 12200
DISPID_PRINTEREXTENSION_EVENT_ONDRIVEREVENT: UInt32 = 12201
DISPID_PRINTEREXTENSION_EVENT_ONPRINTERQUEUESENUMERATED: UInt32 = 12202
DISPID_PRINTERSCRIPTCONTEXT: UInt32 = 12300
DISPID_PRINTERSCRIPTCONTEXT_DRIVERPROPERTIES: UInt32 = 12301
DISPID_PRINTERSCRIPTCONTEXT_QUEUEPROPERTIES: UInt32 = 12302
DISPID_PRINTERSCRIPTCONTEXT_USERPROPERTIES: UInt32 = 12303
DISPID_PRINTSCHEMA_PARAMETERINITIALIZER: UInt32 = 12400
DISPID_PRINTSCHEMA_PARAMETERINITIALIZER_VALUE: UInt32 = 12401
DISPID_PRINTSCHEMA_PARAMETERDEFINITION: UInt32 = 12500
DISPID_PRINTSCHEMA_PARAMETERDEFINITION_USERINPUTREQUIRED: UInt32 = 12501
DISPID_PRINTSCHEMA_PARAMETERDEFINITION_UNITTYPE: UInt32 = 12502
DISPID_PRINTSCHEMA_PARAMETERDEFINITION_DATATYPE: UInt32 = 12503
DISPID_PRINTSCHEMA_PARAMETERDEFINITION_RANGEMIN: UInt32 = 12504
DISPID_PRINTSCHEMA_PARAMETERDEFINITION_RANGEMAX: UInt32 = 12505
DISPID_PRINTJOBCOLLECTION: UInt32 = 12600
DISPID_PRINTJOBCOLLECTION_COUNT: UInt32 = 12601
DISPID_PRINTJOBCOLLECTION_GETAT: UInt32 = 12602
DISPID_PRINTERQUEUEVIEW: UInt32 = 12700
DISPID_PRINTERQUEUEVIEW_SETVIEWRANGE: UInt32 = 12701
DISPID_PRINTERQUEUEVIEW_EVENT: UInt32 = 12800
DISPID_PRINTERQUEUEVIEW_EVENT_ONCHANGED: UInt32 = 12801
NOTIFICATION_RELEASE: Guid = Guid('{ba9a5027-a70e-4ae7-9b7d-eb3e06ad4157}')
PRINT_APP_BIDI_NOTIFY_CHANNEL: Guid = Guid('{2abad223-b994-4aca-82fc-4571b1b585ac}')
PRINT_PORT_MONITOR_NOTIFY_CHANNEL: Guid = Guid('{25df3b0e-74a9-47f5-80ce-79b4b1eb5c58}')
GUID_DEVINTERFACE_USBPRINT: Guid = Guid('{28d78fad-5a12-11d1-ae5b-0000f803a8c2}')
GUID_DEVINTERFACE_IPPUSB_PRINT: Guid = Guid('{f2f40381-f46d-4e51-bce7-62de6cf2d098}')
CLSID_XPSRASTERIZER_FACTORY: Guid = Guid('{503e79bf-1d09-4764-9d72-1eb0c65967c6}')
@winfunctype('COMPSTUI.dll')
def CommonPropertySheetUIA(hWndOwner: win32more.Windows.Win32.Foundation.HWND, pfnPropSheetUI: win32more.Windows.Win32.Graphics.Printing.PFNPROPSHEETUI, lParam: win32more.Windows.Win32.Foundation.LPARAM, pResult: POINTER(UInt32)) -> Int32: ...
@winfunctype('COMPSTUI.dll')
def CommonPropertySheetUIW(hWndOwner: win32more.Windows.Win32.Foundation.HWND, pfnPropSheetUI: win32more.Windows.Win32.Graphics.Printing.PFNPROPSHEETUI, lParam: win32more.Windows.Win32.Foundation.LPARAM, pResult: POINTER(UInt32)) -> Int32: ...
CommonPropertySheetUI = UnicodeAlias('CommonPropertySheetUIW')
@winfunctype('COMPSTUI.dll')
def GetCPSUIUserData(hDlg: win32more.Windows.Win32.Foundation.HWND) -> UIntPtr: ...
@winfunctype('COMPSTUI.dll')
def SetCPSUIUserData(hDlg: win32more.Windows.Win32.Foundation.HWND, CPSUIUserData: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def EnumPrintersA(Flags: UInt32, Name: win32more.Windows.Win32.Foundation.PSTR, Level: UInt32, pPrinterEnum: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32), pcReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def EnumPrintersW(Flags: UInt32, Name: win32more.Windows.Win32.Foundation.PWSTR, Level: UInt32, pPrinterEnum: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32), pcReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumPrinters = UnicodeAlias('EnumPrintersW')
@winfunctype('winspool.drv')
def GetSpoolFileHandle(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('winspool.drv')
def CommitSpoolData(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, hSpoolFile: win32more.Windows.Win32.Foundation.HANDLE, cbCommit: UInt32) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('winspool.drv')
def CloseSpoolFileHandle(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, hSpoolFile: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def OpenPrinterA(pPrinterName: win32more.Windows.Win32.Foundation.PSTR, phPrinter: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE), pDefault: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_DEFAULTSA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def OpenPrinterW(pPrinterName: win32more.Windows.Win32.Foundation.PWSTR, phPrinter: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE), pDefault: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_DEFAULTSW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
OpenPrinter = UnicodeAlias('OpenPrinterW')
@winfunctype('winspool.drv')
def ResetPrinterA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pDefault: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_DEFAULTSA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def ResetPrinterW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pDefault: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_DEFAULTSW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
ResetPrinter = UnicodeAlias('ResetPrinterW')
@winfunctype('winspool.drv')
def SetJobA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, JobId: UInt32, Level: UInt32, pJob: POINTER(Byte), Command: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def SetJobW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, JobId: UInt32, Level: UInt32, pJob: POINTER(Byte), Command: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetJob = UnicodeAlias('SetJobW')
@winfunctype('winspool.drv')
def GetJobA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, JobId: UInt32, Level: UInt32, pJob: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def GetJobW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, JobId: UInt32, Level: UInt32, pJob: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetJob = UnicodeAlias('GetJobW')
@winfunctype('winspool.drv')
def EnumJobsA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, FirstJob: UInt32, NoJobs: UInt32, Level: UInt32, pJob: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32), pcReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def EnumJobsW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, FirstJob: UInt32, NoJobs: UInt32, Level: UInt32, pJob: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32), pcReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumJobs = UnicodeAlias('EnumJobsW')
@winfunctype('winspool.drv')
def AddPrinterA(pName: win32more.Windows.Win32.Foundation.PSTR, Level: UInt32, pPrinter: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('winspool.drv')
def AddPrinterW(pName: win32more.Windows.Win32.Foundation.PWSTR, Level: UInt32, pPrinter: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HANDLE: ...
AddPrinter = UnicodeAlias('AddPrinterW')
@winfunctype('winspool.drv')
def DeletePrinter(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def SetPrinterA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, Level: UInt32, pPrinter: POINTER(Byte), Command: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def SetPrinterW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, Level: UInt32, pPrinter: POINTER(Byte), Command: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetPrinter = UnicodeAlias('SetPrinterW')
@winfunctype('winspool.drv')
def GetPrinterA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, Level: UInt32, pPrinter: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def GetPrinterW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, Level: UInt32, pPrinter: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetPrinter = UnicodeAlias('GetPrinterW')
@winfunctype('winspool.drv')
def AddPrinterDriverA(pName: win32more.Windows.Win32.Foundation.PSTR, Level: UInt32, pDriverInfo: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def AddPrinterDriverW(pName: win32more.Windows.Win32.Foundation.PWSTR, Level: UInt32, pDriverInfo: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
AddPrinterDriver = UnicodeAlias('AddPrinterDriverW')
@winfunctype('winspool.drv')
def AddPrinterDriverExA(pName: win32more.Windows.Win32.Foundation.PSTR, Level: UInt32, lpbDriverInfo: POINTER(Byte), dwFileCopyFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def AddPrinterDriverExW(pName: win32more.Windows.Win32.Foundation.PWSTR, Level: UInt32, lpbDriverInfo: POINTER(Byte), dwFileCopyFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
AddPrinterDriverEx = UnicodeAlias('AddPrinterDriverExW')
@winfunctype('winspool.drv')
def EnumPrinterDriversA(pName: win32more.Windows.Win32.Foundation.PSTR, pEnvironment: win32more.Windows.Win32.Foundation.PSTR, Level: UInt32, pDriverInfo: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32), pcReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def EnumPrinterDriversW(pName: win32more.Windows.Win32.Foundation.PWSTR, pEnvironment: win32more.Windows.Win32.Foundation.PWSTR, Level: UInt32, pDriverInfo: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32), pcReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumPrinterDrivers = UnicodeAlias('EnumPrinterDriversW')
@winfunctype('winspool.drv')
def GetPrinterDriverA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pEnvironment: win32more.Windows.Win32.Foundation.PSTR, Level: UInt32, pDriverInfo: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def GetPrinterDriverW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pEnvironment: win32more.Windows.Win32.Foundation.PWSTR, Level: UInt32, pDriverInfo: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetPrinterDriver = UnicodeAlias('GetPrinterDriverW')
@winfunctype('winspool.drv')
def GetPrinterDriverDirectoryA(pName: win32more.Windows.Win32.Foundation.PSTR, pEnvironment: win32more.Windows.Win32.Foundation.PSTR, Level: UInt32, pDriverDirectory: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def GetPrinterDriverDirectoryW(pName: win32more.Windows.Win32.Foundation.PWSTR, pEnvironment: win32more.Windows.Win32.Foundation.PWSTR, Level: UInt32, pDriverDirectory: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetPrinterDriverDirectory = UnicodeAlias('GetPrinterDriverDirectoryW')
@winfunctype('winspool.drv')
def DeletePrinterDriverA(pName: win32more.Windows.Win32.Foundation.PSTR, pEnvironment: win32more.Windows.Win32.Foundation.PSTR, pDriverName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def DeletePrinterDriverW(pName: win32more.Windows.Win32.Foundation.PWSTR, pEnvironment: win32more.Windows.Win32.Foundation.PWSTR, pDriverName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
DeletePrinterDriver = UnicodeAlias('DeletePrinterDriverW')
@winfunctype('winspool.drv')
def DeletePrinterDriverExA(pName: win32more.Windows.Win32.Foundation.PSTR, pEnvironment: win32more.Windows.Win32.Foundation.PSTR, pDriverName: win32more.Windows.Win32.Foundation.PSTR, dwDeleteFlag: UInt32, dwVersionFlag: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def DeletePrinterDriverExW(pName: win32more.Windows.Win32.Foundation.PWSTR, pEnvironment: win32more.Windows.Win32.Foundation.PWSTR, pDriverName: win32more.Windows.Win32.Foundation.PWSTR, dwDeleteFlag: UInt32, dwVersionFlag: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
DeletePrinterDriverEx = UnicodeAlias('DeletePrinterDriverExW')
@winfunctype('winspool.drv')
def AddPrintProcessorA(pName: win32more.Windows.Win32.Foundation.PSTR, pEnvironment: win32more.Windows.Win32.Foundation.PSTR, pPathName: win32more.Windows.Win32.Foundation.PSTR, pPrintProcessorName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def AddPrintProcessorW(pName: win32more.Windows.Win32.Foundation.PWSTR, pEnvironment: win32more.Windows.Win32.Foundation.PWSTR, pPathName: win32more.Windows.Win32.Foundation.PWSTR, pPrintProcessorName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
AddPrintProcessor = UnicodeAlias('AddPrintProcessorW')
@winfunctype('winspool.drv')
def EnumPrintProcessorsA(pName: win32more.Windows.Win32.Foundation.PSTR, pEnvironment: win32more.Windows.Win32.Foundation.PSTR, Level: UInt32, pPrintProcessorInfo: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32), pcReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def EnumPrintProcessorsW(pName: win32more.Windows.Win32.Foundation.PWSTR, pEnvironment: win32more.Windows.Win32.Foundation.PWSTR, Level: UInt32, pPrintProcessorInfo: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32), pcReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumPrintProcessors = UnicodeAlias('EnumPrintProcessorsW')
@winfunctype('winspool.drv')
def GetPrintProcessorDirectoryA(pName: win32more.Windows.Win32.Foundation.PSTR, pEnvironment: win32more.Windows.Win32.Foundation.PSTR, Level: UInt32, pPrintProcessorInfo: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def GetPrintProcessorDirectoryW(pName: win32more.Windows.Win32.Foundation.PWSTR, pEnvironment: win32more.Windows.Win32.Foundation.PWSTR, Level: UInt32, pPrintProcessorInfo: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetPrintProcessorDirectory = UnicodeAlias('GetPrintProcessorDirectoryW')
@winfunctype('winspool.drv')
def EnumPrintProcessorDatatypesA(pName: win32more.Windows.Win32.Foundation.PSTR, pPrintProcessorName: win32more.Windows.Win32.Foundation.PSTR, Level: UInt32, pDatatypes: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32), pcReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def EnumPrintProcessorDatatypesW(pName: win32more.Windows.Win32.Foundation.PWSTR, pPrintProcessorName: win32more.Windows.Win32.Foundation.PWSTR, Level: UInt32, pDatatypes: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32), pcReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumPrintProcessorDatatypes = UnicodeAlias('EnumPrintProcessorDatatypesW')
@winfunctype('winspool.drv')
def DeletePrintProcessorA(pName: win32more.Windows.Win32.Foundation.PSTR, pEnvironment: win32more.Windows.Win32.Foundation.PSTR, pPrintProcessorName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def DeletePrintProcessorW(pName: win32more.Windows.Win32.Foundation.PWSTR, pEnvironment: win32more.Windows.Win32.Foundation.PWSTR, pPrintProcessorName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
DeletePrintProcessor = UnicodeAlias('DeletePrintProcessorW')
@winfunctype('winspool.drv')
def StartDocPrinterA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, Level: UInt32, pDocInfo: POINTER(win32more.Windows.Win32.Graphics.Printing.DOC_INFO_1A)) -> UInt32: ...
@winfunctype('winspool.drv')
def StartDocPrinterW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, Level: UInt32, pDocInfo: POINTER(win32more.Windows.Win32.Graphics.Printing.DOC_INFO_1W)) -> UInt32: ...
StartDocPrinter = UnicodeAlias('StartDocPrinterW')
@winfunctype('winspool.drv')
def StartPagePrinter(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def WritePrinter(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pBuf: VoidPtr, cbBuf: UInt32, pcWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def FlushPrinter(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pBuf: VoidPtr, cbBuf: UInt32, pcWritten: POINTER(UInt32), cSleep: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def EndPagePrinter(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def AbortPrinter(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def ReadPrinter(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pBuf: VoidPtr, cbBuf: UInt32, pNoBytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def EndDocPrinter(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def AddJobA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, Level: UInt32, pData: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def AddJobW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, Level: UInt32, pData: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
AddJob = UnicodeAlias('AddJobW')
@winfunctype('winspool.drv')
def ScheduleJob(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, JobId: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def PrinterProperties(hWnd: win32more.Windows.Win32.Foundation.HWND, hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def DocumentPropertiesA(hWnd: win32more.Windows.Win32.Foundation.HWND, hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pDeviceName: win32more.Windows.Win32.Foundation.PSTR, pDevModeOutput: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), pDevModeInput: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), fMode: UInt32) -> Int32: ...
@winfunctype('winspool.drv')
def DocumentPropertiesW(hWnd: win32more.Windows.Win32.Foundation.HWND, hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pDeviceName: win32more.Windows.Win32.Foundation.PWSTR, pDevModeOutput: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW), pDevModeInput: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW), fMode: UInt32) -> Int32: ...
DocumentProperties = UnicodeAlias('DocumentPropertiesW')
@winfunctype('winspool.drv')
def AdvancedDocumentPropertiesA(hWnd: win32more.Windows.Win32.Foundation.HWND, hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pDeviceName: win32more.Windows.Win32.Foundation.PSTR, pDevModeOutput: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), pDevModeInput: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)) -> Int32: ...
@winfunctype('winspool.drv')
def AdvancedDocumentPropertiesW(hWnd: win32more.Windows.Win32.Foundation.HWND, hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pDeviceName: win32more.Windows.Win32.Foundation.PWSTR, pDevModeOutput: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW), pDevModeInput: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW)) -> Int32: ...
AdvancedDocumentProperties = UnicodeAlias('AdvancedDocumentPropertiesW')
@winfunctype('winspool.drv')
def ExtDeviceMode(hWnd: win32more.Windows.Win32.Foundation.HWND, hInst: win32more.Windows.Win32.Foundation.HANDLE, pDevModeOutput: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), pDeviceName: win32more.Windows.Win32.Foundation.PSTR, pPort: win32more.Windows.Win32.Foundation.PSTR, pDevModeInput: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), pProfile: win32more.Windows.Win32.Foundation.PSTR, fMode: UInt32) -> Int32: ...
@winfunctype('winspool.drv')
def GetPrinterDataA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pValueName: win32more.Windows.Win32.Foundation.PSTR, pType: POINTER(UInt32), pData: POINTER(Byte), nSize: UInt32, pcbNeeded: POINTER(UInt32)) -> UInt32: ...
@winfunctype('winspool.drv')
def GetPrinterDataW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pValueName: win32more.Windows.Win32.Foundation.PWSTR, pType: POINTER(UInt32), pData: POINTER(Byte), nSize: UInt32, pcbNeeded: POINTER(UInt32)) -> UInt32: ...
GetPrinterData = UnicodeAlias('GetPrinterDataW')
@winfunctype('winspool.drv')
def GetPrinterDataExA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pKeyName: win32more.Windows.Win32.Foundation.PSTR, pValueName: win32more.Windows.Win32.Foundation.PSTR, pType: POINTER(UInt32), pData: POINTER(Byte), nSize: UInt32, pcbNeeded: POINTER(UInt32)) -> UInt32: ...
@winfunctype('winspool.drv')
def GetPrinterDataExW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pKeyName: win32more.Windows.Win32.Foundation.PWSTR, pValueName: win32more.Windows.Win32.Foundation.PWSTR, pType: POINTER(UInt32), pData: POINTER(Byte), nSize: UInt32, pcbNeeded: POINTER(UInt32)) -> UInt32: ...
GetPrinterDataEx = UnicodeAlias('GetPrinterDataExW')
@winfunctype('winspool.drv')
def EnumPrinterDataA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, dwIndex: UInt32, pValueName: win32more.Windows.Win32.Foundation.PSTR, cbValueName: UInt32, pcbValueName: POINTER(UInt32), pType: POINTER(UInt32), pData: POINTER(Byte), cbData: UInt32, pcbData: POINTER(UInt32)) -> UInt32: ...
@winfunctype('winspool.drv')
def EnumPrinterDataW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, dwIndex: UInt32, pValueName: win32more.Windows.Win32.Foundation.PWSTR, cbValueName: UInt32, pcbValueName: POINTER(UInt32), pType: POINTER(UInt32), pData: POINTER(Byte), cbData: UInt32, pcbData: POINTER(UInt32)) -> UInt32: ...
EnumPrinterData = UnicodeAlias('EnumPrinterDataW')
@winfunctype('winspool.drv')
def EnumPrinterDataExA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pKeyName: win32more.Windows.Win32.Foundation.PSTR, pEnumValues: POINTER(Byte), cbEnumValues: UInt32, pcbEnumValues: POINTER(UInt32), pnEnumValues: POINTER(UInt32)) -> UInt32: ...
@winfunctype('winspool.drv')
def EnumPrinterDataExW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pKeyName: win32more.Windows.Win32.Foundation.PWSTR, pEnumValues: POINTER(Byte), cbEnumValues: UInt32, pcbEnumValues: POINTER(UInt32), pnEnumValues: POINTER(UInt32)) -> UInt32: ...
EnumPrinterDataEx = UnicodeAlias('EnumPrinterDataExW')
@winfunctype('winspool.drv')
def EnumPrinterKeyA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pKeyName: win32more.Windows.Win32.Foundation.PSTR, pSubkey: win32more.Windows.Win32.Foundation.PSTR, cbSubkey: UInt32, pcbSubkey: POINTER(UInt32)) -> UInt32: ...
@winfunctype('winspool.drv')
def EnumPrinterKeyW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pKeyName: win32more.Windows.Win32.Foundation.PWSTR, pSubkey: win32more.Windows.Win32.Foundation.PWSTR, cbSubkey: UInt32, pcbSubkey: POINTER(UInt32)) -> UInt32: ...
EnumPrinterKey = UnicodeAlias('EnumPrinterKeyW')
@winfunctype('winspool.drv')
def SetPrinterDataA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pValueName: win32more.Windows.Win32.Foundation.PSTR, Type: UInt32, pData: POINTER(Byte), cbData: UInt32) -> UInt32: ...
@winfunctype('winspool.drv')
def SetPrinterDataW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pValueName: win32more.Windows.Win32.Foundation.PWSTR, Type: UInt32, pData: POINTER(Byte), cbData: UInt32) -> UInt32: ...
SetPrinterData = UnicodeAlias('SetPrinterDataW')
@winfunctype('winspool.drv')
def SetPrinterDataExA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pKeyName: win32more.Windows.Win32.Foundation.PSTR, pValueName: win32more.Windows.Win32.Foundation.PSTR, Type: UInt32, pData: POINTER(Byte), cbData: UInt32) -> UInt32: ...
@winfunctype('winspool.drv')
def SetPrinterDataExW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pKeyName: win32more.Windows.Win32.Foundation.PWSTR, pValueName: win32more.Windows.Win32.Foundation.PWSTR, Type: UInt32, pData: POINTER(Byte), cbData: UInt32) -> UInt32: ...
SetPrinterDataEx = UnicodeAlias('SetPrinterDataExW')
@winfunctype('winspool.drv')
def DeletePrinterDataA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pValueName: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('winspool.drv')
def DeletePrinterDataW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pValueName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
DeletePrinterData = UnicodeAlias('DeletePrinterDataW')
@winfunctype('winspool.drv')
def DeletePrinterDataExA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pKeyName: win32more.Windows.Win32.Foundation.PSTR, pValueName: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('winspool.drv')
def DeletePrinterDataExW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pKeyName: win32more.Windows.Win32.Foundation.PWSTR, pValueName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
DeletePrinterDataEx = UnicodeAlias('DeletePrinterDataExW')
@winfunctype('winspool.drv')
def DeletePrinterKeyA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pKeyName: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('winspool.drv')
def DeletePrinterKeyW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pKeyName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
DeletePrinterKey = UnicodeAlias('DeletePrinterKeyW')
@winfunctype('winspool.drv')
def WaitForPrinterChange(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, Flags: UInt32) -> UInt32: ...
@winfunctype('winspool.drv')
def FindFirstPrinterChangeNotification(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, fdwFilter: UInt32, fdwOptions: UInt32, pPrinterNotifyOptions: VoidPtr) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('winspool.drv')
def FindNextPrinterChangeNotification(hChange: win32more.Windows.Win32.Foundation.HANDLE, pdwChange: POINTER(UInt32), pvReserved: VoidPtr, ppPrinterNotifyInfo: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def FreePrinterNotifyInfo(pPrinterNotifyInfo: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_NOTIFY_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def FindClosePrinterChangeNotification(hChange: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def PrinterMessageBoxA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, Error: UInt32, hWnd: win32more.Windows.Win32.Foundation.HWND, pText: win32more.Windows.Win32.Foundation.PSTR, pCaption: win32more.Windows.Win32.Foundation.PSTR, dwType: UInt32) -> UInt32: ...
@winfunctype('winspool.drv')
def PrinterMessageBoxW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, Error: UInt32, hWnd: win32more.Windows.Win32.Foundation.HWND, pText: win32more.Windows.Win32.Foundation.PWSTR, pCaption: win32more.Windows.Win32.Foundation.PWSTR, dwType: UInt32) -> UInt32: ...
PrinterMessageBox = UnicodeAlias('PrinterMessageBoxW')
@winfunctype('winspool.drv')
def ClosePrinter(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def AddFormA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, Level: UInt32, pForm: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def AddFormW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, Level: UInt32, pForm: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
AddForm = UnicodeAlias('AddFormW')
@winfunctype('winspool.drv')
def DeleteFormA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pFormName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def DeleteFormW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pFormName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
DeleteForm = UnicodeAlias('DeleteFormW')
@winfunctype('winspool.drv')
def GetFormA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pFormName: win32more.Windows.Win32.Foundation.PSTR, Level: UInt32, pForm: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def GetFormW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pFormName: win32more.Windows.Win32.Foundation.PWSTR, Level: UInt32, pForm: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetForm = UnicodeAlias('GetFormW')
@winfunctype('winspool.drv')
def SetFormA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pFormName: win32more.Windows.Win32.Foundation.PSTR, Level: UInt32, pForm: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def SetFormW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pFormName: win32more.Windows.Win32.Foundation.PWSTR, Level: UInt32, pForm: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetForm = UnicodeAlias('SetFormW')
@winfunctype('winspool.drv')
def EnumFormsA(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, Level: UInt32, pForm: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32), pcReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def EnumFormsW(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, Level: UInt32, pForm: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32), pcReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumForms = UnicodeAlias('EnumFormsW')
@winfunctype('winspool.drv')
def EnumMonitorsA(pName: win32more.Windows.Win32.Foundation.PSTR, Level: UInt32, pMonitor: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32), pcReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def EnumMonitorsW(pName: win32more.Windows.Win32.Foundation.PWSTR, Level: UInt32, pMonitor: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32), pcReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumMonitors = UnicodeAlias('EnumMonitorsW')
@winfunctype('winspool.drv')
def AddMonitorA(pName: win32more.Windows.Win32.Foundation.PSTR, Level: UInt32, pMonitors: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def AddMonitorW(pName: win32more.Windows.Win32.Foundation.PWSTR, Level: UInt32, pMonitors: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
AddMonitor = UnicodeAlias('AddMonitorW')
@winfunctype('winspool.drv')
def DeleteMonitorA(pName: win32more.Windows.Win32.Foundation.PSTR, pEnvironment: win32more.Windows.Win32.Foundation.PSTR, pMonitorName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def DeleteMonitorW(pName: win32more.Windows.Win32.Foundation.PWSTR, pEnvironment: win32more.Windows.Win32.Foundation.PWSTR, pMonitorName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
DeleteMonitor = UnicodeAlias('DeleteMonitorW')
@winfunctype('winspool.drv')
def EnumPortsA(pName: win32more.Windows.Win32.Foundation.PSTR, Level: UInt32, pPort: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32), pcReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def EnumPortsW(pName: win32more.Windows.Win32.Foundation.PWSTR, Level: UInt32, pPort: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32), pcReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumPorts = UnicodeAlias('EnumPortsW')
@winfunctype('winspool.drv')
def AddPortA(pName: win32more.Windows.Win32.Foundation.PSTR, hWnd: win32more.Windows.Win32.Foundation.HWND, pMonitorName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def AddPortW(pName: win32more.Windows.Win32.Foundation.PWSTR, hWnd: win32more.Windows.Win32.Foundation.HWND, pMonitorName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
AddPort = UnicodeAlias('AddPortW')
@winfunctype('winspool.drv')
def ConfigurePortA(pName: win32more.Windows.Win32.Foundation.PSTR, hWnd: win32more.Windows.Win32.Foundation.HWND, pPortName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def ConfigurePortW(pName: win32more.Windows.Win32.Foundation.PWSTR, hWnd: win32more.Windows.Win32.Foundation.HWND, pPortName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
ConfigurePort = UnicodeAlias('ConfigurePortW')
@winfunctype('winspool.drv')
def DeletePortA(pName: win32more.Windows.Win32.Foundation.PSTR, hWnd: win32more.Windows.Win32.Foundation.HWND, pPortName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def DeletePortW(pName: win32more.Windows.Win32.Foundation.PWSTR, hWnd: win32more.Windows.Win32.Foundation.HWND, pPortName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
DeletePort = UnicodeAlias('DeletePortW')
@winfunctype('winspool.drv')
def XcvDataW(hXcv: win32more.Windows.Win32.Foundation.HANDLE, pszDataName: win32more.Windows.Win32.Foundation.PWSTR, pInputData: POINTER(Byte), cbInputData: UInt32, pOutputData: POINTER(Byte), cbOutputData: UInt32, pcbOutputNeeded: POINTER(UInt32), pdwStatus: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def GetDefaultPrinterA(pszBuffer: win32more.Windows.Win32.Foundation.PSTR, pcchBuffer: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def GetDefaultPrinterW(pszBuffer: win32more.Windows.Win32.Foundation.PWSTR, pcchBuffer: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetDefaultPrinter = UnicodeAlias('GetDefaultPrinterW')
@winfunctype('winspool.drv')
def SetDefaultPrinterA(pszPrinter: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def SetDefaultPrinterW(pszPrinter: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetDefaultPrinter = UnicodeAlias('SetDefaultPrinterW')
@winfunctype('winspool.drv')
def SetPortA(pName: win32more.Windows.Win32.Foundation.PSTR, pPortName: win32more.Windows.Win32.Foundation.PSTR, dwLevel: UInt32, pPortInfo: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def SetPortW(pName: win32more.Windows.Win32.Foundation.PWSTR, pPortName: win32more.Windows.Win32.Foundation.PWSTR, dwLevel: UInt32, pPortInfo: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetPort = UnicodeAlias('SetPortW')
@winfunctype('winspool.drv')
def AddPrinterConnectionA(pName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def AddPrinterConnectionW(pName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
AddPrinterConnection = UnicodeAlias('AddPrinterConnectionW')
@winfunctype('winspool.drv')
def DeletePrinterConnectionA(pName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def DeletePrinterConnectionW(pName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
DeletePrinterConnection = UnicodeAlias('DeletePrinterConnectionW')
@winfunctype('winspool.drv')
def ConnectToPrinterDlg(hwnd: win32more.Windows.Win32.Foundation.HWND, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('winspool.drv')
def AddPrintProvidorA(pName: win32more.Windows.Win32.Foundation.PSTR, Level: UInt32, pProvidorInfo: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def AddPrintProvidorW(pName: win32more.Windows.Win32.Foundation.PWSTR, Level: UInt32, pProvidorInfo: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
AddPrintProvidor = UnicodeAlias('AddPrintProvidorW')
@winfunctype('winspool.drv')
def DeletePrintProvidorA(pName: win32more.Windows.Win32.Foundation.PSTR, pEnvironment: win32more.Windows.Win32.Foundation.PSTR, pPrintProvidorName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def DeletePrintProvidorW(pName: win32more.Windows.Win32.Foundation.PWSTR, pEnvironment: win32more.Windows.Win32.Foundation.PWSTR, pPrintProvidorName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
DeletePrintProvidor = UnicodeAlias('DeletePrintProvidorW')
@winfunctype('winspool.drv')
def IsValidDevmodeA(pDevmode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), DevmodeSize: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def IsValidDevmodeW(pDevmode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW), DevmodeSize: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
IsValidDevmode = UnicodeAlias('IsValidDevmodeW')
@winfunctype('winspool.drv')
def OpenPrinter2A(pPrinterName: win32more.Windows.Win32.Foundation.PSTR, phPrinter: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE), pDefault: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_DEFAULTSA), pOptions: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_OPTIONSA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def OpenPrinter2W(pPrinterName: win32more.Windows.Win32.Foundation.PWSTR, phPrinter: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE), pDefault: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_DEFAULTSW), pOptions: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_OPTIONSW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
OpenPrinter2 = UnicodeAlias('OpenPrinter2W')
@winfunctype('winspool.drv')
def AddPrinterConnection2A(hWnd: win32more.Windows.Win32.Foundation.HWND, pszName: win32more.Windows.Win32.Foundation.PSTR, dwLevel: UInt32, pConnectionInfo: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def AddPrinterConnection2W(hWnd: win32more.Windows.Win32.Foundation.HWND, pszName: win32more.Windows.Win32.Foundation.PWSTR, dwLevel: UInt32, pConnectionInfo: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
AddPrinterConnection2 = UnicodeAlias('AddPrinterConnection2W')
@winfunctype('winspool.drv')
def InstallPrinterDriverFromPackageA(pszServer: win32more.Windows.Win32.Foundation.PSTR, pszInfPath: win32more.Windows.Win32.Foundation.PSTR, pszDriverName: win32more.Windows.Win32.Foundation.PSTR, pszEnvironment: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('winspool.drv')
def InstallPrinterDriverFromPackageW(pszServer: win32more.Windows.Win32.Foundation.PWSTR, pszInfPath: win32more.Windows.Win32.Foundation.PWSTR, pszDriverName: win32more.Windows.Win32.Foundation.PWSTR, pszEnvironment: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
InstallPrinterDriverFromPackage = UnicodeAlias('InstallPrinterDriverFromPackageW')
@winfunctype('winspool.drv')
def UploadPrinterDriverPackageA(pszServer: win32more.Windows.Win32.Foundation.PSTR, pszInfPath: win32more.Windows.Win32.Foundation.PSTR, pszEnvironment: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32, hwnd: win32more.Windows.Win32.Foundation.HWND, pszDestInfPath: win32more.Windows.Win32.Foundation.PSTR, pcchDestInfPath: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('winspool.drv')
def UploadPrinterDriverPackageW(pszServer: win32more.Windows.Win32.Foundation.PWSTR, pszInfPath: win32more.Windows.Win32.Foundation.PWSTR, pszEnvironment: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, hwnd: win32more.Windows.Win32.Foundation.HWND, pszDestInfPath: win32more.Windows.Win32.Foundation.PWSTR, pcchDestInfPath: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
UploadPrinterDriverPackage = UnicodeAlias('UploadPrinterDriverPackageW')
@winfunctype('winspool.drv')
def GetCorePrinterDriversA(pszServer: win32more.Windows.Win32.Foundation.PSTR, pszEnvironment: win32more.Windows.Win32.Foundation.PSTR, pszzCoreDriverDependencies: win32more.Windows.Win32.Foundation.PSTR, cCorePrinterDrivers: UInt32, pCorePrinterDrivers: POINTER(win32more.Windows.Win32.Graphics.Printing.CORE_PRINTER_DRIVERA)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('winspool.drv')
def GetCorePrinterDriversW(pszServer: win32more.Windows.Win32.Foundation.PWSTR, pszEnvironment: win32more.Windows.Win32.Foundation.PWSTR, pszzCoreDriverDependencies: win32more.Windows.Win32.Foundation.PWSTR, cCorePrinterDrivers: UInt32, pCorePrinterDrivers: POINTER(win32more.Windows.Win32.Graphics.Printing.CORE_PRINTER_DRIVERW)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
GetCorePrinterDrivers = UnicodeAlias('GetCorePrinterDriversW')
@winfunctype('winspool.drv')
def CorePrinterDriverInstalledA(pszServer: win32more.Windows.Win32.Foundation.PSTR, pszEnvironment: win32more.Windows.Win32.Foundation.PSTR, CoreDriverGUID: Guid, ftDriverDate: win32more.Windows.Win32.Foundation.FILETIME, dwlDriverVersion: UInt64, pbDriverInstalled: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('winspool.drv')
def CorePrinterDriverInstalledW(pszServer: win32more.Windows.Win32.Foundation.PWSTR, pszEnvironment: win32more.Windows.Win32.Foundation.PWSTR, CoreDriverGUID: Guid, ftDriverDate: win32more.Windows.Win32.Foundation.FILETIME, dwlDriverVersion: UInt64, pbDriverInstalled: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
CorePrinterDriverInstalled = UnicodeAlias('CorePrinterDriverInstalledW')
@winfunctype('winspool.drv')
def GetPrinterDriverPackagePathA(pszServer: win32more.Windows.Win32.Foundation.PSTR, pszEnvironment: win32more.Windows.Win32.Foundation.PSTR, pszLanguage: win32more.Windows.Win32.Foundation.PSTR, pszPackageID: win32more.Windows.Win32.Foundation.PSTR, pszDriverPackageCab: win32more.Windows.Win32.Foundation.PSTR, cchDriverPackageCab: UInt32, pcchRequiredSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('winspool.drv')
def GetPrinterDriverPackagePathW(pszServer: win32more.Windows.Win32.Foundation.PWSTR, pszEnvironment: win32more.Windows.Win32.Foundation.PWSTR, pszLanguage: win32more.Windows.Win32.Foundation.PWSTR, pszPackageID: win32more.Windows.Win32.Foundation.PWSTR, pszDriverPackageCab: win32more.Windows.Win32.Foundation.PWSTR, cchDriverPackageCab: UInt32, pcchRequiredSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
GetPrinterDriverPackagePath = UnicodeAlias('GetPrinterDriverPackagePathW')
@winfunctype('winspool.drv')
def DeletePrinterDriverPackageA(pszServer: win32more.Windows.Win32.Foundation.PSTR, pszInfPath: win32more.Windows.Win32.Foundation.PSTR, pszEnvironment: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('winspool.drv')
def DeletePrinterDriverPackageW(pszServer: win32more.Windows.Win32.Foundation.PWSTR, pszInfPath: win32more.Windows.Win32.Foundation.PWSTR, pszEnvironment: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
DeletePrinterDriverPackage = UnicodeAlias('DeletePrinterDriverPackageW')
@winfunctype('winspool.drv')
def ReportJobProcessingProgress(printerHandle: win32more.Windows.Win32.Foundation.HANDLE, jobId: UInt32, jobOperation: win32more.Windows.Win32.Graphics.Printing.EPrintXPSJobOperation, jobProgress: win32more.Windows.Win32.Graphics.Printing.EPrintXPSJobProgress) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('winspool.drv')
def GetPrinterDriver2A(hWnd: win32more.Windows.Win32.Foundation.HWND, hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pEnvironment: win32more.Windows.Win32.Foundation.PSTR, Level: UInt32, pDriverInfo: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def GetPrinterDriver2W(hWnd: win32more.Windows.Win32.Foundation.HWND, hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pEnvironment: win32more.Windows.Win32.Foundation.PWSTR, Level: UInt32, pDriverInfo: POINTER(Byte), cbBuf: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetPrinterDriver2 = UnicodeAlias('GetPrinterDriver2W')
@winfunctype('winspool.drv')
def GetPrintExecutionData(pData: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINT_EXECUTION_DATA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def GetJobNamedPropertyValue(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, JobId: UInt32, pszName: win32more.Windows.Win32.Foundation.PWSTR, pValue: POINTER(win32more.Windows.Win32.Graphics.Printing.PrintPropertyValue)) -> UInt32: ...
@winfunctype('winspool.drv')
def FreePrintPropertyValue(pValue: POINTER(win32more.Windows.Win32.Graphics.Printing.PrintPropertyValue)) -> Void: ...
@winfunctype('winspool.drv')
def FreePrintNamedPropertyArray(cProperties: UInt32, ppProperties: POINTER(POINTER(win32more.Windows.Win32.Graphics.Printing.PrintNamedProperty))) -> Void: ...
@winfunctype('winspool.drv')
def SetJobNamedProperty(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, JobId: UInt32, pProperty: POINTER(win32more.Windows.Win32.Graphics.Printing.PrintNamedProperty)) -> UInt32: ...
@winfunctype('winspool.drv')
def DeleteJobNamedProperty(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, JobId: UInt32, pszName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('winspool.drv')
def EnumJobNamedProperties(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, JobId: UInt32, pcProperties: POINTER(UInt32), ppProperties: POINTER(POINTER(win32more.Windows.Win32.Graphics.Printing.PrintNamedProperty))) -> UInt32: ...
@winfunctype('winspool.drv')
def GetPrintOutputInfo(hWnd: win32more.Windows.Win32.Foundation.HWND, pszPrinter: win32more.Windows.Win32.Foundation.PWSTR, phFile: POINTER(win32more.Windows.Win32.Foundation.HANDLE), ppszOutputFile: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('winspool.drv')
def DevQueryPrintEx(pDQPInfo: POINTER(win32more.Windows.Win32.Graphics.Printing.DEVQUERYPRINT_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def RegisterForPrintAsyncNotifications(pszName: win32more.Windows.Win32.Foundation.PWSTR, pNotificationType: POINTER(Guid), eUserFilter: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyUserFilter, eConversationStyle: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyConversationStyle, pCallback: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyCallback, phNotify: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('winspool.drv')
def UnRegisterForPrintAsyncNotifications(param0: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('winspool.drv')
def CreatePrintAsyncNotifyChannel(pszName: win32more.Windows.Win32.Foundation.PWSTR, pNotificationType: POINTER(Guid), eUserFilter: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyUserFilter, eConversationStyle: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyConversationStyle, pCallback: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyCallback, ppIAsynchNotification: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyChannel)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('GDI32.dll')
def GdiGetSpoolFileHandle(pwszPrinterName: win32more.Windows.Win32.Foundation.PWSTR, pDevmode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW), pwszDocName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('GDI32.dll')
def GdiDeleteSpoolFileHandle(SpoolFileHandle: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GdiGetPageCount(SpoolFileHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('GDI32.dll')
def GdiGetDC(SpoolFileHandle: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
@winfunctype('GDI32.dll')
def GdiGetPageHandle(SpoolFileHandle: win32more.Windows.Win32.Foundation.HANDLE, Page: UInt32, pdwPageType: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('GDI32.dll')
def GdiStartDocEMF(SpoolFileHandle: win32more.Windows.Win32.Foundation.HANDLE, pDocInfo: POINTER(win32more.Windows.Win32.Storage.Xps.DOCINFOW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GdiStartPageEMF(SpoolFileHandle: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GdiPlayPageEMF(SpoolFileHandle: win32more.Windows.Win32.Foundation.HANDLE, hemf: win32more.Windows.Win32.Foundation.HANDLE, prectDocument: POINTER(win32more.Windows.Win32.Foundation.RECT), prectBorder: POINTER(win32more.Windows.Win32.Foundation.RECT), prectClip: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GdiEndPageEMF(SpoolFileHandle: win32more.Windows.Win32.Foundation.HANDLE, dwOptimization: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GdiEndDocEMF(SpoolFileHandle: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GdiGetDevmodeForPage(SpoolFileHandle: win32more.Windows.Win32.Foundation.HANDLE, dwPageNumber: UInt32, pCurrDM: POINTER(POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW)), pLastDM: POINTER(POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW))) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('GDI32.dll')
def GdiResetDCEMF(SpoolFileHandle: win32more.Windows.Win32.Foundation.HANDLE, pCurrDM: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SPOOLSS.dll')
def GetJobAttributes(pPrinterName: win32more.Windows.Win32.Foundation.PWSTR, pDevmode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW), pAttributeInfo: POINTER(win32more.Windows.Win32.Graphics.Printing.ATTRIBUTE_INFO_3)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SPOOLSS.dll')
def GetJobAttributesEx(pPrinterName: win32more.Windows.Win32.Foundation.PWSTR, pDevmode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW), dwLevel: UInt32, pAttributeInfo: POINTER(Byte), nSize: UInt32, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def CreatePrinterIC(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW)) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('winspool.drv')
def PlayGdiScriptOnPrinterIC(hPrinterIC: win32more.Windows.Win32.Foundation.HANDLE, pIn: POINTER(Byte), cIn: UInt32, pOut: POINTER(Byte), cOut: UInt32, ul: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def DeletePrinterIC(hPrinterIC: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('winspool.drv')
def DevQueryPrint(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), pResID: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SPOOLSS.dll')
def RevertToPrinterSelf() -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('SPOOLSS.dll')
def ImpersonatePrinterClient(hToken: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SPOOLSS.dll')
def ReplyPrinterChangeNotification(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, fdwChangeFlags: UInt32, pdwResult: POINTER(UInt32), pPrinterNotifyInfo: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SPOOLSS.dll')
def ReplyPrinterChangeNotificationEx(hNotify: win32more.Windows.Win32.Foundation.HANDLE, dwColor: UInt32, fdwFlags: UInt32, pdwResult: POINTER(UInt32), pPrinterNotifyInfo: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SPOOLSS.dll')
def PartialReplyPrinterChangeNotification(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pDataSrc: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_NOTIFY_INFO_DATA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SPOOLSS.dll')
def RouterAllocPrinterNotifyInfo(cPrinterNotifyInfoData: UInt32) -> POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_NOTIFY_INFO): ...
@winfunctype('SPOOLSS.dll')
def RouterFreePrinterNotifyInfo(pInfo: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_NOTIFY_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SPOOLSS.dll')
def RouterAllocBidiResponseContainer(Count: UInt32) -> POINTER(win32more.Windows.Win32.Graphics.Printing.BIDI_RESPONSE_CONTAINER): ...
@winfunctype('SPOOLSS.dll')
def RouterAllocBidiMem(NumBytes: UIntPtr) -> VoidPtr: ...
@winfunctype('winspool.drv')
def RouterFreeBidiResponseContainer(pData: POINTER(win32more.Windows.Win32.Graphics.Printing.BIDI_RESPONSE_CONTAINER)) -> UInt32: ...
@winfunctype('SPOOLSS.dll')
def RouterFreeBidiMem(pMemPointer: VoidPtr) -> Void: ...
@winfunctype('SPOOLSS.dll')
def AppendPrinterNotifyInfoData(pInfoDest: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_NOTIFY_INFO), pDataSrc: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_NOTIFY_INFO_DATA), fdwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SPOOLSS.dll')
def CallRouterFindFirstPrinterChangeNotification(hPrinterRPC: win32more.Windows.Win32.Foundation.HANDLE, fdwFilterFlags: UInt32, fdwOptions: UInt32, hNotify: win32more.Windows.Win32.Foundation.HANDLE, pPrinterNotifyOptions: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_NOTIFY_OPTIONS)) -> UInt32: ...
@winfunctype('SPOOLSS.dll')
def ProvidorFindFirstPrinterChangeNotification(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, fdwFlags: UInt32, fdwOptions: UInt32, hNotify: win32more.Windows.Win32.Foundation.HANDLE, pPrinterNotifyOptions: VoidPtr, pvReserved1: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SPOOLSS.dll')
def ProvidorFindClosePrinterChangeNotification(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SPOOLSS.dll')
def SpoolerFindFirstPrinterChangeNotification(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, fdwFilterFlags: UInt32, fdwOptions: UInt32, pPrinterNotifyOptions: VoidPtr, pvReserved: VoidPtr, pNotificationConfig: VoidPtr, phNotify: POINTER(win32more.Windows.Win32.Foundation.HANDLE), phEvent: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SPOOLSS.dll')
def SpoolerFindNextPrinterChangeNotification(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pfdwChange: POINTER(UInt32), pPrinterNotifyOptions: VoidPtr, ppPrinterNotifyInfo: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SPOOLSS.dll')
def SpoolerRefreshPrinterChangeNotification(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, dwColor: UInt32, pOptions: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_NOTIFY_OPTIONS), ppInfo: POINTER(POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_NOTIFY_INFO))) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SPOOLSS.dll')
def SpoolerFreePrinterNotifyInfo(pInfo: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_NOTIFY_INFO)) -> Void: ...
@winfunctype('SPOOLSS.dll')
def SpoolerFindClosePrinterChangeNotification(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mscms.dll')
def SpoolerCopyFileEvent(pszPrinterName: win32more.Windows.Win32.Foundation.PWSTR, pszKey: win32more.Windows.Win32.Foundation.PWSTR, dwCopyFileEvent: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mscms.dll')
def GenerateCopyFilePaths(pszPrinterName: win32more.Windows.Win32.Foundation.PWSTR, pszDirectory: win32more.Windows.Win32.Foundation.PWSTR, pSplClientInfo: POINTER(Byte), dwLevel: UInt32, pszSourceDir: win32more.Windows.Win32.Foundation.PWSTR, pcchSourceDirSize: POINTER(UInt32), pszTargetDir: win32more.Windows.Win32.Foundation.PWSTR, pcchTargetDirSize: POINTER(UInt32), dwFlags: UInt32) -> UInt32: ...
@winfunctype('SPOOLSS.dll')
def SplPromptUIInUsersSession(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, JobId: UInt32, pUIParams: POINTER(win32more.Windows.Win32.Graphics.Printing.SHOWUIPARAMS), pResponse: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SPOOLSS.dll')
def SplIsSessionZero(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, JobId: UInt32, pIsSessionZero: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> UInt32: ...
@winfunctype('SPOOLSS.dll')
def AddPrintDeviceObject(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, phDeviceObject: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SPOOLSS.dll')
def UpdatePrintDeviceObject(hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, hDeviceObject: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SPOOLSS.dll')
def RemovePrintDeviceObject(hDeviceObject: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class BIDI_DATA(Structure):
    dwBidiType: UInt32
    u: _u_e__Union
    class _u_e__Union(Union):
        bData: win32more.Windows.Win32.Foundation.BOOL
        iData: Int32
        sData: win32more.Windows.Win32.Foundation.PWSTR
        fData: Single
        biData: win32more.Windows.Win32.Graphics.Printing.BINARY_CONTAINER
class BIDI_REQUEST_CONTAINER(Structure):
    Version: UInt32
    Flags: UInt32
    Count: UInt32
    aData: win32more.Windows.Win32.Graphics.Printing.BIDI_REQUEST_DATA * 1
class BIDI_REQUEST_DATA(Structure):
    dwReqNumber: UInt32
    pSchema: win32more.Windows.Win32.Foundation.PWSTR
    data: win32more.Windows.Win32.Graphics.Printing.BIDI_DATA
class BIDI_RESPONSE_CONTAINER(Structure):
    Version: UInt32
    Flags: UInt32
    Count: UInt32
    aData: win32more.Windows.Win32.Graphics.Printing.BIDI_RESPONSE_DATA * 1
class BIDI_RESPONSE_DATA(Structure):
    dwResult: UInt32
    dwReqNumber: UInt32
    pSchema: win32more.Windows.Win32.Foundation.PWSTR
    data: win32more.Windows.Win32.Graphics.Printing.BIDI_DATA
BIDI_TYPE = Int32
BIDI_NULL: win32more.Windows.Win32.Graphics.Printing.BIDI_TYPE = 0
BIDI_INT: win32more.Windows.Win32.Graphics.Printing.BIDI_TYPE = 1
BIDI_FLOAT: win32more.Windows.Win32.Graphics.Printing.BIDI_TYPE = 2
BIDI_BOOL: win32more.Windows.Win32.Graphics.Printing.BIDI_TYPE = 3
BIDI_STRING: win32more.Windows.Win32.Graphics.Printing.BIDI_TYPE = 4
BIDI_TEXT: win32more.Windows.Win32.Graphics.Printing.BIDI_TYPE = 5
BIDI_ENUM: win32more.Windows.Win32.Graphics.Printing.BIDI_TYPE = 6
BIDI_BLOB: win32more.Windows.Win32.Graphics.Printing.BIDI_TYPE = 7
class BINARY_CONTAINER(Structure):
    cbBuf: UInt32
    pData: POINTER(Byte)
BidiRequest = Guid('{b9162a23-45f9-47cc-80f5-fe0fe9b9e1a2}')
BidiRequestContainer = Guid('{fc5b8a24-db05-4a01-8388-22edf6c2bbba}')
BidiSpl = Guid('{2a614240-a4c5-4c33-bd87-1bc709331639}')
class BranchOfficeJobData(Structure):
    eEventType: win32more.Windows.Win32.Graphics.Printing.EBranchOfficeJobEventType
    JobId: UInt32
    JobInfo: _JobInfo_e__Union
    class _JobInfo_e__Union(Union):
        LogJobPrinted: win32more.Windows.Win32.Graphics.Printing.BranchOfficeJobDataPrinted
        LogJobRendered: win32more.Windows.Win32.Graphics.Printing.BranchOfficeJobDataRendered
        LogJobError: win32more.Windows.Win32.Graphics.Printing.BranchOfficeJobDataError
        LogPipelineFailed: win32more.Windows.Win32.Graphics.Printing.BranchOfficeJobDataPipelineFailed
        LogOfflineFileFull: win32more.Windows.Win32.Graphics.Printing.BranchOfficeLogOfflineFileFull
class BranchOfficeJobDataContainer(Structure):
    cJobDataEntries: UInt32
    JobData: win32more.Windows.Win32.Graphics.Printing.BranchOfficeJobData * 1
class BranchOfficeJobDataError(Structure):
    LastError: UInt32
    pDocumentName: win32more.Windows.Win32.Foundation.PWSTR
    pUserName: win32more.Windows.Win32.Foundation.PWSTR
    pPrinterName: win32more.Windows.Win32.Foundation.PWSTR
    pDataType: win32more.Windows.Win32.Foundation.PWSTR
    TotalSize: Int64
    PrintedSize: Int64
    TotalPages: UInt32
    PrintedPages: UInt32
    pMachineName: win32more.Windows.Win32.Foundation.PWSTR
    pJobError: win32more.Windows.Win32.Foundation.PWSTR
    pErrorDescription: win32more.Windows.Win32.Foundation.PWSTR
class BranchOfficeJobDataPipelineFailed(Structure):
    pDocumentName: win32more.Windows.Win32.Foundation.PWSTR
    pPrinterName: win32more.Windows.Win32.Foundation.PWSTR
    pExtraErrorInfo: win32more.Windows.Win32.Foundation.PWSTR
class BranchOfficeJobDataPrinted(Structure):
    Status: UInt32
    pDocumentName: win32more.Windows.Win32.Foundation.PWSTR
    pUserName: win32more.Windows.Win32.Foundation.PWSTR
    pMachineName: win32more.Windows.Win32.Foundation.PWSTR
    pPrinterName: win32more.Windows.Win32.Foundation.PWSTR
    pPortName: win32more.Windows.Win32.Foundation.PWSTR
    Size: Int64
    TotalPages: UInt32
class BranchOfficeJobDataRendered(Structure):
    Size: Int64
    ICMMethod: UInt32
    Color: Int16
    PrintQuality: Int16
    YResolution: Int16
    Copies: Int16
    TTOption: Int16
class BranchOfficeLogOfflineFileFull(Structure):
    pMachineName: win32more.Windows.Win32.Foundation.PWSTR
class COMPROPSHEETUI(Structure):
    cbSize: UInt16
    Flags: UInt16
    hInstCaller: win32more.Windows.Win32.Foundation.HINSTANCE
    pCallerName: POINTER(SByte)
    UserData: UIntPtr
    pHelpFile: POINTER(SByte)
    pfnCallBack: win32more.Windows.Win32.Graphics.Printing._CPSUICALLBACK
    pOptItem: POINTER(win32more.Windows.Win32.Graphics.Printing.OPTITEM)
    pDlgPage: POINTER(win32more.Windows.Win32.Graphics.Printing.DLGPAGE)
    cOptItem: UInt16
    cDlgPage: UInt16
    IconID: UIntPtr
    pOptItemName: POINTER(SByte)
    CallerVersion: UInt16
    OptItemVersion: UInt16
    dwReserved: UIntPtr * 4
class CONFIG_INFO_DATA_1(Structure):
    Reserved: Byte * 128
    dwVersion: UInt32
class CORE_PRINTER_DRIVERA(Structure):
    CoreDriverGUID: Guid
    ftDriverDate: win32more.Windows.Win32.Foundation.FILETIME
    dwlDriverVersion: UInt64
    szPackageID: win32more.Windows.Win32.Foundation.CHAR * 260
class CORE_PRINTER_DRIVERW(Structure):
    CoreDriverGUID: Guid
    ftDriverDate: win32more.Windows.Win32.Foundation.FILETIME
    dwlDriverVersion: UInt64
    szPackageID: Char * 260
CORE_PRINTER_DRIVER = UnicodeAlias('CORE_PRINTER_DRIVERW')
class CPSUICBPARAM(Structure):
    cbSize: UInt16
    Reason: UInt16
    hDlg: win32more.Windows.Win32.Foundation.HWND
    pOptItem: POINTER(win32more.Windows.Win32.Graphics.Printing.OPTITEM)
    cOptItem: UInt16
    Flags: UInt16
    pCurItem: POINTER(win32more.Windows.Win32.Graphics.Printing.OPTITEM)
    Anonymous: _Anonymous_e__Union
    UserData: UIntPtr
    Result: UIntPtr
    class _Anonymous_e__Union(Union):
        OldSel: Int32
        pOldSel: POINTER(SByte)
class CPSUIDATABLOCK(Structure):
    cbData: UInt32
    pbData: POINTER(Byte)
class CUSTOMSIZEPARAM(Structure):
    dwOrder: Int32
    lMinVal: Int32
    lMaxVal: Int32
class DATATYPES_INFO_1A(Structure):
    pName: win32more.Windows.Win32.Foundation.PSTR
class DATATYPES_INFO_1W(Structure):
    pName: win32more.Windows.Win32.Foundation.PWSTR
DATATYPES_INFO_1 = UnicodeAlias('DATATYPES_INFO_1W')
class DATA_HEADER(Structure):
    dwSignature: UInt32
    wSize: UInt16
    wDataID: UInt16
    dwDataSize: UInt32
    dwReserved: UInt32
class DELETE_PORT_DATA_1(Structure):
    psztPortName: Char * 64
    Reserved: Byte * 98
    dwVersion: UInt32
    dwReserved: UInt32
class DEVICEPROPERTYHEADER(Structure):
    cbSize: UInt16
    Flags: UInt16
    hPrinter: win32more.Windows.Win32.Foundation.HANDLE
    pszPrinterName: POINTER(SByte)
class DEVQUERYPRINT_INFO(Structure):
    cbSize: UInt16
    Level: UInt16
    hPrinter: win32more.Windows.Win32.Foundation.HANDLE
    pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)
    pszErrorStr: win32more.Windows.Win32.Foundation.PWSTR
    cchErrorStr: UInt32
    cchNeeded: UInt32
class DLGPAGE(Structure):
    cbSize: UInt16
    Flags: UInt16
    DlgProc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC
    pTabName: POINTER(SByte)
    IconID: UIntPtr
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        DlgTemplateID: UInt16
        hDlgTemplate: win32more.Windows.Win32.Foundation.HANDLE
class DOCEVENT_CREATEDCPRE(Structure):
    pszDriver: win32more.Windows.Win32.Foundation.PWSTR
    pszDevice: win32more.Windows.Win32.Foundation.PWSTR
    pdm: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW)
    bIC: win32more.Windows.Win32.Foundation.BOOL
class DOCEVENT_ESCAPE(Structure):
    iEscape: Int32
    cjInput: Int32
    pvInData: VoidPtr
class DOCEVENT_FILTER(Structure):
    cbSize: UInt32
    cElementsAllocated: UInt32
    cElementsNeeded: UInt32
    cElementsReturned: UInt32
    aDocEventCall: UInt32 * 1
class DOCUMENTPROPERTYHEADER(Structure):
    cbSize: UInt16
    Reserved: UInt16
    hPrinter: win32more.Windows.Win32.Foundation.HANDLE
    pszPrinterName: POINTER(SByte)
    pdmIn: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)
    pdmOut: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)
    cbOut: UInt32
    fMode: UInt32
class DOC_INFO_1A(Structure):
    pDocName: win32more.Windows.Win32.Foundation.PSTR
    pOutputFile: win32more.Windows.Win32.Foundation.PSTR
    pDatatype: win32more.Windows.Win32.Foundation.PSTR
class DOC_INFO_1W(Structure):
    pDocName: win32more.Windows.Win32.Foundation.PWSTR
    pOutputFile: win32more.Windows.Win32.Foundation.PWSTR
    pDatatype: win32more.Windows.Win32.Foundation.PWSTR
DOC_INFO_1 = UnicodeAlias('DOC_INFO_1W')
class DOC_INFO_2A(Structure):
    pDocName: win32more.Windows.Win32.Foundation.PSTR
    pOutputFile: win32more.Windows.Win32.Foundation.PSTR
    pDatatype: win32more.Windows.Win32.Foundation.PSTR
    dwMode: UInt32
    JobId: UInt32
class DOC_INFO_2W(Structure):
    pDocName: win32more.Windows.Win32.Foundation.PWSTR
    pOutputFile: win32more.Windows.Win32.Foundation.PWSTR
    pDatatype: win32more.Windows.Win32.Foundation.PWSTR
    dwMode: UInt32
    JobId: UInt32
DOC_INFO_2 = UnicodeAlias('DOC_INFO_2W')
class DOC_INFO_3A(Structure):
    pDocName: win32more.Windows.Win32.Foundation.PSTR
    pOutputFile: win32more.Windows.Win32.Foundation.PSTR
    pDatatype: win32more.Windows.Win32.Foundation.PSTR
    dwFlags: UInt32
class DOC_INFO_3W(Structure):
    pDocName: win32more.Windows.Win32.Foundation.PWSTR
    pOutputFile: win32more.Windows.Win32.Foundation.PWSTR
    pDatatype: win32more.Windows.Win32.Foundation.PWSTR
    dwFlags: UInt32
DOC_INFO_3 = UnicodeAlias('DOC_INFO_3W')
class DOC_INFO_INTERNAL(Structure):
    pDocName: POINTER(SByte)
    pOutputFile: POINTER(SByte)
    pDatatype: POINTER(SByte)
    bLowILJob: win32more.Windows.Win32.Foundation.BOOL
    hTokenLowIL: win32more.Windows.Win32.Foundation.HANDLE
class DRIVER_INFO_1A(Structure):
    pName: win32more.Windows.Win32.Foundation.PSTR
class DRIVER_INFO_1W(Structure):
    pName: win32more.Windows.Win32.Foundation.PWSTR
DRIVER_INFO_1 = UnicodeAlias('DRIVER_INFO_1W')
class DRIVER_INFO_2A(Structure):
    cVersion: UInt32
    pName: win32more.Windows.Win32.Foundation.PSTR
    pEnvironment: win32more.Windows.Win32.Foundation.PSTR
    pDriverPath: win32more.Windows.Win32.Foundation.PSTR
    pDataFile: win32more.Windows.Win32.Foundation.PSTR
    pConfigFile: win32more.Windows.Win32.Foundation.PSTR
class DRIVER_INFO_2W(Structure):
    cVersion: UInt32
    pName: win32more.Windows.Win32.Foundation.PWSTR
    pEnvironment: win32more.Windows.Win32.Foundation.PWSTR
    pDriverPath: win32more.Windows.Win32.Foundation.PWSTR
    pDataFile: win32more.Windows.Win32.Foundation.PWSTR
    pConfigFile: win32more.Windows.Win32.Foundation.PWSTR
DRIVER_INFO_2 = UnicodeAlias('DRIVER_INFO_2W')
class DRIVER_INFO_3A(Structure):
    cVersion: UInt32
    pName: win32more.Windows.Win32.Foundation.PSTR
    pEnvironment: win32more.Windows.Win32.Foundation.PSTR
    pDriverPath: win32more.Windows.Win32.Foundation.PSTR
    pDataFile: win32more.Windows.Win32.Foundation.PSTR
    pConfigFile: win32more.Windows.Win32.Foundation.PSTR
    pHelpFile: win32more.Windows.Win32.Foundation.PSTR
    pDependentFiles: win32more.Windows.Win32.Foundation.PSTR
    pMonitorName: win32more.Windows.Win32.Foundation.PSTR
    pDefaultDataType: win32more.Windows.Win32.Foundation.PSTR
class DRIVER_INFO_3W(Structure):
    cVersion: UInt32
    pName: win32more.Windows.Win32.Foundation.PWSTR
    pEnvironment: win32more.Windows.Win32.Foundation.PWSTR
    pDriverPath: win32more.Windows.Win32.Foundation.PWSTR
    pDataFile: win32more.Windows.Win32.Foundation.PWSTR
    pConfigFile: win32more.Windows.Win32.Foundation.PWSTR
    pHelpFile: win32more.Windows.Win32.Foundation.PWSTR
    pDependentFiles: win32more.Windows.Win32.Foundation.PWSTR
    pMonitorName: win32more.Windows.Win32.Foundation.PWSTR
    pDefaultDataType: win32more.Windows.Win32.Foundation.PWSTR
DRIVER_INFO_3 = UnicodeAlias('DRIVER_INFO_3W')
class DRIVER_INFO_4A(Structure):
    cVersion: UInt32
    pName: win32more.Windows.Win32.Foundation.PSTR
    pEnvironment: win32more.Windows.Win32.Foundation.PSTR
    pDriverPath: win32more.Windows.Win32.Foundation.PSTR
    pDataFile: win32more.Windows.Win32.Foundation.PSTR
    pConfigFile: win32more.Windows.Win32.Foundation.PSTR
    pHelpFile: win32more.Windows.Win32.Foundation.PSTR
    pDependentFiles: win32more.Windows.Win32.Foundation.PSTR
    pMonitorName: win32more.Windows.Win32.Foundation.PSTR
    pDefaultDataType: win32more.Windows.Win32.Foundation.PSTR
    pszzPreviousNames: win32more.Windows.Win32.Foundation.PSTR
class DRIVER_INFO_4W(Structure):
    cVersion: UInt32
    pName: win32more.Windows.Win32.Foundation.PWSTR
    pEnvironment: win32more.Windows.Win32.Foundation.PWSTR
    pDriverPath: win32more.Windows.Win32.Foundation.PWSTR
    pDataFile: win32more.Windows.Win32.Foundation.PWSTR
    pConfigFile: win32more.Windows.Win32.Foundation.PWSTR
    pHelpFile: win32more.Windows.Win32.Foundation.PWSTR
    pDependentFiles: win32more.Windows.Win32.Foundation.PWSTR
    pMonitorName: win32more.Windows.Win32.Foundation.PWSTR
    pDefaultDataType: win32more.Windows.Win32.Foundation.PWSTR
    pszzPreviousNames: win32more.Windows.Win32.Foundation.PWSTR
DRIVER_INFO_4 = UnicodeAlias('DRIVER_INFO_4W')
class DRIVER_INFO_5A(Structure):
    cVersion: UInt32
    pName: win32more.Windows.Win32.Foundation.PSTR
    pEnvironment: win32more.Windows.Win32.Foundation.PSTR
    pDriverPath: win32more.Windows.Win32.Foundation.PSTR
    pDataFile: win32more.Windows.Win32.Foundation.PSTR
    pConfigFile: win32more.Windows.Win32.Foundation.PSTR
    dwDriverAttributes: UInt32
    dwConfigVersion: UInt32
    dwDriverVersion: UInt32
class DRIVER_INFO_5W(Structure):
    cVersion: UInt32
    pName: win32more.Windows.Win32.Foundation.PWSTR
    pEnvironment: win32more.Windows.Win32.Foundation.PWSTR
    pDriverPath: win32more.Windows.Win32.Foundation.PWSTR
    pDataFile: win32more.Windows.Win32.Foundation.PWSTR
    pConfigFile: win32more.Windows.Win32.Foundation.PWSTR
    dwDriverAttributes: UInt32
    dwConfigVersion: UInt32
    dwDriverVersion: UInt32
DRIVER_INFO_5 = UnicodeAlias('DRIVER_INFO_5W')
class DRIVER_INFO_6A(Structure):
    cVersion: UInt32
    pName: win32more.Windows.Win32.Foundation.PSTR
    pEnvironment: win32more.Windows.Win32.Foundation.PSTR
    pDriverPath: win32more.Windows.Win32.Foundation.PSTR
    pDataFile: win32more.Windows.Win32.Foundation.PSTR
    pConfigFile: win32more.Windows.Win32.Foundation.PSTR
    pHelpFile: win32more.Windows.Win32.Foundation.PSTR
    pDependentFiles: win32more.Windows.Win32.Foundation.PSTR
    pMonitorName: win32more.Windows.Win32.Foundation.PSTR
    pDefaultDataType: win32more.Windows.Win32.Foundation.PSTR
    pszzPreviousNames: win32more.Windows.Win32.Foundation.PSTR
    ftDriverDate: win32more.Windows.Win32.Foundation.FILETIME
    dwlDriverVersion: UInt64
    pszMfgName: win32more.Windows.Win32.Foundation.PSTR
    pszOEMUrl: win32more.Windows.Win32.Foundation.PSTR
    pszHardwareID: win32more.Windows.Win32.Foundation.PSTR
    pszProvider: win32more.Windows.Win32.Foundation.PSTR
class DRIVER_INFO_6W(Structure):
    cVersion: UInt32
    pName: win32more.Windows.Win32.Foundation.PWSTR
    pEnvironment: win32more.Windows.Win32.Foundation.PWSTR
    pDriverPath: win32more.Windows.Win32.Foundation.PWSTR
    pDataFile: win32more.Windows.Win32.Foundation.PWSTR
    pConfigFile: win32more.Windows.Win32.Foundation.PWSTR
    pHelpFile: win32more.Windows.Win32.Foundation.PWSTR
    pDependentFiles: win32more.Windows.Win32.Foundation.PWSTR
    pMonitorName: win32more.Windows.Win32.Foundation.PWSTR
    pDefaultDataType: win32more.Windows.Win32.Foundation.PWSTR
    pszzPreviousNames: win32more.Windows.Win32.Foundation.PWSTR
    ftDriverDate: win32more.Windows.Win32.Foundation.FILETIME
    dwlDriverVersion: UInt64
    pszMfgName: win32more.Windows.Win32.Foundation.PWSTR
    pszOEMUrl: win32more.Windows.Win32.Foundation.PWSTR
    pszHardwareID: win32more.Windows.Win32.Foundation.PWSTR
    pszProvider: win32more.Windows.Win32.Foundation.PWSTR
DRIVER_INFO_6 = UnicodeAlias('DRIVER_INFO_6W')
class DRIVER_INFO_8A(Structure):
    cVersion: UInt32
    pName: win32more.Windows.Win32.Foundation.PSTR
    pEnvironment: win32more.Windows.Win32.Foundation.PSTR
    pDriverPath: win32more.Windows.Win32.Foundation.PSTR
    pDataFile: win32more.Windows.Win32.Foundation.PSTR
    pConfigFile: win32more.Windows.Win32.Foundation.PSTR
    pHelpFile: win32more.Windows.Win32.Foundation.PSTR
    pDependentFiles: win32more.Windows.Win32.Foundation.PSTR
    pMonitorName: win32more.Windows.Win32.Foundation.PSTR
    pDefaultDataType: win32more.Windows.Win32.Foundation.PSTR
    pszzPreviousNames: win32more.Windows.Win32.Foundation.PSTR
    ftDriverDate: win32more.Windows.Win32.Foundation.FILETIME
    dwlDriverVersion: UInt64
    pszMfgName: win32more.Windows.Win32.Foundation.PSTR
    pszOEMUrl: win32more.Windows.Win32.Foundation.PSTR
    pszHardwareID: win32more.Windows.Win32.Foundation.PSTR
    pszProvider: win32more.Windows.Win32.Foundation.PSTR
    pszPrintProcessor: win32more.Windows.Win32.Foundation.PSTR
    pszVendorSetup: win32more.Windows.Win32.Foundation.PSTR
    pszzColorProfiles: win32more.Windows.Win32.Foundation.PSTR
    pszInfPath: win32more.Windows.Win32.Foundation.PSTR
    dwPrinterDriverAttributes: UInt32
    pszzCoreDriverDependencies: win32more.Windows.Win32.Foundation.PSTR
    ftMinInboxDriverVerDate: win32more.Windows.Win32.Foundation.FILETIME
    dwlMinInboxDriverVerVersion: UInt64
class DRIVER_INFO_8W(Structure):
    cVersion: UInt32
    pName: win32more.Windows.Win32.Foundation.PWSTR
    pEnvironment: win32more.Windows.Win32.Foundation.PWSTR
    pDriverPath: win32more.Windows.Win32.Foundation.PWSTR
    pDataFile: win32more.Windows.Win32.Foundation.PWSTR
    pConfigFile: win32more.Windows.Win32.Foundation.PWSTR
    pHelpFile: win32more.Windows.Win32.Foundation.PWSTR
    pDependentFiles: win32more.Windows.Win32.Foundation.PWSTR
    pMonitorName: win32more.Windows.Win32.Foundation.PWSTR
    pDefaultDataType: win32more.Windows.Win32.Foundation.PWSTR
    pszzPreviousNames: win32more.Windows.Win32.Foundation.PWSTR
    ftDriverDate: win32more.Windows.Win32.Foundation.FILETIME
    dwlDriverVersion: UInt64
    pszMfgName: win32more.Windows.Win32.Foundation.PWSTR
    pszOEMUrl: win32more.Windows.Win32.Foundation.PWSTR
    pszHardwareID: win32more.Windows.Win32.Foundation.PWSTR
    pszProvider: win32more.Windows.Win32.Foundation.PWSTR
    pszPrintProcessor: win32more.Windows.Win32.Foundation.PWSTR
    pszVendorSetup: win32more.Windows.Win32.Foundation.PWSTR
    pszzColorProfiles: win32more.Windows.Win32.Foundation.PWSTR
    pszInfPath: win32more.Windows.Win32.Foundation.PWSTR
    dwPrinterDriverAttributes: UInt32
    pszzCoreDriverDependencies: win32more.Windows.Win32.Foundation.PWSTR
    ftMinInboxDriverVerDate: win32more.Windows.Win32.Foundation.FILETIME
    dwlMinInboxDriverVerVersion: UInt64
DRIVER_INFO_8 = UnicodeAlias('DRIVER_INFO_8W')
class DRIVER_UPGRADE_INFO_1(Structure):
    pPrinterName: POINTER(SByte)
    pOldDriverDirectory: POINTER(SByte)
class DRIVER_UPGRADE_INFO_2(Structure):
    pPrinterName: POINTER(SByte)
    pOldDriverDirectory: POINTER(SByte)
    cVersion: UInt32
    pName: POINTER(SByte)
    pEnvironment: POINTER(SByte)
    pDriverPath: POINTER(SByte)
    pDataFile: POINTER(SByte)
    pConfigFile: POINTER(SByte)
    pHelpFile: POINTER(SByte)
    pDependentFiles: POINTER(SByte)
    pMonitorName: POINTER(SByte)
    pDefaultDataType: POINTER(SByte)
    pszzPreviousNames: POINTER(SByte)
EATTRIBUTE_DATATYPE = Int32
kADT_UNKNOWN: win32more.Windows.Win32.Graphics.Printing.EATTRIBUTE_DATATYPE = 0
kADT_BOOL: win32more.Windows.Win32.Graphics.Printing.EATTRIBUTE_DATATYPE = 1
kADT_INT: win32more.Windows.Win32.Graphics.Printing.EATTRIBUTE_DATATYPE = 2
kADT_LONG: win32more.Windows.Win32.Graphics.Printing.EATTRIBUTE_DATATYPE = 3
kADT_DWORD: win32more.Windows.Win32.Graphics.Printing.EATTRIBUTE_DATATYPE = 4
kADT_ASCII: win32more.Windows.Win32.Graphics.Printing.EATTRIBUTE_DATATYPE = 5
kADT_UNICODE: win32more.Windows.Win32.Graphics.Printing.EATTRIBUTE_DATATYPE = 6
kADT_BINARY: win32more.Windows.Win32.Graphics.Printing.EATTRIBUTE_DATATYPE = 7
kADT_SIZE: win32more.Windows.Win32.Graphics.Printing.EATTRIBUTE_DATATYPE = 8
kADT_RECT: win32more.Windows.Win32.Graphics.Printing.EATTRIBUTE_DATATYPE = 9
kADT_CUSTOMSIZEPARAMS: win32more.Windows.Win32.Graphics.Printing.EATTRIBUTE_DATATYPE = 10
EBranchOfficeJobEventType = Int32
kInvalidJobState: win32more.Windows.Win32.Graphics.Printing.EBranchOfficeJobEventType = 0
kLogJobPrinted: win32more.Windows.Win32.Graphics.Printing.EBranchOfficeJobEventType = 1
kLogJobRendered: win32more.Windows.Win32.Graphics.Printing.EBranchOfficeJobEventType = 2
kLogJobError: win32more.Windows.Win32.Graphics.Printing.EBranchOfficeJobEventType = 3
kLogJobPipelineError: win32more.Windows.Win32.Graphics.Printing.EBranchOfficeJobEventType = 4
kLogOfflineFileFull: win32more.Windows.Win32.Graphics.Printing.EBranchOfficeJobEventType = 5
@winfunctype_pointer
def EMFPLAYPROC(param0: win32more.Windows.Win32.Graphics.Gdi.HDC, param1: Int32, param2: win32more.Windows.Win32.Foundation.HANDLE) -> Int32: ...
EPrintPropertyType = Int32
kPropertyTypeString: win32more.Windows.Win32.Graphics.Printing.EPrintPropertyType = 1
kPropertyTypeInt32: win32more.Windows.Win32.Graphics.Printing.EPrintPropertyType = 2
kPropertyTypeInt64: win32more.Windows.Win32.Graphics.Printing.EPrintPropertyType = 3
kPropertyTypeByte: win32more.Windows.Win32.Graphics.Printing.EPrintPropertyType = 4
kPropertyTypeTime: win32more.Windows.Win32.Graphics.Printing.EPrintPropertyType = 5
kPropertyTypeDevMode: win32more.Windows.Win32.Graphics.Printing.EPrintPropertyType = 6
kPropertyTypeSD: win32more.Windows.Win32.Graphics.Printing.EPrintPropertyType = 7
kPropertyTypeNotificationReply: win32more.Windows.Win32.Graphics.Printing.EPrintPropertyType = 8
kPropertyTypeNotificationOptions: win32more.Windows.Win32.Graphics.Printing.EPrintPropertyType = 9
kPropertyTypeBuffer: win32more.Windows.Win32.Graphics.Printing.EPrintPropertyType = 10
EPrintXPSJobOperation = Int32
kJobProduction: win32more.Windows.Win32.Graphics.Printing.EPrintXPSJobOperation = 1
kJobConsumption: win32more.Windows.Win32.Graphics.Printing.EPrintXPSJobOperation = 2
EPrintXPSJobProgress = Int32
kAddingDocumentSequence: win32more.Windows.Win32.Graphics.Printing.EPrintXPSJobProgress = 0
kDocumentSequenceAdded: win32more.Windows.Win32.Graphics.Printing.EPrintXPSJobProgress = 1
kAddingFixedDocument: win32more.Windows.Win32.Graphics.Printing.EPrintXPSJobProgress = 2
kFixedDocumentAdded: win32more.Windows.Win32.Graphics.Printing.EPrintXPSJobProgress = 3
kAddingFixedPage: win32more.Windows.Win32.Graphics.Printing.EPrintXPSJobProgress = 4
kFixedPageAdded: win32more.Windows.Win32.Graphics.Printing.EPrintXPSJobProgress = 5
kResourceAdded: win32more.Windows.Win32.Graphics.Printing.EPrintXPSJobProgress = 6
kFontAdded: win32more.Windows.Win32.Graphics.Printing.EPrintXPSJobProgress = 7
kImageAdded: win32more.Windows.Win32.Graphics.Printing.EPrintXPSJobProgress = 8
kXpsDocumentCommitted: win32more.Windows.Win32.Graphics.Printing.EPrintXPSJobProgress = 9
class EXTCHKBOX(Structure):
    cbSize: UInt16
    Flags: UInt16
    pTitle: POINTER(SByte)
    pSeparator: POINTER(SByte)
    pCheckedName: POINTER(SByte)
    IconID: UIntPtr
    wReserved: UInt16 * 4
    dwReserved: UIntPtr * 2
class EXTPUSH(Structure):
    cbSize: UInt16
    Flags: UInt16
    pTitle: POINTER(SByte)
    Anonymous1: _Anonymous1_e__Union
    IconID: UIntPtr
    Anonymous2: _Anonymous2_e__Union
    dwReserved: UIntPtr * 3
    class _Anonymous1_e__Union(Union):
        DlgProc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC
        pfnCallBack: win32more.Windows.Win32.Foundation.FARPROC
    class _Anonymous2_e__Union(Union):
        DlgTemplateID: UInt16
        hDlgTemplate: win32more.Windows.Win32.Foundation.HANDLE
class EXTTEXTMETRIC(Structure):
    emSize: Int16
    emPointSize: Int16
    emOrientation: Int16
    emMasterHeight: Int16
    emMinScale: Int16
    emMaxScale: Int16
    emMasterUnits: Int16
    emCapHeight: Int16
    emXHeight: Int16
    emLowerCaseAscent: Int16
    emLowerCaseDescent: Int16
    emSlant: Int16
    emSuperScript: Int16
    emSubScript: Int16
    emSuperScriptSize: Int16
    emSubScriptSize: Int16
    emUnderlineOffset: Int16
    emUnderlineWidth: Int16
    emDoubleUpperUnderlineOffset: Int16
    emDoubleLowerUnderlineOffset: Int16
    emDoubleUpperUnderlineWidth: Int16
    emDoubleLowerUnderlineWidth: Int16
    emStrikeOutOffset: Int16
    emStrikeOutWidth: Int16
    emKernPairs: UInt16
    emKernTracks: UInt16
EXpsCompressionOptions = Int32
Compression_NotCompressed: win32more.Windows.Win32.Graphics.Printing.EXpsCompressionOptions = 0
Compression_Normal: win32more.Windows.Win32.Graphics.Printing.EXpsCompressionOptions = 1
Compression_Small: win32more.Windows.Win32.Graphics.Printing.EXpsCompressionOptions = 2
Compression_Fast: win32more.Windows.Win32.Graphics.Printing.EXpsCompressionOptions = 3
EXpsFontOptions = Int32
Font_Normal: win32more.Windows.Win32.Graphics.Printing.EXpsFontOptions = 0
Font_Obfusticate: win32more.Windows.Win32.Graphics.Printing.EXpsFontOptions = 1
EXpsFontRestriction = Int32
Xps_Restricted_Font_Installable: win32more.Windows.Win32.Graphics.Printing.EXpsFontRestriction = 0
Xps_Restricted_Font_NoEmbedding: win32more.Windows.Win32.Graphics.Printing.EXpsFontRestriction = 2
Xps_Restricted_Font_PreviewPrint: win32more.Windows.Win32.Graphics.Printing.EXpsFontRestriction = 4
Xps_Restricted_Font_Editable: win32more.Windows.Win32.Graphics.Printing.EXpsFontRestriction = 8
EXpsJobConsumption = Int32
XpsJob_DocumentSequenceAdded: win32more.Windows.Win32.Graphics.Printing.EXpsJobConsumption = 0
XpsJob_FixedDocumentAdded: win32more.Windows.Win32.Graphics.Printing.EXpsJobConsumption = 1
XpsJob_FixedPageAdded: win32more.Windows.Win32.Graphics.Printing.EXpsJobConsumption = 2
class FORM_INFO_1A(Structure):
    Flags: UInt32
    pName: win32more.Windows.Win32.Foundation.PSTR
    Size: win32more.Windows.Win32.Foundation.SIZE
    ImageableArea: win32more.Windows.Win32.Foundation.RECTL
class FORM_INFO_1W(Structure):
    Flags: UInt32
    pName: win32more.Windows.Win32.Foundation.PWSTR
    Size: win32more.Windows.Win32.Foundation.SIZE
    ImageableArea: win32more.Windows.Win32.Foundation.RECTL
FORM_INFO_1 = UnicodeAlias('FORM_INFO_1W')
class FORM_INFO_2A(Structure):
    Flags: UInt32
    pName: win32more.Windows.Win32.Foundation.PSTR
    Size: win32more.Windows.Win32.Foundation.SIZE
    ImageableArea: win32more.Windows.Win32.Foundation.RECTL
    pKeyword: win32more.Windows.Win32.Foundation.PSTR
    StringType: UInt32
    pMuiDll: win32more.Windows.Win32.Foundation.PSTR
    dwResourceId: UInt32
    pDisplayName: win32more.Windows.Win32.Foundation.PSTR
    wLangId: UInt16
class FORM_INFO_2W(Structure):
    Flags: UInt32
    pName: win32more.Windows.Win32.Foundation.PWSTR
    Size: win32more.Windows.Win32.Foundation.SIZE
    ImageableArea: win32more.Windows.Win32.Foundation.RECTL
    pKeyword: win32more.Windows.Win32.Foundation.PSTR
    StringType: UInt32
    pMuiDll: win32more.Windows.Win32.Foundation.PWSTR
    dwResourceId: UInt32
    pDisplayName: win32more.Windows.Win32.Foundation.PWSTR
    wLangId: UInt16
FORM_INFO_2 = UnicodeAlias('FORM_INFO_2W')
class GLYPHRUN(Structure):
    wcLow: Char
    wGlyphCount: UInt16
class IAsyncGetSendNotificationCookie(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncCookie
    @commethod(5)
    def FinishAsyncCallWithData(self, param0: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyDataObject, param1: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAsyncGetSrvReferralCookie(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    @commethod(3)
    def FinishAsyncCall(self, param0: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CancelAsyncCall(self, param0: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def FinishAsyncCallWithData(self, param0: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IBidiAsyncNotifyChannel(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyChannel
    _iid_ = Guid('{532818f7-921b-4fb2-bff8-2f4fd52ebebf}')
    @commethod(5)
    def CreateNotificationChannel(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetPrintName(self, param0: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyDataObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetChannelNotificationType(self, param0: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyDataObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def AsyncGetNotificationSendResponse(self, param0: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyDataObject, param1: win32more.Windows.Win32.Graphics.Printing.IAsyncGetSendNotificationCookie) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def AsyncCloseChannel(self, param0: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyDataObject, param1: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncCookie) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IBidiRequest(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8f348bd7-4b47-4755-8a9d-0f422df3dc89}')
    @commethod(3)
    def SetSchema(self, pszSchema: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetInputData(self, dwType: UInt32, pData: POINTER(Byte), uSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetResult(self, phr: POINTER(win32more.Windows.Win32.Foundation.HRESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetOutputData(self, dwIndex: UInt32, ppszSchema: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pdwType: POINTER(UInt32), ppData: POINTER(POINTER(Byte)), uSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetEnumCount(self, pdwTotal: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IBidiRequestContainer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d752f6c0-94a8-4275-a77d-8f1d1a1121ae}')
    @commethod(3)
    def AddRequest(self, pRequest: win32more.Windows.Win32.Graphics.Printing.IBidiRequest) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetEnumObject(self, ppenum: POINTER(win32more.Windows.Win32.System.Com.IEnumUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetRequestCount(self, puCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IBidiSpl(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d580dc0e-de39-4649-baa8-bf0b85a03a97}')
    @commethod(3)
    def BindDevice(self, pszDeviceName: win32more.Windows.Win32.Foundation.PWSTR, dwAccess: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def UnbindDevice(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SendRecv(self, pszAction: win32more.Windows.Win32.Foundation.PWSTR, pRequest: win32more.Windows.Win32.Graphics.Printing.IBidiRequest) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def MultiSendRecv(self, pszAction: win32more.Windows.Win32.Foundation.PWSTR, pRequestContainer: win32more.Windows.Win32.Graphics.Printing.IBidiRequestContainer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IBidiSpl2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0e8f51b8-8273-4906-8e7b-be453ffd2e2b}')
    @commethod(3)
    def BindDevice(self, pszDeviceName: win32more.Windows.Win32.Foundation.PWSTR, dwAccess: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def UnbindDevice(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SendRecvXMLString(self, bstrRequest: win32more.Windows.Win32.Foundation.BSTR, pbstrResponse: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SendRecvXMLStream(self, pSRequest: win32more.Windows.Win32.System.Com.IStream, ppSResponse: POINTER(win32more.Windows.Win32.System.Com.IStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IFixedDocument(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f222ca9f-9968-4db9-81bd-abaebf15f93f}')
    @commethod(3)
    def GetUri(self, uri: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetPrintTicket(self, ppPrintTicket: POINTER(win32more.Windows.Win32.Graphics.Printing.IPartPrintTicket)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetPrintTicket(self, pPrintTicket: win32more.Windows.Win32.Graphics.Printing.IPartPrintTicket) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IFixedDocumentSequence(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8028d181-2c32-4249-8493-1bfb22045574}')
    @commethod(3)
    def GetUri(self, uri: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetPrintTicket(self, ppPrintTicket: POINTER(win32more.Windows.Win32.Graphics.Printing.IPartPrintTicket)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetPrintTicket(self, pPrintTicket: win32more.Windows.Win32.Graphics.Printing.IPartPrintTicket) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IFixedPage(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPartBase
    _iid_ = Guid('{3d9f6448-7e95-4cb5-94fb-0180c2883a57}')
    @commethod(7)
    def GetPrintTicket(self, ppPrintTicket: POINTER(win32more.Windows.Win32.Graphics.Printing.IPartPrintTicket)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetPagePart(self, uri: win32more.Windows.Win32.Foundation.PWSTR, ppUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetWriteStream(self, ppWriteStream: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintWriteStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetPrintTicket(self, ppPrintTicket: win32more.Windows.Win32.Graphics.Printing.IPartPrintTicket) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetPagePart(self, pUnk: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def DeleteResource(self, uri: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetXpsPartIterator(self, pXpsPartIt: POINTER(win32more.Windows.Win32.Graphics.Printing.IXpsPartIterator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IImgCreateErrorInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Ole.ICreateErrorInfo
    _iid_ = Guid('{1c55a64c-07cd-4fb5-90f7-b753d91f0c9e}')
    @commethod(8)
    def AttachToErrorInfo(self, pErrorInfo: POINTER(win32more.Windows.Win32.Graphics.Printing.ImgErrorInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IImgErrorInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IErrorInfo
    _iid_ = Guid('{2bce4ece-d30e-445a-9423-6829be945ad8}')
    @commethod(8)
    def GetDeveloperDescription(self, pbstrDevDescription: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetUserErrorId(self, pErrorId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetUserParameterCount(self, pcUserParams: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetUserParameter(self, cParam: UInt32, pbstrParam: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetUserFallback(self, pbstrFallback: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetExceptionId(self, pExceptionId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def DetachErrorInfo(self, pErrorInfo: POINTER(win32more.Windows.Win32.Graphics.Printing.ImgErrorInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IInterFilterCommunicator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4daf1e69-81fd-462d-940f-8cd3ddf56fca}')
    @commethod(3)
    def RequestReader(self, ppIReader: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def RequestWriter(self, ppIWriter: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INSERTPSUIPAGE_INFO(Structure):
    cbSize: UInt16
    Type: Byte
    Mode: Byte
    dwData1: UIntPtr
    dwData2: UIntPtr
    dwData3: UIntPtr
class INVOC(Structure):
    dwCount: UInt32
    loOffset: UInt32
class IPartBase(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{36d51e28-369e-43ba-a666-9540c62c3f58}')
    @commethod(3)
    def GetUri(self, uri: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetStream(self, ppStream: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintReadStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetPartCompression(self, pCompression: POINTER(win32more.Windows.Win32.Graphics.Printing.EXpsCompressionOptions)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetPartCompression(self, compression: win32more.Windows.Win32.Graphics.Printing.EXpsCompressionOptions) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPartColorProfile(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPartBase
    _iid_ = Guid('{63cca95b-7d18-4762-b15e-98658693d24a}')
class IPartDiscardControl(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{cc350c00-095b-42a5-bf0f-c8780edadb3c}')
    @commethod(3)
    def GetDiscardProperties(self, uriSentinelPage: POINTER(win32more.Windows.Win32.Foundation.BSTR), uriPartToDiscard: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPartFont(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPartBase
    _iid_ = Guid('{e07fe0ab-1124-43d0-a865-e8ffb6a3ea82}')
    @commethod(7)
    def GetFontProperties(self, pContentType: POINTER(win32more.Windows.Win32.Foundation.BSTR), pFontOptions: POINTER(win32more.Windows.Win32.Graphics.Printing.EXpsFontOptions)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetFontContent(self, pContentType: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetFontOptions(self, options: win32more.Windows.Win32.Graphics.Printing.EXpsFontOptions) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPartFont2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPartFont
    _iid_ = Guid('{511e025f-d6cb-43be-bf65-63fe88515a39}')
    @commethod(10)
    def GetFontRestriction(self, pRestriction: POINTER(win32more.Windows.Win32.Graphics.Printing.EXpsFontRestriction)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPartImage(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPartBase
    _iid_ = Guid('{725f2e3c-401a-4705-9de0-fe6f1353b87f}')
    @commethod(7)
    def GetImageProperties(self, pContentType: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetImageContent(self, pContentType: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPartPrintTicket(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPartBase
    _iid_ = Guid('{4a0f50f6-f9a2-41f0-99e7-5ae955be8e9e}')
class IPartResourceDictionary(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPartBase
    _iid_ = Guid('{16cfce6d-e744-4fb3-b474-f1d54f024a01}')
class IPartThumbnail(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPartBase
    _iid_ = Guid('{027ed1c9-ba39-4cc5-aa55-7ec3a0de171a}')
    @commethod(7)
    def GetThumbnailProperties(self, pContentType: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetThumbnailContent(self, pContentType: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintAsyncCookie(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    @commethod(3)
    def FinishAsyncCall(self, param0: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CancelAsyncCall(self, param0: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintAsyncNewChannelCookie(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncCookie
    @commethod(5)
    def FinishAsyncCallWithData(self, param0: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyChannel), param1: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintAsyncNotify(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{532818f7-921b-4fb2-bff8-2f4fd52ebebf}')
    @commethod(3)
    def CreatePrintAsyncNotifyChannel(self, param0: UInt32, param1: POINTER(Guid), param2: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyUserFilter, param3: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyConversationStyle, param4: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyCallback, param5: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyChannel)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreatePrintAsyncNotifyRegistration(self, param0: POINTER(Guid), param1: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyUserFilter, param2: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyConversationStyle, param3: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyCallback, param4: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyRegistration)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintAsyncNotifyCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7def34c1-9d92-4c99-b3b3-db94a9d4191b}')
    @commethod(3)
    def OnEventNotify(self, pChannel: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyChannel, pData: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyDataObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ChannelClosed(self, pChannel: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyChannel, pData: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyDataObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintAsyncNotifyChannel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4a5031b1-1f3f-4db0-a462-4530ed8b0451}')
    @commethod(3)
    def SendNotification(self, pData: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyDataObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CloseChannel(self, pData: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyDataObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintAsyncNotifyDataObject(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{77cf513e-5d49-4789-9f30-d0822b335c0d}')
    @commethod(3)
    def AcquireData(self, ppNotificationData: POINTER(POINTER(Byte)), pSize: POINTER(UInt32), ppSchema: POINTER(POINTER(Guid))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ReleaseData(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintAsyncNotifyRegistration(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0f6f27b6-6f86-4591-9203-64c3bfadedfe}')
    @commethod(3)
    def RegisterForNotifications(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def UnregisterForNotifications(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintAsyncNotifyServerReferral(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    @commethod(3)
    def GetServerReferral(self, param0: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AsyncGetServerReferral(self, param0: win32more.Windows.Win32.Graphics.Printing.IAsyncGetSrvReferralCookie) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetServerReferral(self, pRmtServerReferral: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintBidiAsyncNotifyRegistration(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyRegistration
    @commethod(5)
    def AsyncGetNewChannel(self, param0: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNewChannelCookie) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintClassObjectFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9af593dd-9b02-48a8-9bad-69ace423f88b}')
    @commethod(3)
    def GetPrintClassObject(self, pszPrinterName: win32more.Windows.Win32.Foundation.PWSTR, riid: POINTER(Guid), ppNewObject: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintCoreHelper(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a89ec53e-3905-49c6-9c1a-c0a88117fdb6}')
    @commethod(3)
    def GetOption(self, pDevmode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), cbSize: UInt32, pszFeatureRequested: win32more.Windows.Win32.Foundation.PSTR, ppszOption: POINTER(win32more.Windows.Win32.Foundation.PSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetOptions(self, pDevmode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), cbSize: UInt32, bResolveConflicts: win32more.Windows.Win32.Foundation.BOOL, pFOPairs: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINT_FEATURE_OPTION), cPairs: UInt32, pcPairsWritten: POINTER(UInt32), pdwResult: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def EnumConstrainedOptions(self, pDevmode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), cbSize: UInt32, pszFeatureKeyword: win32more.Windows.Win32.Foundation.PSTR, pConstrainedOptionList: POINTER(POINTER(POINTER(win32more.Windows.Win32.Foundation.PSTR))), pdwNumOptions: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def WhyConstrained(self, pDevmode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), cbSize: UInt32, pszFeatureKeyword: win32more.Windows.Win32.Foundation.PSTR, pszOptionKeyword: win32more.Windows.Win32.Foundation.PSTR, ppFOConstraints: POINTER(POINTER(win32more.Windows.Win32.Graphics.Printing.PRINT_FEATURE_OPTION)), pdwNumOptions: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def EnumFeatures(self, pFeatureList: POINTER(POINTER(POINTER(win32more.Windows.Win32.Foundation.PSTR))), pdwNumFeatures: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def EnumOptions(self, pszFeatureKeyword: win32more.Windows.Win32.Foundation.PSTR, pOptionList: POINTER(POINTER(POINTER(win32more.Windows.Win32.Foundation.PSTR))), pdwNumOptions: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetFontSubstitution(self, pszTrueTypeFontName: win32more.Windows.Win32.Foundation.PWSTR, ppszDevFontName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetFontSubstitution(self, pszTrueTypeFontName: win32more.Windows.Win32.Foundation.PWSTR, pszDevFontName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateInstanceOfMSXMLObject(self, rclsid: POINTER(Guid), pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, dwClsContext: UInt32, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintCoreHelperPS(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintCoreHelper
    _iid_ = Guid('{c2c14f6f-95d3-4d63-96cf-6bd9e6c907c2}')
    @commethod(12)
    def GetGlobalAttribute(self, pszAttribute: win32more.Windows.Win32.Foundation.PSTR, pdwDataType: POINTER(UInt32), ppbData: POINTER(POINTER(Byte)), pcbSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetFeatureAttribute(self, pszFeatureKeyword: win32more.Windows.Win32.Foundation.PSTR, pszAttribute: win32more.Windows.Win32.Foundation.PSTR, pdwDataType: POINTER(UInt32), ppbData: POINTER(POINTER(Byte)), pcbSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetOptionAttribute(self, pszFeatureKeyword: win32more.Windows.Win32.Foundation.PSTR, pszOptionKeyword: win32more.Windows.Win32.Foundation.PSTR, pszAttribute: win32more.Windows.Win32.Foundation.PSTR, pdwDataType: POINTER(UInt32), ppbData: POINTER(POINTER(Byte)), pcbSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintCoreHelperUni(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintCoreHelper
    _iid_ = Guid('{7e8e51d6-e5ee-4426-817b-958b9444eb79}')
    @commethod(12)
    def CreateGDLSnapshot(self, pDevmode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), cbSize: UInt32, dwFlags: UInt32, ppSnapshotStream: POINTER(win32more.Windows.Win32.System.Com.IStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateDefaultGDLSnapshot(self, dwFlags: UInt32, ppSnapshotStream: POINTER(win32more.Windows.Win32.System.Com.IStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintCoreHelperUni2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintCoreHelperUni
    _iid_ = Guid('{6c8afdfc-ead0-4d2d-8071-9bf0175a6c3a}')
    @commethod(14)
    def GetNamedCommand(self, pDevmode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), cbSize: UInt32, pszCommandName: win32more.Windows.Win32.Foundation.PWSTR, ppCommandBytes: POINTER(POINTER(Byte)), pcbCommandSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintCoreUI2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintOemDriverUI
    _iid_ = Guid('{085ccfca-3adf-4c9e-b491-d851a6edc997}')
    @commethod(6)
    def GetOptions(self, poemuiobj: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMUIOBJ), dwFlags: UInt32, pmszFeaturesRequested: POINTER(SByte), cbIn: UInt32, pmszFeatureOptionBuf: win32more.Windows.Win32.Foundation.PSTR, cbSize: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetOptions(self, poemuiobj: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMUIOBJ), dwFlags: UInt32, pmszFeatureOptionBuf: POINTER(SByte), cbIn: UInt32, pdwResult: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def EnumConstrainedOptions(self, poemuiobj: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMUIOBJ), dwFlags: UInt32, pszFeatureKeyword: win32more.Windows.Win32.Foundation.PSTR, pmszConstrainedOptionList: win32more.Windows.Win32.Foundation.PSTR, cbSize: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def WhyConstrained(self, poemuiobj: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMUIOBJ), dwFlags: UInt32, pszFeatureKeyword: win32more.Windows.Win32.Foundation.PSTR, pszOptionKeyword: win32more.Windows.Win32.Foundation.PSTR, pmszReasonList: win32more.Windows.Win32.Foundation.PSTR, cbSize: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetGlobalAttribute(self, poemuiobj: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMUIOBJ), dwFlags: UInt32, pszAttribute: win32more.Windows.Win32.Foundation.PSTR, pdwDataType: POINTER(UInt32), pbData: POINTER(Byte), cbSize: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetFeatureAttribute(self, poemuiobj: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMUIOBJ), dwFlags: UInt32, pszFeatureKeyword: win32more.Windows.Win32.Foundation.PSTR, pszAttribute: win32more.Windows.Win32.Foundation.PSTR, pdwDataType: POINTER(UInt32), pbData: POINTER(Byte), cbSize: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetOptionAttribute(self, poemuiobj: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMUIOBJ), dwFlags: UInt32, pszFeatureKeyword: win32more.Windows.Win32.Foundation.PSTR, pszOptionKeyword: win32more.Windows.Win32.Foundation.PSTR, pszAttribute: win32more.Windows.Win32.Foundation.PSTR, pdwDataType: POINTER(UInt32), pbData: POINTER(Byte), cbSize: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def EnumFeatures(self, poemuiobj: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMUIOBJ), dwFlags: UInt32, pmszFeatureList: win32more.Windows.Win32.Foundation.PSTR, cbSize: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def EnumOptions(self, poemuiobj: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMUIOBJ), dwFlags: UInt32, pszFeatureKeyword: win32more.Windows.Win32.Foundation.PSTR, pmszOptionList: win32more.Windows.Win32.Foundation.PSTR, cbSize: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def QuerySimulationSupport(self, hPrinter: win32more.Windows.Win32.Foundation.HANDLE, dwLevel: UInt32, pCaps: POINTER(Byte), cbSize: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintJob(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b771dab8-1282-41b7-858c-f206e4d20577}')
    @commethod(3)
    def get_Name(self, pbstrName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_Id(self, pulID: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_PrintedPages(self, pulPages: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def get_TotalPages(self, pulPages: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def get_Status(self, pStatus: POINTER(win32more.Windows.Win32.Graphics.Printing.PrintJobStatus)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_SubmissionTime(self, pSubmissionTime: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def RequestCancel(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintJobCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{72b82a24-a598-4e87-895f-cdb23a49e9dc}')
    @commethod(7)
    def get_Count(self, pulCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetAt(self, ulIndex: UInt32, ppJob: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintJob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get__NewEnum(self, ppUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintOemCommon(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7f42285e-91d5-11d1-8820-00c04fb961ec}')
    @commethod(3)
    def GetInfo(self, dwMode: UInt32, pBuffer: VoidPtr, cbSize: UInt32, pcbNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DevMode(self, dwMode: UInt32, pOemDMParam: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMDMPARAM)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintOemDriverUI(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{92b05d50-78bc-11d1-9480-00a0c90640b8}')
    @commethod(3)
    def DrvGetDriverSetting(self, pci: VoidPtr, Feature: win32more.Windows.Win32.Foundation.PSTR, pOutput: VoidPtr, cbSize: UInt32, pcbNeeded: POINTER(UInt32), pdwOptionsReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DrvUpgradeRegistrySetting(self, hPrinter: win32more.Windows.Win32.Foundation.HANDLE, pFeature: win32more.Windows.Win32.Foundation.PSTR, pOption: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def DrvUpdateUISetting(self, pci: VoidPtr, pOptItem: VoidPtr, dwPreviousSelection: UInt32, dwMode: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintOemUI(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintOemCommon
    _iid_ = Guid('{c6a7a9d0-774c-11d1-947f-00a0c90640b8}')
    @commethod(5)
    def PublishDriverInterface(self, pIUnknown: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CommonUIProp(self, dwMode: UInt32, pOemCUIPParam: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMCUIPPARAM)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def DocumentPropertySheets(self, pPSUIInfo: POINTER(win32more.Windows.Win32.Graphics.Printing.PROPSHEETUI_INFO), lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DevicePropertySheets(self, pPSUIInfo: POINTER(win32more.Windows.Win32.Graphics.Printing.PROPSHEETUI_INFO), lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def DevQueryPrintEx(self, poemuiobj: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMUIOBJ), pDQPInfo: POINTER(win32more.Windows.Win32.Graphics.Printing.DEVQUERYPRINT_INFO), pPublicDM: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), pOEMDM: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def DeviceCapabilitiesA(self, poemuiobj: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMUIOBJ), hPrinter: win32more.Windows.Win32.Foundation.HANDLE, pDeviceName: win32more.Windows.Win32.Foundation.PWSTR, wCapability: UInt16, pOutput: VoidPtr, pPublicDM: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), pOEMDM: VoidPtr, dwOld: UInt32, dwResult: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def UpgradePrinter(self, dwLevel: UInt32, pDriverUpgradeInfo: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def PrinterEvent(self, pPrinterName: win32more.Windows.Win32.Foundation.PWSTR, iDriverEvent: Int32, dwFlags: UInt32, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def DriverEvent(self, dwDriverEvent: UInt32, dwLevel: UInt32, pDriverInfo: POINTER(Byte), lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def QueryColorProfile(self, hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, poemuiobj: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMUIOBJ), pPublicDM: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), pOEMDM: VoidPtr, ulQueryMode: UInt32, pvProfileData: VoidPtr, pcbProfileData: POINTER(UInt32), pflProfileData: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def FontInstallerDlgProc(self, hWnd: win32more.Windows.Win32.Foundation.HWND, usMsg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def UpdateExternalFonts(self, hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, hHeap: win32more.Windows.Win32.Foundation.HANDLE, pwstrCartridges: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintOemUI2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintOemUI
    _iid_ = Guid('{292515f9-b54b-489b-9275-bab56821395e}')
    @commethod(17)
    def QueryJobAttributes(self, hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, pDevmode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), dwLevel: UInt32, lpAttributeInfo: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def HideStandardUI(self, dwMode: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def DocumentEvent(self, hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iEsc: Int32, cbIn: UInt32, pvIn: VoidPtr, cbOut: UInt32, pvOut: VoidPtr, piResult: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintOemUIMXDC(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7349d725-e2c1-4dca-afb5-c13e91bc9306}')
    @commethod(3)
    def AdjustImageableArea(self, hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, cbDevMode: UInt32, pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), cbOEMDM: UInt32, pOEMDM: VoidPtr, prclImageableArea: POINTER(win32more.Windows.Win32.Foundation.RECTL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AdjustImageCompression(self, hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, cbDevMode: UInt32, pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), cbOEMDM: UInt32, pOEMDM: VoidPtr, pCompressionMode: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def AdjustDPI(self, hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, cbDevMode: UInt32, pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), cbOEMDM: UInt32, pOEMDM: VoidPtr, pDPI: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintPipelineFilter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{cdb62fc0-8bed-434e-86fb-a2cae55f19ea}')
    @commethod(3)
    def InitializeFilter(self, pINegotiation: win32more.Windows.Win32.Graphics.Printing.IInterFilterCommunicator, pIPropertyBag: win32more.Windows.Win32.Graphics.Printing.IPrintPipelinePropertyBag, pIPipelineControl: win32more.Windows.Win32.Graphics.Printing.IPrintPipelineManagerControl) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ShutdownOperation(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def StartOperation(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintPipelineManagerControl(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{aa3e4910-5889-4681-91ef-823ad4ed4e44}')
    @commethod(3)
    def RequestShutdown(self, hrReason: win32more.Windows.Win32.Foundation.HRESULT, pReason: win32more.Windows.Win32.Graphics.Printing.IImgErrorInfo) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def FilterFinished(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintPipelineProgressReport(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{edc12c7c-ed40-4ea5-96a6-5e4397497a61}')
    @commethod(3)
    def ReportProgress(self, update: win32more.Windows.Win32.Graphics.Printing.EXpsJobConsumption) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintPipelinePropertyBag(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8b8c99dc-7892-4a95-8a04-57422e9fbb47}')
    @commethod(3)
    def AddProperty(self, pszName: win32more.Windows.Win32.Foundation.PWSTR, pVar: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetProperty(self, pszName: win32more.Windows.Win32.Foundation.PWSTR, pVar: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def DeleteProperty(self, pszName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
class IPrintPreviewDxgiPackageTarget(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1a6dd0ad-1e2a-4e99-a5ba-91f17818290e}')
    @commethod(3)
    def SetJobPageCount(self, countType: win32more.Windows.Win32.Graphics.Printing.PageCountType, count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DrawPage(self, jobPageNumber: UInt32, pageImage: win32more.Windows.Win32.Graphics.Dxgi.IDXGISurface, dpiX: Single, dpiY: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def InvalidatePreview(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintReadStream(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4d47a67c-66cc-4430-850e-daf466fe5bc4}')
    @commethod(3)
    def Seek(self, dlibMove: Int64, dwOrigin: UInt32, plibNewPosition: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ReadBytes(self, pvBuffer: VoidPtr, cbRequested: UInt32, pcbRead: POINTER(UInt32), pbEndOfFile: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintReadStreamFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{acb971e3-df8d-4fc2-bee6-0609d15f3cf9}')
    @commethod(3)
    def GetStream(self, ppStream: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintReadStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintSchemaAsyncOperation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{143c8dcb-d37f-47f7-88e8-6b1d21f2c5f7}')
    @commethod(7)
    def Start(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Cancel(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintSchemaAsyncOperationEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{23adbb16-0133-4906-b29a-1dce1d026379}')
    @commethod(7)
    def Completed(self, pTicket: win32more.Windows.Win32.Graphics.Printing.IPrintSchemaTicket, hrOperation: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintSchemaCapabilities(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintSchemaElement
    _iid_ = Guid('{5a577640-501d-4927-bcd0-5ef57a7ed175}')
    @commethod(10)
    def GetFeatureByKeyName(self, bstrKeyName: win32more.Windows.Win32.Foundation.BSTR, ppFeature: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintSchemaFeature)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetFeature(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, bstrNamespaceUri: win32more.Windows.Win32.Foundation.BSTR, ppFeature: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintSchemaFeature)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_PageImageableSize(self, ppPageImageableSize: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintSchemaPageImageableSize)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_JobCopiesAllDocumentsMinValue(self, pulJobCopiesAllDocumentsMinValue: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_JobCopiesAllDocumentsMaxValue(self, pulJobCopiesAllDocumentsMaxValue: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetSelectedOptionInPrintTicket(self, pFeature: win32more.Windows.Win32.Graphics.Printing.IPrintSchemaFeature, ppOption: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintSchemaOption)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetOptions(self, pFeature: win32more.Windows.Win32.Graphics.Printing.IPrintSchemaFeature, ppOptionCollection: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintSchemaOptionCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintSchemaCapabilities2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintSchemaCapabilities
    _iid_ = Guid('{b58845f4-9970-4d87-a636-169fb82ed642}')
    @commethod(17)
    def GetParameterDefinition(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, bstrNamespaceUri: win32more.Windows.Win32.Foundation.BSTR, ppParameterDefinition: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintSchemaParameterDefinition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintSchemaDisplayableElement(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintSchemaElement
    _iid_ = Guid('{af45af49-d6aa-407d-bf87-3912236e9d94}')
    @commethod(10)
    def get_DisplayName(self, pbstrDisplayName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintSchemaElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{724c1646-e64b-4bbf-8eb4-d45e4fd580da}')
    @commethod(7)
    def get_XmlNode(self, ppXmlNode: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Name(self, pbstrName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_NamespaceUri(self, pbstrNamespaceUri: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintSchemaFeature(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintSchemaDisplayableElement
    _iid_ = Guid('{ef189461-5d62-4626-8e57-ff83583c4826}')
    @commethod(11)
    def get_SelectedOption(self, ppOption: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintSchemaOption)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_SelectedOption(self, pOption: win32more.Windows.Win32.Graphics.Printing.IPrintSchemaOption) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_SelectionType(self, pSelectionType: POINTER(win32more.Windows.Win32.Graphics.Printing.PrintSchemaSelectionType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetOption(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, bstrNamespaceUri: win32more.Windows.Win32.Foundation.BSTR, ppOption: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintSchemaOption)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_DisplayUI(self, pbShow: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintSchemaNUpOption(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintSchemaOption
    _iid_ = Guid('{1f6342f2-d848-42e3-8995-c10a9ef9a3ba}')
    @commethod(14)
    def get_PagesPerSheet(self, pulPagesPerSheet: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintSchemaOption(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintSchemaDisplayableElement
    _iid_ = Guid('{66bb2f51-5844-4997-8d70-4b7cc221cf92}')
    @commethod(11)
    def get_Selected(self, pbIsSelected: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_Constrained(self, pSetting: POINTER(win32more.Windows.Win32.Graphics.Printing.PrintSchemaConstrainedSetting)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetPropertyValue(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, bstrNamespaceUri: win32more.Windows.Win32.Foundation.BSTR, ppXmlValueNode: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintSchemaOptionCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{baecb0bd-a946-4771-bc30-e8b24f8d45c1}')
    @commethod(7)
    def get_Count(self, pulCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetAt(self, ulIndex: UInt32, ppOption: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintSchemaOption)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get__NewEnum(self, ppUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintSchemaPageImageableSize(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintSchemaElement
    _iid_ = Guid('{7c85bf5e-dc7c-4f61-839b-4107e1c9b68e}')
    @commethod(10)
    def get_ImageableSizeWidthInMicrons(self, pulImageableSizeWidth: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_ImageableSizeHeightInMicrons(self, pulImageableSizeHeight: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_OriginWidthInMicrons(self, pulOriginWidth: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_OriginHeightInMicrons(self, pulOriginHeight: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_ExtentWidthInMicrons(self, pulExtentWidth: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_ExtentHeightInMicrons(self, pulExtentHeight: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintSchemaPageMediaSizeOption(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintSchemaOption
    _iid_ = Guid('{68746729-f493-4830-a10f-69028774605d}')
    @commethod(14)
    def get_WidthInMicrons(self, pulWidth: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_HeightInMicrons(self, pulHeight: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintSchemaParameterDefinition(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintSchemaDisplayableElement
    _iid_ = Guid('{b5ade81e-0e61-4fe1-81c6-c333e4ffe0f1}')
    @commethod(11)
    def get_UserInputRequired(self, pbIsRequired: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_UnitType(self, pbstrUnitType: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_DataType(self, pDataType: POINTER(win32more.Windows.Win32.Graphics.Printing.PrintSchemaParameterDataType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_RangeMin(self, pRangeMin: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_RangeMax(self, pRangeMax: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintSchemaParameterInitializer(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintSchemaElement
    _iid_ = Guid('{52027082-0b74-4648-9564-828cc6cb656c}')
    @commethod(10)
    def get_Value(self, pVar: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_Value(self, pVar: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintSchemaTicket(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintSchemaElement
    _iid_ = Guid('{e480b861-4708-4e6d-a5b4-a2b4eeb9baa4}')
    @commethod(10)
    def GetFeatureByKeyName(self, bstrKeyName: win32more.Windows.Win32.Foundation.BSTR, ppFeature: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintSchemaFeature)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetFeature(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, bstrNamespaceUri: win32more.Windows.Win32.Foundation.BSTR, ppFeature: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintSchemaFeature)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def ValidateAsync(self, ppAsyncOperation: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintSchemaAsyncOperation)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CommitAsync(self, pPrintTicketCommit: win32more.Windows.Win32.Graphics.Printing.IPrintSchemaTicket, ppAsyncOperation: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintSchemaAsyncOperation)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def NotifyXmlChanged(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetCapabilities(self, ppCapabilities: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintSchemaCapabilities)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_JobCopiesAllDocuments(self, pulJobCopiesAllDocuments: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_JobCopiesAllDocuments(self, ulJobCopiesAllDocuments: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintSchemaTicket2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintSchemaTicket
    _iid_ = Guid('{2ec1f844-766a-47a1-91f4-2eeb6190f80c}')
    @commethod(18)
    def GetParameterInitializer(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, bstrNamespaceUri: win32more.Windows.Win32.Foundation.BSTR, ppParameterInitializer: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintSchemaParameterInitializer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintTicketProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bb5116db-0a23-4c3a-a6b6-89e5558dfb5d}')
    @commethod(3)
    def GetSupportedVersions(self, hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, ppVersions: POINTER(POINTER(Int32)), cVersions: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def BindPrinter(self, hPrinter: win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE, version: Int32, pOptions: POINTER(win32more.Windows.Win32.Graphics.Printing.SHIMOPTS), pDevModeFlags: POINTER(UInt32), cNamespaces: POINTER(Int32), ppNamespaces: POINTER(POINTER(win32more.Windows.Win32.Foundation.BSTR))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def QueryDeviceNamespace(self, pDefaultNamespace: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def ConvertPrintTicketToDevMode(self, pPrintTicket: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMDocument2, cbDevmodeIn: UInt32, pDevmodeIn: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), pcbDevmodeOut: POINTER(UInt32), ppDevmodeOut: POINTER(POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ConvertDevModeToPrintTicket(self, cbDevmode: UInt32, pDevmode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA), pPrintTicket: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMDocument2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetPrintCapabilities(self, pPrintTicket: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMDocument2, ppCapabilities: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMDocument2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def ValidatePrintTicket(self, pBaseTicket: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMDocument2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintTicketProvider2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintTicketProvider
    _iid_ = Guid('{b8a70ab2-3dfc-4fec-a074-511b13c651cb}')
    @commethod(10)
    def GetPrintDeviceCapabilities(self, pPrintTicket: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMDocument2, ppDeviceCapabilities: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMDocument2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetPrintDeviceResources(self, pszLocaleName: win32more.Windows.Win32.Foundation.PWSTR, pPrintTicket: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMDocument2, ppDeviceResources: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMDocument2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintUnidiAsyncNotifyRegistration(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrintAsyncNotifyRegistration
    @commethod(5)
    def AsyncGetNotification(self, param0: win32more.Windows.Win32.Graphics.Printing.IAsyncGetSendNotificationCookie) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintWriteStream(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{65bb7f1b-371e-4571-8ac7-912f510c1a38}')
    @commethod(3)
    def WriteBytes(self, pvBuffer: VoidPtr, cbBuffer: UInt32, pcbWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Close(self) -> Void: ...
class IPrintWriteStreamFlush(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{07d11ff8-1753-4873-b749-6cdaf068e4c3}')
    @commethod(3)
    def FlushData(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterBidiSetRequestCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c52d32dd-f2b4-4052-8502-ec4305ecb71f}')
    @commethod(3)
    def Completed(self, bstrResponse: win32more.Windows.Win32.Foundation.BSTR, hrStatus: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterExtensionAsyncOperation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{108d6a23-6a4b-4552-9448-68b427186acd}')
    @commethod(3)
    def Cancel(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterExtensionContext(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{39843bf2-c4d2-41fd-b4b2-aedbee5e1900}')
    @commethod(7)
    def get_PrinterQueue(self, ppQueue: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrinterQueue)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_PrintSchemaTicket(self, ppTicket: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintSchemaTicket)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_DriverProperties(self, ppPropertyBag: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrinterPropertyBag)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_UserProperties(self, ppPropertyBag: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrinterPropertyBag)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterExtensionContextCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{fb476970-9bab-4861-811e-3e98b0c5addf}')
    @commethod(7)
    def get_Count(self, pulCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetAt(self, ulIndex: UInt32, ppContext: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrinterExtensionContext)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get__NewEnum(self, ppUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterExtensionEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{c093cb63-5ef5-4585-af8e-4d5637487b57}')
    @commethod(7)
    def OnDriverEvent(self, pEventArgs: win32more.Windows.Win32.Graphics.Printing.IPrinterExtensionEventArgs) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def OnPrinterQueuesEnumerated(self, pContextCollection: win32more.Windows.Win32.Graphics.Printing.IPrinterExtensionContextCollection) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterExtensionEventArgs(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrinterExtensionContext
    _iid_ = Guid('{39843bf4-c4d2-41fd-b4b2-aedbee5e1900}')
    @commethod(11)
    def get_BidiNotification(self, pbstrBidiNotification: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_ReasonId(self, pReasonId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_Request(self, ppRequest: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrinterExtensionRequest)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_SourceApplication(self, pbstrApplication: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_DetailedReasonId(self, pDetailedReasonId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_WindowModal(self, pbModal: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_WindowParent(self, phwndParent: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterExtensionManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{93c6eb8c-b001-4355-9629-8e8a1b3f8e77}')
    @commethod(3)
    def EnableEvents(self, printerDriverId: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DisableEvents(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterExtensionRequest(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{39843bf3-c4d2-41fd-b4b2-aedbee5e1900}')
    @commethod(7)
    def Cancel(self, hrStatus: win32more.Windows.Win32.Foundation.HRESULT, bstrLogMessage: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Complete(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterPropertyBag(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{fea77364-df95-4a23-a905-019b79a8e481}')
    @commethod(7)
    def GetBool(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, pbValue: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetBool(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, bValue: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetInt32(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, pnValue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetInt32(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, nValue: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetString(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, pbstrValue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetString(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, bstrValue: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetBytes(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, pcbValue: POINTER(UInt32), ppValue: POINTER(POINTER(Byte))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SetBytes(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, cbValue: UInt32, pValue: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetReadStream(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, ppValue: POINTER(win32more.Windows.Win32.System.Com.IStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetWriteStream(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, ppValue: POINTER(win32more.Windows.Win32.System.Com.IStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterQueue(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3580a828-07fe-4b94-ac1a-757d9d2d3056}')
    @commethod(7)
    def get_Handle(self, phPrinter: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Name(self, pbstrName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SendBidiQuery(self, bstrBidiQuery: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetProperties(self, ppPropertyBag: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrinterPropertyBag)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterQueue2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrinterQueue
    _iid_ = Guid('{8cd444e8-c9bb-49b3-8e38-e03209416131}')
    @commethod(11)
    def SendBidiSetRequestAsync(self, bstrBidiRequest: win32more.Windows.Win32.Foundation.BSTR, pCallback: win32more.Windows.Win32.Graphics.Printing.IPrinterBidiSetRequestCallback, ppAsyncOperation: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrinterExtensionAsyncOperation)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetPrinterQueueView(self, ulViewOffset: UInt32, ulViewSize: UInt32, ppJobView: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrinterQueueView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterQueueEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{214685f6-7b78-4681-87e0-495f739273d1}')
    @commethod(7)
    def OnBidiResponseReceived(self, bstrResponse: win32more.Windows.Win32.Foundation.BSTR, hrStatus: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterQueueView(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{476e2969-3b2b-4b3f-8277-cff6056042aa}')
    @commethod(7)
    def SetViewRange(self, ulViewOffset: UInt32, ulViewSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterQueueViewEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{c5b6042b-fd21-404a-a0ef-e2fbb52b9080}')
    @commethod(7)
    def OnChanged(self, pCollection: win32more.Windows.Win32.Graphics.Printing.IPrintJobCollection, ulViewOffset: UInt32, ulViewSize: UInt32, ulCountJobsInPrintQueue: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterScriptContext(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{066acbca-8881-49c9-bb98-fae16b4889e1}')
    @commethod(7)
    def get_DriverProperties(self, ppPropertyBag: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrinterScriptablePropertyBag)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_QueueProperties(self, ppPropertyBag: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrinterScriptablePropertyBag)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_UserProperties(self, ppPropertyBag: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrinterScriptablePropertyBag)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterScriptablePropertyBag(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{91c7765f-ed57-49ad-8b01-dc24816a5294}')
    @commethod(7)
    def GetBool(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, pbValue: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetBool(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, bValue: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetInt32(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, pnValue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetInt32(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, nValue: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetString(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, pbstrValue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetString(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, bstrValue: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetBytes(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, ppArray: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SetBytes(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, pArray: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetReadStream(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, ppStream: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrinterScriptableStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetWriteStream(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, ppStream: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrinterScriptableStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterScriptablePropertyBag2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrinterScriptablePropertyBag
    _iid_ = Guid('{2a1c53c4-8638-4b3e-b518-2773c94556a3}')
    @commethod(17)
    def GetReadStreamAsXML(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, ppXmlNode: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterScriptableSequentialStream(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{2072838a-316f-467a-a949-27f68c44a854}')
    @commethod(7)
    def Read(self, cbRead: Int32, ppArray: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Write(self, pArray: win32more.Windows.Win32.System.Com.IDispatch, pcbWritten: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinterScriptableStream(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Printing.IPrinterScriptableSequentialStream
    _iid_ = Guid('{7edf9a92-4750-41a5-a17f-879a6f4f7dcb}')
    @commethod(9)
    def Commit(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def Seek(self, lOffset: Int32, streamSeek: win32more.Windows.Win32.System.Com.STREAM_SEEK, plPosition: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetSize(self, lSize: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXpsDocument(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e8d907db-62a9-4a95-abe7-e01763dd30f8}')
    @commethod(3)
    def GetThumbnail(self, ppThumbnail: POINTER(win32more.Windows.Win32.Graphics.Printing.IPartThumbnail)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetThumbnail(self, pThumbnail: win32more.Windows.Win32.Graphics.Printing.IPartThumbnail) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXpsDocumentConsumer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4368d8a2-4181-4a9f-b295-3d9a38bb9ba0}')
    @commethod(3)
    def SendXpsUnknown(self, pUnknown: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SendXpsDocument(self, pIXpsDocument: win32more.Windows.Win32.Graphics.Printing.IXpsDocument) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SendFixedDocumentSequence(self, pIFixedDocumentSequence: win32more.Windows.Win32.Graphics.Printing.IFixedDocumentSequence) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SendFixedDocument(self, pIFixedDocument: win32more.Windows.Win32.Graphics.Printing.IFixedDocument) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SendFixedPage(self, pIFixedPage: win32more.Windows.Win32.Graphics.Printing.IFixedPage) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CloseSender(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetNewEmptyPart(self, uri: win32more.Windows.Win32.Foundation.PWSTR, riid: POINTER(Guid), ppNewObject: POINTER(VoidPtr), ppWriteStream: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrintWriteStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXpsDocumentProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b8cf8530-5562-47c4-ab67-b1f69ecf961e}')
    @commethod(3)
    def GetXpsPart(self, ppIXpsPart: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXpsPartIterator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0021d3cd-af6f-42ab-9999-14bc82a62d2e}')
    @commethod(3)
    def Reset(self) -> Void: ...
    @commethod(4)
    def Current(self, pUri: POINTER(win32more.Windows.Win32.Foundation.BSTR), ppXpsPart: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def IsDone(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(6)
    def Next(self) -> Void: ...
class IXpsRasterizationFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e094808a-24c6-482b-a3a7-c21ac9b55f17}')
    @commethod(3)
    def CreateRasterizer(self, xpsPage: win32more.Windows.Win32.Storage.Xps.IXpsOMPage, DPI: Single, nonTextRenderingMode: win32more.Windows.Win32.Graphics.Printing.XPSRAS_RENDERING_MODE, textRenderingMode: win32more.Windows.Win32.Graphics.Printing.XPSRAS_RENDERING_MODE, ppIXPSRasterizer: POINTER(win32more.Windows.Win32.Graphics.Printing.IXpsRasterizer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXpsRasterizationFactory1(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{2d6e5f77-6414-4a1e-a8e0-d4194ce6a26f}')
    @commethod(3)
    def CreateRasterizer(self, xpsPage: win32more.Windows.Win32.Storage.Xps.IXpsOMPage, DPI: Single, nonTextRenderingMode: win32more.Windows.Win32.Graphics.Printing.XPSRAS_RENDERING_MODE, textRenderingMode: win32more.Windows.Win32.Graphics.Printing.XPSRAS_RENDERING_MODE, pixelFormat: win32more.Windows.Win32.Graphics.Printing.XPSRAS_PIXEL_FORMAT, ppIXPSRasterizer: POINTER(win32more.Windows.Win32.Graphics.Printing.IXpsRasterizer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXpsRasterizationFactory2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9c16ce3e-10f5-41fd-9ddc-6826669c2ff6}')
    @commethod(3)
    def CreateRasterizer(self, xpsPage: win32more.Windows.Win32.Storage.Xps.IXpsOMPage, DPIX: Single, DPIY: Single, nonTextRenderingMode: win32more.Windows.Win32.Graphics.Printing.XPSRAS_RENDERING_MODE, textRenderingMode: win32more.Windows.Win32.Graphics.Printing.XPSRAS_RENDERING_MODE, pixelFormat: win32more.Windows.Win32.Graphics.Printing.XPSRAS_PIXEL_FORMAT, backgroundColor: win32more.Windows.Win32.Graphics.Printing.XPSRAS_BACKGROUND_COLOR, ppIXpsRasterizer: POINTER(win32more.Windows.Win32.Graphics.Printing.IXpsRasterizer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXpsRasterizer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7567cfc8-c156-47a8-9dac-11a2ae5bdd6b}')
    @commethod(3)
    def RasterizeRect(self, x: Int32, y: Int32, width: Int32, height: Int32, notificationCallback: win32more.Windows.Win32.Graphics.Printing.IXpsRasterizerNotificationCallback, bitmap: POINTER(win32more.Windows.Win32.Graphics.Imaging.IWICBitmap)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetMinimalLineWidth(self, width: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXpsRasterizerNotificationCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9ab8fd0d-cb94-49c2-9cb0-97ec1d5469d2}')
    @commethod(3)
    def Continue(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ImgErrorInfo(Structure):
    description: win32more.Windows.Win32.Foundation.BSTR
    guid: Guid
    helpContext: UInt32
    helpFile: win32more.Windows.Win32.Foundation.BSTR
    source: win32more.Windows.Win32.Foundation.BSTR
    devDescription: win32more.Windows.Win32.Foundation.BSTR
    errorID: Guid
    cUserParameters: UInt32
    aUserParameters: POINTER(win32more.Windows.Win32.Foundation.BSTR)
    userFallback: win32more.Windows.Win32.Foundation.BSTR
    exceptionID: UInt32
class JOB_INFO_1A(Structure):
    JobId: UInt32
    pPrinterName: win32more.Windows.Win32.Foundation.PSTR
    pMachineName: win32more.Windows.Win32.Foundation.PSTR
    pUserName: win32more.Windows.Win32.Foundation.PSTR
    pDocument: win32more.Windows.Win32.Foundation.PSTR
    pDatatype: win32more.Windows.Win32.Foundation.PSTR
    pStatus: win32more.Windows.Win32.Foundation.PSTR
    Status: UInt32
    Priority: UInt32
    Position: UInt32
    TotalPages: UInt32
    PagesPrinted: UInt32
    Submitted: win32more.Windows.Win32.Foundation.SYSTEMTIME
class JOB_INFO_1W(Structure):
    JobId: UInt32
    pPrinterName: win32more.Windows.Win32.Foundation.PWSTR
    pMachineName: win32more.Windows.Win32.Foundation.PWSTR
    pUserName: win32more.Windows.Win32.Foundation.PWSTR
    pDocument: win32more.Windows.Win32.Foundation.PWSTR
    pDatatype: win32more.Windows.Win32.Foundation.PWSTR
    pStatus: win32more.Windows.Win32.Foundation.PWSTR
    Status: UInt32
    Priority: UInt32
    Position: UInt32
    TotalPages: UInt32
    PagesPrinted: UInt32
    Submitted: win32more.Windows.Win32.Foundation.SYSTEMTIME
JOB_INFO_1 = UnicodeAlias('JOB_INFO_1W')
class JOB_INFO_2A(Structure):
    JobId: UInt32
    pPrinterName: win32more.Windows.Win32.Foundation.PSTR
    pMachineName: win32more.Windows.Win32.Foundation.PSTR
    pUserName: win32more.Windows.Win32.Foundation.PSTR
    pDocument: win32more.Windows.Win32.Foundation.PSTR
    pNotifyName: win32more.Windows.Win32.Foundation.PSTR
    pDatatype: win32more.Windows.Win32.Foundation.PSTR
    pPrintProcessor: win32more.Windows.Win32.Foundation.PSTR
    pParameters: win32more.Windows.Win32.Foundation.PSTR
    pDriverName: win32more.Windows.Win32.Foundation.PSTR
    pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)
    pStatus: win32more.Windows.Win32.Foundation.PSTR
    pSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR
    Status: UInt32
    Priority: UInt32
    Position: UInt32
    StartTime: UInt32
    UntilTime: UInt32
    TotalPages: UInt32
    Size: UInt32
    Submitted: win32more.Windows.Win32.Foundation.SYSTEMTIME
    Time: UInt32
    PagesPrinted: UInt32
class JOB_INFO_2W(Structure):
    JobId: UInt32
    pPrinterName: win32more.Windows.Win32.Foundation.PWSTR
    pMachineName: win32more.Windows.Win32.Foundation.PWSTR
    pUserName: win32more.Windows.Win32.Foundation.PWSTR
    pDocument: win32more.Windows.Win32.Foundation.PWSTR
    pNotifyName: win32more.Windows.Win32.Foundation.PWSTR
    pDatatype: win32more.Windows.Win32.Foundation.PWSTR
    pPrintProcessor: win32more.Windows.Win32.Foundation.PWSTR
    pParameters: win32more.Windows.Win32.Foundation.PWSTR
    pDriverName: win32more.Windows.Win32.Foundation.PWSTR
    pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW)
    pStatus: win32more.Windows.Win32.Foundation.PWSTR
    pSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR
    Status: UInt32
    Priority: UInt32
    Position: UInt32
    StartTime: UInt32
    UntilTime: UInt32
    TotalPages: UInt32
    Size: UInt32
    Submitted: win32more.Windows.Win32.Foundation.SYSTEMTIME
    Time: UInt32
    PagesPrinted: UInt32
JOB_INFO_2 = UnicodeAlias('JOB_INFO_2W')
class JOB_INFO_3(Structure):
    JobId: UInt32
    NextJobId: UInt32
    Reserved: UInt32
class JOB_INFO_4A(Structure):
    JobId: UInt32
    pPrinterName: win32more.Windows.Win32.Foundation.PSTR
    pMachineName: win32more.Windows.Win32.Foundation.PSTR
    pUserName: win32more.Windows.Win32.Foundation.PSTR
    pDocument: win32more.Windows.Win32.Foundation.PSTR
    pNotifyName: win32more.Windows.Win32.Foundation.PSTR
    pDatatype: win32more.Windows.Win32.Foundation.PSTR
    pPrintProcessor: win32more.Windows.Win32.Foundation.PSTR
    pParameters: win32more.Windows.Win32.Foundation.PSTR
    pDriverName: win32more.Windows.Win32.Foundation.PSTR
    pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)
    pStatus: win32more.Windows.Win32.Foundation.PSTR
    pSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR
    Status: UInt32
    Priority: UInt32
    Position: UInt32
    StartTime: UInt32
    UntilTime: UInt32
    TotalPages: UInt32
    Size: UInt32
    Submitted: win32more.Windows.Win32.Foundation.SYSTEMTIME
    Time: UInt32
    PagesPrinted: UInt32
    SizeHigh: Int32
class JOB_INFO_4W(Structure):
    JobId: UInt32
    pPrinterName: win32more.Windows.Win32.Foundation.PWSTR
    pMachineName: win32more.Windows.Win32.Foundation.PWSTR
    pUserName: win32more.Windows.Win32.Foundation.PWSTR
    pDocument: win32more.Windows.Win32.Foundation.PWSTR
    pNotifyName: win32more.Windows.Win32.Foundation.PWSTR
    pDatatype: win32more.Windows.Win32.Foundation.PWSTR
    pPrintProcessor: win32more.Windows.Win32.Foundation.PWSTR
    pParameters: win32more.Windows.Win32.Foundation.PWSTR
    pDriverName: win32more.Windows.Win32.Foundation.PWSTR
    pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW)
    pStatus: win32more.Windows.Win32.Foundation.PWSTR
    pSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR
    Status: UInt32
    Priority: UInt32
    Position: UInt32
    StartTime: UInt32
    UntilTime: UInt32
    TotalPages: UInt32
    Size: UInt32
    Submitted: win32more.Windows.Win32.Foundation.SYSTEMTIME
    Time: UInt32
    PagesPrinted: UInt32
    SizeHigh: Int32
JOB_INFO_4 = UnicodeAlias('JOB_INFO_4W')
class KERNDATA(Structure):
    dwSize: UInt32
    dwKernPairNum: UInt32
    KernPair: win32more.Windows.Win32.Devices.Display.FD_KERNINGPAIR * 1
class MAPTABLE(Structure):
    dwSize: UInt32
    dwGlyphNum: UInt32
    Trans: win32more.Windows.Win32.Graphics.Printing.TRANSDATA * 1
class MESSAGEBOX_PARAMS(Structure):
    cbSize: UInt32
    pTitle: win32more.Windows.Win32.Foundation.PWSTR
    pMessage: win32more.Windows.Win32.Foundation.PWSTR
    Style: UInt32
    dwTimeout: UInt32
    bWait: win32more.Windows.Win32.Foundation.BOOL
class MONITOR(Structure):
    pfnEnumPorts: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_ENUMPORTS
    pfnOpenPort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_OPENPORT
    pfnOpenPortEx: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_OPENPORTEX
    pfnStartDocPort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_STARTDOCPORT
    pfnWritePort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_WRITEPORT
    pfnReadPort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_READPORT
    pfnEndDocPort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_ENDDOCPORT
    pfnClosePort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_CLOSEPORT
    pfnAddPort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_ADDPORT
    pfnAddPortEx: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_ADDPORTEX
    pfnConfigurePort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_CONFIGUREPORT
    pfnDeletePort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_DELETEPORT
    pfnGetPrinterDataFromPort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_GETPRINTERDATAFROMPORT
    pfnSetPortTimeOuts: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_SETPORTTIMEOUTS
    pfnXcvOpenPort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_XCVOPENPORT
    pfnXcvDataPort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_XCVDATAPORT
    pfnXcvClosePort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_XCVCLOSEPORT
class MONITOR2(Structure):
    cbSize: UInt32
    pfnEnumPorts: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_ENUMPORTS2
    pfnOpenPort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_OPENPORT2
    pfnOpenPortEx: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_OPENPORTEX2
    pfnStartDocPort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_STARTDOCPORT2
    pfnWritePort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_WRITEPORT2
    pfnReadPort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_READPORT2
    pfnEndDocPort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_ENDDOCPORT2
    pfnClosePort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_CLOSEPORT2
    pfnAddPort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_ADDPORT2
    pfnAddPortEx: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_ADDPORTEX2
    pfnConfigurePort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_CONFIGUREPORT2
    pfnDeletePort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_DELETEPORT2
    pfnGetPrinterDataFromPort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_GETPRINTERDATAFROMPORT2
    pfnSetPortTimeOuts: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_SETPORTTIMEOUTS2
    pfnXcvOpenPort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_XCVOPENPORT2
    pfnXcvDataPort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_XCVDATAPORT2
    pfnXcvClosePort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_XCVCLOSEPORT2
    pfnShutdown: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_SHUTDOWN2
    pfnSendRecvBidiDataFromPort: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_SENDRECVBIDIDATAFROMPORT2
    pfnNotifyUsedPorts: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_NOTIFYUSEDPORTS2
    pfnNotifyUnusedPorts: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_NOTIFYUNUSEDPORTS2
    pfnPowerEvent: win32more.Windows.Win32.Graphics.Printing.PFN_PRINTING_POWEREVENT2
class MONITOREX(Structure):
    dwMonitorSize: UInt32
    Monitor: win32more.Windows.Win32.Graphics.Printing.MONITOR
class MONITORINIT(Structure):
    cbSize: UInt32
    hSpooler: win32more.Windows.Win32.Foundation.HANDLE
    hckRegistryRoot: win32more.Windows.Win32.System.Registry.HKEY
    pMonitorReg: POINTER(win32more.Windows.Win32.Graphics.Printing.MONITORREG)
    bLocal: win32more.Windows.Win32.Foundation.BOOL
    pszServerName: win32more.Windows.Win32.Foundation.PWSTR
class MONITORREG(Structure):
    cbSize: UInt32
    fpCreateKey: IntPtr
    fpOpenKey: IntPtr
    fpCloseKey: IntPtr
    fpDeleteKey: IntPtr
    fpEnumKey: IntPtr
    fpQueryInfoKey: IntPtr
    fpSetValue: IntPtr
    fpDeleteValue: IntPtr
    fpEnumValue: IntPtr
    fpQueryValue: IntPtr
class MONITORUI(Structure):
    dwMonitorUISize: UInt32
    pfnAddPortUI: IntPtr
    pfnConfigurePortUI: IntPtr
    pfnDeletePortUI: IntPtr
class MONITOR_INFO_1A(Structure):
    pName: win32more.Windows.Win32.Foundation.PSTR
class MONITOR_INFO_1W(Structure):
    pName: win32more.Windows.Win32.Foundation.PWSTR
MONITOR_INFO_1 = UnicodeAlias('MONITOR_INFO_1W')
class MONITOR_INFO_2A(Structure):
    pName: win32more.Windows.Win32.Foundation.PSTR
    pEnvironment: win32more.Windows.Win32.Foundation.PSTR
    pDLLName: win32more.Windows.Win32.Foundation.PSTR
class MONITOR_INFO_2W(Structure):
    pName: win32more.Windows.Win32.Foundation.PWSTR
    pEnvironment: win32more.Windows.Win32.Foundation.PWSTR
    pDLLName: win32more.Windows.Win32.Foundation.PWSTR
MONITOR_INFO_2 = UnicodeAlias('MONITOR_INFO_2W')
class MXDC_ESCAPE_HEADER_T(Structure):
    cbInput: UInt32
    cbOutput: UInt32
    opCode: UInt32
    _pack_ = 1
class MXDC_GET_FILENAME_DATA_T(Structure):
    cbOutput: UInt32
    wszData: Char * 1
    _pack_ = 1
MXDC_IMAGE_TYPE_ENUMS = Int32
MXDC_IMAGETYPE_JPEGHIGH_COMPRESSION: win32more.Windows.Win32.Graphics.Printing.MXDC_IMAGE_TYPE_ENUMS = 1
MXDC_IMAGETYPE_JPEGMEDIUM_COMPRESSION: win32more.Windows.Win32.Graphics.Printing.MXDC_IMAGE_TYPE_ENUMS = 2
MXDC_IMAGETYPE_JPEGLOW_COMPRESSION: win32more.Windows.Win32.Graphics.Printing.MXDC_IMAGE_TYPE_ENUMS = 3
MXDC_IMAGETYPE_PNG: win32more.Windows.Win32.Graphics.Printing.MXDC_IMAGE_TYPE_ENUMS = 4
MXDC_LANDSCAPE_ROTATION_ENUMS = Int32
MXDC_LANDSCAPE_ROTATE_COUNTERCLOCKWISE_90_DEGREES: win32more.Windows.Win32.Graphics.Printing.MXDC_LANDSCAPE_ROTATION_ENUMS = 90
MXDC_LANDSCAPE_ROTATE_NONE: win32more.Windows.Win32.Graphics.Printing.MXDC_LANDSCAPE_ROTATION_ENUMS = 0
MXDC_LANDSCAPE_ROTATE_COUNTERCLOCKWISE_270_DEGREES: win32more.Windows.Win32.Graphics.Printing.MXDC_LANDSCAPE_ROTATION_ENUMS = -90
class MXDC_PRINTTICKET_DATA_T(Structure):
    dwDataSize: UInt32
    bData: Byte * 1
    _pack_ = 1
class MXDC_PRINTTICKET_ESCAPE_T(Structure):
    mxdcEscape: win32more.Windows.Win32.Graphics.Printing.MXDC_ESCAPE_HEADER_T
    printTicketData: win32more.Windows.Win32.Graphics.Printing.MXDC_PRINTTICKET_DATA_T
    _pack_ = 1
class MXDC_S0PAGE_DATA_T(Structure):
    dwSize: UInt32
    bData: Byte * 1
    _pack_ = 1
class MXDC_S0PAGE_PASSTHROUGH_ESCAPE_T(Structure):
    mxdcEscape: win32more.Windows.Win32.Graphics.Printing.MXDC_ESCAPE_HEADER_T
    xpsS0PageData: win32more.Windows.Win32.Graphics.Printing.MXDC_S0PAGE_DATA_T
    _pack_ = 1
class MXDC_S0PAGE_RESOURCE_ESCAPE_T(Structure):
    mxdcEscape: win32more.Windows.Win32.Graphics.Printing.MXDC_ESCAPE_HEADER_T
    xpsS0PageResourcePassthrough: win32more.Windows.Win32.Graphics.Printing.MXDC_XPS_S0PAGE_RESOURCE_T
    _pack_ = 1
MXDC_S0_PAGE_ENUMS = Int32
MXDC_RESOURCE_TTF: win32more.Windows.Win32.Graphics.Printing.MXDC_S0_PAGE_ENUMS = 0
MXDC_RESOURCE_JPEG: win32more.Windows.Win32.Graphics.Printing.MXDC_S0_PAGE_ENUMS = 1
MXDC_RESOURCE_PNG: win32more.Windows.Win32.Graphics.Printing.MXDC_S0_PAGE_ENUMS = 2
MXDC_RESOURCE_TIFF: win32more.Windows.Win32.Graphics.Printing.MXDC_S0_PAGE_ENUMS = 3
MXDC_RESOURCE_WDP: win32more.Windows.Win32.Graphics.Printing.MXDC_S0_PAGE_ENUMS = 4
MXDC_RESOURCE_DICTIONARY: win32more.Windows.Win32.Graphics.Printing.MXDC_S0_PAGE_ENUMS = 5
MXDC_RESOURCE_ICC_PROFILE: win32more.Windows.Win32.Graphics.Printing.MXDC_S0_PAGE_ENUMS = 6
MXDC_RESOURCE_JPEG_THUMBNAIL: win32more.Windows.Win32.Graphics.Printing.MXDC_S0_PAGE_ENUMS = 7
MXDC_RESOURCE_PNG_THUMBNAIL: win32more.Windows.Win32.Graphics.Printing.MXDC_S0_PAGE_ENUMS = 8
MXDC_RESOURCE_MAX: win32more.Windows.Win32.Graphics.Printing.MXDC_S0_PAGE_ENUMS = 9
class MXDC_XPS_S0PAGE_RESOURCE_T(Structure):
    dwSize: UInt32
    dwResourceType: UInt32
    szUri: Byte * 260
    dwDataSize: UInt32
    bData: Byte * 1
    _pack_ = 1
NOTIFICATION_CALLBACK_COMMANDS = Int32
NOTIFICATION_COMMAND_NOTIFY: win32more.Windows.Win32.Graphics.Printing.NOTIFICATION_CALLBACK_COMMANDS = 0
NOTIFICATION_COMMAND_CONTEXT_ACQUIRE: win32more.Windows.Win32.Graphics.Printing.NOTIFICATION_CALLBACK_COMMANDS = 1
NOTIFICATION_COMMAND_CONTEXT_RELEASE: win32more.Windows.Win32.Graphics.Printing.NOTIFICATION_CALLBACK_COMMANDS = 2
class NOTIFICATION_CONFIG_1(Structure):
    cbSize: UInt32
    fdwFlags: UInt32
    pfnNotifyCallback: win32more.Windows.Win32.Graphics.Printing.ROUTER_NOTIFY_CALLBACK
    pContext: VoidPtr
NOTIFICATION_CONFIG_FLAGS = Int32
NOTIFICATION_CONFIG_CREATE_EVENT: win32more.Windows.Win32.Graphics.Printing.NOTIFICATION_CONFIG_FLAGS = 1
NOTIFICATION_CONFIG_REGISTER_CALLBACK: win32more.Windows.Win32.Graphics.Printing.NOTIFICATION_CONFIG_FLAGS = 2
NOTIFICATION_CONFIG_EVENT_TRIGGER: win32more.Windows.Win32.Graphics.Printing.NOTIFICATION_CONFIG_FLAGS = 4
NOTIFICATION_CONFIG_ASYNC_CHANNEL: win32more.Windows.Win32.Graphics.Printing.NOTIFICATION_CONFIG_FLAGS = 8
@winfunctype_pointer
def OEMCUIPCALLBACK(param0: POINTER(win32more.Windows.Win32.Graphics.Printing.CPSUICBPARAM), param1: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMCUIPPARAM)) -> Int32: ...
class OEMCUIPPARAM(Structure):
    cbSize: UInt32
    poemuiobj: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMUIOBJ)
    hPrinter: win32more.Windows.Win32.Foundation.HANDLE
    pPrinterName: win32more.Windows.Win32.Foundation.PWSTR
    hModule: win32more.Windows.Win32.Foundation.HANDLE
    hOEMHeap: win32more.Windows.Win32.Foundation.HANDLE
    pPublicDM: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)
    pOEMDM: VoidPtr
    dwFlags: UInt32
    pDrvOptItems: POINTER(win32more.Windows.Win32.Graphics.Printing.OPTITEM)
    cDrvOptItems: UInt32
    pOEMOptItems: POINTER(win32more.Windows.Win32.Graphics.Printing.OPTITEM)
    cOEMOptItems: UInt32
    pOEMUserData: VoidPtr
    OEMCUIPCallback: win32more.Windows.Win32.Graphics.Printing.OEMCUIPCALLBACK
class OEMDMPARAM(Structure):
    cbSize: UInt32
    pdriverobj: VoidPtr
    hPrinter: win32more.Windows.Win32.Foundation.HANDLE
    hModule: win32more.Windows.Win32.Foundation.HANDLE
    pPublicDMIn: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)
    pPublicDMOut: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)
    pOEMDMIn: VoidPtr
    pOEMDMOut: VoidPtr
    cbBufSize: UInt32
class OEMFONTINSTPARAM(Structure):
    cbSize: UInt32
    hPrinter: win32more.Windows.Win32.Foundation.HANDLE
    hModule: win32more.Windows.Win32.Foundation.HANDLE
    hHeap: win32more.Windows.Win32.Foundation.HANDLE
    dwFlags: UInt32
    pFontInstallerName: win32more.Windows.Win32.Foundation.PWSTR
class OEMUIOBJ(Structure):
    cbSize: UInt32
    pOemUIProcs: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMUIPROCS)
class OEMUIPROCS(Structure):
    DrvGetDriverSetting: win32more.Windows.Win32.Graphics.Printing.PFN_DrvGetDriverSetting
    DrvUpdateUISetting: win32more.Windows.Win32.Graphics.Printing.PFN_DrvUpdateUISetting
class OEMUIPSPARAM(Structure):
    cbSize: UInt32
    poemuiobj: POINTER(win32more.Windows.Win32.Graphics.Printing.OEMUIOBJ)
    hPrinter: win32more.Windows.Win32.Foundation.HANDLE
    pPrinterName: win32more.Windows.Win32.Foundation.PWSTR
    hModule: win32more.Windows.Win32.Foundation.HANDLE
    hOEMHeap: win32more.Windows.Win32.Foundation.HANDLE
    pPublicDM: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)
    pOEMDM: VoidPtr
    pOEMUserData: VoidPtr
    dwFlags: UInt32
    pOemEntry: VoidPtr
class OEM_DMEXTRAHEADER(Structure):
    dwSize: UInt32
    dwSignature: UInt32
    dwVersion: UInt32
class OIEXT(Structure):
    cbSize: UInt16
    Flags: UInt16
    hInstCaller: win32more.Windows.Win32.Foundation.HINSTANCE
    pHelpFile: POINTER(SByte)
    dwReserved: UIntPtr * 4
class OPTCOMBO(Structure):
    cbSize: UInt16
    Flags: Byte
    cListItem: UInt16
    pListItem: POINTER(win32more.Windows.Win32.Graphics.Printing.OPTPARAM)
    Sel: Int32
    dwReserved: UInt32 * 3
class OPTITEM(Structure):
    cbSize: UInt16
    Level: Byte
    DlgPageIdx: Byte
    Flags: UInt32
    UserData: UIntPtr
    pName: POINTER(SByte)
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    pOptType: POINTER(win32more.Windows.Win32.Graphics.Printing.OPTTYPE)
    HelpIndex: UInt32
    DMPubID: Byte
    UserItemID: Byte
    wReserved: UInt16
    pOIExt: POINTER(win32more.Windows.Win32.Graphics.Printing.OIEXT)
    dwReserved: UIntPtr * 3
    class _Anonymous1_e__Union(Union):
        Sel: Int32
        pSel: POINTER(SByte)
    class _Anonymous2_e__Union(Union):
        pExtChkBox: POINTER(win32more.Windows.Win32.Graphics.Printing.EXTCHKBOX)
        pExtPush: POINTER(win32more.Windows.Win32.Graphics.Printing.EXTPUSH)
class OPTPARAM(Structure):
    cbSize: UInt16
    Flags: Byte
    Style: Byte
    pData: POINTER(SByte)
    IconID: UIntPtr
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    dwReserved: UIntPtr * 2
class OPTTYPE(Structure):
    cbSize: UInt16
    Type: Byte
    Flags: Byte
    Count: UInt16
    BegCtrlID: UInt16
    pOptParam: POINTER(win32more.Windows.Win32.Graphics.Printing.OPTPARAM)
    Style: UInt16
    wReserved: UInt16 * 3
    dwReserved: UIntPtr * 3
@winfunctype_pointer
def PFNCOMPROPSHEET(hComPropSheet: win32more.Windows.Win32.Foundation.HANDLE, Function: UInt32, lParam1: win32more.Windows.Win32.Foundation.LPARAM, lParam2: win32more.Windows.Win32.Foundation.LPARAM) -> IntPtr: ...
@winfunctype_pointer
def PFNPROPSHEETUI(pPSUIInfo: POINTER(win32more.Windows.Win32.Graphics.Printing.PROPSHEETUI_INFO), lParam: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype_pointer
def PFN_DrvGetDriverSetting(pdriverobj: VoidPtr, Feature: win32more.Windows.Win32.Foundation.PSTR, pOutput: VoidPtr, cbSize: UInt32, pcbNeeded: POINTER(UInt32), pdwOptionsReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_DrvUpdateUISetting(pdriverobj: VoidPtr, pOptItem: VoidPtr, dwPreviousSelection: UInt32, dwMode: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_DrvUpgradeRegistrySetting(hPrinter: win32more.Windows.Win32.Foundation.HANDLE, pFeature: win32more.Windows.Win32.Foundation.PSTR, pOption: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_ADDPORT(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: win32more.Windows.Win32.Foundation.HWND, param2: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_ADDPORT2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: win32more.Windows.Win32.Foundation.HWND, param3: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_ADDPORTEX(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: UInt32, param2: POINTER(Byte), param3: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_ADDPORTEX2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: UInt32, param3: POINTER(Byte), param4: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_CLOSEPORT(param0: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_CLOSEPORT2(param0: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_CONFIGUREPORT(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: win32more.Windows.Win32.Foundation.HWND, param2: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_CONFIGUREPORT2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: win32more.Windows.Win32.Foundation.HWND, param3: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_DELETEPORT(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: win32more.Windows.Win32.Foundation.HWND, param2: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_DELETEPORT2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: win32more.Windows.Win32.Foundation.HWND, param3: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_ENDDOCPORT(param0: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_ENDDOCPORT2(param0: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_ENUMPORTS(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: UInt32, param2: POINTER(Byte), param3: UInt32, param4: POINTER(UInt32), param5: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_ENUMPORTS2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: UInt32, param3: POINTER(Byte), param4: UInt32, param5: POINTER(UInt32), param6: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_GETPRINTERDATAFROMPORT(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: UInt32, param2: win32more.Windows.Win32.Foundation.PWSTR, param3: win32more.Windows.Win32.Foundation.PWSTR, param4: UInt32, param5: win32more.Windows.Win32.Foundation.PWSTR, param6: UInt32, param7: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_GETPRINTERDATAFROMPORT2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: UInt32, param2: win32more.Windows.Win32.Foundation.PWSTR, param3: win32more.Windows.Win32.Foundation.PWSTR, param4: UInt32, param5: win32more.Windows.Win32.Foundation.PWSTR, param6: UInt32, param7: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_NOTIFYUNUSEDPORTS2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: UInt32, param2: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PFN_PRINTING_NOTIFYUSEDPORTS2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: UInt32, param2: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PFN_PRINTING_OPENPORT(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_OPENPORT2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_OPENPORTEX(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: win32more.Windows.Win32.Foundation.PWSTR, param3: POINTER(win32more.Windows.Win32.Foundation.HANDLE), param4: POINTER(win32more.Windows.Win32.Graphics.Printing.MONITOR2)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_OPENPORTEX2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.HANDLE, param2: win32more.Windows.Win32.Foundation.PWSTR, param3: win32more.Windows.Win32.Foundation.PWSTR, param4: POINTER(win32more.Windows.Win32.Foundation.HANDLE), param5: POINTER(win32more.Windows.Win32.Graphics.Printing.MONITOR2)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_POWEREVENT2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: UInt32, param2: POINTER(win32more.Windows.Win32.System.Power.POWERBROADCAST_SETTING)) -> UInt32: ...
@winfunctype_pointer
def PFN_PRINTING_READPORT(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: POINTER(Byte), param2: UInt32, param3: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_READPORT2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: POINTER(Byte), param2: UInt32, param3: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_SENDRECVBIDIDATAFROMPORT2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: UInt32, param2: win32more.Windows.Win32.Foundation.PWSTR, param3: POINTER(win32more.Windows.Win32.Graphics.Printing.BIDI_REQUEST_CONTAINER), param4: POINTER(POINTER(win32more.Windows.Win32.Graphics.Printing.BIDI_RESPONSE_CONTAINER))) -> UInt32: ...
@winfunctype_pointer
def PFN_PRINTING_SETPORTTIMEOUTS(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: POINTER(win32more.Windows.Win32.Devices.Communication.COMMTIMEOUTS), param2: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_SETPORTTIMEOUTS2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: POINTER(win32more.Windows.Win32.Devices.Communication.COMMTIMEOUTS), param2: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_SHUTDOWN2(param0: win32more.Windows.Win32.Foundation.HANDLE) -> Void: ...
@winfunctype_pointer
def PFN_PRINTING_STARTDOCPORT(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: UInt32, param3: UInt32, param4: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_STARTDOCPORT2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: UInt32, param3: UInt32, param4: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_WRITEPORT(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: POINTER(Byte), param2: UInt32, param3: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_WRITEPORT2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: POINTER(Byte), param2: UInt32, param3: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_XCVCLOSEPORT(param0: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_XCVCLOSEPORT2(param0: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_XCVDATAPORT(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: POINTER(Byte), param3: UInt32, param4: POINTER(Byte), param5: UInt32, param6: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PFN_PRINTING_XCVDATAPORT2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: POINTER(Byte), param3: UInt32, param4: POINTER(Byte), param5: UInt32, param6: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PFN_PRINTING_XCVOPENPORT(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: UInt32, param2: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_PRINTING_XCVOPENPORT2(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: UInt32, param3: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
class PORT_DATA_1(Structure):
    sztPortName: Char * 64
    dwVersion: UInt32
    dwProtocol: UInt32
    cbSize: UInt32
    dwReserved: UInt32
    sztHostAddress: Char * 49
    sztSNMPCommunity: Char * 33
    dwDoubleSpool: UInt32
    sztQueue: Char * 33
    sztIPAddress: Char * 16
    Reserved: Byte * 540
    dwPortNumber: UInt32
    dwSNMPEnabled: UInt32
    dwSNMPDevIndex: UInt32
class PORT_DATA_2(Structure):
    sztPortName: Char * 64
    dwVersion: UInt32
    dwProtocol: UInt32
    cbSize: UInt32
    dwReserved: UInt32
    sztHostAddress: Char * 128
    sztSNMPCommunity: Char * 33
    dwDoubleSpool: UInt32
    sztQueue: Char * 33
    Reserved: Byte * 514
    dwPortNumber: UInt32
    dwSNMPEnabled: UInt32
    dwSNMPDevIndex: UInt32
    dwPortMonitorMibIndex: UInt32
class PORT_DATA_LIST_1(Structure):
    dwVersion: UInt32
    cPortData: UInt32
    pPortData: win32more.Windows.Win32.Graphics.Printing.PORT_DATA_2 * 1
class PORT_INFO_1A(Structure):
    pName: win32more.Windows.Win32.Foundation.PSTR
class PORT_INFO_1W(Structure):
    pName: win32more.Windows.Win32.Foundation.PWSTR
PORT_INFO_1 = UnicodeAlias('PORT_INFO_1W')
class PORT_INFO_2A(Structure):
    pPortName: win32more.Windows.Win32.Foundation.PSTR
    pMonitorName: win32more.Windows.Win32.Foundation.PSTR
    pDescription: win32more.Windows.Win32.Foundation.PSTR
    fPortType: UInt32
    Reserved: UInt32
class PORT_INFO_2W(Structure):
    pPortName: win32more.Windows.Win32.Foundation.PWSTR
    pMonitorName: win32more.Windows.Win32.Foundation.PWSTR
    pDescription: win32more.Windows.Win32.Foundation.PWSTR
    fPortType: UInt32
    Reserved: UInt32
PORT_INFO_2 = UnicodeAlias('PORT_INFO_2W')
class PORT_INFO_3A(Structure):
    dwStatus: UInt32
    pszStatus: win32more.Windows.Win32.Foundation.PSTR
    dwSeverity: UInt32
class PORT_INFO_3W(Structure):
    dwStatus: UInt32
    pszStatus: win32more.Windows.Win32.Foundation.PWSTR
    dwSeverity: UInt32
PORT_INFO_3 = UnicodeAlias('PORT_INFO_3W')
PRINTER_ACCESS_RIGHTS = UInt32
PRINTER_ALL_ACCESS: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 983052
PRINTER_READ: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 131080
PRINTER_WRITE: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 131080
PRINTER_EXECUTE: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 131080
SERVER_ALL_ACCESS: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 983043
SERVER_READ: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 131074
SERVER_WRITE: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 131075
SERVER_EXECUTE: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 131074
PRINTER_DELETE: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 65536
PRINTER_READ_CONTROL: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 131072
PRINTER_WRITE_DAC: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 262144
PRINTER_WRITE_OWNER: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 524288
PRINTER_SYNCHRONIZE: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 1048576
PRINTER_STANDARD_RIGHTS_REQUIRED: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 983040
PRINTER_STANDARD_RIGHTS_READ: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 131072
PRINTER_STANDARD_RIGHTS_WRITE: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 131072
PRINTER_STANDARD_RIGHTS_EXECUTE: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 131072
SERVER_ACCESS_ADMINISTER: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 1
SERVER_ACCESS_ENUMERATE: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 2
PRINTER_ACCESS_ADMINISTER: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 4
PRINTER_ACCESS_USE: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 8
PRINTER_ACCESS_MANAGE_LIMITED: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS = 64
class PRINTER_CONNECTION_INFO_1A(Structure):
    dwFlags: UInt32
    pszDriverName: win32more.Windows.Win32.Foundation.PSTR
class PRINTER_CONNECTION_INFO_1W(Structure):
    dwFlags: UInt32
    pszDriverName: win32more.Windows.Win32.Foundation.PWSTR
PRINTER_CONNECTION_INFO_1 = UnicodeAlias('PRINTER_CONNECTION_INFO_1W')
class PRINTER_DEFAULTSA(Structure):
    pDatatype: win32more.Windows.Win32.Foundation.PSTR
    pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)
    DesiredAccess: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS
class PRINTER_DEFAULTSW(Structure):
    pDatatype: win32more.Windows.Win32.Foundation.PWSTR
    pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW)
    DesiredAccess: win32more.Windows.Win32.Graphics.Printing.PRINTER_ACCESS_RIGHTS
PRINTER_DEFAULTS = UnicodeAlias('PRINTER_DEFAULTSW')
class PRINTER_ENUM_VALUESA(Structure):
    pValueName: win32more.Windows.Win32.Foundation.PSTR
    cbValueName: UInt32
    dwType: UInt32
    pData: POINTER(Byte)
    cbData: UInt32
class PRINTER_ENUM_VALUESW(Structure):
    pValueName: win32more.Windows.Win32.Foundation.PWSTR
    cbValueName: UInt32
    dwType: UInt32
    pData: POINTER(Byte)
    cbData: UInt32
PRINTER_ENUM_VALUES = UnicodeAlias('PRINTER_ENUM_VALUESW')
class PRINTER_EVENT_ATTRIBUTES_INFO(Structure):
    cbSize: UInt32
    dwOldAttributes: UInt32
    dwNewAttributes: UInt32
class PRINTER_HANDLE(Structure):
    Value: VoidPtr
class PRINTER_INFO_1A(Structure):
    Flags: UInt32
    pDescription: win32more.Windows.Win32.Foundation.PSTR
    pName: win32more.Windows.Win32.Foundation.PSTR
    pComment: win32more.Windows.Win32.Foundation.PSTR
class PRINTER_INFO_1W(Structure):
    Flags: UInt32
    pDescription: win32more.Windows.Win32.Foundation.PWSTR
    pName: win32more.Windows.Win32.Foundation.PWSTR
    pComment: win32more.Windows.Win32.Foundation.PWSTR
PRINTER_INFO_1 = UnicodeAlias('PRINTER_INFO_1W')
class PRINTER_INFO_2A(Structure):
    pServerName: win32more.Windows.Win32.Foundation.PSTR
    pPrinterName: win32more.Windows.Win32.Foundation.PSTR
    pShareName: win32more.Windows.Win32.Foundation.PSTR
    pPortName: win32more.Windows.Win32.Foundation.PSTR
    pDriverName: win32more.Windows.Win32.Foundation.PSTR
    pComment: win32more.Windows.Win32.Foundation.PSTR
    pLocation: win32more.Windows.Win32.Foundation.PSTR
    pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)
    pSepFile: win32more.Windows.Win32.Foundation.PSTR
    pPrintProcessor: win32more.Windows.Win32.Foundation.PSTR
    pDatatype: win32more.Windows.Win32.Foundation.PSTR
    pParameters: win32more.Windows.Win32.Foundation.PSTR
    pSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR
    Attributes: UInt32
    Priority: UInt32
    DefaultPriority: UInt32
    StartTime: UInt32
    UntilTime: UInt32
    Status: UInt32
    cJobs: UInt32
    AveragePPM: UInt32
class PRINTER_INFO_2W(Structure):
    pServerName: win32more.Windows.Win32.Foundation.PWSTR
    pPrinterName: win32more.Windows.Win32.Foundation.PWSTR
    pShareName: win32more.Windows.Win32.Foundation.PWSTR
    pPortName: win32more.Windows.Win32.Foundation.PWSTR
    pDriverName: win32more.Windows.Win32.Foundation.PWSTR
    pComment: win32more.Windows.Win32.Foundation.PWSTR
    pLocation: win32more.Windows.Win32.Foundation.PWSTR
    pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW)
    pSepFile: win32more.Windows.Win32.Foundation.PWSTR
    pPrintProcessor: win32more.Windows.Win32.Foundation.PWSTR
    pDatatype: win32more.Windows.Win32.Foundation.PWSTR
    pParameters: win32more.Windows.Win32.Foundation.PWSTR
    pSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR
    Attributes: UInt32
    Priority: UInt32
    DefaultPriority: UInt32
    StartTime: UInt32
    UntilTime: UInt32
    Status: UInt32
    cJobs: UInt32
    AveragePPM: UInt32
PRINTER_INFO_2 = UnicodeAlias('PRINTER_INFO_2W')
class PRINTER_INFO_3(Structure):
    pSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR
class PRINTER_INFO_4A(Structure):
    pPrinterName: win32more.Windows.Win32.Foundation.PSTR
    pServerName: win32more.Windows.Win32.Foundation.PSTR
    Attributes: UInt32
class PRINTER_INFO_4W(Structure):
    pPrinterName: win32more.Windows.Win32.Foundation.PWSTR
    pServerName: win32more.Windows.Win32.Foundation.PWSTR
    Attributes: UInt32
PRINTER_INFO_4 = UnicodeAlias('PRINTER_INFO_4W')
class PRINTER_INFO_5A(Structure):
    pPrinterName: win32more.Windows.Win32.Foundation.PSTR
    pPortName: win32more.Windows.Win32.Foundation.PSTR
    Attributes: UInt32
    DeviceNotSelectedTimeout: UInt32
    TransmissionRetryTimeout: UInt32
class PRINTER_INFO_5W(Structure):
    pPrinterName: win32more.Windows.Win32.Foundation.PWSTR
    pPortName: win32more.Windows.Win32.Foundation.PWSTR
    Attributes: UInt32
    DeviceNotSelectedTimeout: UInt32
    TransmissionRetryTimeout: UInt32
PRINTER_INFO_5 = UnicodeAlias('PRINTER_INFO_5W')
class PRINTER_INFO_6(Structure):
    dwStatus: UInt32
class PRINTER_INFO_7A(Structure):
    pszObjectGUID: win32more.Windows.Win32.Foundation.PSTR
    dwAction: UInt32
class PRINTER_INFO_7W(Structure):
    pszObjectGUID: win32more.Windows.Win32.Foundation.PWSTR
    dwAction: UInt32
PRINTER_INFO_7 = UnicodeAlias('PRINTER_INFO_7W')
class PRINTER_INFO_8A(Structure):
    pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)
class PRINTER_INFO_8W(Structure):
    pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW)
PRINTER_INFO_8 = UnicodeAlias('PRINTER_INFO_8W')
class PRINTER_INFO_9A(Structure):
    pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)
class PRINTER_INFO_9W(Structure):
    pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEW)
PRINTER_INFO_9 = UnicodeAlias('PRINTER_INFO_9W')
class PRINTER_NOTIFY_INFO(Structure):
    Version: UInt32
    Flags: UInt32
    Count: UInt32
    aData: win32more.Windows.Win32.Graphics.Printing.PRINTER_NOTIFY_INFO_DATA * 1
class PRINTER_NOTIFY_INFO_DATA(Structure):
    Type: UInt16
    Field: UInt16
    Reserved: UInt32
    Id: UInt32
    NotifyData: _NotifyData_e__Union
    class _NotifyData_e__Union(Union):
        adwData: UInt32 * 2
        Data: _Data_e__Struct
        class _Data_e__Struct(Structure):
            cbBuf: UInt32
            pBuf: VoidPtr
class PRINTER_NOTIFY_INIT(Structure):
    Size: UInt32
    Reserved: UInt32
    PollTime: UInt32
class PRINTER_NOTIFY_OPTIONS(Structure):
    Version: UInt32
    Flags: UInt32
    Count: UInt32
    pTypes: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_NOTIFY_OPTIONS_TYPE)
class PRINTER_NOTIFY_OPTIONS_TYPE(Structure):
    Type: UInt16
    Reserved0: UInt16
    Reserved1: UInt32
    Reserved2: UInt32
    Count: UInt32
    pFields: POINTER(UInt16)
class PRINTER_OPTIONSA(Structure):
    cbSize: UInt32
    dwFlags: UInt32
class PRINTER_OPTIONSW(Structure):
    cbSize: UInt32
    dwFlags: UInt32
PRINTER_OPTIONS = UnicodeAlias('PRINTER_OPTIONSW')
PRINTER_OPTION_FLAGS = Int32
PRINTER_OPTION_NO_CACHE: win32more.Windows.Win32.Graphics.Printing.PRINTER_OPTION_FLAGS = 1
PRINTER_OPTION_CACHE: win32more.Windows.Win32.Graphics.Printing.PRINTER_OPTION_FLAGS = 2
PRINTER_OPTION_CLIENT_CHANGE: win32more.Windows.Win32.Graphics.Printing.PRINTER_OPTION_FLAGS = 4
PRINTER_OPTION_NO_CLIENT_DATA: win32more.Windows.Win32.Graphics.Printing.PRINTER_OPTION_FLAGS = 8
class PRINTIFI32(Structure):
    cjThis: UInt32
    cjIfiExtra: UInt32
    dpwszFamilyName: Int32
    dpwszStyleName: Int32
    dpwszFaceName: Int32
    dpwszUniqueName: Int32
    dpFontSim: Int32
    lEmbedId: Int32
    lItalicAngle: Int32
    lCharBias: Int32
    dpCharSets: Int32
    jWinCharSet: Byte
    jWinPitchAndFamily: Byte
    usWinWeight: UInt16
    flInfo: UInt32
    fsSelection: UInt16
    fsType: UInt16
    fwdUnitsPerEm: Int16
    fwdLowestPPEm: Int16
    fwdWinAscender: Int16
    fwdWinDescender: Int16
    fwdMacAscender: Int16
    fwdMacDescender: Int16
    fwdMacLineGap: Int16
    fwdTypoAscender: Int16
    fwdTypoDescender: Int16
    fwdTypoLineGap: Int16
    fwdAveCharWidth: Int16
    fwdMaxCharInc: Int16
    fwdCapHeight: Int16
    fwdXHeight: Int16
    fwdSubscriptXSize: Int16
    fwdSubscriptYSize: Int16
    fwdSubscriptXOffset: Int16
    fwdSubscriptYOffset: Int16
    fwdSuperscriptXSize: Int16
    fwdSuperscriptYSize: Int16
    fwdSuperscriptXOffset: Int16
    fwdSuperscriptYOffset: Int16
    fwdUnderscoreSize: Int16
    fwdUnderscorePosition: Int16
    fwdStrikeoutSize: Int16
    fwdStrikeoutPosition: Int16
    chFirstChar: Byte
    chLastChar: Byte
    chDefaultChar: Byte
    chBreakChar: Byte
    wcFirstChar: Char
    wcLastChar: Char
    wcDefaultChar: Char
    wcBreakChar: Char
    ptlBaseline: win32more.Windows.Win32.Foundation.POINTL
    ptlAspect: win32more.Windows.Win32.Foundation.POINTL
    ptlCaret: win32more.Windows.Win32.Foundation.POINTL
    rclFontBox: win32more.Windows.Win32.Foundation.RECTL
    achVendId: Byte * 4
    cKerningPairs: UInt32
    ulPanoseCulture: UInt32
    panose: win32more.Windows.Win32.Graphics.Gdi.PANOSE
class PRINTPROCESSOROPENDATA(Structure):
    pDevMode: POINTER(win32more.Windows.Win32.Graphics.Gdi.DEVMODEA)
    pDatatype: win32more.Windows.Win32.Foundation.PWSTR
    pParameters: win32more.Windows.Win32.Foundation.PWSTR
    pDocumentName: win32more.Windows.Win32.Foundation.PWSTR
    JobId: UInt32
    pOutputFile: win32more.Windows.Win32.Foundation.PWSTR
    pPrinterName: win32more.Windows.Win32.Foundation.PWSTR
class PRINTPROCESSOR_CAPS_1(Structure):
    dwLevel: UInt32
    dwNupOptions: UInt32
    dwPageOrderFlags: UInt32
    dwNumberOfCopies: UInt32
class PRINTPROCESSOR_CAPS_2(Structure):
    dwLevel: UInt32
    dwNupOptions: UInt32
    dwPageOrderFlags: UInt32
    dwNumberOfCopies: UInt32
    dwDuplexHandlingCaps: UInt32
    dwNupDirectionCaps: UInt32
    dwNupBorderCaps: UInt32
    dwBookletHandlingCaps: UInt32
    dwScalingCaps: UInt32
class PRINTPROCESSOR_INFO_1A(Structure):
    pName: win32more.Windows.Win32.Foundation.PSTR
class PRINTPROCESSOR_INFO_1W(Structure):
    pName: win32more.Windows.Win32.Foundation.PWSTR
PRINTPROCESSOR_INFO_1 = UnicodeAlias('PRINTPROCESSOR_INFO_1W')
class PRINTPROVIDOR(Structure):
    fpOpenPrinter: IntPtr
    fpSetJob: IntPtr
    fpGetJob: IntPtr
    fpEnumJobs: IntPtr
    fpAddPrinter: IntPtr
    fpDeletePrinter: IntPtr
    fpSetPrinter: IntPtr
    fpGetPrinter: IntPtr
    fpEnumPrinters: IntPtr
    fpAddPrinterDriver: IntPtr
    fpEnumPrinterDrivers: IntPtr
    fpGetPrinterDriver: IntPtr
    fpGetPrinterDriverDirectory: IntPtr
    fpDeletePrinterDriver: IntPtr
    fpAddPrintProcessor: IntPtr
    fpEnumPrintProcessors: IntPtr
    fpGetPrintProcessorDirectory: IntPtr
    fpDeletePrintProcessor: IntPtr
    fpEnumPrintProcessorDatatypes: IntPtr
    fpStartDocPrinter: IntPtr
    fpStartPagePrinter: IntPtr
    fpWritePrinter: IntPtr
    fpEndPagePrinter: IntPtr
    fpAbortPrinter: IntPtr
    fpReadPrinter: IntPtr
    fpEndDocPrinter: IntPtr
    fpAddJob: IntPtr
    fpScheduleJob: IntPtr
    fpGetPrinterData: IntPtr
    fpSetPrinterData: IntPtr
    fpWaitForPrinterChange: IntPtr
    fpClosePrinter: IntPtr
    fpAddForm: IntPtr
    fpDeleteForm: IntPtr
    fpGetForm: IntPtr
    fpSetForm: IntPtr
    fpEnumForms: IntPtr
    fpEnumMonitors: IntPtr
    fpEnumPorts: IntPtr
    fpAddPort: IntPtr
    fpConfigurePort: IntPtr
    fpDeletePort: IntPtr
    fpCreatePrinterIC: IntPtr
    fpPlayGdiScriptOnPrinterIC: IntPtr
    fpDeletePrinterIC: IntPtr
    fpAddPrinterConnection: IntPtr
    fpDeletePrinterConnection: IntPtr
    fpPrinterMessageBox: IntPtr
    fpAddMonitor: IntPtr
    fpDeleteMonitor: IntPtr
    fpResetPrinter: IntPtr
    fpGetPrinterDriverEx: IntPtr
    fpFindFirstPrinterChangeNotification: IntPtr
    fpFindClosePrinterChangeNotification: IntPtr
    fpAddPortEx: IntPtr
    fpShutDown: IntPtr
    fpRefreshPrinterChangeNotification: IntPtr
    fpOpenPrinterEx: IntPtr
    fpAddPrinterEx: IntPtr
    fpSetPort: IntPtr
    fpEnumPrinterData: IntPtr
    fpDeletePrinterData: IntPtr
    fpClusterSplOpen: IntPtr
    fpClusterSplClose: IntPtr
    fpClusterSplIsAlive: IntPtr
    fpSetPrinterDataEx: IntPtr
    fpGetPrinterDataEx: IntPtr
    fpEnumPrinterDataEx: IntPtr
    fpEnumPrinterKey: IntPtr
    fpDeletePrinterDataEx: IntPtr
    fpDeletePrinterKey: IntPtr
    fpSeekPrinter: IntPtr
    fpDeletePrinterDriverEx: IntPtr
    fpAddPerMachineConnection: IntPtr
    fpDeletePerMachineConnection: IntPtr
    fpEnumPerMachineConnections: IntPtr
    fpXcvData: IntPtr
    fpAddPrinterDriverEx: IntPtr
    fpSplReadPrinter: IntPtr
    fpDriverUnloadComplete: IntPtr
    fpGetSpoolFileInfo: IntPtr
    fpCommitSpoolData: IntPtr
    fpCloseSpoolFileHandle: IntPtr
    fpFlushPrinter: IntPtr
    fpSendRecvBidiData: IntPtr
    fpAddPrinterConnection2: IntPtr
    fpGetPrintClassObject: IntPtr
    fpReportJobProcessingProgress: IntPtr
    fpEnumAndLogProvidorObjects: IntPtr
    fpInternalGetPrinterDriver: IntPtr
    fpFindCompatibleDriver: IntPtr
    fpInstallPrinterDriverPackageFromConnection: IntPtr
    fpGetJobNamedPropertyValue: IntPtr
    fpSetJobNamedProperty: IntPtr
    fpDeleteJobNamedProperty: IntPtr
    fpEnumJobNamedProperties: IntPtr
    fpPowerEvent: IntPtr
    fpGetUserPropertyBag: IntPtr
    fpCanShutdown: IntPtr
    fpLogJobInfoForBranchOffice: IntPtr
    fpRegeneratePrintDeviceCapabilities: IntPtr
    fpPrintSupportOperation: IntPtr
    fpIppCreateJobOnPrinter: IntPtr
    fpIppGetJobAttributes: IntPtr
    fpIppSetJobAttributes: IntPtr
    fpIppGetPrinterAttributes: IntPtr
    fpIppSetPrinterAttributes: IntPtr
    fpIppCreateJobOnPrinterWithAttributes: IntPtr
PRINT_EXECUTION_CONTEXT = Int32
PRINT_EXECUTION_CONTEXT_APPLICATION: win32more.Windows.Win32.Graphics.Printing.PRINT_EXECUTION_CONTEXT = 0
PRINT_EXECUTION_CONTEXT_SPOOLER_SERVICE: win32more.Windows.Win32.Graphics.Printing.PRINT_EXECUTION_CONTEXT = 1
PRINT_EXECUTION_CONTEXT_SPOOLER_ISOLATION_HOST: win32more.Windows.Win32.Graphics.Printing.PRINT_EXECUTION_CONTEXT = 2
PRINT_EXECUTION_CONTEXT_FILTER_PIPELINE: win32more.Windows.Win32.Graphics.Printing.PRINT_EXECUTION_CONTEXT = 3
PRINT_EXECUTION_CONTEXT_WOW64: win32more.Windows.Win32.Graphics.Printing.PRINT_EXECUTION_CONTEXT = 4
class PRINT_EXECUTION_DATA(Structure):
    context: win32more.Windows.Win32.Graphics.Printing.PRINT_EXECUTION_CONTEXT
    clientAppPID: UInt32
class PRINT_FEATURE_OPTION(Structure):
    pszFeature: win32more.Windows.Win32.Foundation.PSTR
    pszOption: win32more.Windows.Win32.Foundation.PSTR
class PROPSHEETUI_GETICON_INFO(Structure):
    cbSize: UInt16
    Flags: UInt16
    cxIcon: UInt16
    cyIcon: UInt16
    hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
class PROPSHEETUI_INFO(Structure):
    cbSize: UInt16
    Version: UInt16
    Flags: UInt16
    Reason: UInt16
    hComPropSheet: win32more.Windows.Win32.Foundation.HANDLE
    pfnComPropSheet: win32more.Windows.Win32.Graphics.Printing.PFNCOMPROPSHEET
    lParamInit: win32more.Windows.Win32.Foundation.LPARAM
    UserData: UIntPtr
    Result: UIntPtr
class PROPSHEETUI_INFO_HEADER(Structure):
    cbSize: UInt16
    Flags: UInt16
    pTitle: POINTER(SByte)
    hWndParent: win32more.Windows.Win32.Foundation.HWND
    hInst: win32more.Windows.Win32.Foundation.HINSTANCE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
        IconID: UIntPtr
class PROVIDOR_INFO_1A(Structure):
    pName: win32more.Windows.Win32.Foundation.PSTR
    pEnvironment: win32more.Windows.Win32.Foundation.PSTR
    pDLLName: win32more.Windows.Win32.Foundation.PSTR
class PROVIDOR_INFO_1W(Structure):
    pName: win32more.Windows.Win32.Foundation.PWSTR
    pEnvironment: win32more.Windows.Win32.Foundation.PWSTR
    pDLLName: win32more.Windows.Win32.Foundation.PWSTR
PROVIDOR_INFO_1 = UnicodeAlias('PROVIDOR_INFO_1W')
class PROVIDOR_INFO_2A(Structure):
    pOrder: win32more.Windows.Win32.Foundation.PSTR
class PROVIDOR_INFO_2W(Structure):
    pOrder: win32more.Windows.Win32.Foundation.PWSTR
PROVIDOR_INFO_2 = UnicodeAlias('PROVIDOR_INFO_2W')
class PSCRIPT5_PRIVATE_DEVMODE(Structure):
    wReserved: UInt16 * 57
    wSize: UInt16
class PSPINFO(Structure):
    cbSize: UInt16
    wReserved: UInt16
    hComPropSheet: win32more.Windows.Win32.Foundation.HANDLE
    hCPSUIPage: win32more.Windows.Win32.Foundation.HANDLE
    pfnComPropSheet: win32more.Windows.Win32.Graphics.Printing.PFNCOMPROPSHEET
class PUBLISHERINFO(Structure):
    dwMode: UInt32
    wMinoutlinePPEM: UInt16
    wMaxbitmapPPEM: UInt16
PageCountType = Int32
FinalPageCount: win32more.Windows.Win32.Graphics.Printing.PageCountType = 0
IntermediatePageCount: win32more.Windows.Win32.Graphics.Printing.PageCountType = 1
PrintAsyncNotifyConversationStyle = Int32
kBiDirectional: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyConversationStyle = 0
kUniDirectional: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyConversationStyle = 1
PrintAsyncNotifyError = Int32
CHANNEL_CLOSED_BY_SERVER: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 1
CHANNEL_CLOSED_BY_ANOTHER_LISTENER: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 2
CHANNEL_CLOSED_BY_SAME_LISTENER: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 3
CHANNEL_RELEASED_BY_LISTENER: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 4
UNIRECTIONAL_NOTIFICATION_LOST: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 5
ASYNC_NOTIFICATION_FAILURE: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 6
NO_LISTENERS: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 7
CHANNEL_ALREADY_CLOSED: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 8
CHANNEL_ALREADY_OPENED: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 9
CHANNEL_WAITING_FOR_CLIENT_NOTIFICATION: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 10
CHANNEL_NOT_OPENED: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 11
ASYNC_CALL_ALREADY_PARKED: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 12
NOT_REGISTERED: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 13
ALREADY_UNREGISTERED: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 14
ALREADY_REGISTERED: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 15
CHANNEL_ACQUIRED: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 16
ASYNC_CALL_IN_PROGRESS: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 17
MAX_NOTIFICATION_SIZE_EXCEEDED: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 18
INTERNAL_NOTIFICATION_QUEUE_IS_FULL: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 19
INVALID_NOTIFICATION_TYPE: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 20
MAX_REGISTRATION_COUNT_EXCEEDED: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 21
MAX_CHANNEL_COUNT_EXCEEDED: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 22
LOCAL_ONLY_REGISTRATION: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 23
REMOTE_ONLY_REGISTRATION: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyError = 24
PrintAsyncNotifyUserFilter = Int32
kPerUser: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyUserFilter = 0
kAllUsers: win32more.Windows.Win32.Graphics.Printing.PrintAsyncNotifyUserFilter = 1
PrintJobStatus = Int32
PrintJobStatus_Paused: win32more.Windows.Win32.Graphics.Printing.PrintJobStatus = 1
PrintJobStatus_Error: win32more.Windows.Win32.Graphics.Printing.PrintJobStatus = 2
PrintJobStatus_Deleting: win32more.Windows.Win32.Graphics.Printing.PrintJobStatus = 4
PrintJobStatus_Spooling: win32more.Windows.Win32.Graphics.Printing.PrintJobStatus = 8
PrintJobStatus_Printing: win32more.Windows.Win32.Graphics.Printing.PrintJobStatus = 16
PrintJobStatus_Offline: win32more.Windows.Win32.Graphics.Printing.PrintJobStatus = 32
PrintJobStatus_PaperOut: win32more.Windows.Win32.Graphics.Printing.PrintJobStatus = 64
PrintJobStatus_Printed: win32more.Windows.Win32.Graphics.Printing.PrintJobStatus = 128
PrintJobStatus_Deleted: win32more.Windows.Win32.Graphics.Printing.PrintJobStatus = 256
PrintJobStatus_BlockedDeviceQueue: win32more.Windows.Win32.Graphics.Printing.PrintJobStatus = 512
PrintJobStatus_UserIntervention: win32more.Windows.Win32.Graphics.Printing.PrintJobStatus = 1024
PrintJobStatus_Restarted: win32more.Windows.Win32.Graphics.Printing.PrintJobStatus = 2048
PrintJobStatus_Complete: win32more.Windows.Win32.Graphics.Printing.PrintJobStatus = 4096
PrintJobStatus_Retained: win32more.Windows.Win32.Graphics.Printing.PrintJobStatus = 8192
class PrintNamedProperty(Structure):
    propertyName: win32more.Windows.Win32.Foundation.PWSTR
    propertyValue: win32more.Windows.Win32.Graphics.Printing.PrintPropertyValue
class PrintPropertiesCollection(Structure):
    numberOfProperties: UInt32
    propertiesCollection: POINTER(win32more.Windows.Win32.Graphics.Printing.PrintNamedProperty)
class PrintPropertyValue(Structure):
    ePropertyType: win32more.Windows.Win32.Graphics.Printing.EPrintPropertyType
    value: _value_e__Union
    class _value_e__Union(Union):
        propertyByte: Byte
        propertyString: win32more.Windows.Win32.Foundation.PWSTR
        propertyInt32: Int32
        propertyInt64: Int64
        propertyBlob: _propertyBlob_e__Struct
        class _propertyBlob_e__Struct(Structure):
            cbBuf: UInt32
            pBuf: VoidPtr
PrintSchemaAsyncOperation = Guid('{43b2f83d-10f2-48ab-831b-55fdbdbd34a4}')
PrintSchemaConstrainedSetting = Int32
PrintSchemaConstrainedSetting_None: win32more.Windows.Win32.Graphics.Printing.PrintSchemaConstrainedSetting = 0
PrintSchemaConstrainedSetting_PrintTicket: win32more.Windows.Win32.Graphics.Printing.PrintSchemaConstrainedSetting = 1
PrintSchemaConstrainedSetting_Admin: win32more.Windows.Win32.Graphics.Printing.PrintSchemaConstrainedSetting = 2
PrintSchemaConstrainedSetting_Device: win32more.Windows.Win32.Graphics.Printing.PrintSchemaConstrainedSetting = 3
PrintSchemaParameterDataType = Int32
PrintSchemaParameterDataType_Integer: win32more.Windows.Win32.Graphics.Printing.PrintSchemaParameterDataType = 0
PrintSchemaParameterDataType_NumericString: win32more.Windows.Win32.Graphics.Printing.PrintSchemaParameterDataType = 1
PrintSchemaParameterDataType_String: win32more.Windows.Win32.Graphics.Printing.PrintSchemaParameterDataType = 2
PrintSchemaSelectionType = Int32
PrintSchemaSelectionType_PickOne: win32more.Windows.Win32.Graphics.Printing.PrintSchemaSelectionType = 0
PrintSchemaSelectionType_PickMany: win32more.Windows.Win32.Graphics.Printing.PrintSchemaSelectionType = 1
PrinterExtensionManager = Guid('{331b60da-9e90-4dd0-9c84-eac4e659b61f}')
PrinterQueue = Guid('{eb54c230-798c-4c9e-b461-29fad04039b1}')
PrinterQueueView = Guid('{eb54c231-798c-4c9e-b461-29fad04039b1}')
@winfunctype_pointer
def ROUTER_NOTIFY_CALLBACK(dwCommand: UInt32, pContext: VoidPtr, dwColor: UInt32, pNofityInfo: POINTER(win32more.Windows.Win32.Graphics.Printing.PRINTER_NOTIFY_INFO), fdwFlags: UInt32, pdwResult: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
class SETRESULT_INFO(Structure):
    cbSize: UInt16
    wReserved: UInt16
    hSetResult: win32more.Windows.Win32.Foundation.HANDLE
    Result: win32more.Windows.Win32.Foundation.LRESULT
SHIMOPTS = Int32
PTSHIM_DEFAULT: win32more.Windows.Win32.Graphics.Printing.SHIMOPTS = 0
PTSHIM_NOSNAPSHOT: win32more.Windows.Win32.Graphics.Printing.SHIMOPTS = 1
class SHOWUIPARAMS(Structure):
    UIType: win32more.Windows.Win32.Graphics.Printing.UI_TYPE
    MessageBoxParams: win32more.Windows.Win32.Graphics.Printing.MESSAGEBOX_PARAMS
class SIMULATE_CAPS_1(Structure):
    dwLevel: UInt32
    dwPageOrderFlags: UInt32
    dwNumberOfCopies: UInt32
    dwCollate: UInt32
    dwNupOptions: UInt32
class SPLCLIENT_INFO_1(Structure):
    dwSize: UInt32
    pMachineName: win32more.Windows.Win32.Foundation.PWSTR
    pUserName: win32more.Windows.Win32.Foundation.PWSTR
    dwBuildNum: UInt32
    dwMajorVersion: UInt32
    dwMinorVersion: UInt32
    wProcessorArchitecture: UInt16
class SPLCLIENT_INFO_2_W2K(Structure):
    hSplPrinter: UIntPtr
if ARCH in 'X64,ARM64':
    class SPLCLIENT_INFO_2_WINXP(Structure):
        hSplPrinter: UInt64
elif ARCH in 'X86':
    class SPLCLIENT_INFO_2_WINXP(Structure):
        hSplPrinter: UInt32
class SPLCLIENT_INFO_3_VISTA(Structure):
    cbSize: UInt32
    dwFlags: UInt32
    dwSize: UInt32
    pMachineName: win32more.Windows.Win32.Foundation.PWSTR
    pUserName: win32more.Windows.Win32.Foundation.PWSTR
    dwBuildNum: UInt32
    dwMajorVersion: UInt32
    dwMinorVersion: UInt32
    wProcessorArchitecture: UInt16
    hSplPrinter: UInt64
class SPLCLIENT_INFO_INTERNAL(Structure):
    cbSize: UInt32
    dwFlags: UInt32
    dwSize: UInt32
    pMachineName: win32more.Windows.Win32.Foundation.PWSTR
    pUserName: win32more.Windows.Win32.Foundation.PWSTR
    dwBuildNum: UInt32
    dwMajorVersion: UInt32
    dwMinorVersion: UInt32
    wProcessorArchitecture: UInt16
    hSplPrinter: UInt64
    dwProcessId: UInt32
    dwSessionId: UInt32
class TRANSDATA(Structure):
    ubCodePageID: Byte
    ubType: Byte
    uCode: _uCode_e__Union
    class _uCode_e__Union(Union):
        sCode: Int16
        ubCode: Byte
        ubPairs: Byte * 2
class UFF_FILEHEADER(Structure):
    dwSignature: UInt32
    dwVersion: UInt32
    dwSize: UInt32
    nFonts: UInt32
    nGlyphSets: UInt32
    nVarData: UInt32
    offFontDir: UInt32
    dwFlags: UInt32
    dwReserved: UInt32 * 4
class UFF_FONTDIRECTORY(Structure):
    dwSignature: UInt32
    wSize: UInt16
    wFontID: UInt16
    sGlyphID: Int16
    wFlags: UInt16
    dwInstallerSig: UInt32
    offFontName: UInt32
    offCartridgeName: UInt32
    offFontData: UInt32
    offGlyphData: UInt32
    offVarData: UInt32
UI_TYPE = Int32
kMessageBox: win32more.Windows.Win32.Graphics.Printing.UI_TYPE = 0
class UNIDRVINFO(Structure):
    dwSize: UInt32
    flGenFlags: UInt32
    wType: UInt16
    fCaps: UInt16
    wXRes: UInt16
    wYRes: UInt16
    sYAdjust: Int16
    sYMoved: Int16
    wPrivateData: UInt16
    sShift: Int16
    SelectFont: win32more.Windows.Win32.Graphics.Printing.INVOC
    UnSelectFont: win32more.Windows.Win32.Graphics.Printing.INVOC
    wReserved: UInt16 * 4
class UNIDRV_PRIVATE_DEVMODE(Structure):
    wReserved: UInt16 * 4
    wSize: UInt16
class UNIFM_HDR(Structure):
    dwSize: UInt32
    dwVersion: UInt32
    ulDefaultCodepage: UInt32
    lGlyphSetDataRCID: Int32
    loUnidrvInfo: UInt32
    loIFIMetrics: UInt32
    loExtTextMetric: UInt32
    loWidthTable: UInt32
    loKernPair: UInt32
    dwReserved: UInt32 * 2
class UNI_CODEPAGEINFO(Structure):
    dwCodePage: UInt32
    SelectSymbolSet: win32more.Windows.Win32.Graphics.Printing.INVOC
    UnSelectSymbolSet: win32more.Windows.Win32.Graphics.Printing.INVOC
class UNI_GLYPHSETDATA(Structure):
    dwSize: UInt32
    dwVersion: UInt32
    dwFlags: UInt32
    lPredefinedID: Int32
    dwGlyphCount: UInt32
    dwRunCount: UInt32
    loRunOffset: UInt32
    dwCodePageCount: UInt32
    loCodePageOffset: UInt32
    loMapTableOffset: UInt32
    dwReserved: UInt32 * 2
class USERDATA(Structure):
    dwSize: UInt32
    dwItemID: UIntPtr
    pKeyWordName: win32more.Windows.Win32.Foundation.PSTR
    dwReserved: UInt32 * 8
class WIDTHRUN(Structure):
    wStartGlyph: UInt16
    wGlyphCount: UInt16
    loCharWidthOffset: UInt32
class WIDTHTABLE(Structure):
    dwSize: UInt32
    dwRunNum: UInt32
    WidthRun: win32more.Windows.Win32.Graphics.Printing.WIDTHRUN * 1
XPSRAS_BACKGROUND_COLOR = Int32
XPSRAS_BACKGROUND_COLOR_TRANSPARENT: win32more.Windows.Win32.Graphics.Printing.XPSRAS_BACKGROUND_COLOR = 0
XPSRAS_BACKGROUND_COLOR_OPAQUE: win32more.Windows.Win32.Graphics.Printing.XPSRAS_BACKGROUND_COLOR = 1
XPSRAS_PIXEL_FORMAT = Int32
XPSRAS_PIXEL_FORMAT_32BPP_PBGRA_UINT_SRGB: win32more.Windows.Win32.Graphics.Printing.XPSRAS_PIXEL_FORMAT = 1
XPSRAS_PIXEL_FORMAT_64BPP_PRGBA_HALF_SCRGB: win32more.Windows.Win32.Graphics.Printing.XPSRAS_PIXEL_FORMAT = 2
XPSRAS_PIXEL_FORMAT_128BPP_PRGBA_FLOAT_SCRGB: win32more.Windows.Win32.Graphics.Printing.XPSRAS_PIXEL_FORMAT = 3
XPSRAS_RENDERING_MODE = Int32
XPSRAS_RENDERING_MODE_ANTIALIASED: win32more.Windows.Win32.Graphics.Printing.XPSRAS_RENDERING_MODE = 0
XPSRAS_RENDERING_MODE_ALIASED: win32more.Windows.Win32.Graphics.Printing.XPSRAS_RENDERING_MODE = 1
@winfunctype_pointer
def _CPSUICALLBACK(pCPSUICBParam: POINTER(win32more.Windows.Win32.Graphics.Printing.CPSUICBPARAM)) -> Int32: ...
class _SPLCLIENT_INFO_2_V3(Structure):
    hSplPrinter: UInt64


make_ready(__name__)
