from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Registry
import win32more.Windows.Win32.UI.Controls
import win32more.Windows.Win32.UI.Input.Pointer
import win32more.Windows.Win32.UI.WindowsAndMessaging
AEROWIZARDPARTS = Int32
AW_TITLEBAR: win32more.Windows.Win32.UI.Controls.AEROWIZARDPARTS = 1
AW_HEADERAREA: win32more.Windows.Win32.UI.Controls.AEROWIZARDPARTS = 2
AW_CONTENTAREA: win32more.Windows.Win32.UI.Controls.AEROWIZARDPARTS = 3
AW_COMMANDAREA: win32more.Windows.Win32.UI.Controls.AEROWIZARDPARTS = 4
AW_BUTTON: win32more.Windows.Win32.UI.Controls.AEROWIZARDPARTS = 5
ARROWBTNSTATES = Int32
ABS_UPNORMAL: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 1
ABS_UPHOT: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 2
ABS_UPPRESSED: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 3
ABS_UPDISABLED: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 4
ABS_DOWNNORMAL: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 5
ABS_DOWNHOT: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 6
ABS_DOWNPRESSED: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 7
ABS_DOWNDISABLED: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 8
ABS_LEFTNORMAL: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 9
ABS_LEFTHOT: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 10
ABS_LEFTPRESSED: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 11
ABS_LEFTDISABLED: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 12
ABS_RIGHTNORMAL: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 13
ABS_RIGHTHOT: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 14
ABS_RIGHTPRESSED: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 15
ABS_RIGHTDISABLED: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 16
ABS_UPHOVER: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 17
ABS_DOWNHOVER: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 18
ABS_LEFTHOVER: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 19
ABS_RIGHTHOVER: win32more.Windows.Win32.UI.Controls.ARROWBTNSTATES = 20
TVI_ROOT: win32more.Windows.Win32.UI.Controls.HTREEITEM = -65536
TVI_FIRST: win32more.Windows.Win32.UI.Controls.HTREEITEM = -65535
TVI_LAST: win32more.Windows.Win32.UI.Controls.HTREEITEM = -65534
TVI_SORT: win32more.Windows.Win32.UI.Controls.HTREEITEM = -65533
NM_FIRST: UInt32 = 0
NM_OUTOFMEMORY: UInt32 = 4294967295
NM_CLICK: UInt32 = 4294967294
NM_DBLCLK: UInt32 = 4294967293
NM_RETURN: UInt32 = 4294967292
NM_RCLICK: UInt32 = 4294967291
NM_RDBLCLK: UInt32 = 4294967290
NM_SETFOCUS: UInt32 = 4294967289
NM_KILLFOCUS: UInt32 = 4294967288
NM_CUSTOMDRAW: UInt32 = 4294967284
NM_HOVER: UInt32 = 4294967283
NM_NCHITTEST: UInt32 = 4294967282
NM_KEYDOWN: UInt32 = 4294967281
NM_RELEASEDCAPTURE: UInt32 = 4294967280
NM_SETCURSOR: UInt32 = 4294967279
NM_CHAR: UInt32 = 4294967278
NM_TOOLTIPSCREATED: UInt32 = 4294967277
NM_LDOWN: UInt32 = 4294967276
NM_RDOWN: UInt32 = 4294967275
NM_THEMECHANGED: UInt32 = 4294967274
NM_FONTCHANGED: UInt32 = 4294967273
NM_CUSTOMTEXT: UInt32 = 4294967272
NM_TVSTATEIMAGECHANGING: UInt32 = 4294967272
EM_SCROLLCARET: UInt32 = 183
EM_SETLIMITTEXT: UInt32 = 197
EM_GETLIMITTEXT: UInt32 = 213
EM_POSFROMCHAR: UInt32 = 214
EM_CHARFROMPOS: UInt32 = 215
HOTKEYF_EXT: UInt32 = 8
WM_CTLCOLOR: UInt32 = 25
ODT_HEADER: UInt32 = 100
LVM_FIRST: UInt32 = 4096
TV_FIRST: UInt32 = 4352
HDM_FIRST: UInt32 = 4608
TCM_FIRST: UInt32 = 4864
PGM_FIRST: UInt32 = 5120
ECM_FIRST: UInt32 = 5376
BCM_FIRST: UInt32 = 5632
CBM_FIRST: UInt32 = 5888
CCM_FIRST: UInt32 = 8192
CCM_LAST: UInt32 = 8704
CCM_SETBKCOLOR: UInt32 = 8193
CCM_SETCOLORSCHEME: UInt32 = 8194
CCM_GETCOLORSCHEME: UInt32 = 8195
CCM_GETDROPTARGET: UInt32 = 8196
CCM_SETUNICODEFORMAT: UInt32 = 8197
CCM_GETUNICODEFORMAT: UInt32 = 8198
COMCTL32_VERSION: UInt32 = 6
CCM_SETVERSION: UInt32 = 8199
CCM_GETVERSION: UInt32 = 8200
CCM_SETNOTIFYWINDOW: UInt32 = 8201
CCM_SETWINDOWTHEME: UInt32 = 8203
CCM_DPISCALE: UInt32 = 8204
INFOTIPSIZE: UInt32 = 1024
NM_LAST: UInt32 = 4294967197
LVN_FIRST: UInt32 = 4294967196
LVN_LAST: UInt32 = 4294967097
HDN_FIRST: UInt32 = 4294966996
HDN_LAST: UInt32 = 4294966897
TVN_FIRST: UInt32 = 4294966896
TVN_LAST: UInt32 = 4294966797
TTN_FIRST: UInt32 = 4294966776
TTN_LAST: UInt32 = 4294966747
TCN_FIRST: UInt32 = 4294966746
TCN_LAST: UInt32 = 4294966716
CDN_FIRST: UInt32 = 4294966695
CDN_LAST: UInt32 = 4294966597
TBN_FIRST: UInt32 = 4294966596
TBN_LAST: UInt32 = 4294966576
UDN_FIRST: UInt32 = 4294966575
UDN_LAST: UInt32 = 4294966567
DTN_FIRST: UInt32 = 4294966556
DTN_LAST: UInt32 = 4294966551
MCN_FIRST: UInt32 = 4294966550
MCN_LAST: UInt32 = 4294966544
DTN_FIRST2: UInt32 = 4294966543
DTN_LAST2: UInt32 = 4294966497
CBEN_FIRST: UInt32 = 4294966496
CBEN_LAST: UInt32 = 4294966466
RBN_FIRST: UInt32 = 4294966465
RBN_LAST: UInt32 = 4294966437
IPN_FIRST: UInt32 = 4294966436
IPN_LAST: UInt32 = 4294966417
SBN_FIRST: UInt32 = 4294966416
SBN_LAST: UInt32 = 4294966397
PGN_FIRST: UInt32 = 4294966396
PGN_LAST: UInt32 = 4294966346
WMN_FIRST: UInt32 = 4294966296
WMN_LAST: UInt32 = 4294966096
BCN_FIRST: UInt32 = 4294966046
BCN_LAST: UInt32 = 4294965946
TRBN_FIRST: UInt32 = 4294965795
TRBN_LAST: UInt32 = 4294965777
EN_FIRST: UInt32 = 4294965776
EN_LAST: UInt32 = 4294965756
MSGF_COMMCTRL_BEGINDRAG: UInt32 = 16896
MSGF_COMMCTRL_SIZEHEADER: UInt32 = 16897
MSGF_COMMCTRL_DRAGSELECT: UInt32 = 16898
MSGF_COMMCTRL_TOOLBARCUST: UInt32 = 16899
CDRF_DODEFAULT: UInt32 = 0
CDRF_NEWFONT: UInt32 = 2
CDRF_SKIPDEFAULT: UInt32 = 4
CDRF_DOERASE: UInt32 = 8
CDRF_SKIPPOSTPAINT: UInt32 = 256
CDRF_NOTIFYPOSTPAINT: UInt32 = 16
CDRF_NOTIFYITEMDRAW: UInt32 = 32
CDRF_NOTIFYSUBITEMDRAW: UInt32 = 32
CDRF_NOTIFYPOSTERASE: UInt32 = 64
CDDS_POSTERASE: UInt32 = 4
CDDS_ITEM: UInt32 = 65536
NM_GETCUSTOMSPLITRECT: UInt32 = 4294966049
CLR_NONE: Int32 = -1
CLR_DEFAULT: Int32 = -16777216
CLR_HILIGHT: Int32 = -16777216
ILS_NORMAL: UInt32 = 0
ILS_GLOW: UInt32 = 1
ILS_SHADOW: UInt32 = 2
ILS_SATURATE: UInt32 = 4
ILS_ALPHA: UInt32 = 8
ILGT_NORMAL: UInt32 = 0
ILGT_ASYNC: UInt32 = 1
WC_HEADERA: String = 'SysHeader32'
WC_HEADERW: String = 'SysHeader32'
WC_HEADER: String = 'SysHeader32'
HDS_HORZ: UInt32 = 0
HDS_BUTTONS: UInt32 = 2
HDS_HOTTRACK: UInt32 = 4
HDS_HIDDEN: UInt32 = 8
HDS_DRAGDROP: UInt32 = 64
HDS_FULLDRAG: UInt32 = 128
HDS_FILTERBAR: UInt32 = 256
HDS_FLAT: UInt32 = 512
HDS_CHECKBOXES: UInt32 = 1024
HDS_NOSIZING: UInt32 = 2048
HDS_OVERFLOW: UInt32 = 4096
HDM_GETITEMCOUNT: UInt32 = 4608
HDM_INSERTITEMA: UInt32 = 4609
HDM_INSERTITEMW: UInt32 = 4618
HDM_INSERTITEM: UInt32 = 4618
HDM_DELETEITEM: UInt32 = 4610
HDM_GETITEMA: UInt32 = 4611
HDM_GETITEMW: UInt32 = 4619
HDM_GETITEM: UInt32 = 4619
HDM_SETITEMA: UInt32 = 4612
HDM_SETITEMW: UInt32 = 4620
HDM_SETITEM: UInt32 = 4620
HDM_LAYOUT: UInt32 = 4613
HDSIL_NORMAL: UInt32 = 0
HDSIL_STATE: UInt32 = 1
HDM_HITTEST: UInt32 = 4614
HDM_GETITEMRECT: UInt32 = 4615
HDM_SETIMAGELIST: UInt32 = 4616
HDM_GETIMAGELIST: UInt32 = 4617
HDM_ORDERTOINDEX: UInt32 = 4623
HDM_CREATEDRAGIMAGE: UInt32 = 4624
HDM_GETORDERARRAY: UInt32 = 4625
HDM_SETORDERARRAY: UInt32 = 4626
HDM_SETHOTDIVIDER: UInt32 = 4627
HDM_SETBITMAPMARGIN: UInt32 = 4628
HDM_GETBITMAPMARGIN: UInt32 = 4629
HDM_SETUNICODEFORMAT: UInt32 = 8197
HDM_GETUNICODEFORMAT: UInt32 = 8198
HDM_SETFILTERCHANGETIMEOUT: UInt32 = 4630
HDM_EDITFILTER: UInt32 = 4631
HDM_CLEARFILTER: UInt32 = 4632
HDM_GETITEMDROPDOWNRECT: UInt32 = 4633
HDM_GETOVERFLOWRECT: UInt32 = 4634
HDM_GETFOCUSEDITEM: UInt32 = 4635
HDM_SETFOCUSEDITEM: UInt32 = 4636
HDN_ITEMCHANGINGA: UInt32 = 4294966996
HDN_ITEMCHANGINGW: UInt32 = 4294966976
HDN_ITEMCHANGEDA: UInt32 = 4294966995
HDN_ITEMCHANGEDW: UInt32 = 4294966975
HDN_ITEMCLICKA: UInt32 = 4294966994
HDN_ITEMCLICKW: UInt32 = 4294966974
HDN_ITEMDBLCLICKA: UInt32 = 4294966993
HDN_ITEMDBLCLICKW: UInt32 = 4294966973
HDN_DIVIDERDBLCLICKA: UInt32 = 4294966991
HDN_DIVIDERDBLCLICKW: UInt32 = 4294966971
HDN_BEGINTRACKA: UInt32 = 4294966990
HDN_BEGINTRACKW: UInt32 = 4294966970
HDN_ENDTRACKA: UInt32 = 4294966989
HDN_ENDTRACKW: UInt32 = 4294966969
HDN_TRACKA: UInt32 = 4294966988
HDN_TRACKW: UInt32 = 4294966968
HDN_GETDISPINFOA: UInt32 = 4294966987
HDN_GETDISPINFOW: UInt32 = 4294966967
HDN_BEGINDRAG: UInt32 = 4294966986
HDN_ENDDRAG: UInt32 = 4294966985
HDN_FILTERCHANGE: UInt32 = 4294966984
HDN_FILTERBTNCLICK: UInt32 = 4294966983
HDN_BEGINFILTEREDIT: UInt32 = 4294966982
HDN_ENDFILTEREDIT: UInt32 = 4294966981
HDN_ITEMSTATEICONCLICK: UInt32 = 4294966980
HDN_ITEMKEYDOWN: UInt32 = 4294966979
HDN_DROPDOWN: UInt32 = 4294966978
HDN_OVERFLOWCLICK: UInt32 = 4294966977
HDN_ITEMCHANGING: UInt32 = 4294966976
HDN_ITEMCHANGED: UInt32 = 4294966975
HDN_ITEMCLICK: UInt32 = 4294966974
HDN_ITEMDBLCLICK: UInt32 = 4294966973
HDN_DIVIDERDBLCLICK: UInt32 = 4294966971
HDN_BEGINTRACK: UInt32 = 4294966970
HDN_ENDTRACK: UInt32 = 4294966969
HDN_TRACK: UInt32 = 4294966968
HDN_GETDISPINFO: UInt32 = 4294966967
TOOLBARCLASSNAMEW: String = 'ToolbarWindow32'
TOOLBARCLASSNAMEA: String = 'ToolbarWindow32'
TOOLBARCLASSNAME: String = 'ToolbarWindow32'
CMB_MASKED: UInt32 = 2
TBSTATE_CHECKED: UInt32 = 1
TBSTATE_PRESSED: UInt32 = 2
TBSTATE_ENABLED: UInt32 = 4
TBSTATE_HIDDEN: UInt32 = 8
TBSTATE_INDETERMINATE: UInt32 = 16
TBSTATE_WRAP: UInt32 = 32
TBSTATE_ELLIPSES: UInt32 = 64
TBSTATE_MARKED: UInt32 = 128
TBSTYLE_BUTTON: UInt32 = 0
TBSTYLE_SEP: UInt32 = 1
TBSTYLE_CHECK: UInt32 = 2
TBSTYLE_GROUP: UInt32 = 4
TBSTYLE_DROPDOWN: UInt32 = 8
TBSTYLE_AUTOSIZE: UInt32 = 16
TBSTYLE_NOPREFIX: UInt32 = 32
TBSTYLE_TOOLTIPS: UInt32 = 256
TBSTYLE_WRAPABLE: UInt32 = 512
TBSTYLE_ALTDRAG: UInt32 = 1024
TBSTYLE_FLAT: UInt32 = 2048
TBSTYLE_LIST: UInt32 = 4096
TBSTYLE_CUSTOMERASE: UInt32 = 8192
TBSTYLE_REGISTERDROP: UInt32 = 16384
TBSTYLE_TRANSPARENT: UInt32 = 32768
TBSTYLE_EX_DRAWDDARROWS: UInt32 = 1
BTNS_BUTTON: UInt32 = 0
BTNS_SEP: UInt32 = 1
BTNS_CHECK: UInt32 = 2
BTNS_GROUP: UInt32 = 4
BTNS_DROPDOWN: UInt32 = 8
BTNS_AUTOSIZE: UInt32 = 16
BTNS_NOPREFIX: UInt32 = 32
BTNS_SHOWTEXT: UInt32 = 64
BTNS_WHOLEDROPDOWN: UInt32 = 128
TBSTYLE_EX_MIXEDBUTTONS: UInt32 = 8
TBSTYLE_EX_HIDECLIPPEDBUTTONS: UInt32 = 16
TBSTYLE_EX_MULTICOLUMN: UInt32 = 2
TBSTYLE_EX_VERTICAL: UInt32 = 4
TBSTYLE_EX_DOUBLEBUFFER: UInt32 = 128
TBCDRF_NOEDGES: UInt32 = 65536
TBCDRF_HILITEHOTTRACK: UInt32 = 131072
TBCDRF_NOOFFSET: UInt32 = 262144
TBCDRF_NOMARK: UInt32 = 524288
TBCDRF_NOETCHEDEFFECT: UInt32 = 1048576
TBCDRF_BLENDICON: UInt32 = 2097152
TBCDRF_NOBACKGROUND: UInt32 = 4194304
TBCDRF_USECDCOLORS: UInt32 = 8388608
TB_ENABLEBUTTON: UInt32 = 1025
TB_CHECKBUTTON: UInt32 = 1026
TB_PRESSBUTTON: UInt32 = 1027
TB_HIDEBUTTON: UInt32 = 1028
TB_INDETERMINATE: UInt32 = 1029
TB_MARKBUTTON: UInt32 = 1030
TB_ISBUTTONENABLED: UInt32 = 1033
TB_ISBUTTONCHECKED: UInt32 = 1034
TB_ISBUTTONPRESSED: UInt32 = 1035
TB_ISBUTTONHIDDEN: UInt32 = 1036
TB_ISBUTTONINDETERMINATE: UInt32 = 1037
TB_ISBUTTONHIGHLIGHTED: UInt32 = 1038
TB_SETSTATE: UInt32 = 1041
TB_GETSTATE: UInt32 = 1042
TB_ADDBITMAP: UInt32 = 1043
IDB_STD_SMALL_COLOR: UInt32 = 0
IDB_STD_LARGE_COLOR: UInt32 = 1
IDB_VIEW_SMALL_COLOR: UInt32 = 4
IDB_VIEW_LARGE_COLOR: UInt32 = 5
IDB_HIST_SMALL_COLOR: UInt32 = 8
IDB_HIST_LARGE_COLOR: UInt32 = 9
IDB_HIST_NORMAL: UInt32 = 12
IDB_HIST_HOT: UInt32 = 13
IDB_HIST_DISABLED: UInt32 = 14
IDB_HIST_PRESSED: UInt32 = 15
STD_CUT: UInt32 = 0
STD_COPY: UInt32 = 1
STD_PASTE: UInt32 = 2
STD_UNDO: UInt32 = 3
STD_REDOW: UInt32 = 4
STD_DELETE: UInt32 = 5
STD_FILENEW: UInt32 = 6
STD_FILEOPEN: UInt32 = 7
STD_FILESAVE: UInt32 = 8
STD_PRINTPRE: UInt32 = 9
STD_PROPERTIES: UInt32 = 10
STD_HELP: UInt32 = 11
STD_FIND: UInt32 = 12
STD_REPLACE: UInt32 = 13
STD_PRINT: UInt32 = 14
VIEW_LARGEICONS: UInt32 = 0
VIEW_SMALLICONS: UInt32 = 1
VIEW_LIST: UInt32 = 2
VIEW_DETAILS: UInt32 = 3
VIEW_SORTNAME: UInt32 = 4
VIEW_SORTSIZE: UInt32 = 5
VIEW_SORTDATE: UInt32 = 6
VIEW_SORTTYPE: UInt32 = 7
VIEW_PARENTFOLDER: UInt32 = 8
VIEW_NETCONNECT: UInt32 = 9
VIEW_NETDISCONNECT: UInt32 = 10
VIEW_NEWFOLDER: UInt32 = 11
VIEW_VIEWMENU: UInt32 = 12
HIST_BACK: UInt32 = 0
HIST_FORWARD: UInt32 = 1
HIST_FAVORITES: UInt32 = 2
HIST_ADDTOFAVORITES: UInt32 = 3
HIST_VIEWTREE: UInt32 = 4
TB_ADDBUTTONSA: UInt32 = 1044
TB_INSERTBUTTONA: UInt32 = 1045
TB_DELETEBUTTON: UInt32 = 1046
TB_GETBUTTON: UInt32 = 1047
TB_BUTTONCOUNT: UInt32 = 1048
TB_COMMANDTOINDEX: UInt32 = 1049
TB_SAVERESTOREA: UInt32 = 1050
TB_SAVERESTOREW: UInt32 = 1100
TB_CUSTOMIZE: UInt32 = 1051
TB_ADDSTRINGA: UInt32 = 1052
TB_ADDSTRINGW: UInt32 = 1101
TB_GETITEMRECT: UInt32 = 1053
TB_BUTTONSTRUCTSIZE: UInt32 = 1054
TB_SETBUTTONSIZE: UInt32 = 1055
TB_SETBITMAPSIZE: UInt32 = 1056
TB_AUTOSIZE: UInt32 = 1057
TB_GETTOOLTIPS: UInt32 = 1059
TB_SETTOOLTIPS: UInt32 = 1060
TB_SETPARENT: UInt32 = 1061
TB_SETROWS: UInt32 = 1063
TB_GETROWS: UInt32 = 1064
TB_SETCMDID: UInt32 = 1066
TB_CHANGEBITMAP: UInt32 = 1067
TB_GETBITMAP: UInt32 = 1068
TB_GETBUTTONTEXTA: UInt32 = 1069
TB_GETBUTTONTEXTW: UInt32 = 1099
TB_REPLACEBITMAP: UInt32 = 1070
TB_SETINDENT: UInt32 = 1071
TB_SETIMAGELIST: UInt32 = 1072
TB_GETIMAGELIST: UInt32 = 1073
TB_LOADIMAGES: UInt32 = 1074
TB_GETRECT: UInt32 = 1075
TB_SETHOTIMAGELIST: UInt32 = 1076
TB_GETHOTIMAGELIST: UInt32 = 1077
TB_SETDISABLEDIMAGELIST: UInt32 = 1078
TB_GETDISABLEDIMAGELIST: UInt32 = 1079
TB_SETSTYLE: UInt32 = 1080
TB_GETSTYLE: UInt32 = 1081
TB_GETBUTTONSIZE: UInt32 = 1082
TB_SETBUTTONWIDTH: UInt32 = 1083
TB_SETMAXTEXTROWS: UInt32 = 1084
TB_GETTEXTROWS: UInt32 = 1085
TB_GETBUTTONTEXT: UInt32 = 1099
TB_SAVERESTORE: UInt32 = 1100
TB_ADDSTRING: UInt32 = 1101
TB_GETOBJECT: UInt32 = 1086
TB_GETHOTITEM: UInt32 = 1095
TB_SETHOTITEM: UInt32 = 1096
TB_SETANCHORHIGHLIGHT: UInt32 = 1097
TB_GETANCHORHIGHLIGHT: UInt32 = 1098
TB_MAPACCELERATORA: UInt32 = 1102
TB_GETINSERTMARK: UInt32 = 1103
TB_SETINSERTMARK: UInt32 = 1104
TB_INSERTMARKHITTEST: UInt32 = 1105
TB_MOVEBUTTON: UInt32 = 1106
TB_GETMAXSIZE: UInt32 = 1107
TB_SETEXTENDEDSTYLE: UInt32 = 1108
TB_GETEXTENDEDSTYLE: UInt32 = 1109
TB_GETPADDING: UInt32 = 1110
TB_SETPADDING: UInt32 = 1111
TB_SETINSERTMARKCOLOR: UInt32 = 1112
TB_GETINSERTMARKCOLOR: UInt32 = 1113
TB_SETCOLORSCHEME: UInt32 = 8194
TB_GETCOLORSCHEME: UInt32 = 8195
TB_SETUNICODEFORMAT: UInt32 = 8197
TB_GETUNICODEFORMAT: UInt32 = 8198
TB_MAPACCELERATORW: UInt32 = 1114
TB_MAPACCELERATOR: UInt32 = 1114
TBBF_LARGE: UInt32 = 1
TB_GETBITMAPFLAGS: UInt32 = 1065
TB_GETBUTTONINFOW: UInt32 = 1087
TB_SETBUTTONINFOW: UInt32 = 1088
TB_GETBUTTONINFOA: UInt32 = 1089
TB_SETBUTTONINFOA: UInt32 = 1090
TB_GETBUTTONINFO: UInt32 = 1087
TB_SETBUTTONINFO: UInt32 = 1088
TB_INSERTBUTTONW: UInt32 = 1091
TB_ADDBUTTONSW: UInt32 = 1092
TB_HITTEST: UInt32 = 1093
TB_INSERTBUTTON: UInt32 = 1091
TB_ADDBUTTONS: UInt32 = 1092
TB_SETDRAWTEXTFLAGS: UInt32 = 1094
TB_GETSTRINGW: UInt32 = 1115
TB_GETSTRINGA: UInt32 = 1116
TB_GETSTRING: UInt32 = 1115
TB_SETBOUNDINGSIZE: UInt32 = 1117
TB_SETHOTITEM2: UInt32 = 1118
TB_HASACCELERATOR: UInt32 = 1119
TB_SETLISTGAP: UInt32 = 1120
TB_GETIMAGELISTCOUNT: UInt32 = 1122
TB_GETIDEALSIZE: UInt32 = 1123
TBMF_PAD: UInt32 = 1
TBMF_BARPAD: UInt32 = 2
TBMF_BUTTONSPACING: UInt32 = 4
TB_GETMETRICS: UInt32 = 1125
TB_SETMETRICS: UInt32 = 1126
TB_GETITEMDROPDOWNRECT: UInt32 = 1127
TB_SETPRESSEDIMAGELIST: UInt32 = 1128
TB_GETPRESSEDIMAGELIST: UInt32 = 1129
TB_SETWINDOWTHEME: UInt32 = 8203
TBN_GETBUTTONINFOA: UInt32 = 4294966596
TBN_BEGINDRAG: UInt32 = 4294966595
TBN_ENDDRAG: UInt32 = 4294966594
TBN_BEGINADJUST: UInt32 = 4294966593
TBN_ENDADJUST: UInt32 = 4294966592
TBN_RESET: UInt32 = 4294966591
TBN_QUERYINSERT: UInt32 = 4294966590
TBN_QUERYDELETE: UInt32 = 4294966589
TBN_TOOLBARCHANGE: UInt32 = 4294966588
TBN_CUSTHELP: UInt32 = 4294966587
TBN_DROPDOWN: UInt32 = 4294966586
TBN_GETOBJECT: UInt32 = 4294966584
TBN_HOTITEMCHANGE: UInt32 = 4294966583
TBN_DRAGOUT: UInt32 = 4294966582
TBN_DELETINGBUTTON: UInt32 = 4294966581
TBN_GETDISPINFOA: UInt32 = 4294966580
TBN_GETDISPINFOW: UInt32 = 4294966579
TBN_GETINFOTIPA: UInt32 = 4294966578
TBN_GETINFOTIPW: UInt32 = 4294966577
TBN_GETBUTTONINFOW: UInt32 = 4294966576
TBN_RESTORE: UInt32 = 4294966575
TBN_SAVE: UInt32 = 4294966574
TBN_INITCUSTOMIZE: UInt32 = 4294966573
TBNRF_HIDEHELP: UInt32 = 1
TBNRF_ENDCUSTOMIZE: UInt32 = 2
TBN_WRAPHOTITEM: UInt32 = 4294966572
TBN_DUPACCELERATOR: UInt32 = 4294966571
TBN_WRAPACCELERATOR: UInt32 = 4294966570
TBN_DRAGOVER: UInt32 = 4294966569
TBN_MAPACCELERATOR: UInt32 = 4294966568
TBN_GETINFOTIP: UInt32 = 4294966577
TBN_GETDISPINFO: UInt32 = 4294966579
TBDDRET_DEFAULT: UInt32 = 0
TBDDRET_NODEFAULT: UInt32 = 1
TBDDRET_TREATPRESSED: UInt32 = 2
TBN_GETBUTTONINFO: UInt32 = 4294966576
REBARCLASSNAMEW: String = 'ReBarWindow32'
REBARCLASSNAMEA: String = 'ReBarWindow32'
REBARCLASSNAME: String = 'ReBarWindow32'
RBIM_IMAGELIST: UInt32 = 1
RBS_TOOLTIPS: UInt32 = 256
RBS_VARHEIGHT: UInt32 = 512
RBS_BANDBORDERS: UInt32 = 1024
RBS_FIXEDORDER: UInt32 = 2048
RBS_REGISTERDROP: UInt32 = 4096
RBS_AUTOSIZE: UInt32 = 8192
RBS_VERTICALGRIPPER: UInt32 = 16384
RBS_DBLCLKTOGGLE: UInt32 = 32768
RBBS_BREAK: UInt32 = 1
RBBS_FIXEDSIZE: UInt32 = 2
RBBS_CHILDEDGE: UInt32 = 4
RBBS_HIDDEN: UInt32 = 8
RBBS_NOVERT: UInt32 = 16
RBBS_FIXEDBMP: UInt32 = 32
RBBS_VARIABLEHEIGHT: UInt32 = 64
RBBS_GRIPPERALWAYS: UInt32 = 128
RBBS_NOGRIPPER: UInt32 = 256
RBBS_USECHEVRON: UInt32 = 512
RBBS_HIDETITLE: UInt32 = 1024
RBBS_TOPALIGN: UInt32 = 2048
RBBIM_STYLE: UInt32 = 1
RBBIM_COLORS: UInt32 = 2
RBBIM_TEXT: UInt32 = 4
RBBIM_IMAGE: UInt32 = 8
RBBIM_CHILD: UInt32 = 16
RBBIM_CHILDSIZE: UInt32 = 32
RBBIM_SIZE: UInt32 = 64
RBBIM_BACKGROUND: UInt32 = 128
RBBIM_ID: UInt32 = 256
RBBIM_IDEALSIZE: UInt32 = 512
RBBIM_LPARAM: UInt32 = 1024
RBBIM_HEADERSIZE: UInt32 = 2048
RBBIM_CHEVRONLOCATION: UInt32 = 4096
RBBIM_CHEVRONSTATE: UInt32 = 8192
RB_INSERTBANDA: UInt32 = 1025
RB_DELETEBAND: UInt32 = 1026
RB_GETBARINFO: UInt32 = 1027
RB_SETBARINFO: UInt32 = 1028
RB_SETBANDINFOA: UInt32 = 1030
RB_SETPARENT: UInt32 = 1031
RB_HITTEST: UInt32 = 1032
RB_GETRECT: UInt32 = 1033
RB_INSERTBANDW: UInt32 = 1034
RB_SETBANDINFOW: UInt32 = 1035
RB_GETBANDCOUNT: UInt32 = 1036
RB_GETROWCOUNT: UInt32 = 1037
RB_GETROWHEIGHT: UInt32 = 1038
RB_IDTOINDEX: UInt32 = 1040
RB_GETTOOLTIPS: UInt32 = 1041
RB_SETTOOLTIPS: UInt32 = 1042
RB_SETBKCOLOR: UInt32 = 1043
RB_GETBKCOLOR: UInt32 = 1044
RB_SETTEXTCOLOR: UInt32 = 1045
RB_GETTEXTCOLOR: UInt32 = 1046
RBSTR_CHANGERECT: UInt32 = 1
RB_SIZETORECT: UInt32 = 1047
RB_SETCOLORSCHEME: UInt32 = 8194
RB_GETCOLORSCHEME: UInt32 = 8195
RB_INSERTBAND: UInt32 = 1034
RB_SETBANDINFO: UInt32 = 1035
RB_BEGINDRAG: UInt32 = 1048
RB_ENDDRAG: UInt32 = 1049
RB_DRAGMOVE: UInt32 = 1050
RB_GETBARHEIGHT: UInt32 = 1051
RB_GETBANDINFOW: UInt32 = 1052
RB_GETBANDINFOA: UInt32 = 1053
RB_GETBANDINFO: UInt32 = 1052
RB_MINIMIZEBAND: UInt32 = 1054
RB_MAXIMIZEBAND: UInt32 = 1055
RB_GETDROPTARGET: UInt32 = 8196
RB_GETBANDBORDERS: UInt32 = 1058
RB_SHOWBAND: UInt32 = 1059
RB_SETPALETTE: UInt32 = 1061
RB_GETPALETTE: UInt32 = 1062
RB_MOVEBAND: UInt32 = 1063
RB_SETUNICODEFORMAT: UInt32 = 8197
RB_GETUNICODEFORMAT: UInt32 = 8198
RB_GETBANDMARGINS: UInt32 = 1064
RB_SETWINDOWTHEME: UInt32 = 8203
RB_SETEXTENDEDSTYLE: UInt32 = 1065
RB_GETEXTENDEDSTYLE: UInt32 = 1066
RB_PUSHCHEVRON: UInt32 = 1067
RB_SETBANDWIDTH: UInt32 = 1068
RBN_HEIGHTCHANGE: UInt32 = 4294966465
RBN_GETOBJECT: UInt32 = 4294966464
RBN_LAYOUTCHANGED: UInt32 = 4294966463
RBN_AUTOSIZE: UInt32 = 4294966462
RBN_BEGINDRAG: UInt32 = 4294966461
RBN_ENDDRAG: UInt32 = 4294966460
RBN_DELETINGBAND: UInt32 = 4294966459
RBN_DELETEDBAND: UInt32 = 4294966458
RBN_CHILDSIZE: UInt32 = 4294966457
RBN_CHEVRONPUSHED: UInt32 = 4294966455
RBN_SPLITTERDRAG: UInt32 = 4294966454
RBN_MINMAX: UInt32 = 4294966444
RBN_AUTOBREAK: UInt32 = 4294966443
RBAB_AUTOSIZE: UInt32 = 1
RBAB_ADDBAND: UInt32 = 2
RBHT_NOWHERE: UInt32 = 1
RBHT_CAPTION: UInt32 = 2
RBHT_CLIENT: UInt32 = 3
RBHT_GRABBER: UInt32 = 4
RBHT_CHEVRON: UInt32 = 8
RBHT_SPLITTER: UInt32 = 16
TOOLTIPS_CLASSW: String = 'tooltips_class32'
TOOLTIPS_CLASSA: String = 'tooltips_class32'
TOOLTIPS_CLASS: String = 'tooltips_class32'
TTS_ALWAYSTIP: UInt32 = 1
TTS_NOPREFIX: UInt32 = 2
TTS_NOANIMATE: UInt32 = 16
TTS_NOFADE: UInt32 = 32
TTS_BALLOON: UInt32 = 64
TTS_CLOSE: UInt32 = 128
TTS_USEVISUALSTYLE: UInt32 = 256
TTDT_AUTOMATIC: UInt32 = 0
TTDT_RESHOW: UInt32 = 1
TTDT_AUTOPOP: UInt32 = 2
TTDT_INITIAL: UInt32 = 3
TTM_ACTIVATE: UInt32 = 1025
TTM_SETDELAYTIME: UInt32 = 1027
TTM_ADDTOOLA: UInt32 = 1028
TTM_ADDTOOLW: UInt32 = 1074
TTM_DELTOOLA: UInt32 = 1029
TTM_DELTOOLW: UInt32 = 1075
TTM_NEWTOOLRECTA: UInt32 = 1030
TTM_NEWTOOLRECTW: UInt32 = 1076
TTM_RELAYEVENT: UInt32 = 1031
TTM_GETTOOLINFOA: UInt32 = 1032
TTM_GETTOOLINFOW: UInt32 = 1077
TTM_SETTOOLINFOA: UInt32 = 1033
TTM_SETTOOLINFOW: UInt32 = 1078
TTM_HITTESTA: UInt32 = 1034
TTM_HITTESTW: UInt32 = 1079
TTM_GETTEXTA: UInt32 = 1035
TTM_GETTEXTW: UInt32 = 1080
TTM_UPDATETIPTEXTA: UInt32 = 1036
TTM_UPDATETIPTEXTW: UInt32 = 1081
TTM_GETTOOLCOUNT: UInt32 = 1037
TTM_ENUMTOOLSA: UInt32 = 1038
TTM_ENUMTOOLSW: UInt32 = 1082
TTM_GETCURRENTTOOLA: UInt32 = 1039
TTM_GETCURRENTTOOLW: UInt32 = 1083
TTM_WINDOWFROMPOINT: UInt32 = 1040
TTM_TRACKACTIVATE: UInt32 = 1041
TTM_TRACKPOSITION: UInt32 = 1042
TTM_SETTIPBKCOLOR: UInt32 = 1043
TTM_SETTIPTEXTCOLOR: UInt32 = 1044
TTM_GETDELAYTIME: UInt32 = 1045
TTM_GETTIPBKCOLOR: UInt32 = 1046
TTM_GETTIPTEXTCOLOR: UInt32 = 1047
TTM_SETMAXTIPWIDTH: UInt32 = 1048
TTM_GETMAXTIPWIDTH: UInt32 = 1049
TTM_SETMARGIN: UInt32 = 1050
TTM_GETMARGIN: UInt32 = 1051
TTM_POP: UInt32 = 1052
TTM_UPDATE: UInt32 = 1053
TTM_GETBUBBLESIZE: UInt32 = 1054
TTM_ADJUSTRECT: UInt32 = 1055
TTM_SETTITLEA: UInt32 = 1056
TTM_SETTITLEW: UInt32 = 1057
TTM_POPUP: UInt32 = 1058
TTM_GETTITLE: UInt32 = 1059
TTM_ADDTOOL: UInt32 = 1074
TTM_DELTOOL: UInt32 = 1075
TTM_NEWTOOLRECT: UInt32 = 1076
TTM_GETTOOLINFO: UInt32 = 1077
TTM_SETTOOLINFO: UInt32 = 1078
TTM_HITTEST: UInt32 = 1079
TTM_GETTEXT: UInt32 = 1080
TTM_UPDATETIPTEXT: UInt32 = 1081
TTM_ENUMTOOLS: UInt32 = 1082
TTM_GETCURRENTTOOL: UInt32 = 1083
TTM_SETTITLE: UInt32 = 1057
TTM_SETWINDOWTHEME: UInt32 = 8203
TTN_GETDISPINFOA: UInt32 = 4294966776
TTN_GETDISPINFOW: UInt32 = 4294966766
TTN_SHOW: UInt32 = 4294966775
TTN_POP: UInt32 = 4294966774
TTN_LINKCLICK: UInt32 = 4294966773
TTN_GETDISPINFO: UInt32 = 4294966766
TTN_NEEDTEXT: UInt32 = 4294966766
TTN_NEEDTEXTA: UInt32 = 4294966776
TTN_NEEDTEXTW: UInt32 = 4294966766
SBARS_SIZEGRIP: UInt32 = 256
SBARS_TOOLTIPS: UInt32 = 2048
SBT_TOOLTIPS: UInt32 = 2048
STATUSCLASSNAMEW: String = 'msctls_statusbar32'
STATUSCLASSNAMEA: String = 'msctls_statusbar32'
STATUSCLASSNAME: String = 'msctls_statusbar32'
SB_SETTEXTA: UInt32 = 1025
SB_SETTEXTW: UInt32 = 1035
SB_GETTEXTA: UInt32 = 1026
SB_GETTEXTW: UInt32 = 1037
SB_GETTEXTLENGTHA: UInt32 = 1027
SB_GETTEXTLENGTHW: UInt32 = 1036
SB_GETTEXT: UInt32 = 1037
SB_SETTEXT: UInt32 = 1035
SB_GETTEXTLENGTH: UInt32 = 1036
SB_SETPARTS: UInt32 = 1028
SB_GETPARTS: UInt32 = 1030
SB_GETBORDERS: UInt32 = 1031
SB_SETMINHEIGHT: UInt32 = 1032
SB_SIMPLE: UInt32 = 1033
SB_GETRECT: UInt32 = 1034
SB_ISSIMPLE: UInt32 = 1038
SB_SETICON: UInt32 = 1039
SB_SETTIPTEXTA: UInt32 = 1040
SB_SETTIPTEXTW: UInt32 = 1041
SB_GETTIPTEXTA: UInt32 = 1042
SB_GETTIPTEXTW: UInt32 = 1043
SB_GETICON: UInt32 = 1044
SB_SETUNICODEFORMAT: UInt32 = 8197
SB_GETUNICODEFORMAT: UInt32 = 8198
SBT_OWNERDRAW: UInt32 = 4096
SBT_NOBORDERS: UInt32 = 256
SBT_POPOUT: UInt32 = 512
SBT_RTLREADING: UInt32 = 1024
SBT_NOTABPARSING: UInt32 = 2048
SB_SETBKCOLOR: UInt32 = 8193
SBN_SIMPLEMODECHANGE: UInt32 = 4294966416
SB_SIMPLEID: UInt32 = 255
TRACKBAR_CLASSA: String = 'msctls_trackbar32'
TRACKBAR_CLASSW: String = 'msctls_trackbar32'
TRACKBAR_CLASS: String = 'msctls_trackbar32'
TBS_AUTOTICKS: UInt32 = 1
TBS_VERT: UInt32 = 2
TBS_HORZ: UInt32 = 0
TBS_TOP: UInt32 = 4
TBS_BOTTOM: UInt32 = 0
TBS_LEFT: UInt32 = 4
TBS_RIGHT: UInt32 = 0
TBS_BOTH: UInt32 = 8
TBS_NOTICKS: UInt32 = 16
TBS_ENABLESELRANGE: UInt32 = 32
TBS_FIXEDLENGTH: UInt32 = 64
TBS_NOTHUMB: UInt32 = 128
TBS_TOOLTIPS: UInt32 = 256
TBS_REVERSED: UInt32 = 512
TBS_DOWNISLEFT: UInt32 = 1024
TBS_NOTIFYBEFOREMOVE: UInt32 = 2048
TBS_TRANSPARENTBKGND: UInt32 = 4096
TBM_GETRANGEMIN: UInt32 = 1025
TBM_GETRANGEMAX: UInt32 = 1026
TBM_GETTIC: UInt32 = 1027
TBM_SETTIC: UInt32 = 1028
TBM_SETPOS: UInt32 = 1029
TBM_SETRANGE: UInt32 = 1030
TBM_SETRANGEMIN: UInt32 = 1031
TBM_SETRANGEMAX: UInt32 = 1032
TBM_CLEARTICS: UInt32 = 1033
TBM_SETSEL: UInt32 = 1034
TBM_SETSELSTART: UInt32 = 1035
TBM_SETSELEND: UInt32 = 1036
TBM_GETPTICS: UInt32 = 1038
TBM_GETTICPOS: UInt32 = 1039
TBM_GETNUMTICS: UInt32 = 1040
TBM_GETSELSTART: UInt32 = 1041
TBM_GETSELEND: UInt32 = 1042
TBM_CLEARSEL: UInt32 = 1043
TBM_SETTICFREQ: UInt32 = 1044
TBM_SETPAGESIZE: UInt32 = 1045
TBM_GETPAGESIZE: UInt32 = 1046
TBM_SETLINESIZE: UInt32 = 1047
TBM_GETLINESIZE: UInt32 = 1048
TBM_GETTHUMBRECT: UInt32 = 1049
TBM_GETCHANNELRECT: UInt32 = 1050
TBM_SETTHUMBLENGTH: UInt32 = 1051
TBM_GETTHUMBLENGTH: UInt32 = 1052
TBM_SETTOOLTIPS: UInt32 = 1053
TBM_GETTOOLTIPS: UInt32 = 1054
TBM_SETTIPSIDE: UInt32 = 1055
TBTS_TOP: UInt32 = 0
TBTS_LEFT: UInt32 = 1
TBTS_BOTTOM: UInt32 = 2
TBTS_RIGHT: UInt32 = 3
TBM_SETBUDDY: UInt32 = 1056
TBM_GETBUDDY: UInt32 = 1057
TBM_SETPOSNOTIFY: UInt32 = 1058
TBM_SETUNICODEFORMAT: UInt32 = 8197
TBM_GETUNICODEFORMAT: UInt32 = 8198
TB_LINEUP: UInt32 = 0
TB_LINEDOWN: UInt32 = 1
TB_PAGEUP: UInt32 = 2
TB_PAGEDOWN: UInt32 = 3
TB_THUMBPOSITION: UInt32 = 4
TB_THUMBTRACK: UInt32 = 5
TB_TOP: UInt32 = 6
TB_BOTTOM: UInt32 = 7
TB_ENDTRACK: UInt32 = 8
TBCD_TICS: UInt32 = 1
TBCD_THUMB: UInt32 = 2
TBCD_CHANNEL: UInt32 = 3
TRBN_THUMBPOSCHANGING: UInt32 = 4294965794
DL_CURSORSET: UInt32 = 0
DL_STOPCURSOR: UInt32 = 1
DL_COPYCURSOR: UInt32 = 2
DL_MOVECURSOR: UInt32 = 3
DRAGLISTMSGSTRING: String = 'commctrl_DragListMsg'
UPDOWN_CLASSA: String = 'msctls_updown32'
UPDOWN_CLASSW: String = 'msctls_updown32'
UPDOWN_CLASS: String = 'msctls_updown32'
UD_MAXVAL: UInt32 = 32767
UDS_WRAP: UInt32 = 1
UDS_SETBUDDYINT: UInt32 = 2
UDS_ALIGNRIGHT: UInt32 = 4
UDS_ALIGNLEFT: UInt32 = 8
UDS_AUTOBUDDY: UInt32 = 16
UDS_ARROWKEYS: UInt32 = 32
UDS_HORZ: UInt32 = 64
UDS_NOTHOUSANDS: UInt32 = 128
UDS_HOTTRACK: UInt32 = 256
UDM_SETRANGE: UInt32 = 1125
UDM_GETRANGE: UInt32 = 1126
UDM_SETPOS: UInt32 = 1127
UDM_GETPOS: UInt32 = 1128
UDM_SETBUDDY: UInt32 = 1129
UDM_GETBUDDY: UInt32 = 1130
UDM_SETACCEL: UInt32 = 1131
UDM_GETACCEL: UInt32 = 1132
UDM_SETBASE: UInt32 = 1133
UDM_GETBASE: UInt32 = 1134
UDM_SETRANGE32: UInt32 = 1135
UDM_GETRANGE32: UInt32 = 1136
UDM_SETUNICODEFORMAT: UInt32 = 8197
UDM_GETUNICODEFORMAT: UInt32 = 8198
UDM_SETPOS32: UInt32 = 1137
UDM_GETPOS32: UInt32 = 1138
UDN_DELTAPOS: UInt32 = 4294966574
PROGRESS_CLASSA: String = 'msctls_progress32'
PROGRESS_CLASSW: String = 'msctls_progress32'
PROGRESS_CLASS: String = 'msctls_progress32'
PBS_SMOOTH: UInt32 = 1
PBS_VERTICAL: UInt32 = 4
PBM_SETRANGE: UInt32 = 1025
PBM_SETPOS: UInt32 = 1026
PBM_DELTAPOS: UInt32 = 1027
PBM_SETSTEP: UInt32 = 1028
PBM_STEPIT: UInt32 = 1029
PBM_SETRANGE32: UInt32 = 1030
PBM_GETRANGE: UInt32 = 1031
PBM_GETPOS: UInt32 = 1032
PBM_SETBARCOLOR: UInt32 = 1033
PBM_SETBKCOLOR: UInt32 = 8193
PBS_MARQUEE: UInt32 = 8
PBM_SETMARQUEE: UInt32 = 1034
PBS_SMOOTHREVERSE: UInt32 = 16
PBM_GETSTEP: UInt32 = 1037
PBM_GETBKCOLOR: UInt32 = 1038
PBM_GETBARCOLOR: UInt32 = 1039
PBM_SETSTATE: UInt32 = 1040
PBM_GETSTATE: UInt32 = 1041
PBST_NORMAL: UInt32 = 1
PBST_ERROR: UInt32 = 2
PBST_PAUSED: UInt32 = 3
HOTKEYF_SHIFT: UInt32 = 1
HOTKEYF_CONTROL: UInt32 = 2
HOTKEYF_ALT: UInt32 = 4
HKCOMB_NONE: UInt32 = 1
HKCOMB_S: UInt32 = 2
HKCOMB_C: UInt32 = 4
HKCOMB_A: UInt32 = 8
HKCOMB_SC: UInt32 = 16
HKCOMB_SA: UInt32 = 32
HKCOMB_CA: UInt32 = 64
HKCOMB_SCA: UInt32 = 128
HKM_SETHOTKEY: UInt32 = 1025
HKM_GETHOTKEY: UInt32 = 1026
HKM_SETRULES: UInt32 = 1027
HOTKEY_CLASSA: String = 'msctls_hotkey32'
HOTKEY_CLASSW: String = 'msctls_hotkey32'
HOTKEY_CLASS: String = 'msctls_hotkey32'
CCS_TOP: Int32 = 1
CCS_NOMOVEY: Int32 = 2
CCS_BOTTOM: Int32 = 3
CCS_NORESIZE: Int32 = 4
CCS_NOPARENTALIGN: Int32 = 8
CCS_ADJUSTABLE: Int32 = 32
CCS_NODIVIDER: Int32 = 64
CCS_VERT: Int32 = 128
INVALID_LINK_INDEX: Int32 = -1
MAX_LINKID_TEXT: UInt32 = 48
WC_LINK: String = 'SysLink'
LWS_TRANSPARENT: UInt32 = 1
LWS_IGNORERETURN: UInt32 = 2
LWS_NOPREFIX: UInt32 = 4
LWS_USEVISUALSTYLE: UInt32 = 8
LWS_USECUSTOMTEXT: UInt32 = 16
LWS_RIGHT: UInt32 = 32
LM_HITTEST: UInt32 = 1792
LM_GETIDEALHEIGHT: UInt32 = 1793
LM_SETITEM: UInt32 = 1794
LM_GETITEM: UInt32 = 1795
LM_GETIDEALSIZE: UInt32 = 1793
WC_LISTVIEWA: String = 'SysListView32'
WC_LISTVIEWW: String = 'SysListView32'
WC_LISTVIEW: String = 'SysListView32'
LVS_ICON: UInt32 = 0
LVS_REPORT: UInt32 = 1
LVS_SMALLICON: UInt32 = 2
LVS_LIST: UInt32 = 3
LVS_TYPEMASK: UInt32 = 3
LVS_SINGLESEL: UInt32 = 4
LVS_SHOWSELALWAYS: UInt32 = 8
LVS_SORTASCENDING: UInt32 = 16
LVS_SORTDESCENDING: UInt32 = 32
LVS_SHAREIMAGELISTS: UInt32 = 64
LVS_NOLABELWRAP: UInt32 = 128
LVS_AUTOARRANGE: UInt32 = 256
LVS_EDITLABELS: UInt32 = 512
LVS_OWNERDATA: UInt32 = 4096
LVS_NOSCROLL: UInt32 = 8192
LVS_TYPESTYLEMASK: UInt32 = 64512
LVS_ALIGNTOP: UInt32 = 0
LVS_ALIGNLEFT: UInt32 = 2048
LVS_ALIGNMASK: UInt32 = 3072
LVS_OWNERDRAWFIXED: UInt32 = 1024
LVS_NOCOLUMNHEADER: UInt32 = 16384
LVS_NOSORTHEADER: UInt32 = 32768
LVM_SETUNICODEFORMAT: UInt32 = 8197
LVM_GETUNICODEFORMAT: UInt32 = 8198
LVM_GETBKCOLOR: UInt32 = 4096
LVM_SETBKCOLOR: UInt32 = 4097
LVM_GETIMAGELIST: UInt32 = 4098
LVSIL_NORMAL: UInt32 = 0
LVSIL_SMALL: UInt32 = 1
LVSIL_STATE: UInt32 = 2
LVSIL_GROUPHEADER: UInt32 = 3
LVM_SETIMAGELIST: UInt32 = 4099
LVM_GETITEMCOUNT: UInt32 = 4100
I_INDENTCALLBACK: Int32 = -1
I_IMAGECALLBACK: Int32 = -1
I_IMAGENONE: Int32 = -2
LVM_GETITEMA: UInt32 = 4101
LVM_GETITEMW: UInt32 = 4171
LVM_GETITEM: UInt32 = 4171
LVM_SETITEMA: UInt32 = 4102
LVM_SETITEMW: UInt32 = 4172
LVM_SETITEM: UInt32 = 4172
LVM_INSERTITEMA: UInt32 = 4103
LVM_INSERTITEMW: UInt32 = 4173
LVM_INSERTITEM: UInt32 = 4173
LVM_DELETEITEM: UInt32 = 4104
LVM_DELETEALLITEMS: UInt32 = 4105
LVM_GETCALLBACKMASK: UInt32 = 4106
LVM_SETCALLBACKMASK: UInt32 = 4107
LVNI_ALL: UInt32 = 0
LVNI_FOCUSED: UInt32 = 1
LVNI_SELECTED: UInt32 = 2
LVNI_CUT: UInt32 = 4
LVNI_DROPHILITED: UInt32 = 8
LVNI_VISIBLEORDER: UInt32 = 16
LVNI_PREVIOUS: UInt32 = 32
LVNI_VISIBLEONLY: UInt32 = 64
LVNI_SAMEGROUPONLY: UInt32 = 128
LVNI_ABOVE: UInt32 = 256
LVNI_BELOW: UInt32 = 512
LVNI_TOLEFT: UInt32 = 1024
LVNI_TORIGHT: UInt32 = 2048
LVM_GETNEXTITEM: UInt32 = 4108
LVM_FINDITEMA: UInt32 = 4109
LVM_FINDITEMW: UInt32 = 4179
LVM_FINDITEM: UInt32 = 4179
LVIR_BOUNDS: UInt32 = 0
LVIR_ICON: UInt32 = 1
LVIR_LABEL: UInt32 = 2
LVIR_SELECTBOUNDS: UInt32 = 3
LVM_GETITEMRECT: UInt32 = 4110
LVM_SETITEMPOSITION: UInt32 = 4111
LVM_GETITEMPOSITION: UInt32 = 4112
LVM_GETSTRINGWIDTHA: UInt32 = 4113
LVM_GETSTRINGWIDTHW: UInt32 = 4183
LVM_GETSTRINGWIDTH: UInt32 = 4183
LVM_HITTEST: UInt32 = 4114
LVM_ENSUREVISIBLE: UInt32 = 4115
LVM_SCROLL: UInt32 = 4116
LVM_REDRAWITEMS: UInt32 = 4117
LVA_DEFAULT: UInt32 = 0
LVA_ALIGNLEFT: UInt32 = 1
LVA_ALIGNTOP: UInt32 = 2
LVA_SNAPTOGRID: UInt32 = 5
LVM_ARRANGE: UInt32 = 4118
LVM_EDITLABELA: UInt32 = 4119
LVM_EDITLABELW: UInt32 = 4214
LVM_EDITLABEL: UInt32 = 4214
LVM_GETEDITCONTROL: UInt32 = 4120
LVM_GETCOLUMNA: UInt32 = 4121
LVM_GETCOLUMNW: UInt32 = 4191
LVM_GETCOLUMN: UInt32 = 4191
LVM_SETCOLUMNA: UInt32 = 4122
LVM_SETCOLUMNW: UInt32 = 4192
LVM_SETCOLUMN: UInt32 = 4192
LVM_INSERTCOLUMNA: UInt32 = 4123
LVM_INSERTCOLUMNW: UInt32 = 4193
LVM_INSERTCOLUMN: UInt32 = 4193
LVM_DELETECOLUMN: UInt32 = 4124
LVM_GETCOLUMNWIDTH: UInt32 = 4125
LVSCW_AUTOSIZE: Int32 = -1
LVSCW_AUTOSIZE_USEHEADER: Int32 = -2
LVM_SETCOLUMNWIDTH: UInt32 = 4126
LVM_GETHEADER: UInt32 = 4127
LVM_CREATEDRAGIMAGE: UInt32 = 4129
LVM_GETVIEWRECT: UInt32 = 4130
LVM_GETTEXTCOLOR: UInt32 = 4131
LVM_SETTEXTCOLOR: UInt32 = 4132
LVM_GETTEXTBKCOLOR: UInt32 = 4133
LVM_SETTEXTBKCOLOR: UInt32 = 4134
LVM_GETTOPINDEX: UInt32 = 4135
LVM_GETCOUNTPERPAGE: UInt32 = 4136
LVM_GETORIGIN: UInt32 = 4137
LVM_UPDATE: UInt32 = 4138
LVM_SETITEMSTATE: UInt32 = 4139
LVM_GETITEMSTATE: UInt32 = 4140
LVM_GETITEMTEXTA: UInt32 = 4141
LVM_GETITEMTEXTW: UInt32 = 4211
LVM_GETITEMTEXT: UInt32 = 4211
LVM_SETITEMTEXTA: UInt32 = 4142
LVM_SETITEMTEXTW: UInt32 = 4212
LVM_SETITEMTEXT: UInt32 = 4212
LVSICF_NOINVALIDATEALL: UInt32 = 1
LVSICF_NOSCROLL: UInt32 = 2
LVM_SETITEMCOUNT: UInt32 = 4143
LVM_SORTITEMS: UInt32 = 4144
LVM_SETITEMPOSITION32: UInt32 = 4145
LVM_GETSELECTEDCOUNT: UInt32 = 4146
LVM_GETITEMSPACING: UInt32 = 4147
LVM_GETISEARCHSTRINGA: UInt32 = 4148
LVM_GETISEARCHSTRINGW: UInt32 = 4213
LVM_GETISEARCHSTRING: UInt32 = 4213
LVM_SETICONSPACING: UInt32 = 4149
LVM_SETEXTENDEDLISTVIEWSTYLE: UInt32 = 4150
LVM_GETEXTENDEDLISTVIEWSTYLE: UInt32 = 4151
LVS_EX_GRIDLINES: UInt32 = 1
LVS_EX_SUBITEMIMAGES: UInt32 = 2
LVS_EX_CHECKBOXES: UInt32 = 4
LVS_EX_TRACKSELECT: UInt32 = 8
LVS_EX_HEADERDRAGDROP: UInt32 = 16
LVS_EX_FULLROWSELECT: UInt32 = 32
LVS_EX_ONECLICKACTIVATE: UInt32 = 64
LVS_EX_TWOCLICKACTIVATE: UInt32 = 128
LVS_EX_FLATSB: UInt32 = 256
LVS_EX_REGIONAL: UInt32 = 512
LVS_EX_INFOTIP: UInt32 = 1024
LVS_EX_UNDERLINEHOT: UInt32 = 2048
LVS_EX_UNDERLINECOLD: UInt32 = 4096
LVS_EX_MULTIWORKAREAS: UInt32 = 8192
LVS_EX_LABELTIP: UInt32 = 16384
LVS_EX_BORDERSELECT: UInt32 = 32768
LVS_EX_DOUBLEBUFFER: UInt32 = 65536
LVS_EX_HIDELABELS: UInt32 = 131072
LVS_EX_SINGLEROW: UInt32 = 262144
LVS_EX_SNAPTOGRID: UInt32 = 524288
LVS_EX_SIMPLESELECT: UInt32 = 1048576
LVS_EX_JUSTIFYCOLUMNS: UInt32 = 2097152
LVS_EX_TRANSPARENTBKGND: UInt32 = 4194304
LVS_EX_TRANSPARENTSHADOWTEXT: UInt32 = 8388608
LVS_EX_AUTOAUTOARRANGE: UInt32 = 16777216
LVS_EX_HEADERINALLVIEWS: UInt32 = 33554432
LVS_EX_AUTOCHECKSELECT: UInt32 = 134217728
LVS_EX_AUTOSIZECOLUMNS: UInt32 = 268435456
LVS_EX_COLUMNSNAPPOINTS: UInt32 = 1073741824
LVS_EX_COLUMNOVERFLOW: UInt32 = 2147483648
LVM_GETSUBITEMRECT: UInt32 = 4152
LVM_SUBITEMHITTEST: UInt32 = 4153
LVM_SETCOLUMNORDERARRAY: UInt32 = 4154
LVM_GETCOLUMNORDERARRAY: UInt32 = 4155
LVM_SETHOTITEM: UInt32 = 4156
LVM_GETHOTITEM: UInt32 = 4157
LVM_SETHOTCURSOR: UInt32 = 4158
LVM_GETHOTCURSOR: UInt32 = 4159
LVM_APPROXIMATEVIEWRECT: UInt32 = 4160
LV_MAX_WORKAREAS: UInt32 = 16
LVM_SETWORKAREAS: UInt32 = 4161
LVM_GETWORKAREAS: UInt32 = 4166
LVM_GETNUMBEROFWORKAREAS: UInt32 = 4169
LVM_GETSELECTIONMARK: UInt32 = 4162
LVM_SETSELECTIONMARK: UInt32 = 4163
LVM_SETHOVERTIME: UInt32 = 4167
LVM_GETHOVERTIME: UInt32 = 4168
LVM_SETTOOLTIPS: UInt32 = 4170
LVM_GETTOOLTIPS: UInt32 = 4174
LVM_SORTITEMSEX: UInt32 = 4177
LVM_SETBKIMAGEA: UInt32 = 4164
LVM_SETBKIMAGEW: UInt32 = 4234
LVM_GETBKIMAGEA: UInt32 = 4165
LVM_GETBKIMAGEW: UInt32 = 4235
LVM_SETSELECTEDCOLUMN: UInt32 = 4236
LV_VIEW_ICON: UInt32 = 0
LV_VIEW_DETAILS: UInt32 = 1
LV_VIEW_SMALLICON: UInt32 = 2
LV_VIEW_LIST: UInt32 = 3
LV_VIEW_TILE: UInt32 = 4
LV_VIEW_MAX: UInt32 = 4
LVM_SETVIEW: UInt32 = 4238
LVM_GETVIEW: UInt32 = 4239
LVM_INSERTGROUP: UInt32 = 4241
LVM_SETGROUPINFO: UInt32 = 4243
LVM_GETGROUPINFO: UInt32 = 4245
LVM_REMOVEGROUP: UInt32 = 4246
LVM_MOVEGROUP: UInt32 = 4247
LVM_GETGROUPCOUNT: UInt32 = 4248
LVM_GETGROUPINFOBYINDEX: UInt32 = 4249
LVM_MOVEITEMTOGROUP: UInt32 = 4250
LVGGR_GROUP: UInt32 = 0
LVGGR_HEADER: UInt32 = 1
LVGGR_LABEL: UInt32 = 2
LVGGR_SUBSETLINK: UInt32 = 3
LVM_GETGROUPRECT: UInt32 = 4194
LVGMF_NONE: UInt32 = 0
LVGMF_BORDERSIZE: UInt32 = 1
LVGMF_BORDERCOLOR: UInt32 = 2
LVGMF_TEXTCOLOR: UInt32 = 4
LVM_SETGROUPMETRICS: UInt32 = 4251
LVM_GETGROUPMETRICS: UInt32 = 4252
LVM_ENABLEGROUPVIEW: UInt32 = 4253
LVM_SORTGROUPS: UInt32 = 4254
LVM_INSERTGROUPSORTED: UInt32 = 4255
LVM_REMOVEALLGROUPS: UInt32 = 4256
LVM_HASGROUP: UInt32 = 4257
LVM_GETGROUPSTATE: UInt32 = 4188
LVM_GETFOCUSEDGROUP: UInt32 = 4189
LVTVIF_EXTENDED: UInt32 = 4
LVM_SETTILEVIEWINFO: UInt32 = 4258
LVM_GETTILEVIEWINFO: UInt32 = 4259
LVM_SETTILEINFO: UInt32 = 4260
LVM_GETTILEINFO: UInt32 = 4261
LVIM_AFTER: UInt32 = 1
LVM_SETINSERTMARK: UInt32 = 4262
LVM_GETINSERTMARK: UInt32 = 4263
LVM_INSERTMARKHITTEST: UInt32 = 4264
LVM_GETINSERTMARKRECT: UInt32 = 4265
LVM_SETINSERTMARKCOLOR: UInt32 = 4266
LVM_GETINSERTMARKCOLOR: UInt32 = 4267
LVM_SETINFOTIP: UInt32 = 4269
LVM_GETSELECTEDCOLUMN: UInt32 = 4270
LVM_ISGROUPVIEWENABLED: UInt32 = 4271
LVM_GETOUTLINECOLOR: UInt32 = 4272
LVM_SETOUTLINECOLOR: UInt32 = 4273
LVM_CANCELEDITLABEL: UInt32 = 4275
LVM_MAPINDEXTOID: UInt32 = 4276
LVM_MAPIDTOINDEX: UInt32 = 4277
LVM_ISITEMVISIBLE: UInt32 = 4278
LVM_GETEMPTYTEXT: UInt32 = 4300
LVM_GETFOOTERRECT: UInt32 = 4301
LVFF_ITEMCOUNT: UInt32 = 1
LVM_GETFOOTERINFO: UInt32 = 4302
LVM_GETFOOTERITEMRECT: UInt32 = 4303
LVFIS_FOCUSED: UInt32 = 1
LVM_GETFOOTERITEM: UInt32 = 4304
LVM_GETITEMINDEXRECT: UInt32 = 4305
LVM_SETITEMINDEXSTATE: UInt32 = 4306
LVM_GETNEXTITEMINDEX: UInt32 = 4307
LVM_SETBKIMAGE: UInt32 = 4234
LVM_GETBKIMAGE: UInt32 = 4235
LVKF_ALT: UInt32 = 1
LVKF_CONTROL: UInt32 = 2
LVKF_SHIFT: UInt32 = 4
LVCDRF_NOSELECT: UInt32 = 65536
LVCDRF_NOGROUPFRAME: UInt32 = 131072
LVN_ITEMCHANGING: UInt32 = 4294967196
LVN_ITEMCHANGED: UInt32 = 4294967195
LVN_INSERTITEM: UInt32 = 4294967194
LVN_DELETEITEM: UInt32 = 4294967193
LVN_DELETEALLITEMS: UInt32 = 4294967192
LVN_BEGINLABELEDITA: UInt32 = 4294967191
LVN_BEGINLABELEDITW: UInt32 = 4294967121
LVN_ENDLABELEDITA: UInt32 = 4294967190
LVN_ENDLABELEDITW: UInt32 = 4294967120
LVN_COLUMNCLICK: UInt32 = 4294967188
LVN_BEGINDRAG: UInt32 = 4294967187
LVN_BEGINRDRAG: UInt32 = 4294967185
LVN_ODCACHEHINT: UInt32 = 4294967183
LVN_ODFINDITEMA: UInt32 = 4294967144
LVN_ODFINDITEMW: UInt32 = 4294967117
LVN_ITEMACTIVATE: UInt32 = 4294967182
LVN_ODSTATECHANGED: UInt32 = 4294967181
LVN_ODFINDITEM: UInt32 = 4294967117
LVN_HOTTRACK: UInt32 = 4294967175
LVN_GETDISPINFOA: UInt32 = 4294967146
LVN_GETDISPINFOW: UInt32 = 4294967119
LVN_SETDISPINFOA: UInt32 = 4294967145
LVN_SETDISPINFOW: UInt32 = 4294967118
LVN_BEGINLABELEDIT: UInt32 = 4294967121
LVN_ENDLABELEDIT: UInt32 = 4294967120
LVN_GETDISPINFO: UInt32 = 4294967119
LVN_SETDISPINFO: UInt32 = 4294967118
LVN_KEYDOWN: UInt32 = 4294967141
LVN_MARQUEEBEGIN: UInt32 = 4294967140
LVN_GETINFOTIPA: UInt32 = 4294967139
LVN_GETINFOTIPW: UInt32 = 4294967138
LVN_GETINFOTIP: UInt32 = 4294967138
LVNSCH_DEFAULT: Int32 = -1
LVNSCH_ERROR: Int32 = -2
LVNSCH_IGNORE: Int32 = -3
LVN_INCREMENTALSEARCHA: UInt32 = 4294967134
LVN_INCREMENTALSEARCHW: UInt32 = 4294967133
LVN_INCREMENTALSEARCH: UInt32 = 4294967133
LVN_COLUMNDROPDOWN: UInt32 = 4294967132
LVN_COLUMNOVERFLOWCLICK: UInt32 = 4294967130
LVN_BEGINSCROLL: UInt32 = 4294967116
LVN_ENDSCROLL: UInt32 = 4294967115
LVN_LINKCLICK: UInt32 = 4294967112
LVN_GETEMPTYMARKUP: UInt32 = 4294967109
WC_TREEVIEWA: String = 'SysTreeView32'
WC_TREEVIEWW: String = 'SysTreeView32'
WC_TREEVIEW: String = 'SysTreeView32'
TVS_HASBUTTONS: UInt32 = 1
TVS_HASLINES: UInt32 = 2
TVS_LINESATROOT: UInt32 = 4
TVS_EDITLABELS: UInt32 = 8
TVS_DISABLEDRAGDROP: UInt32 = 16
TVS_SHOWSELALWAYS: UInt32 = 32
TVS_RTLREADING: UInt32 = 64
TVS_NOTOOLTIPS: UInt32 = 128
TVS_CHECKBOXES: UInt32 = 256
TVS_TRACKSELECT: UInt32 = 512
TVS_SINGLEEXPAND: UInt32 = 1024
TVS_INFOTIP: UInt32 = 2048
TVS_FULLROWSELECT: UInt32 = 4096
TVS_NOSCROLL: UInt32 = 8192
TVS_NONEVENHEIGHT: UInt32 = 16384
TVS_NOHSCROLL: UInt32 = 32768
TVS_EX_NOSINGLECOLLAPSE: UInt32 = 1
TVS_EX_MULTISELECT: UInt32 = 2
TVS_EX_DOUBLEBUFFER: UInt32 = 4
TVS_EX_NOINDENTSTATE: UInt32 = 8
TVS_EX_RICHTOOLTIP: UInt32 = 16
TVS_EX_AUTOHSCROLL: UInt32 = 32
TVS_EX_FADEINOUTEXPANDOS: UInt32 = 64
TVS_EX_PARTIALCHECKBOXES: UInt32 = 128
TVS_EX_EXCLUSIONCHECKBOXES: UInt32 = 256
TVS_EX_DIMMEDCHECKBOXES: UInt32 = 512
TVS_EX_DRAWIMAGEASYNC: UInt32 = 1024
TVM_INSERTITEMA: UInt32 = 4352
TVM_INSERTITEMW: UInt32 = 4402
TVM_INSERTITEM: UInt32 = 4402
TVM_DELETEITEM: UInt32 = 4353
TVM_EXPAND: UInt32 = 4354
TVM_GETITEMRECT: UInt32 = 4356
TVM_GETCOUNT: UInt32 = 4357
TVM_GETINDENT: UInt32 = 4358
TVM_SETINDENT: UInt32 = 4359
TVM_GETIMAGELIST: UInt32 = 4360
TVSIL_NORMAL: UInt32 = 0
TVSIL_STATE: UInt32 = 2
TVM_SETIMAGELIST: UInt32 = 4361
TVM_GETNEXTITEM: UInt32 = 4362
TVGN_ROOT: UInt32 = 0
TVGN_NEXT: UInt32 = 1
TVGN_PREVIOUS: UInt32 = 2
TVGN_PARENT: UInt32 = 3
TVGN_CHILD: UInt32 = 4
TVGN_FIRSTVISIBLE: UInt32 = 5
TVGN_NEXTVISIBLE: UInt32 = 6
TVGN_PREVIOUSVISIBLE: UInt32 = 7
TVGN_DROPHILITE: UInt32 = 8
TVGN_CARET: UInt32 = 9
TVGN_LASTVISIBLE: UInt32 = 10
TVGN_NEXTSELECTED: UInt32 = 11
TVSI_NOSINGLEEXPAND: UInt32 = 32768
TVM_SELECTITEM: UInt32 = 4363
TVM_GETITEMA: UInt32 = 4364
TVM_GETITEMW: UInt32 = 4414
TVM_GETITEM: UInt32 = 4414
TVM_SETITEMA: UInt32 = 4365
TVM_SETITEMW: UInt32 = 4415
TVM_SETITEM: UInt32 = 4415
TVM_EDITLABELA: UInt32 = 4366
TVM_EDITLABELW: UInt32 = 4417
TVM_EDITLABEL: UInt32 = 4417
TVM_GETEDITCONTROL: UInt32 = 4367
TVM_GETVISIBLECOUNT: UInt32 = 4368
TVM_HITTEST: UInt32 = 4369
TVM_CREATEDRAGIMAGE: UInt32 = 4370
TVM_SORTCHILDREN: UInt32 = 4371
TVM_ENSUREVISIBLE: UInt32 = 4372
TVM_SORTCHILDRENCB: UInt32 = 4373
TVM_ENDEDITLABELNOW: UInt32 = 4374
TVM_GETISEARCHSTRINGA: UInt32 = 4375
TVM_GETISEARCHSTRINGW: UInt32 = 4416
TVM_GETISEARCHSTRING: UInt32 = 4416
TVM_SETTOOLTIPS: UInt32 = 4376
TVM_GETTOOLTIPS: UInt32 = 4377
TVM_SETINSERTMARK: UInt32 = 4378
TVM_SETUNICODEFORMAT: UInt32 = 8197
TVM_GETUNICODEFORMAT: UInt32 = 8198
TVM_SETITEMHEIGHT: UInt32 = 4379
TVM_GETITEMHEIGHT: UInt32 = 4380
TVM_SETBKCOLOR: UInt32 = 4381
TVM_SETTEXTCOLOR: UInt32 = 4382
TVM_GETBKCOLOR: UInt32 = 4383
TVM_GETTEXTCOLOR: UInt32 = 4384
TVM_SETSCROLLTIME: UInt32 = 4385
TVM_GETSCROLLTIME: UInt32 = 4386
TVM_SETINSERTMARKCOLOR: UInt32 = 4389
TVM_GETINSERTMARKCOLOR: UInt32 = 4390
TVM_SETBORDER: UInt32 = 4387
TVSBF_XBORDER: UInt32 = 1
TVSBF_YBORDER: UInt32 = 2
TVM_GETITEMSTATE: UInt32 = 4391
TVM_SETLINECOLOR: UInt32 = 4392
TVM_GETLINECOLOR: UInt32 = 4393
TVM_MAPACCIDTOHTREEITEM: UInt32 = 4394
TVM_MAPHTREEITEMTOACCID: UInt32 = 4395
TVM_SETEXTENDEDSTYLE: UInt32 = 4396
TVM_GETEXTENDEDSTYLE: UInt32 = 4397
TVM_SETAUTOSCROLLINFO: UInt32 = 4411
TVM_SETHOT: UInt32 = 4410
TVM_GETSELECTEDCOUNT: UInt32 = 4422
TVM_SHOWINFOTIP: UInt32 = 4423
TVM_GETITEMPARTRECT: UInt32 = 4424
TVN_SELCHANGINGA: UInt32 = 4294966895
TVN_SELCHANGINGW: UInt32 = 4294966846
TVN_SELCHANGEDA: UInt32 = 4294966894
TVN_SELCHANGEDW: UInt32 = 4294966845
TVN_GETDISPINFOA: UInt32 = 4294966893
TVN_GETDISPINFOW: UInt32 = 4294966844
TVN_SETDISPINFOA: UInt32 = 4294966892
TVN_SETDISPINFOW: UInt32 = 4294966843
TVN_ITEMEXPANDINGA: UInt32 = 4294966891
TVN_ITEMEXPANDINGW: UInt32 = 4294966842
TVN_ITEMEXPANDEDA: UInt32 = 4294966890
TVN_ITEMEXPANDEDW: UInt32 = 4294966841
TVN_BEGINDRAGA: UInt32 = 4294966889
TVN_BEGINDRAGW: UInt32 = 4294966840
TVN_BEGINRDRAGA: UInt32 = 4294966888
TVN_BEGINRDRAGW: UInt32 = 4294966839
TVN_DELETEITEMA: UInt32 = 4294966887
TVN_DELETEITEMW: UInt32 = 4294966838
TVN_BEGINLABELEDITA: UInt32 = 4294966886
TVN_BEGINLABELEDITW: UInt32 = 4294966837
TVN_ENDLABELEDITA: UInt32 = 4294966885
TVN_ENDLABELEDITW: UInt32 = 4294966836
TVN_KEYDOWN: UInt32 = 4294966884
TVN_GETINFOTIPA: UInt32 = 4294966883
TVN_GETINFOTIPW: UInt32 = 4294966882
TVN_SINGLEEXPAND: UInt32 = 4294966881
TVNRET_DEFAULT: UInt32 = 0
TVNRET_SKIPOLD: UInt32 = 1
TVNRET_SKIPNEW: UInt32 = 2
TVN_ITEMCHANGINGA: UInt32 = 4294966880
TVN_ITEMCHANGINGW: UInt32 = 4294966879
TVN_ITEMCHANGEDA: UInt32 = 4294966878
TVN_ITEMCHANGEDW: UInt32 = 4294966877
TVN_ASYNCDRAW: UInt32 = 4294966876
TVN_SELCHANGING: UInt32 = 4294966846
TVN_SELCHANGED: UInt32 = 4294966845
TVN_GETDISPINFO: UInt32 = 4294966844
TVN_SETDISPINFO: UInt32 = 4294966843
TVN_ITEMEXPANDING: UInt32 = 4294966842
TVN_ITEMEXPANDED: UInt32 = 4294966841
TVN_BEGINDRAG: UInt32 = 4294966840
TVN_BEGINRDRAG: UInt32 = 4294966839
TVN_DELETEITEM: UInt32 = 4294966838
TVN_BEGINLABELEDIT: UInt32 = 4294966837
TVN_ENDLABELEDIT: UInt32 = 4294966836
TVN_GETINFOTIP: UInt32 = 4294966882
TVCDRF_NOIMAGES: UInt32 = 65536
TVN_ITEMCHANGING: UInt32 = 4294966879
TVN_ITEMCHANGED: UInt32 = 4294966877
WC_COMBOBOXEXW: String = 'ComboBoxEx32'
WC_COMBOBOXEXA: String = 'ComboBoxEx32'
WC_COMBOBOXEX: String = 'ComboBoxEx32'
CBEM_INSERTITEMA: UInt32 = 1025
CBEM_SETIMAGELIST: UInt32 = 1026
CBEM_GETIMAGELIST: UInt32 = 1027
CBEM_GETITEMA: UInt32 = 1028
CBEM_SETITEMA: UInt32 = 1029
CBEM_GETCOMBOCONTROL: UInt32 = 1030
CBEM_GETEDITCONTROL: UInt32 = 1031
CBEM_SETEXSTYLE: UInt32 = 1032
CBEM_SETEXTENDEDSTYLE: UInt32 = 1038
CBEM_GETEXSTYLE: UInt32 = 1033
CBEM_GETEXTENDEDSTYLE: UInt32 = 1033
CBEM_SETUNICODEFORMAT: UInt32 = 8197
CBEM_GETUNICODEFORMAT: UInt32 = 8198
CBEM_HASEDITCHANGED: UInt32 = 1034
CBEM_INSERTITEMW: UInt32 = 1035
CBEM_SETITEMW: UInt32 = 1036
CBEM_GETITEMW: UInt32 = 1037
CBEM_INSERTITEM: UInt32 = 1035
CBEM_SETITEM: UInt32 = 1036
CBEM_GETITEM: UInt32 = 1037
CBEM_SETWINDOWTHEME: UInt32 = 8203
CBES_EX_NOEDITIMAGE: UInt32 = 1
CBES_EX_NOEDITIMAGEINDENT: UInt32 = 2
CBES_EX_PATHWORDBREAKPROC: UInt32 = 4
CBES_EX_NOSIZELIMIT: UInt32 = 8
CBES_EX_CASESENSITIVE: UInt32 = 16
CBES_EX_TEXTENDELLIPSIS: UInt32 = 32
CBEN_GETDISPINFOA: UInt32 = 4294966496
CBEN_INSERTITEM: UInt32 = 4294966495
CBEN_DELETEITEM: UInt32 = 4294966494
CBEN_BEGINEDIT: UInt32 = 4294966492
CBEN_ENDEDITA: UInt32 = 4294966491
CBEN_ENDEDITW: UInt32 = 4294966490
CBEN_GETDISPINFOW: UInt32 = 4294966489
CBEN_DRAGBEGINA: UInt32 = 4294966488
CBEN_DRAGBEGINW: UInt32 = 4294966487
CBEN_DRAGBEGIN: UInt32 = 4294966487
CBEN_ENDEDIT: UInt32 = 4294966490
CBENF_KILLFOCUS: UInt32 = 1
CBENF_RETURN: UInt32 = 2
CBENF_ESCAPE: UInt32 = 3
CBENF_DROPDOWN: UInt32 = 4
CBEMAXSTRLEN: UInt32 = 260
WC_TABCONTROLA: String = 'SysTabControl32'
WC_TABCONTROLW: String = 'SysTabControl32'
WC_TABCONTROL: String = 'SysTabControl32'
TCS_SCROLLOPPOSITE: UInt32 = 1
TCS_BOTTOM: UInt32 = 2
TCS_RIGHT: UInt32 = 2
TCS_MULTISELECT: UInt32 = 4
TCS_FLATBUTTONS: UInt32 = 8
TCS_FORCEICONLEFT: UInt32 = 16
TCS_FORCELABELLEFT: UInt32 = 32
TCS_HOTTRACK: UInt32 = 64
TCS_VERTICAL: UInt32 = 128
TCS_TABS: UInt32 = 0
TCS_BUTTONS: UInt32 = 256
TCS_SINGLELINE: UInt32 = 0
TCS_MULTILINE: UInt32 = 512
TCS_RIGHTJUSTIFY: UInt32 = 0
TCS_FIXEDWIDTH: UInt32 = 1024
TCS_RAGGEDRIGHT: UInt32 = 2048
TCS_FOCUSONBUTTONDOWN: UInt32 = 4096
TCS_OWNERDRAWFIXED: UInt32 = 8192
TCS_TOOLTIPS: UInt32 = 16384
TCS_FOCUSNEVER: UInt32 = 32768
TCS_EX_FLATSEPARATORS: UInt32 = 1
TCS_EX_REGISTERDROP: UInt32 = 2
TCM_GETIMAGELIST: UInt32 = 4866
TCM_SETIMAGELIST: UInt32 = 4867
TCM_GETITEMCOUNT: UInt32 = 4868
TCM_GETITEMA: UInt32 = 4869
TCM_GETITEMW: UInt32 = 4924
TCM_GETITEM: UInt32 = 4924
TCM_SETITEMA: UInt32 = 4870
TCM_SETITEMW: UInt32 = 4925
TCM_SETITEM: UInt32 = 4925
TCM_INSERTITEMA: UInt32 = 4871
TCM_INSERTITEMW: UInt32 = 4926
TCM_INSERTITEM: UInt32 = 4926
TCM_DELETEITEM: UInt32 = 4872
TCM_DELETEALLITEMS: UInt32 = 4873
TCM_GETITEMRECT: UInt32 = 4874
TCM_GETCURSEL: UInt32 = 4875
TCM_SETCURSEL: UInt32 = 4876
TCM_HITTEST: UInt32 = 4877
TCM_SETITEMEXTRA: UInt32 = 4878
TCM_ADJUSTRECT: UInt32 = 4904
TCM_SETITEMSIZE: UInt32 = 4905
TCM_REMOVEIMAGE: UInt32 = 4906
TCM_SETPADDING: UInt32 = 4907
TCM_GETROWCOUNT: UInt32 = 4908
TCM_GETTOOLTIPS: UInt32 = 4909
TCM_SETTOOLTIPS: UInt32 = 4910
TCM_GETCURFOCUS: UInt32 = 4911
TCM_SETCURFOCUS: UInt32 = 4912
TCM_SETMINTABWIDTH: UInt32 = 4913
TCM_DESELECTALL: UInt32 = 4914
TCM_HIGHLIGHTITEM: UInt32 = 4915
TCM_SETEXTENDEDSTYLE: UInt32 = 4916
TCM_GETEXTENDEDSTYLE: UInt32 = 4917
TCM_SETUNICODEFORMAT: UInt32 = 8197
TCM_GETUNICODEFORMAT: UInt32 = 8198
TCN_KEYDOWN: UInt32 = 4294966746
TCN_SELCHANGE: UInt32 = 4294966745
TCN_SELCHANGING: UInt32 = 4294966744
TCN_GETOBJECT: UInt32 = 4294966743
TCN_FOCUSCHANGE: UInt32 = 4294966742
ANIMATE_CLASSW: String = 'SysAnimate32'
ANIMATE_CLASSA: String = 'SysAnimate32'
ANIMATE_CLASS: String = 'SysAnimate32'
ACS_CENTER: UInt32 = 1
ACS_TRANSPARENT: UInt32 = 2
ACS_AUTOPLAY: UInt32 = 4
ACS_TIMER: UInt32 = 8
ACM_OPENA: UInt32 = 1124
ACM_OPENW: UInt32 = 1127
ACM_OPEN: UInt32 = 1127
ACM_PLAY: UInt32 = 1125
ACM_STOP: UInt32 = 1126
ACM_ISPLAYING: UInt32 = 1128
ACN_START: UInt32 = 1
ACN_STOP: UInt32 = 2
MONTHCAL_CLASSW: String = 'SysMonthCal32'
MONTHCAL_CLASSA: String = 'SysMonthCal32'
MONTHCAL_CLASS: String = 'SysMonthCal32'
MCM_FIRST: UInt32 = 4096
MCM_GETCURSEL: UInt32 = 4097
MCM_SETCURSEL: UInt32 = 4098
MCM_GETMAXSELCOUNT: UInt32 = 4099
MCM_SETMAXSELCOUNT: UInt32 = 4100
MCM_GETSELRANGE: UInt32 = 4101
MCM_SETSELRANGE: UInt32 = 4102
MCM_GETMONTHRANGE: UInt32 = 4103
MCM_SETDAYSTATE: UInt32 = 4104
MCM_GETMINREQRECT: UInt32 = 4105
MCM_SETCOLOR: UInt32 = 4106
MCM_GETCOLOR: UInt32 = 4107
MCSC_BACKGROUND: UInt32 = 0
MCSC_TEXT: UInt32 = 1
MCSC_TITLEBK: UInt32 = 2
MCSC_TITLETEXT: UInt32 = 3
MCSC_MONTHBK: UInt32 = 4
MCSC_TRAILINGTEXT: UInt32 = 5
MCM_SETTODAY: UInt32 = 4108
MCM_GETTODAY: UInt32 = 4109
MCM_HITTEST: UInt32 = 4110
MCM_SETFIRSTDAYOFWEEK: UInt32 = 4111
MCM_GETFIRSTDAYOFWEEK: UInt32 = 4112
MCM_GETRANGE: UInt32 = 4113
MCM_SETRANGE: UInt32 = 4114
MCM_GETMONTHDELTA: UInt32 = 4115
MCM_SETMONTHDELTA: UInt32 = 4116
MCM_GETMAXTODAYWIDTH: UInt32 = 4117
MCM_SETUNICODEFORMAT: UInt32 = 8197
MCM_GETUNICODEFORMAT: UInt32 = 8198
MCM_GETCURRENTVIEW: UInt32 = 4118
MCM_GETCALENDARCOUNT: UInt32 = 4119
MCM_GETCALENDARGRIDINFO: UInt32 = 4120
MCM_GETCALID: UInt32 = 4123
MCM_SETCALID: UInt32 = 4124
MCM_SIZERECTTOMIN: UInt32 = 4125
MCM_SETCALENDARBORDER: UInt32 = 4126
MCM_GETCALENDARBORDER: UInt32 = 4127
MCM_SETCURRENTVIEW: UInt32 = 4128
MCN_SELCHANGE: UInt32 = 4294966547
MCN_GETDAYSTATE: UInt32 = 4294966549
MCN_SELECT: UInt32 = 4294966550
MCN_VIEWCHANGE: UInt32 = 4294966546
MCS_DAYSTATE: UInt32 = 1
MCS_MULTISELECT: UInt32 = 2
MCS_WEEKNUMBERS: UInt32 = 4
MCS_NOTODAYCIRCLE: UInt32 = 8
MCS_NOTODAY: UInt32 = 16
MCS_NOTRAILINGDATES: UInt32 = 64
MCS_SHORTDAYSOFWEEK: UInt32 = 128
MCS_NOSELCHANGEONNAV: UInt32 = 256
GMR_VISIBLE: UInt32 = 0
GMR_DAYSTATE: UInt32 = 1
DATETIMEPICK_CLASSW: String = 'SysDateTimePick32'
DATETIMEPICK_CLASSA: String = 'SysDateTimePick32'
DATETIMEPICK_CLASS: String = 'SysDateTimePick32'
DTM_FIRST: UInt32 = 4096
DTM_GETSYSTEMTIME: UInt32 = 4097
DTM_SETSYSTEMTIME: UInt32 = 4098
DTM_GETRANGE: UInt32 = 4099
DTM_SETRANGE: UInt32 = 4100
DTM_SETFORMATA: UInt32 = 4101
DTM_SETFORMATW: UInt32 = 4146
DTM_SETFORMAT: UInt32 = 4146
DTM_SETMCCOLOR: UInt32 = 4102
DTM_GETMCCOLOR: UInt32 = 4103
DTM_GETMONTHCAL: UInt32 = 4104
DTM_SETMCFONT: UInt32 = 4105
DTM_GETMCFONT: UInt32 = 4106
DTM_SETMCSTYLE: UInt32 = 4107
DTM_GETMCSTYLE: UInt32 = 4108
DTM_CLOSEMONTHCAL: UInt32 = 4109
DTM_GETDATETIMEPICKERINFO: UInt32 = 4110
DTM_GETIDEALSIZE: UInt32 = 4111
DTS_UPDOWN: UInt32 = 1
DTS_SHOWNONE: UInt32 = 2
DTS_SHORTDATEFORMAT: UInt32 = 0
DTS_LONGDATEFORMAT: UInt32 = 4
DTS_SHORTDATECENTURYFORMAT: UInt32 = 12
DTS_TIMEFORMAT: UInt32 = 9
DTS_APPCANPARSE: UInt32 = 16
DTS_RIGHTALIGN: UInt32 = 32
DTN_DATETIMECHANGE: UInt32 = 4294966537
DTN_USERSTRINGA: UInt32 = 4294966538
DTN_USERSTRINGW: UInt32 = 4294966551
DTN_USERSTRING: UInt32 = 4294966551
DTN_WMKEYDOWNA: UInt32 = 4294966539
DTN_WMKEYDOWNW: UInt32 = 4294966552
DTN_WMKEYDOWN: UInt32 = 4294966552
DTN_FORMATA: UInt32 = 4294966540
DTN_FORMATW: UInt32 = 4294966553
DTN_FORMAT: UInt32 = 4294966553
DTN_FORMATQUERYA: UInt32 = 4294966541
DTN_FORMATQUERYW: UInt32 = 4294966554
DTN_FORMATQUERY: UInt32 = 4294966554
DTN_DROPDOWN: UInt32 = 4294966542
DTN_CLOSEUP: UInt32 = 4294966543
GDTR_MIN: UInt32 = 1
GDTR_MAX: UInt32 = 2
GDT_ERROR: Int32 = -1
IPM_CLEARADDRESS: UInt32 = 1124
IPM_SETADDRESS: UInt32 = 1125
IPM_GETADDRESS: UInt32 = 1126
IPM_SETRANGE: UInt32 = 1127
IPM_SETFOCUS: UInt32 = 1128
IPM_ISBLANK: UInt32 = 1129
WC_IPADDRESSW: String = 'SysIPAddress32'
WC_IPADDRESSA: String = 'SysIPAddress32'
WC_IPADDRESS: String = 'SysIPAddress32'
IPN_FIELDCHANGED: UInt32 = 4294966436
WC_PAGESCROLLERW: String = 'SysPager'
WC_PAGESCROLLERA: String = 'SysPager'
WC_PAGESCROLLER: String = 'SysPager'
PGS_VERT: UInt32 = 0
PGS_HORZ: UInt32 = 1
PGS_AUTOSCROLL: UInt32 = 2
PGS_DRAGNDROP: UInt32 = 4
PGF_INVISIBLE: UInt32 = 0
PGF_NORMAL: UInt32 = 1
PGF_GRAYED: UInt32 = 2
PGF_DEPRESSED: UInt32 = 4
PGF_HOT: UInt32 = 8
PGB_TOPORLEFT: UInt32 = 0
PGB_BOTTOMORRIGHT: UInt32 = 1
PGM_SETCHILD: UInt32 = 5121
PGM_RECALCSIZE: UInt32 = 5122
PGM_FORWARDMOUSE: UInt32 = 5123
PGM_SETBKCOLOR: UInt32 = 5124
PGM_GETBKCOLOR: UInt32 = 5125
PGM_SETBORDER: UInt32 = 5126
PGM_GETBORDER: UInt32 = 5127
PGM_SETPOS: UInt32 = 5128
PGM_GETPOS: UInt32 = 5129
PGM_SETBUTTONSIZE: UInt32 = 5130
PGM_GETBUTTONSIZE: UInt32 = 5131
PGM_GETBUTTONSTATE: UInt32 = 5132
PGM_GETDROPTARGET: UInt32 = 8196
PGM_SETSCROLLINFO: UInt32 = 5133
PGN_SCROLL: UInt32 = 4294966395
PGN_CALCSIZE: UInt32 = 4294966394
PGN_HOTITEMCHANGE: UInt32 = 4294966393
WC_NATIVEFONTCTLW: String = 'NativeFontCtl'
WC_NATIVEFONTCTLA: String = 'NativeFontCtl'
WC_NATIVEFONTCTL: String = 'NativeFontCtl'
NFS_EDIT: UInt32 = 1
NFS_STATIC: UInt32 = 2
NFS_LISTCOMBO: UInt32 = 4
NFS_BUTTON: UInt32 = 8
NFS_ALL: UInt32 = 16
NFS_USEFONTASSOC: UInt32 = 32
WC_BUTTONA: String = 'Button'
WC_BUTTONW: String = 'Button'
WC_BUTTON: String = 'Button'
BCM_GETIDEALSIZE: UInt32 = 5633
BCM_SETIMAGELIST: UInt32 = 5634
BCM_GETIMAGELIST: UInt32 = 5635
BCM_SETTEXTMARGIN: UInt32 = 5636
BCM_GETTEXTMARGIN: UInt32 = 5637
BCN_HOTITEMCHANGE: UInt32 = 4294966047
BST_HOT: UInt32 = 512
BST_DROPDOWNPUSHED: UInt32 = 1024
BS_SPLITBUTTON: Int32 = 12
BS_DEFSPLITBUTTON: Int32 = 13
BS_COMMANDLINK: Int32 = 14
BS_DEFCOMMANDLINK: Int32 = 15
BCSIF_GLYPH: UInt32 = 1
BCSIF_IMAGE: UInt32 = 2
BCSIF_STYLE: UInt32 = 4
BCSIF_SIZE: UInt32 = 8
BCSS_NOSPLIT: UInt32 = 1
BCSS_STRETCH: UInt32 = 2
BCSS_ALIGNLEFT: UInt32 = 4
BCSS_IMAGE: UInt32 = 8
BCM_SETDROPDOWNSTATE: UInt32 = 5638
BCM_SETSPLITINFO: UInt32 = 5639
BCM_GETSPLITINFO: UInt32 = 5640
BCM_SETNOTE: UInt32 = 5641
BCM_GETNOTE: UInt32 = 5642
BCM_GETNOTELENGTH: UInt32 = 5643
BCM_SETSHIELD: UInt32 = 5644
BCN_DROPDOWN: UInt32 = 4294966048
WC_STATICA: String = 'Static'
WC_STATICW: String = 'Static'
WC_STATIC: String = 'Static'
WC_EDITA: String = 'Edit'
WC_EDITW: String = 'Edit'
WC_EDIT: String = 'Edit'
ES_EX_ALLOWEOL_CR: Int32 = 1
ES_EX_ALLOWEOL_LF: Int32 = 2
ES_EX_CONVERT_EOL_ON_PASTE: Int32 = 4
ES_EX_ZOOMABLE: Int32 = 16
EM_SETCUEBANNER: UInt32 = 5377
EM_GETCUEBANNER: UInt32 = 5378
EM_SHOWBALLOONTIP: UInt32 = 5379
EM_HIDEBALLOONTIP: UInt32 = 5380
EM_SETHILITE: UInt32 = 5381
EM_GETHILITE: UInt32 = 5382
EM_NOSETFOCUS: UInt32 = 5383
EM_TAKEFOCUS: UInt32 = 5384
EM_SETEXTENDEDSTYLE: UInt32 = 5386
EM_GETEXTENDEDSTYLE: UInt32 = 5387
EM_SETENDOFLINE: UInt32 = 5388
EM_GETENDOFLINE: UInt32 = 5389
EM_ENABLESEARCHWEB: UInt32 = 5390
EM_SEARCHWEB: UInt32 = 5391
EM_SETCARETINDEX: UInt32 = 5393
EM_GETCARETINDEX: UInt32 = 5394
EM_FILELINEFROMCHAR: UInt32 = 5395
EM_FILELINEINDEX: UInt32 = 5396
EM_FILELINELENGTH: UInt32 = 5397
EM_GETFILELINE: UInt32 = 5398
EM_GETFILELINECOUNT: UInt32 = 5399
EN_SEARCHWEB: UInt32 = 4294965776
WC_LISTBOXA: String = 'ListBox'
WC_LISTBOXW: String = 'ListBox'
WC_LISTBOX: String = 'ListBox'
WC_COMBOBOXA: String = 'ComboBox'
WC_COMBOBOXW: String = 'ComboBox'
WC_COMBOBOX: String = 'ComboBox'
CB_SETMINVISIBLE: UInt32 = 5889
CB_GETMINVISIBLE: UInt32 = 5890
CB_SETCUEBANNER: UInt32 = 5891
CB_GETCUEBANNER: UInt32 = 5892
WC_SCROLLBARA: String = 'ScrollBar'
WC_SCROLLBARW: String = 'ScrollBar'
WC_SCROLLBAR: String = 'ScrollBar'
TD_WARNING_ICON: win32more.Windows.Win32.Foundation.PWSTR = 65535
TD_ERROR_ICON: win32more.Windows.Win32.Foundation.PWSTR = 65534
TD_INFORMATION_ICON: win32more.Windows.Win32.Foundation.PWSTR = 65533
TD_SHIELD_ICON: win32more.Windows.Win32.Foundation.PWSTR = 65532
WM_MOUSEHOVER: UInt32 = 673
WM_MOUSELEAVE: UInt32 = 675
HOVER_DEFAULT: UInt32 = 4294967295
WSB_PROP_MASK: Int32 = 4095
FSB_FLAT_MODE: UInt32 = 2
FSB_ENCARTA_MODE: UInt32 = 1
FSB_REGULAR_MODE: UInt32 = 0
ILDRF_IMAGELOWQUALITY: UInt32 = 1
ILDRF_OVERLAYLOWQUALITY: UInt32 = 16
ILR_DEFAULT: UInt32 = 0
ILR_HORIZONTAL_LEFT: UInt32 = 0
ILR_HORIZONTAL_CENTER: UInt32 = 1
ILR_HORIZONTAL_RIGHT: UInt32 = 2
ILR_VERTICAL_TOP: UInt32 = 0
ILR_VERTICAL_CENTER: UInt32 = 16
ILR_VERTICAL_BOTTOM: UInt32 = 32
ILR_SCALE_CLIP: UInt32 = 0
ILR_SCALE_ASPECTRATIO: UInt32 = 256
ILGOS_ALWAYS: UInt32 = 0
ILGOS_FROMSTANDBY: UInt32 = 1
ILFIP_ALWAYS: UInt32 = 0
ILFIP_FROMSTANDBY: UInt32 = 1
ILDI_PURGE: UInt32 = 1
ILDI_STANDBY: UInt32 = 2
ILDI_RESETACCESS: UInt32 = 4
ILDI_QUERYACCESS: UInt32 = 8
CCHCCCLASS: UInt32 = 32
CCHCCDESC: UInt32 = 32
CCHCCTEXT: UInt32 = 256
CCF_NOTEXT: UInt32 = 1
ctlFirst: UInt32 = 1024
ctlLast: UInt32 = 1279
psh1: UInt32 = 1024
psh2: UInt32 = 1025
psh3: UInt32 = 1026
psh4: UInt32 = 1027
psh5: UInt32 = 1028
psh6: UInt32 = 1029
psh7: UInt32 = 1030
psh8: UInt32 = 1031
psh9: UInt32 = 1032
psh10: UInt32 = 1033
psh11: UInt32 = 1034
psh12: UInt32 = 1035
psh13: UInt32 = 1036
psh14: UInt32 = 1037
psh15: UInt32 = 1038
pshHelp: UInt32 = 1038
psh16: UInt32 = 1039
chx1: UInt32 = 1040
chx2: UInt32 = 1041
chx3: UInt32 = 1042
chx4: UInt32 = 1043
chx5: UInt32 = 1044
chx6: UInt32 = 1045
chx7: UInt32 = 1046
chx8: UInt32 = 1047
chx9: UInt32 = 1048
chx10: UInt32 = 1049
chx11: UInt32 = 1050
chx12: UInt32 = 1051
chx13: UInt32 = 1052
chx14: UInt32 = 1053
chx15: UInt32 = 1054
chx16: UInt32 = 1055
rad1: UInt32 = 1056
rad2: UInt32 = 1057
rad3: UInt32 = 1058
rad4: UInt32 = 1059
rad5: UInt32 = 1060
rad6: UInt32 = 1061
rad7: UInt32 = 1062
rad8: UInt32 = 1063
rad9: UInt32 = 1064
rad10: UInt32 = 1065
rad11: UInt32 = 1066
rad12: UInt32 = 1067
rad13: UInt32 = 1068
rad14: UInt32 = 1069
rad15: UInt32 = 1070
rad16: UInt32 = 1071
grp1: UInt32 = 1072
grp2: UInt32 = 1073
grp3: UInt32 = 1074
grp4: UInt32 = 1075
frm1: UInt32 = 1076
frm2: UInt32 = 1077
frm3: UInt32 = 1078
frm4: UInt32 = 1079
rct1: UInt32 = 1080
rct2: UInt32 = 1081
rct3: UInt32 = 1082
rct4: UInt32 = 1083
ico1: UInt32 = 1084
ico2: UInt32 = 1085
ico3: UInt32 = 1086
ico4: UInt32 = 1087
stc1: UInt32 = 1088
stc2: UInt32 = 1089
stc3: UInt32 = 1090
stc4: UInt32 = 1091
stc5: UInt32 = 1092
stc6: UInt32 = 1093
stc7: UInt32 = 1094
stc8: UInt32 = 1095
stc9: UInt32 = 1096
stc10: UInt32 = 1097
stc11: UInt32 = 1098
stc12: UInt32 = 1099
stc13: UInt32 = 1100
stc14: UInt32 = 1101
stc15: UInt32 = 1102
stc16: UInt32 = 1103
stc17: UInt32 = 1104
stc18: UInt32 = 1105
stc19: UInt32 = 1106
stc20: UInt32 = 1107
stc21: UInt32 = 1108
stc22: UInt32 = 1109
stc23: UInt32 = 1110
stc24: UInt32 = 1111
stc25: UInt32 = 1112
stc26: UInt32 = 1113
stc27: UInt32 = 1114
stc28: UInt32 = 1115
stc29: UInt32 = 1116
stc30: UInt32 = 1117
stc31: UInt32 = 1118
stc32: UInt32 = 1119
lst1: UInt32 = 1120
lst2: UInt32 = 1121
lst3: UInt32 = 1122
lst4: UInt32 = 1123
lst5: UInt32 = 1124
lst6: UInt32 = 1125
lst7: UInt32 = 1126
lst8: UInt32 = 1127
lst9: UInt32 = 1128
lst10: UInt32 = 1129
lst11: UInt32 = 1130
lst12: UInt32 = 1131
lst13: UInt32 = 1132
lst14: UInt32 = 1133
lst15: UInt32 = 1134
lst16: UInt32 = 1135
cmb1: UInt32 = 1136
cmb2: UInt32 = 1137
cmb3: UInt32 = 1138
cmb4: UInt32 = 1139
cmb5: UInt32 = 1140
cmb6: UInt32 = 1141
cmb7: UInt32 = 1142
cmb8: UInt32 = 1143
cmb9: UInt32 = 1144
cmb10: UInt32 = 1145
cmb11: UInt32 = 1146
cmb12: UInt32 = 1147
cmb13: UInt32 = 1148
cmb14: UInt32 = 1149
cmb15: UInt32 = 1150
cmb16: UInt32 = 1151
edt1: UInt32 = 1152
edt2: UInt32 = 1153
edt3: UInt32 = 1154
edt4: UInt32 = 1155
edt5: UInt32 = 1156
edt6: UInt32 = 1157
edt7: UInt32 = 1158
edt8: UInt32 = 1159
edt9: UInt32 = 1160
edt10: UInt32 = 1161
edt11: UInt32 = 1162
edt12: UInt32 = 1163
edt13: UInt32 = 1164
edt14: UInt32 = 1165
edt15: UInt32 = 1166
edt16: UInt32 = 1167
scr1: UInt32 = 1168
scr2: UInt32 = 1169
scr3: UInt32 = 1170
scr4: UInt32 = 1171
scr5: UInt32 = 1172
scr6: UInt32 = 1173
scr7: UInt32 = 1174
scr8: UInt32 = 1175
ctl1: UInt32 = 1184
FILEOPENORD: UInt32 = 1536
MULTIFILEOPENORD: UInt32 = 1537
PRINTDLGORD: UInt32 = 1538
PRNSETUPDLGORD: UInt32 = 1539
FINDDLGORD: UInt32 = 1540
REPLACEDLGORD: UInt32 = 1541
FONTDLGORD: UInt32 = 1542
FORMATDLGORD31: UInt32 = 1543
FORMATDLGORD30: UInt32 = 1544
RUNDLGORD: UInt32 = 1545
PAGESETUPDLGORD: UInt32 = 1546
NEWFILEOPENORD: UInt32 = 1547
PRINTDLGEXORD: UInt32 = 1549
PAGESETUPDLGORDMOTIF: UInt32 = 1550
COLORMGMTDLGORD: UInt32 = 1551
NEWFILEOPENV2ORD: UInt32 = 1552
NEWFILEOPENV3ORD: UInt32 = 1553
NEWFORMATDLGWITHLINK: UInt32 = 1591
IDC_MANAGE_LINK: UInt32 = 1592
DA_LAST: UInt32 = 2147483647
DA_ERR: Int32 = -1
DSA_APPEND: UInt32 = 2147483647
DSA_ERR: Int32 = -1
DPAM_SORTED: UInt32 = 1
DPAM_NORMAL: UInt32 = 2
DPAM_UNION: UInt32 = 4
DPAM_INTERSECT: UInt32 = 8
DPAS_SORTED: UInt32 = 1
DPAS_INSERTBEFORE: UInt32 = 2
DPAS_INSERTAFTER: UInt32 = 4
DPA_APPEND: UInt32 = 2147483647
DPA_ERR: Int32 = -1
MAXPROPPAGES: UInt32 = 100
PSP_DEFAULT: UInt32 = 0
PSP_DLGINDIRECT: UInt32 = 1
PSP_USEHICON: UInt32 = 2
PSP_USEICONID: UInt32 = 4
PSP_USETITLE: UInt32 = 8
PSP_RTLREADING: UInt32 = 16
PSP_HASHELP: UInt32 = 32
PSP_USEREFPARENT: UInt32 = 64
PSP_USECALLBACK: UInt32 = 128
PSP_PREMATURE: UInt32 = 1024
PSP_HIDEHEADER: UInt32 = 2048
PSP_USEHEADERTITLE: UInt32 = 4096
PSP_USEHEADERSUBTITLE: UInt32 = 8192
PSP_USEFUSIONCONTEXT: UInt32 = 16384
PSH_DEFAULT: UInt32 = 0
PSH_PROPTITLE: UInt32 = 1
PSH_USEHICON: UInt32 = 2
PSH_USEICONID: UInt32 = 4
PSH_PROPSHEETPAGE: UInt32 = 8
PSH_WIZARDHASFINISH: UInt32 = 16
PSH_WIZARD: UInt32 = 32
PSH_USEPSTARTPAGE: UInt32 = 64
PSH_NOAPPLYNOW: UInt32 = 128
PSH_USECALLBACK: UInt32 = 256
PSH_HASHELP: UInt32 = 512
PSH_MODELESS: UInt32 = 1024
PSH_RTLREADING: UInt32 = 2048
PSH_WIZARDCONTEXTHELP: UInt32 = 4096
PSH_WIZARD97: UInt32 = 8192
PSH_WATERMARK: UInt32 = 32768
PSH_USEHBMWATERMARK: UInt32 = 65536
PSH_USEHPLWATERMARK: UInt32 = 131072
PSH_STRETCHWATERMARK: UInt32 = 262144
PSH_HEADER: UInt32 = 524288
PSH_USEHBMHEADER: UInt32 = 1048576
PSH_USEPAGELANG: UInt32 = 2097152
PSH_WIZARD_LITE: UInt32 = 4194304
PSH_NOCONTEXTHELP: UInt32 = 33554432
PSH_AEROWIZARD: UInt32 = 16384
PSH_RESIZABLE: UInt32 = 67108864
PSH_HEADERBITMAP: UInt32 = 134217728
PSH_NOMARGIN: UInt32 = 268435456
PSCB_INITIALIZED: UInt32 = 1
PSCB_PRECREATE: UInt32 = 2
PSCB_BUTTONPRESSED: UInt32 = 3
PSN_FIRST: UInt32 = 4294967096
PSN_LAST: UInt32 = 4294966997
PSN_SETACTIVE: UInt32 = 4294967096
PSN_KILLACTIVE: UInt32 = 4294967095
PSN_APPLY: UInt32 = 4294967094
PSN_RESET: UInt32 = 4294967093
PSN_HELP: UInt32 = 4294967091
PSN_WIZBACK: UInt32 = 4294967090
PSN_WIZNEXT: UInt32 = 4294967089
PSN_WIZFINISH: UInt32 = 4294967088
PSN_QUERYCANCEL: UInt32 = 4294967087
PSN_GETOBJECT: UInt32 = 4294967086
PSN_TRANSLATEACCELERATOR: UInt32 = 4294967084
PSN_QUERYINITIALFOCUS: UInt32 = 4294967083
PSNRET_NOERROR: UInt32 = 0
PSNRET_INVALID: UInt32 = 1
PSNRET_INVALID_NOCHANGEPAGE: UInt32 = 2
PSNRET_MESSAGEHANDLED: UInt32 = 3
PSM_SETCURSEL: UInt32 = 1125
PSM_REMOVEPAGE: UInt32 = 1126
PSM_ADDPAGE: UInt32 = 1127
PSM_CHANGED: UInt32 = 1128
PSM_RESTARTWINDOWS: UInt32 = 1129
PSM_REBOOTSYSTEM: UInt32 = 1130
PSM_CANCELTOCLOSE: UInt32 = 1131
PSM_QUERYSIBLINGS: UInt32 = 1132
PSM_UNCHANGED: UInt32 = 1133
PSM_APPLY: UInt32 = 1134
PSM_SETTITLEA: UInt32 = 1135
PSM_SETTITLEW: UInt32 = 1144
PSM_SETTITLE: UInt32 = 1144
PSM_SETWIZBUTTONS: UInt32 = 1136
PSWIZB_BACK: UInt32 = 1
PSWIZB_NEXT: UInt32 = 2
PSWIZB_FINISH: UInt32 = 4
PSWIZB_DISABLEDFINISH: UInt32 = 8
PSWIZBF_ELEVATIONREQUIRED: UInt32 = 1
PSWIZB_CANCEL: UInt32 = 16
PSM_PRESSBUTTON: UInt32 = 1137
PSBTN_BACK: UInt32 = 0
PSBTN_NEXT: UInt32 = 1
PSBTN_FINISH: UInt32 = 2
PSBTN_OK: UInt32 = 3
PSBTN_APPLYNOW: UInt32 = 4
PSBTN_CANCEL: UInt32 = 5
PSBTN_HELP: UInt32 = 6
PSBTN_MAX: UInt32 = 6
PSM_SETCURSELID: UInt32 = 1138
PSM_SETFINISHTEXTA: UInt32 = 1139
PSM_SETFINISHTEXTW: UInt32 = 1145
PSM_SETFINISHTEXT: UInt32 = 1145
PSM_GETTABCONTROL: UInt32 = 1140
PSM_ISDIALOGMESSAGE: UInt32 = 1141
PSM_GETCURRENTPAGEHWND: UInt32 = 1142
PSM_INSERTPAGE: UInt32 = 1143
PSM_SETHEADERTITLEA: UInt32 = 1149
PSM_SETHEADERTITLEW: UInt32 = 1150
PSM_SETHEADERTITLE: UInt32 = 1150
PSM_SETHEADERSUBTITLEA: UInt32 = 1151
PSM_SETHEADERSUBTITLEW: UInt32 = 1152
PSM_SETHEADERSUBTITLE: UInt32 = 1152
PSM_HWNDTOINDEX: UInt32 = 1153
PSM_INDEXTOHWND: UInt32 = 1154
PSM_PAGETOINDEX: UInt32 = 1155
PSM_INDEXTOPAGE: UInt32 = 1156
PSM_IDTOINDEX: UInt32 = 1157
PSM_INDEXTOID: UInt32 = 1158
PSM_GETRESULT: UInt32 = 1159
PSM_RECALCPAGESIZES: UInt32 = 1160
PSM_SETNEXTTEXTW: UInt32 = 1161
PSM_SETNEXTTEXT: UInt32 = 1161
PSWIZB_SHOW: UInt32 = 0
PSWIZB_RESTORE: UInt32 = 1
PSM_SHOWWIZBUTTONS: UInt32 = 1162
PSM_ENABLEWIZBUTTONS: UInt32 = 1163
PSM_SETBUTTONTEXTW: UInt32 = 1164
PSM_SETBUTTONTEXT: UInt32 = 1164
ID_PSRESTARTWINDOWS: UInt32 = 2
WIZ_CXDLG: UInt32 = 276
WIZ_CYDLG: UInt32 = 140
WIZ_CXBMP: UInt32 = 80
WIZ_BODYX: UInt32 = 92
WIZ_BODYCX: UInt32 = 184
PROP_SM_CXDLG: UInt32 = 212
PROP_SM_CYDLG: UInt32 = 188
PROP_MED_CXDLG: UInt32 = 227
PROP_MED_CYDLG: UInt32 = 215
PROP_LG_CXDLG: UInt32 = 252
PROP_LG_CYDLG: UInt32 = 218
MAX_THEMECOLOR: UInt32 = 64
MAX_THEMESIZE: UInt32 = 64
DTBG_CLIPRECT: UInt32 = 1
DTBG_DRAWSOLID: UInt32 = 2
DTBG_OMITBORDER: UInt32 = 4
DTBG_OMITCONTENT: UInt32 = 8
DTBG_COMPUTINGREGION: UInt32 = 16
DTBG_MIRRORDC: UInt32 = 32
DTBG_NOMIRROR: UInt32 = 64
DTT_GRAYED: UInt32 = 1
DTT_FLAGS2VALIDBITS: UInt32 = 1
MAX_INTLIST_COUNT: UInt32 = 402
ETDT_DISABLE: UInt32 = 1
ETDT_ENABLE: UInt32 = 2
ETDT_USETABTEXTURE: UInt32 = 4
ETDT_USEAEROWIZARDTABTEXTURE: UInt32 = 8
SZ_THDOCPROP_DISPLAYNAME: String = 'DisplayName'
SZ_THDOCPROP_CANONICALNAME: String = 'ThemeName'
SZ_THDOCPROP_TOOLTIP: String = 'ToolTip'
SZ_THDOCPROP_AUTHOR: String = 'author'
WTNCA_NODRAWCAPTION: UInt32 = 1
WTNCA_NODRAWICON: UInt32 = 2
WTNCA_NOSYSMENU: UInt32 = 4
WTNCA_NOMIRRORHELP: UInt32 = 8
TMTVS_RESERVEDLOW: UInt32 = 100000
TMTVS_RESERVEDHIGH: UInt32 = 19999
VSCLASS_AEROWIZARDSTYLE: String = 'AEROWIZARDSTYLE'
VSCLASS_AEROWIZARD: String = 'AEROWIZARD'
VSCLASS_BUTTONSTYLE: String = 'BUTTONSTYLE'
VSCLASS_BUTTON: String = 'BUTTON'
VSCLASS_COMBOBOXSTYLE: String = 'COMBOBOXSTYLE'
VSCLASS_COMBOBOX: String = 'COMBOBOX'
VSCLASS_COMMUNICATIONSSTYLE: String = 'COMMUNICATIONSSTYLE'
VSCLASS_COMMUNICATIONS: String = 'COMMUNICATIONS'
VSCLASS_CONTROLPANELSTYLE: String = 'CONTROLPANELSTYLE'
VSCLASS_CONTROLPANEL: String = 'CONTROLPANEL'
VSCLASS_DATEPICKERSTYLE: String = 'DATEPICKERSTYLE'
VSCLASS_DATEPICKER: String = 'DATEPICKER'
VSCLASS_DRAGDROPSTYLE: String = 'DRAGDROPSTYLE'
VSCLASS_DRAGDROP: String = 'DRAGDROP'
VSCLASS_EDITSTYLE: String = 'EDITSTYLE'
VSCLASS_EDIT: String = 'EDIT'
VSCLASS_EXPLORERBARSTYLE: String = 'EXPLORERBARSTYLE'
VSCLASS_EXPLORERBAR: String = 'EXPLORERBAR'
VSCLASS_FLYOUTSTYLE: String = 'FLYOUTSTYLE'
VSCLASS_FLYOUT: String = 'FLYOUT'
VSCLASS_HEADERSTYLE: String = 'HEADERSTYLE'
VSCLASS_HEADER: String = 'HEADER'
VSCLASS_LISTBOXSTYLE: String = 'LISTBOXSTYLE'
VSCLASS_LISTBOX: String = 'LISTBOX'
VSCLASS_LISTVIEWSTYLE: String = 'LISTVIEWSTYLE'
VSCLASS_LISTVIEW: String = 'LISTVIEW'
VSCLASS_MENUSTYLE: String = 'MENUSTYLE'
VSCLASS_MENU: String = 'MENU'
VSCLASS_NAVIGATION: String = 'NAVIGATION'
VSCLASS_PROGRESSSTYLE: String = 'PROGRESSSTYLE'
VSCLASS_PROGRESS: String = 'PROGRESS'
VSCLASS_REBARSTYLE: String = 'REBARSTYLE'
VSCLASS_REBAR: String = 'REBAR'
VSCLASS_SCROLLBARSTYLE: String = 'SCROLLBARSTYLE'
VSCLASS_SCROLLBAR: String = 'SCROLLBAR'
VSCLASS_SPINSTYLE: String = 'SPINSTYLE'
VSCLASS_SPIN: String = 'SPIN'
VSCLASS_STATUSSTYLE: String = 'STATUSSTYLE'
VSCLASS_STATUS: String = 'STATUS'
VSCLASS_TABSTYLE: String = 'TABSTYLE'
VSCLASS_TAB: String = 'TAB'
VSCLASS_TASKDIALOGSTYLE: String = 'TASKDIALOGSTYLE'
VSCLASS_TASKDIALOG: String = 'TASKDIALOG'
VSCLASS_TEXTSTYLE: String = 'TEXTSTYLE'
VSCLASS_TOOLBARSTYLE: String = 'TOOLBARSTYLE'
VSCLASS_TOOLBAR: String = 'TOOLBAR'
VSCLASS_TOOLTIPSTYLE: String = 'TOOLTIPSTYLE'
VSCLASS_TOOLTIP: String = 'TOOLTIP'
VSCLASS_TRACKBARSTYLE: String = 'TRACKBARSTYLE'
VSCLASS_TRACKBAR: String = 'TRACKBAR'
VSCLASS_TREEVIEWSTYLE: String = 'TREEVIEWSTYLE'
VSCLASS_TREEVIEW: String = 'TREEVIEW'
VSCLASS_USERTILE: String = 'USERTILE'
VSCLASS_TEXTSELECTIONGRIPPER: String = 'TEXTSELECTIONGRIPPER'
VSCLASS_WINDOWSTYLE: String = 'WINDOWSTYLE'
VSCLASS_WINDOW: String = 'WINDOW'
VSCLASS_LINK: String = 'LINK'
VSCLASS_EMPTYMARKUP: String = 'EMPTYMARKUP'
VSCLASS_STATIC: String = 'STATIC'
VSCLASS_PAGE: String = 'PAGE'
VSCLASS_MONTHCAL: String = 'MONTHCAL'
VSCLASS_CLOCK: String = 'CLOCK'
VSCLASS_TRAYNOTIFY: String = 'TRAYNOTIFY'
VSCLASS_TASKBAR: String = 'TASKBAR'
VSCLASS_TASKBAND: String = 'TASKBAND'
VSCLASS_STARTPANEL: String = 'STARTPANEL'
VSCLASS_MENUBAND: String = 'MENUBAND'
EM_GETSEL: UInt32 = 176
EM_SETSEL: UInt32 = 177
EM_GETRECT: UInt32 = 178
EM_SETRECT: UInt32 = 179
EM_SETRECTNP: UInt32 = 180
EM_SCROLL: UInt32 = 181
EM_LINESCROLL: UInt32 = 182
EM_GETMODIFY: UInt32 = 184
EM_SETMODIFY: UInt32 = 185
EM_GETLINECOUNT: UInt32 = 186
EM_LINEINDEX: UInt32 = 187
EM_SETHANDLE: UInt32 = 188
EM_GETHANDLE: UInt32 = 189
EM_GETTHUMB: UInt32 = 190
EM_LINELENGTH: UInt32 = 193
EM_REPLACESEL: UInt32 = 194
EM_GETLINE: UInt32 = 196
EM_LIMITTEXT: UInt32 = 197
EM_CANUNDO: UInt32 = 198
EM_UNDO: UInt32 = 199
EM_FMTLINES: UInt32 = 200
EM_LINEFROMCHAR: UInt32 = 201
EM_SETTABSTOPS: UInt32 = 203
EM_SETPASSWORDCHAR: UInt32 = 204
EM_EMPTYUNDOBUFFER: UInt32 = 205
EM_GETFIRSTVISIBLELINE: UInt32 = 206
EM_SETREADONLY: UInt32 = 207
EM_SETWORDBREAKPROC: UInt32 = 208
EM_GETWORDBREAKPROC: UInt32 = 209
EM_GETPASSWORDCHAR: UInt32 = 210
EM_SETMARGINS: UInt32 = 211
EM_GETMARGINS: UInt32 = 212
EM_SETIMESTATUS: UInt32 = 216
EM_GETIMESTATUS: UInt32 = 217
EM_ENABLEFEATURE: UInt32 = 218
@winfunctype('COMCTL32.dll')
def CreatePropertySheetPageA(constPropSheetPagePointer: POINTER(win32more.Windows.Win32.UI.Controls.PROPSHEETPAGEA)) -> win32more.Windows.Win32.UI.Controls.HPROPSHEETPAGE: ...
@winfunctype('COMCTL32.dll')
def CreatePropertySheetPageW(constPropSheetPagePointer: POINTER(win32more.Windows.Win32.UI.Controls.PROPSHEETPAGEW)) -> win32more.Windows.Win32.UI.Controls.HPROPSHEETPAGE: ...
CreatePropertySheetPage = UnicodeAlias('CreatePropertySheetPageW')
@winfunctype('COMCTL32.dll')
def DestroyPropertySheetPage(param0: win32more.Windows.Win32.UI.Controls.HPROPSHEETPAGE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def PropertySheetA(param0: POINTER(win32more.Windows.Win32.UI.Controls.PROPSHEETHEADERA_V2)) -> IntPtr: ...
@winfunctype('COMCTL32.dll')
def PropertySheetW(param0: POINTER(win32more.Windows.Win32.UI.Controls.PROPSHEETHEADERW_V2)) -> IntPtr: ...
PropertySheet = UnicodeAlias('PropertySheetW')
@winfunctype('COMCTL32.dll')
def InitCommonControls() -> Void: ...
@winfunctype('COMCTL32.dll')
def InitCommonControlsEx(picce: POINTER(win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_Create(cx: Int32, cy: Int32, flags: win32more.Windows.Win32.UI.Controls.IMAGELIST_CREATION_FLAGS, cInitial: Int32, cGrow: Int32) -> win32more.Windows.Win32.UI.Controls.HIMAGELIST: ...
@winfunctype('COMCTL32.dll')
def ImageList_Destroy(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_GetImageCount(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST) -> Int32: ...
@winfunctype('COMCTL32.dll')
def ImageList_SetImageCount(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, uNewCount: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_Add(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, hbmImage: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, hbmMask: win32more.Windows.Win32.Graphics.Gdi.HBITMAP) -> Int32: ...
@winfunctype('COMCTL32.dll')
def ImageList_ReplaceIcon(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, i: Int32, hicon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON) -> Int32: ...
@winfunctype('COMCTL32.dll')
def ImageList_SetBkColor(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, clrBk: win32more.Windows.Win32.Foundation.COLORREF) -> win32more.Windows.Win32.Foundation.COLORREF: ...
@winfunctype('COMCTL32.dll')
def ImageList_GetBkColor(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST) -> win32more.Windows.Win32.Foundation.COLORREF: ...
@winfunctype('COMCTL32.dll')
def ImageList_SetOverlayImage(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, iImage: Int32, iOverlay: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_Draw(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, i: Int32, hdcDst: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, fStyle: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_Replace(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, i: Int32, hbmImage: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, hbmMask: win32more.Windows.Win32.Graphics.Gdi.HBITMAP) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_AddMasked(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, hbmImage: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, crMask: win32more.Windows.Win32.Foundation.COLORREF) -> Int32: ...
@winfunctype('COMCTL32.dll')
def ImageList_DrawEx(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, i: Int32, hdcDst: win32more.Windows.Win32.Graphics.Gdi.HDC, x: Int32, y: Int32, dx: Int32, dy: Int32, rgbBk: win32more.Windows.Win32.Foundation.COLORREF, rgbFg: win32more.Windows.Win32.Foundation.COLORREF, fStyle: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_DrawIndirect(pimldp: POINTER(win32more.Windows.Win32.UI.Controls.IMAGELISTDRAWPARAMS)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_Remove(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, i: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_GetIcon(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, i: Int32, flags: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HICON: ...
@winfunctype('COMCTL32.dll')
def ImageList_LoadImageA(hi: win32more.Windows.Win32.Foundation.HINSTANCE, lpbmp: win32more.Windows.Win32.Foundation.PSTR, cx: Int32, cGrow: Int32, crMask: win32more.Windows.Win32.Foundation.COLORREF, uType: UInt32, uFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS) -> win32more.Windows.Win32.UI.Controls.HIMAGELIST: ...
@winfunctype('COMCTL32.dll')
def ImageList_LoadImageW(hi: win32more.Windows.Win32.Foundation.HINSTANCE, lpbmp: win32more.Windows.Win32.Foundation.PWSTR, cx: Int32, cGrow: Int32, crMask: win32more.Windows.Win32.Foundation.COLORREF, uType: UInt32, uFlags: win32more.Windows.Win32.UI.WindowsAndMessaging.IMAGE_FLAGS) -> win32more.Windows.Win32.UI.Controls.HIMAGELIST: ...
ImageList_LoadImage = UnicodeAlias('ImageList_LoadImageW')
@winfunctype('COMCTL32.dll')
def ImageList_Copy(himlDst: win32more.Windows.Win32.UI.Controls.HIMAGELIST, iDst: Int32, himlSrc: win32more.Windows.Win32.UI.Controls.HIMAGELIST, iSrc: Int32, uFlags: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_COPY_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_BeginDrag(himlTrack: win32more.Windows.Win32.UI.Controls.HIMAGELIST, iTrack: Int32, dxHotspot: Int32, dyHotspot: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_EndDrag() -> Void: ...
@winfunctype('COMCTL32.dll')
def ImageList_DragEnter(hwndLock: win32more.Windows.Win32.Foundation.HWND, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_DragLeave(hwndLock: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_DragMove(x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_SetDragCursorImage(himlDrag: win32more.Windows.Win32.UI.Controls.HIMAGELIST, iDrag: Int32, dxHotspot: Int32, dyHotspot: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_DragShowNolock(fShow: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_GetDragImage(ppt: POINTER(win32more.Windows.Win32.Foundation.POINT), pptHotspot: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.UI.Controls.HIMAGELIST: ...
@winfunctype('COMCTL32.dll')
def ImageList_Read(pstm: win32more.Windows.Win32.System.Com.IStream) -> win32more.Windows.Win32.UI.Controls.HIMAGELIST: ...
@winfunctype('COMCTL32.dll')
def ImageList_Write(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, pstm: win32more.Windows.Win32.System.Com.IStream) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_ReadEx(dwFlags: UInt32, pstm: win32more.Windows.Win32.System.Com.IStream, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('COMCTL32.dll')
def ImageList_WriteEx(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, dwFlags: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_WRITE_STREAM_FLAGS, pstm: win32more.Windows.Win32.System.Com.IStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('COMCTL32.dll')
def ImageList_GetIconSize(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, cx: POINTER(Int32), cy: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_SetIconSize(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, cx: Int32, cy: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_GetImageInfo(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, i: Int32, pImageInfo: POINTER(win32more.Windows.Win32.UI.Controls.IMAGEINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def ImageList_Merge(himl1: win32more.Windows.Win32.UI.Controls.HIMAGELIST, i1: Int32, himl2: win32more.Windows.Win32.UI.Controls.HIMAGELIST, i2: Int32, dx: Int32, dy: Int32) -> win32more.Windows.Win32.UI.Controls.HIMAGELIST: ...
@winfunctype('COMCTL32.dll')
def ImageList_Duplicate(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST) -> win32more.Windows.Win32.UI.Controls.HIMAGELIST: ...
@winfunctype('COMCTL32.dll')
def HIMAGELIST_QueryInterface(himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('COMCTL32.dll')
def CreateToolbarEx(hwnd: win32more.Windows.Win32.Foundation.HWND, ws: UInt32, wID: UInt32, nBitmaps: Int32, hBMInst: win32more.Windows.Win32.Foundation.HINSTANCE, wBMID: UIntPtr, lpButtons: POINTER(win32more.Windows.Win32.UI.Controls.TBBUTTON), iNumButtons: Int32, dxButton: Int32, dyButton: Int32, dxBitmap: Int32, dyBitmap: Int32, uStructSize: UInt32) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('COMCTL32.dll')
def CreateMappedBitmap(hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, idBitmap: IntPtr, wFlags: UInt32, lpColorMap: POINTER(win32more.Windows.Win32.UI.Controls.COLORMAP), iNumMaps: Int32) -> win32more.Windows.Win32.Graphics.Gdi.HBITMAP: ...
@winfunctype('COMCTL32.dll')
def DrawStatusTextA(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, lprc: POINTER(win32more.Windows.Win32.Foundation.RECT), pszText: win32more.Windows.Win32.Foundation.PSTR, uFlags: UInt32) -> Void: ...
@winfunctype('COMCTL32.dll')
def DrawStatusTextW(hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, lprc: POINTER(win32more.Windows.Win32.Foundation.RECT), pszText: win32more.Windows.Win32.Foundation.PWSTR, uFlags: UInt32) -> Void: ...
DrawStatusText = UnicodeAlias('DrawStatusTextW')
@winfunctype('COMCTL32.dll')
def CreateStatusWindowA(style: Int32, lpszText: win32more.Windows.Win32.Foundation.PSTR, hwndParent: win32more.Windows.Win32.Foundation.HWND, wID: UInt32) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('COMCTL32.dll')
def CreateStatusWindowW(style: Int32, lpszText: win32more.Windows.Win32.Foundation.PWSTR, hwndParent: win32more.Windows.Win32.Foundation.HWND, wID: UInt32) -> win32more.Windows.Win32.Foundation.HWND: ...
CreateStatusWindow = UnicodeAlias('CreateStatusWindowW')
@winfunctype('COMCTL32.dll')
def MenuHelp(uMsg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM, hMainMenu: win32more.Windows.Win32.UI.WindowsAndMessaging.HMENU, hInst: win32more.Windows.Win32.Foundation.HINSTANCE, hwndStatus: win32more.Windows.Win32.Foundation.HWND, lpwIDs: POINTER(UInt32)) -> Void: ...
@winfunctype('COMCTL32.dll')
def ShowHideMenuCtl(hWnd: win32more.Windows.Win32.Foundation.HWND, uFlags: UIntPtr, lpInfo: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def GetEffectiveClientRect(hWnd: win32more.Windows.Win32.Foundation.HWND, lprc: POINTER(win32more.Windows.Win32.Foundation.RECT), lpInfo: POINTER(Int32)) -> Void: ...
@winfunctype('COMCTL32.dll')
def MakeDragList(hLB: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def DrawInsert(handParent: win32more.Windows.Win32.Foundation.HWND, hLB: win32more.Windows.Win32.Foundation.HWND, nItem: Int32) -> Void: ...
@winfunctype('COMCTL32.dll')
def LBItemFromPt(hLB: win32more.Windows.Win32.Foundation.HWND, pt: win32more.Windows.Win32.Foundation.POINT, bAutoScroll: win32more.Windows.Win32.Foundation.BOOL) -> Int32: ...
@winfunctype('COMCTL32.dll')
def CreateUpDownControl(dwStyle: UInt32, x: Int32, y: Int32, cx: Int32, cy: Int32, hParent: win32more.Windows.Win32.Foundation.HWND, nID: Int32, hInst: win32more.Windows.Win32.Foundation.HINSTANCE, hBuddy: win32more.Windows.Win32.Foundation.HWND, nUpper: Int32, nLower: Int32, nPos: Int32) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('COMCTL32.dll')
def TaskDialogIndirect(pTaskConfig: POINTER(win32more.Windows.Win32.UI.Controls.TASKDIALOGCONFIG), pnButton: POINTER(Int32), pnRadioButton: POINTER(Int32), pfVerificationFlagChecked: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('COMCTL32.dll')
def TaskDialog(hwndOwner: win32more.Windows.Win32.Foundation.HWND, hInstance: win32more.Windows.Win32.Foundation.HINSTANCE, pszWindowTitle: win32more.Windows.Win32.Foundation.PWSTR, pszMainInstruction: win32more.Windows.Win32.Foundation.PWSTR, pszContent: win32more.Windows.Win32.Foundation.PWSTR, dwCommonButtons: win32more.Windows.Win32.UI.Controls.TASKDIALOG_COMMON_BUTTON_FLAGS, pszIcon: win32more.Windows.Win32.Foundation.PWSTR, pnButton: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('COMCTL32.dll')
def InitMUILanguage(uiLang: UInt16) -> Void: ...
@winfunctype('COMCTL32.dll')
def GetMUILanguage() -> UInt16: ...
@winfunctype('COMCTL32.dll')
def DSA_Create(cbItem: Int32, cItemGrow: Int32) -> win32more.Windows.Win32.UI.Controls.HDSA: ...
@winfunctype('COMCTL32.dll')
def DSA_Destroy(hdsa: win32more.Windows.Win32.UI.Controls.HDSA) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def DSA_DestroyCallback(hdsa: win32more.Windows.Win32.UI.Controls.HDSA, pfnCB: win32more.Windows.Win32.UI.Controls.PFNDAENUMCALLBACK, pData: VoidPtr) -> Void: ...
@winfunctype('COMCTL32.dll')
def DSA_DeleteItem(hdsa: win32more.Windows.Win32.UI.Controls.HDSA, i: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def DSA_DeleteAllItems(hdsa: win32more.Windows.Win32.UI.Controls.HDSA) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def DSA_EnumCallback(hdsa: win32more.Windows.Win32.UI.Controls.HDSA, pfnCB: win32more.Windows.Win32.UI.Controls.PFNDAENUMCALLBACK, pData: VoidPtr) -> Void: ...
@winfunctype('COMCTL32.dll')
def DSA_InsertItem(hdsa: win32more.Windows.Win32.UI.Controls.HDSA, i: Int32, pitem: VoidPtr) -> Int32: ...
@winfunctype('COMCTL32.dll')
def DSA_GetItemPtr(hdsa: win32more.Windows.Win32.UI.Controls.HDSA, i: Int32) -> VoidPtr: ...
@winfunctype('COMCTL32.dll')
def DSA_GetItem(hdsa: win32more.Windows.Win32.UI.Controls.HDSA, i: Int32, pitem: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def DSA_SetItem(hdsa: win32more.Windows.Win32.UI.Controls.HDSA, i: Int32, pitem: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def DSA_Clone(hdsa: win32more.Windows.Win32.UI.Controls.HDSA) -> win32more.Windows.Win32.UI.Controls.HDSA: ...
@winfunctype('COMCTL32.dll')
def DSA_GetSize(hdsa: win32more.Windows.Win32.UI.Controls.HDSA) -> UInt64: ...
@winfunctype('COMCTL32.dll')
def DSA_Sort(pdsa: win32more.Windows.Win32.UI.Controls.HDSA, pfnCompare: win32more.Windows.Win32.UI.Controls.PFNDACOMPARE, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def DPA_Create(cItemGrow: Int32) -> win32more.Windows.Win32.UI.Controls.HDPA: ...
@winfunctype('COMCTL32.dll')
def DPA_CreateEx(cpGrow: Int32, hheap: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.UI.Controls.HDPA: ...
@winfunctype('COMCTL32.dll')
def DPA_Clone(hdpa: win32more.Windows.Win32.UI.Controls.HDPA, hdpaNew: win32more.Windows.Win32.UI.Controls.HDPA) -> win32more.Windows.Win32.UI.Controls.HDPA: ...
@winfunctype('COMCTL32.dll')
def DPA_Destroy(hdpa: win32more.Windows.Win32.UI.Controls.HDPA) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def DPA_DestroyCallback(hdpa: win32more.Windows.Win32.UI.Controls.HDPA, pfnCB: win32more.Windows.Win32.UI.Controls.PFNDAENUMCALLBACK, pData: VoidPtr) -> Void: ...
@winfunctype('COMCTL32.dll')
def DPA_DeletePtr(hdpa: win32more.Windows.Win32.UI.Controls.HDPA, i: Int32) -> VoidPtr: ...
@winfunctype('COMCTL32.dll')
def DPA_DeleteAllPtrs(hdpa: win32more.Windows.Win32.UI.Controls.HDPA) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def DPA_EnumCallback(hdpa: win32more.Windows.Win32.UI.Controls.HDPA, pfnCB: win32more.Windows.Win32.UI.Controls.PFNDAENUMCALLBACK, pData: VoidPtr) -> Void: ...
@winfunctype('COMCTL32.dll')
def DPA_Grow(pdpa: win32more.Windows.Win32.UI.Controls.HDPA, cp: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def DPA_InsertPtr(hdpa: win32more.Windows.Win32.UI.Controls.HDPA, i: Int32, p: VoidPtr) -> Int32: ...
@winfunctype('COMCTL32.dll')
def DPA_SetPtr(hdpa: win32more.Windows.Win32.UI.Controls.HDPA, i: Int32, p: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def DPA_GetPtr(hdpa: win32more.Windows.Win32.UI.Controls.HDPA, i: IntPtr) -> VoidPtr: ...
@winfunctype('COMCTL32.dll')
def DPA_GetPtrIndex(hdpa: win32more.Windows.Win32.UI.Controls.HDPA, p: VoidPtr) -> Int32: ...
@winfunctype('COMCTL32.dll')
def DPA_GetSize(hdpa: win32more.Windows.Win32.UI.Controls.HDPA) -> UInt64: ...
@winfunctype('COMCTL32.dll')
def DPA_Sort(hdpa: win32more.Windows.Win32.UI.Controls.HDPA, pfnCompare: win32more.Windows.Win32.UI.Controls.PFNDACOMPARE, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def DPA_LoadStream(phdpa: POINTER(win32more.Windows.Win32.UI.Controls.HDPA), pfn: win32more.Windows.Win32.UI.Controls.PFNDPASTREAM, pstream: win32more.Windows.Win32.System.Com.IStream, pvInstData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('COMCTL32.dll')
def DPA_SaveStream(hdpa: win32more.Windows.Win32.UI.Controls.HDPA, pfn: win32more.Windows.Win32.UI.Controls.PFNDPASTREAM, pstream: win32more.Windows.Win32.System.Com.IStream, pvInstData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('COMCTL32.dll')
def DPA_Merge(hdpaDest: win32more.Windows.Win32.UI.Controls.HDPA, hdpaSrc: win32more.Windows.Win32.UI.Controls.HDPA, dwFlags: UInt32, pfnCompare: win32more.Windows.Win32.UI.Controls.PFNDACOMPARE, pfnMerge: win32more.Windows.Win32.UI.Controls.PFNDPAMERGE, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def DPA_Search(hdpa: win32more.Windows.Win32.UI.Controls.HDPA, pFind: VoidPtr, iStart: Int32, pfnCompare: win32more.Windows.Win32.UI.Controls.PFNDACOMPARE, lParam: win32more.Windows.Win32.Foundation.LPARAM, options: UInt32) -> Int32: ...
@winfunctype('COMCTL32.dll')
def Str_SetPtrW(ppsz: POINTER(win32more.Windows.Win32.Foundation.PWSTR), psz: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def FlatSB_EnableScrollBar(param0: win32more.Windows.Win32.Foundation.HWND, param1: Int32, param2: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def FlatSB_ShowScrollBar(param0: win32more.Windows.Win32.Foundation.HWND, code: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS, param2: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def FlatSB_GetScrollRange(param0: win32more.Windows.Win32.Foundation.HWND, code: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS, param2: POINTER(Int32), param3: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def FlatSB_GetScrollInfo(param0: win32more.Windows.Win32.Foundation.HWND, code: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS, param2: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def FlatSB_GetScrollPos(param0: win32more.Windows.Win32.Foundation.HWND, code: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS) -> Int32: ...
@winfunctype('COMCTL32.dll')
def FlatSB_GetScrollProp(param0: win32more.Windows.Win32.Foundation.HWND, propIndex: win32more.Windows.Win32.UI.Controls.WSB_PROP, param2: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def FlatSB_SetScrollPos(param0: win32more.Windows.Win32.Foundation.HWND, code: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS, pos: Int32, fRedraw: win32more.Windows.Win32.Foundation.BOOL) -> Int32: ...
@winfunctype('COMCTL32.dll')
def FlatSB_SetScrollInfo(param0: win32more.Windows.Win32.Foundation.HWND, code: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS, psi: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLINFO), fRedraw: win32more.Windows.Win32.Foundation.BOOL) -> Int32: ...
@winfunctype('COMCTL32.dll')
def FlatSB_SetScrollRange(param0: win32more.Windows.Win32.Foundation.HWND, code: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS, min: Int32, max: Int32, fRedraw: win32more.Windows.Win32.Foundation.BOOL) -> Int32: ...
@winfunctype('COMCTL32.dll')
def FlatSB_SetScrollProp(param0: win32more.Windows.Win32.Foundation.HWND, index: UInt32, newValue: IntPtr, param3: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def InitializeFlatSB(param0: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('COMCTL32.dll')
def UninitializeFlatSB(param0: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('COMCTL32.dll')
def LoadIconMetric(hinst: win32more.Windows.Win32.Foundation.HINSTANCE, pszName: win32more.Windows.Win32.Foundation.PWSTR, lims: win32more.Windows.Win32.UI.Controls._LI_METRIC, phico: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('COMCTL32.dll')
def LoadIconWithScaleDown(hinst: win32more.Windows.Win32.Foundation.HINSTANCE, pszName: win32more.Windows.Win32.Foundation.PWSTR, cx: Int32, cy: Int32, phico: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('COMCTL32.dll')
def DrawShadowText(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, pszText: win32more.Windows.Win32.Foundation.PWSTR, cch: UInt32, prc: POINTER(win32more.Windows.Win32.Foundation.RECT), dwFlags: UInt32, crText: win32more.Windows.Win32.Foundation.COLORREF, crShadow: win32more.Windows.Win32.Foundation.COLORREF, ixOffset: Int32, iyOffset: Int32) -> Int32: ...
@winfunctype('COMCTL32.dll')
def ImageList_CoCreateInstance(rclsid: POINTER(Guid), punkOuter: win32more.Windows.Win32.System.Com.IUnknown, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def BeginPanningFeedback(hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('UxTheme.dll')
def UpdatePanningFeedback(hwnd: win32more.Windows.Win32.Foundation.HWND, lTotalOverpanOffsetX: Int32, lTotalOverpanOffsetY: Int32, fInInertia: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('UxTheme.dll')
def EndPanningFeedback(hwnd: win32more.Windows.Win32.Foundation.HWND, fAnimateBack: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('UXTHEME.dll')
def GetThemeAnimationProperty(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iStoryboardId: Int32, iTargetId: Int32, eProperty: win32more.Windows.Win32.UI.Controls.TA_PROPERTY, pvProperty: VoidPtr, cbSize: UInt32, pcbSizeOut: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def GetThemeAnimationTransform(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iStoryboardId: Int32, iTargetId: Int32, dwTransformIndex: UInt32, pTransform: POINTER(win32more.Windows.Win32.UI.Controls.TA_TRANSFORM), cbSize: UInt32, pcbSizeOut: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def GetThemeTimingFunction(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iTimingFunctionId: Int32, pTimingFunction: POINTER(win32more.Windows.Win32.UI.Controls.TA_TIMINGFUNCTION), cbSize: UInt32, pcbSizeOut: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def OpenThemeData(hwnd: win32more.Windows.Win32.Foundation.HWND, pszClassList: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.UI.Controls.HTHEME: ...
@winfunctype('UXTHEME.dll')
def OpenThemeDataEx(hwnd: win32more.Windows.Win32.Foundation.HWND, pszClassList: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: win32more.Windows.Win32.UI.Controls.OPEN_THEME_DATA_FLAGS) -> win32more.Windows.Win32.UI.Controls.HTHEME: ...
@winfunctype('UXTHEME.dll')
def CloseThemeData(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def DrawThemeBackground(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iPartId: Int32, iStateId: Int32, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT), pClipRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def DrawThemeBackgroundEx(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iPartId: Int32, iStateId: Int32, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT), pOptions: POINTER(win32more.Windows.Win32.UI.Controls.DTBGOPTS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def DrawThemeText(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iPartId: Int32, iStateId: Int32, pszText: win32more.Windows.Win32.Foundation.PWSTR, cchText: Int32, dwTextFlags: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT, dwTextFlags2: UInt32, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def GetThemeBackgroundContentRect(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iPartId: Int32, iStateId: Int32, pBoundingRect: POINTER(win32more.Windows.Win32.Foundation.RECT), pContentRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def GetThemeBackgroundExtent(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iPartId: Int32, iStateId: Int32, pContentRect: POINTER(win32more.Windows.Win32.Foundation.RECT), pExtentRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def GetThemeBackgroundRegion(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iPartId: Int32, iStateId: Int32, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT), pRegion: POINTER(win32more.Windows.Win32.Graphics.Gdi.HRGN)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def GetThemePartSize(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iPartId: Int32, iStateId: Int32, prc: POINTER(win32more.Windows.Win32.Foundation.RECT), eSize: win32more.Windows.Win32.UI.Controls.THEMESIZE, psz: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def GetThemeTextExtent(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iPartId: Int32, iStateId: Int32, pszText: win32more.Windows.Win32.Foundation.PWSTR, cchCharCount: Int32, dwTextFlags: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT, pBoundingRect: POINTER(win32more.Windows.Win32.Foundation.RECT), pExtentRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def GetThemeTextMetrics(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iPartId: Int32, iStateId: Int32, ptm: POINTER(win32more.Windows.Win32.Graphics.Gdi.TEXTMETRICW)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def HitTestThemeBackground(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iPartId: Int32, iStateId: Int32, dwOptions: win32more.Windows.Win32.UI.Controls.HIT_TEST_BACKGROUND_OPTIONS, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT), hrgn: win32more.Windows.Win32.Graphics.Gdi.HRGN, ptTest: win32more.Windows.Win32.Foundation.POINT, pwHitTestCode: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def DrawThemeEdge(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iPartId: Int32, iStateId: Int32, pDestRect: POINTER(win32more.Windows.Win32.Foundation.RECT), uEdge: win32more.Windows.Win32.Graphics.Gdi.DRAWEDGE_FLAGS, uFlags: win32more.Windows.Win32.Graphics.Gdi.DRAW_EDGE_FLAGS, pContentRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def DrawThemeIcon(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iPartId: Int32, iStateId: Int32, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT), himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST, iImageIndex: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def IsThemePartDefined(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iPartId: Int32, iStateId: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('UxTheme.dll')
def IsThemeBackgroundPartiallyTransparent(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iPartId: Int32, iStateId: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('UXTHEME.dll')
def GetThemeColor(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iPartId: Int32, iStateId: Int32, iPropId: Int32, pColor: POINTER(win32more.Windows.Win32.Foundation.COLORREF)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def GetThemeMetric(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iPartId: Int32, iStateId: Int32, iPropId: Int32, piVal: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def GetThemeString(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iPartId: Int32, iStateId: Int32, iPropId: Int32, pszBuff: win32more.Windows.Win32.Foundation.PWSTR, cchMaxBuffChars: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def GetThemeBool(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iPartId: Int32, iStateId: Int32, iPropId: Int32, pfVal: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def GetThemeInt(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iPartId: Int32, iStateId: Int32, iPropId: Int32, piVal: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def GetThemeEnumValue(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iPartId: Int32, iStateId: Int32, iPropId: Int32, piVal: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def GetThemePosition(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iPartId: Int32, iStateId: Int32, iPropId: Int32, pPoint: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def GetThemeFont(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iPartId: Int32, iStateId: Int32, iPropId: Int32, pFont: POINTER(win32more.Windows.Win32.Graphics.Gdi.LOGFONTW)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def GetThemeRect(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iPartId: Int32, iStateId: Int32, iPropId: Int32, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def GetThemeMargins(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iPartId: Int32, iStateId: Int32, iPropId: Int32, prc: POINTER(win32more.Windows.Win32.Foundation.RECT), pMargins: POINTER(win32more.Windows.Win32.UI.Controls.MARGINS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def GetThemeIntList(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iPartId: Int32, iStateId: Int32, iPropId: Int32, pIntList: POINTER(win32more.Windows.Win32.UI.Controls.INTLIST)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def GetThemePropertyOrigin(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iPartId: Int32, iStateId: Int32, iPropId: Int32, pOrigin: POINTER(win32more.Windows.Win32.UI.Controls.PROPERTYORIGIN)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def SetWindowTheme(hwnd: win32more.Windows.Win32.Foundation.HWND, pszSubAppName: win32more.Windows.Win32.Foundation.PWSTR, pszSubIdList: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def GetThemeFilename(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iPartId: Int32, iStateId: Int32, iPropId: Int32, pszThemeFileName: win32more.Windows.Win32.Foundation.PWSTR, cchMaxBuffChars: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def GetThemeSysColor(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iColorId: Int32) -> win32more.Windows.Win32.Foundation.COLORREF: ...
@winfunctype('UxTheme.dll')
def GetThemeSysColorBrush(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iColorId: Int32) -> win32more.Windows.Win32.Graphics.Gdi.HBRUSH: ...
@winfunctype('UxTheme.dll')
def GetThemeSysBool(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iBoolId: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('UxTheme.dll')
def GetThemeSysSize(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iSizeId: Int32) -> Int32: ...
@winfunctype('UxTheme.dll')
def GetThemeSysFont(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iFontId: Int32, plf: POINTER(win32more.Windows.Win32.Graphics.Gdi.LOGFONTW)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def GetThemeSysString(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iStringId: Int32, pszStringBuff: win32more.Windows.Win32.Foundation.PWSTR, cchMaxStringChars: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def GetThemeSysInt(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iIntId: Int32, piValue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def IsThemeActive() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('UXTHEME.dll')
def IsAppThemed() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('UXTHEME.dll')
def GetWindowTheme(hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.UI.Controls.HTHEME: ...
@winfunctype('UxTheme.dll')
def EnableThemeDialogTexture(hwnd: win32more.Windows.Win32.Foundation.HWND, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def IsThemeDialogTextureEnabled(hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('UXTHEME.dll')
def GetThemeAppProperties() -> win32more.Windows.Win32.UI.Controls.SET_THEME_APP_PROPERTIES_FLAGS: ...
@winfunctype('UxTheme.dll')
def SetThemeAppProperties(dwFlags: win32more.Windows.Win32.UI.Controls.SET_THEME_APP_PROPERTIES_FLAGS) -> Void: ...
@winfunctype('UXTHEME.dll')
def GetCurrentThemeName(pszThemeFileName: win32more.Windows.Win32.Foundation.PWSTR, cchMaxNameChars: Int32, pszColorBuff: win32more.Windows.Win32.Foundation.PWSTR, cchMaxColorChars: Int32, pszSizeBuff: win32more.Windows.Win32.Foundation.PWSTR, cchMaxSizeChars: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def GetThemeDocumentationProperty(pszThemeName: win32more.Windows.Win32.Foundation.PWSTR, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, pszValueBuff: win32more.Windows.Win32.Foundation.PWSTR, cchMaxValChars: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def DrawThemeParentBackground(hwnd: win32more.Windows.Win32.Foundation.HWND, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, prc: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def EnableTheming(fEnable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def DrawThemeParentBackgroundEx(hwnd: win32more.Windows.Win32.Foundation.HWND, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, dwFlags: win32more.Windows.Win32.UI.Controls.DRAW_THEME_PARENT_BACKGROUND_FLAGS, prc: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def SetWindowThemeAttribute(hwnd: win32more.Windows.Win32.Foundation.HWND, eAttribute: win32more.Windows.Win32.UI.Controls.WINDOWTHEMEATTRIBUTETYPE, pvAttribute: VoidPtr, cbAttribute: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def DrawThemeTextEx(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, iPartId: Int32, iStateId: Int32, pszText: win32more.Windows.Win32.Foundation.PWSTR, cchText: Int32, dwTextFlags: win32more.Windows.Win32.Graphics.Gdi.DRAW_TEXT_FORMAT, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT), pOptions: POINTER(win32more.Windows.Win32.UI.Controls.DTTOPTS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def GetThemeBitmap(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iPartId: Int32, iStateId: Int32, iPropId: Int32, dwFlags: win32more.Windows.Win32.UI.Controls.GET_THEME_BITMAP_FLAGS, phBitmap: POINTER(win32more.Windows.Win32.Graphics.Gdi.HBITMAP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def GetThemeStream(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iPartId: Int32, iStateId: Int32, iPropId: Int32, ppvStream: POINTER(VoidPtr), pcbStream: POINTER(UInt32), hInst: win32more.Windows.Win32.Foundation.HINSTANCE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def BufferedPaintInit() -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def BufferedPaintUnInit() -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def BeginBufferedPaint(hdcTarget: win32more.Windows.Win32.Graphics.Gdi.HDC, prcTarget: POINTER(win32more.Windows.Win32.Foundation.RECT), dwFormat: win32more.Windows.Win32.UI.Controls.BP_BUFFERFORMAT, pPaintParams: POINTER(win32more.Windows.Win32.UI.Controls.BP_PAINTPARAMS), phdc: POINTER(win32more.Windows.Win32.Graphics.Gdi.HDC)) -> IntPtr: ...
@winfunctype('UXTHEME.dll')
def EndBufferedPaint(hBufferedPaint: IntPtr, fUpdateTarget: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def GetBufferedPaintTargetRect(hBufferedPaint: IntPtr, prc: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def GetBufferedPaintTargetDC(hBufferedPaint: IntPtr) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
@winfunctype('UxTheme.dll')
def GetBufferedPaintDC(hBufferedPaint: IntPtr) -> win32more.Windows.Win32.Graphics.Gdi.HDC: ...
@winfunctype('UXTHEME.dll')
def GetBufferedPaintBits(hBufferedPaint: IntPtr, ppbBuffer: POINTER(POINTER(win32more.Windows.Win32.Graphics.Gdi.RGBQUAD)), pcxRow: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def BufferedPaintClear(hBufferedPaint: IntPtr, prc: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def BufferedPaintSetAlpha(hBufferedPaint: IntPtr, prc: POINTER(win32more.Windows.Win32.Foundation.RECT), alpha: Byte) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UXTHEME.dll')
def BufferedPaintStopAllAnimations(hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def BeginBufferedAnimation(hwnd: win32more.Windows.Win32.Foundation.HWND, hdcTarget: win32more.Windows.Win32.Graphics.Gdi.HDC, prcTarget: POINTER(win32more.Windows.Win32.Foundation.RECT), dwFormat: win32more.Windows.Win32.UI.Controls.BP_BUFFERFORMAT, pPaintParams: POINTER(win32more.Windows.Win32.UI.Controls.BP_PAINTPARAMS), pAnimationParams: POINTER(win32more.Windows.Win32.UI.Controls.BP_ANIMATIONPARAMS), phdcFrom: POINTER(win32more.Windows.Win32.Graphics.Gdi.HDC), phdcTo: POINTER(win32more.Windows.Win32.Graphics.Gdi.HDC)) -> IntPtr: ...
@winfunctype('UxTheme.dll')
def EndBufferedAnimation(hbpAnimation: IntPtr, fUpdateTarget: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('UxTheme.dll')
def BufferedPaintRenderAnimation(hwnd: win32more.Windows.Win32.Foundation.HWND, hdcTarget: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('UXTHEME.dll')
def IsCompositionActive() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('UxTheme.dll')
def GetThemeTransitionDuration(hTheme: win32more.Windows.Win32.UI.Controls.HTHEME, iPartId: Int32, iStateIdFrom: Int32, iStateIdTo: Int32, iPropId: Int32, pdwDuration: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USER32.dll')
def CheckDlgButton(hDlg: win32more.Windows.Win32.Foundation.HWND, nIDButton: Int32, uCheck: win32more.Windows.Win32.UI.Controls.DLG_BUTTON_CHECK_STATE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def CheckRadioButton(hDlg: win32more.Windows.Win32.Foundation.HWND, nIDFirstButton: Int32, nIDLastButton: Int32, nIDCheckButton: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def IsDlgButtonChecked(hDlg: win32more.Windows.Win32.Foundation.HWND, nIDButton: Int32) -> UInt32: ...
@winfunctype('USER32.dll')
def IsCharLowerW(ch: Char) -> win32more.Windows.Win32.Foundation.BOOL: ...
IsCharLower = UnicodeAlias('IsCharLowerW')
@winfunctype('USER32.dll')
def CreateSyntheticPointerDevice(pointerType: win32more.Windows.Win32.UI.WindowsAndMessaging.POINTER_INPUT_TYPE, maxCount: UInt32, mode: win32more.Windows.Win32.UI.Controls.POINTER_FEEDBACK_MODE) -> win32more.Windows.Win32.UI.Controls.HSYNTHETICPOINTERDEVICE: ...
@winfunctype('USER32.dll')
def DestroySyntheticPointerDevice(device: win32more.Windows.Win32.UI.Controls.HSYNTHETICPOINTERDEVICE) -> Void: ...
@winfunctype('USER32.dll')
def RegisterTouchHitTestingWindow(hwnd: win32more.Windows.Win32.Foundation.HWND, value: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def EvaluateProximityToRect(controlBoundingBox: POINTER(win32more.Windows.Win32.Foundation.RECT), pHitTestingInput: POINTER(win32more.Windows.Win32.UI.Controls.TOUCH_HIT_TESTING_INPUT), pProximityEval: POINTER(win32more.Windows.Win32.UI.Controls.TOUCH_HIT_TESTING_PROXIMITY_EVALUATION)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def EvaluateProximityToPolygon(numVertices: UInt32, controlPolygon: POINTER(win32more.Windows.Win32.Foundation.POINT), pHitTestingInput: POINTER(win32more.Windows.Win32.UI.Controls.TOUCH_HIT_TESTING_INPUT), pProximityEval: POINTER(win32more.Windows.Win32.UI.Controls.TOUCH_HIT_TESTING_PROXIMITY_EVALUATION)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def PackTouchHitTestingProximityEvaluation(pHitTestingInput: POINTER(win32more.Windows.Win32.UI.Controls.TOUCH_HIT_TESTING_INPUT), pProximityEval: POINTER(win32more.Windows.Win32.UI.Controls.TOUCH_HIT_TESTING_PROXIMITY_EVALUATION)) -> win32more.Windows.Win32.Foundation.LRESULT: ...
@winfunctype('USER32.dll')
def GetWindowFeedbackSetting(hwnd: win32more.Windows.Win32.Foundation.HWND, feedback: win32more.Windows.Win32.UI.Controls.FEEDBACK_TYPE, dwFlags: UInt32, pSize: POINTER(UInt32), config: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetWindowFeedbackSetting(hwnd: win32more.Windows.Win32.Foundation.HWND, feedback: win32more.Windows.Win32.UI.Controls.FEEDBACK_TYPE, dwFlags: UInt32, size: UInt32, configuration: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetScrollPos(hWnd: win32more.Windows.Win32.Foundation.HWND, nBar: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS, nPos: Int32, bRedraw: win32more.Windows.Win32.Foundation.BOOL) -> Int32: ...
@winfunctype('USER32.dll')
def SetScrollRange(hWnd: win32more.Windows.Win32.Foundation.HWND, nBar: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS, nMinPos: Int32, nMaxPos: Int32, bRedraw: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ShowScrollBar(hWnd: win32more.Windows.Win32.Foundation.HWND, wBar: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS, bShow: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def EnableScrollBar(hWnd: win32more.Windows.Win32.Foundation.HWND, wSBflags: UInt32, wArrows: win32more.Windows.Win32.UI.Controls.ENABLE_SCROLL_BAR_ARROWS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DlgDirListA(hDlg: win32more.Windows.Win32.Foundation.HWND, lpPathSpec: win32more.Windows.Win32.Foundation.PSTR, nIDListBox: Int32, nIDStaticPath: Int32, uFileType: win32more.Windows.Win32.UI.Controls.DLG_DIR_LIST_FILE_TYPE) -> Int32: ...
@winfunctype('USER32.dll')
def DlgDirListW(hDlg: win32more.Windows.Win32.Foundation.HWND, lpPathSpec: win32more.Windows.Win32.Foundation.PWSTR, nIDListBox: Int32, nIDStaticPath: Int32, uFileType: win32more.Windows.Win32.UI.Controls.DLG_DIR_LIST_FILE_TYPE) -> Int32: ...
DlgDirList = UnicodeAlias('DlgDirListW')
@winfunctype('USER32.dll')
def DlgDirSelectExA(hwndDlg: win32more.Windows.Win32.Foundation.HWND, lpString: win32more.Windows.Win32.Foundation.PSTR, chCount: Int32, idListBox: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DlgDirSelectExW(hwndDlg: win32more.Windows.Win32.Foundation.HWND, lpString: win32more.Windows.Win32.Foundation.PWSTR, chCount: Int32, idListBox: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
DlgDirSelectEx = UnicodeAlias('DlgDirSelectExW')
@winfunctype('USER32.dll')
def DlgDirListComboBoxA(hDlg: win32more.Windows.Win32.Foundation.HWND, lpPathSpec: win32more.Windows.Win32.Foundation.PSTR, nIDComboBox: Int32, nIDStaticPath: Int32, uFiletype: win32more.Windows.Win32.UI.Controls.DLG_DIR_LIST_FILE_TYPE) -> Int32: ...
@winfunctype('USER32.dll')
def DlgDirListComboBoxW(hDlg: win32more.Windows.Win32.Foundation.HWND, lpPathSpec: win32more.Windows.Win32.Foundation.PWSTR, nIDComboBox: Int32, nIDStaticPath: Int32, uFiletype: win32more.Windows.Win32.UI.Controls.DLG_DIR_LIST_FILE_TYPE) -> Int32: ...
DlgDirListComboBox = UnicodeAlias('DlgDirListComboBoxW')
@winfunctype('USER32.dll')
def DlgDirSelectComboBoxExA(hwndDlg: win32more.Windows.Win32.Foundation.HWND, lpString: win32more.Windows.Win32.Foundation.PSTR, cchOut: Int32, idComboBox: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DlgDirSelectComboBoxExW(hwndDlg: win32more.Windows.Win32.Foundation.HWND, lpString: win32more.Windows.Win32.Foundation.PWSTR, cchOut: Int32, idComboBox: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
DlgDirSelectComboBoxEx = UnicodeAlias('DlgDirSelectComboBoxExW')
@winfunctype('USER32.dll')
def SetScrollInfo(hwnd: win32more.Windows.Win32.Foundation.HWND, nBar: win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLBAR_CONSTANTS, lpsi: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.SCROLLINFO), redraw: win32more.Windows.Win32.Foundation.BOOL) -> Int32: ...
@winfunctype('USER32.dll')
def GetComboBoxInfo(hwndCombo: win32more.Windows.Win32.Foundation.HWND, pcbi: POINTER(win32more.Windows.Win32.UI.Controls.COMBOBOXINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetListBoxInfo(hwnd: win32more.Windows.Win32.Foundation.HWND) -> UInt32: ...
@winfunctype('USER32.dll')
def RegisterPointerDeviceNotifications(window: win32more.Windows.Win32.Foundation.HWND, notifyRange: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
BACKGROUNDSTATES = Int32
EBS_NORMAL: win32more.Windows.Win32.UI.Controls.BACKGROUNDSTATES = 1
EBS_HOT: win32more.Windows.Win32.UI.Controls.BACKGROUNDSTATES = 2
EBS_DISABLED: win32more.Windows.Win32.UI.Controls.BACKGROUNDSTATES = 3
EBS_FOCUSED: win32more.Windows.Win32.UI.Controls.BACKGROUNDSTATES = 4
EBS_READONLY: win32more.Windows.Win32.UI.Controls.BACKGROUNDSTATES = 5
EBS_ASSIST: win32more.Windows.Win32.UI.Controls.BACKGROUNDSTATES = 6
BACKGROUNDWITHBORDERSTATES = Int32
EBWBS_NORMAL: win32more.Windows.Win32.UI.Controls.BACKGROUNDWITHBORDERSTATES = 1
EBWBS_HOT: win32more.Windows.Win32.UI.Controls.BACKGROUNDWITHBORDERSTATES = 2
EBWBS_DISABLED: win32more.Windows.Win32.UI.Controls.BACKGROUNDWITHBORDERSTATES = 3
EBWBS_FOCUSED: win32more.Windows.Win32.UI.Controls.BACKGROUNDWITHBORDERSTATES = 4
BALLOONSTATES = Int32
TTBS_NORMAL: win32more.Windows.Win32.UI.Controls.BALLOONSTATES = 1
TTBS_LINK: win32more.Windows.Win32.UI.Controls.BALLOONSTATES = 2
BALLOONSTEMSTATES = Int32
TTBSS_POINTINGUPLEFTWALL: win32more.Windows.Win32.UI.Controls.BALLOONSTEMSTATES = 1
TTBSS_POINTINGUPCENTERED: win32more.Windows.Win32.UI.Controls.BALLOONSTEMSTATES = 2
TTBSS_POINTINGUPRIGHTWALL: win32more.Windows.Win32.UI.Controls.BALLOONSTEMSTATES = 3
TTBSS_POINTINGDOWNRIGHTWALL: win32more.Windows.Win32.UI.Controls.BALLOONSTEMSTATES = 4
TTBSS_POINTINGDOWNCENTERED: win32more.Windows.Win32.UI.Controls.BALLOONSTEMSTATES = 5
TTBSS_POINTINGDOWNLEFTWALL: win32more.Windows.Win32.UI.Controls.BALLOONSTEMSTATES = 6
BARBACKGROUNDSTATES = Int32
MB_ACTIVE: win32more.Windows.Win32.UI.Controls.BARBACKGROUNDSTATES = 1
MB_INACTIVE: win32more.Windows.Win32.UI.Controls.BARBACKGROUNDSTATES = 2
BARITEMSTATES = Int32
MBI_NORMAL: win32more.Windows.Win32.UI.Controls.BARITEMSTATES = 1
MBI_HOT: win32more.Windows.Win32.UI.Controls.BARITEMSTATES = 2
MBI_PUSHED: win32more.Windows.Win32.UI.Controls.BARITEMSTATES = 3
MBI_DISABLED: win32more.Windows.Win32.UI.Controls.BARITEMSTATES = 4
MBI_DISABLEDHOT: win32more.Windows.Win32.UI.Controls.BARITEMSTATES = 5
MBI_DISABLEDPUSHED: win32more.Windows.Win32.UI.Controls.BARITEMSTATES = 6
BGTYPE = Int32
BT_IMAGEFILE: win32more.Windows.Win32.UI.Controls.BGTYPE = 0
BT_BORDERFILL: win32more.Windows.Win32.UI.Controls.BGTYPE = 1
BT_NONE: win32more.Windows.Win32.UI.Controls.BGTYPE = 2
BODYSTATES = Int32
FBS_NORMAL: win32more.Windows.Win32.UI.Controls.BODYSTATES = 1
FBS_EMPHASIZED: win32more.Windows.Win32.UI.Controls.BODYSTATES = 2
BORDERSTATES = Int32
CBB_NORMAL: win32more.Windows.Win32.UI.Controls.BORDERSTATES = 1
CBB_HOT: win32more.Windows.Win32.UI.Controls.BORDERSTATES = 2
CBB_FOCUSED: win32more.Windows.Win32.UI.Controls.BORDERSTATES = 3
CBB_DISABLED: win32more.Windows.Win32.UI.Controls.BORDERSTATES = 4
BORDERTYPE = Int32
BT_RECT: win32more.Windows.Win32.UI.Controls.BORDERTYPE = 0
BT_ROUNDRECT: win32more.Windows.Win32.UI.Controls.BORDERTYPE = 1
BT_ELLIPSE: win32more.Windows.Win32.UI.Controls.BORDERTYPE = 2
BORDER_HSCROLLSTATES = Int32
LBPSH_NORMAL: win32more.Windows.Win32.UI.Controls.BORDER_HSCROLLSTATES = 1
LBPSH_FOCUSED: win32more.Windows.Win32.UI.Controls.BORDER_HSCROLLSTATES = 2
LBPSH_HOT: win32more.Windows.Win32.UI.Controls.BORDER_HSCROLLSTATES = 3
LBPSH_DISABLED: win32more.Windows.Win32.UI.Controls.BORDER_HSCROLLSTATES = 4
BORDER_HVSCROLLSTATES = Int32
LBPSHV_NORMAL: win32more.Windows.Win32.UI.Controls.BORDER_HVSCROLLSTATES = 1
LBPSHV_FOCUSED: win32more.Windows.Win32.UI.Controls.BORDER_HVSCROLLSTATES = 2
LBPSHV_HOT: win32more.Windows.Win32.UI.Controls.BORDER_HVSCROLLSTATES = 3
LBPSHV_DISABLED: win32more.Windows.Win32.UI.Controls.BORDER_HVSCROLLSTATES = 4
BORDER_NOSCROLLSTATES = Int32
LBPSN_NORMAL: win32more.Windows.Win32.UI.Controls.BORDER_NOSCROLLSTATES = 1
LBPSN_FOCUSED: win32more.Windows.Win32.UI.Controls.BORDER_NOSCROLLSTATES = 2
LBPSN_HOT: win32more.Windows.Win32.UI.Controls.BORDER_NOSCROLLSTATES = 3
LBPSN_DISABLED: win32more.Windows.Win32.UI.Controls.BORDER_NOSCROLLSTATES = 4
BORDER_VSCROLLSTATES = Int32
LBPSV_NORMAL: win32more.Windows.Win32.UI.Controls.BORDER_VSCROLLSTATES = 1
LBPSV_FOCUSED: win32more.Windows.Win32.UI.Controls.BORDER_VSCROLLSTATES = 2
LBPSV_HOT: win32more.Windows.Win32.UI.Controls.BORDER_VSCROLLSTATES = 3
LBPSV_DISABLED: win32more.Windows.Win32.UI.Controls.BORDER_VSCROLLSTATES = 4
class BP_ANIMATIONPARAMS(Structure):
    cbSize: UInt32
    dwFlags: UInt32
    style: win32more.Windows.Win32.UI.Controls.BP_ANIMATIONSTYLE
    dwDuration: UInt32
BP_ANIMATIONSTYLE = Int32
BPAS_NONE: win32more.Windows.Win32.UI.Controls.BP_ANIMATIONSTYLE = 0
BPAS_LINEAR: win32more.Windows.Win32.UI.Controls.BP_ANIMATIONSTYLE = 1
BPAS_CUBIC: win32more.Windows.Win32.UI.Controls.BP_ANIMATIONSTYLE = 2
BPAS_SINE: win32more.Windows.Win32.UI.Controls.BP_ANIMATIONSTYLE = 3
BP_BUFFERFORMAT = Int32
BPBF_COMPATIBLEBITMAP: win32more.Windows.Win32.UI.Controls.BP_BUFFERFORMAT = 0
BPBF_DIB: win32more.Windows.Win32.UI.Controls.BP_BUFFERFORMAT = 1
BPBF_TOPDOWNDIB: win32more.Windows.Win32.UI.Controls.BP_BUFFERFORMAT = 2
BPBF_TOPDOWNMONODIB: win32more.Windows.Win32.UI.Controls.BP_BUFFERFORMAT = 3
class BP_PAINTPARAMS(Structure):
    cbSize: UInt32
    dwFlags: win32more.Windows.Win32.UI.Controls.BP_PAINTPARAMS_FLAGS
    prcExclude: POINTER(win32more.Windows.Win32.Foundation.RECT)
    pBlendFunction: POINTER(win32more.Windows.Win32.Graphics.Gdi.BLENDFUNCTION)
BP_PAINTPARAMS_FLAGS = UInt32
BPPF_ERASE: win32more.Windows.Win32.UI.Controls.BP_PAINTPARAMS_FLAGS = 1
BPPF_NOCLIP: win32more.Windows.Win32.UI.Controls.BP_PAINTPARAMS_FLAGS = 2
BPPF_NONCLIENT: win32more.Windows.Win32.UI.Controls.BP_PAINTPARAMS_FLAGS = 4
BUTTONPARTS = Int32
BP_PUSHBUTTON: win32more.Windows.Win32.UI.Controls.BUTTONPARTS = 1
BP_RADIOBUTTON: win32more.Windows.Win32.UI.Controls.BUTTONPARTS = 2
BP_CHECKBOX: win32more.Windows.Win32.UI.Controls.BUTTONPARTS = 3
BP_GROUPBOX: win32more.Windows.Win32.UI.Controls.BUTTONPARTS = 4
BP_USERBUTTON: win32more.Windows.Win32.UI.Controls.BUTTONPARTS = 5
BP_COMMANDLINK: win32more.Windows.Win32.UI.Controls.BUTTONPARTS = 6
BP_COMMANDLINKGLYPH: win32more.Windows.Win32.UI.Controls.BUTTONPARTS = 7
BP_RADIOBUTTON_HCDISABLED: win32more.Windows.Win32.UI.Controls.BUTTONPARTS = 8
BP_CHECKBOX_HCDISABLED: win32more.Windows.Win32.UI.Controls.BUTTONPARTS = 9
BP_GROUPBOX_HCDISABLED: win32more.Windows.Win32.UI.Controls.BUTTONPARTS = 10
BP_PUSHBUTTONDROPDOWN: win32more.Windows.Win32.UI.Controls.BUTTONPARTS = 11
class BUTTON_IMAGELIST(Structure):
    himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST
    margin: win32more.Windows.Win32.Foundation.RECT
    uAlign: win32more.Windows.Win32.UI.Controls.BUTTON_IMAGELIST_ALIGN
BUTTON_IMAGELIST_ALIGN = UInt32
BUTTON_IMAGELIST_ALIGN_LEFT: win32more.Windows.Win32.UI.Controls.BUTTON_IMAGELIST_ALIGN = 0
BUTTON_IMAGELIST_ALIGN_RIGHT: win32more.Windows.Win32.UI.Controls.BUTTON_IMAGELIST_ALIGN = 1
BUTTON_IMAGELIST_ALIGN_TOP: win32more.Windows.Win32.UI.Controls.BUTTON_IMAGELIST_ALIGN = 2
BUTTON_IMAGELIST_ALIGN_BOTTOM: win32more.Windows.Win32.UI.Controls.BUTTON_IMAGELIST_ALIGN = 3
BUTTON_IMAGELIST_ALIGN_CENTER: win32more.Windows.Win32.UI.Controls.BUTTON_IMAGELIST_ALIGN = 4
class BUTTON_SPLITINFO(Structure):
    mask: UInt32
    himlGlyph: win32more.Windows.Win32.UI.Controls.HIMAGELIST
    uSplitStyle: UInt32
    size: win32more.Windows.Win32.Foundation.SIZE
CAPTIONSTATES = Int32
CS_ACTIVE: win32more.Windows.Win32.UI.Controls.CAPTIONSTATES = 1
CS_INACTIVE: win32more.Windows.Win32.UI.Controls.CAPTIONSTATES = 2
CS_DISABLED: win32more.Windows.Win32.UI.Controls.CAPTIONSTATES = 3
class CCINFOA(Structure):
    szClass: win32more.Windows.Win32.Foundation.CHAR * 32
    flOptions: UInt32
    szDesc: win32more.Windows.Win32.Foundation.CHAR * 32
    cxDefault: UInt32
    cyDefault: UInt32
    flStyleDefault: UInt32
    flExtStyleDefault: UInt32
    flCtrlTypeMask: UInt32
    szTextDefault: win32more.Windows.Win32.Foundation.CHAR * 256
    cStyleFlags: Int32
    aStyleFlags: POINTER(win32more.Windows.Win32.UI.Controls.CCSTYLEFLAGA)
    lpfnStyle: win32more.Windows.Win32.UI.Controls.LPFNCCSTYLEA
    lpfnSizeToText: win32more.Windows.Win32.UI.Controls.LPFNCCSIZETOTEXTA
    dwReserved1: UInt32
    dwReserved2: UInt32
class CCINFOW(Structure):
    szClass: Char * 32
    flOptions: UInt32
    szDesc: Char * 32
    cxDefault: UInt32
    cyDefault: UInt32
    flStyleDefault: UInt32
    flExtStyleDefault: UInt32
    flCtrlTypeMask: UInt32
    cStyleFlags: Int32
    aStyleFlags: POINTER(win32more.Windows.Win32.UI.Controls.CCSTYLEFLAGW)
    szTextDefault: Char * 256
    lpfnStyle: win32more.Windows.Win32.UI.Controls.LPFNCCSTYLEW
    lpfnSizeToText: win32more.Windows.Win32.UI.Controls.LPFNCCSIZETOTEXTW
    dwReserved1: UInt32
    dwReserved2: UInt32
CCINFO = UnicodeAlias('CCINFOW')
class CCSTYLEA(Structure):
    flStyle: UInt32
    flExtStyle: UInt32
    szText: win32more.Windows.Win32.Foundation.CHAR * 256
    lgid: UInt16
    wReserved1: UInt16
class CCSTYLEFLAGA(Structure):
    flStyle: UInt32
    flStyleMask: UInt32
    pszStyle: win32more.Windows.Win32.Foundation.PSTR
class CCSTYLEFLAGW(Structure):
    flStyle: UInt32
    flStyleMask: UInt32
    pszStyle: win32more.Windows.Win32.Foundation.PWSTR
CCSTYLEFLAG = UnicodeAlias('CCSTYLEFLAGW')
class CCSTYLEW(Structure):
    flStyle: UInt32
    flExtStyle: UInt32
    szText: Char * 256
    lgid: UInt16
    wReserved1: UInt16
CCSTYLE = UnicodeAlias('CCSTYLEW')
CHECKBOXSTATES = Int32
CBS_UNCHECKEDNORMAL: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 1
CBS_UNCHECKEDHOT: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 2
CBS_UNCHECKEDPRESSED: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 3
CBS_UNCHECKEDDISABLED: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 4
CBS_CHECKEDNORMAL: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 5
CBS_CHECKEDHOT: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 6
CBS_CHECKEDPRESSED: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 7
CBS_CHECKEDDISABLED: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 8
CBS_MIXEDNORMAL: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 9
CBS_MIXEDHOT: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 10
CBS_MIXEDPRESSED: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 11
CBS_MIXEDDISABLED: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 12
CBS_IMPLICITNORMAL: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 13
CBS_IMPLICITHOT: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 14
CBS_IMPLICITPRESSED: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 15
CBS_IMPLICITDISABLED: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 16
CBS_EXCLUDEDNORMAL: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 17
CBS_EXCLUDEDHOT: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 18
CBS_EXCLUDEDPRESSED: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 19
CBS_EXCLUDEDDISABLED: win32more.Windows.Win32.UI.Controls.CHECKBOXSTATES = 20
CHEVRONSTATES = Int32
CHEVS_NORMAL: win32more.Windows.Win32.UI.Controls.CHEVRONSTATES = 1
CHEVS_HOT: win32more.Windows.Win32.UI.Controls.CHEVRONSTATES = 2
CHEVS_PRESSED: win32more.Windows.Win32.UI.Controls.CHEVRONSTATES = 3
CHEVRONVERTSTATES = Int32
CHEVSV_NORMAL: win32more.Windows.Win32.UI.Controls.CHEVRONVERTSTATES = 1
CHEVSV_HOT: win32more.Windows.Win32.UI.Controls.CHEVRONVERTSTATES = 2
CHEVSV_PRESSED: win32more.Windows.Win32.UI.Controls.CHEVRONVERTSTATES = 3
CLOCKPARTS = Int32
CLP_TIME: win32more.Windows.Win32.UI.Controls.CLOCKPARTS = 1
CLOCKSTATES = Int32
CLS_NORMAL: win32more.Windows.Win32.UI.Controls.CLOCKSTATES = 1
CLS_HOT: win32more.Windows.Win32.UI.Controls.CLOCKSTATES = 2
CLS_PRESSED: win32more.Windows.Win32.UI.Controls.CLOCKSTATES = 3
CLOSEBUTTONSTATES = Int32
CBS_NORMAL: win32more.Windows.Win32.UI.Controls.CLOSEBUTTONSTATES = 1
CBS_HOT: win32more.Windows.Win32.UI.Controls.CLOSEBUTTONSTATES = 2
CBS_PUSHED: win32more.Windows.Win32.UI.Controls.CLOSEBUTTONSTATES = 3
CBS_DISABLED: win32more.Windows.Win32.UI.Controls.CLOSEBUTTONSTATES = 4
CLOSESTATES = Int32
TTCS_NORMAL: win32more.Windows.Win32.UI.Controls.CLOSESTATES = 1
TTCS_HOT: win32more.Windows.Win32.UI.Controls.CLOSESTATES = 2
TTCS_PRESSED: win32more.Windows.Win32.UI.Controls.CLOSESTATES = 3
COLLAPSEBUTTONSTATES = Int32
LVCB_NORMAL: win32more.Windows.Win32.UI.Controls.COLLAPSEBUTTONSTATES = 1
LVCB_HOVER: win32more.Windows.Win32.UI.Controls.COLLAPSEBUTTONSTATES = 2
LVCB_PUSHED: win32more.Windows.Win32.UI.Controls.COLLAPSEBUTTONSTATES = 3
class COLORMAP(Structure):
    from_: win32more.Windows.Win32.Foundation.COLORREF
    to: win32more.Windows.Win32.Foundation.COLORREF
class COLORSCHEME(Structure):
    dwSize: UInt32
    clrBtnHighlight: win32more.Windows.Win32.Foundation.COLORREF
    clrBtnShadow: win32more.Windows.Win32.Foundation.COLORREF
class COMBOBOXEXITEMA(Structure):
    mask: win32more.Windows.Win32.UI.Controls.COMBOBOX_EX_ITEM_FLAGS
    iItem: IntPtr
    pszText: win32more.Windows.Win32.Foundation.PSTR
    cchTextMax: Int32
    iImage: Int32
    iSelectedImage: Int32
    iOverlay: Int32
    iIndent: Int32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
class COMBOBOXEXITEMW(Structure):
    mask: win32more.Windows.Win32.UI.Controls.COMBOBOX_EX_ITEM_FLAGS
    iItem: IntPtr
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    cchTextMax: Int32
    iImage: Int32
    iSelectedImage: Int32
    iOverlay: Int32
    iIndent: Int32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
COMBOBOXEXITEM = UnicodeAlias('COMBOBOXEXITEMW')
class COMBOBOXINFO(Structure):
    cbSize: UInt32
    rcItem: win32more.Windows.Win32.Foundation.RECT
    rcButton: win32more.Windows.Win32.Foundation.RECT
    stateButton: win32more.Windows.Win32.UI.Controls.COMBOBOXINFO_BUTTON_STATE
    hwndCombo: win32more.Windows.Win32.Foundation.HWND
    hwndItem: win32more.Windows.Win32.Foundation.HWND
    hwndList: win32more.Windows.Win32.Foundation.HWND
COMBOBOXINFO_BUTTON_STATE = UInt32
STATE_SYSTEM_INVISIBLE: win32more.Windows.Win32.UI.Controls.COMBOBOXINFO_BUTTON_STATE = 32768
STATE_SYSTEM_PRESSED: win32more.Windows.Win32.UI.Controls.COMBOBOXINFO_BUTTON_STATE = 8
STATE_SYSTEM_FOCUSABLE: win32more.Windows.Win32.UI.Controls.COMBOBOXINFO_BUTTON_STATE = 1048576
STATE_SYSTEM_OFFSCREEN: win32more.Windows.Win32.UI.Controls.COMBOBOXINFO_BUTTON_STATE = 65536
STATE_SYSTEM_UNAVAILABLE: win32more.Windows.Win32.UI.Controls.COMBOBOXINFO_BUTTON_STATE = 1
COMBOBOXPARTS = Int32
CP_DROPDOWNBUTTON: win32more.Windows.Win32.UI.Controls.COMBOBOXPARTS = 1
CP_BACKGROUND: win32more.Windows.Win32.UI.Controls.COMBOBOXPARTS = 2
CP_TRANSPARENTBACKGROUND: win32more.Windows.Win32.UI.Controls.COMBOBOXPARTS = 3
CP_BORDER: win32more.Windows.Win32.UI.Controls.COMBOBOXPARTS = 4
CP_READONLY: win32more.Windows.Win32.UI.Controls.COMBOBOXPARTS = 5
CP_DROPDOWNBUTTONRIGHT: win32more.Windows.Win32.UI.Controls.COMBOBOXPARTS = 6
CP_DROPDOWNBUTTONLEFT: win32more.Windows.Win32.UI.Controls.COMBOBOXPARTS = 7
CP_CUEBANNER: win32more.Windows.Win32.UI.Controls.COMBOBOXPARTS = 8
CP_DROPDOWNITEM: win32more.Windows.Win32.UI.Controls.COMBOBOXPARTS = 9
COMBOBOXSTYLESTATES = Int32
CBXS_NORMAL: win32more.Windows.Win32.UI.Controls.COMBOBOXSTYLESTATES = 1
CBXS_HOT: win32more.Windows.Win32.UI.Controls.COMBOBOXSTYLESTATES = 2
CBXS_PRESSED: win32more.Windows.Win32.UI.Controls.COMBOBOXSTYLESTATES = 3
CBXS_DISABLED: win32more.Windows.Win32.UI.Controls.COMBOBOXSTYLESTATES = 4
COMBOBOX_EX_ITEM_FLAGS = UInt32
CBEIF_DI_SETITEM: win32more.Windows.Win32.UI.Controls.COMBOBOX_EX_ITEM_FLAGS = 268435456
CBEIF_IMAGE: win32more.Windows.Win32.UI.Controls.COMBOBOX_EX_ITEM_FLAGS = 2
CBEIF_INDENT: win32more.Windows.Win32.UI.Controls.COMBOBOX_EX_ITEM_FLAGS = 16
CBEIF_LPARAM: win32more.Windows.Win32.UI.Controls.COMBOBOX_EX_ITEM_FLAGS = 32
CBEIF_OVERLAY: win32more.Windows.Win32.UI.Controls.COMBOBOX_EX_ITEM_FLAGS = 8
CBEIF_SELECTEDIMAGE: win32more.Windows.Win32.UI.Controls.COMBOBOX_EX_ITEM_FLAGS = 4
CBEIF_TEXT: win32more.Windows.Win32.UI.Controls.COMBOBOX_EX_ITEM_FLAGS = 1
COMMANDLINKGLYPHSTATES = Int32
CMDLGS_NORMAL: win32more.Windows.Win32.UI.Controls.COMMANDLINKGLYPHSTATES = 1
CMDLGS_HOT: win32more.Windows.Win32.UI.Controls.COMMANDLINKGLYPHSTATES = 2
CMDLGS_PRESSED: win32more.Windows.Win32.UI.Controls.COMMANDLINKGLYPHSTATES = 3
CMDLGS_DISABLED: win32more.Windows.Win32.UI.Controls.COMMANDLINKGLYPHSTATES = 4
CMDLGS_DEFAULTED: win32more.Windows.Win32.UI.Controls.COMMANDLINKGLYPHSTATES = 5
COMMANDLINKSTATES = Int32
CMDLS_NORMAL: win32more.Windows.Win32.UI.Controls.COMMANDLINKSTATES = 1
CMDLS_HOT: win32more.Windows.Win32.UI.Controls.COMMANDLINKSTATES = 2
CMDLS_PRESSED: win32more.Windows.Win32.UI.Controls.COMMANDLINKSTATES = 3
CMDLS_DISABLED: win32more.Windows.Win32.UI.Controls.COMMANDLINKSTATES = 4
CMDLS_DEFAULTED: win32more.Windows.Win32.UI.Controls.COMMANDLINKSTATES = 5
CMDLS_DEFAULTED_ANIMATING: win32more.Windows.Win32.UI.Controls.COMMANDLINKSTATES = 6
COMMUNICATIONSPARTS = Int32
CSST_TAB: win32more.Windows.Win32.UI.Controls.COMMUNICATIONSPARTS = 1
class COMPAREITEMSTRUCT(Structure):
    CtlType: win32more.Windows.Win32.UI.Controls.DRAWITEMSTRUCT_CTL_TYPE
    CtlID: UInt32
    hwndItem: win32more.Windows.Win32.Foundation.HWND
    itemID1: UInt32
    itemData1: UIntPtr
    itemID2: UInt32
    itemData2: UIntPtr
    dwLocaleId: UInt32
CONTENTALIGNMENT = Int32
CA_LEFT: win32more.Windows.Win32.UI.Controls.CONTENTALIGNMENT = 0
CA_CENTER: win32more.Windows.Win32.UI.Controls.CONTENTALIGNMENT = 1
CA_RIGHT: win32more.Windows.Win32.UI.Controls.CONTENTALIGNMENT = 2
CONTENTAREASTATES = Int32
AW_S_CONTENTAREA_NOMARGIN: win32more.Windows.Win32.UI.Controls.CONTENTAREASTATES = 1
CONTENTLINKSTATES = Int32
CPCL_NORMAL: win32more.Windows.Win32.UI.Controls.CONTENTLINKSTATES = 1
CPCL_HOT: win32more.Windows.Win32.UI.Controls.CONTENTLINKSTATES = 2
CPCL_PRESSED: win32more.Windows.Win32.UI.Controls.CONTENTLINKSTATES = 3
CPCL_DISABLED: win32more.Windows.Win32.UI.Controls.CONTENTLINKSTATES = 4
CONTENTPANESTATES = Int32
TDLGCPS_STANDALONE: win32more.Windows.Win32.UI.Controls.CONTENTPANESTATES = 1
CONTROLLABELSTATES = Int32
TS_CONTROLLABEL_NORMAL: win32more.Windows.Win32.UI.Controls.CONTROLLABELSTATES = 1
TS_CONTROLLABEL_DISABLED: win32more.Windows.Win32.UI.Controls.CONTROLLABELSTATES = 2
CONTROLPANELPARTS = Int32
CPANEL_NAVIGATIONPANE: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 1
CPANEL_CONTENTPANE: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 2
CPANEL_NAVIGATIONPANELABEL: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 3
CPANEL_CONTENTPANELABEL: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 4
CPANEL_TITLE: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 5
CPANEL_BODYTEXT: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 6
CPANEL_HELPLINK: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 7
CPANEL_TASKLINK: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 8
CPANEL_GROUPTEXT: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 9
CPANEL_CONTENTLINK: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 10
CPANEL_SECTIONTITLELINK: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 11
CPANEL_LARGECOMMANDAREA: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 12
CPANEL_SMALLCOMMANDAREA: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 13
CPANEL_BUTTON: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 14
CPANEL_MESSAGETEXT: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 15
CPANEL_NAVIGATIONPANELINE: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 16
CPANEL_CONTENTPANELINE: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 17
CPANEL_BANNERAREA: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 18
CPANEL_BODYTITLE: win32more.Windows.Win32.UI.Controls.CONTROLPANELPARTS = 19
COPYSTATES = Int32
DDCOPY_HIGHLIGHT: win32more.Windows.Win32.UI.Controls.COPYSTATES = 1
DDCOPY_NOHIGHLIGHT: win32more.Windows.Win32.UI.Controls.COPYSTATES = 2
CREATELINKSTATES = Int32
DDCREATELINK_HIGHLIGHT: win32more.Windows.Win32.UI.Controls.CREATELINKSTATES = 1
DDCREATELINK_NOHIGHLIGHT: win32more.Windows.Win32.UI.Controls.CREATELINKSTATES = 2
CUEBANNERSTATES = Int32
CBCB_NORMAL: win32more.Windows.Win32.UI.Controls.CUEBANNERSTATES = 1
CBCB_HOT: win32more.Windows.Win32.UI.Controls.CUEBANNERSTATES = 2
CBCB_PRESSED: win32more.Windows.Win32.UI.Controls.CUEBANNERSTATES = 3
CBCB_DISABLED: win32more.Windows.Win32.UI.Controls.CUEBANNERSTATES = 4
DATEBORDERSTATES = Int32
DPDB_NORMAL: win32more.Windows.Win32.UI.Controls.DATEBORDERSTATES = 1
DPDB_HOT: win32more.Windows.Win32.UI.Controls.DATEBORDERSTATES = 2
DPDB_FOCUSED: win32more.Windows.Win32.UI.Controls.DATEBORDERSTATES = 3
DPDB_DISABLED: win32more.Windows.Win32.UI.Controls.DATEBORDERSTATES = 4
DATEPICKERPARTS = Int32
DP_DATETEXT: win32more.Windows.Win32.UI.Controls.DATEPICKERPARTS = 1
DP_DATEBORDER: win32more.Windows.Win32.UI.Controls.DATEPICKERPARTS = 2
DP_SHOWCALENDARBUTTONRIGHT: win32more.Windows.Win32.UI.Controls.DATEPICKERPARTS = 3
DATETEXTSTATES = Int32
DPDT_NORMAL: win32more.Windows.Win32.UI.Controls.DATETEXTSTATES = 1
DPDT_DISABLED: win32more.Windows.Win32.UI.Controls.DATETEXTSTATES = 2
DPDT_SELECTED: win32more.Windows.Win32.UI.Controls.DATETEXTSTATES = 3
class DATETIMEPICKERINFO(Structure):
    cbSize: UInt32
    rcCheck: win32more.Windows.Win32.Foundation.RECT
    stateCheck: UInt32
    rcButton: win32more.Windows.Win32.Foundation.RECT
    stateButton: UInt32
    hwndEdit: win32more.Windows.Win32.Foundation.HWND
    hwndUD: win32more.Windows.Win32.Foundation.HWND
    hwndDropDown: win32more.Windows.Win32.Foundation.HWND
class DELETEITEMSTRUCT(Structure):
    CtlType: win32more.Windows.Win32.UI.Controls.DRAWITEMSTRUCT_CTL_TYPE
    CtlID: UInt32
    itemID: UInt32
    hwndItem: win32more.Windows.Win32.Foundation.HWND
    itemData: UIntPtr
DLG_BUTTON_CHECK_STATE = UInt32
BST_CHECKED: win32more.Windows.Win32.UI.Controls.DLG_BUTTON_CHECK_STATE = 1
BST_INDETERMINATE: win32more.Windows.Win32.UI.Controls.DLG_BUTTON_CHECK_STATE = 2
BST_UNCHECKED: win32more.Windows.Win32.UI.Controls.DLG_BUTTON_CHECK_STATE = 0
DLG_DIR_LIST_FILE_TYPE = UInt32
DDL_ARCHIVE: win32more.Windows.Win32.UI.Controls.DLG_DIR_LIST_FILE_TYPE = 32
DDL_DIRECTORY: win32more.Windows.Win32.UI.Controls.DLG_DIR_LIST_FILE_TYPE = 16
DDL_DRIVES: win32more.Windows.Win32.UI.Controls.DLG_DIR_LIST_FILE_TYPE = 16384
DDL_EXCLUSIVE: win32more.Windows.Win32.UI.Controls.DLG_DIR_LIST_FILE_TYPE = 32768
DDL_HIDDEN: win32more.Windows.Win32.UI.Controls.DLG_DIR_LIST_FILE_TYPE = 2
DDL_READONLY: win32more.Windows.Win32.UI.Controls.DLG_DIR_LIST_FILE_TYPE = 1
DDL_READWRITE: win32more.Windows.Win32.UI.Controls.DLG_DIR_LIST_FILE_TYPE = 0
DDL_SYSTEM: win32more.Windows.Win32.UI.Controls.DLG_DIR_LIST_FILE_TYPE = 4
DDL_POSTMSGS: win32more.Windows.Win32.UI.Controls.DLG_DIR_LIST_FILE_TYPE = 8192
DOWNHORZSTATES = Int32
DNHZS_NORMAL: win32more.Windows.Win32.UI.Controls.DOWNHORZSTATES = 1
DNHZS_HOT: win32more.Windows.Win32.UI.Controls.DOWNHORZSTATES = 2
DNHZS_PRESSED: win32more.Windows.Win32.UI.Controls.DOWNHORZSTATES = 3
DNHZS_DISABLED: win32more.Windows.Win32.UI.Controls.DOWNHORZSTATES = 4
DOWNSTATES = Int32
DNS_NORMAL: win32more.Windows.Win32.UI.Controls.DOWNSTATES = 1
DNS_HOT: win32more.Windows.Win32.UI.Controls.DOWNSTATES = 2
DNS_PRESSED: win32more.Windows.Win32.UI.Controls.DOWNSTATES = 3
DNS_DISABLED: win32more.Windows.Win32.UI.Controls.DOWNSTATES = 4
DPAMM_MESSAGE = UInt32
DPAMM_MERGE: win32more.Windows.Win32.UI.Controls.DPAMM_MESSAGE = 1
DPAMM_DELETE: win32more.Windows.Win32.UI.Controls.DPAMM_MESSAGE = 2
DPAMM_INSERT: win32more.Windows.Win32.UI.Controls.DPAMM_MESSAGE = 3
class DPASTREAMINFO(Structure):
    iPos: Int32
    pvItem: VoidPtr
DRAGDROPPARTS = Int32
DD_COPY: win32more.Windows.Win32.UI.Controls.DRAGDROPPARTS = 1
DD_MOVE: win32more.Windows.Win32.UI.Controls.DRAGDROPPARTS = 2
DD_UPDATEMETADATA: win32more.Windows.Win32.UI.Controls.DRAGDROPPARTS = 3
DD_CREATELINK: win32more.Windows.Win32.UI.Controls.DRAGDROPPARTS = 4
DD_WARNING: win32more.Windows.Win32.UI.Controls.DRAGDROPPARTS = 5
DD_NONE: win32more.Windows.Win32.UI.Controls.DRAGDROPPARTS = 6
DD_IMAGEBG: win32more.Windows.Win32.UI.Controls.DRAGDROPPARTS = 7
DD_TEXTBG: win32more.Windows.Win32.UI.Controls.DRAGDROPPARTS = 8
class DRAGLISTINFO(Structure):
    uNotification: win32more.Windows.Win32.UI.Controls.DRAGLISTINFO_NOTIFICATION_FLAGS
    hWnd: win32more.Windows.Win32.Foundation.HWND
    ptCursor: win32more.Windows.Win32.Foundation.POINT
DRAGLISTINFO_NOTIFICATION_FLAGS = UInt32
DL_BEGINDRAG: win32more.Windows.Win32.UI.Controls.DRAGLISTINFO_NOTIFICATION_FLAGS = 1157
DL_CANCELDRAG: win32more.Windows.Win32.UI.Controls.DRAGLISTINFO_NOTIFICATION_FLAGS = 1160
DL_DRAGGING: win32more.Windows.Win32.UI.Controls.DRAGLISTINFO_NOTIFICATION_FLAGS = 1158
DL_DROPPED: win32more.Windows.Win32.UI.Controls.DRAGLISTINFO_NOTIFICATION_FLAGS = 1159
class DRAWITEMSTRUCT(Structure):
    CtlType: win32more.Windows.Win32.UI.Controls.DRAWITEMSTRUCT_CTL_TYPE
    CtlID: UInt32
    itemID: UInt32
    itemAction: win32more.Windows.Win32.UI.Controls.ODA_FLAGS
    itemState: win32more.Windows.Win32.UI.Controls.ODS_FLAGS
    hwndItem: win32more.Windows.Win32.Foundation.HWND
    hDC: win32more.Windows.Win32.Graphics.Gdi.HDC
    rcItem: win32more.Windows.Win32.Foundation.RECT
    itemData: UIntPtr
DRAWITEMSTRUCT_CTL_TYPE = UInt32
ODT_BUTTON: win32more.Windows.Win32.UI.Controls.DRAWITEMSTRUCT_CTL_TYPE = 4
ODT_COMBOBOX: win32more.Windows.Win32.UI.Controls.DRAWITEMSTRUCT_CTL_TYPE = 3
ODT_LISTBOX: win32more.Windows.Win32.UI.Controls.DRAWITEMSTRUCT_CTL_TYPE = 2
ODT_LISTVIEW: win32more.Windows.Win32.UI.Controls.DRAWITEMSTRUCT_CTL_TYPE = 102
ODT_MENU: win32more.Windows.Win32.UI.Controls.DRAWITEMSTRUCT_CTL_TYPE = 1
ODT_STATIC: win32more.Windows.Win32.UI.Controls.DRAWITEMSTRUCT_CTL_TYPE = 5
ODT_TAB: win32more.Windows.Win32.UI.Controls.DRAWITEMSTRUCT_CTL_TYPE = 101
DRAW_THEME_PARENT_BACKGROUND_FLAGS = UInt32
DTPB_WINDOWDC: win32more.Windows.Win32.UI.Controls.DRAW_THEME_PARENT_BACKGROUND_FLAGS = 1
DTPB_USECTLCOLORSTATIC: win32more.Windows.Win32.UI.Controls.DRAW_THEME_PARENT_BACKGROUND_FLAGS = 2
DTPB_USEERASEBKGND: win32more.Windows.Win32.UI.Controls.DRAW_THEME_PARENT_BACKGROUND_FLAGS = 4
DROPDOWNBUTTONLEFTSTATES = Int32
CBXSL_NORMAL: win32more.Windows.Win32.UI.Controls.DROPDOWNBUTTONLEFTSTATES = 1
CBXSL_HOT: win32more.Windows.Win32.UI.Controls.DROPDOWNBUTTONLEFTSTATES = 2
CBXSL_PRESSED: win32more.Windows.Win32.UI.Controls.DROPDOWNBUTTONLEFTSTATES = 3
CBXSL_DISABLED: win32more.Windows.Win32.UI.Controls.DROPDOWNBUTTONLEFTSTATES = 4
DROPDOWNBUTTONRIGHTSTATES = Int32
CBXSR_NORMAL: win32more.Windows.Win32.UI.Controls.DROPDOWNBUTTONRIGHTSTATES = 1
CBXSR_HOT: win32more.Windows.Win32.UI.Controls.DROPDOWNBUTTONRIGHTSTATES = 2
CBXSR_PRESSED: win32more.Windows.Win32.UI.Controls.DROPDOWNBUTTONRIGHTSTATES = 3
CBXSR_DISABLED: win32more.Windows.Win32.UI.Controls.DROPDOWNBUTTONRIGHTSTATES = 4
DROPDOWNITEMSTATES = Int32
CBDI_NORMAL: win32more.Windows.Win32.UI.Controls.DROPDOWNITEMSTATES = 1
CBDI_HIGHLIGHTED: win32more.Windows.Win32.UI.Controls.DROPDOWNITEMSTATES = 2
class DTBGOPTS(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    rcClip: win32more.Windows.Win32.Foundation.RECT
class DTTOPTS(Structure):
    dwSize: UInt32
    dwFlags: win32more.Windows.Win32.UI.Controls.DTTOPTS_FLAGS
    crText: win32more.Windows.Win32.Foundation.COLORREF
    crBorder: win32more.Windows.Win32.Foundation.COLORREF
    crShadow: win32more.Windows.Win32.Foundation.COLORREF
    iTextShadowType: Int32
    ptShadowOffset: win32more.Windows.Win32.Foundation.POINT
    iBorderSize: Int32
    iFontPropId: Int32
    iColorPropId: Int32
    iStateId: Int32
    fApplyOverlay: win32more.Windows.Win32.Foundation.BOOL
    iGlowSize: Int32
    pfnDrawTextCallback: win32more.Windows.Win32.UI.Controls.DTT_CALLBACK_PROC
    lParam: win32more.Windows.Win32.Foundation.LPARAM
DTTOPTS_FLAGS = UInt32
DTT_TEXTCOLOR: win32more.Windows.Win32.UI.Controls.DTTOPTS_FLAGS = 1
DTT_BORDERCOLOR: win32more.Windows.Win32.UI.Controls.DTTOPTS_FLAGS = 2
DTT_SHADOWCOLOR: win32more.Windows.Win32.UI.Controls.DTTOPTS_FLAGS = 4
DTT_SHADOWTYPE: win32more.Windows.Win32.UI.Controls.DTTOPTS_FLAGS = 8
DTT_SHADOWOFFSET: win32more.Windows.Win32.UI.Controls.DTTOPTS_FLAGS = 16
DTT_BORDERSIZE: win32more.Windows.Win32.UI.Controls.DTTOPTS_FLAGS = 32
DTT_FONTPROP: win32more.Windows.Win32.UI.Controls.DTTOPTS_FLAGS = 64
DTT_COLORPROP: win32more.Windows.Win32.UI.Controls.DTTOPTS_FLAGS = 128
DTT_STATEID: win32more.Windows.Win32.UI.Controls.DTTOPTS_FLAGS = 256
DTT_CALCRECT: win32more.Windows.Win32.UI.Controls.DTTOPTS_FLAGS = 512
DTT_APPLYOVERLAY: win32more.Windows.Win32.UI.Controls.DTTOPTS_FLAGS = 1024
DTT_GLOWSIZE: win32more.Windows.Win32.UI.Controls.DTTOPTS_FLAGS = 2048
DTT_CALLBACK: win32more.Windows.Win32.UI.Controls.DTTOPTS_FLAGS = 4096
DTT_COMPOSITED: win32more.Windows.Win32.UI.Controls.DTTOPTS_FLAGS = 8192
DTT_VALIDBITS: win32more.Windows.Win32.UI.Controls.DTTOPTS_FLAGS = 12287
@winfunctype_pointer
def DTT_CALLBACK_PROC(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, pszText: win32more.Windows.Win32.Foundation.PWSTR, cchText: Int32, prc: POINTER(win32more.Windows.Win32.Foundation.RECT), dwFlags: UInt32, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
EC_ENDOFLINE = Int32
EC_ENDOFLINE_DETECTFROMCONTENT: win32more.Windows.Win32.UI.Controls.EC_ENDOFLINE = 0
EC_ENDOFLINE_CRLF: win32more.Windows.Win32.UI.Controls.EC_ENDOFLINE = 1
EC_ENDOFLINE_CR: win32more.Windows.Win32.UI.Controls.EC_ENDOFLINE = 2
EC_ENDOFLINE_LF: win32more.Windows.Win32.UI.Controls.EC_ENDOFLINE = 3
EC_SEARCHWEB_ENTRYPOINT = Int32
EC_SEARCHWEB_ENTRYPOINT_EXTERNAL: win32more.Windows.Win32.UI.Controls.EC_SEARCHWEB_ENTRYPOINT = 0
EC_SEARCHWEB_ENTRYPOINT_CONTEXTMENU: win32more.Windows.Win32.UI.Controls.EC_SEARCHWEB_ENTRYPOINT = 1
class EDITBALLOONTIP(Structure):
    cbStruct: UInt32
    pszTitle: win32more.Windows.Win32.Foundation.PWSTR
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    ttiIcon: win32more.Windows.Win32.UI.Controls.EDITBALLOONTIP_ICON
EDITBALLOONTIP_ICON = Int32
TTI_ERROR: win32more.Windows.Win32.UI.Controls.EDITBALLOONTIP_ICON = 3
TTI_INFO: win32more.Windows.Win32.UI.Controls.EDITBALLOONTIP_ICON = 1
TTI_NONE: win32more.Windows.Win32.UI.Controls.EDITBALLOONTIP_ICON = 0
TTI_WARNING: win32more.Windows.Win32.UI.Controls.EDITBALLOONTIP_ICON = 2
TTI_INFO_LARGE: win32more.Windows.Win32.UI.Controls.EDITBALLOONTIP_ICON = 4
TTI_WARNING_LARGE: win32more.Windows.Win32.UI.Controls.EDITBALLOONTIP_ICON = 5
TTI_ERROR_LARGE: win32more.Windows.Win32.UI.Controls.EDITBALLOONTIP_ICON = 6
EDITBORDER_HSCROLLSTATES = Int32
EPSH_NORMAL: win32more.Windows.Win32.UI.Controls.EDITBORDER_HSCROLLSTATES = 1
EPSH_HOT: win32more.Windows.Win32.UI.Controls.EDITBORDER_HSCROLLSTATES = 2
EPSH_FOCUSED: win32more.Windows.Win32.UI.Controls.EDITBORDER_HSCROLLSTATES = 3
EPSH_DISABLED: win32more.Windows.Win32.UI.Controls.EDITBORDER_HSCROLLSTATES = 4
EDITBORDER_HVSCROLLSTATES = Int32
EPSHV_NORMAL: win32more.Windows.Win32.UI.Controls.EDITBORDER_HVSCROLLSTATES = 1
EPSHV_HOT: win32more.Windows.Win32.UI.Controls.EDITBORDER_HVSCROLLSTATES = 2
EPSHV_FOCUSED: win32more.Windows.Win32.UI.Controls.EDITBORDER_HVSCROLLSTATES = 3
EPSHV_DISABLED: win32more.Windows.Win32.UI.Controls.EDITBORDER_HVSCROLLSTATES = 4
EDITBORDER_NOSCROLLSTATES = Int32
EPSN_NORMAL: win32more.Windows.Win32.UI.Controls.EDITBORDER_NOSCROLLSTATES = 1
EPSN_HOT: win32more.Windows.Win32.UI.Controls.EDITBORDER_NOSCROLLSTATES = 2
EPSN_FOCUSED: win32more.Windows.Win32.UI.Controls.EDITBORDER_NOSCROLLSTATES = 3
EPSN_DISABLED: win32more.Windows.Win32.UI.Controls.EDITBORDER_NOSCROLLSTATES = 4
EDITBORDER_VSCROLLSTATES = Int32
EPSV_NORMAL: win32more.Windows.Win32.UI.Controls.EDITBORDER_VSCROLLSTATES = 1
EPSV_HOT: win32more.Windows.Win32.UI.Controls.EDITBORDER_VSCROLLSTATES = 2
EPSV_FOCUSED: win32more.Windows.Win32.UI.Controls.EDITBORDER_VSCROLLSTATES = 3
EPSV_DISABLED: win32more.Windows.Win32.UI.Controls.EDITBORDER_VSCROLLSTATES = 4
EDITPARTS = Int32
EP_EDITTEXT: win32more.Windows.Win32.UI.Controls.EDITPARTS = 1
EP_CARET: win32more.Windows.Win32.UI.Controls.EDITPARTS = 2
EP_BACKGROUND: win32more.Windows.Win32.UI.Controls.EDITPARTS = 3
EP_PASSWORD: win32more.Windows.Win32.UI.Controls.EDITPARTS = 4
EP_BACKGROUNDWITHBORDER: win32more.Windows.Win32.UI.Controls.EDITPARTS = 5
EP_EDITBORDER_NOSCROLL: win32more.Windows.Win32.UI.Controls.EDITPARTS = 6
EP_EDITBORDER_HSCROLL: win32more.Windows.Win32.UI.Controls.EDITPARTS = 7
EP_EDITBORDER_VSCROLL: win32more.Windows.Win32.UI.Controls.EDITPARTS = 8
EP_EDITBORDER_HVSCROLL: win32more.Windows.Win32.UI.Controls.EDITPARTS = 9
EDITTEXTSTATES = Int32
ETS_NORMAL: win32more.Windows.Win32.UI.Controls.EDITTEXTSTATES = 1
ETS_HOT: win32more.Windows.Win32.UI.Controls.EDITTEXTSTATES = 2
ETS_SELECTED: win32more.Windows.Win32.UI.Controls.EDITTEXTSTATES = 3
ETS_DISABLED: win32more.Windows.Win32.UI.Controls.EDITTEXTSTATES = 4
ETS_FOCUSED: win32more.Windows.Win32.UI.Controls.EDITTEXTSTATES = 5
ETS_READONLY: win32more.Windows.Win32.UI.Controls.EDITTEXTSTATES = 6
ETS_ASSIST: win32more.Windows.Win32.UI.Controls.EDITTEXTSTATES = 7
ETS_CUEBANNER: win32more.Windows.Win32.UI.Controls.EDITTEXTSTATES = 8
@winfunctype_pointer
def EDITWORDBREAKPROCA(lpch: win32more.Windows.Win32.Foundation.PSTR, ichCurrent: Int32, cch: Int32, code: win32more.Windows.Win32.UI.Controls.WORD_BREAK_ACTION) -> Int32: ...
@winfunctype_pointer
def EDITWORDBREAKPROCW(lpch: win32more.Windows.Win32.Foundation.PWSTR, ichCurrent: Int32, cch: Int32, code: win32more.Windows.Win32.UI.Controls.WORD_BREAK_ACTION) -> Int32: ...
EDITWORDBREAKPROC = UnicodeAlias('EDITWORDBREAKPROCW')
EMPTYMARKUPPARTS = Int32
EMP_MARKUPTEXT: win32more.Windows.Win32.UI.Controls.EMPTYMARKUPPARTS = 1
ENABLE_SCROLL_BAR_ARROWS = UInt32
ESB_DISABLE_BOTH: win32more.Windows.Win32.UI.Controls.ENABLE_SCROLL_BAR_ARROWS = 3
ESB_DISABLE_DOWN: win32more.Windows.Win32.UI.Controls.ENABLE_SCROLL_BAR_ARROWS = 2
ESB_DISABLE_LEFT: win32more.Windows.Win32.UI.Controls.ENABLE_SCROLL_BAR_ARROWS = 1
ESB_DISABLE_LTUP: win32more.Windows.Win32.UI.Controls.ENABLE_SCROLL_BAR_ARROWS = 1
ESB_DISABLE_RIGHT: win32more.Windows.Win32.UI.Controls.ENABLE_SCROLL_BAR_ARROWS = 2
ESB_DISABLE_RTDN: win32more.Windows.Win32.UI.Controls.ENABLE_SCROLL_BAR_ARROWS = 2
ESB_DISABLE_UP: win32more.Windows.Win32.UI.Controls.ENABLE_SCROLL_BAR_ARROWS = 1
ESB_ENABLE_BOTH: win32more.Windows.Win32.UI.Controls.ENABLE_SCROLL_BAR_ARROWS = 0
EXPANDBUTTONSTATES = Int32
LVEB_NORMAL: win32more.Windows.Win32.UI.Controls.EXPANDBUTTONSTATES = 1
LVEB_HOVER: win32more.Windows.Win32.UI.Controls.EXPANDBUTTONSTATES = 2
LVEB_PUSHED: win32more.Windows.Win32.UI.Controls.EXPANDBUTTONSTATES = 3
EXPANDOBUTTONSTATES = Int32
TDLGEBS_NORMAL: win32more.Windows.Win32.UI.Controls.EXPANDOBUTTONSTATES = 1
TDLGEBS_HOVER: win32more.Windows.Win32.UI.Controls.EXPANDOBUTTONSTATES = 2
TDLGEBS_PRESSED: win32more.Windows.Win32.UI.Controls.EXPANDOBUTTONSTATES = 3
TDLGEBS_EXPANDEDNORMAL: win32more.Windows.Win32.UI.Controls.EXPANDOBUTTONSTATES = 4
TDLGEBS_EXPANDEDHOVER: win32more.Windows.Win32.UI.Controls.EXPANDOBUTTONSTATES = 5
TDLGEBS_EXPANDEDPRESSED: win32more.Windows.Win32.UI.Controls.EXPANDOBUTTONSTATES = 6
TDLGEBS_NORMALDISABLED: win32more.Windows.Win32.UI.Controls.EXPANDOBUTTONSTATES = 7
TDLGEBS_EXPANDEDDISABLED: win32more.Windows.Win32.UI.Controls.EXPANDOBUTTONSTATES = 8
EXPLORERBARPARTS = Int32
EBP_HEADERBACKGROUND: win32more.Windows.Win32.UI.Controls.EXPLORERBARPARTS = 1
EBP_HEADERCLOSE: win32more.Windows.Win32.UI.Controls.EXPLORERBARPARTS = 2
EBP_HEADERPIN: win32more.Windows.Win32.UI.Controls.EXPLORERBARPARTS = 3
EBP_IEBARMENU: win32more.Windows.Win32.UI.Controls.EXPLORERBARPARTS = 4
EBP_NORMALGROUPBACKGROUND: win32more.Windows.Win32.UI.Controls.EXPLORERBARPARTS = 5
EBP_NORMALGROUPCOLLAPSE: win32more.Windows.Win32.UI.Controls.EXPLORERBARPARTS = 6
EBP_NORMALGROUPEXPAND: win32more.Windows.Win32.UI.Controls.EXPLORERBARPARTS = 7
EBP_NORMALGROUPHEAD: win32more.Windows.Win32.UI.Controls.EXPLORERBARPARTS = 8
EBP_SPECIALGROUPBACKGROUND: win32more.Windows.Win32.UI.Controls.EXPLORERBARPARTS = 9
EBP_SPECIALGROUPCOLLAPSE: win32more.Windows.Win32.UI.Controls.EXPLORERBARPARTS = 10
EBP_SPECIALGROUPEXPAND: win32more.Windows.Win32.UI.Controls.EXPLORERBARPARTS = 11
EBP_SPECIALGROUPHEAD: win32more.Windows.Win32.UI.Controls.EXPLORERBARPARTS = 12
FEEDBACK_TYPE = Int32
FEEDBACK_TOUCH_CONTACTVISUALIZATION: win32more.Windows.Win32.UI.Controls.FEEDBACK_TYPE = 1
FEEDBACK_PEN_BARRELVISUALIZATION: win32more.Windows.Win32.UI.Controls.FEEDBACK_TYPE = 2
FEEDBACK_PEN_TAP: win32more.Windows.Win32.UI.Controls.FEEDBACK_TYPE = 3
FEEDBACK_PEN_DOUBLETAP: win32more.Windows.Win32.UI.Controls.FEEDBACK_TYPE = 4
FEEDBACK_PEN_PRESSANDHOLD: win32more.Windows.Win32.UI.Controls.FEEDBACK_TYPE = 5
FEEDBACK_PEN_RIGHTTAP: win32more.Windows.Win32.UI.Controls.FEEDBACK_TYPE = 6
FEEDBACK_TOUCH_TAP: win32more.Windows.Win32.UI.Controls.FEEDBACK_TYPE = 7
FEEDBACK_TOUCH_DOUBLETAP: win32more.Windows.Win32.UI.Controls.FEEDBACK_TYPE = 8
FEEDBACK_TOUCH_PRESSANDHOLD: win32more.Windows.Win32.UI.Controls.FEEDBACK_TYPE = 9
FEEDBACK_TOUCH_RIGHTTAP: win32more.Windows.Win32.UI.Controls.FEEDBACK_TYPE = 10
FEEDBACK_GESTURE_PRESSANDTAP: win32more.Windows.Win32.UI.Controls.FEEDBACK_TYPE = 11
FEEDBACK_MAX: win32more.Windows.Win32.UI.Controls.FEEDBACK_TYPE = -1
FILLSTATES = Int32
PBFS_NORMAL: win32more.Windows.Win32.UI.Controls.FILLSTATES = 1
PBFS_ERROR: win32more.Windows.Win32.UI.Controls.FILLSTATES = 2
PBFS_PAUSED: win32more.Windows.Win32.UI.Controls.FILLSTATES = 3
PBFS_PARTIAL: win32more.Windows.Win32.UI.Controls.FILLSTATES = 4
FILLTYPE = Int32
FT_SOLID: win32more.Windows.Win32.UI.Controls.FILLTYPE = 0
FT_VERTGRADIENT: win32more.Windows.Win32.UI.Controls.FILLTYPE = 1
FT_HORZGRADIENT: win32more.Windows.Win32.UI.Controls.FILLTYPE = 2
FT_RADIALGRADIENT: win32more.Windows.Win32.UI.Controls.FILLTYPE = 3
FT_TILEIMAGE: win32more.Windows.Win32.UI.Controls.FILLTYPE = 4
FILLVERTSTATES = Int32
PBFVS_NORMAL: win32more.Windows.Win32.UI.Controls.FILLVERTSTATES = 1
PBFVS_ERROR: win32more.Windows.Win32.UI.Controls.FILLVERTSTATES = 2
PBFVS_PAUSED: win32more.Windows.Win32.UI.Controls.FILLVERTSTATES = 3
PBFVS_PARTIAL: win32more.Windows.Win32.UI.Controls.FILLVERTSTATES = 4
FLYOUTPARTS = Int32
FLYOUT_HEADER: win32more.Windows.Win32.UI.Controls.FLYOUTPARTS = 1
FLYOUT_BODY: win32more.Windows.Win32.UI.Controls.FLYOUTPARTS = 2
FLYOUT_LABEL: win32more.Windows.Win32.UI.Controls.FLYOUTPARTS = 3
FLYOUT_LINK: win32more.Windows.Win32.UI.Controls.FLYOUTPARTS = 4
FLYOUT_DIVIDER: win32more.Windows.Win32.UI.Controls.FLYOUTPARTS = 5
FLYOUT_WINDOW: win32more.Windows.Win32.UI.Controls.FLYOUTPARTS = 6
FLYOUT_LINKAREA: win32more.Windows.Win32.UI.Controls.FLYOUTPARTS = 7
FLYOUT_LINKHEADER: win32more.Windows.Win32.UI.Controls.FLYOUTPARTS = 8
FRAMEBOTTOMSTATES = Int32
FRB_ACTIVE: win32more.Windows.Win32.UI.Controls.FRAMEBOTTOMSTATES = 1
FRB_INACTIVE: win32more.Windows.Win32.UI.Controls.FRAMEBOTTOMSTATES = 2
FRAMELEFTSTATES = Int32
FRL_ACTIVE: win32more.Windows.Win32.UI.Controls.FRAMELEFTSTATES = 1
FRL_INACTIVE: win32more.Windows.Win32.UI.Controls.FRAMELEFTSTATES = 2
FRAMERIGHTSTATES = Int32
FRR_ACTIVE: win32more.Windows.Win32.UI.Controls.FRAMERIGHTSTATES = 1
FRR_INACTIVE: win32more.Windows.Win32.UI.Controls.FRAMERIGHTSTATES = 2
FRAMESTATES = Int32
FS_ACTIVE: win32more.Windows.Win32.UI.Controls.FRAMESTATES = 1
FS_INACTIVE: win32more.Windows.Win32.UI.Controls.FRAMESTATES = 2
GET_THEME_BITMAP_FLAGS = UInt32
GBF_DIRECT: win32more.Windows.Win32.UI.Controls.GET_THEME_BITMAP_FLAGS = 1
GBF_COPY: win32more.Windows.Win32.UI.Controls.GET_THEME_BITMAP_FLAGS = 2
GBF_VALIDBITS: win32more.Windows.Win32.UI.Controls.GET_THEME_BITMAP_FLAGS = 3
GLYPHFONTSIZINGTYPE = Int32
GFST_NONE: win32more.Windows.Win32.UI.Controls.GLYPHFONTSIZINGTYPE = 0
GFST_SIZE: win32more.Windows.Win32.UI.Controls.GLYPHFONTSIZINGTYPE = 1
GFST_DPI: win32more.Windows.Win32.UI.Controls.GLYPHFONTSIZINGTYPE = 2
GLYPHSTATES = Int32
GLPS_CLOSED: win32more.Windows.Win32.UI.Controls.GLYPHSTATES = 1
GLPS_OPENED: win32more.Windows.Win32.UI.Controls.GLYPHSTATES = 2
GLYPHTYPE = Int32
GT_NONE: win32more.Windows.Win32.UI.Controls.GLYPHTYPE = 0
GT_IMAGEGLYPH: win32more.Windows.Win32.UI.Controls.GLYPHTYPE = 1
GT_FONTGLYPH: win32more.Windows.Win32.UI.Controls.GLYPHTYPE = 2
GRIDCELLBACKGROUNDSTATES = Int32
MCGCB_SELECTED: win32more.Windows.Win32.UI.Controls.GRIDCELLBACKGROUNDSTATES = 1
MCGCB_HOT: win32more.Windows.Win32.UI.Controls.GRIDCELLBACKGROUNDSTATES = 2
MCGCB_SELECTEDHOT: win32more.Windows.Win32.UI.Controls.GRIDCELLBACKGROUNDSTATES = 3
MCGCB_SELECTEDNOTFOCUSED: win32more.Windows.Win32.UI.Controls.GRIDCELLBACKGROUNDSTATES = 4
MCGCB_TODAY: win32more.Windows.Win32.UI.Controls.GRIDCELLBACKGROUNDSTATES = 5
MCGCB_TODAYSELECTED: win32more.Windows.Win32.UI.Controls.GRIDCELLBACKGROUNDSTATES = 6
GRIDCELLSTATES = Int32
MCGC_HOT: win32more.Windows.Win32.UI.Controls.GRIDCELLSTATES = 1
MCGC_HASSTATE: win32more.Windows.Win32.UI.Controls.GRIDCELLSTATES = 2
MCGC_HASSTATEHOT: win32more.Windows.Win32.UI.Controls.GRIDCELLSTATES = 3
MCGC_TODAY: win32more.Windows.Win32.UI.Controls.GRIDCELLSTATES = 4
MCGC_TODAYSELECTED: win32more.Windows.Win32.UI.Controls.GRIDCELLSTATES = 5
MCGC_SELECTED: win32more.Windows.Win32.UI.Controls.GRIDCELLSTATES = 6
MCGC_SELECTEDHOT: win32more.Windows.Win32.UI.Controls.GRIDCELLSTATES = 7
GRIDCELLUPPERSTATES = Int32
MCGCU_HOT: win32more.Windows.Win32.UI.Controls.GRIDCELLUPPERSTATES = 1
MCGCU_HASSTATE: win32more.Windows.Win32.UI.Controls.GRIDCELLUPPERSTATES = 2
MCGCU_HASSTATEHOT: win32more.Windows.Win32.UI.Controls.GRIDCELLUPPERSTATES = 3
MCGCU_SELECTED: win32more.Windows.Win32.UI.Controls.GRIDCELLUPPERSTATES = 4
MCGCU_SELECTEDHOT: win32more.Windows.Win32.UI.Controls.GRIDCELLUPPERSTATES = 5
GRIPPERSTATES = Int32
TSGS_NORMAL: win32more.Windows.Win32.UI.Controls.GRIPPERSTATES = 1
TSGS_CENTERED: win32more.Windows.Win32.UI.Controls.GRIPPERSTATES = 2
GROUPBOXSTATES = Int32
GBS_NORMAL: win32more.Windows.Win32.UI.Controls.GROUPBOXSTATES = 1
GBS_DISABLED: win32more.Windows.Win32.UI.Controls.GROUPBOXSTATES = 2
GROUPHEADERLINESTATES = Int32
LVGHL_OPEN: win32more.Windows.Win32.UI.Controls.GROUPHEADERLINESTATES = 1
LVGHL_OPENHOT: win32more.Windows.Win32.UI.Controls.GROUPHEADERLINESTATES = 2
LVGHL_OPENSELECTED: win32more.Windows.Win32.UI.Controls.GROUPHEADERLINESTATES = 3
LVGHL_OPENSELECTEDHOT: win32more.Windows.Win32.UI.Controls.GROUPHEADERLINESTATES = 4
LVGHL_OPENSELECTEDNOTFOCUSED: win32more.Windows.Win32.UI.Controls.GROUPHEADERLINESTATES = 5
LVGHL_OPENSELECTEDNOTFOCUSEDHOT: win32more.Windows.Win32.UI.Controls.GROUPHEADERLINESTATES = 6
LVGHL_OPENMIXEDSELECTION: win32more.Windows.Win32.UI.Controls.GROUPHEADERLINESTATES = 7
LVGHL_OPENMIXEDSELECTIONHOT: win32more.Windows.Win32.UI.Controls.GROUPHEADERLINESTATES = 8
LVGHL_CLOSE: win32more.Windows.Win32.UI.Controls.GROUPHEADERLINESTATES = 9
LVGHL_CLOSEHOT: win32more.Windows.Win32.UI.Controls.GROUPHEADERLINESTATES = 10
LVGHL_CLOSESELECTED: win32more.Windows.Win32.UI.Controls.GROUPHEADERLINESTATES = 11
LVGHL_CLOSESELECTEDHOT: win32more.Windows.Win32.UI.Controls.GROUPHEADERLINESTATES = 12
LVGHL_CLOSESELECTEDNOTFOCUSED: win32more.Windows.Win32.UI.Controls.GROUPHEADERLINESTATES = 13
LVGHL_CLOSESELECTEDNOTFOCUSEDHOT: win32more.Windows.Win32.UI.Controls.GROUPHEADERLINESTATES = 14
LVGHL_CLOSEMIXEDSELECTION: win32more.Windows.Win32.UI.Controls.GROUPHEADERLINESTATES = 15
LVGHL_CLOSEMIXEDSELECTIONHOT: win32more.Windows.Win32.UI.Controls.GROUPHEADERLINESTATES = 16
GROUPHEADERSTATES = Int32
LVGH_OPEN: win32more.Windows.Win32.UI.Controls.GROUPHEADERSTATES = 1
LVGH_OPENHOT: win32more.Windows.Win32.UI.Controls.GROUPHEADERSTATES = 2
LVGH_OPENSELECTED: win32more.Windows.Win32.UI.Controls.GROUPHEADERSTATES = 3
LVGH_OPENSELECTEDHOT: win32more.Windows.Win32.UI.Controls.GROUPHEADERSTATES = 4
LVGH_OPENSELECTEDNOTFOCUSED: win32more.Windows.Win32.UI.Controls.GROUPHEADERSTATES = 5
LVGH_OPENSELECTEDNOTFOCUSEDHOT: win32more.Windows.Win32.UI.Controls.GROUPHEADERSTATES = 6
LVGH_OPENMIXEDSELECTION: win32more.Windows.Win32.UI.Controls.GROUPHEADERSTATES = 7
LVGH_OPENMIXEDSELECTIONHOT: win32more.Windows.Win32.UI.Controls.GROUPHEADERSTATES = 8
LVGH_CLOSE: win32more.Windows.Win32.UI.Controls.GROUPHEADERSTATES = 9
LVGH_CLOSEHOT: win32more.Windows.Win32.UI.Controls.GROUPHEADERSTATES = 10
LVGH_CLOSESELECTED: win32more.Windows.Win32.UI.Controls.GROUPHEADERSTATES = 11
LVGH_CLOSESELECTEDHOT: win32more.Windows.Win32.UI.Controls.GROUPHEADERSTATES = 12
LVGH_CLOSESELECTEDNOTFOCUSED: win32more.Windows.Win32.UI.Controls.GROUPHEADERSTATES = 13
LVGH_CLOSESELECTEDNOTFOCUSEDHOT: win32more.Windows.Win32.UI.Controls.GROUPHEADERSTATES = 14
LVGH_CLOSEMIXEDSELECTION: win32more.Windows.Win32.UI.Controls.GROUPHEADERSTATES = 15
LVGH_CLOSEMIXEDSELECTIONHOT: win32more.Windows.Win32.UI.Controls.GROUPHEADERSTATES = 16
HALIGN = Int32
HA_LEFT: win32more.Windows.Win32.UI.Controls.HALIGN = 0
HA_CENTER: win32more.Windows.Win32.UI.Controls.HALIGN = 1
HA_RIGHT: win32more.Windows.Win32.UI.Controls.HALIGN = 2
class HDHITTESTINFO(Structure):
    pt: win32more.Windows.Win32.Foundation.POINT
    flags: win32more.Windows.Win32.UI.Controls.HEADER_HITTEST_INFO_FLAGS
    iItem: Int32
class HDITEMA(Structure):
    mask: win32more.Windows.Win32.UI.Controls.HDI_MASK
    cxy: Int32
    pszText: win32more.Windows.Win32.Foundation.PSTR
    hbm: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
    cchTextMax: Int32
    fmt: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    iImage: Int32
    iOrder: Int32
    type: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_TYPE
    pvFilter: VoidPtr
    state: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_STATE
class HDITEMW(Structure):
    mask: win32more.Windows.Win32.UI.Controls.HDI_MASK
    cxy: Int32
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    hbm: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
    cchTextMax: Int32
    fmt: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    iImage: Int32
    iOrder: Int32
    type: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_TYPE
    pvFilter: VoidPtr
    state: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_STATE
HDITEM = UnicodeAlias('HDITEMW')
HDI_MASK = UInt32
HDI_WIDTH: win32more.Windows.Win32.UI.Controls.HDI_MASK = 1
HDI_HEIGHT: win32more.Windows.Win32.UI.Controls.HDI_MASK = 1
HDI_TEXT: win32more.Windows.Win32.UI.Controls.HDI_MASK = 2
HDI_FORMAT: win32more.Windows.Win32.UI.Controls.HDI_MASK = 4
HDI_LPARAM: win32more.Windows.Win32.UI.Controls.HDI_MASK = 8
HDI_BITMAP: win32more.Windows.Win32.UI.Controls.HDI_MASK = 16
HDI_IMAGE: win32more.Windows.Win32.UI.Controls.HDI_MASK = 32
HDI_DI_SETITEM: win32more.Windows.Win32.UI.Controls.HDI_MASK = 64
HDI_ORDER: win32more.Windows.Win32.UI.Controls.HDI_MASK = 128
HDI_FILTER: win32more.Windows.Win32.UI.Controls.HDI_MASK = 256
HDI_STATE: win32more.Windows.Win32.UI.Controls.HDI_MASK = 512
class HDLAYOUT(Structure):
    prc: POINTER(win32more.Windows.Win32.Foundation.RECT)
    pwpos: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOWPOS)
HDPA = IntPtr
HDSA = IntPtr
class HD_TEXTFILTERA(Structure):
    pszText: win32more.Windows.Win32.Foundation.PSTR
    cchTextMax: Int32
class HD_TEXTFILTERW(Structure):
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    cchTextMax: Int32
HD_TEXTFILTER = UnicodeAlias('HD_TEXTFILTERW')
HEADERAREASTATES = Int32
AW_S_HEADERAREA_NOMARGIN: win32more.Windows.Win32.UI.Controls.HEADERAREASTATES = 1
HEADERCLOSESTATES = Int32
EBHC_NORMAL: win32more.Windows.Win32.UI.Controls.HEADERCLOSESTATES = 1
EBHC_HOT: win32more.Windows.Win32.UI.Controls.HEADERCLOSESTATES = 2
EBHC_PRESSED: win32more.Windows.Win32.UI.Controls.HEADERCLOSESTATES = 3
HEADERDROPDOWNFILTERSTATES = Int32
HDDFS_NORMAL: win32more.Windows.Win32.UI.Controls.HEADERDROPDOWNFILTERSTATES = 1
HDDFS_SOFTHOT: win32more.Windows.Win32.UI.Controls.HEADERDROPDOWNFILTERSTATES = 2
HDDFS_HOT: win32more.Windows.Win32.UI.Controls.HEADERDROPDOWNFILTERSTATES = 3
HEADERDROPDOWNSTATES = Int32
HDDS_NORMAL: win32more.Windows.Win32.UI.Controls.HEADERDROPDOWNSTATES = 1
HDDS_SOFTHOT: win32more.Windows.Win32.UI.Controls.HEADERDROPDOWNSTATES = 2
HDDS_HOT: win32more.Windows.Win32.UI.Controls.HEADERDROPDOWNSTATES = 3
HEADERITEMLEFTSTATES = Int32
HILS_NORMAL: win32more.Windows.Win32.UI.Controls.HEADERITEMLEFTSTATES = 1
HILS_HOT: win32more.Windows.Win32.UI.Controls.HEADERITEMLEFTSTATES = 2
HILS_PRESSED: win32more.Windows.Win32.UI.Controls.HEADERITEMLEFTSTATES = 3
HEADERITEMRIGHTSTATES = Int32
HIRS_NORMAL: win32more.Windows.Win32.UI.Controls.HEADERITEMRIGHTSTATES = 1
HIRS_HOT: win32more.Windows.Win32.UI.Controls.HEADERITEMRIGHTSTATES = 2
HIRS_PRESSED: win32more.Windows.Win32.UI.Controls.HEADERITEMRIGHTSTATES = 3
HEADERITEMSTATES = Int32
HIS_NORMAL: win32more.Windows.Win32.UI.Controls.HEADERITEMSTATES = 1
HIS_HOT: win32more.Windows.Win32.UI.Controls.HEADERITEMSTATES = 2
HIS_PRESSED: win32more.Windows.Win32.UI.Controls.HEADERITEMSTATES = 3
HIS_SORTEDNORMAL: win32more.Windows.Win32.UI.Controls.HEADERITEMSTATES = 4
HIS_SORTEDHOT: win32more.Windows.Win32.UI.Controls.HEADERITEMSTATES = 5
HIS_SORTEDPRESSED: win32more.Windows.Win32.UI.Controls.HEADERITEMSTATES = 6
HIS_ICONNORMAL: win32more.Windows.Win32.UI.Controls.HEADERITEMSTATES = 7
HIS_ICONHOT: win32more.Windows.Win32.UI.Controls.HEADERITEMSTATES = 8
HIS_ICONPRESSED: win32more.Windows.Win32.UI.Controls.HEADERITEMSTATES = 9
HIS_ICONSORTEDNORMAL: win32more.Windows.Win32.UI.Controls.HEADERITEMSTATES = 10
HIS_ICONSORTEDHOT: win32more.Windows.Win32.UI.Controls.HEADERITEMSTATES = 11
HIS_ICONSORTEDPRESSED: win32more.Windows.Win32.UI.Controls.HEADERITEMSTATES = 12
HEADEROVERFLOWSTATES = Int32
HOFS_NORMAL: win32more.Windows.Win32.UI.Controls.HEADEROVERFLOWSTATES = 1
HOFS_HOT: win32more.Windows.Win32.UI.Controls.HEADEROVERFLOWSTATES = 2
HEADERPARTS = Int32
HP_HEADERITEM: win32more.Windows.Win32.UI.Controls.HEADERPARTS = 1
HP_HEADERITEMLEFT: win32more.Windows.Win32.UI.Controls.HEADERPARTS = 2
HP_HEADERITEMRIGHT: win32more.Windows.Win32.UI.Controls.HEADERPARTS = 3
HP_HEADERSORTARROW: win32more.Windows.Win32.UI.Controls.HEADERPARTS = 4
HP_HEADERDROPDOWN: win32more.Windows.Win32.UI.Controls.HEADERPARTS = 5
HP_HEADERDROPDOWNFILTER: win32more.Windows.Win32.UI.Controls.HEADERPARTS = 6
HP_HEADEROVERFLOW: win32more.Windows.Win32.UI.Controls.HEADERPARTS = 7
HEADERPINSTATES = Int32
EBHP_NORMAL: win32more.Windows.Win32.UI.Controls.HEADERPINSTATES = 1
EBHP_HOT: win32more.Windows.Win32.UI.Controls.HEADERPINSTATES = 2
EBHP_PRESSED: win32more.Windows.Win32.UI.Controls.HEADERPINSTATES = 3
EBHP_SELECTEDNORMAL: win32more.Windows.Win32.UI.Controls.HEADERPINSTATES = 4
EBHP_SELECTEDHOT: win32more.Windows.Win32.UI.Controls.HEADERPINSTATES = 5
EBHP_SELECTEDPRESSED: win32more.Windows.Win32.UI.Controls.HEADERPINSTATES = 6
HEADERSORTARROWSTATES = Int32
HSAS_SORTEDUP: win32more.Windows.Win32.UI.Controls.HEADERSORTARROWSTATES = 1
HSAS_SORTEDDOWN: win32more.Windows.Win32.UI.Controls.HEADERSORTARROWSTATES = 2
HEADERSTYLESTATES = Int32
HBG_DETAILS: win32more.Windows.Win32.UI.Controls.HEADERSTYLESTATES = 1
HBG_ICON: win32more.Windows.Win32.UI.Controls.HEADERSTYLESTATES = 2
HEADER_CONTROL_FORMAT_FLAGS = Int32
HDF_LEFT: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS = 0
HDF_RIGHT: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS = 1
HDF_CENTER: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS = 2
HDF_JUSTIFYMASK: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS = 3
HDF_RTLREADING: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS = 4
HDF_BITMAP: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS = 8192
HDF_STRING: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS = 16384
HDF_OWNERDRAW: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS = 32768
HDF_IMAGE: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS = 2048
HDF_BITMAP_ON_RIGHT: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS = 4096
HDF_SORTUP: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS = 1024
HDF_SORTDOWN: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS = 512
HDF_CHECKBOX: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS = 64
HDF_CHECKED: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS = 128
HDF_FIXEDWIDTH: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS = 256
HDF_SPLITBUTTON: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_FLAGS = 16777216
HEADER_CONTROL_FORMAT_STATE = UInt32
HDIS_FOCUSED: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_STATE = 1
HEADER_CONTROL_FORMAT_TYPE = UInt32
HDFT_ISSTRING: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_TYPE = 0
HDFT_ISNUMBER: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_TYPE = 1
HDFT_ISDATE: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_TYPE = 2
HDFT_HASNOVALUE: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_FORMAT_TYPE = 32768
HEADER_CONTROL_NOTIFICATION_BUTTON = Int32
HEADER_CONTROL_NOTIFICATION_BUTTON_LEFT: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_NOTIFICATION_BUTTON = 0
HEADER_CONTROL_NOTIFICATION_BUTTON_RIGHT: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_NOTIFICATION_BUTTON = 1
HEADER_CONTROL_NOTIFICATION_BUTTON_MIDDLE: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_NOTIFICATION_BUTTON = 2
HEADER_HITTEST_INFO_FLAGS = UInt32
HHT_NOWHERE: win32more.Windows.Win32.UI.Controls.HEADER_HITTEST_INFO_FLAGS = 1
HHT_ONHEADER: win32more.Windows.Win32.UI.Controls.HEADER_HITTEST_INFO_FLAGS = 2
HHT_ONDIVIDER: win32more.Windows.Win32.UI.Controls.HEADER_HITTEST_INFO_FLAGS = 4
HHT_ONDIVOPEN: win32more.Windows.Win32.UI.Controls.HEADER_HITTEST_INFO_FLAGS = 8
HHT_ONFILTER: win32more.Windows.Win32.UI.Controls.HEADER_HITTEST_INFO_FLAGS = 16
HHT_ONFILTERBUTTON: win32more.Windows.Win32.UI.Controls.HEADER_HITTEST_INFO_FLAGS = 32
HHT_ABOVE: win32more.Windows.Win32.UI.Controls.HEADER_HITTEST_INFO_FLAGS = 256
HHT_BELOW: win32more.Windows.Win32.UI.Controls.HEADER_HITTEST_INFO_FLAGS = 512
HHT_TORIGHT: win32more.Windows.Win32.UI.Controls.HEADER_HITTEST_INFO_FLAGS = 1024
HHT_TOLEFT: win32more.Windows.Win32.UI.Controls.HEADER_HITTEST_INFO_FLAGS = 2048
HHT_ONITEMSTATEICON: win32more.Windows.Win32.UI.Controls.HEADER_HITTEST_INFO_FLAGS = 4096
HHT_ONDROPDOWN: win32more.Windows.Win32.UI.Controls.HEADER_HITTEST_INFO_FLAGS = 8192
HHT_ONOVERFLOW: win32more.Windows.Win32.UI.Controls.HEADER_HITTEST_INFO_FLAGS = 16384
HELPBUTTONSTATES = Int32
HBS_NORMAL: win32more.Windows.Win32.UI.Controls.HELPBUTTONSTATES = 1
HBS_HOT: win32more.Windows.Win32.UI.Controls.HELPBUTTONSTATES = 2
HBS_PUSHED: win32more.Windows.Win32.UI.Controls.HELPBUTTONSTATES = 3
HBS_DISABLED: win32more.Windows.Win32.UI.Controls.HELPBUTTONSTATES = 4
HELPLINKSTATES = Int32
CPHL_NORMAL: win32more.Windows.Win32.UI.Controls.HELPLINKSTATES = 1
CPHL_HOT: win32more.Windows.Win32.UI.Controls.HELPLINKSTATES = 2
CPHL_PRESSED: win32more.Windows.Win32.UI.Controls.HELPLINKSTATES = 3
CPHL_DISABLED: win32more.Windows.Win32.UI.Controls.HELPLINKSTATES = 4
HIMAGELIST = IntPtr
HIT_TEST_BACKGROUND_OPTIONS = UInt32
HTTB_BACKGROUNDSEG: win32more.Windows.Win32.UI.Controls.HIT_TEST_BACKGROUND_OPTIONS = 0
HTTB_FIXEDBORDER: win32more.Windows.Win32.UI.Controls.HIT_TEST_BACKGROUND_OPTIONS = 2
HTTB_CAPTION: win32more.Windows.Win32.UI.Controls.HIT_TEST_BACKGROUND_OPTIONS = 4
HTTB_RESIZINGBORDER_LEFT: win32more.Windows.Win32.UI.Controls.HIT_TEST_BACKGROUND_OPTIONS = 16
HTTB_RESIZINGBORDER_TOP: win32more.Windows.Win32.UI.Controls.HIT_TEST_BACKGROUND_OPTIONS = 32
HTTB_RESIZINGBORDER_RIGHT: win32more.Windows.Win32.UI.Controls.HIT_TEST_BACKGROUND_OPTIONS = 64
HTTB_RESIZINGBORDER_BOTTOM: win32more.Windows.Win32.UI.Controls.HIT_TEST_BACKGROUND_OPTIONS = 128
HTTB_RESIZINGBORDER: win32more.Windows.Win32.UI.Controls.HIT_TEST_BACKGROUND_OPTIONS = 240
HTTB_SIZINGTEMPLATE: win32more.Windows.Win32.UI.Controls.HIT_TEST_BACKGROUND_OPTIONS = 256
HTTB_SYSTEMSIZINGMARGINS: win32more.Windows.Win32.UI.Controls.HIT_TEST_BACKGROUND_OPTIONS = 512
HORZSCROLLSTATES = Int32
HSS_NORMAL: win32more.Windows.Win32.UI.Controls.HORZSCROLLSTATES = 1
HSS_HOT: win32more.Windows.Win32.UI.Controls.HORZSCROLLSTATES = 2
HSS_PUSHED: win32more.Windows.Win32.UI.Controls.HORZSCROLLSTATES = 3
HSS_DISABLED: win32more.Windows.Win32.UI.Controls.HORZSCROLLSTATES = 4
HORZTHUMBSTATES = Int32
HTS_NORMAL: win32more.Windows.Win32.UI.Controls.HORZTHUMBSTATES = 1
HTS_HOT: win32more.Windows.Win32.UI.Controls.HORZTHUMBSTATES = 2
HTS_PUSHED: win32more.Windows.Win32.UI.Controls.HORZTHUMBSTATES = 3
HTS_DISABLED: win32more.Windows.Win32.UI.Controls.HORZTHUMBSTATES = 4
HOTGLYPHSTATES = Int32
HGLPS_CLOSED: win32more.Windows.Win32.UI.Controls.HOTGLYPHSTATES = 1
HGLPS_OPENED: win32more.Windows.Win32.UI.Controls.HOTGLYPHSTATES = 2
HOVERBACKGROUNDSTATES = Int32
UTS_NORMAL: win32more.Windows.Win32.UI.Controls.HOVERBACKGROUNDSTATES = 1
UTS_HOT: win32more.Windows.Win32.UI.Controls.HOVERBACKGROUNDSTATES = 2
UTS_PRESSED: win32more.Windows.Win32.UI.Controls.HOVERBACKGROUNDSTATES = 3
HPROPSHEETPAGE = VoidPtr
HSYNTHETICPOINTERDEVICE = VoidPtr
HTHEME = IntPtr
HTREEITEM = IntPtr
HYPERLINKSTATES = Int32
HLS_NORMALTEXT: win32more.Windows.Win32.UI.Controls.HYPERLINKSTATES = 1
HLS_LINKTEXT: win32more.Windows.Win32.UI.Controls.HYPERLINKSTATES = 2
HYPERLINKTEXTSTATES = Int32
TS_HYPERLINK_NORMAL: win32more.Windows.Win32.UI.Controls.HYPERLINKTEXTSTATES = 1
TS_HYPERLINK_HOT: win32more.Windows.Win32.UI.Controls.HYPERLINKTEXTSTATES = 2
TS_HYPERLINK_PRESSED: win32more.Windows.Win32.UI.Controls.HYPERLINKTEXTSTATES = 3
TS_HYPERLINK_DISABLED: win32more.Windows.Win32.UI.Controls.HYPERLINKTEXTSTATES = 4
ICONEFFECT = Int32
ICE_NONE: win32more.Windows.Win32.UI.Controls.ICONEFFECT = 0
ICE_GLOW: win32more.Windows.Win32.UI.Controls.ICONEFFECT = 1
ICE_SHADOW: win32more.Windows.Win32.UI.Controls.ICONEFFECT = 2
ICE_PULSE: win32more.Windows.Win32.UI.Controls.ICONEFFECT = 3
ICE_ALPHA: win32more.Windows.Win32.UI.Controls.ICONEFFECT = 4
IEBARMENUSTATES = Int32
EBM_NORMAL: win32more.Windows.Win32.UI.Controls.IEBARMENUSTATES = 1
EBM_HOT: win32more.Windows.Win32.UI.Controls.IEBARMENUSTATES = 2
EBM_PRESSED: win32more.Windows.Win32.UI.Controls.IEBARMENUSTATES = 3
class IImageList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{46eb5926-582e-4017-9fdf-e8998daa0950}')
    @commethod(3)
    def Add(self, hbmImage: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, hbmMask: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, pi: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ReplaceIcon(self, i: Int32, hicon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON, pi: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetOverlayImage(self, iImage: Int32, iOverlay: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Replace(self, i: Int32, hbmImage: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, hbmMask: win32more.Windows.Win32.Graphics.Gdi.HBITMAP) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def AddMasked(self, hbmImage: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, crMask: win32more.Windows.Win32.Foundation.COLORREF, pi: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Draw(self, pimldp: POINTER(win32more.Windows.Win32.UI.Controls.IMAGELISTDRAWPARAMS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Remove(self, i: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetIcon(self, i: Int32, flags: UInt32, picon: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetImageInfo(self, i: Int32, pImageInfo: POINTER(win32more.Windows.Win32.UI.Controls.IMAGEINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Copy(self, iDst: Int32, punkSrc: win32more.Windows.Win32.System.Com.IUnknown, iSrc: Int32, uFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def Merge(self, i1: Int32, punk2: win32more.Windows.Win32.System.Com.IUnknown, i2: Int32, dx: Int32, dy: Int32, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Clone(self, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetImageRect(self, i: Int32, prc: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetIconSize(self, cx: POINTER(Int32), cy: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def SetIconSize(self, cx: Int32, cy: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetImageCount(self, pi: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def SetImageCount(self, uNewCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetBkColor(self, clrBk: win32more.Windows.Win32.Foundation.COLORREF, pclr: POINTER(win32more.Windows.Win32.Foundation.COLORREF)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetBkColor(self, pclr: POINTER(win32more.Windows.Win32.Foundation.COLORREF)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def BeginDrag(self, iTrack: Int32, dxHotspot: Int32, dyHotspot: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def EndDrag(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def DragEnter(self, hwndLock: win32more.Windows.Win32.Foundation.HWND, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def DragLeave(self, hwndLock: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def DragMove(self, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def SetDragCursorImage(self, punk: win32more.Windows.Win32.System.Com.IUnknown, iDrag: Int32, dxHotspot: Int32, dyHotspot: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def DragShowNolock(self, fShow: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def GetDragImage(self, ppt: POINTER(win32more.Windows.Win32.Foundation.POINT), pptHotspot: POINTER(win32more.Windows.Win32.Foundation.POINT), riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def GetItemFlags(self, i: Int32, dwFlags: POINTER(win32more.Windows.Win32.UI.Controls.IMAGE_LIST_ITEM_FLAGS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def GetOverlayImage(self, iOverlay: Int32, piIndex: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IImageList2(ComPtr):
    extends: win32more.Windows.Win32.UI.Controls.IImageList
    _iid_ = Guid('{192b9d83-50fc-457b-90a0-2b82a8b5dae1}')
    @commethod(32)
    def Resize(self, cxNewIconSize: Int32, cyNewIconSize: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetOriginalSize(self, iImage: Int32, dwFlags: UInt32, pcx: POINTER(Int32), pcy: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def SetOriginalSize(self, iImage: Int32, cx: Int32, cy: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def SetCallback(self, punk: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def GetCallback(self, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def ForceImagePresent(self, iImage: Int32, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def DiscardImages(self, iFirstImage: Int32, iLastImage: Int32, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def PreloadImages(self, pimldp: POINTER(win32more.Windows.Win32.UI.Controls.IMAGELISTDRAWPARAMS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def GetStatistics(self, pils: POINTER(win32more.Windows.Win32.UI.Controls.IMAGELISTSTATS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def Initialize(self, cx: Int32, cy: Int32, flags: win32more.Windows.Win32.UI.Controls.IMAGELIST_CREATION_FLAGS, cInitial: Int32, cGrow: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def Replace2(self, i: Int32, hbmImage: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, hbmMask: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, punk: win32more.Windows.Win32.System.Com.IUnknown, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def ReplaceFromImageList(self, i: Int32, pil: win32more.Windows.Win32.UI.Controls.IImageList, iSrc: Int32, punk: win32more.Windows.Win32.System.Com.IUnknown, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMAGEINFO(Structure):
    hbmImage: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
    hbmMask: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
    Unused1: Int32
    Unused2: Int32
    rcImage: win32more.Windows.Win32.Foundation.RECT
IMAGELAYOUT = Int32
IL_VERTICAL: win32more.Windows.Win32.UI.Controls.IMAGELAYOUT = 0
IL_HORIZONTAL: win32more.Windows.Win32.UI.Controls.IMAGELAYOUT = 1
class IMAGELISTDRAWPARAMS(Structure):
    cbSize: UInt32
    himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST
    i: Int32
    hdcDst: win32more.Windows.Win32.Graphics.Gdi.HDC
    x: Int32
    y: Int32
    cx: Int32
    cy: Int32
    xBitmap: Int32
    yBitmap: Int32
    rgbBk: win32more.Windows.Win32.Foundation.COLORREF
    rgbFg: win32more.Windows.Win32.Foundation.COLORREF
    fStyle: UInt32
    dwRop: UInt32
    fState: UInt32
    Frame: UInt32
    crEffect: win32more.Windows.Win32.Foundation.COLORREF
class IMAGELISTSTATS(Structure):
    cbSize: UInt32
    cAlloc: Int32
    cUsed: Int32
    cStandby: Int32
IMAGELIST_CREATION_FLAGS = UInt32
ILC_MASK: win32more.Windows.Win32.UI.Controls.IMAGELIST_CREATION_FLAGS = 1
ILC_COLOR: win32more.Windows.Win32.UI.Controls.IMAGELIST_CREATION_FLAGS = 0
ILC_COLORDDB: win32more.Windows.Win32.UI.Controls.IMAGELIST_CREATION_FLAGS = 254
ILC_COLOR4: win32more.Windows.Win32.UI.Controls.IMAGELIST_CREATION_FLAGS = 4
ILC_COLOR8: win32more.Windows.Win32.UI.Controls.IMAGELIST_CREATION_FLAGS = 8
ILC_COLOR16: win32more.Windows.Win32.UI.Controls.IMAGELIST_CREATION_FLAGS = 16
ILC_COLOR24: win32more.Windows.Win32.UI.Controls.IMAGELIST_CREATION_FLAGS = 24
ILC_COLOR32: win32more.Windows.Win32.UI.Controls.IMAGELIST_CREATION_FLAGS = 32
ILC_PALETTE: win32more.Windows.Win32.UI.Controls.IMAGELIST_CREATION_FLAGS = 2048
ILC_MIRROR: win32more.Windows.Win32.UI.Controls.IMAGELIST_CREATION_FLAGS = 8192
ILC_PERITEMMIRROR: win32more.Windows.Win32.UI.Controls.IMAGELIST_CREATION_FLAGS = 32768
ILC_ORIGINALSIZE: win32more.Windows.Win32.UI.Controls.IMAGELIST_CREATION_FLAGS = 65536
ILC_HIGHQUALITYSCALE: win32more.Windows.Win32.UI.Controls.IMAGELIST_CREATION_FLAGS = 131072
IMAGESELECTTYPE = Int32
IST_NONE: win32more.Windows.Win32.UI.Controls.IMAGESELECTTYPE = 0
IST_SIZE: win32more.Windows.Win32.UI.Controls.IMAGESELECTTYPE = 1
IST_DPI: win32more.Windows.Win32.UI.Controls.IMAGESELECTTYPE = 2
IMAGE_LIST_COPY_FLAGS = UInt32
ILCF_MOVE: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_COPY_FLAGS = 0
ILCF_SWAP: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_COPY_FLAGS = 1
IMAGE_LIST_DRAW_STYLE = UInt32
ILD_NORMAL: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE = 0
ILD_TRANSPARENT: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE = 1
ILD_BLEND25: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE = 2
ILD_FOCUS: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE = 2
ILD_BLEND50: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE = 4
ILD_SELECTED: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE = 4
ILD_BLEND: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE = 4
ILD_MASK: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE = 16
ILD_IMAGE: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE = 32
ILD_ROP: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE = 64
ILD_OVERLAYMASK: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE = 3840
ILD_PRESERVEALPHA: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE = 4096
ILD_SCALE: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE = 8192
ILD_DPISCALE: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE = 16384
ILD_ASYNC: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_DRAW_STYLE = 32768
IMAGE_LIST_ITEM_FLAGS = UInt32
ILIF_ALPHA: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_ITEM_FLAGS = 1
ILIF_LOWQUALITY: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_ITEM_FLAGS = 2
IMAGE_LIST_WRITE_STREAM_FLAGS = UInt32
ILP_NORMAL: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_WRITE_STREAM_FLAGS = 0
ILP_DOWNLEVEL: win32more.Windows.Win32.UI.Controls.IMAGE_LIST_WRITE_STREAM_FLAGS = 1
class INITCOMMONCONTROLSEX(Structure):
    dwSize: UInt32
    dwICC: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC
INITCOMMONCONTROLSEX_ICC = UInt32
ICC_ANIMATE_CLASS: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC = 128
ICC_BAR_CLASSES: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC = 4
ICC_COOL_CLASSES: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC = 1024
ICC_DATE_CLASSES: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC = 256
ICC_HOTKEY_CLASS: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC = 64
ICC_INTERNET_CLASSES: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC = 2048
ICC_LINK_CLASS: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC = 32768
ICC_LISTVIEW_CLASSES: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC = 1
ICC_NATIVEFNTCTL_CLASS: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC = 8192
ICC_PAGESCROLLER_CLASS: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC = 4096
ICC_PROGRESS_CLASS: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC = 32
ICC_STANDARD_CLASSES: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC = 16384
ICC_TAB_CLASSES: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC = 8
ICC_TREEVIEW_CLASSES: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC = 2
ICC_UPDOWN_CLASS: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC = 16
ICC_USEREX_CLASSES: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC = 512
ICC_WIN95_CLASSES: win32more.Windows.Win32.UI.Controls.INITCOMMONCONTROLSEX_ICC = 255
class INTLIST(Structure):
    iValueCount: Int32
    iValues: Int32 * 402
ITEMSTATES = Int32
LBPSI_HOT: win32more.Windows.Win32.UI.Controls.ITEMSTATES = 1
LBPSI_HOTSELECTED: win32more.Windows.Win32.UI.Controls.ITEMSTATES = 2
LBPSI_SELECTED: win32more.Windows.Win32.UI.Controls.ITEMSTATES = 3
LBPSI_SELECTEDNOTFOCUS: win32more.Windows.Win32.UI.Controls.ITEMSTATES = 4
ImageList = Guid('{7c476ba2-02b1-48f4-8048-b24619ddc058}')
LABELSTATES = Int32
FLS_NORMAL: win32more.Windows.Win32.UI.Controls.LABELSTATES = 1
FLS_SELECTED: win32more.Windows.Win32.UI.Controls.LABELSTATES = 2
FLS_EMPHASIZED: win32more.Windows.Win32.UI.Controls.LABELSTATES = 3
FLS_DISABLED: win32more.Windows.Win32.UI.Controls.LABELSTATES = 4
class LHITTESTINFO(Structure):
    pt: win32more.Windows.Win32.Foundation.POINT
    item: win32more.Windows.Win32.UI.Controls.LITEM
LINKHEADERSTATES = Int32
FLH_NORMAL: win32more.Windows.Win32.UI.Controls.LINKHEADERSTATES = 1
FLH_HOVER: win32more.Windows.Win32.UI.Controls.LINKHEADERSTATES = 2
LINKPARTS = Int32
LP_HYPERLINK: win32more.Windows.Win32.UI.Controls.LINKPARTS = 1
LINKSTATES = Int32
FLYOUTLINK_NORMAL: win32more.Windows.Win32.UI.Controls.LINKSTATES = 1
FLYOUTLINK_HOVER: win32more.Windows.Win32.UI.Controls.LINKSTATES = 2
LISTBOXPARTS = Int32
LBCP_BORDER_HSCROLL: win32more.Windows.Win32.UI.Controls.LISTBOXPARTS = 1
LBCP_BORDER_HVSCROLL: win32more.Windows.Win32.UI.Controls.LISTBOXPARTS = 2
LBCP_BORDER_NOSCROLL: win32more.Windows.Win32.UI.Controls.LISTBOXPARTS = 3
LBCP_BORDER_VSCROLL: win32more.Windows.Win32.UI.Controls.LISTBOXPARTS = 4
LBCP_ITEM: win32more.Windows.Win32.UI.Controls.LISTBOXPARTS = 5
LISTITEMSTATES = Int32
LISS_NORMAL: win32more.Windows.Win32.UI.Controls.LISTITEMSTATES = 1
LISS_HOT: win32more.Windows.Win32.UI.Controls.LISTITEMSTATES = 2
LISS_SELECTED: win32more.Windows.Win32.UI.Controls.LISTITEMSTATES = 3
LISS_DISABLED: win32more.Windows.Win32.UI.Controls.LISTITEMSTATES = 4
LISS_SELECTEDNOTFOCUS: win32more.Windows.Win32.UI.Controls.LISTITEMSTATES = 5
LISS_HOTSELECTED: win32more.Windows.Win32.UI.Controls.LISTITEMSTATES = 6
LISTVIEWPARTS = Int32
LVP_LISTITEM: win32more.Windows.Win32.UI.Controls.LISTVIEWPARTS = 1
LVP_LISTGROUP: win32more.Windows.Win32.UI.Controls.LISTVIEWPARTS = 2
LVP_LISTDETAIL: win32more.Windows.Win32.UI.Controls.LISTVIEWPARTS = 3
LVP_LISTSORTEDDETAIL: win32more.Windows.Win32.UI.Controls.LISTVIEWPARTS = 4
LVP_EMPTYTEXT: win32more.Windows.Win32.UI.Controls.LISTVIEWPARTS = 5
LVP_GROUPHEADER: win32more.Windows.Win32.UI.Controls.LISTVIEWPARTS = 6
LVP_GROUPHEADERLINE: win32more.Windows.Win32.UI.Controls.LISTVIEWPARTS = 7
LVP_EXPANDBUTTON: win32more.Windows.Win32.UI.Controls.LISTVIEWPARTS = 8
LVP_COLLAPSEBUTTON: win32more.Windows.Win32.UI.Controls.LISTVIEWPARTS = 9
LVP_COLUMNDETAIL: win32more.Windows.Win32.UI.Controls.LISTVIEWPARTS = 10
LIST_ITEM_FLAGS = UInt32
LIF_ITEMINDEX: win32more.Windows.Win32.UI.Controls.LIST_ITEM_FLAGS = 1
LIF_STATE: win32more.Windows.Win32.UI.Controls.LIST_ITEM_FLAGS = 2
LIF_ITEMID: win32more.Windows.Win32.UI.Controls.LIST_ITEM_FLAGS = 4
LIF_URL: win32more.Windows.Win32.UI.Controls.LIST_ITEM_FLAGS = 8
LIST_ITEM_STATE_FLAGS = UInt32
LIS_FOCUSED: win32more.Windows.Win32.UI.Controls.LIST_ITEM_STATE_FLAGS = 1
LIS_ENABLED: win32more.Windows.Win32.UI.Controls.LIST_ITEM_STATE_FLAGS = 2
LIS_VISITED: win32more.Windows.Win32.UI.Controls.LIST_ITEM_STATE_FLAGS = 4
LIS_HOTTRACK: win32more.Windows.Win32.UI.Controls.LIST_ITEM_STATE_FLAGS = 8
LIS_DEFAULTCOLORS: win32more.Windows.Win32.UI.Controls.LIST_ITEM_STATE_FLAGS = 16
LIST_VIEW_BACKGROUND_IMAGE_FLAGS = UInt32
LVBKIF_SOURCE_NONE: win32more.Windows.Win32.UI.Controls.LIST_VIEW_BACKGROUND_IMAGE_FLAGS = 0
LVBKIF_SOURCE_HBITMAP: win32more.Windows.Win32.UI.Controls.LIST_VIEW_BACKGROUND_IMAGE_FLAGS = 1
LVBKIF_SOURCE_URL: win32more.Windows.Win32.UI.Controls.LIST_VIEW_BACKGROUND_IMAGE_FLAGS = 2
LVBKIF_SOURCE_MASK: win32more.Windows.Win32.UI.Controls.LIST_VIEW_BACKGROUND_IMAGE_FLAGS = 3
LVBKIF_STYLE_NORMAL: win32more.Windows.Win32.UI.Controls.LIST_VIEW_BACKGROUND_IMAGE_FLAGS = 0
LVBKIF_STYLE_TILE: win32more.Windows.Win32.UI.Controls.LIST_VIEW_BACKGROUND_IMAGE_FLAGS = 16
LVBKIF_STYLE_MASK: win32more.Windows.Win32.UI.Controls.LIST_VIEW_BACKGROUND_IMAGE_FLAGS = 16
LVBKIF_FLAG_TILEOFFSET: win32more.Windows.Win32.UI.Controls.LIST_VIEW_BACKGROUND_IMAGE_FLAGS = 256
LVBKIF_TYPE_WATERMARK: win32more.Windows.Win32.UI.Controls.LIST_VIEW_BACKGROUND_IMAGE_FLAGS = 268435456
LVBKIF_FLAG_ALPHABLEND: win32more.Windows.Win32.UI.Controls.LIST_VIEW_BACKGROUND_IMAGE_FLAGS = 536870912
LIST_VIEW_GROUP_ALIGN_FLAGS = UInt32
LVGA_HEADER_LEFT: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_ALIGN_FLAGS = 1
LVGA_HEADER_CENTER: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_ALIGN_FLAGS = 2
LVGA_HEADER_RIGHT: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_ALIGN_FLAGS = 4
LVGA_FOOTER_LEFT: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_ALIGN_FLAGS = 8
LVGA_FOOTER_CENTER: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_ALIGN_FLAGS = 16
LVGA_FOOTER_RIGHT: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_ALIGN_FLAGS = 32
LIST_VIEW_GROUP_STATE_FLAGS = UInt32
LVGS_NORMAL: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_STATE_FLAGS = 0
LVGS_COLLAPSED: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_STATE_FLAGS = 1
LVGS_HIDDEN: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_STATE_FLAGS = 2
LVGS_NOHEADER: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_STATE_FLAGS = 4
LVGS_COLLAPSIBLE: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_STATE_FLAGS = 8
LVGS_FOCUSED: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_STATE_FLAGS = 16
LVGS_SELECTED: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_STATE_FLAGS = 32
LVGS_SUBSETED: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_STATE_FLAGS = 64
LVGS_SUBSETLINKFOCUSED: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_STATE_FLAGS = 128
LIST_VIEW_ITEM_COLUMN_FORMAT_FLAGS = Int32
LVCFMT_LINE_BREAK: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_COLUMN_FORMAT_FLAGS = 1048576
LVCFMT_FILL: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_COLUMN_FORMAT_FLAGS = 2097152
LVCFMT_WRAP: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_COLUMN_FORMAT_FLAGS = 4194304
LVCFMT_NO_TITLE: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_COLUMN_FORMAT_FLAGS = 8388608
LVCFMT_TILE_PLACEMENTMASK: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_COLUMN_FORMAT_FLAGS = 3145728
LIST_VIEW_ITEM_FLAGS = UInt32
LVIF_TEXT: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_FLAGS = 1
LVIF_IMAGE: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_FLAGS = 2
LVIF_PARAM: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_FLAGS = 4
LVIF_STATE: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_FLAGS = 8
LVIF_INDENT: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_FLAGS = 16
LVIF_NORECOMPUTE: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_FLAGS = 2048
LVIF_GROUPID: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_FLAGS = 256
LVIF_COLUMNS: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_FLAGS = 512
LVIF_COLFMT: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_FLAGS = 65536
LVIF_DI_SETITEM: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_FLAGS = 4096
LIST_VIEW_ITEM_STATE_FLAGS = UInt32
LVIS_FOCUSED: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_STATE_FLAGS = 1
LVIS_SELECTED: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_STATE_FLAGS = 2
LVIS_CUT: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_STATE_FLAGS = 4
LVIS_DROPHILITED: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_STATE_FLAGS = 8
LVIS_GLOW: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_STATE_FLAGS = 16
LVIS_ACTIVATING: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_STATE_FLAGS = 32
LVIS_OVERLAYMASK: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_STATE_FLAGS = 3840
LVIS_STATEIMAGEMASK: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_STATE_FLAGS = 61440
class LITEM(Structure):
    mask: win32more.Windows.Win32.UI.Controls.LIST_ITEM_FLAGS
    iLink: Int32
    state: win32more.Windows.Win32.UI.Controls.LIST_ITEM_STATE_FLAGS
    stateMask: win32more.Windows.Win32.UI.Controls.LIST_ITEM_STATE_FLAGS
    szID: Char * 48
    szUrl: Char * 2084
LOGOFFBUTTONSSTATES = Int32
SPLS_NORMAL: win32more.Windows.Win32.UI.Controls.LOGOFFBUTTONSSTATES = 1
SPLS_HOT: win32more.Windows.Win32.UI.Controls.LOGOFFBUTTONSSTATES = 2
SPLS_PRESSED: win32more.Windows.Win32.UI.Controls.LOGOFFBUTTONSSTATES = 3
@winfunctype_pointer
def LPFNADDPROPSHEETPAGES(param0: VoidPtr, param1: win32more.Windows.Win32.UI.Controls.LPFNSVADDPROPSHEETPAGE, param2: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LPFNCCINFOA(acci: POINTER(win32more.Windows.Win32.UI.Controls.CCINFOA)) -> UInt32: ...
@winfunctype_pointer
def LPFNCCINFOW(acci: POINTER(win32more.Windows.Win32.UI.Controls.CCINFOW)) -> UInt32: ...
LPFNCCINFO = UnicodeAlias('LPFNCCINFOW')
@winfunctype_pointer
def LPFNCCSIZETOTEXTA(flStyle: UInt32, flExtStyle: UInt32, hfont: win32more.Windows.Win32.Graphics.Gdi.HFONT, pszText: win32more.Windows.Win32.Foundation.PSTR) -> Int32: ...
@winfunctype_pointer
def LPFNCCSIZETOTEXTW(flStyle: UInt32, flExtStyle: UInt32, hfont: win32more.Windows.Win32.Graphics.Gdi.HFONT, pszText: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
LPFNCCSIZETOTEXT = UnicodeAlias('LPFNCCSIZETOTEXTW')
@winfunctype_pointer
def LPFNCCSTYLEA(hwndParent: win32more.Windows.Win32.Foundation.HWND, pccs: POINTER(win32more.Windows.Win32.UI.Controls.CCSTYLEA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LPFNCCSTYLEW(hwndParent: win32more.Windows.Win32.Foundation.HWND, pccs: POINTER(win32more.Windows.Win32.UI.Controls.CCSTYLEW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
LPFNCCSTYLE = UnicodeAlias('LPFNCCSTYLEW')
@winfunctype_pointer
def LPFNPSPCALLBACKA(hwnd: win32more.Windows.Win32.Foundation.HWND, uMsg: win32more.Windows.Win32.UI.Controls.PSPCB_MESSAGE, ppsp: POINTER(win32more.Windows.Win32.UI.Controls.PROPSHEETPAGEA)) -> UInt32: ...
@winfunctype_pointer
def LPFNPSPCALLBACKW(hwnd: win32more.Windows.Win32.Foundation.HWND, uMsg: win32more.Windows.Win32.UI.Controls.PSPCB_MESSAGE, ppsp: POINTER(win32more.Windows.Win32.UI.Controls.PROPSHEETPAGEW)) -> UInt32: ...
LPFNPSPCALLBACK = UnicodeAlias('LPFNPSPCALLBACKW')
@winfunctype_pointer
def LPFNSVADDPROPSHEETPAGE(param0: win32more.Windows.Win32.UI.Controls.HPROPSHEETPAGE, param1: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
class LVBKIMAGEA(Structure):
    ulFlags: win32more.Windows.Win32.UI.Controls.LIST_VIEW_BACKGROUND_IMAGE_FLAGS
    hbm: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
    pszImage: win32more.Windows.Win32.Foundation.PSTR
    cchImageMax: UInt32
    xOffsetPercent: Int32
    yOffsetPercent: Int32
class LVBKIMAGEW(Structure):
    ulFlags: win32more.Windows.Win32.UI.Controls.LIST_VIEW_BACKGROUND_IMAGE_FLAGS
    hbm: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
    pszImage: win32more.Windows.Win32.Foundation.PWSTR
    cchImageMax: UInt32
    xOffsetPercent: Int32
    yOffsetPercent: Int32
LVBKIMAGE = UnicodeAlias('LVBKIMAGEW')
class LVCOLUMNA(Structure):
    mask: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_MASK
    fmt: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_FORMAT
    cx: Int32
    pszText: win32more.Windows.Win32.Foundation.PSTR
    cchTextMax: Int32
    iSubItem: Int32
    iImage: Int32
    iOrder: Int32
    cxMin: Int32
    cxDefault: Int32
    cxIdeal: Int32
class LVCOLUMNW(Structure):
    mask: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_MASK
    fmt: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_FORMAT
    cx: Int32
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    cchTextMax: Int32
    iSubItem: Int32
    iImage: Int32
    iOrder: Int32
    cxMin: Int32
    cxDefault: Int32
    cxIdeal: Int32
LVCOLUMN = UnicodeAlias('LVCOLUMNW')
LVCOLUMNW_FORMAT = Int32
LVCFMT_LEFT: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_FORMAT = 0
LVCFMT_RIGHT: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_FORMAT = 1
LVCFMT_CENTER: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_FORMAT = 2
LVCFMT_JUSTIFYMASK: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_FORMAT = 3
LVCFMT_IMAGE: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_FORMAT = 2048
LVCFMT_BITMAP_ON_RIGHT: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_FORMAT = 4096
LVCFMT_COL_HAS_IMAGES: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_FORMAT = 32768
LVCFMT_FIXED_WIDTH: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_FORMAT = 256
LVCFMT_NO_DPI_SCALE: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_FORMAT = 262144
LVCFMT_FIXED_RATIO: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_FORMAT = 524288
LVCFMT_SPLITBUTTON: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_FORMAT = 16777216
LVCOLUMNW_MASK = UInt32
LVCF_FMT: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_MASK = 1
LVCF_WIDTH: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_MASK = 2
LVCF_TEXT: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_MASK = 4
LVCF_SUBITEM: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_MASK = 8
LVCF_IMAGE: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_MASK = 16
LVCF_ORDER: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_MASK = 32
LVCF_MINWIDTH: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_MASK = 64
LVCF_DEFAULTWIDTH: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_MASK = 128
LVCF_IDEALWIDTH: win32more.Windows.Win32.UI.Controls.LVCOLUMNW_MASK = 256
class LVFINDINFOA(Structure):
    flags: win32more.Windows.Win32.UI.Controls.LVFINDINFOW_FLAGS
    psz: win32more.Windows.Win32.Foundation.PSTR
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    pt: win32more.Windows.Win32.Foundation.POINT
    vkDirection: UInt32
class LVFINDINFOW(Structure):
    flags: win32more.Windows.Win32.UI.Controls.LVFINDINFOW_FLAGS
    psz: win32more.Windows.Win32.Foundation.PWSTR
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    pt: win32more.Windows.Win32.Foundation.POINT
    vkDirection: UInt32
LVFINDINFO = UnicodeAlias('LVFINDINFOW')
LVFINDINFOW_FLAGS = UInt32
LVFI_PARAM: win32more.Windows.Win32.UI.Controls.LVFINDINFOW_FLAGS = 1
LVFI_PARTIAL: win32more.Windows.Win32.UI.Controls.LVFINDINFOW_FLAGS = 8
LVFI_STRING: win32more.Windows.Win32.UI.Controls.LVFINDINFOW_FLAGS = 2
LVFI_SUBSTRING: win32more.Windows.Win32.UI.Controls.LVFINDINFOW_FLAGS = 4
LVFI_WRAP: win32more.Windows.Win32.UI.Controls.LVFINDINFOW_FLAGS = 32
LVFI_NEARESTXY: win32more.Windows.Win32.UI.Controls.LVFINDINFOW_FLAGS = 64
class LVFOOTERINFO(Structure):
    mask: UInt32
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    cchTextMax: Int32
    cItems: UInt32
class LVFOOTERITEM(Structure):
    mask: win32more.Windows.Win32.UI.Controls.LVFOOTERITEM_MASK
    iItem: Int32
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    cchTextMax: Int32
    state: UInt32
    stateMask: UInt32
LVFOOTERITEM_MASK = UInt32
LVFIF_TEXT: win32more.Windows.Win32.UI.Controls.LVFOOTERITEM_MASK = 1
LVFIF_STATE: win32more.Windows.Win32.UI.Controls.LVFOOTERITEM_MASK = 2
class LVGROUP(Structure):
    cbSize: UInt32
    mask: win32more.Windows.Win32.UI.Controls.LVGROUP_MASK
    pszHeader: win32more.Windows.Win32.Foundation.PWSTR
    cchHeader: Int32
    pszFooter: win32more.Windows.Win32.Foundation.PWSTR
    cchFooter: Int32
    iGroupId: Int32
    stateMask: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_STATE_FLAGS
    state: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_STATE_FLAGS
    uAlign: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_ALIGN_FLAGS
    pszSubtitle: win32more.Windows.Win32.Foundation.PWSTR
    cchSubtitle: UInt32
    pszTask: win32more.Windows.Win32.Foundation.PWSTR
    cchTask: UInt32
    pszDescriptionTop: win32more.Windows.Win32.Foundation.PWSTR
    cchDescriptionTop: UInt32
    pszDescriptionBottom: win32more.Windows.Win32.Foundation.PWSTR
    cchDescriptionBottom: UInt32
    iTitleImage: Int32
    iExtendedImage: Int32
    iFirstItem: Int32
    cItems: UInt32
    pszSubsetTitle: win32more.Windows.Win32.Foundation.PWSTR
    cchSubsetTitle: UInt32
class LVGROUPMETRICS(Structure):
    cbSize: UInt32
    mask: UInt32
    Left: UInt32
    Top: UInt32
    Right: UInt32
    Bottom: UInt32
    crLeft: win32more.Windows.Win32.Foundation.COLORREF
    crTop: win32more.Windows.Win32.Foundation.COLORREF
    crRight: win32more.Windows.Win32.Foundation.COLORREF
    crBottom: win32more.Windows.Win32.Foundation.COLORREF
    crHeader: win32more.Windows.Win32.Foundation.COLORREF
    crFooter: win32more.Windows.Win32.Foundation.COLORREF
LVGROUP_MASK = UInt32
LVGF_NONE: win32more.Windows.Win32.UI.Controls.LVGROUP_MASK = 0
LVGF_HEADER: win32more.Windows.Win32.UI.Controls.LVGROUP_MASK = 1
LVGF_FOOTER: win32more.Windows.Win32.UI.Controls.LVGROUP_MASK = 2
LVGF_STATE: win32more.Windows.Win32.UI.Controls.LVGROUP_MASK = 4
LVGF_ALIGN: win32more.Windows.Win32.UI.Controls.LVGROUP_MASK = 8
LVGF_GROUPID: win32more.Windows.Win32.UI.Controls.LVGROUP_MASK = 16
LVGF_SUBTITLE: win32more.Windows.Win32.UI.Controls.LVGROUP_MASK = 256
LVGF_TASK: win32more.Windows.Win32.UI.Controls.LVGROUP_MASK = 512
LVGF_DESCRIPTIONTOP: win32more.Windows.Win32.UI.Controls.LVGROUP_MASK = 1024
LVGF_DESCRIPTIONBOTTOM: win32more.Windows.Win32.UI.Controls.LVGROUP_MASK = 2048
LVGF_TITLEIMAGE: win32more.Windows.Win32.UI.Controls.LVGROUP_MASK = 4096
LVGF_EXTENDEDIMAGE: win32more.Windows.Win32.UI.Controls.LVGROUP_MASK = 8192
LVGF_ITEMS: win32more.Windows.Win32.UI.Controls.LVGROUP_MASK = 16384
LVGF_SUBSET: win32more.Windows.Win32.UI.Controls.LVGROUP_MASK = 32768
LVGF_SUBSETITEMS: win32more.Windows.Win32.UI.Controls.LVGROUP_MASK = 65536
class LVHITTESTINFO(Structure):
    pt: win32more.Windows.Win32.Foundation.POINT
    flags: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS
    iItem: Int32
    iSubItem: Int32
    iGroup: Int32
LVHITTESTINFO_FLAGS = UInt32
LVHT_ABOVE: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS = 8
LVHT_BELOW: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS = 16
LVHT_NOWHERE: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS = 1
LVHT_ONITEMICON: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS = 2
LVHT_ONITEMLABEL: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS = 4
LVHT_ONITEMSTATEICON: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS = 8
LVHT_TOLEFT: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS = 64
LVHT_TORIGHT: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS = 32
LVHT_EX_GROUP_HEADER: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS = 268435456
LVHT_EX_GROUP_FOOTER: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS = 536870912
LVHT_EX_GROUP_COLLAPSE: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS = 1073741824
LVHT_EX_GROUP_BACKGROUND: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS = 2147483648
LVHT_EX_GROUP_STATEICON: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS = 16777216
LVHT_EX_GROUP_SUBSETLINK: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS = 33554432
LVHT_EX_GROUP: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS = 4076863488
LVHT_EX_ONCONTENTS: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS = 67108864
LVHT_EX_FOOTER: win32more.Windows.Win32.UI.Controls.LVHITTESTINFO_FLAGS = 134217728
class LVINSERTGROUPSORTED(Structure):
    pfnGroupCompare: win32more.Windows.Win32.UI.Controls.PFNLVGROUPCOMPARE
    pvData: VoidPtr
    lvGroup: win32more.Windows.Win32.UI.Controls.LVGROUP
class LVINSERTMARK(Structure):
    cbSize: UInt32
    dwFlags: UInt32
    iItem: Int32
    dwReserved: UInt32
class LVITEMA(Structure):
    mask: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_FLAGS
    iItem: Int32
    iSubItem: Int32
    state: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_STATE_FLAGS
    stateMask: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_STATE_FLAGS
    pszText: win32more.Windows.Win32.Foundation.PSTR
    cchTextMax: Int32
    iImage: Int32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    iIndent: Int32
    iGroupId: Int32
    cColumns: UInt32
    puColumns: POINTER(UInt32)
    piColFmt: POINTER(win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_COLUMN_FORMAT_FLAGS)
    iGroup: Int32
LVITEMA_GROUP_ID = Int32
I_GROUPIDCALLBACK: win32more.Windows.Win32.UI.Controls.LVITEMA_GROUP_ID = -1
I_GROUPIDNONE: win32more.Windows.Win32.UI.Controls.LVITEMA_GROUP_ID = -2
class LVITEMINDEX(Structure):
    iItem: Int32
    iGroup: Int32
class LVITEMW(Structure):
    mask: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_FLAGS
    iItem: Int32
    iSubItem: Int32
    state: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_STATE_FLAGS
    stateMask: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_STATE_FLAGS
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    cchTextMax: Int32
    iImage: Int32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    iIndent: Int32
    iGroupId: Int32
    cColumns: UInt32
    puColumns: POINTER(UInt32)
    piColFmt: POINTER(win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_COLUMN_FORMAT_FLAGS)
    iGroup: Int32
LVITEM = UnicodeAlias('LVITEMW')
class LVSETINFOTIP(Structure):
    cbSize: UInt32
    dwFlags: UInt32
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    iItem: Int32
    iSubItem: Int32
class LVTILEINFO(Structure):
    cbSize: UInt32
    iItem: Int32
    cColumns: UInt32
    puColumns: POINTER(UInt32)
    piColFmt: POINTER(Int32)
class LVTILEVIEWINFO(Structure):
    cbSize: UInt32
    dwMask: win32more.Windows.Win32.UI.Controls.LVTILEVIEWINFO_MASK
    dwFlags: win32more.Windows.Win32.UI.Controls.LVTILEVIEWINFO_FLAGS
    sizeTile: win32more.Windows.Win32.Foundation.SIZE
    cLines: Int32
    rcLabelMargin: win32more.Windows.Win32.Foundation.RECT
LVTILEVIEWINFO_FLAGS = UInt32
LVTVIF_AUTOSIZE: win32more.Windows.Win32.UI.Controls.LVTILEVIEWINFO_FLAGS = 0
LVTVIF_FIXEDWIDTH: win32more.Windows.Win32.UI.Controls.LVTILEVIEWINFO_FLAGS = 1
LVTVIF_FIXEDHEIGHT: win32more.Windows.Win32.UI.Controls.LVTILEVIEWINFO_FLAGS = 2
LVTVIF_FIXEDSIZE: win32more.Windows.Win32.UI.Controls.LVTILEVIEWINFO_FLAGS = 3
LVTILEVIEWINFO_MASK = UInt32
LVTVIM_TILESIZE: win32more.Windows.Win32.UI.Controls.LVTILEVIEWINFO_MASK = 1
LVTVIM_COLUMNS: win32more.Windows.Win32.UI.Controls.LVTILEVIEWINFO_MASK = 2
LVTVIM_LABELMARGIN: win32more.Windows.Win32.UI.Controls.LVTILEVIEWINFO_MASK = 4
class MARGINS(Structure):
    cxLeftWidth: Int32
    cxRightWidth: Int32
    cyTopHeight: Int32
    cyBottomHeight: Int32
MARKUPTEXTSTATES = Int32
EMT_NORMALTEXT: win32more.Windows.Win32.UI.Controls.MARKUPTEXTSTATES = 1
EMT_LINKTEXT: win32more.Windows.Win32.UI.Controls.MARKUPTEXTSTATES = 2
MAXBUTTONSTATES = Int32
MAXBS_NORMAL: win32more.Windows.Win32.UI.Controls.MAXBUTTONSTATES = 1
MAXBS_HOT: win32more.Windows.Win32.UI.Controls.MAXBUTTONSTATES = 2
MAXBS_PUSHED: win32more.Windows.Win32.UI.Controls.MAXBUTTONSTATES = 3
MAXBS_DISABLED: win32more.Windows.Win32.UI.Controls.MAXBUTTONSTATES = 4
MAXCAPTIONSTATES = Int32
MXCS_ACTIVE: win32more.Windows.Win32.UI.Controls.MAXCAPTIONSTATES = 1
MXCS_INACTIVE: win32more.Windows.Win32.UI.Controls.MAXCAPTIONSTATES = 2
MXCS_DISABLED: win32more.Windows.Win32.UI.Controls.MAXCAPTIONSTATES = 3
class MCGRIDINFO(Structure):
    cbSize: UInt32
    dwPart: win32more.Windows.Win32.UI.Controls.MCGRIDINFO_PART
    dwFlags: win32more.Windows.Win32.UI.Controls.MCGRIDINFO_FLAGS
    iCalendar: Int32
    iRow: Int32
    iCol: Int32
    bSelected: win32more.Windows.Win32.Foundation.BOOL
    stStart: win32more.Windows.Win32.Foundation.SYSTEMTIME
    stEnd: win32more.Windows.Win32.Foundation.SYSTEMTIME
    rc: win32more.Windows.Win32.Foundation.RECT
    pszName: win32more.Windows.Win32.Foundation.PWSTR
    cchName: UIntPtr
MCGRIDINFO_FLAGS = UInt32
MCGIF_DATE: win32more.Windows.Win32.UI.Controls.MCGRIDINFO_FLAGS = 1
MCGIF_RECT: win32more.Windows.Win32.UI.Controls.MCGRIDINFO_FLAGS = 2
MCGIF_NAME: win32more.Windows.Win32.UI.Controls.MCGRIDINFO_FLAGS = 4
MCGRIDINFO_PART = UInt32
MCGIP_CALENDARCONTROL: win32more.Windows.Win32.UI.Controls.MCGRIDINFO_PART = 0
MCGIP_NEXT: win32more.Windows.Win32.UI.Controls.MCGRIDINFO_PART = 1
MCGIP_PREV: win32more.Windows.Win32.UI.Controls.MCGRIDINFO_PART = 2
MCGIP_FOOTER: win32more.Windows.Win32.UI.Controls.MCGRIDINFO_PART = 3
MCGIP_CALENDAR: win32more.Windows.Win32.UI.Controls.MCGRIDINFO_PART = 4
MCGIP_CALENDARHEADER: win32more.Windows.Win32.UI.Controls.MCGRIDINFO_PART = 5
MCGIP_CALENDARBODY: win32more.Windows.Win32.UI.Controls.MCGRIDINFO_PART = 6
MCGIP_CALENDARROW: win32more.Windows.Win32.UI.Controls.MCGRIDINFO_PART = 7
MCGIP_CALENDARCELL: win32more.Windows.Win32.UI.Controls.MCGRIDINFO_PART = 8
class MCHITTESTINFO(Structure):
    cbSize: UInt32
    pt: win32more.Windows.Win32.Foundation.POINT
    uHit: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS
    st: win32more.Windows.Win32.Foundation.SYSTEMTIME
    rc: win32more.Windows.Win32.Foundation.RECT
    iOffset: Int32
    iRow: Int32
    iCol: Int32
MCHITTESTINFO_HIT_FLAGS = UInt32
MCHT_TITLE: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 65536
MCHT_CALENDAR: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 131072
MCHT_TODAYLINK: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 196608
MCHT_CALENDARCONTROL: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 1048576
MCHT_NEXT: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 16777216
MCHT_PREV: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 33554432
MCHT_NOWHERE: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 0
MCHT_TITLEBK: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 65536
MCHT_TITLEMONTH: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 65537
MCHT_TITLEYEAR: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 65538
MCHT_TITLEBTNNEXT: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 16842755
MCHT_TITLEBTNPREV: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 33619971
MCHT_CALENDARBK: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 131072
MCHT_CALENDARDATE: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 131073
MCHT_CALENDARDATENEXT: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 16908289
MCHT_CALENDARDATEPREV: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 33685505
MCHT_CALENDARDAY: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 131074
MCHT_CALENDARWEEKNUM: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 131075
MCHT_CALENDARDATEMIN: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 131076
MCHT_CALENDARDATEMAX: win32more.Windows.Win32.UI.Controls.MCHITTESTINFO_HIT_FLAGS = 131077
MDICLOSEBUTTONSTATES = Int32
MDCL_NORMAL: win32more.Windows.Win32.UI.Controls.MDICLOSEBUTTONSTATES = 1
MDCL_HOT: win32more.Windows.Win32.UI.Controls.MDICLOSEBUTTONSTATES = 2
MDCL_PUSHED: win32more.Windows.Win32.UI.Controls.MDICLOSEBUTTONSTATES = 3
MDCL_DISABLED: win32more.Windows.Win32.UI.Controls.MDICLOSEBUTTONSTATES = 4
MDIMINBUTTONSTATES = Int32
MDMI_NORMAL: win32more.Windows.Win32.UI.Controls.MDIMINBUTTONSTATES = 1
MDMI_HOT: win32more.Windows.Win32.UI.Controls.MDIMINBUTTONSTATES = 2
MDMI_PUSHED: win32more.Windows.Win32.UI.Controls.MDIMINBUTTONSTATES = 3
MDMI_DISABLED: win32more.Windows.Win32.UI.Controls.MDIMINBUTTONSTATES = 4
MDIRESTOREBUTTONSTATES = Int32
MDRE_NORMAL: win32more.Windows.Win32.UI.Controls.MDIRESTOREBUTTONSTATES = 1
MDRE_HOT: win32more.Windows.Win32.UI.Controls.MDIRESTOREBUTTONSTATES = 2
MDRE_PUSHED: win32more.Windows.Win32.UI.Controls.MDIRESTOREBUTTONSTATES = 3
MDRE_DISABLED: win32more.Windows.Win32.UI.Controls.MDIRESTOREBUTTONSTATES = 4
class MEASUREITEMSTRUCT(Structure):
    CtlType: win32more.Windows.Win32.UI.Controls.DRAWITEMSTRUCT_CTL_TYPE
    CtlID: UInt32
    itemID: UInt32
    itemWidth: UInt32
    itemHeight: UInt32
    itemData: UIntPtr
MENUBANDPARTS = Int32
MDP_NEWAPPBUTTON: win32more.Windows.Win32.UI.Controls.MENUBANDPARTS = 1
MDP_SEPERATOR: win32more.Windows.Win32.UI.Controls.MENUBANDPARTS = 2
MENUBANDSTATES = Int32
MDS_NORMAL: win32more.Windows.Win32.UI.Controls.MENUBANDSTATES = 1
MDS_HOT: win32more.Windows.Win32.UI.Controls.MENUBANDSTATES = 2
MDS_PRESSED: win32more.Windows.Win32.UI.Controls.MENUBANDSTATES = 3
MDS_DISABLED: win32more.Windows.Win32.UI.Controls.MENUBANDSTATES = 4
MDS_CHECKED: win32more.Windows.Win32.UI.Controls.MENUBANDSTATES = 5
MDS_HOTCHECKED: win32more.Windows.Win32.UI.Controls.MENUBANDSTATES = 6
MENUPARTS = Int32
MENU_MENUITEM_TMSCHEMA: win32more.Windows.Win32.UI.Controls.MENUPARTS = 1
MENU_MENUDROPDOWN_TMSCHEMA: win32more.Windows.Win32.UI.Controls.MENUPARTS = 2
MENU_MENUBARITEM_TMSCHEMA: win32more.Windows.Win32.UI.Controls.MENUPARTS = 3
MENU_MENUBARDROPDOWN_TMSCHEMA: win32more.Windows.Win32.UI.Controls.MENUPARTS = 4
MENU_CHEVRON_TMSCHEMA: win32more.Windows.Win32.UI.Controls.MENUPARTS = 5
MENU_SEPARATOR_TMSCHEMA: win32more.Windows.Win32.UI.Controls.MENUPARTS = 6
MENU_BARBACKGROUND: win32more.Windows.Win32.UI.Controls.MENUPARTS = 7
MENU_BARITEM: win32more.Windows.Win32.UI.Controls.MENUPARTS = 8
MENU_POPUPBACKGROUND: win32more.Windows.Win32.UI.Controls.MENUPARTS = 9
MENU_POPUPBORDERS: win32more.Windows.Win32.UI.Controls.MENUPARTS = 10
MENU_POPUPCHECK: win32more.Windows.Win32.UI.Controls.MENUPARTS = 11
MENU_POPUPCHECKBACKGROUND: win32more.Windows.Win32.UI.Controls.MENUPARTS = 12
MENU_POPUPGUTTER: win32more.Windows.Win32.UI.Controls.MENUPARTS = 13
MENU_POPUPITEM: win32more.Windows.Win32.UI.Controls.MENUPARTS = 14
MENU_POPUPSEPARATOR: win32more.Windows.Win32.UI.Controls.MENUPARTS = 15
MENU_POPUPSUBMENU: win32more.Windows.Win32.UI.Controls.MENUPARTS = 16
MENU_SYSTEMCLOSE: win32more.Windows.Win32.UI.Controls.MENUPARTS = 17
MENU_SYSTEMMAXIMIZE: win32more.Windows.Win32.UI.Controls.MENUPARTS = 18
MENU_SYSTEMMINIMIZE: win32more.Windows.Win32.UI.Controls.MENUPARTS = 19
MENU_SYSTEMRESTORE: win32more.Windows.Win32.UI.Controls.MENUPARTS = 20
MENU_SYSTEMCLOSE_HCHOT: win32more.Windows.Win32.UI.Controls.MENUPARTS = 22
MENU_SYSTEMMAXIMIZE_HCHOT: win32more.Windows.Win32.UI.Controls.MENUPARTS = 23
MENU_SYSTEMMINIMIZE_HCHOT: win32more.Windows.Win32.UI.Controls.MENUPARTS = 24
MENU_SYSTEMRESTORE_HCHOT: win32more.Windows.Win32.UI.Controls.MENUPARTS = 25
MENU_POPUPITEMKBFOCUS: win32more.Windows.Win32.UI.Controls.MENUPARTS = 26
MENU_POPUPITEM_FOCUSABLE: win32more.Windows.Win32.UI.Controls.MENUPARTS = 27
MENU_POPUPSUBMENU_HCHOT: win32more.Windows.Win32.UI.Controls.MENUPARTS = 21
MINBUTTONSTATES = Int32
MINBS_NORMAL: win32more.Windows.Win32.UI.Controls.MINBUTTONSTATES = 1
MINBS_HOT: win32more.Windows.Win32.UI.Controls.MINBUTTONSTATES = 2
MINBS_PUSHED: win32more.Windows.Win32.UI.Controls.MINBUTTONSTATES = 3
MINBS_DISABLED: win32more.Windows.Win32.UI.Controls.MINBUTTONSTATES = 4
MINCAPTIONSTATES = Int32
MNCS_ACTIVE: win32more.Windows.Win32.UI.Controls.MINCAPTIONSTATES = 1
MNCS_INACTIVE: win32more.Windows.Win32.UI.Controls.MINCAPTIONSTATES = 2
MNCS_DISABLED: win32more.Windows.Win32.UI.Controls.MINCAPTIONSTATES = 3
MONTHCALPARTS = Int32
MC_BACKGROUND: win32more.Windows.Win32.UI.Controls.MONTHCALPARTS = 1
MC_BORDERS: win32more.Windows.Win32.UI.Controls.MONTHCALPARTS = 2
MC_GRIDBACKGROUND: win32more.Windows.Win32.UI.Controls.MONTHCALPARTS = 3
MC_COLHEADERSPLITTER: win32more.Windows.Win32.UI.Controls.MONTHCALPARTS = 4
MC_GRIDCELLBACKGROUND: win32more.Windows.Win32.UI.Controls.MONTHCALPARTS = 5
MC_GRIDCELL: win32more.Windows.Win32.UI.Controls.MONTHCALPARTS = 6
MC_GRIDCELLUPPER: win32more.Windows.Win32.UI.Controls.MONTHCALPARTS = 7
MC_TRAILINGGRIDCELL: win32more.Windows.Win32.UI.Controls.MONTHCALPARTS = 8
MC_TRAILINGGRIDCELLUPPER: win32more.Windows.Win32.UI.Controls.MONTHCALPARTS = 9
MC_NAVNEXT: win32more.Windows.Win32.UI.Controls.MONTHCALPARTS = 10
MC_NAVPREV: win32more.Windows.Win32.UI.Controls.MONTHCALPARTS = 11
MONTH_CALDENDAR_MESSAGES_VIEW = UInt32
MCMV_MONTH: win32more.Windows.Win32.UI.Controls.MONTH_CALDENDAR_MESSAGES_VIEW = 0
MCMV_YEAR: win32more.Windows.Win32.UI.Controls.MONTH_CALDENDAR_MESSAGES_VIEW = 1
MCMV_DECADE: win32more.Windows.Win32.UI.Controls.MONTH_CALDENDAR_MESSAGES_VIEW = 2
MCMV_CENTURY: win32more.Windows.Win32.UI.Controls.MONTH_CALDENDAR_MESSAGES_VIEW = 3
MCMV_MAX: win32more.Windows.Win32.UI.Controls.MONTH_CALDENDAR_MESSAGES_VIEW = 3
MOREPROGRAMSARROWBACKSTATES = Int32
SPSB_NORMAL: win32more.Windows.Win32.UI.Controls.MOREPROGRAMSARROWBACKSTATES = 1
SPSB_HOT: win32more.Windows.Win32.UI.Controls.MOREPROGRAMSARROWBACKSTATES = 2
SPSB_PRESSED: win32more.Windows.Win32.UI.Controls.MOREPROGRAMSARROWBACKSTATES = 3
MOREPROGRAMSARROWSTATES = Int32
SPS_NORMAL: win32more.Windows.Win32.UI.Controls.MOREPROGRAMSARROWSTATES = 1
SPS_HOT: win32more.Windows.Win32.UI.Controls.MOREPROGRAMSARROWSTATES = 2
SPS_PRESSED: win32more.Windows.Win32.UI.Controls.MOREPROGRAMSARROWSTATES = 3
MOREPROGRAMSTABSTATES = Int32
SPMPT_NORMAL: win32more.Windows.Win32.UI.Controls.MOREPROGRAMSTABSTATES = 1
SPMPT_HOT: win32more.Windows.Win32.UI.Controls.MOREPROGRAMSTABSTATES = 2
SPMPT_SELECTED: win32more.Windows.Win32.UI.Controls.MOREPROGRAMSTABSTATES = 3
SPMPT_DISABLED: win32more.Windows.Win32.UI.Controls.MOREPROGRAMSTABSTATES = 4
SPMPT_FOCUSED: win32more.Windows.Win32.UI.Controls.MOREPROGRAMSTABSTATES = 5
MOVESTATES = Int32
DDMOVE_HIGHLIGHT: win32more.Windows.Win32.UI.Controls.MOVESTATES = 1
DDMOVE_NOHIGHLIGHT: win32more.Windows.Win32.UI.Controls.MOVESTATES = 2
NAVIGATIONPARTS = Int32
NAV_BACKBUTTON: win32more.Windows.Win32.UI.Controls.NAVIGATIONPARTS = 1
NAV_FORWARDBUTTON: win32more.Windows.Win32.UI.Controls.NAVIGATIONPARTS = 2
NAV_MENUBUTTON: win32more.Windows.Win32.UI.Controls.NAVIGATIONPARTS = 3
NAVNEXTSTATES = Int32
MCNN_NORMAL: win32more.Windows.Win32.UI.Controls.NAVNEXTSTATES = 1
MCNN_HOT: win32more.Windows.Win32.UI.Controls.NAVNEXTSTATES = 2
MCNN_PRESSED: win32more.Windows.Win32.UI.Controls.NAVNEXTSTATES = 3
MCNN_DISABLED: win32more.Windows.Win32.UI.Controls.NAVNEXTSTATES = 4
NAVPREVSTATES = Int32
MCNP_NORMAL: win32more.Windows.Win32.UI.Controls.NAVPREVSTATES = 1
MCNP_HOT: win32more.Windows.Win32.UI.Controls.NAVPREVSTATES = 2
MCNP_PRESSED: win32more.Windows.Win32.UI.Controls.NAVPREVSTATES = 3
MCNP_DISABLED: win32more.Windows.Win32.UI.Controls.NAVPREVSTATES = 4
NAV_BACKBUTTONSTATES = Int32
NAV_BB_NORMAL: win32more.Windows.Win32.UI.Controls.NAV_BACKBUTTONSTATES = 1
NAV_BB_HOT: win32more.Windows.Win32.UI.Controls.NAV_BACKBUTTONSTATES = 2
NAV_BB_PRESSED: win32more.Windows.Win32.UI.Controls.NAV_BACKBUTTONSTATES = 3
NAV_BB_DISABLED: win32more.Windows.Win32.UI.Controls.NAV_BACKBUTTONSTATES = 4
NAV_FORWARDBUTTONSTATES = Int32
NAV_FB_NORMAL: win32more.Windows.Win32.UI.Controls.NAV_FORWARDBUTTONSTATES = 1
NAV_FB_HOT: win32more.Windows.Win32.UI.Controls.NAV_FORWARDBUTTONSTATES = 2
NAV_FB_PRESSED: win32more.Windows.Win32.UI.Controls.NAV_FORWARDBUTTONSTATES = 3
NAV_FB_DISABLED: win32more.Windows.Win32.UI.Controls.NAV_FORWARDBUTTONSTATES = 4
NAV_MENUBUTTONSTATES = Int32
NAV_MB_NORMAL: win32more.Windows.Win32.UI.Controls.NAV_MENUBUTTONSTATES = 1
NAV_MB_HOT: win32more.Windows.Win32.UI.Controls.NAV_MENUBUTTONSTATES = 2
NAV_MB_PRESSED: win32more.Windows.Win32.UI.Controls.NAV_MENUBUTTONSTATES = 3
NAV_MB_DISABLED: win32more.Windows.Win32.UI.Controls.NAV_MENUBUTTONSTATES = 4
class NMBCDROPDOWN(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    rcButton: win32more.Windows.Win32.Foundation.RECT
class NMBCHOTITEM(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    dwFlags: win32more.Windows.Win32.UI.Controls.NMTBHOTITEM_FLAGS
class NMCBEDRAGBEGINA(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iItemid: Int32
    szText: win32more.Windows.Win32.Foundation.CHAR * 260
class NMCBEDRAGBEGINW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iItemid: Int32
    szText: Char * 260
NMCBEDRAGBEGIN = UnicodeAlias('NMCBEDRAGBEGINW')
class NMCBEENDEDITA(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    fChanged: win32more.Windows.Win32.Foundation.BOOL
    iNewSelection: Int32
    szText: win32more.Windows.Win32.Foundation.CHAR * 260
    iWhy: Int32
class NMCBEENDEDITW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    fChanged: win32more.Windows.Win32.Foundation.BOOL
    iNewSelection: Int32
    szText: Char * 260
    iWhy: Int32
NMCBEENDEDIT = UnicodeAlias('NMCBEENDEDITW')
class NMCHAR(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    ch: UInt32
    dwItemPrev: UInt32
    dwItemNext: UInt32
class NMCOMBOBOXEXA(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    ceItem: win32more.Windows.Win32.UI.Controls.COMBOBOXEXITEMA
class NMCOMBOBOXEXW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    ceItem: win32more.Windows.Win32.UI.Controls.COMBOBOXEXITEMW
NMCOMBOBOXEX = UnicodeAlias('NMCOMBOBOXEXW')
class NMCUSTOMDRAW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    dwDrawStage: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STAGE
    hdc: win32more.Windows.Win32.Graphics.Gdi.HDC
    rc: win32more.Windows.Win32.Foundation.RECT
    dwItemSpec: UIntPtr
    uItemState: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STATE_FLAGS
    lItemlParam: win32more.Windows.Win32.Foundation.LPARAM
NMCUSTOMDRAW_DRAW_STAGE = UInt32
CDDS_POSTPAINT: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STAGE = 2
CDDS_PREERASE: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STAGE = 3
CDDS_PREPAINT: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STAGE = 1
CDDS_ITEMPOSTERASE: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STAGE = 65540
CDDS_ITEMPOSTPAINT: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STAGE = 65538
CDDS_ITEMPREERASE: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STAGE = 65539
CDDS_ITEMPREPAINT: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STAGE = 65537
CDDS_SUBITEM: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STAGE = 131072
NMCUSTOMDRAW_DRAW_STATE_FLAGS = UInt32
CDIS_SELECTED: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STATE_FLAGS = 1
CDIS_GRAYED: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STATE_FLAGS = 2
CDIS_DISABLED: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STATE_FLAGS = 4
CDIS_CHECKED: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STATE_FLAGS = 8
CDIS_FOCUS: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STATE_FLAGS = 16
CDIS_DEFAULT: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STATE_FLAGS = 32
CDIS_HOT: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STATE_FLAGS = 64
CDIS_MARKED: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STATE_FLAGS = 128
CDIS_INDETERMINATE: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STATE_FLAGS = 256
CDIS_SHOWKEYBOARDCUES: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STATE_FLAGS = 512
CDIS_NEARHOT: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STATE_FLAGS = 1024
CDIS_OTHERSIDEHOT: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STATE_FLAGS = 2048
CDIS_DROPHILITED: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW_DRAW_STATE_FLAGS = 4096
class NMCUSTOMSPLITRECTINFO(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    rcClient: win32more.Windows.Win32.Foundation.RECT
    rcButton: win32more.Windows.Win32.Foundation.RECT
    rcSplit: win32more.Windows.Win32.Foundation.RECT
class NMCUSTOMTEXT(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    hDC: win32more.Windows.Win32.Graphics.Gdi.HDC
    lpString: win32more.Windows.Win32.Foundation.PWSTR
    nCount: Int32
    lpRect: POINTER(win32more.Windows.Win32.Foundation.RECT)
    uFormat: UInt32
    fLink: win32more.Windows.Win32.Foundation.BOOL
class NMDATETIMECHANGE(Structure):
    nmhdr: win32more.Windows.Win32.UI.Controls.NMHDR
    dwFlags: win32more.Windows.Win32.UI.Controls.NMDATETIMECHANGE_FLAGS
    st: win32more.Windows.Win32.Foundation.SYSTEMTIME
NMDATETIMECHANGE_FLAGS = UInt32
GDT_NONE: win32more.Windows.Win32.UI.Controls.NMDATETIMECHANGE_FLAGS = 1
GDT_VALID: win32more.Windows.Win32.UI.Controls.NMDATETIMECHANGE_FLAGS = 0
class NMDATETIMEFORMATA(Structure):
    nmhdr: win32more.Windows.Win32.UI.Controls.NMHDR
    pszFormat: win32more.Windows.Win32.Foundation.PSTR
    st: win32more.Windows.Win32.Foundation.SYSTEMTIME
    pszDisplay: win32more.Windows.Win32.Foundation.PSTR
    szDisplay: win32more.Windows.Win32.Foundation.CHAR * 64
class NMDATETIMEFORMATQUERYA(Structure):
    nmhdr: win32more.Windows.Win32.UI.Controls.NMHDR
    pszFormat: win32more.Windows.Win32.Foundation.PSTR
    szMax: win32more.Windows.Win32.Foundation.SIZE
class NMDATETIMEFORMATQUERYW(Structure):
    nmhdr: win32more.Windows.Win32.UI.Controls.NMHDR
    pszFormat: win32more.Windows.Win32.Foundation.PWSTR
    szMax: win32more.Windows.Win32.Foundation.SIZE
NMDATETIMEFORMATQUERY = UnicodeAlias('NMDATETIMEFORMATQUERYW')
class NMDATETIMEFORMATW(Structure):
    nmhdr: win32more.Windows.Win32.UI.Controls.NMHDR
    pszFormat: win32more.Windows.Win32.Foundation.PWSTR
    st: win32more.Windows.Win32.Foundation.SYSTEMTIME
    pszDisplay: win32more.Windows.Win32.Foundation.PWSTR
    szDisplay: Char * 64
NMDATETIMEFORMAT = UnicodeAlias('NMDATETIMEFORMATW')
class NMDATETIMESTRINGA(Structure):
    nmhdr: win32more.Windows.Win32.UI.Controls.NMHDR
    pszUserString: win32more.Windows.Win32.Foundation.PSTR
    st: win32more.Windows.Win32.Foundation.SYSTEMTIME
    dwFlags: UInt32
class NMDATETIMESTRINGW(Structure):
    nmhdr: win32more.Windows.Win32.UI.Controls.NMHDR
    pszUserString: win32more.Windows.Win32.Foundation.PWSTR
    st: win32more.Windows.Win32.Foundation.SYSTEMTIME
    dwFlags: UInt32
NMDATETIMESTRING = UnicodeAlias('NMDATETIMESTRINGW')
class NMDATETIMEWMKEYDOWNA(Structure):
    nmhdr: win32more.Windows.Win32.UI.Controls.NMHDR
    nVirtKey: Int32
    pszFormat: win32more.Windows.Win32.Foundation.PSTR
    st: win32more.Windows.Win32.Foundation.SYSTEMTIME
class NMDATETIMEWMKEYDOWNW(Structure):
    nmhdr: win32more.Windows.Win32.UI.Controls.NMHDR
    nVirtKey: Int32
    pszFormat: win32more.Windows.Win32.Foundation.PWSTR
    st: win32more.Windows.Win32.Foundation.SYSTEMTIME
NMDATETIMEWMKEYDOWN = UnicodeAlias('NMDATETIMEWMKEYDOWNW')
class NMDAYSTATE(Structure):
    nmhdr: win32more.Windows.Win32.UI.Controls.NMHDR
    stStart: win32more.Windows.Win32.Foundation.SYSTEMTIME
    cDayState: Int32
    prgDayState: POINTER(UInt32)
class NMHDDISPINFOA(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iItem: Int32
    mask: win32more.Windows.Win32.UI.Controls.HDI_MASK
    pszText: win32more.Windows.Win32.Foundation.PSTR
    cchTextMax: Int32
    iImage: Int32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
class NMHDDISPINFOW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iItem: Int32
    mask: win32more.Windows.Win32.UI.Controls.HDI_MASK
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    cchTextMax: Int32
    iImage: Int32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
NMHDDISPINFO = UnicodeAlias('NMHDDISPINFOW')
class NMHDFILTERBTNCLICK(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iItem: Int32
    rc: win32more.Windows.Win32.Foundation.RECT
class NMHDR(Structure):
    hwndFrom: win32more.Windows.Win32.Foundation.HWND
    idFrom: UIntPtr
    code: UInt32
class NMHEADERA(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iItem: Int32
    iButton: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_NOTIFICATION_BUTTON
    pitem: POINTER(win32more.Windows.Win32.UI.Controls.HDITEMA)
class NMHEADERW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iItem: Int32
    iButton: win32more.Windows.Win32.UI.Controls.HEADER_CONTROL_NOTIFICATION_BUTTON
    pitem: POINTER(win32more.Windows.Win32.UI.Controls.HDITEMW)
NMHEADER = UnicodeAlias('NMHEADERW')
class NMIPADDRESS(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iField: Int32
    iValue: Int32
class NMITEMACTIVATE(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iItem: Int32
    iSubItem: Int32
    uNewState: UInt32
    uOldState: UInt32
    uChanged: UInt32
    ptAction: win32more.Windows.Win32.Foundation.POINT
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    uKeyFlags: UInt32
class NMKEY(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    nVKey: UInt32
    uFlags: UInt32
class NMLINK(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    item: win32more.Windows.Win32.UI.Controls.LITEM
class NMLISTVIEW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iItem: Int32
    iSubItem: Int32
    uNewState: UInt32
    uOldState: UInt32
    uChanged: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_FLAGS
    ptAction: win32more.Windows.Win32.Foundation.POINT
    lParam: win32more.Windows.Win32.Foundation.LPARAM
class NMLVCACHEHINT(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iFrom: Int32
    iTo: Int32
class NMLVCUSTOMDRAW(Structure):
    nmcd: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW
    clrText: win32more.Windows.Win32.Foundation.COLORREF
    clrTextBk: win32more.Windows.Win32.Foundation.COLORREF
    iSubItem: Int32
    dwItemType: win32more.Windows.Win32.UI.Controls.NMLVCUSTOMDRAW_ITEM_TYPE
    clrFace: win32more.Windows.Win32.Foundation.COLORREF
    iIconEffect: Int32
    iIconPhase: Int32
    iPartId: Int32
    iStateId: Int32
    rcText: win32more.Windows.Win32.Foundation.RECT
    uAlign: win32more.Windows.Win32.UI.Controls.LIST_VIEW_GROUP_ALIGN_FLAGS
NMLVCUSTOMDRAW_ITEM_TYPE = UInt32
LVCDI_ITEM: win32more.Windows.Win32.UI.Controls.NMLVCUSTOMDRAW_ITEM_TYPE = 0
LVCDI_GROUP: win32more.Windows.Win32.UI.Controls.NMLVCUSTOMDRAW_ITEM_TYPE = 1
LVCDI_ITEMSLIST: win32more.Windows.Win32.UI.Controls.NMLVCUSTOMDRAW_ITEM_TYPE = 2
class NMLVDISPINFOA(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    item: win32more.Windows.Win32.UI.Controls.LVITEMA
class NMLVDISPINFOW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    item: win32more.Windows.Win32.UI.Controls.LVITEMW
NMLVDISPINFO = UnicodeAlias('NMLVDISPINFOW')
class NMLVEMPTYMARKUP(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    dwFlags: win32more.Windows.Win32.UI.Controls.NMLVEMPTYMARKUP_FLAGS
    szMarkup: Char * 2084
NMLVEMPTYMARKUP_FLAGS = UInt32
EMF_CENTERED: win32more.Windows.Win32.UI.Controls.NMLVEMPTYMARKUP_FLAGS = 1
class NMLVFINDITEMA(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iStart: Int32
    lvfi: win32more.Windows.Win32.UI.Controls.LVFINDINFOA
class NMLVFINDITEMW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iStart: Int32
    lvfi: win32more.Windows.Win32.UI.Controls.LVFINDINFOW
NMLVFINDITEM = UnicodeAlias('NMLVFINDITEMW')
class NMLVGETINFOTIPA(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    dwFlags: win32more.Windows.Win32.UI.Controls.NMLVGETINFOTIP_FLAGS
    pszText: win32more.Windows.Win32.Foundation.PSTR
    cchTextMax: Int32
    iItem: Int32
    iSubItem: Int32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
class NMLVGETINFOTIPW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    dwFlags: win32more.Windows.Win32.UI.Controls.NMLVGETINFOTIP_FLAGS
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    cchTextMax: Int32
    iItem: Int32
    iSubItem: Int32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
NMLVGETINFOTIP = UnicodeAlias('NMLVGETINFOTIPW')
NMLVGETINFOTIP_FLAGS = UInt32
LVGIT_UNFOLDED: win32more.Windows.Win32.UI.Controls.NMLVGETINFOTIP_FLAGS = 1
LVGIT_ZERO: win32more.Windows.Win32.UI.Controls.NMLVGETINFOTIP_FLAGS = 0
class NMLVKEYDOWN(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    wVKey: UInt16
    flags: UInt32
    _pack_ = 1
class NMLVLINK(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    link: win32more.Windows.Win32.UI.Controls.LITEM
    iItem: Int32
    iSubItem: Int32
class NMLVODSTATECHANGE(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iFrom: Int32
    iTo: Int32
    uNewState: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_STATE_FLAGS
    uOldState: win32more.Windows.Win32.UI.Controls.LIST_VIEW_ITEM_STATE_FLAGS
class NMLVSCROLL(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    dx: Int32
    dy: Int32
class NMMOUSE(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    dwItemSpec: UIntPtr
    dwItemData: UIntPtr
    pt: win32more.Windows.Win32.Foundation.POINT
    dwHitInfo: win32more.Windows.Win32.Foundation.LPARAM
class NMOBJECTNOTIFY(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iItem: Int32
    piid: POINTER(Guid)
    pObject: VoidPtr
    hResult: win32more.Windows.Win32.Foundation.HRESULT
    dwFlags: UInt32
class NMPGCALCSIZE(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    dwFlag: win32more.Windows.Win32.UI.Controls.NMPGCALCSIZE_FLAGS
    iWidth: Int32
    iHeight: Int32
NMPGCALCSIZE_FLAGS = UInt32
PGF_CALCHEIGHT: win32more.Windows.Win32.UI.Controls.NMPGCALCSIZE_FLAGS = 2
PGF_CALCWIDTH: win32more.Windows.Win32.UI.Controls.NMPGCALCSIZE_FLAGS = 1
class NMPGHOTITEM(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    idOld: Int32
    idNew: Int32
    dwFlags: UInt32
class NMPGSCROLL(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    fwKeys: win32more.Windows.Win32.UI.Controls.NMPGSCROLL_KEYS
    rcParent: win32more.Windows.Win32.Foundation.RECT
    iDir: win32more.Windows.Win32.UI.Controls.NMPGSCROLL_DIR
    iXpos: Int32
    iYpos: Int32
    iScroll: Int32
    _pack_ = 1
NMPGSCROLL_DIR = Int32
PGF_SCROLLDOWN: win32more.Windows.Win32.UI.Controls.NMPGSCROLL_DIR = 2
PGF_SCROLLLEFT: win32more.Windows.Win32.UI.Controls.NMPGSCROLL_DIR = 4
PGF_SCROLLRIGHT: win32more.Windows.Win32.UI.Controls.NMPGSCROLL_DIR = 8
PGF_SCROLLUP: win32more.Windows.Win32.UI.Controls.NMPGSCROLL_DIR = 1
NMPGSCROLL_KEYS = UInt16
PGK_NONE: win32more.Windows.Win32.UI.Controls.NMPGSCROLL_KEYS = 0
PGK_SHIFT: win32more.Windows.Win32.UI.Controls.NMPGSCROLL_KEYS = 1
PGK_CONTROL: win32more.Windows.Win32.UI.Controls.NMPGSCROLL_KEYS = 2
PGK_MENU: win32more.Windows.Win32.UI.Controls.NMPGSCROLL_KEYS = 4
class NMRBAUTOSIZE(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    fChanged: win32more.Windows.Win32.Foundation.BOOL
    rcTarget: win32more.Windows.Win32.Foundation.RECT
    rcActual: win32more.Windows.Win32.Foundation.RECT
class NMREBAR(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    dwMask: win32more.Windows.Win32.UI.Controls.NMREBAR_MASK_FLAGS
    uBand: UInt32
    fStyle: UInt32
    wID: UInt32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
class NMREBARAUTOBREAK(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    uBand: UInt32
    wID: UInt32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    uMsg: UInt32
    fStyleCurrent: UInt32
    fAutoBreak: win32more.Windows.Win32.Foundation.BOOL
class NMREBARCHEVRON(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    uBand: UInt32
    wID: UInt32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    rc: win32more.Windows.Win32.Foundation.RECT
    lParamNM: win32more.Windows.Win32.Foundation.LPARAM
class NMREBARCHILDSIZE(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    uBand: UInt32
    wID: UInt32
    rcChild: win32more.Windows.Win32.Foundation.RECT
    rcBand: win32more.Windows.Win32.Foundation.RECT
class NMREBARSPLITTER(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    rcSizing: win32more.Windows.Win32.Foundation.RECT
NMREBAR_MASK_FLAGS = UInt32
RBNM_ID: win32more.Windows.Win32.UI.Controls.NMREBAR_MASK_FLAGS = 1
RBNM_LPARAM: win32more.Windows.Win32.UI.Controls.NMREBAR_MASK_FLAGS = 4
RBNM_STYLE: win32more.Windows.Win32.UI.Controls.NMREBAR_MASK_FLAGS = 2
class NMSEARCHWEB(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    entrypoint: win32more.Windows.Win32.UI.Controls.EC_SEARCHWEB_ENTRYPOINT
    hasQueryText: win32more.Windows.Win32.Foundation.BOOL
    invokeSucceeded: win32more.Windows.Win32.Foundation.BOOL
class NMSELCHANGE(Structure):
    nmhdr: win32more.Windows.Win32.UI.Controls.NMHDR
    stSelStart: win32more.Windows.Win32.Foundation.SYSTEMTIME
    stSelEnd: win32more.Windows.Win32.Foundation.SYSTEMTIME
class NMTBCUSTOMDRAW(Structure):
    nmcd: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW
    hbrMonoDither: win32more.Windows.Win32.Graphics.Gdi.HBRUSH
    hbrLines: win32more.Windows.Win32.Graphics.Gdi.HBRUSH
    hpenLines: win32more.Windows.Win32.Graphics.Gdi.HPEN
    clrText: win32more.Windows.Win32.Foundation.COLORREF
    clrMark: win32more.Windows.Win32.Foundation.COLORREF
    clrTextHighlight: win32more.Windows.Win32.Foundation.COLORREF
    clrBtnFace: win32more.Windows.Win32.Foundation.COLORREF
    clrBtnHighlight: win32more.Windows.Win32.Foundation.COLORREF
    clrHighlightHotTrack: win32more.Windows.Win32.Foundation.COLORREF
    rcText: win32more.Windows.Win32.Foundation.RECT
    nStringBkMode: Int32
    nHLStringBkMode: Int32
    iListGap: Int32
class NMTBDISPINFOA(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    dwMask: win32more.Windows.Win32.UI.Controls.NMTBDISPINFOW_MASK
    idCommand: Int32
    lParam: UIntPtr
    iImage: Int32
    pszText: win32more.Windows.Win32.Foundation.PSTR
    cchText: Int32
class NMTBDISPINFOW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    dwMask: win32more.Windows.Win32.UI.Controls.NMTBDISPINFOW_MASK
    idCommand: Int32
    lParam: UIntPtr
    iImage: Int32
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    cchText: Int32
NMTBDISPINFO = UnicodeAlias('NMTBDISPINFOW')
NMTBDISPINFOW_MASK = UInt32
TBNF_IMAGE: win32more.Windows.Win32.UI.Controls.NMTBDISPINFOW_MASK = 1
TBNF_TEXT: win32more.Windows.Win32.UI.Controls.NMTBDISPINFOW_MASK = 2
TBNF_DI_SETITEM: win32more.Windows.Win32.UI.Controls.NMTBDISPINFOW_MASK = 268435456
class NMTBGETINFOTIPA(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    pszText: win32more.Windows.Win32.Foundation.PSTR
    cchTextMax: Int32
    iItem: Int32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
class NMTBGETINFOTIPW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    cchTextMax: Int32
    iItem: Int32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
NMTBGETINFOTIP = UnicodeAlias('NMTBGETINFOTIPW')
class NMTBHOTITEM(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    idOld: Int32
    idNew: Int32
    dwFlags: win32more.Windows.Win32.UI.Controls.NMTBHOTITEM_FLAGS
NMTBHOTITEM_FLAGS = UInt32
HICF_ACCELERATOR: win32more.Windows.Win32.UI.Controls.NMTBHOTITEM_FLAGS = 4
HICF_ARROWKEYS: win32more.Windows.Win32.UI.Controls.NMTBHOTITEM_FLAGS = 2
HICF_DUPACCEL: win32more.Windows.Win32.UI.Controls.NMTBHOTITEM_FLAGS = 8
HICF_ENTERING: win32more.Windows.Win32.UI.Controls.NMTBHOTITEM_FLAGS = 16
HICF_LEAVING: win32more.Windows.Win32.UI.Controls.NMTBHOTITEM_FLAGS = 32
HICF_LMOUSE: win32more.Windows.Win32.UI.Controls.NMTBHOTITEM_FLAGS = 128
HICF_MOUSE: win32more.Windows.Win32.UI.Controls.NMTBHOTITEM_FLAGS = 1
HICF_OTHER: win32more.Windows.Win32.UI.Controls.NMTBHOTITEM_FLAGS = 0
HICF_RESELECT: win32more.Windows.Win32.UI.Controls.NMTBHOTITEM_FLAGS = 64
HICF_TOGGLEDROPDOWN: win32more.Windows.Win32.UI.Controls.NMTBHOTITEM_FLAGS = 256
class NMTBRESTORE(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    pData: POINTER(UInt32)
    pCurrent: POINTER(UInt32)
    cbData: UInt32
    iItem: Int32
    cButtons: Int32
    cbBytesPerRecord: Int32
    tbButton: win32more.Windows.Win32.UI.Controls.TBBUTTON
class NMTBSAVE(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    pData: POINTER(UInt32)
    pCurrent: POINTER(UInt32)
    cbData: UInt32
    iItem: Int32
    cButtons: Int32
    tbButton: win32more.Windows.Win32.UI.Controls.TBBUTTON
class NMTCKEYDOWN(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    wVKey: UInt16
    flags: UInt32
    _pack_ = 1
class NMTOOLBARA(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iItem: Int32
    tbButton: win32more.Windows.Win32.UI.Controls.TBBUTTON
    cchText: Int32
    pszText: win32more.Windows.Win32.Foundation.PSTR
    rcButton: win32more.Windows.Win32.Foundation.RECT
class NMTOOLBARW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iItem: Int32
    tbButton: win32more.Windows.Win32.UI.Controls.TBBUTTON
    cchText: Int32
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    rcButton: win32more.Windows.Win32.Foundation.RECT
NMTOOLBAR = UnicodeAlias('NMTOOLBARW')
class NMTOOLTIPSCREATED(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    hwndToolTips: win32more.Windows.Win32.Foundation.HWND
class NMTRBTHUMBPOSCHANGING(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    dwPos: UInt32
    nReason: Int32
class NMTREEVIEWA(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    action: win32more.Windows.Win32.UI.Controls.NM_TREEVIEW_ACTION
    itemOld: win32more.Windows.Win32.UI.Controls.TVITEMA
    itemNew: win32more.Windows.Win32.UI.Controls.TVITEMA
    ptDrag: win32more.Windows.Win32.Foundation.POINT
class NMTREEVIEWW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    action: win32more.Windows.Win32.UI.Controls.NM_TREEVIEW_ACTION
    itemOld: win32more.Windows.Win32.UI.Controls.TVITEMW
    itemNew: win32more.Windows.Win32.UI.Controls.TVITEMW
    ptDrag: win32more.Windows.Win32.Foundation.POINT
NMTREEVIEW = UnicodeAlias('NMTREEVIEWW')
class NMTTCUSTOMDRAW(Structure):
    nmcd: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW
    uDrawFlags: UInt32
class NMTTDISPINFOA(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    lpszText: win32more.Windows.Win32.Foundation.PSTR
    szText: win32more.Windows.Win32.Foundation.CHAR * 80
    hinst: win32more.Windows.Win32.Foundation.HINSTANCE
    uFlags: win32more.Windows.Win32.UI.Controls.TOOLTIP_FLAGS
    lParam: win32more.Windows.Win32.Foundation.LPARAM
class NMTTDISPINFOW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    lpszText: win32more.Windows.Win32.Foundation.PWSTR
    szText: Char * 80
    hinst: win32more.Windows.Win32.Foundation.HINSTANCE
    uFlags: win32more.Windows.Win32.UI.Controls.TOOLTIP_FLAGS
    lParam: win32more.Windows.Win32.Foundation.LPARAM
NMTTDISPINFO = UnicodeAlias('NMTTDISPINFOW')
class NMTVASYNCDRAW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    pimldp: POINTER(win32more.Windows.Win32.UI.Controls.IMAGELISTDRAWPARAMS)
    hr: win32more.Windows.Win32.Foundation.HRESULT
    hItem: win32more.Windows.Win32.UI.Controls.HTREEITEM
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    dwRetFlags: UInt32
    iRetImageIndex: Int32
class NMTVCUSTOMDRAW(Structure):
    nmcd: win32more.Windows.Win32.UI.Controls.NMCUSTOMDRAW
    clrText: win32more.Windows.Win32.Foundation.COLORREF
    clrTextBk: win32more.Windows.Win32.Foundation.COLORREF
    iLevel: Int32
class NMTVDISPINFOA(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    item: win32more.Windows.Win32.UI.Controls.TVITEMA
class NMTVDISPINFOEXA(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    item: win32more.Windows.Win32.UI.Controls.TVITEMEXA
class NMTVDISPINFOEXW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    item: win32more.Windows.Win32.UI.Controls.TVITEMEXW
NMTVDISPINFOEX = UnicodeAlias('NMTVDISPINFOEXW')
class NMTVDISPINFOW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    item: win32more.Windows.Win32.UI.Controls.TVITEMW
NMTVDISPINFO = UnicodeAlias('NMTVDISPINFOW')
class NMTVGETINFOTIPA(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    pszText: win32more.Windows.Win32.Foundation.PSTR
    cchTextMax: Int32
    hItem: win32more.Windows.Win32.UI.Controls.HTREEITEM
    lParam: win32more.Windows.Win32.Foundation.LPARAM
class NMTVGETINFOTIPW(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    cchTextMax: Int32
    hItem: win32more.Windows.Win32.UI.Controls.HTREEITEM
    lParam: win32more.Windows.Win32.Foundation.LPARAM
NMTVGETINFOTIP = UnicodeAlias('NMTVGETINFOTIPW')
class NMTVITEMCHANGE(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    uChanged: UInt32
    hItem: win32more.Windows.Win32.UI.Controls.HTREEITEM
    uStateNew: UInt32
    uStateOld: UInt32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
class NMTVKEYDOWN(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    wVKey: UInt16
    flags: UInt32
    _pack_ = 1
class NMTVSTATEIMAGECHANGING(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    hti: win32more.Windows.Win32.UI.Controls.HTREEITEM
    iOldStateImageIndex: Int32
    iNewStateImageIndex: Int32
class NMUPDOWN(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    iPos: Int32
    iDelta: Int32
class NMVIEWCHANGE(Structure):
    nmhdr: win32more.Windows.Win32.UI.Controls.NMHDR
    dwOldView: win32more.Windows.Win32.UI.Controls.MONTH_CALDENDAR_MESSAGES_VIEW
    dwNewView: win32more.Windows.Win32.UI.Controls.MONTH_CALDENDAR_MESSAGES_VIEW
NM_TREEVIEW_ACTION = UInt32
TVE_COLLAPSE: win32more.Windows.Win32.UI.Controls.NM_TREEVIEW_ACTION = 1
TVE_EXPAND: win32more.Windows.Win32.UI.Controls.NM_TREEVIEW_ACTION = 2
TVE_TOGGLE: win32more.Windows.Win32.UI.Controls.NM_TREEVIEW_ACTION = 3
TVE_EXPANDPARTIAL: win32more.Windows.Win32.UI.Controls.NM_TREEVIEW_ACTION = 16384
TVE_COLLAPSERESET: win32more.Windows.Win32.UI.Controls.NM_TREEVIEW_ACTION = 32768
TVC_UNKNOWN: win32more.Windows.Win32.UI.Controls.NM_TREEVIEW_ACTION = 0
TVC_BYMOUSE: win32more.Windows.Win32.UI.Controls.NM_TREEVIEW_ACTION = 1
TVC_BYKEYBOARD: win32more.Windows.Win32.UI.Controls.NM_TREEVIEW_ACTION = 2
NONESTATES = Int32
DDNONE_HIGHLIGHT: win32more.Windows.Win32.UI.Controls.NONESTATES = 1
DDNONE_NOHIGHLIGHT: win32more.Windows.Win32.UI.Controls.NONESTATES = 2
NORMALGROUPCOLLAPSESTATES = Int32
EBNGC_NORMAL: win32more.Windows.Win32.UI.Controls.NORMALGROUPCOLLAPSESTATES = 1
EBNGC_HOT: win32more.Windows.Win32.UI.Controls.NORMALGROUPCOLLAPSESTATES = 2
EBNGC_PRESSED: win32more.Windows.Win32.UI.Controls.NORMALGROUPCOLLAPSESTATES = 3
NORMALGROUPEXPANDSTATES = Int32
EBNGE_NORMAL: win32more.Windows.Win32.UI.Controls.NORMALGROUPEXPANDSTATES = 1
EBNGE_HOT: win32more.Windows.Win32.UI.Controls.NORMALGROUPEXPANDSTATES = 2
EBNGE_PRESSED: win32more.Windows.Win32.UI.Controls.NORMALGROUPEXPANDSTATES = 3
ODA_FLAGS = UInt32
ODA_DRAWENTIRE: win32more.Windows.Win32.UI.Controls.ODA_FLAGS = 1
ODA_SELECT: win32more.Windows.Win32.UI.Controls.ODA_FLAGS = 2
ODA_FOCUS: win32more.Windows.Win32.UI.Controls.ODA_FLAGS = 4
ODS_FLAGS = UInt32
ODS_SELECTED: win32more.Windows.Win32.UI.Controls.ODS_FLAGS = 1
ODS_GRAYED: win32more.Windows.Win32.UI.Controls.ODS_FLAGS = 2
ODS_DISABLED: win32more.Windows.Win32.UI.Controls.ODS_FLAGS = 4
ODS_CHECKED: win32more.Windows.Win32.UI.Controls.ODS_FLAGS = 8
ODS_FOCUS: win32more.Windows.Win32.UI.Controls.ODS_FLAGS = 16
ODS_DEFAULT: win32more.Windows.Win32.UI.Controls.ODS_FLAGS = 32
ODS_COMBOBOXEDIT: win32more.Windows.Win32.UI.Controls.ODS_FLAGS = 4096
ODS_HOTLIGHT: win32more.Windows.Win32.UI.Controls.ODS_FLAGS = 64
ODS_INACTIVE: win32more.Windows.Win32.UI.Controls.ODS_FLAGS = 128
ODS_NOACCEL: win32more.Windows.Win32.UI.Controls.ODS_FLAGS = 256
ODS_NOFOCUSRECT: win32more.Windows.Win32.UI.Controls.ODS_FLAGS = 512
OFFSETTYPE = Int32
OT_TOPLEFT: win32more.Windows.Win32.UI.Controls.OFFSETTYPE = 0
OT_TOPRIGHT: win32more.Windows.Win32.UI.Controls.OFFSETTYPE = 1
OT_TOPMIDDLE: win32more.Windows.Win32.UI.Controls.OFFSETTYPE = 2
OT_BOTTOMLEFT: win32more.Windows.Win32.UI.Controls.OFFSETTYPE = 3
OT_BOTTOMRIGHT: win32more.Windows.Win32.UI.Controls.OFFSETTYPE = 4
OT_BOTTOMMIDDLE: win32more.Windows.Win32.UI.Controls.OFFSETTYPE = 5
OT_MIDDLELEFT: win32more.Windows.Win32.UI.Controls.OFFSETTYPE = 6
OT_MIDDLERIGHT: win32more.Windows.Win32.UI.Controls.OFFSETTYPE = 7
OT_LEFTOFCAPTION: win32more.Windows.Win32.UI.Controls.OFFSETTYPE = 8
OT_RIGHTOFCAPTION: win32more.Windows.Win32.UI.Controls.OFFSETTYPE = 9
OT_LEFTOFLASTBUTTON: win32more.Windows.Win32.UI.Controls.OFFSETTYPE = 10
OT_RIGHTOFLASTBUTTON: win32more.Windows.Win32.UI.Controls.OFFSETTYPE = 11
OT_ABOVELASTBUTTON: win32more.Windows.Win32.UI.Controls.OFFSETTYPE = 12
OT_BELOWLASTBUTTON: win32more.Windows.Win32.UI.Controls.OFFSETTYPE = 13
OPENBOXSTATES = Int32
SPOB_NORMAL: win32more.Windows.Win32.UI.Controls.OPENBOXSTATES = 1
SPOB_HOT: win32more.Windows.Win32.UI.Controls.OPENBOXSTATES = 2
SPOB_SELECTED: win32more.Windows.Win32.UI.Controls.OPENBOXSTATES = 3
SPOB_DISABLED: win32more.Windows.Win32.UI.Controls.OPENBOXSTATES = 4
SPOB_FOCUSED: win32more.Windows.Win32.UI.Controls.OPENBOXSTATES = 5
OPEN_THEME_DATA_FLAGS = UInt32
OTD_FORCE_RECT_SIZING: win32more.Windows.Win32.UI.Controls.OPEN_THEME_DATA_FLAGS = 1
OTD_NONCLIENT: win32more.Windows.Win32.UI.Controls.OPEN_THEME_DATA_FLAGS = 2
PAGEPARTS = Int32
PGRP_UP: win32more.Windows.Win32.UI.Controls.PAGEPARTS = 1
PGRP_DOWN: win32more.Windows.Win32.UI.Controls.PAGEPARTS = 2
PGRP_UPHORZ: win32more.Windows.Win32.UI.Controls.PAGEPARTS = 3
PGRP_DOWNHORZ: win32more.Windows.Win32.UI.Controls.PAGEPARTS = 4
class PBRANGE(Structure):
    iLow: Int32
    iHigh: Int32
@winfunctype_pointer
def PFNDACOMPARE(p1: VoidPtr, p2: VoidPtr, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype_pointer
def PFNDACOMPARECONST(p1: VoidPtr, p2: VoidPtr, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype_pointer
def PFNDAENUMCALLBACK(p: VoidPtr, pData: VoidPtr) -> Int32: ...
@winfunctype_pointer
def PFNDAENUMCALLBACKCONST(p: VoidPtr, pData: VoidPtr) -> Int32: ...
@winfunctype_pointer
def PFNDPAMERGE(uMsg: win32more.Windows.Win32.UI.Controls.DPAMM_MESSAGE, pvDest: VoidPtr, pvSrc: VoidPtr, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> VoidPtr: ...
@winfunctype_pointer
def PFNDPAMERGECONST(uMsg: win32more.Windows.Win32.UI.Controls.DPAMM_MESSAGE, pvDest: VoidPtr, pvSrc: VoidPtr, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> VoidPtr: ...
@winfunctype_pointer
def PFNDPASTREAM(pinfo: POINTER(win32more.Windows.Win32.UI.Controls.DPASTREAMINFO), pstream: win32more.Windows.Win32.System.Com.IStream, pvInstData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFNLVCOMPARE(param0: win32more.Windows.Win32.Foundation.LPARAM, param1: win32more.Windows.Win32.Foundation.LPARAM, param2: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype_pointer
def PFNLVGROUPCOMPARE(param0: Int32, param1: Int32, param2: VoidPtr) -> Int32: ...
@winfunctype_pointer
def PFNPROPSHEETCALLBACK(param0: win32more.Windows.Win32.Foundation.HWND, param1: UInt32, param2: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype_pointer
def PFNTVCOMPARE(lParam1: win32more.Windows.Win32.Foundation.LPARAM, lParam2: win32more.Windows.Win32.Foundation.LPARAM, lParamSort: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype_pointer
def PFTASKDIALOGCALLBACK(hwnd: win32more.Windows.Win32.Foundation.HWND, msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM, lpRefData: IntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class POINTER_DEVICE_CURSOR_INFO(Structure):
    cursorId: UInt32
    cursor: win32more.Windows.Win32.UI.Controls.POINTER_DEVICE_CURSOR_TYPE
POINTER_DEVICE_CURSOR_TYPE = Int32
POINTER_DEVICE_CURSOR_TYPE_UNKNOWN: win32more.Windows.Win32.UI.Controls.POINTER_DEVICE_CURSOR_TYPE = 0
POINTER_DEVICE_CURSOR_TYPE_TIP: win32more.Windows.Win32.UI.Controls.POINTER_DEVICE_CURSOR_TYPE = 1
POINTER_DEVICE_CURSOR_TYPE_ERASER: win32more.Windows.Win32.UI.Controls.POINTER_DEVICE_CURSOR_TYPE = 2
POINTER_DEVICE_CURSOR_TYPE_MAX: win32more.Windows.Win32.UI.Controls.POINTER_DEVICE_CURSOR_TYPE = -1
class POINTER_DEVICE_INFO(Structure):
    displayOrientation: UInt32
    device: win32more.Windows.Win32.Foundation.HANDLE
    pointerDeviceType: win32more.Windows.Win32.UI.Controls.POINTER_DEVICE_TYPE
    monitor: win32more.Windows.Win32.Graphics.Gdi.HMONITOR
    startingCursorId: UInt32
    maxActiveContacts: UInt16
    productString: Char * 520
class POINTER_DEVICE_PROPERTY(Structure):
    logicalMin: Int32
    logicalMax: Int32
    physicalMin: Int32
    physicalMax: Int32
    unit: UInt32
    unitExponent: UInt32
    usagePageId: UInt16
    usageId: UInt16
POINTER_DEVICE_TYPE = Int32
POINTER_DEVICE_TYPE_INTEGRATED_PEN: win32more.Windows.Win32.UI.Controls.POINTER_DEVICE_TYPE = 1
POINTER_DEVICE_TYPE_EXTERNAL_PEN: win32more.Windows.Win32.UI.Controls.POINTER_DEVICE_TYPE = 2
POINTER_DEVICE_TYPE_TOUCH: win32more.Windows.Win32.UI.Controls.POINTER_DEVICE_TYPE = 3
POINTER_DEVICE_TYPE_TOUCH_PAD: win32more.Windows.Win32.UI.Controls.POINTER_DEVICE_TYPE = 4
POINTER_DEVICE_TYPE_MAX: win32more.Windows.Win32.UI.Controls.POINTER_DEVICE_TYPE = -1
POINTER_FEEDBACK_MODE = Int32
POINTER_FEEDBACK_DEFAULT: win32more.Windows.Win32.UI.Controls.POINTER_FEEDBACK_MODE = 1
POINTER_FEEDBACK_INDIRECT: win32more.Windows.Win32.UI.Controls.POINTER_FEEDBACK_MODE = 2
POINTER_FEEDBACK_NONE: win32more.Windows.Win32.UI.Controls.POINTER_FEEDBACK_MODE = 3
class POINTER_TYPE_INFO(Structure):
    type: win32more.Windows.Win32.UI.WindowsAndMessaging.POINTER_INPUT_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        touchInfo: win32more.Windows.Win32.UI.Input.Pointer.POINTER_TOUCH_INFO
        penInfo: win32more.Windows.Win32.UI.Input.Pointer.POINTER_PEN_INFO
POPUPCHECKBACKGROUNDSTATES = Int32
MCB_DISABLED: win32more.Windows.Win32.UI.Controls.POPUPCHECKBACKGROUNDSTATES = 1
MCB_NORMAL: win32more.Windows.Win32.UI.Controls.POPUPCHECKBACKGROUNDSTATES = 2
MCB_BITMAP: win32more.Windows.Win32.UI.Controls.POPUPCHECKBACKGROUNDSTATES = 3
POPUPCHECKSTATES = Int32
MC_CHECKMARKNORMAL: win32more.Windows.Win32.UI.Controls.POPUPCHECKSTATES = 1
MC_CHECKMARKDISABLED: win32more.Windows.Win32.UI.Controls.POPUPCHECKSTATES = 2
MC_BULLETNORMAL: win32more.Windows.Win32.UI.Controls.POPUPCHECKSTATES = 3
MC_BULLETDISABLED: win32more.Windows.Win32.UI.Controls.POPUPCHECKSTATES = 4
POPUPITEMFOCUSABLESTATES = Int32
MPIF_NORMAL: win32more.Windows.Win32.UI.Controls.POPUPITEMFOCUSABLESTATES = 1
MPIF_HOT: win32more.Windows.Win32.UI.Controls.POPUPITEMFOCUSABLESTATES = 2
MPIF_DISABLED: win32more.Windows.Win32.UI.Controls.POPUPITEMFOCUSABLESTATES = 3
MPIF_DISABLEDHOT: win32more.Windows.Win32.UI.Controls.POPUPITEMFOCUSABLESTATES = 4
POPUPITEMKBFOCUSSTATES = Int32
MPIKBFOCUS_NORMAL: win32more.Windows.Win32.UI.Controls.POPUPITEMKBFOCUSSTATES = 1
POPUPITEMSTATES = Int32
MPI_NORMAL: win32more.Windows.Win32.UI.Controls.POPUPITEMSTATES = 1
MPI_HOT: win32more.Windows.Win32.UI.Controls.POPUPITEMSTATES = 2
MPI_DISABLED: win32more.Windows.Win32.UI.Controls.POPUPITEMSTATES = 3
MPI_DISABLEDHOT: win32more.Windows.Win32.UI.Controls.POPUPITEMSTATES = 4
POPUPSUBMENUHCHOTSTATES = Int32
MSMHC_HOT: win32more.Windows.Win32.UI.Controls.POPUPSUBMENUHCHOTSTATES = 1
POPUPSUBMENUSTATES = Int32
MSM_NORMAL: win32more.Windows.Win32.UI.Controls.POPUPSUBMENUSTATES = 1
MSM_DISABLED: win32more.Windows.Win32.UI.Controls.POPUPSUBMENUSTATES = 2
PROGRESSPARTS = Int32
PP_BAR: win32more.Windows.Win32.UI.Controls.PROGRESSPARTS = 1
PP_BARVERT: win32more.Windows.Win32.UI.Controls.PROGRESSPARTS = 2
PP_CHUNK: win32more.Windows.Win32.UI.Controls.PROGRESSPARTS = 3
PP_CHUNKVERT: win32more.Windows.Win32.UI.Controls.PROGRESSPARTS = 4
PP_FILL: win32more.Windows.Win32.UI.Controls.PROGRESSPARTS = 5
PP_FILLVERT: win32more.Windows.Win32.UI.Controls.PROGRESSPARTS = 6
PP_PULSEOVERLAY: win32more.Windows.Win32.UI.Controls.PROGRESSPARTS = 7
PP_MOVEOVERLAY: win32more.Windows.Win32.UI.Controls.PROGRESSPARTS = 8
PP_PULSEOVERLAYVERT: win32more.Windows.Win32.UI.Controls.PROGRESSPARTS = 9
PP_MOVEOVERLAYVERT: win32more.Windows.Win32.UI.Controls.PROGRESSPARTS = 10
PP_TRANSPARENTBAR: win32more.Windows.Win32.UI.Controls.PROGRESSPARTS = 11
PP_TRANSPARENTBARVERT: win32more.Windows.Win32.UI.Controls.PROGRESSPARTS = 12
PROPERTYORIGIN = Int32
PO_STATE: win32more.Windows.Win32.UI.Controls.PROPERTYORIGIN = 0
PO_PART: win32more.Windows.Win32.UI.Controls.PROPERTYORIGIN = 1
PO_CLASS: win32more.Windows.Win32.UI.Controls.PROPERTYORIGIN = 2
PO_GLOBAL: win32more.Windows.Win32.UI.Controls.PROPERTYORIGIN = 3
PO_NOTFOUND: win32more.Windows.Win32.UI.Controls.PROPERTYORIGIN = 4
class PROPSHEETHEADERA_V1(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    hwndParent: win32more.Windows.Win32.Foundation.HWND
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    Anonymous1: _Anonymous1_e__Union
    pszCaption: win32more.Windows.Win32.Foundation.PSTR
    nPages: UInt32
    Anonymous2: _Anonymous2_e__Union
    Anonymous3: _Anonymous3_e__Union
    pfnCallback: win32more.Windows.Win32.UI.Controls.PFNPROPSHEETCALLBACK
    class _Anonymous1_e__Union(Union):
        hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
        pszIcon: win32more.Windows.Win32.Foundation.PSTR
    class _Anonymous2_e__Union(Union):
        nStartPage: UInt32
        pStartPage: win32more.Windows.Win32.Foundation.PSTR
    class _Anonymous3_e__Union(Union):
        ppsp: POINTER(win32more.Windows.Win32.UI.Controls.PROPSHEETPAGEA)
        phpage: POINTER(win32more.Windows.Win32.UI.Controls.HPROPSHEETPAGE)
class PROPSHEETHEADERA_V2(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    hwndParent: win32more.Windows.Win32.Foundation.HWND
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    Anonymous1: _Anonymous1_e__Union
    pszCaption: win32more.Windows.Win32.Foundation.PSTR
    nPages: UInt32
    Anonymous2: _Anonymous2_e__Union
    Anonymous3: _Anonymous3_e__Union
    pfnCallback: win32more.Windows.Win32.UI.Controls.PFNPROPSHEETCALLBACK
    Anonymous4: _Anonymous4_e__Union
    hplWatermark: win32more.Windows.Win32.Graphics.Gdi.HPALETTE
    Anonymous5: _Anonymous5_e__Union
    class _Anonymous1_e__Union(Union):
        hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
        pszIcon: win32more.Windows.Win32.Foundation.PSTR
    class _Anonymous2_e__Union(Union):
        nStartPage: UInt32
        pStartPage: win32more.Windows.Win32.Foundation.PSTR
    class _Anonymous3_e__Union(Union):
        ppsp: POINTER(win32more.Windows.Win32.UI.Controls.PROPSHEETPAGEA)
        phpage: POINTER(win32more.Windows.Win32.UI.Controls.HPROPSHEETPAGE)
    class _Anonymous4_e__Union(Union):
        hbmWatermark: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
        pszbmWatermark: win32more.Windows.Win32.Foundation.PSTR
    class _Anonymous5_e__Union(Union):
        hbmHeader: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
        pszbmHeader: win32more.Windows.Win32.Foundation.PSTR
class PROPSHEETHEADERW_V1(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    hwndParent: win32more.Windows.Win32.Foundation.HWND
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    Anonymous1: _Anonymous1_e__Union
    pszCaption: win32more.Windows.Win32.Foundation.PWSTR
    nPages: UInt32
    Anonymous2: _Anonymous2_e__Union
    Anonymous3: _Anonymous3_e__Union
    pfnCallback: win32more.Windows.Win32.UI.Controls.PFNPROPSHEETCALLBACK
    class _Anonymous1_e__Union(Union):
        hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
        pszIcon: win32more.Windows.Win32.Foundation.PWSTR
    class _Anonymous2_e__Union(Union):
        nStartPage: UInt32
        pStartPage: win32more.Windows.Win32.Foundation.PWSTR
    class _Anonymous3_e__Union(Union):
        ppsp: POINTER(win32more.Windows.Win32.UI.Controls.PROPSHEETPAGEW)
        phpage: POINTER(win32more.Windows.Win32.UI.Controls.HPROPSHEETPAGE)
class PROPSHEETHEADERW_V2(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    hwndParent: win32more.Windows.Win32.Foundation.HWND
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    Anonymous1: _Anonymous1_e__Union
    pszCaption: win32more.Windows.Win32.Foundation.PWSTR
    nPages: UInt32
    Anonymous2: _Anonymous2_e__Union
    Anonymous3: _Anonymous3_e__Union
    pfnCallback: win32more.Windows.Win32.UI.Controls.PFNPROPSHEETCALLBACK
    Anonymous4: _Anonymous4_e__Union
    hplWatermark: win32more.Windows.Win32.Graphics.Gdi.HPALETTE
    Anonymous5: _Anonymous5_e__Union
    class _Anonymous1_e__Union(Union):
        hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
        pszIcon: win32more.Windows.Win32.Foundation.PWSTR
    class _Anonymous2_e__Union(Union):
        nStartPage: UInt32
        pStartPage: win32more.Windows.Win32.Foundation.PWSTR
    class _Anonymous3_e__Union(Union):
        ppsp: POINTER(win32more.Windows.Win32.UI.Controls.PROPSHEETPAGEW)
        phpage: POINTER(win32more.Windows.Win32.UI.Controls.HPROPSHEETPAGE)
    class _Anonymous4_e__Union(Union):
        hbmWatermark: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
        pszbmWatermark: win32more.Windows.Win32.Foundation.PWSTR
    class _Anonymous5_e__Union(Union):
        hbmHeader: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
        pszbmHeader: win32more.Windows.Win32.Foundation.PWSTR
class PROPSHEETPAGEA(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    pszTitle: win32more.Windows.Win32.Foundation.PSTR
    pfnDlgProc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    pfnCallback: win32more.Windows.Win32.UI.Controls.LPFNPSPCALLBACKA
    pcRefParent: POINTER(UInt32)
    pszHeaderTitle: win32more.Windows.Win32.Foundation.PSTR
    pszHeaderSubTitle: win32more.Windows.Win32.Foundation.PSTR
    hActCtx: win32more.Windows.Win32.Foundation.HANDLE
    Anonymous3: _Anonymous3_e__Union
    class _Anonymous1_e__Union(Union):
        pszTemplate: win32more.Windows.Win32.Foundation.PSTR
        pResource: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.DLGTEMPLATE)
    class _Anonymous2_e__Union(Union):
        hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
        pszIcon: win32more.Windows.Win32.Foundation.PSTR
    class _Anonymous3_e__Union(Union):
        hbmHeader: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
        pszbmHeader: win32more.Windows.Win32.Foundation.PSTR
class PROPSHEETPAGEA_V1(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    pszTitle: win32more.Windows.Win32.Foundation.PSTR
    pfnDlgProc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    pfnCallback: win32more.Windows.Win32.UI.Controls.LPFNPSPCALLBACKA
    pcRefParent: POINTER(UInt32)
    class _Anonymous1_e__Union(Union):
        pszTemplate: win32more.Windows.Win32.Foundation.PSTR
        pResource: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.DLGTEMPLATE)
    class _Anonymous2_e__Union(Union):
        hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
        pszIcon: win32more.Windows.Win32.Foundation.PSTR
class PROPSHEETPAGEA_V2(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    pszTitle: win32more.Windows.Win32.Foundation.PSTR
    pfnDlgProc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    pfnCallback: win32more.Windows.Win32.UI.Controls.LPFNPSPCALLBACKA
    pcRefParent: POINTER(UInt32)
    pszHeaderTitle: win32more.Windows.Win32.Foundation.PSTR
    pszHeaderSubTitle: win32more.Windows.Win32.Foundation.PSTR
    class _Anonymous1_e__Union(Union):
        pszTemplate: win32more.Windows.Win32.Foundation.PSTR
        pResource: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.DLGTEMPLATE)
    class _Anonymous2_e__Union(Union):
        hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
        pszIcon: win32more.Windows.Win32.Foundation.PSTR
class PROPSHEETPAGEA_V3(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    pszTitle: win32more.Windows.Win32.Foundation.PSTR
    pfnDlgProc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    pfnCallback: win32more.Windows.Win32.UI.Controls.LPFNPSPCALLBACKA
    pcRefParent: POINTER(UInt32)
    pszHeaderTitle: win32more.Windows.Win32.Foundation.PSTR
    pszHeaderSubTitle: win32more.Windows.Win32.Foundation.PSTR
    hActCtx: win32more.Windows.Win32.Foundation.HANDLE
    class _Anonymous1_e__Union(Union):
        pszTemplate: win32more.Windows.Win32.Foundation.PSTR
        pResource: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.DLGTEMPLATE)
    class _Anonymous2_e__Union(Union):
        hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
        pszIcon: win32more.Windows.Win32.Foundation.PSTR
class PROPSHEETPAGEW(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    pszTitle: win32more.Windows.Win32.Foundation.PWSTR
    pfnDlgProc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    pfnCallback: win32more.Windows.Win32.UI.Controls.LPFNPSPCALLBACKW
    pcRefParent: POINTER(UInt32)
    pszHeaderTitle: win32more.Windows.Win32.Foundation.PWSTR
    pszHeaderSubTitle: win32more.Windows.Win32.Foundation.PWSTR
    hActCtx: win32more.Windows.Win32.Foundation.HANDLE
    Anonymous3: _Anonymous3_e__Union
    class _Anonymous1_e__Union(Union):
        pszTemplate: win32more.Windows.Win32.Foundation.PWSTR
        pResource: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.DLGTEMPLATE)
    class _Anonymous2_e__Union(Union):
        hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
        pszIcon: win32more.Windows.Win32.Foundation.PWSTR
    class _Anonymous3_e__Union(Union):
        hbmHeader: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
        pszbmHeader: win32more.Windows.Win32.Foundation.PWSTR
PROPSHEETPAGE = UnicodeAlias('PROPSHEETPAGEW')
class PROPSHEETPAGEW_V1(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    pszTitle: win32more.Windows.Win32.Foundation.PWSTR
    pfnDlgProc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    pfnCallback: win32more.Windows.Win32.UI.Controls.LPFNPSPCALLBACKW
    pcRefParent: POINTER(UInt32)
    class _Anonymous1_e__Union(Union):
        pszTemplate: win32more.Windows.Win32.Foundation.PWSTR
        pResource: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.DLGTEMPLATE)
    class _Anonymous2_e__Union(Union):
        hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
        pszIcon: win32more.Windows.Win32.Foundation.PWSTR
class PROPSHEETPAGEW_V2(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    pszTitle: win32more.Windows.Win32.Foundation.PWSTR
    pfnDlgProc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    pfnCallback: win32more.Windows.Win32.UI.Controls.LPFNPSPCALLBACKW
    pcRefParent: POINTER(UInt32)
    pszHeaderTitle: win32more.Windows.Win32.Foundation.PWSTR
    pszHeaderSubTitle: win32more.Windows.Win32.Foundation.PWSTR
    class _Anonymous1_e__Union(Union):
        pszTemplate: win32more.Windows.Win32.Foundation.PWSTR
        pResource: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.DLGTEMPLATE)
    class _Anonymous2_e__Union(Union):
        hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
        pszIcon: win32more.Windows.Win32.Foundation.PWSTR
class PROPSHEETPAGEW_V3(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    pszTitle: win32more.Windows.Win32.Foundation.PWSTR
    pfnDlgProc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    pfnCallback: win32more.Windows.Win32.UI.Controls.LPFNPSPCALLBACKW
    pcRefParent: POINTER(UInt32)
    pszHeaderTitle: win32more.Windows.Win32.Foundation.PWSTR
    pszHeaderSubTitle: win32more.Windows.Win32.Foundation.PWSTR
    hActCtx: win32more.Windows.Win32.Foundation.HANDLE
    class _Anonymous1_e__Union(Union):
        pszTemplate: win32more.Windows.Win32.Foundation.PWSTR
        pResource: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.DLGTEMPLATE)
    class _Anonymous2_e__Union(Union):
        hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
        pszIcon: win32more.Windows.Win32.Foundation.PWSTR
class PSHNOTIFY(Structure):
    hdr: win32more.Windows.Win32.UI.Controls.NMHDR
    lParam: win32more.Windows.Win32.Foundation.LPARAM
PSPCB_MESSAGE = UInt32
PSPCB_ADDREF: win32more.Windows.Win32.UI.Controls.PSPCB_MESSAGE = 0
PSPCB_CREATE: win32more.Windows.Win32.UI.Controls.PSPCB_MESSAGE = 2
PSPCB_RELEASE: win32more.Windows.Win32.UI.Controls.PSPCB_MESSAGE = 1
PSPCB_SI_INITDIALOG: win32more.Windows.Win32.UI.Controls.PSPCB_MESSAGE = 1025
PUSHBUTTONDROPDOWNSTATES = Int32
PBDDS_NORMAL: win32more.Windows.Win32.UI.Controls.PUSHBUTTONDROPDOWNSTATES = 1
PBDDS_DISABLED: win32more.Windows.Win32.UI.Controls.PUSHBUTTONDROPDOWNSTATES = 2
PUSHBUTTONSTATES = Int32
PBS_NORMAL: win32more.Windows.Win32.UI.Controls.PUSHBUTTONSTATES = 1
PBS_HOT: win32more.Windows.Win32.UI.Controls.PUSHBUTTONSTATES = 2
PBS_PRESSED: win32more.Windows.Win32.UI.Controls.PUSHBUTTONSTATES = 3
PBS_DISABLED: win32more.Windows.Win32.UI.Controls.PUSHBUTTONSTATES = 4
PBS_DEFAULTED: win32more.Windows.Win32.UI.Controls.PUSHBUTTONSTATES = 5
PBS_DEFAULTED_ANIMATING: win32more.Windows.Win32.UI.Controls.PUSHBUTTONSTATES = 6
RADIOBUTTONSTATES = Int32
RBS_UNCHECKEDNORMAL: win32more.Windows.Win32.UI.Controls.RADIOBUTTONSTATES = 1
RBS_UNCHECKEDHOT: win32more.Windows.Win32.UI.Controls.RADIOBUTTONSTATES = 2
RBS_UNCHECKEDPRESSED: win32more.Windows.Win32.UI.Controls.RADIOBUTTONSTATES = 3
RBS_UNCHECKEDDISABLED: win32more.Windows.Win32.UI.Controls.RADIOBUTTONSTATES = 4
RBS_CHECKEDNORMAL: win32more.Windows.Win32.UI.Controls.RADIOBUTTONSTATES = 5
RBS_CHECKEDHOT: win32more.Windows.Win32.UI.Controls.RADIOBUTTONSTATES = 6
RBS_CHECKEDPRESSED: win32more.Windows.Win32.UI.Controls.RADIOBUTTONSTATES = 7
RBS_CHECKEDDISABLED: win32more.Windows.Win32.UI.Controls.RADIOBUTTONSTATES = 8
class RBHITTESTINFO(Structure):
    pt: win32more.Windows.Win32.Foundation.POINT
    flags: UInt32
    iBand: Int32
READONLYSTATES = Int32
CBRO_NORMAL: win32more.Windows.Win32.UI.Controls.READONLYSTATES = 1
CBRO_HOT: win32more.Windows.Win32.UI.Controls.READONLYSTATES = 2
CBRO_PRESSED: win32more.Windows.Win32.UI.Controls.READONLYSTATES = 3
CBRO_DISABLED: win32more.Windows.Win32.UI.Controls.READONLYSTATES = 4
class REBARBANDINFOA(Structure):
    cbSize: UInt32
    fMask: UInt32
    fStyle: UInt32
    clrFore: win32more.Windows.Win32.Foundation.COLORREF
    clrBack: win32more.Windows.Win32.Foundation.COLORREF
    lpText: win32more.Windows.Win32.Foundation.PSTR
    cch: UInt32
    iImage: Int32
    hwndChild: win32more.Windows.Win32.Foundation.HWND
    cxMinChild: UInt32
    cyMinChild: UInt32
    cx: UInt32
    hbmBack: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
    wID: UInt32
    cyChild: UInt32
    cyMaxChild: UInt32
    cyIntegral: UInt32
    cxIdeal: UInt32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    cxHeader: UInt32
    rcChevronLocation: win32more.Windows.Win32.Foundation.RECT
    uChevronState: UInt32
class REBARBANDINFOW(Structure):
    cbSize: UInt32
    fMask: UInt32
    fStyle: UInt32
    clrFore: win32more.Windows.Win32.Foundation.COLORREF
    clrBack: win32more.Windows.Win32.Foundation.COLORREF
    lpText: win32more.Windows.Win32.Foundation.PWSTR
    cch: UInt32
    iImage: Int32
    hwndChild: win32more.Windows.Win32.Foundation.HWND
    cxMinChild: UInt32
    cyMinChild: UInt32
    cx: UInt32
    hbmBack: win32more.Windows.Win32.Graphics.Gdi.HBITMAP
    wID: UInt32
    cyChild: UInt32
    cyMaxChild: UInt32
    cyIntegral: UInt32
    cxIdeal: UInt32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    cxHeader: UInt32
    rcChevronLocation: win32more.Windows.Win32.Foundation.RECT
    uChevronState: UInt32
REBARBANDINFO = UnicodeAlias('REBARBANDINFOW')
class REBARINFO(Structure):
    cbSize: UInt32
    fMask: UInt32
    himl: win32more.Windows.Win32.UI.Controls.HIMAGELIST
REBARPARTS = Int32
RP_GRIPPER: win32more.Windows.Win32.UI.Controls.REBARPARTS = 1
RP_GRIPPERVERT: win32more.Windows.Win32.UI.Controls.REBARPARTS = 2
RP_BAND: win32more.Windows.Win32.UI.Controls.REBARPARTS = 3
RP_CHEVRON: win32more.Windows.Win32.UI.Controls.REBARPARTS = 4
RP_CHEVRONVERT: win32more.Windows.Win32.UI.Controls.REBARPARTS = 5
RP_BACKGROUND: win32more.Windows.Win32.UI.Controls.REBARPARTS = 6
RP_SPLITTER: win32more.Windows.Win32.UI.Controls.REBARPARTS = 7
RP_SPLITTERVERT: win32more.Windows.Win32.UI.Controls.REBARPARTS = 8
RESTOREBUTTONSTATES = Int32
RBS_NORMAL: win32more.Windows.Win32.UI.Controls.RESTOREBUTTONSTATES = 1
RBS_HOT: win32more.Windows.Win32.UI.Controls.RESTOREBUTTONSTATES = 2
RBS_PUSHED: win32more.Windows.Win32.UI.Controls.RESTOREBUTTONSTATES = 3
RBS_DISABLED: win32more.Windows.Win32.UI.Controls.RESTOREBUTTONSTATES = 4
SCROLLBARPARTS = Int32
SBP_ARROWBTN: win32more.Windows.Win32.UI.Controls.SCROLLBARPARTS = 1
SBP_THUMBBTNHORZ: win32more.Windows.Win32.UI.Controls.SCROLLBARPARTS = 2
SBP_THUMBBTNVERT: win32more.Windows.Win32.UI.Controls.SCROLLBARPARTS = 3
SBP_LOWERTRACKHORZ: win32more.Windows.Win32.UI.Controls.SCROLLBARPARTS = 4
SBP_UPPERTRACKHORZ: win32more.Windows.Win32.UI.Controls.SCROLLBARPARTS = 5
SBP_LOWERTRACKVERT: win32more.Windows.Win32.UI.Controls.SCROLLBARPARTS = 6
SBP_UPPERTRACKVERT: win32more.Windows.Win32.UI.Controls.SCROLLBARPARTS = 7
SBP_GRIPPERHORZ: win32more.Windows.Win32.UI.Controls.SCROLLBARPARTS = 8
SBP_GRIPPERVERT: win32more.Windows.Win32.UI.Controls.SCROLLBARPARTS = 9
SBP_SIZEBOX: win32more.Windows.Win32.UI.Controls.SCROLLBARPARTS = 10
SBP_SIZEBOXBKGND: win32more.Windows.Win32.UI.Controls.SCROLLBARPARTS = 11
SCROLLBARSTYLESTATES = Int32
SCRBS_NORMAL: win32more.Windows.Win32.UI.Controls.SCROLLBARSTYLESTATES = 1
SCRBS_HOT: win32more.Windows.Win32.UI.Controls.SCROLLBARSTYLESTATES = 2
SCRBS_PRESSED: win32more.Windows.Win32.UI.Controls.SCROLLBARSTYLESTATES = 3
SCRBS_DISABLED: win32more.Windows.Win32.UI.Controls.SCROLLBARSTYLESTATES = 4
SCRBS_HOVER: win32more.Windows.Win32.UI.Controls.SCROLLBARSTYLESTATES = 5
SECTIONTITLELINKSTATES = Int32
CPSTL_NORMAL: win32more.Windows.Win32.UI.Controls.SECTIONTITLELINKSTATES = 1
CPSTL_HOT: win32more.Windows.Win32.UI.Controls.SECTIONTITLELINKSTATES = 2
SET_THEME_APP_PROPERTIES_FLAGS = UInt32
ALLOW_NONCLIENT: win32more.Windows.Win32.UI.Controls.SET_THEME_APP_PROPERTIES_FLAGS = 1
ALLOW_CONTROLS: win32more.Windows.Win32.UI.Controls.SET_THEME_APP_PROPERTIES_FLAGS = 2
ALLOW_WEBCONTENT: win32more.Windows.Win32.UI.Controls.SET_THEME_APP_PROPERTIES_FLAGS = 4
VALIDBITS: win32more.Windows.Win32.UI.Controls.SET_THEME_APP_PROPERTIES_FLAGS = 7
SHOWCALENDARBUTTONRIGHTSTATES = Int32
DPSCBR_NORMAL: win32more.Windows.Win32.UI.Controls.SHOWCALENDARBUTTONRIGHTSTATES = 1
DPSCBR_HOT: win32more.Windows.Win32.UI.Controls.SHOWCALENDARBUTTONRIGHTSTATES = 2
DPSCBR_PRESSED: win32more.Windows.Win32.UI.Controls.SHOWCALENDARBUTTONRIGHTSTATES = 3
DPSCBR_DISABLED: win32more.Windows.Win32.UI.Controls.SHOWCALENDARBUTTONRIGHTSTATES = 4
SIZEBOXSTATES = Int32
SZB_RIGHTALIGN: win32more.Windows.Win32.UI.Controls.SIZEBOXSTATES = 1
SZB_LEFTALIGN: win32more.Windows.Win32.UI.Controls.SIZEBOXSTATES = 2
SZB_TOPRIGHTALIGN: win32more.Windows.Win32.UI.Controls.SIZEBOXSTATES = 3
SZB_TOPLEFTALIGN: win32more.Windows.Win32.UI.Controls.SIZEBOXSTATES = 4
SZB_HALFBOTTOMRIGHTALIGN: win32more.Windows.Win32.UI.Controls.SIZEBOXSTATES = 5
SZB_HALFBOTTOMLEFTALIGN: win32more.Windows.Win32.UI.Controls.SIZEBOXSTATES = 6
SZB_HALFTOPRIGHTALIGN: win32more.Windows.Win32.UI.Controls.SIZEBOXSTATES = 7
SZB_HALFTOPLEFTALIGN: win32more.Windows.Win32.UI.Controls.SIZEBOXSTATES = 8
SIZINGTYPE = Int32
ST_TRUESIZE: win32more.Windows.Win32.UI.Controls.SIZINGTYPE = 0
ST_STRETCH: win32more.Windows.Win32.UI.Controls.SIZINGTYPE = 1
ST_TILE: win32more.Windows.Win32.UI.Controls.SIZINGTYPE = 2
SMALLCAPTIONSTATES = Int32
SCS_ACTIVE: win32more.Windows.Win32.UI.Controls.SMALLCAPTIONSTATES = 1
SCS_INACTIVE: win32more.Windows.Win32.UI.Controls.SMALLCAPTIONSTATES = 2
SCS_DISABLED: win32more.Windows.Win32.UI.Controls.SMALLCAPTIONSTATES = 3
SMALLCLOSEBUTTONSTATES = Int32
SCBS_NORMAL: win32more.Windows.Win32.UI.Controls.SMALLCLOSEBUTTONSTATES = 1
SCBS_HOT: win32more.Windows.Win32.UI.Controls.SMALLCLOSEBUTTONSTATES = 2
SCBS_PUSHED: win32more.Windows.Win32.UI.Controls.SMALLCLOSEBUTTONSTATES = 3
SCBS_DISABLED: win32more.Windows.Win32.UI.Controls.SMALLCLOSEBUTTONSTATES = 4
SMALLFRAMEBOTTOMSTATES = Int32
SFRB_ACTIVE: win32more.Windows.Win32.UI.Controls.SMALLFRAMEBOTTOMSTATES = 1
SFRB_INACTIVE: win32more.Windows.Win32.UI.Controls.SMALLFRAMEBOTTOMSTATES = 2
SMALLFRAMELEFTSTATES = Int32
SFRL_ACTIVE: win32more.Windows.Win32.UI.Controls.SMALLFRAMELEFTSTATES = 1
SFRL_INACTIVE: win32more.Windows.Win32.UI.Controls.SMALLFRAMELEFTSTATES = 2
SMALLFRAMERIGHTSTATES = Int32
SFRR_ACTIVE: win32more.Windows.Win32.UI.Controls.SMALLFRAMERIGHTSTATES = 1
SFRR_INACTIVE: win32more.Windows.Win32.UI.Controls.SMALLFRAMERIGHTSTATES = 2
SOFTWAREEXPLORERSTATES = Int32
SPSE_NORMAL: win32more.Windows.Win32.UI.Controls.SOFTWAREEXPLORERSTATES = 1
SPSE_HOT: win32more.Windows.Win32.UI.Controls.SOFTWAREEXPLORERSTATES = 2
SPSE_SELECTED: win32more.Windows.Win32.UI.Controls.SOFTWAREEXPLORERSTATES = 3
SPSE_DISABLED: win32more.Windows.Win32.UI.Controls.SOFTWAREEXPLORERSTATES = 4
SPSE_FOCUSED: win32more.Windows.Win32.UI.Controls.SOFTWAREEXPLORERSTATES = 5
SPECIALGROUPCOLLAPSESTATES = Int32
EBSGC_NORMAL: win32more.Windows.Win32.UI.Controls.SPECIALGROUPCOLLAPSESTATES = 1
EBSGC_HOT: win32more.Windows.Win32.UI.Controls.SPECIALGROUPCOLLAPSESTATES = 2
EBSGC_PRESSED: win32more.Windows.Win32.UI.Controls.SPECIALGROUPCOLLAPSESTATES = 3
SPECIALGROUPEXPANDSTATES = Int32
EBSGE_NORMAL: win32more.Windows.Win32.UI.Controls.SPECIALGROUPEXPANDSTATES = 1
EBSGE_HOT: win32more.Windows.Win32.UI.Controls.SPECIALGROUPEXPANDSTATES = 2
EBSGE_PRESSED: win32more.Windows.Win32.UI.Controls.SPECIALGROUPEXPANDSTATES = 3
SPINPARTS = Int32
SPNP_UP: win32more.Windows.Win32.UI.Controls.SPINPARTS = 1
SPNP_DOWN: win32more.Windows.Win32.UI.Controls.SPINPARTS = 2
SPNP_UPHORZ: win32more.Windows.Win32.UI.Controls.SPINPARTS = 3
SPNP_DOWNHORZ: win32more.Windows.Win32.UI.Controls.SPINPARTS = 4
SPLITTERSTATES = Int32
SPLITS_NORMAL: win32more.Windows.Win32.UI.Controls.SPLITTERSTATES = 1
SPLITS_HOT: win32more.Windows.Win32.UI.Controls.SPLITTERSTATES = 2
SPLITS_PRESSED: win32more.Windows.Win32.UI.Controls.SPLITTERSTATES = 3
SPLITTERVERTSTATES = Int32
SPLITSV_NORMAL: win32more.Windows.Win32.UI.Controls.SPLITTERVERTSTATES = 1
SPLITSV_HOT: win32more.Windows.Win32.UI.Controls.SPLITTERVERTSTATES = 2
SPLITSV_PRESSED: win32more.Windows.Win32.UI.Controls.SPLITTERVERTSTATES = 3
STANDARDSTATES = Int32
TTSS_NORMAL: win32more.Windows.Win32.UI.Controls.STANDARDSTATES = 1
TTSS_LINK: win32more.Windows.Win32.UI.Controls.STANDARDSTATES = 2
STARTPANELPARTS = Int32
SPP_USERPANE: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 1
SPP_MOREPROGRAMS: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 2
SPP_MOREPROGRAMSARROW: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 3
SPP_PROGLIST: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 4
SPP_PROGLISTSEPARATOR: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 5
SPP_PLACESLIST: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 6
SPP_PLACESLISTSEPARATOR: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 7
SPP_LOGOFF: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 8
SPP_LOGOFFBUTTONS: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 9
SPP_USERPICTURE: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 10
SPP_PREVIEW: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 11
SPP_MOREPROGRAMSTAB: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 12
SPP_NSCHOST: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 13
SPP_SOFTWAREEXPLORER: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 14
SPP_OPENBOX: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 15
SPP_SEARCHVIEW: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 16
SPP_MOREPROGRAMSARROWBACK: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 17
SPP_TOPMATCH: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 18
SPP_LOGOFFSPLITBUTTONDROPDOWN: win32more.Windows.Win32.UI.Controls.STARTPANELPARTS = 19
STATICPARTS = Int32
STAT_TEXT: win32more.Windows.Win32.UI.Controls.STATICPARTS = 1
STATUSPARTS = Int32
SP_PANE: win32more.Windows.Win32.UI.Controls.STATUSPARTS = 1
SP_GRIPPERPANE: win32more.Windows.Win32.UI.Controls.STATUSPARTS = 2
SP_GRIPPER: win32more.Windows.Win32.UI.Controls.STATUSPARTS = 3
SYSBUTTONSTATES = Int32
SBS_NORMAL: win32more.Windows.Win32.UI.Controls.SYSBUTTONSTATES = 1
SBS_HOT: win32more.Windows.Win32.UI.Controls.SYSBUTTONSTATES = 2
SBS_PUSHED: win32more.Windows.Win32.UI.Controls.SYSBUTTONSTATES = 3
SBS_DISABLED: win32more.Windows.Win32.UI.Controls.SYSBUTTONSTATES = 4
SYSTEMCLOSEHCHOTSTATES = Int32
MSYSCHC_HOT: win32more.Windows.Win32.UI.Controls.SYSTEMCLOSEHCHOTSTATES = 1
SYSTEMCLOSESTATES = Int32
MSYSC_NORMAL: win32more.Windows.Win32.UI.Controls.SYSTEMCLOSESTATES = 1
MSYSC_DISABLED: win32more.Windows.Win32.UI.Controls.SYSTEMCLOSESTATES = 2
SYSTEMMAXIMIZEHCHOTSTATES = Int32
MSYSMXHC_HOT: win32more.Windows.Win32.UI.Controls.SYSTEMMAXIMIZEHCHOTSTATES = 1
SYSTEMMAXIMIZESTATES = Int32
MSYSMX_NORMAL: win32more.Windows.Win32.UI.Controls.SYSTEMMAXIMIZESTATES = 1
MSYSMX_DISABLED: win32more.Windows.Win32.UI.Controls.SYSTEMMAXIMIZESTATES = 2
SYSTEMMINIMIZEHCHOTSTATES = Int32
MSYSMNHC_HOT: win32more.Windows.Win32.UI.Controls.SYSTEMMINIMIZEHCHOTSTATES = 1
SYSTEMMINIMIZESTATES = Int32
MSYSMN_NORMAL: win32more.Windows.Win32.UI.Controls.SYSTEMMINIMIZESTATES = 1
MSYSMN_DISABLED: win32more.Windows.Win32.UI.Controls.SYSTEMMINIMIZESTATES = 2
SYSTEMRESTOREHCHOTSTATES = Int32
MSYSRHC_HOT: win32more.Windows.Win32.UI.Controls.SYSTEMRESTOREHCHOTSTATES = 1
SYSTEMRESTORESTATES = Int32
MSYSR_NORMAL: win32more.Windows.Win32.UI.Controls.SYSTEMRESTORESTATES = 1
MSYSR_DISABLED: win32more.Windows.Win32.UI.Controls.SYSTEMRESTORESTATES = 2
TABITEMBOTHEDGESTATES = Int32
TIBES_NORMAL: win32more.Windows.Win32.UI.Controls.TABITEMBOTHEDGESTATES = 1
TIBES_HOT: win32more.Windows.Win32.UI.Controls.TABITEMBOTHEDGESTATES = 2
TIBES_SELECTED: win32more.Windows.Win32.UI.Controls.TABITEMBOTHEDGESTATES = 3
TIBES_DISABLED: win32more.Windows.Win32.UI.Controls.TABITEMBOTHEDGESTATES = 4
TIBES_FOCUSED: win32more.Windows.Win32.UI.Controls.TABITEMBOTHEDGESTATES = 5
TABITEMLEFTEDGESTATES = Int32
TILES_NORMAL: win32more.Windows.Win32.UI.Controls.TABITEMLEFTEDGESTATES = 1
TILES_HOT: win32more.Windows.Win32.UI.Controls.TABITEMLEFTEDGESTATES = 2
TILES_SELECTED: win32more.Windows.Win32.UI.Controls.TABITEMLEFTEDGESTATES = 3
TILES_DISABLED: win32more.Windows.Win32.UI.Controls.TABITEMLEFTEDGESTATES = 4
TILES_FOCUSED: win32more.Windows.Win32.UI.Controls.TABITEMLEFTEDGESTATES = 5
TABITEMRIGHTEDGESTATES = Int32
TIRES_NORMAL: win32more.Windows.Win32.UI.Controls.TABITEMRIGHTEDGESTATES = 1
TIRES_HOT: win32more.Windows.Win32.UI.Controls.TABITEMRIGHTEDGESTATES = 2
TIRES_SELECTED: win32more.Windows.Win32.UI.Controls.TABITEMRIGHTEDGESTATES = 3
TIRES_DISABLED: win32more.Windows.Win32.UI.Controls.TABITEMRIGHTEDGESTATES = 4
TIRES_FOCUSED: win32more.Windows.Win32.UI.Controls.TABITEMRIGHTEDGESTATES = 5
TABITEMSTATES = Int32
TIS_NORMAL: win32more.Windows.Win32.UI.Controls.TABITEMSTATES = 1
TIS_HOT: win32more.Windows.Win32.UI.Controls.TABITEMSTATES = 2
TIS_SELECTED: win32more.Windows.Win32.UI.Controls.TABITEMSTATES = 3
TIS_DISABLED: win32more.Windows.Win32.UI.Controls.TABITEMSTATES = 4
TIS_FOCUSED: win32more.Windows.Win32.UI.Controls.TABITEMSTATES = 5
TABPARTS = Int32
TABP_TABITEM: win32more.Windows.Win32.UI.Controls.TABPARTS = 1
TABP_TABITEMLEFTEDGE: win32more.Windows.Win32.UI.Controls.TABPARTS = 2
TABP_TABITEMRIGHTEDGE: win32more.Windows.Win32.UI.Controls.TABPARTS = 3
TABP_TABITEMBOTHEDGE: win32more.Windows.Win32.UI.Controls.TABPARTS = 4
TABP_TOPTABITEM: win32more.Windows.Win32.UI.Controls.TABPARTS = 5
TABP_TOPTABITEMLEFTEDGE: win32more.Windows.Win32.UI.Controls.TABPARTS = 6
TABP_TOPTABITEMRIGHTEDGE: win32more.Windows.Win32.UI.Controls.TABPARTS = 7
TABP_TOPTABITEMBOTHEDGE: win32more.Windows.Win32.UI.Controls.TABPARTS = 8
TABP_PANE: win32more.Windows.Win32.UI.Controls.TABPARTS = 9
TABP_BODY: win32more.Windows.Win32.UI.Controls.TABPARTS = 10
TABP_AEROWIZARDBODY: win32more.Windows.Win32.UI.Controls.TABPARTS = 11
TABSTATES = Int32
CSTB_NORMAL: win32more.Windows.Win32.UI.Controls.TABSTATES = 1
CSTB_HOT: win32more.Windows.Win32.UI.Controls.TABSTATES = 2
CSTB_SELECTED: win32more.Windows.Win32.UI.Controls.TABSTATES = 3
TAB_CONTROL_ITEM_STATE = UInt32
TCIS_BUTTONPRESSED: win32more.Windows.Win32.UI.Controls.TAB_CONTROL_ITEM_STATE = 1
TCIS_HIGHLIGHTED: win32more.Windows.Win32.UI.Controls.TAB_CONTROL_ITEM_STATE = 2
TASKBANDPARTS = Int32
TDP_GROUPCOUNT: win32more.Windows.Win32.UI.Controls.TASKBANDPARTS = 1
TDP_FLASHBUTTON: win32more.Windows.Win32.UI.Controls.TASKBANDPARTS = 2
TDP_FLASHBUTTONGROUPMENU: win32more.Windows.Win32.UI.Controls.TASKBANDPARTS = 3
TASKBARPARTS = Int32
TBP_BACKGROUNDBOTTOM: win32more.Windows.Win32.UI.Controls.TASKBARPARTS = 1
TBP_BACKGROUNDRIGHT: win32more.Windows.Win32.UI.Controls.TASKBARPARTS = 2
TBP_BACKGROUNDTOP: win32more.Windows.Win32.UI.Controls.TASKBARPARTS = 3
TBP_BACKGROUNDLEFT: win32more.Windows.Win32.UI.Controls.TASKBARPARTS = 4
TBP_SIZINGBARBOTTOM: win32more.Windows.Win32.UI.Controls.TASKBARPARTS = 5
TBP_SIZINGBARRIGHT: win32more.Windows.Win32.UI.Controls.TASKBARPARTS = 6
TBP_SIZINGBARTOP: win32more.Windows.Win32.UI.Controls.TASKBARPARTS = 7
TBP_SIZINGBARLEFT: win32more.Windows.Win32.UI.Controls.TASKBARPARTS = 8
class TASKDIALOGCONFIG(Structure):
    cbSize: UInt32
    hwndParent: win32more.Windows.Win32.Foundation.HWND
    hInstance: win32more.Windows.Win32.Foundation.HINSTANCE
    dwFlags: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS
    dwCommonButtons: win32more.Windows.Win32.UI.Controls.TASKDIALOG_COMMON_BUTTON_FLAGS
    pszWindowTitle: win32more.Windows.Win32.Foundation.PWSTR
    Anonymous1: _Anonymous1_e__Union
    pszMainInstruction: win32more.Windows.Win32.Foundation.PWSTR
    pszContent: win32more.Windows.Win32.Foundation.PWSTR
    cButtons: UInt32
    pButtons: POINTER(win32more.Windows.Win32.UI.Controls.TASKDIALOG_BUTTON)
    nDefaultButton: Int32
    cRadioButtons: UInt32
    pRadioButtons: POINTER(win32more.Windows.Win32.UI.Controls.TASKDIALOG_BUTTON)
    nDefaultRadioButton: Int32
    pszVerificationText: win32more.Windows.Win32.Foundation.PWSTR
    pszExpandedInformation: win32more.Windows.Win32.Foundation.PWSTR
    pszExpandedControlText: win32more.Windows.Win32.Foundation.PWSTR
    pszCollapsedControlText: win32more.Windows.Win32.Foundation.PWSTR
    Anonymous2: _Anonymous2_e__Union
    pszFooter: win32more.Windows.Win32.Foundation.PWSTR
    pfCallback: win32more.Windows.Win32.UI.Controls.PFTASKDIALOGCALLBACK
    lpCallbackData: IntPtr
    cxWidth: UInt32
    _pack_ = 1
    class _Anonymous1_e__Union(Union):
        hMainIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
        pszMainIcon: win32more.Windows.Win32.Foundation.PWSTR
        _pack_ = 1
    class _Anonymous2_e__Union(Union):
        hFooterIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON
        pszFooterIcon: win32more.Windows.Win32.Foundation.PWSTR
        _pack_ = 1
TASKDIALOGPARTS = Int32
TDLG_PRIMARYPANEL: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 1
TDLG_MAININSTRUCTIONPANE: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 2
TDLG_MAINICON: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 3
TDLG_CONTENTPANE: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 4
TDLG_CONTENTICON: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 5
TDLG_EXPANDEDCONTENT: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 6
TDLG_COMMANDLINKPANE: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 7
TDLG_SECONDARYPANEL: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 8
TDLG_CONTROLPANE: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 9
TDLG_BUTTONSECTION: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 10
TDLG_BUTTONWRAPPER: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 11
TDLG_EXPANDOTEXT: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 12
TDLG_EXPANDOBUTTON: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 13
TDLG_VERIFICATIONTEXT: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 14
TDLG_FOOTNOTEPANE: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 15
TDLG_FOOTNOTEAREA: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 16
TDLG_FOOTNOTESEPARATOR: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 17
TDLG_EXPANDEDFOOTERAREA: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 18
TDLG_PROGRESSBAR: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 19
TDLG_IMAGEALIGNMENT: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 20
TDLG_RADIOBUTTONPANE: win32more.Windows.Win32.UI.Controls.TASKDIALOGPARTS = 21
class TASKDIALOG_BUTTON(Structure):
    nButtonID: Int32
    pszButtonText: win32more.Windows.Win32.Foundation.PWSTR
    _pack_ = 1
TASKDIALOG_COMMON_BUTTON_FLAGS = Int32
TDCBF_OK_BUTTON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_COMMON_BUTTON_FLAGS = 1
TDCBF_YES_BUTTON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_COMMON_BUTTON_FLAGS = 2
TDCBF_NO_BUTTON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_COMMON_BUTTON_FLAGS = 4
TDCBF_CANCEL_BUTTON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_COMMON_BUTTON_FLAGS = 8
TDCBF_RETRY_BUTTON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_COMMON_BUTTON_FLAGS = 16
TDCBF_CLOSE_BUTTON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_COMMON_BUTTON_FLAGS = 32
TDCBF_ABORT_BUTTON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_COMMON_BUTTON_FLAGS = 65536
TDCBF_IGNORE_BUTTON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_COMMON_BUTTON_FLAGS = 131072
TDCBF_TRYAGAIN_BUTTON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_COMMON_BUTTON_FLAGS = 262144
TDCBF_CONTINUE_BUTTON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_COMMON_BUTTON_FLAGS = 524288
TDCBF_HELP_BUTTON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_COMMON_BUTTON_FLAGS = 1048576
TASKDIALOG_ELEMENTS = Int32
TDE_CONTENT: win32more.Windows.Win32.UI.Controls.TASKDIALOG_ELEMENTS = 0
TDE_EXPANDED_INFORMATION: win32more.Windows.Win32.UI.Controls.TASKDIALOG_ELEMENTS = 1
TDE_FOOTER: win32more.Windows.Win32.UI.Controls.TASKDIALOG_ELEMENTS = 2
TDE_MAIN_INSTRUCTION: win32more.Windows.Win32.UI.Controls.TASKDIALOG_ELEMENTS = 3
TASKDIALOG_FLAGS = Int32
TDF_ENABLE_HYPERLINKS: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 1
TDF_USE_HICON_MAIN: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 2
TDF_USE_HICON_FOOTER: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 4
TDF_ALLOW_DIALOG_CANCELLATION: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 8
TDF_USE_COMMAND_LINKS: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 16
TDF_USE_COMMAND_LINKS_NO_ICON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 32
TDF_EXPAND_FOOTER_AREA: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 64
TDF_EXPANDED_BY_DEFAULT: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 128
TDF_VERIFICATION_FLAG_CHECKED: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 256
TDF_SHOW_PROGRESS_BAR: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 512
TDF_SHOW_MARQUEE_PROGRESS_BAR: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 1024
TDF_CALLBACK_TIMER: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 2048
TDF_POSITION_RELATIVE_TO_WINDOW: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 4096
TDF_RTL_LAYOUT: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 8192
TDF_NO_DEFAULT_RADIO_BUTTON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 16384
TDF_CAN_BE_MINIMIZED: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 32768
TDF_NO_SET_FOREGROUND: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 65536
TDF_SIZE_TO_CONTENT: win32more.Windows.Win32.UI.Controls.TASKDIALOG_FLAGS = 16777216
TASKDIALOG_ICON_ELEMENTS = Int32
TDIE_ICON_MAIN: win32more.Windows.Win32.UI.Controls.TASKDIALOG_ICON_ELEMENTS = 0
TDIE_ICON_FOOTER: win32more.Windows.Win32.UI.Controls.TASKDIALOG_ICON_ELEMENTS = 1
TASKDIALOG_MESSAGES = Int32
TDM_NAVIGATE_PAGE: win32more.Windows.Win32.UI.Controls.TASKDIALOG_MESSAGES = 1125
TDM_CLICK_BUTTON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_MESSAGES = 1126
TDM_SET_MARQUEE_PROGRESS_BAR: win32more.Windows.Win32.UI.Controls.TASKDIALOG_MESSAGES = 1127
TDM_SET_PROGRESS_BAR_STATE: win32more.Windows.Win32.UI.Controls.TASKDIALOG_MESSAGES = 1128
TDM_SET_PROGRESS_BAR_RANGE: win32more.Windows.Win32.UI.Controls.TASKDIALOG_MESSAGES = 1129
TDM_SET_PROGRESS_BAR_POS: win32more.Windows.Win32.UI.Controls.TASKDIALOG_MESSAGES = 1130
TDM_SET_PROGRESS_BAR_MARQUEE: win32more.Windows.Win32.UI.Controls.TASKDIALOG_MESSAGES = 1131
TDM_SET_ELEMENT_TEXT: win32more.Windows.Win32.UI.Controls.TASKDIALOG_MESSAGES = 1132
TDM_CLICK_RADIO_BUTTON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_MESSAGES = 1134
TDM_ENABLE_BUTTON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_MESSAGES = 1135
TDM_ENABLE_RADIO_BUTTON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_MESSAGES = 1136
TDM_CLICK_VERIFICATION: win32more.Windows.Win32.UI.Controls.TASKDIALOG_MESSAGES = 1137
TDM_UPDATE_ELEMENT_TEXT: win32more.Windows.Win32.UI.Controls.TASKDIALOG_MESSAGES = 1138
TDM_SET_BUTTON_ELEVATION_REQUIRED_STATE: win32more.Windows.Win32.UI.Controls.TASKDIALOG_MESSAGES = 1139
TDM_UPDATE_ICON: win32more.Windows.Win32.UI.Controls.TASKDIALOG_MESSAGES = 1140
TASKDIALOG_NOTIFICATIONS = Int32
TDN_CREATED: win32more.Windows.Win32.UI.Controls.TASKDIALOG_NOTIFICATIONS = 0
TDN_NAVIGATED: win32more.Windows.Win32.UI.Controls.TASKDIALOG_NOTIFICATIONS = 1
TDN_BUTTON_CLICKED: win32more.Windows.Win32.UI.Controls.TASKDIALOG_NOTIFICATIONS = 2
TDN_HYPERLINK_CLICKED: win32more.Windows.Win32.UI.Controls.TASKDIALOG_NOTIFICATIONS = 3
TDN_TIMER: win32more.Windows.Win32.UI.Controls.TASKDIALOG_NOTIFICATIONS = 4
TDN_DESTROYED: win32more.Windows.Win32.UI.Controls.TASKDIALOG_NOTIFICATIONS = 5
TDN_RADIO_BUTTON_CLICKED: win32more.Windows.Win32.UI.Controls.TASKDIALOG_NOTIFICATIONS = 6
TDN_DIALOG_CONSTRUCTED: win32more.Windows.Win32.UI.Controls.TASKDIALOG_NOTIFICATIONS = 7
TDN_VERIFICATION_CLICKED: win32more.Windows.Win32.UI.Controls.TASKDIALOG_NOTIFICATIONS = 8
TDN_HELP: win32more.Windows.Win32.UI.Controls.TASKDIALOG_NOTIFICATIONS = 9
TDN_EXPANDO_BUTTON_CLICKED: win32more.Windows.Win32.UI.Controls.TASKDIALOG_NOTIFICATIONS = 10
TASKLINKSTATES = Int32
CPTL_NORMAL: win32more.Windows.Win32.UI.Controls.TASKLINKSTATES = 1
CPTL_HOT: win32more.Windows.Win32.UI.Controls.TASKLINKSTATES = 2
CPTL_PRESSED: win32more.Windows.Win32.UI.Controls.TASKLINKSTATES = 3
CPTL_DISABLED: win32more.Windows.Win32.UI.Controls.TASKLINKSTATES = 4
CPTL_PAGE: win32more.Windows.Win32.UI.Controls.TASKLINKSTATES = 5
class TA_CUBIC_BEZIER(Structure):
    header: win32more.Windows.Win32.UI.Controls.TA_TIMINGFUNCTION
    rX0: Single
    rY0: Single
    rX1: Single
    rY1: Single
TA_PROPERTY = Int32
TAP_FLAGS: win32more.Windows.Win32.UI.Controls.TA_PROPERTY = 0
TAP_TRANSFORMCOUNT: win32more.Windows.Win32.UI.Controls.TA_PROPERTY = 1
TAP_STAGGERDELAY: win32more.Windows.Win32.UI.Controls.TA_PROPERTY = 2
TAP_STAGGERDELAYCAP: win32more.Windows.Win32.UI.Controls.TA_PROPERTY = 3
TAP_STAGGERDELAYFACTOR: win32more.Windows.Win32.UI.Controls.TA_PROPERTY = 4
TAP_ZORDER: win32more.Windows.Win32.UI.Controls.TA_PROPERTY = 5
TA_PROPERTY_FLAG = Int32
TAPF_NONE: win32more.Windows.Win32.UI.Controls.TA_PROPERTY_FLAG = 0
TAPF_HASSTAGGER: win32more.Windows.Win32.UI.Controls.TA_PROPERTY_FLAG = 1
TAPF_ISRTLAWARE: win32more.Windows.Win32.UI.Controls.TA_PROPERTY_FLAG = 2
TAPF_ALLOWCOLLECTION: win32more.Windows.Win32.UI.Controls.TA_PROPERTY_FLAG = 4
TAPF_HASBACKGROUND: win32more.Windows.Win32.UI.Controls.TA_PROPERTY_FLAG = 8
TAPF_HASPERSPECTIVE: win32more.Windows.Win32.UI.Controls.TA_PROPERTY_FLAG = 16
class TA_TIMINGFUNCTION(Structure):
    eTimingFunctionType: win32more.Windows.Win32.UI.Controls.TA_TIMINGFUNCTION_TYPE
TA_TIMINGFUNCTION_TYPE = Int32
TTFT_UNDEFINED: win32more.Windows.Win32.UI.Controls.TA_TIMINGFUNCTION_TYPE = 0
TTFT_CUBIC_BEZIER: win32more.Windows.Win32.UI.Controls.TA_TIMINGFUNCTION_TYPE = 1
class TA_TRANSFORM(Structure):
    eTransformType: win32more.Windows.Win32.UI.Controls.TA_TRANSFORM_TYPE
    dwTimingFunctionId: UInt32
    dwStartTime: UInt32
    dwDurationTime: UInt32
    eFlags: win32more.Windows.Win32.UI.Controls.TA_TRANSFORM_FLAG
class TA_TRANSFORM_2D(Structure):
    header: win32more.Windows.Win32.UI.Controls.TA_TRANSFORM
    rX: Single
    rY: Single
    rInitialX: Single
    rInitialY: Single
    rOriginX: Single
    rOriginY: Single
class TA_TRANSFORM_CLIP(Structure):
    header: win32more.Windows.Win32.UI.Controls.TA_TRANSFORM
    rLeft: Single
    rTop: Single
    rRight: Single
    rBottom: Single
    rInitialLeft: Single
    rInitialTop: Single
    rInitialRight: Single
    rInitialBottom: Single
TA_TRANSFORM_FLAG = Int32
TATF_NONE: win32more.Windows.Win32.UI.Controls.TA_TRANSFORM_FLAG = 0
TATF_TARGETVALUES_USER: win32more.Windows.Win32.UI.Controls.TA_TRANSFORM_FLAG = 1
TATF_HASINITIALVALUES: win32more.Windows.Win32.UI.Controls.TA_TRANSFORM_FLAG = 2
TATF_HASORIGINVALUES: win32more.Windows.Win32.UI.Controls.TA_TRANSFORM_FLAG = 4
class TA_TRANSFORM_OPACITY(Structure):
    header: win32more.Windows.Win32.UI.Controls.TA_TRANSFORM
    rOpacity: Single
    rInitialOpacity: Single
TA_TRANSFORM_TYPE = Int32
TATT_TRANSLATE_2D: win32more.Windows.Win32.UI.Controls.TA_TRANSFORM_TYPE = 0
TATT_SCALE_2D: win32more.Windows.Win32.UI.Controls.TA_TRANSFORM_TYPE = 1
TATT_OPACITY: win32more.Windows.Win32.UI.Controls.TA_TRANSFORM_TYPE = 2
TATT_CLIP: win32more.Windows.Win32.UI.Controls.TA_TRANSFORM_TYPE = 3
class TBADDBITMAP(Structure):
    hInst: win32more.Windows.Win32.Foundation.HINSTANCE
    nID: UIntPtr
if ARCH in 'X64,ARM64':
    class TBBUTTON(Structure):
        iBitmap: Int32
        idCommand: Int32
        fsState: Byte
        fsStyle: Byte
        bReserved: Byte * 6
        dwData: UIntPtr
        iString: IntPtr
elif ARCH in 'X86':
    class TBBUTTON(Structure):
        iBitmap: Int32
        idCommand: Int32
        fsState: Byte
        fsStyle: Byte
        bReserved: Byte * 2
        dwData: UIntPtr
        iString: IntPtr
class TBBUTTONINFOA(Structure):
    cbSize: UInt32
    dwMask: win32more.Windows.Win32.UI.Controls.TBBUTTONINFOW_MASK
    idCommand: Int32
    iImage: Int32
    fsState: Byte
    fsStyle: Byte
    cx: UInt16
    lParam: UIntPtr
    pszText: win32more.Windows.Win32.Foundation.PSTR
    cchText: Int32
class TBBUTTONINFOW(Structure):
    cbSize: UInt32
    dwMask: win32more.Windows.Win32.UI.Controls.TBBUTTONINFOW_MASK
    idCommand: Int32
    iImage: Int32
    fsState: Byte
    fsStyle: Byte
    cx: UInt16
    lParam: UIntPtr
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    cchText: Int32
TBBUTTONINFO = UnicodeAlias('TBBUTTONINFOW')
TBBUTTONINFOW_MASK = UInt32
TBIF_BYINDEX: win32more.Windows.Win32.UI.Controls.TBBUTTONINFOW_MASK = 2147483648
TBIF_COMMAND: win32more.Windows.Win32.UI.Controls.TBBUTTONINFOW_MASK = 32
TBIF_IMAGE: win32more.Windows.Win32.UI.Controls.TBBUTTONINFOW_MASK = 1
TBIF_LPARAM: win32more.Windows.Win32.UI.Controls.TBBUTTONINFOW_MASK = 16
TBIF_SIZE: win32more.Windows.Win32.UI.Controls.TBBUTTONINFOW_MASK = 64
TBIF_STATE: win32more.Windows.Win32.UI.Controls.TBBUTTONINFOW_MASK = 4
TBIF_STYLE: win32more.Windows.Win32.UI.Controls.TBBUTTONINFOW_MASK = 8
TBIF_TEXT: win32more.Windows.Win32.UI.Controls.TBBUTTONINFOW_MASK = 2
class TBINSERTMARK(Structure):
    iButton: Int32
    dwFlags: win32more.Windows.Win32.UI.Controls.TBINSERTMARK_FLAGS
TBINSERTMARK_FLAGS = UInt32
TBIMHT_NONE: win32more.Windows.Win32.UI.Controls.TBINSERTMARK_FLAGS = 0
TBIMHT_AFTER: win32more.Windows.Win32.UI.Controls.TBINSERTMARK_FLAGS = 1
TBIMHT_BACKGROUND: win32more.Windows.Win32.UI.Controls.TBINSERTMARK_FLAGS = 2
class TBMETRICS(Structure):
    cbSize: UInt32
    dwMask: UInt32
    cxPad: Int32
    cyPad: Int32
    cxBarPad: Int32
    cyBarPad: Int32
    cxButtonSpacing: Int32
    cyButtonSpacing: Int32
class TBREPLACEBITMAP(Structure):
    hInstOld: win32more.Windows.Win32.Foundation.HINSTANCE
    nIDOld: UIntPtr
    hInstNew: win32more.Windows.Win32.Foundation.HINSTANCE
    nIDNew: UIntPtr
    nButtons: Int32
class TBSAVEPARAMSA(Structure):
    hkr: win32more.Windows.Win32.System.Registry.HKEY
    pszSubKey: win32more.Windows.Win32.Foundation.PSTR
    pszValueName: win32more.Windows.Win32.Foundation.PSTR
class TBSAVEPARAMSW(Structure):
    hkr: win32more.Windows.Win32.System.Registry.HKEY
    pszSubKey: win32more.Windows.Win32.Foundation.PWSTR
    pszValueName: win32more.Windows.Win32.Foundation.PWSTR
TBSAVEPARAMS = UnicodeAlias('TBSAVEPARAMSW')
class TCHITTESTINFO(Structure):
    pt: win32more.Windows.Win32.Foundation.POINT
    flags: win32more.Windows.Win32.UI.Controls.TCHITTESTINFO_FLAGS
TCHITTESTINFO_FLAGS = UInt32
TCHT_NOWHERE: win32more.Windows.Win32.UI.Controls.TCHITTESTINFO_FLAGS = 1
TCHT_ONITEM: win32more.Windows.Win32.UI.Controls.TCHITTESTINFO_FLAGS = 6
TCHT_ONITEMICON: win32more.Windows.Win32.UI.Controls.TCHITTESTINFO_FLAGS = 2
TCHT_ONITEMLABEL: win32more.Windows.Win32.UI.Controls.TCHITTESTINFO_FLAGS = 4
class TCITEMA(Structure):
    mask: win32more.Windows.Win32.UI.Controls.TCITEMHEADERA_MASK
    dwState: win32more.Windows.Win32.UI.Controls.TAB_CONTROL_ITEM_STATE
    dwStateMask: win32more.Windows.Win32.UI.Controls.TAB_CONTROL_ITEM_STATE
    pszText: win32more.Windows.Win32.Foundation.PSTR
    cchTextMax: Int32
    iImage: Int32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
class TCITEMHEADERA(Structure):
    mask: win32more.Windows.Win32.UI.Controls.TCITEMHEADERA_MASK
    lpReserved1: UInt32
    lpReserved2: UInt32
    pszText: win32more.Windows.Win32.Foundation.PSTR
    cchTextMax: Int32
    iImage: Int32
TCITEMHEADERA_MASK = UInt32
TCIF_IMAGE: win32more.Windows.Win32.UI.Controls.TCITEMHEADERA_MASK = 2
TCIF_RTLREADING: win32more.Windows.Win32.UI.Controls.TCITEMHEADERA_MASK = 4
TCIF_TEXT: win32more.Windows.Win32.UI.Controls.TCITEMHEADERA_MASK = 1
TCIF_PARAM: win32more.Windows.Win32.UI.Controls.TCITEMHEADERA_MASK = 8
TCIF_STATE: win32more.Windows.Win32.UI.Controls.TCITEMHEADERA_MASK = 16
class TCITEMHEADERW(Structure):
    mask: win32more.Windows.Win32.UI.Controls.TCITEMHEADERA_MASK
    lpReserved1: UInt32
    lpReserved2: UInt32
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    cchTextMax: Int32
    iImage: Int32
TCITEMHEADER = UnicodeAlias('TCITEMHEADERW')
class TCITEMW(Structure):
    mask: win32more.Windows.Win32.UI.Controls.TCITEMHEADERA_MASK
    dwState: win32more.Windows.Win32.UI.Controls.TAB_CONTROL_ITEM_STATE
    dwStateMask: win32more.Windows.Win32.UI.Controls.TAB_CONTROL_ITEM_STATE
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    cchTextMax: Int32
    iImage: Int32
    lParam: win32more.Windows.Win32.Foundation.LPARAM
TCITEM = UnicodeAlias('TCITEMW')
TEXTSELECTIONGRIPPERPARTS = Int32
TSGP_GRIPPER: win32more.Windows.Win32.UI.Controls.TEXTSELECTIONGRIPPERPARTS = 1
TEXTSHADOWTYPE = Int32
TST_NONE: win32more.Windows.Win32.UI.Controls.TEXTSHADOWTYPE = 0
TST_SINGLE: win32more.Windows.Win32.UI.Controls.TEXTSHADOWTYPE = 1
TST_CONTINUOUS: win32more.Windows.Win32.UI.Controls.TEXTSHADOWTYPE = 2
TEXTSTYLEPARTS = Int32
TEXT_MAININSTRUCTION: win32more.Windows.Win32.UI.Controls.TEXTSTYLEPARTS = 1
TEXT_INSTRUCTION: win32more.Windows.Win32.UI.Controls.TEXTSTYLEPARTS = 2
TEXT_BODYTITLE: win32more.Windows.Win32.UI.Controls.TEXTSTYLEPARTS = 3
TEXT_BODYTEXT: win32more.Windows.Win32.UI.Controls.TEXTSTYLEPARTS = 4
TEXT_SECONDARYTEXT: win32more.Windows.Win32.UI.Controls.TEXTSTYLEPARTS = 5
TEXT_HYPERLINKTEXT: win32more.Windows.Win32.UI.Controls.TEXTSTYLEPARTS = 6
TEXT_EXPANDED: win32more.Windows.Win32.UI.Controls.TEXTSTYLEPARTS = 7
TEXT_LABEL: win32more.Windows.Win32.UI.Controls.TEXTSTYLEPARTS = 8
TEXT_CONTROLLABEL: win32more.Windows.Win32.UI.Controls.TEXTSTYLEPARTS = 9
THEMESIZE = Int32
TS_MIN: win32more.Windows.Win32.UI.Controls.THEMESIZE = 0
TS_TRUE: win32more.Windows.Win32.UI.Controls.THEMESIZE = 1
TS_DRAW: win32more.Windows.Win32.UI.Controls.THEMESIZE = 2
THEME_PROPERTY_SYMBOL_ID = UInt32
TMT_RESERVEDLOW: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 0
TMT_RESERVEDHIGH: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 7999
TMT_DIBDATA: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2
TMT_GLYPHDIBDATA: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 8
TMT_ENUM: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 200
TMT_STRING: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 201
TMT_INT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 202
TMT_BOOL: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 203
TMT_COLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 204
TMT_MARGINS: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 205
TMT_FILENAME: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 206
TMT_SIZE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 207
TMT_POSITION: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 208
TMT_RECT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 209
TMT_FONT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 210
TMT_INTLIST: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 211
TMT_HBITMAP: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 212
TMT_DISKSTREAM: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 213
TMT_STREAM: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 214
TMT_BITMAPREF: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 215
TMT_FLOAT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 216
TMT_FLOATLIST: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 217
TMT_COLORSCHEMES: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 401
TMT_SIZES: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 402
TMT_CHARSET: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 403
TMT_NAME: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 600
TMT_DISPLAYNAME: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 601
TMT_TOOLTIP: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 602
TMT_COMPANY: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 603
TMT_AUTHOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 604
TMT_COPYRIGHT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 605
TMT_URL: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 606
TMT_VERSION: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 607
TMT_DESCRIPTION: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 608
TMT_FIRST_RCSTRING_NAME: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 601
TMT_LAST_RCSTRING_NAME: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 608
TMT_CAPTIONFONT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 801
TMT_SMALLCAPTIONFONT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 802
TMT_MENUFONT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 803
TMT_STATUSFONT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 804
TMT_MSGBOXFONT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 805
TMT_ICONTITLEFONT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 806
TMT_HEADING1FONT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 807
TMT_HEADING2FONT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 808
TMT_BODYFONT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 809
TMT_FIRSTFONT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 801
TMT_LASTFONT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 809
TMT_FLATMENUS: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1001
TMT_FIRSTBOOL: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1001
TMT_LASTBOOL: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1001
TMT_SIZINGBORDERWIDTH: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1201
TMT_SCROLLBARWIDTH: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1202
TMT_SCROLLBARHEIGHT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1203
TMT_CAPTIONBARWIDTH: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1204
TMT_CAPTIONBARHEIGHT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1205
TMT_SMCAPTIONBARWIDTH: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1206
TMT_SMCAPTIONBARHEIGHT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1207
TMT_MENUBARWIDTH: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1208
TMT_MENUBARHEIGHT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1209
TMT_PADDEDBORDERWIDTH: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1210
TMT_FIRSTSIZE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1201
TMT_LASTSIZE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1210
TMT_MINCOLORDEPTH: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1301
TMT_FIRSTINT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1301
TMT_LASTINT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1301
TMT_CSSNAME: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1401
TMT_XMLNAME: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1402
TMT_LASTUPDATED: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1403
TMT_ALIAS: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1404
TMT_FIRSTSTRING: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1401
TMT_LASTSTRING: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1404
TMT_SCROLLBAR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1601
TMT_BACKGROUND: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1602
TMT_ACTIVECAPTION: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1603
TMT_INACTIVECAPTION: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1604
TMT_MENU: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1605
TMT_WINDOW: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1606
TMT_WINDOWFRAME: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1607
TMT_MENUTEXT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1608
TMT_WINDOWTEXT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1609
TMT_CAPTIONTEXT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1610
TMT_ACTIVEBORDER: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1611
TMT_INACTIVEBORDER: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1612
TMT_APPWORKSPACE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1613
TMT_HIGHLIGHT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1614
TMT_HIGHLIGHTTEXT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1615
TMT_BTNFACE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1616
TMT_BTNSHADOW: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1617
TMT_GRAYTEXT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1618
TMT_BTNTEXT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1619
TMT_INACTIVECAPTIONTEXT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1620
TMT_BTNHIGHLIGHT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1621
TMT_DKSHADOW3D: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1622
TMT_LIGHT3D: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1623
TMT_INFOTEXT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1624
TMT_INFOBK: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1625
TMT_BUTTONALTERNATEFACE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1626
TMT_HOTTRACKING: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1627
TMT_GRADIENTACTIVECAPTION: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1628
TMT_GRADIENTINACTIVECAPTION: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1629
TMT_MENUHILIGHT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1630
TMT_MENUBAR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1631
TMT_FIRSTCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1601
TMT_LASTCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1631
TMT_FROMHUE1: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1801
TMT_FROMHUE2: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1802
TMT_FROMHUE3: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1803
TMT_FROMHUE4: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1804
TMT_FROMHUE5: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1805
TMT_TOHUE1: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1806
TMT_TOHUE2: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1807
TMT_TOHUE3: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1808
TMT_TOHUE4: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1809
TMT_TOHUE5: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 1810
TMT_FROMCOLOR1: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2001
TMT_FROMCOLOR2: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2002
TMT_FROMCOLOR3: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2003
TMT_FROMCOLOR4: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2004
TMT_FROMCOLOR5: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2005
TMT_TOCOLOR1: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2006
TMT_TOCOLOR2: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2007
TMT_TOCOLOR3: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2008
TMT_TOCOLOR4: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2009
TMT_TOCOLOR5: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2010
TMT_TRANSPARENT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2201
TMT_AUTOSIZE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2202
TMT_BORDERONLY: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2203
TMT_COMPOSITED: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2204
TMT_BGFILL: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2205
TMT_GLYPHTRANSPARENT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2206
TMT_GLYPHONLY: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2207
TMT_ALWAYSSHOWSIZINGBAR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2208
TMT_MIRRORIMAGE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2209
TMT_UNIFORMSIZING: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2210
TMT_INTEGRALSIZING: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2211
TMT_SOURCEGROW: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2212
TMT_SOURCESHRINK: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2213
TMT_DRAWBORDERS: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2214
TMT_NOETCHEDEFFECT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2215
TMT_TEXTAPPLYOVERLAY: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2216
TMT_TEXTGLOW: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2217
TMT_TEXTITALIC: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2218
TMT_COMPOSITEDOPAQUE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2219
TMT_LOCALIZEDMIRRORIMAGE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2220
TMT_IMAGECOUNT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2401
TMT_ALPHALEVEL: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2402
TMT_BORDERSIZE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2403
TMT_ROUNDCORNERWIDTH: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2404
TMT_ROUNDCORNERHEIGHT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2405
TMT_GRADIENTRATIO1: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2406
TMT_GRADIENTRATIO2: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2407
TMT_GRADIENTRATIO3: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2408
TMT_GRADIENTRATIO4: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2409
TMT_GRADIENTRATIO5: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2410
TMT_PROGRESSCHUNKSIZE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2411
TMT_PROGRESSSPACESIZE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2412
TMT_SATURATION: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2413
TMT_TEXTBORDERSIZE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2414
TMT_ALPHATHRESHOLD: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2415
TMT_WIDTH: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2416
TMT_HEIGHT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2417
TMT_GLYPHINDEX: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2418
TMT_TRUESIZESTRETCHMARK: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2419
TMT_MINDPI1: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2420
TMT_MINDPI2: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2421
TMT_MINDPI3: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2422
TMT_MINDPI4: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2423
TMT_MINDPI5: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2424
TMT_TEXTGLOWSIZE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2425
TMT_FRAMESPERSECOND: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2426
TMT_PIXELSPERFRAME: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2427
TMT_ANIMATIONDELAY: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2428
TMT_GLOWINTENSITY: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2429
TMT_OPACITY: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2430
TMT_COLORIZATIONCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2431
TMT_COLORIZATIONOPACITY: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2432
TMT_MINDPI6: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2433
TMT_MINDPI7: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2434
TMT_GLYPHFONT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 2601
TMT_IMAGEFILE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3001
TMT_IMAGEFILE1: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3002
TMT_IMAGEFILE2: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3003
TMT_IMAGEFILE3: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3004
TMT_IMAGEFILE4: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3005
TMT_IMAGEFILE5: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3006
TMT_GLYPHIMAGEFILE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3008
TMT_IMAGEFILE6: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3009
TMT_IMAGEFILE7: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3010
TMT_TEXT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3201
TMT_CLASSICVALUE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3202
TMT_OFFSET: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3401
TMT_TEXTSHADOWOFFSET: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3402
TMT_MINSIZE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3403
TMT_MINSIZE1: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3404
TMT_MINSIZE2: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3405
TMT_MINSIZE3: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3406
TMT_MINSIZE4: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3407
TMT_MINSIZE5: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3408
TMT_NORMALSIZE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3409
TMT_MINSIZE6: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3410
TMT_MINSIZE7: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3411
TMT_SIZINGMARGINS: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3601
TMT_CONTENTMARGINS: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3602
TMT_CAPTIONMARGINS: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3603
TMT_BORDERCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3801
TMT_FILLCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3802
TMT_TEXTCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3803
TMT_EDGELIGHTCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3804
TMT_EDGEHIGHLIGHTCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3805
TMT_EDGESHADOWCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3806
TMT_EDGEDKSHADOWCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3807
TMT_EDGEFILLCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3808
TMT_TRANSPARENTCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3809
TMT_GRADIENTCOLOR1: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3810
TMT_GRADIENTCOLOR2: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3811
TMT_GRADIENTCOLOR3: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3812
TMT_GRADIENTCOLOR4: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3813
TMT_GRADIENTCOLOR5: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3814
TMT_SHADOWCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3815
TMT_GLOWCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3816
TMT_TEXTBORDERCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3817
TMT_TEXTSHADOWCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3818
TMT_GLYPHTEXTCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3819
TMT_GLYPHTRANSPARENTCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3820
TMT_FILLCOLORHINT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3821
TMT_BORDERCOLORHINT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3822
TMT_ACCENTCOLORHINT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3823
TMT_TEXTCOLORHINT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3824
TMT_HEADING1TEXTCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3825
TMT_HEADING2TEXTCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3826
TMT_BODYTEXTCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 3827
TMT_BGTYPE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 4001
TMT_BORDERTYPE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 4002
TMT_FILLTYPE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 4003
TMT_SIZINGTYPE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 4004
TMT_HALIGN: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 4005
TMT_CONTENTALIGNMENT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 4006
TMT_VALIGN: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 4007
TMT_OFFSETTYPE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 4008
TMT_ICONEFFECT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 4009
TMT_TEXTSHADOWTYPE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 4010
TMT_IMAGELAYOUT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 4011
TMT_GLYPHTYPE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 4012
TMT_IMAGESELECTTYPE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 4013
TMT_GLYPHFONTSIZINGTYPE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 4014
TMT_TRUESIZESCALINGTYPE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 4015
TMT_USERPICTURE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 5001
TMT_DEFAULTPANESIZE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 5002
TMT_BLENDCOLOR: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 5003
TMT_CUSTOMSPLITRECT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 5004
TMT_ANIMATIONBUTTONRECT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 5005
TMT_ANIMATIONDURATION: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 5006
TMT_TRANSITIONDURATIONS: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 6000
TMT_SCALEDBACKGROUND: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 7001
TMT_ATLASIMAGE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 8000
TMT_ATLASINPUTIMAGE: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 8001
TMT_ATLASRECT: win32more.Windows.Win32.UI.Controls.THEME_PROPERTY_SYMBOL_ID = 8002
THUMBBOTTOMSTATES = Int32
TUBS_NORMAL: win32more.Windows.Win32.UI.Controls.THUMBBOTTOMSTATES = 1
TUBS_HOT: win32more.Windows.Win32.UI.Controls.THUMBBOTTOMSTATES = 2
TUBS_PRESSED: win32more.Windows.Win32.UI.Controls.THUMBBOTTOMSTATES = 3
TUBS_FOCUSED: win32more.Windows.Win32.UI.Controls.THUMBBOTTOMSTATES = 4
TUBS_DISABLED: win32more.Windows.Win32.UI.Controls.THUMBBOTTOMSTATES = 5
THUMBLEFTSTATES = Int32
TUVLS_NORMAL: win32more.Windows.Win32.UI.Controls.THUMBLEFTSTATES = 1
TUVLS_HOT: win32more.Windows.Win32.UI.Controls.THUMBLEFTSTATES = 2
TUVLS_PRESSED: win32more.Windows.Win32.UI.Controls.THUMBLEFTSTATES = 3
TUVLS_FOCUSED: win32more.Windows.Win32.UI.Controls.THUMBLEFTSTATES = 4
TUVLS_DISABLED: win32more.Windows.Win32.UI.Controls.THUMBLEFTSTATES = 5
THUMBRIGHTSTATES = Int32
TUVRS_NORMAL: win32more.Windows.Win32.UI.Controls.THUMBRIGHTSTATES = 1
TUVRS_HOT: win32more.Windows.Win32.UI.Controls.THUMBRIGHTSTATES = 2
TUVRS_PRESSED: win32more.Windows.Win32.UI.Controls.THUMBRIGHTSTATES = 3
TUVRS_FOCUSED: win32more.Windows.Win32.UI.Controls.THUMBRIGHTSTATES = 4
TUVRS_DISABLED: win32more.Windows.Win32.UI.Controls.THUMBRIGHTSTATES = 5
THUMBSTATES = Int32
TUS_NORMAL: win32more.Windows.Win32.UI.Controls.THUMBSTATES = 1
TUS_HOT: win32more.Windows.Win32.UI.Controls.THUMBSTATES = 2
TUS_PRESSED: win32more.Windows.Win32.UI.Controls.THUMBSTATES = 3
TUS_FOCUSED: win32more.Windows.Win32.UI.Controls.THUMBSTATES = 4
TUS_DISABLED: win32more.Windows.Win32.UI.Controls.THUMBSTATES = 5
THUMBTOPSTATES = Int32
TUTS_NORMAL: win32more.Windows.Win32.UI.Controls.THUMBTOPSTATES = 1
TUTS_HOT: win32more.Windows.Win32.UI.Controls.THUMBTOPSTATES = 2
TUTS_PRESSED: win32more.Windows.Win32.UI.Controls.THUMBTOPSTATES = 3
TUTS_FOCUSED: win32more.Windows.Win32.UI.Controls.THUMBTOPSTATES = 4
TUTS_DISABLED: win32more.Windows.Win32.UI.Controls.THUMBTOPSTATES = 5
THUMBVERTSTATES = Int32
TUVS_NORMAL: win32more.Windows.Win32.UI.Controls.THUMBVERTSTATES = 1
TUVS_HOT: win32more.Windows.Win32.UI.Controls.THUMBVERTSTATES = 2
TUVS_PRESSED: win32more.Windows.Win32.UI.Controls.THUMBVERTSTATES = 3
TUVS_FOCUSED: win32more.Windows.Win32.UI.Controls.THUMBVERTSTATES = 4
TUVS_DISABLED: win32more.Windows.Win32.UI.Controls.THUMBVERTSTATES = 5
TICSSTATES = Int32
TSS_NORMAL: win32more.Windows.Win32.UI.Controls.TICSSTATES = 1
TICSVERTSTATES = Int32
TSVS_NORMAL: win32more.Windows.Win32.UI.Controls.TICSVERTSTATES = 1
TITLEBARSTATES = Int32
AW_S_TITLEBAR_ACTIVE: win32more.Windows.Win32.UI.Controls.TITLEBARSTATES = 1
AW_S_TITLEBAR_INACTIVE: win32more.Windows.Win32.UI.Controls.TITLEBARSTATES = 2
TOOLBARPARTS = Int32
TP_BUTTON: win32more.Windows.Win32.UI.Controls.TOOLBARPARTS = 1
TP_DROPDOWNBUTTON: win32more.Windows.Win32.UI.Controls.TOOLBARPARTS = 2
TP_SPLITBUTTON: win32more.Windows.Win32.UI.Controls.TOOLBARPARTS = 3
TP_SPLITBUTTONDROPDOWN: win32more.Windows.Win32.UI.Controls.TOOLBARPARTS = 4
TP_SEPARATOR: win32more.Windows.Win32.UI.Controls.TOOLBARPARTS = 5
TP_SEPARATORVERT: win32more.Windows.Win32.UI.Controls.TOOLBARPARTS = 6
TP_DROPDOWNBUTTONGLYPH: win32more.Windows.Win32.UI.Controls.TOOLBARPARTS = 7
TOOLBARSTYLESTATES = Int32
TS_NORMAL: win32more.Windows.Win32.UI.Controls.TOOLBARSTYLESTATES = 1
TS_HOT: win32more.Windows.Win32.UI.Controls.TOOLBARSTYLESTATES = 2
TS_PRESSED: win32more.Windows.Win32.UI.Controls.TOOLBARSTYLESTATES = 3
TS_DISABLED: win32more.Windows.Win32.UI.Controls.TOOLBARSTYLESTATES = 4
TS_CHECKED: win32more.Windows.Win32.UI.Controls.TOOLBARSTYLESTATES = 5
TS_HOTCHECKED: win32more.Windows.Win32.UI.Controls.TOOLBARSTYLESTATES = 6
TS_NEARHOT: win32more.Windows.Win32.UI.Controls.TOOLBARSTYLESTATES = 7
TS_OTHERSIDEHOT: win32more.Windows.Win32.UI.Controls.TOOLBARSTYLESTATES = 8
TOOLTIPPARTS = Int32
TTP_STANDARD: win32more.Windows.Win32.UI.Controls.TOOLTIPPARTS = 1
TTP_STANDARDTITLE: win32more.Windows.Win32.UI.Controls.TOOLTIPPARTS = 2
TTP_BALLOON: win32more.Windows.Win32.UI.Controls.TOOLTIPPARTS = 3
TTP_BALLOONTITLE: win32more.Windows.Win32.UI.Controls.TOOLTIPPARTS = 4
TTP_CLOSE: win32more.Windows.Win32.UI.Controls.TOOLTIPPARTS = 5
TTP_BALLOONSTEM: win32more.Windows.Win32.UI.Controls.TOOLTIPPARTS = 6
TTP_WRENCH: win32more.Windows.Win32.UI.Controls.TOOLTIPPARTS = 7
TOOLTIP_FLAGS = UInt32
TTF_IDISHWND: win32more.Windows.Win32.UI.Controls.TOOLTIP_FLAGS = 1
TTF_CENTERTIP: win32more.Windows.Win32.UI.Controls.TOOLTIP_FLAGS = 2
TTF_RTLREADING: win32more.Windows.Win32.UI.Controls.TOOLTIP_FLAGS = 4
TTF_SUBCLASS: win32more.Windows.Win32.UI.Controls.TOOLTIP_FLAGS = 16
TTF_TRACK: win32more.Windows.Win32.UI.Controls.TOOLTIP_FLAGS = 32
TTF_ABSOLUTE: win32more.Windows.Win32.UI.Controls.TOOLTIP_FLAGS = 128
TTF_TRANSPARENT: win32more.Windows.Win32.UI.Controls.TOOLTIP_FLAGS = 256
TTF_PARSELINKS: win32more.Windows.Win32.UI.Controls.TOOLTIP_FLAGS = 4096
TTF_DI_SETITEM: win32more.Windows.Win32.UI.Controls.TOOLTIP_FLAGS = 32768
TOPTABITEMBOTHEDGESTATES = Int32
TTIBES_NORMAL: win32more.Windows.Win32.UI.Controls.TOPTABITEMBOTHEDGESTATES = 1
TTIBES_HOT: win32more.Windows.Win32.UI.Controls.TOPTABITEMBOTHEDGESTATES = 2
TTIBES_SELECTED: win32more.Windows.Win32.UI.Controls.TOPTABITEMBOTHEDGESTATES = 3
TTIBES_DISABLED: win32more.Windows.Win32.UI.Controls.TOPTABITEMBOTHEDGESTATES = 4
TTIBES_FOCUSED: win32more.Windows.Win32.UI.Controls.TOPTABITEMBOTHEDGESTATES = 5
TOPTABITEMLEFTEDGESTATES = Int32
TTILES_NORMAL: win32more.Windows.Win32.UI.Controls.TOPTABITEMLEFTEDGESTATES = 1
TTILES_HOT: win32more.Windows.Win32.UI.Controls.TOPTABITEMLEFTEDGESTATES = 2
TTILES_SELECTED: win32more.Windows.Win32.UI.Controls.TOPTABITEMLEFTEDGESTATES = 3
TTILES_DISABLED: win32more.Windows.Win32.UI.Controls.TOPTABITEMLEFTEDGESTATES = 4
TTILES_FOCUSED: win32more.Windows.Win32.UI.Controls.TOPTABITEMLEFTEDGESTATES = 5
TOPTABITEMRIGHTEDGESTATES = Int32
TTIRES_NORMAL: win32more.Windows.Win32.UI.Controls.TOPTABITEMRIGHTEDGESTATES = 1
TTIRES_HOT: win32more.Windows.Win32.UI.Controls.TOPTABITEMRIGHTEDGESTATES = 2
TTIRES_SELECTED: win32more.Windows.Win32.UI.Controls.TOPTABITEMRIGHTEDGESTATES = 3
TTIRES_DISABLED: win32more.Windows.Win32.UI.Controls.TOPTABITEMRIGHTEDGESTATES = 4
TTIRES_FOCUSED: win32more.Windows.Win32.UI.Controls.TOPTABITEMRIGHTEDGESTATES = 5
TOPTABITEMSTATES = Int32
TTIS_NORMAL: win32more.Windows.Win32.UI.Controls.TOPTABITEMSTATES = 1
TTIS_HOT: win32more.Windows.Win32.UI.Controls.TOPTABITEMSTATES = 2
TTIS_SELECTED: win32more.Windows.Win32.UI.Controls.TOPTABITEMSTATES = 3
TTIS_DISABLED: win32more.Windows.Win32.UI.Controls.TOPTABITEMSTATES = 4
TTIS_FOCUSED: win32more.Windows.Win32.UI.Controls.TOPTABITEMSTATES = 5
class TOUCH_HIT_TESTING_INPUT(Structure):
    pointerId: UInt32
    point: win32more.Windows.Win32.Foundation.POINT
    boundingBox: win32more.Windows.Win32.Foundation.RECT
    nonOccludedBoundingBox: win32more.Windows.Win32.Foundation.RECT
    orientation: UInt32
class TOUCH_HIT_TESTING_PROXIMITY_EVALUATION(Structure):
    score: UInt16
    adjustedPoint: win32more.Windows.Win32.Foundation.POINT
TRACKBARPARTS = Int32
TKP_TRACK: win32more.Windows.Win32.UI.Controls.TRACKBARPARTS = 1
TKP_TRACKVERT: win32more.Windows.Win32.UI.Controls.TRACKBARPARTS = 2
TKP_THUMB: win32more.Windows.Win32.UI.Controls.TRACKBARPARTS = 3
TKP_THUMBBOTTOM: win32more.Windows.Win32.UI.Controls.TRACKBARPARTS = 4
TKP_THUMBTOP: win32more.Windows.Win32.UI.Controls.TRACKBARPARTS = 5
TKP_THUMBVERT: win32more.Windows.Win32.UI.Controls.TRACKBARPARTS = 6
TKP_THUMBLEFT: win32more.Windows.Win32.UI.Controls.TRACKBARPARTS = 7
TKP_THUMBRIGHT: win32more.Windows.Win32.UI.Controls.TRACKBARPARTS = 8
TKP_TICS: win32more.Windows.Win32.UI.Controls.TRACKBARPARTS = 9
TKP_TICSVERT: win32more.Windows.Win32.UI.Controls.TRACKBARPARTS = 10
TRACKBARSTYLESTATES = Int32
TKS_NORMAL: win32more.Windows.Win32.UI.Controls.TRACKBARSTYLESTATES = 1
TRACKSTATES = Int32
TRS_NORMAL: win32more.Windows.Win32.UI.Controls.TRACKSTATES = 1
TRACKVERTSTATES = Int32
TRVS_NORMAL: win32more.Windows.Win32.UI.Controls.TRACKVERTSTATES = 1
TRAILINGGRIDCELLSTATES = Int32
MCTGC_HOT: win32more.Windows.Win32.UI.Controls.TRAILINGGRIDCELLSTATES = 1
MCTGC_HASSTATE: win32more.Windows.Win32.UI.Controls.TRAILINGGRIDCELLSTATES = 2
MCTGC_HASSTATEHOT: win32more.Windows.Win32.UI.Controls.TRAILINGGRIDCELLSTATES = 3
MCTGC_TODAY: win32more.Windows.Win32.UI.Controls.TRAILINGGRIDCELLSTATES = 4
MCTGC_TODAYSELECTED: win32more.Windows.Win32.UI.Controls.TRAILINGGRIDCELLSTATES = 5
MCTGC_SELECTED: win32more.Windows.Win32.UI.Controls.TRAILINGGRIDCELLSTATES = 6
MCTGC_SELECTEDHOT: win32more.Windows.Win32.UI.Controls.TRAILINGGRIDCELLSTATES = 7
TRAILINGGRIDCELLUPPERSTATES = Int32
MCTGCU_HOT: win32more.Windows.Win32.UI.Controls.TRAILINGGRIDCELLUPPERSTATES = 1
MCTGCU_HASSTATE: win32more.Windows.Win32.UI.Controls.TRAILINGGRIDCELLUPPERSTATES = 2
MCTGCU_HASSTATEHOT: win32more.Windows.Win32.UI.Controls.TRAILINGGRIDCELLUPPERSTATES = 3
MCTGCU_SELECTED: win32more.Windows.Win32.UI.Controls.TRAILINGGRIDCELLUPPERSTATES = 4
MCTGCU_SELECTEDHOT: win32more.Windows.Win32.UI.Controls.TRAILINGGRIDCELLUPPERSTATES = 5
TRANSPARENTBACKGROUNDSTATES = Int32
CBTBS_NORMAL: win32more.Windows.Win32.UI.Controls.TRANSPARENTBACKGROUNDSTATES = 1
CBTBS_HOT: win32more.Windows.Win32.UI.Controls.TRANSPARENTBACKGROUNDSTATES = 2
CBTBS_DISABLED: win32more.Windows.Win32.UI.Controls.TRANSPARENTBACKGROUNDSTATES = 3
CBTBS_FOCUSED: win32more.Windows.Win32.UI.Controls.TRANSPARENTBACKGROUNDSTATES = 4
TRANSPARENTBARSTATES = Int32
PBBS_NORMAL: win32more.Windows.Win32.UI.Controls.TRANSPARENTBARSTATES = 1
PBBS_PARTIAL: win32more.Windows.Win32.UI.Controls.TRANSPARENTBARSTATES = 2
TRANSPARENTBARVERTSTATES = Int32
PBBVS_NORMAL: win32more.Windows.Win32.UI.Controls.TRANSPARENTBARVERTSTATES = 1
PBBVS_PARTIAL: win32more.Windows.Win32.UI.Controls.TRANSPARENTBARVERTSTATES = 2
TRAYNOTIFYPARTS = Int32
TNP_BACKGROUND: win32more.Windows.Win32.UI.Controls.TRAYNOTIFYPARTS = 1
TNP_ANIMBACKGROUND: win32more.Windows.Win32.UI.Controls.TRAYNOTIFYPARTS = 2
TREEITEMSTATES = Int32
TREIS_NORMAL: win32more.Windows.Win32.UI.Controls.TREEITEMSTATES = 1
TREIS_HOT: win32more.Windows.Win32.UI.Controls.TREEITEMSTATES = 2
TREIS_SELECTED: win32more.Windows.Win32.UI.Controls.TREEITEMSTATES = 3
TREIS_DISABLED: win32more.Windows.Win32.UI.Controls.TREEITEMSTATES = 4
TREIS_SELECTEDNOTFOCUS: win32more.Windows.Win32.UI.Controls.TREEITEMSTATES = 5
TREIS_HOTSELECTED: win32more.Windows.Win32.UI.Controls.TREEITEMSTATES = 6
TREEVIEWPARTS = Int32
TVP_TREEITEM: win32more.Windows.Win32.UI.Controls.TREEVIEWPARTS = 1
TVP_GLYPH: win32more.Windows.Win32.UI.Controls.TREEVIEWPARTS = 2
TVP_BRANCH: win32more.Windows.Win32.UI.Controls.TREEVIEWPARTS = 3
TVP_HOTGLYPH: win32more.Windows.Win32.UI.Controls.TREEVIEWPARTS = 4
TREE_VIEW_ITEM_STATE_FLAGS = UInt32
TVIS_SELECTED: win32more.Windows.Win32.UI.Controls.TREE_VIEW_ITEM_STATE_FLAGS = 2
TVIS_CUT: win32more.Windows.Win32.UI.Controls.TREE_VIEW_ITEM_STATE_FLAGS = 4
TVIS_DROPHILITED: win32more.Windows.Win32.UI.Controls.TREE_VIEW_ITEM_STATE_FLAGS = 8
TVIS_BOLD: win32more.Windows.Win32.UI.Controls.TREE_VIEW_ITEM_STATE_FLAGS = 16
TVIS_EXPANDED: win32more.Windows.Win32.UI.Controls.TREE_VIEW_ITEM_STATE_FLAGS = 32
TVIS_EXPANDEDONCE: win32more.Windows.Win32.UI.Controls.TREE_VIEW_ITEM_STATE_FLAGS = 64
TVIS_EXPANDPARTIAL: win32more.Windows.Win32.UI.Controls.TREE_VIEW_ITEM_STATE_FLAGS = 128
TVIS_OVERLAYMASK: win32more.Windows.Win32.UI.Controls.TREE_VIEW_ITEM_STATE_FLAGS = 3840
TVIS_STATEIMAGEMASK: win32more.Windows.Win32.UI.Controls.TREE_VIEW_ITEM_STATE_FLAGS = 61440
TVIS_USERMASK: win32more.Windows.Win32.UI.Controls.TREE_VIEW_ITEM_STATE_FLAGS = 61440
TVIS_EX_FLAT: win32more.Windows.Win32.UI.Controls.TREE_VIEW_ITEM_STATE_FLAGS = 1
TVIS_EX_DISABLED: win32more.Windows.Win32.UI.Controls.TREE_VIEW_ITEM_STATE_FLAGS = 2
TVIS_EX_ALL: win32more.Windows.Win32.UI.Controls.TREE_VIEW_ITEM_STATE_FLAGS = 2
TRUESIZESCALINGTYPE = Int32
TSST_NONE: win32more.Windows.Win32.UI.Controls.TRUESIZESCALINGTYPE = 0
TSST_SIZE: win32more.Windows.Win32.UI.Controls.TRUESIZESCALINGTYPE = 1
TSST_DPI: win32more.Windows.Win32.UI.Controls.TRUESIZESCALINGTYPE = 2
class TTGETTITLE(Structure):
    dwSize: UInt32
    uTitleBitmap: UInt32
    cch: UInt32
    pszTitle: win32more.Windows.Win32.Foundation.PWSTR
class TTHITTESTINFOA(Structure):
    hwnd: win32more.Windows.Win32.Foundation.HWND
    pt: win32more.Windows.Win32.Foundation.POINT
    ti: win32more.Windows.Win32.UI.Controls.TTTOOLINFOA
class TTHITTESTINFOW(Structure):
    hwnd: win32more.Windows.Win32.Foundation.HWND
    pt: win32more.Windows.Win32.Foundation.POINT
    ti: win32more.Windows.Win32.UI.Controls.TTTOOLINFOW
TTHITTESTINFO = UnicodeAlias('TTHITTESTINFOW')
class TTTOOLINFOA(Structure):
    cbSize: UInt32
    uFlags: win32more.Windows.Win32.UI.Controls.TOOLTIP_FLAGS
    hwnd: win32more.Windows.Win32.Foundation.HWND
    uId: UIntPtr
    rect: win32more.Windows.Win32.Foundation.RECT
    hinst: win32more.Windows.Win32.Foundation.HINSTANCE
    lpszText: win32more.Windows.Win32.Foundation.PSTR
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    lpReserved: VoidPtr
class TTTOOLINFOW(Structure):
    cbSize: UInt32
    uFlags: win32more.Windows.Win32.UI.Controls.TOOLTIP_FLAGS
    hwnd: win32more.Windows.Win32.Foundation.HWND
    uId: UIntPtr
    rect: win32more.Windows.Win32.Foundation.RECT
    hinst: win32more.Windows.Win32.Foundation.HINSTANCE
    lpszText: win32more.Windows.Win32.Foundation.PWSTR
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    lpReserved: VoidPtr
TTTOOLINFO = UnicodeAlias('TTTOOLINFOW')
class TVGETITEMPARTRECTINFO(Structure):
    hti: win32more.Windows.Win32.UI.Controls.HTREEITEM
    prc: POINTER(win32more.Windows.Win32.Foundation.RECT)
    partID: win32more.Windows.Win32.UI.Controls.TVITEMPART
class TVHITTESTINFO(Structure):
    pt: win32more.Windows.Win32.Foundation.POINT
    flags: win32more.Windows.Win32.UI.Controls.TVHITTESTINFO_FLAGS
    hItem: win32more.Windows.Win32.UI.Controls.HTREEITEM
TVHITTESTINFO_FLAGS = UInt32
TVHT_ABOVE: win32more.Windows.Win32.UI.Controls.TVHITTESTINFO_FLAGS = 256
TVHT_BELOW: win32more.Windows.Win32.UI.Controls.TVHITTESTINFO_FLAGS = 512
TVHT_NOWHERE: win32more.Windows.Win32.UI.Controls.TVHITTESTINFO_FLAGS = 1
TVHT_ONITEM: win32more.Windows.Win32.UI.Controls.TVHITTESTINFO_FLAGS = 70
TVHT_ONITEMBUTTON: win32more.Windows.Win32.UI.Controls.TVHITTESTINFO_FLAGS = 16
TVHT_ONITEMICON: win32more.Windows.Win32.UI.Controls.TVHITTESTINFO_FLAGS = 2
TVHT_ONITEMINDENT: win32more.Windows.Win32.UI.Controls.TVHITTESTINFO_FLAGS = 8
TVHT_ONITEMLABEL: win32more.Windows.Win32.UI.Controls.TVHITTESTINFO_FLAGS = 4
TVHT_ONITEMRIGHT: win32more.Windows.Win32.UI.Controls.TVHITTESTINFO_FLAGS = 32
TVHT_ONITEMSTATEICON: win32more.Windows.Win32.UI.Controls.TVHITTESTINFO_FLAGS = 64
TVHT_TOLEFT: win32more.Windows.Win32.UI.Controls.TVHITTESTINFO_FLAGS = 2048
TVHT_TORIGHT: win32more.Windows.Win32.UI.Controls.TVHITTESTINFO_FLAGS = 1024
class TVINSERTSTRUCTA(Structure):
    hParent: win32more.Windows.Win32.UI.Controls.HTREEITEM
    hInsertAfter: win32more.Windows.Win32.UI.Controls.HTREEITEM
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        itemex: win32more.Windows.Win32.UI.Controls.TVITEMEXA
        item: win32more.Windows.Win32.UI.Controls.TVITEMA
class TVINSERTSTRUCTW(Structure):
    hParent: win32more.Windows.Win32.UI.Controls.HTREEITEM
    hInsertAfter: win32more.Windows.Win32.UI.Controls.HTREEITEM
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        itemex: win32more.Windows.Win32.UI.Controls.TVITEMEXW
        item: win32more.Windows.Win32.UI.Controls.TVITEMW
TVINSERTSTRUCT = UnicodeAlias('TVINSERTSTRUCTW')
class TVITEMA(Structure):
    mask: win32more.Windows.Win32.UI.Controls.TVITEM_MASK
    hItem: win32more.Windows.Win32.UI.Controls.HTREEITEM
    state: win32more.Windows.Win32.UI.Controls.TREE_VIEW_ITEM_STATE_FLAGS
    stateMask: win32more.Windows.Win32.UI.Controls.TREE_VIEW_ITEM_STATE_FLAGS
    pszText: win32more.Windows.Win32.Foundation.PSTR
    cchTextMax: Int32
    iImage: Int32
    iSelectedImage: Int32
    cChildren: win32more.Windows.Win32.UI.Controls.TVITEMEXW_CHILDREN
    lParam: win32more.Windows.Win32.Foundation.LPARAM
class TVITEMEXA(Structure):
    mask: win32more.Windows.Win32.UI.Controls.TVITEM_MASK
    hItem: win32more.Windows.Win32.UI.Controls.HTREEITEM
    state: UInt32
    stateMask: UInt32
    pszText: win32more.Windows.Win32.Foundation.PSTR
    cchTextMax: Int32
    iImage: Int32
    iSelectedImage: Int32
    cChildren: win32more.Windows.Win32.UI.Controls.TVITEMEXW_CHILDREN
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    iIntegral: Int32
    uStateEx: UInt32
    hwnd: win32more.Windows.Win32.Foundation.HWND
    iExpandedImage: Int32
    iReserved: Int32
class TVITEMEXW(Structure):
    mask: win32more.Windows.Win32.UI.Controls.TVITEM_MASK
    hItem: win32more.Windows.Win32.UI.Controls.HTREEITEM
    state: UInt32
    stateMask: UInt32
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    cchTextMax: Int32
    iImage: Int32
    iSelectedImage: Int32
    cChildren: win32more.Windows.Win32.UI.Controls.TVITEMEXW_CHILDREN
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    iIntegral: Int32
    uStateEx: UInt32
    hwnd: win32more.Windows.Win32.Foundation.HWND
    iExpandedImage: Int32
    iReserved: Int32
TVITEMEX = UnicodeAlias('TVITEMEXW')
TVITEMEXW_CHILDREN = Int32
I_ZERO: win32more.Windows.Win32.UI.Controls.TVITEMEXW_CHILDREN = 0
I_ONE_OR_MORE: win32more.Windows.Win32.UI.Controls.TVITEMEXW_CHILDREN = 1
I_CHILDRENCALLBACK: win32more.Windows.Win32.UI.Controls.TVITEMEXW_CHILDREN = -1
I_CHILDRENAUTO: win32more.Windows.Win32.UI.Controls.TVITEMEXW_CHILDREN = -2
TVITEMPART = Int32
TVGIPR_BUTTON: win32more.Windows.Win32.UI.Controls.TVITEMPART = 1
class TVITEMW(Structure):
    mask: win32more.Windows.Win32.UI.Controls.TVITEM_MASK
    hItem: win32more.Windows.Win32.UI.Controls.HTREEITEM
    state: win32more.Windows.Win32.UI.Controls.TREE_VIEW_ITEM_STATE_FLAGS
    stateMask: win32more.Windows.Win32.UI.Controls.TREE_VIEW_ITEM_STATE_FLAGS
    pszText: win32more.Windows.Win32.Foundation.PWSTR
    cchTextMax: Int32
    iImage: Int32
    iSelectedImage: Int32
    cChildren: win32more.Windows.Win32.UI.Controls.TVITEMEXW_CHILDREN
    lParam: win32more.Windows.Win32.Foundation.LPARAM
TVITEM = UnicodeAlias('TVITEMW')
TVITEM_MASK = UInt32
TVIF_CHILDREN: win32more.Windows.Win32.UI.Controls.TVITEM_MASK = 64
TVIF_DI_SETITEM: win32more.Windows.Win32.UI.Controls.TVITEM_MASK = 4096
TVIF_HANDLE: win32more.Windows.Win32.UI.Controls.TVITEM_MASK = 16
TVIF_IMAGE: win32more.Windows.Win32.UI.Controls.TVITEM_MASK = 2
TVIF_PARAM: win32more.Windows.Win32.UI.Controls.TVITEM_MASK = 4
TVIF_SELECTEDIMAGE: win32more.Windows.Win32.UI.Controls.TVITEM_MASK = 32
TVIF_STATE: win32more.Windows.Win32.UI.Controls.TVITEM_MASK = 8
TVIF_TEXT: win32more.Windows.Win32.UI.Controls.TVITEM_MASK = 1
TVIF_EXPANDEDIMAGE: win32more.Windows.Win32.UI.Controls.TVITEM_MASK = 512
TVIF_INTEGRAL: win32more.Windows.Win32.UI.Controls.TVITEM_MASK = 128
TVIF_STATEEX: win32more.Windows.Win32.UI.Controls.TVITEM_MASK = 256
class TVSORTCB(Structure):
    hParent: win32more.Windows.Win32.UI.Controls.HTREEITEM
    lpfnCompare: win32more.Windows.Win32.UI.Controls.PFNTVCOMPARE
    lParam: win32more.Windows.Win32.Foundation.LPARAM
class UDACCEL(Structure):
    nSec: UInt32
    nInc: UInt32
UPDATEMETADATASTATES = Int32
DDUPDATEMETADATA_HIGHLIGHT: win32more.Windows.Win32.UI.Controls.UPDATEMETADATASTATES = 1
DDUPDATEMETADATA_NOHIGHLIGHT: win32more.Windows.Win32.UI.Controls.UPDATEMETADATASTATES = 2
UPHORZSTATES = Int32
UPHZS_NORMAL: win32more.Windows.Win32.UI.Controls.UPHORZSTATES = 1
UPHZS_HOT: win32more.Windows.Win32.UI.Controls.UPHORZSTATES = 2
UPHZS_PRESSED: win32more.Windows.Win32.UI.Controls.UPHORZSTATES = 3
UPHZS_DISABLED: win32more.Windows.Win32.UI.Controls.UPHORZSTATES = 4
UPSTATES = Int32
UPS_NORMAL: win32more.Windows.Win32.UI.Controls.UPSTATES = 1
UPS_HOT: win32more.Windows.Win32.UI.Controls.UPSTATES = 2
UPS_PRESSED: win32more.Windows.Win32.UI.Controls.UPSTATES = 3
UPS_DISABLED: win32more.Windows.Win32.UI.Controls.UPSTATES = 4
class USAGE_PROPERTIES(Structure):
    level: UInt16
    page: UInt16
    usage: UInt16
    logicalMinimum: Int32
    logicalMaximum: Int32
    unit: UInt16
    exponent: UInt16
    count: Byte
    physicalMinimum: Int32
    physicalMaximum: Int32
USERTILEPARTS = Int32
UTP_STROKEBACKGROUND: win32more.Windows.Win32.UI.Controls.USERTILEPARTS = 1
UTP_HOVERBACKGROUND: win32more.Windows.Win32.UI.Controls.USERTILEPARTS = 2
VALIGN = Int32
VA_TOP: win32more.Windows.Win32.UI.Controls.VALIGN = 0
VA_CENTER: win32more.Windows.Win32.UI.Controls.VALIGN = 1
VA_BOTTOM: win32more.Windows.Win32.UI.Controls.VALIGN = 2
VERTSCROLLSTATES = Int32
VSS_NORMAL: win32more.Windows.Win32.UI.Controls.VERTSCROLLSTATES = 1
VSS_HOT: win32more.Windows.Win32.UI.Controls.VERTSCROLLSTATES = 2
VSS_PUSHED: win32more.Windows.Win32.UI.Controls.VERTSCROLLSTATES = 3
VSS_DISABLED: win32more.Windows.Win32.UI.Controls.VERTSCROLLSTATES = 4
VERTTHUMBSTATES = Int32
VTS_NORMAL: win32more.Windows.Win32.UI.Controls.VERTTHUMBSTATES = 1
VTS_HOT: win32more.Windows.Win32.UI.Controls.VERTTHUMBSTATES = 2
VTS_PUSHED: win32more.Windows.Win32.UI.Controls.VERTTHUMBSTATES = 3
VTS_DISABLED: win32more.Windows.Win32.UI.Controls.VERTTHUMBSTATES = 4
WARNINGSTATES = Int32
DDWARNING_HIGHLIGHT: win32more.Windows.Win32.UI.Controls.WARNINGSTATES = 1
DDWARNING_NOHIGHLIGHT: win32more.Windows.Win32.UI.Controls.WARNINGSTATES = 2
WINDOWPARTS = Int32
WP_CAPTION: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 1
WP_SMALLCAPTION: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 2
WP_MINCAPTION: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 3
WP_SMALLMINCAPTION: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 4
WP_MAXCAPTION: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 5
WP_SMALLMAXCAPTION: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 6
WP_FRAMELEFT: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 7
WP_FRAMERIGHT: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 8
WP_FRAMEBOTTOM: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 9
WP_SMALLFRAMELEFT: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 10
WP_SMALLFRAMERIGHT: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 11
WP_SMALLFRAMEBOTTOM: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 12
WP_SYSBUTTON: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 13
WP_MDISYSBUTTON: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 14
WP_MINBUTTON: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 15
WP_MDIMINBUTTON: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 16
WP_MAXBUTTON: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 17
WP_CLOSEBUTTON: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 18
WP_SMALLCLOSEBUTTON: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 19
WP_MDICLOSEBUTTON: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 20
WP_RESTOREBUTTON: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 21
WP_MDIRESTOREBUTTON: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 22
WP_HELPBUTTON: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 23
WP_MDIHELPBUTTON: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 24
WP_HORZSCROLL: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 25
WP_HORZTHUMB: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 26
WP_VERTSCROLL: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 27
WP_VERTTHUMB: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 28
WP_DIALOG: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 29
WP_CAPTIONSIZINGTEMPLATE: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 30
WP_SMALLCAPTIONSIZINGTEMPLATE: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 31
WP_FRAMELEFTSIZINGTEMPLATE: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 32
WP_SMALLFRAMELEFTSIZINGTEMPLATE: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 33
WP_FRAMERIGHTSIZINGTEMPLATE: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 34
WP_SMALLFRAMERIGHTSIZINGTEMPLATE: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 35
WP_FRAMEBOTTOMSIZINGTEMPLATE: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 36
WP_SMALLFRAMEBOTTOMSIZINGTEMPLATE: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 37
WP_FRAME: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 38
WP_BORDER: win32more.Windows.Win32.UI.Controls.WINDOWPARTS = 39
WINDOWTHEMEATTRIBUTETYPE = Int32
WTA_NONCLIENT: win32more.Windows.Win32.UI.Controls.WINDOWTHEMEATTRIBUTETYPE = 1
WORD_BREAK_ACTION = Int32
WB_CLASSIFY: win32more.Windows.Win32.UI.Controls.WORD_BREAK_ACTION = 3
WB_ISDELIMITER: win32more.Windows.Win32.UI.Controls.WORD_BREAK_ACTION = 2
WB_LEFT: win32more.Windows.Win32.UI.Controls.WORD_BREAK_ACTION = 0
WB_LEFTBREAK: win32more.Windows.Win32.UI.Controls.WORD_BREAK_ACTION = 6
WB_MOVEWORDLEFT: win32more.Windows.Win32.UI.Controls.WORD_BREAK_ACTION = 4
WB_MOVEWORDRIGHT: win32more.Windows.Win32.UI.Controls.WORD_BREAK_ACTION = 5
WB_RIGHT: win32more.Windows.Win32.UI.Controls.WORD_BREAK_ACTION = 1
WB_RIGHTBREAK: win32more.Windows.Win32.UI.Controls.WORD_BREAK_ACTION = 7
WRENCHSTATES = Int32
TTWS_NORMAL: win32more.Windows.Win32.UI.Controls.WRENCHSTATES = 1
TTWS_HOT: win32more.Windows.Win32.UI.Controls.WRENCHSTATES = 2
TTWS_PRESSED: win32more.Windows.Win32.UI.Controls.WRENCHSTATES = 3
WSB_PROP = Int32
WSB_PROP_CXHSCROLL: win32more.Windows.Win32.UI.Controls.WSB_PROP = 2
WSB_PROP_CXHTHUMB: win32more.Windows.Win32.UI.Controls.WSB_PROP = 16
WSB_PROP_CXVSCROLL: win32more.Windows.Win32.UI.Controls.WSB_PROP = 8
WSB_PROP_CYHSCROLL: win32more.Windows.Win32.UI.Controls.WSB_PROP = 4
WSB_PROP_CYVSCROLL: win32more.Windows.Win32.UI.Controls.WSB_PROP = 1
WSB_PROP_CYVTHUMB: win32more.Windows.Win32.UI.Controls.WSB_PROP = 32
WSB_PROP_HBKGCOLOR: win32more.Windows.Win32.UI.Controls.WSB_PROP = 128
WSB_PROP_HSTYLE: win32more.Windows.Win32.UI.Controls.WSB_PROP = 512
WSB_PROP_PALETTE: win32more.Windows.Win32.UI.Controls.WSB_PROP = 2048
WSB_PROP_VBKGCOLOR: win32more.Windows.Win32.UI.Controls.WSB_PROP = 64
WSB_PROP_VSTYLE: win32more.Windows.Win32.UI.Controls.WSB_PROP = 256
WSB_PROP_WINSTYLE: win32more.Windows.Win32.UI.Controls.WSB_PROP = 1024
class WTA_OPTIONS(Structure):
    dwFlags: UInt32
    dwMask: UInt32
_LI_METRIC = Int32
LIM_SMALL: win32more.Windows.Win32.UI.Controls._LI_METRIC = 0
LIM_LARGE: win32more.Windows.Win32.UI.Controls._LI_METRIC = 1


make_ready(__name__)
