from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.Security.Authentication.Identity
import win32more.Windows.Win32.Security.Credentials
import win32more.Windows.Win32.Security.Cryptography
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Kernel
import win32more.Windows.Win32.System.PasswordManagement
import win32more.Windows.Win32.System.Rpc
import win32more.Windows.Win32.System.Threading
@winfunctype_pointer
def ACCEPT_SECURITY_CONTEXT_FN(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param2: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), param3: UInt32, param4: UInt32, param5: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param6: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), param7: POINTER(UInt32), param8: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def ACQUIRE_CREDENTIALS_HANDLE_FN_A(param0: POINTER(SByte), param1: POINTER(SByte), param2: UInt32, param3: VoidPtr, param4: VoidPtr, param5: win32more.Windows.Win32.Security.Authentication.Identity.SEC_GET_KEY_FN, param6: VoidPtr, param7: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param8: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def ACQUIRE_CREDENTIALS_HANDLE_FN_W(param0: POINTER(UInt16), param1: POINTER(UInt16), param2: UInt32, param3: VoidPtr, param4: VoidPtr, param5: win32more.Windows.Win32.Security.Authentication.Identity.SEC_GET_KEY_FN, param6: VoidPtr, param7: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param8: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
ACQUIRE_CREDENTIALS_HANDLE_FN = UnicodeAlias('ACQUIRE_CREDENTIALS_HANDLE_FN_W')
@winfunctype_pointer
def ADD_CREDENTIALS_FN_A(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: POINTER(SByte), param2: POINTER(SByte), param3: UInt32, param4: VoidPtr, param5: win32more.Windows.Win32.Security.Authentication.Identity.SEC_GET_KEY_FN, param6: VoidPtr, param7: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def ADD_CREDENTIALS_FN_W(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: POINTER(UInt16), param2: POINTER(UInt16), param3: UInt32, param4: VoidPtr, param5: win32more.Windows.Win32.Security.Authentication.Identity.SEC_GET_KEY_FN, param6: VoidPtr, param7: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
ADD_CREDENTIALS_FN = UnicodeAlias('ADD_CREDENTIALS_FN_W')
@winfunctype_pointer
def APPLY_CONTROL_TOKEN_FN(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
ASC_REQ_FLAGS = UInt32
ASC_REQ_DELEGATE: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 1
ASC_REQ_MUTUAL_AUTH: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 2
ASC_REQ_REPLAY_DETECT: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 4
ASC_REQ_SEQUENCE_DETECT: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 8
ASC_REQ_CONFIDENTIALITY: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 16
ASC_REQ_USE_SESSION_KEY: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 32
ASC_REQ_SESSION_TICKET: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 64
ASC_REQ_ALLOCATE_MEMORY: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 256
ASC_REQ_USE_DCE_STYLE: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 512
ASC_REQ_DATAGRAM: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 1024
ASC_REQ_CONNECTION: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 2048
ASC_REQ_CALL_LEVEL: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 4096
ASC_REQ_FRAGMENT_SUPPLIED: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 8192
ASC_REQ_EXTENDED_ERROR: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 32768
ASC_REQ_STREAM: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 65536
ASC_REQ_INTEGRITY: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 131072
ASC_REQ_LICENSING: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 262144
ASC_REQ_IDENTIFY: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 524288
ASC_REQ_ALLOW_NULL_SESSION: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 1048576
ASC_REQ_ALLOW_NON_USER_LOGONS: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 2097152
ASC_REQ_ALLOW_CONTEXT_REPLAY: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 4194304
ASC_REQ_FRAGMENT_TO_FIT: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 8388608
ASC_REQ_NO_TOKEN: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 16777216
ASC_REQ_PROXY_BINDINGS: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 67108864
ASC_REQ_ALLOW_MISSING_BINDINGS: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS = 268435456
ASC_REQ_HIGH_FLAGS = UInt64
ASC_REQ_MESSAGES: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_HIGH_FLAGS = 4294967296
class AUDIT_POLICY_INFORMATION(Structure):
    AuditSubCategoryGuid: Guid
    AuditingInformation: UInt32
    AuditCategoryGuid: Guid
NTLMSP_NAME_A: String = 'NTLM'
NTLMSP_NAME: String = 'NTLM'
MICROSOFT_KERBEROS_NAME_A: String = 'Kerberos'
MICROSOFT_KERBEROS_NAME_W: String = 'Kerberos'
MICROSOFT_KERBEROS_NAME: String = 'Kerberos'
NEGOSSP_NAME_W: String = 'Negotiate'
NEGOSSP_NAME_A: String = 'Negotiate'
NEGOSSP_NAME: String = 'Negotiate'
CLOUDAP_NAME_W: String = 'CloudAP'
ClOUDAP_NAME_A: String = 'CloudAP'
CLOUDAP_NAME: String = 'CloudAP'
ISSP_LEVEL: UInt32 = 32
ISSP_MODE: UInt32 = 1
SECPKG_FLAG_INTEGRITY: UInt32 = 1
SECPKG_FLAG_PRIVACY: UInt32 = 2
SECPKG_FLAG_TOKEN_ONLY: UInt32 = 4
SECPKG_FLAG_DATAGRAM: UInt32 = 8
SECPKG_FLAG_CONNECTION: UInt32 = 16
SECPKG_FLAG_MULTI_REQUIRED: UInt32 = 32
SECPKG_FLAG_CLIENT_ONLY: UInt32 = 64
SECPKG_FLAG_EXTENDED_ERROR: UInt32 = 128
SECPKG_FLAG_IMPERSONATION: UInt32 = 256
SECPKG_FLAG_ACCEPT_WIN32_NAME: UInt32 = 512
SECPKG_FLAG_STREAM: UInt32 = 1024
SECPKG_FLAG_NEGOTIABLE: UInt32 = 2048
SECPKG_FLAG_GSS_COMPATIBLE: UInt32 = 4096
SECPKG_FLAG_LOGON: UInt32 = 8192
SECPKG_FLAG_ASCII_BUFFERS: UInt32 = 16384
SECPKG_FLAG_FRAGMENT: UInt32 = 32768
SECPKG_FLAG_MUTUAL_AUTH: UInt32 = 65536
SECPKG_FLAG_DELEGATION: UInt32 = 131072
SECPKG_FLAG_READONLY_WITH_CHECKSUM: UInt32 = 262144
SECPKG_FLAG_RESTRICTED_TOKENS: UInt32 = 524288
SECPKG_FLAG_NEGO_EXTENDER: UInt32 = 1048576
SECPKG_FLAG_NEGOTIABLE2: UInt32 = 2097152
SECPKG_FLAG_APPCONTAINER_PASSTHROUGH: UInt32 = 4194304
SECPKG_FLAG_APPCONTAINER_CHECKS: UInt32 = 8388608
SECPKG_FLAG_CREDENTIAL_ISOLATION_ENABLED: UInt32 = 16777216
SECPKG_FLAG_APPLY_LOOPBACK: UInt32 = 33554432
SECPKG_ID_NONE: UInt32 = 65535
SECPKG_CALLFLAGS_APPCONTAINER: UInt32 = 1
SECPKG_CALLFLAGS_APPCONTAINER_AUTHCAPABLE: UInt32 = 2
SECPKG_CALLFLAGS_FORCE_SUPPLIED: UInt32 = 4
SECPKG_CALLFLAGS_APPCONTAINER_UPNCAPABLE: UInt32 = 8
SECBUFFER_VERSION: UInt32 = 0
SECBUFFER_EMPTY: UInt32 = 0
SECBUFFER_DATA: UInt32 = 1
SECBUFFER_TOKEN: UInt32 = 2
SECBUFFER_PKG_PARAMS: UInt32 = 3
SECBUFFER_MISSING: UInt32 = 4
SECBUFFER_EXTRA: UInt32 = 5
SECBUFFER_STREAM_TRAILER: UInt32 = 6
SECBUFFER_STREAM_HEADER: UInt32 = 7
SECBUFFER_NEGOTIATION_INFO: UInt32 = 8
SECBUFFER_PADDING: UInt32 = 9
SECBUFFER_STREAM: UInt32 = 10
SECBUFFER_MECHLIST: UInt32 = 11
SECBUFFER_MECHLIST_SIGNATURE: UInt32 = 12
SECBUFFER_TARGET: UInt32 = 13
SECBUFFER_CHANNEL_BINDINGS: UInt32 = 14
SECBUFFER_CHANGE_PASS_RESPONSE: UInt32 = 15
SECBUFFER_TARGET_HOST: UInt32 = 16
SECBUFFER_ALERT: UInt32 = 17
SECBUFFER_APPLICATION_PROTOCOLS: UInt32 = 18
SECBUFFER_SRTP_PROTECTION_PROFILES: UInt32 = 19
SECBUFFER_SRTP_MASTER_KEY_IDENTIFIER: UInt32 = 20
SECBUFFER_TOKEN_BINDING: UInt32 = 21
SECBUFFER_PRESHARED_KEY: UInt32 = 22
SECBUFFER_PRESHARED_KEY_IDENTITY: UInt32 = 23
SECBUFFER_DTLS_MTU: UInt32 = 24
SECBUFFER_SEND_GENERIC_TLS_EXTENSION: UInt32 = 25
SECBUFFER_SUBSCRIBE_GENERIC_TLS_EXTENSION: UInt32 = 26
SECBUFFER_FLAGS: UInt32 = 27
SECBUFFER_TRAFFIC_SECRETS: UInt32 = 28
SECBUFFER_CERTIFICATE_REQUEST_CONTEXT: UInt32 = 29
SECBUFFER_CHANNEL_BINDINGS_RESULT: UInt32 = 30
SECBUFFER_ATTRMASK: UInt32 = 4026531840
SECBUFFER_READONLY: UInt32 = 2147483648
SECBUFFER_READONLY_WITH_CHECKSUM: UInt32 = 268435456
SECBUFFER_RESERVED: UInt32 = 1610612736
SEC_CHANNEL_BINDINGS_AUDIT_BINDINGS: UInt32 = 1
SEC_CHANNEL_BINDINGS_VALID_FLAGS: UInt32 = 1
SEC_CHANNEL_BINDINGS_RESULT_CLIENT_SUPPORT: UInt32 = 1
SEC_CHANNEL_BINDINGS_RESULT_ABSENT: UInt32 = 2
SEC_CHANNEL_BINDINGS_RESULT_NOTVALID_MISMATCH: UInt32 = 4
SEC_CHANNEL_BINDINGS_RESULT_NOTVALID_MISSING: UInt32 = 8
SEC_CHANNEL_BINDINGS_RESULT_VALID_MATCHED: UInt32 = 16
SEC_CHANNEL_BINDINGS_RESULT_VALID_PROXY: UInt32 = 32
SEC_CHANNEL_BINDINGS_RESULT_VALID_MISSING: UInt32 = 64
SZ_ALG_MAX_SIZE: UInt32 = 64
SECURITY_NATIVE_DREP: UInt32 = 16
SECURITY_NETWORK_DREP: UInt32 = 0
SECPKG_CRED_BOTH: UInt32 = 3
SECPKG_CRED_DEFAULT: UInt32 = 4
SECPKG_CRED_RESERVED: UInt32 = 4026531840
SECPKG_CRED_AUTOLOGON_RESTRICTED: UInt32 = 16
SECPKG_CRED_PROCESS_POLICY_ONLY: UInt32 = 32
ISC_RET_DELEGATE: UInt32 = 1
ISC_RET_MUTUAL_AUTH: UInt32 = 2
ISC_RET_REPLAY_DETECT: UInt32 = 4
ISC_RET_SEQUENCE_DETECT: UInt32 = 8
ISC_RET_CONFIDENTIALITY: UInt32 = 16
ISC_RET_USE_SESSION_KEY: UInt32 = 32
ISC_RET_USED_COLLECTED_CREDS: UInt32 = 64
ISC_RET_USED_SUPPLIED_CREDS: UInt32 = 128
ISC_RET_ALLOCATED_MEMORY: UInt32 = 256
ISC_RET_USED_DCE_STYLE: UInt32 = 512
ISC_RET_DATAGRAM: UInt32 = 1024
ISC_RET_CONNECTION: UInt32 = 2048
ISC_RET_INTERMEDIATE_RETURN: UInt32 = 4096
ISC_RET_CALL_LEVEL: UInt32 = 8192
ISC_RET_EXTENDED_ERROR: UInt32 = 16384
ISC_RET_STREAM: UInt32 = 32768
ISC_RET_INTEGRITY: UInt32 = 65536
ISC_RET_IDENTIFY: UInt32 = 131072
ISC_RET_NULL_SESSION: UInt32 = 262144
ISC_RET_MANUAL_CRED_VALIDATION: UInt32 = 524288
ISC_RET_RESERVED1: UInt32 = 1048576
ISC_RET_FRAGMENT_ONLY: UInt32 = 2097152
ISC_RET_FORWARD_CREDENTIALS: UInt32 = 4194304
ISC_RET_USED_HTTP_STYLE: UInt32 = 16777216
ISC_RET_NO_ADDITIONAL_TOKEN: UInt32 = 33554432
ISC_RET_REAUTHENTICATION: UInt32 = 134217728
ISC_RET_CONFIDENTIALITY_ONLY: UInt32 = 1073741824
ISC_RET_MESSAGES: UInt64 = 4294967296
ISC_RET_DEFERRED_CRED_VALIDATION: UInt64 = 8589934592
ISC_RET_NO_POST_HANDSHAKE_AUTH: UInt64 = 17179869184
ASC_RET_DELEGATE: UInt32 = 1
ASC_RET_MUTUAL_AUTH: UInt32 = 2
ASC_RET_REPLAY_DETECT: UInt32 = 4
ASC_RET_SEQUENCE_DETECT: UInt32 = 8
ASC_RET_CONFIDENTIALITY: UInt32 = 16
ASC_RET_USE_SESSION_KEY: UInt32 = 32
ASC_RET_SESSION_TICKET: UInt32 = 64
ASC_RET_ALLOCATED_MEMORY: UInt32 = 256
ASC_RET_USED_DCE_STYLE: UInt32 = 512
ASC_RET_DATAGRAM: UInt32 = 1024
ASC_RET_CONNECTION: UInt32 = 2048
ASC_RET_CALL_LEVEL: UInt32 = 8192
ASC_RET_THIRD_LEG_FAILED: UInt32 = 16384
ASC_RET_EXTENDED_ERROR: UInt32 = 32768
ASC_RET_STREAM: UInt32 = 65536
ASC_RET_INTEGRITY: UInt32 = 131072
ASC_RET_LICENSING: UInt32 = 262144
ASC_RET_IDENTIFY: UInt32 = 524288
ASC_RET_NULL_SESSION: UInt32 = 1048576
ASC_RET_ALLOW_NON_USER_LOGONS: UInt32 = 2097152
ASC_RET_ALLOW_CONTEXT_REPLAY: UInt32 = 4194304
ASC_RET_FRAGMENT_ONLY: UInt32 = 8388608
ASC_RET_NO_TOKEN: UInt32 = 16777216
ASC_RET_NO_ADDITIONAL_TOKEN: UInt32 = 33554432
ASC_RET_MESSAGES: UInt64 = 4294967296
SECPKG_CRED_ATTR_NAMES: UInt32 = 1
SECPKG_CRED_ATTR_SSI_PROVIDER: UInt32 = 2
SECPKG_CRED_ATTR_KDC_PROXY_SETTINGS: UInt32 = 3
SECPKG_CRED_ATTR_CERT: UInt32 = 4
SECPKG_CRED_ATTR_PAC_BYPASS: UInt32 = 5
KDC_PROXY_SETTINGS_V1: UInt32 = 1
KDC_PROXY_SETTINGS_FLAGS_FORCEPROXY: UInt32 = 1
SECPKG_ATTR_PROTO_INFO: UInt32 = 7
SECPKG_ATTR_USER_FLAGS: UInt32 = 11
SECPKG_ATTR_USE_VALIDATED: UInt32 = 15
SECPKG_ATTR_CREDENTIAL_NAME: UInt32 = 16
SECPKG_ATTR_TARGET: UInt32 = 19
SECPKG_ATTR_AUTHENTICATION_ID: UInt32 = 20
SECPKG_ATTR_LOGOFF_TIME: UInt32 = 21
SECPKG_ATTR_NEGO_KEYS: UInt32 = 22
SECPKG_ATTR_PROMPTING_NEEDED: UInt32 = 24
SECPKG_ATTR_NEGO_PKG_INFO: UInt32 = 31
SECPKG_ATTR_NEGO_STATUS: UInt32 = 32
SECPKG_ATTR_CONTEXT_DELETED: UInt32 = 33
SECPKG_ATTR_APPLICATION_PROTOCOL: UInt32 = 35
SECPKG_ATTR_NEGOTIATED_TLS_EXTENSIONS: UInt32 = 36
SECPKG_ATTR_IS_LOOPBACK: UInt32 = 37
SECPKG_ATTR_NEGO_INFO_FLAG_NO_KERBEROS: UInt32 = 1
SECPKG_ATTR_NEGO_INFO_FLAG_NO_NTLM: UInt32 = 2
SECPKG_NEGOTIATION_COMPLETE: UInt32 = 0
SECPKG_NEGOTIATION_OPTIMISTIC: UInt32 = 1
SECPKG_NEGOTIATION_IN_PROGRESS: UInt32 = 2
SECPKG_NEGOTIATION_DIRECT: UInt32 = 3
SECPKG_NEGOTIATION_TRY_MULTICRED: UInt32 = 4
MAX_PROTOCOL_ID_SIZE: UInt32 = 255
SECQOP_WRAP_NO_ENCRYPT: UInt32 = 2147483649
SECQOP_WRAP_OOB_DATA: UInt32 = 1073741824
SECURITY_ENTRYPOINT_ANSIW: String = 'InitSecurityInterfaceW'
SECURITY_ENTRYPOINT_ANSIA: String = 'InitSecurityInterfaceA'
SECURITY_ENTRYPOINT16: String = 'INITSECURITYINTERFACEA'
SECURITY_ENTRYPOINT_ANSI: String = 'InitSecurityInterfaceW'
SECURITY_ENTRYPOINT: String = 'INITSECURITYINTERFACEA'
SECURITY_SUPPORT_PROVIDER_INTERFACE_VERSION: UInt32 = 1
SECURITY_SUPPORT_PROVIDER_INTERFACE_VERSION_2: UInt32 = 2
SECURITY_SUPPORT_PROVIDER_INTERFACE_VERSION_3: UInt32 = 3
SECURITY_SUPPORT_PROVIDER_INTERFACE_VERSION_4: UInt32 = 4
SECURITY_SUPPORT_PROVIDER_INTERFACE_VERSION_5: UInt32 = 5
SASL_OPTION_SEND_SIZE: UInt32 = 1
SASL_OPTION_RECV_SIZE: UInt32 = 2
SASL_OPTION_AUTHZ_STRING: UInt32 = 3
SASL_OPTION_AUTHZ_PROCESSING: UInt32 = 4
SEC_WINNT_AUTH_IDENTITY_VERSION_2: UInt32 = 513
SEC_WINNT_AUTH_IDENTITY_VERSION: UInt32 = 512
SEC_WINNT_AUTH_IDENTITY_FLAGS_PROCESS_ENCRYPTED: UInt32 = 16
SEC_WINNT_AUTH_IDENTITY_FLAGS_SYSTEM_PROTECTED: UInt32 = 32
SEC_WINNT_AUTH_IDENTITY_FLAGS_USER_PROTECTED: UInt32 = 64
SEC_WINNT_AUTH_IDENTITY_FLAGS_SYSTEM_ENCRYPTED: UInt32 = 128
SEC_WINNT_AUTH_IDENTITY_FLAGS_RESERVED: UInt32 = 65536
SEC_WINNT_AUTH_IDENTITY_FLAGS_NULL_USER: UInt32 = 131072
SEC_WINNT_AUTH_IDENTITY_FLAGS_NULL_DOMAIN: UInt32 = 262144
SEC_WINNT_AUTH_IDENTITY_FLAGS_ID_PROVIDER: UInt32 = 524288
SEC_WINNT_AUTH_IDENTITY_FLAGS_SSPIPFC_USE_MASK: UInt32 = 4278190080
SEC_WINNT_AUTH_IDENTITY_FLAGS_SSPIPFC_CREDPROV_DO_NOT_SAVE: UInt32 = 2147483648
SEC_WINNT_AUTH_IDENTITY_FLAGS_SSPIPFC_SAVE_CRED_BY_CALLER: UInt32 = 2147483648
SEC_WINNT_AUTH_IDENTITY_FLAGS_SSPIPFC_SAVE_CRED_CHECKED: UInt32 = 1073741824
SEC_WINNT_AUTH_IDENTITY_FLAGS_SSPIPFC_NO_CHECKBOX: UInt32 = 536870912
SEC_WINNT_AUTH_IDENTITY_FLAGS_SSPIPFC_CREDPROV_DO_NOT_LOAD: UInt32 = 268435456
SSPIPFC_CREDPROV_DO_NOT_SAVE: UInt32 = 1
SSPIPFC_SAVE_CRED_BY_CALLER: UInt32 = 1
SSPIPFC_NO_CHECKBOX: UInt32 = 2
SSPIPFC_CREDPROV_DO_NOT_LOAD: UInt32 = 4
SSPIPFC_USE_CREDUIBROKER: UInt32 = 8
NGC_DATA_FLAG_KERB_CERTIFICATE_LOGON_FLAG_CHECK_DUPLICATES: UInt32 = 1
NGC_DATA_FLAG_KERB_CERTIFICATE_LOGON_FLAG_USE_CERTIFICATE_INFO: UInt32 = 2
NGC_DATA_FLAG_IS_SMARTCARD_DATA: UInt32 = 4
NGC_DATA_FLAG_IS_CLOUD_TRUST_CRED: UInt32 = 8
SEC_WINNT_AUTH_IDENTITY_ENCRYPT_SAME_LOGON: UInt32 = 1
SEC_WINNT_AUTH_IDENTITY_ENCRYPT_SAME_PROCESS: UInt32 = 2
SEC_WINNT_AUTH_IDENTITY_ENCRYPT_FOR_SYSTEM: UInt32 = 4
SEC_WINNT_AUTH_IDENTITY_MARSHALLED: UInt32 = 4
SEC_WINNT_AUTH_IDENTITY_ONLY: UInt32 = 8
SECPKG_OPTIONS_PERMANENT: UInt32 = 1
LOOKUP_VIEW_LOCAL_INFORMATION: UInt32 = 1
LOOKUP_TRANSLATE_NAMES: UInt32 = 2048
SECPKG_ATTR_ISSUER_LIST: UInt32 = 80
SECPKG_ATTR_REMOTE_CRED: UInt32 = 81
SECPKG_ATTR_SUPPORTED_ALGS: UInt32 = 86
SECPKG_ATTR_CIPHER_STRENGTHS: UInt32 = 87
SECPKG_ATTR_SUPPORTED_PROTOCOLS: UInt32 = 88
SECPKG_ATTR_MAPPED_CRED_ATTR: UInt32 = 92
SECPKG_ATTR_REMOTE_CERTIFICATES: UInt32 = 95
SECPKG_ATTR_CLIENT_CERT_POLICY: UInt32 = 96
SECPKG_ATTR_CC_POLICY_RESULT: UInt32 = 97
SECPKG_ATTR_USE_NCRYPT: UInt32 = 98
SECPKG_ATTR_LOCAL_CERT_INFO: UInt32 = 99
SECPKG_ATTR_CIPHER_INFO: UInt32 = 100
SECPKG_ATTR_REMOTE_CERT_CHAIN: UInt32 = 103
SECPKG_ATTR_UI_INFO: UInt32 = 104
SECPKG_ATTR_KEYING_MATERIAL: UInt32 = 107
SECPKG_ATTR_SRTP_PARAMETERS: UInt32 = 108
SECPKG_ATTR_TOKEN_BINDING: UInt32 = 109
SECPKG_ATTR_CONNECTION_INFO_EX: UInt32 = 110
SECPKG_ATTR_KEYING_MATERIAL_TOKEN_BINDING: UInt32 = 111
SECPKG_ATTR_KEYING_MATERIAL_INPROC: UInt32 = 112
SECPKG_ATTR_CERT_CHECK_RESULT: UInt32 = 113
SECPKG_ATTR_CERT_CHECK_RESULT_INPROC: UInt32 = 114
SECPKG_ATTR_SESSION_TICKET_KEYS: UInt32 = 115
SECPKG_ATTR_SERIALIZED_REMOTE_CERT_CONTEXT_INPROC: UInt32 = 116
SECPKG_ATTR_SERIALIZED_REMOTE_CERT_CONTEXT: UInt32 = 117
SESSION_TICKET_INFO_V0: UInt32 = 0
SESSION_TICKET_INFO_VERSION: UInt32 = 0
LSA_MODE_PASSWORD_PROTECTED: Int32 = 1
LSA_MODE_INDIVIDUAL_ACCOUNTS: Int32 = 2
LSA_MODE_MANDATORY_ACCESS: Int32 = 4
LSA_MODE_LOG_FULL: Int32 = 8
LSA_MAXIMUM_SID_COUNT: Int32 = 256
LSA_MAXIMUM_ENUMERATION_LENGTH: UInt32 = 32000
LSA_CALL_LICENSE_SERVER: UInt32 = 2147483648
SE_ADT_OBJECT_ONLY: UInt32 = 1
SE_MAX_AUDIT_PARAMETERS: UInt32 = 32
SE_MAX_GENERIC_AUDIT_PARAMETERS: UInt32 = 28
SE_ADT_PARAMETERS_SELF_RELATIVE: UInt32 = 1
SE_ADT_PARAMETERS_SEND_TO_LSA: UInt32 = 2
SE_ADT_PARAMETER_EXTENSIBLE_AUDIT: UInt32 = 4
SE_ADT_PARAMETER_GENERIC_AUDIT: UInt32 = 8
SE_ADT_PARAMETER_WRITE_SYNCHRONOUS: UInt32 = 16
LSA_ADT_SECURITY_SOURCE_NAME: String = 'Microsoft-Windows-Security-Auditing'
LSA_ADT_LEGACY_SECURITY_SOURCE_NAME: String = 'Security'
SE_ADT_POLICY_AUDIT_EVENT_TYPE_EX_BEGIN: UInt32 = 100
POLICY_AUDIT_EVENT_UNCHANGED: Int32 = 0
POLICY_AUDIT_EVENT_SUCCESS: Int32 = 1
POLICY_AUDIT_EVENT_FAILURE: Int32 = 2
POLICY_AUDIT_EVENT_NONE: Int32 = 4
LSA_AP_NAME_INITIALIZE_PACKAGE: String = 'LsaApInitializePackage\x00'
LSA_AP_NAME_LOGON_USER: String = 'LsaApLogonUser\x00'
LSA_AP_NAME_LOGON_USER_EX: String = 'LsaApLogonUserEx\x00'
LSA_AP_NAME_CALL_PACKAGE: String = 'LsaApCallPackage\x00'
LSA_AP_NAME_LOGON_TERMINATED: String = 'LsaApLogonTerminated\x00'
LSA_AP_NAME_CALL_PACKAGE_UNTRUSTED: String = 'LsaApCallPackageUntrusted\x00'
LSA_AP_NAME_CALL_PACKAGE_PASSTHROUGH: String = 'LsaApCallPackagePassthrough\x00'
POLICY_VIEW_LOCAL_INFORMATION: Int32 = 1
POLICY_VIEW_AUDIT_INFORMATION: Int32 = 2
POLICY_GET_PRIVATE_INFORMATION: Int32 = 4
POLICY_TRUST_ADMIN: Int32 = 8
POLICY_CREATE_ACCOUNT: Int32 = 16
POLICY_CREATE_SECRET: Int32 = 32
POLICY_CREATE_PRIVILEGE: Int32 = 64
POLICY_SET_DEFAULT_QUOTA_LIMITS: Int32 = 128
POLICY_SET_AUDIT_REQUIREMENTS: Int32 = 256
POLICY_AUDIT_LOG_ADMIN: Int32 = 512
POLICY_SERVER_ADMIN: Int32 = 1024
POLICY_LOOKUP_NAMES: Int32 = 2048
POLICY_NOTIFICATION: Int32 = 4096
LSA_LOOKUP_ISOLATED_AS_LOCAL: UInt32 = 2147483648
LSA_LOOKUP_DISALLOW_CONNECTED_ACCOUNT_INTERNET_SID: UInt32 = 2147483648
LSA_LOOKUP_PREFER_INTERNET_NAMES: UInt32 = 1073741824
PER_USER_POLICY_UNCHANGED: UInt32 = 0
PER_USER_AUDIT_SUCCESS_INCLUDE: UInt32 = 1
PER_USER_AUDIT_SUCCESS_EXCLUDE: UInt32 = 2
PER_USER_AUDIT_FAILURE_INCLUDE: UInt32 = 4
PER_USER_AUDIT_FAILURE_EXCLUDE: UInt32 = 8
PER_USER_AUDIT_NONE: UInt32 = 16
POLICY_QOS_SCHANNEL_REQUIRED: UInt32 = 1
POLICY_QOS_OUTBOUND_INTEGRITY: UInt32 = 2
POLICY_QOS_OUTBOUND_CONFIDENTIALITY: UInt32 = 4
POLICY_QOS_INBOUND_INTEGRITY: UInt32 = 8
POLICY_QOS_INBOUND_CONFIDENTIALITY: UInt32 = 16
POLICY_QOS_ALLOW_LOCAL_ROOT_CERT_STORE: UInt32 = 32
POLICY_QOS_RAS_SERVER_ALLOWED: UInt32 = 64
POLICY_QOS_DHCP_SERVER_ALLOWED: UInt32 = 128
POLICY_KERBEROS_VALIDATE_CLIENT: UInt32 = 128
ACCOUNT_VIEW: Int32 = 1
ACCOUNT_ADJUST_PRIVILEGES: Int32 = 2
ACCOUNT_ADJUST_QUOTAS: Int32 = 4
ACCOUNT_ADJUST_SYSTEM_ACCESS: Int32 = 8
TRUSTED_QUERY_DOMAIN_NAME: Int32 = 1
TRUSTED_QUERY_CONTROLLERS: Int32 = 2
TRUSTED_SET_CONTROLLERS: Int32 = 4
TRUSTED_QUERY_POSIX: Int32 = 8
TRUSTED_SET_POSIX: Int32 = 16
TRUSTED_SET_AUTH: Int32 = 32
TRUSTED_QUERY_AUTH: Int32 = 64
LSAD_AES_CRYPT_SHA512_HASH_SIZE: UInt32 = 64
LSAD_AES_KEY_SIZE: UInt32 = 16
LSAD_AES_SALT_SIZE: UInt32 = 16
LSAD_AES_BLOCK_SIZE: UInt32 = 16
TRUST_TYPE_AAD: UInt32 = 5
TRUST_ATTRIBUTE_TREE_PARENT: UInt32 = 4194304
TRUST_ATTRIBUTE_TREE_ROOT: UInt32 = 8388608
TRUST_ATTRIBUTES_VALID: UInt32 = 4278386687
TRUST_ATTRIBUTE_QUARANTINED_DOMAIN: UInt32 = 4
TRUST_ATTRIBUTE_TRUST_USES_RC4_ENCRYPTION: UInt32 = 128
TRUST_ATTRIBUTE_TRUST_USES_AES_KEYS: UInt32 = 256
TRUST_ATTRIBUTE_CROSS_ORGANIZATION_NO_TGT_DELEGATION: UInt32 = 512
TRUST_ATTRIBUTE_PIM_TRUST: UInt32 = 1024
TRUST_ATTRIBUTE_CROSS_ORGANIZATION_ENABLE_TGT_DELEGATION: UInt32 = 2048
TRUST_ATTRIBUTE_DISABLE_AUTH_TARGET_VALIDATION: UInt32 = 4096
TRUST_ATTRIBUTES_USER: UInt32 = 4278190080
LSA_FOREST_TRUST_RECORD_TYPE_UNRECOGNIZED: UInt32 = 2147483648
LSA_FTRECORD_DISABLED_REASONS: Int32 = 65535
LSA_TLN_DISABLED_NEW: Int32 = 1
LSA_TLN_DISABLED_ADMIN: Int32 = 2
LSA_TLN_DISABLED_CONFLICT: Int32 = 4
LSA_SID_DISABLED_ADMIN: Int32 = 1
LSA_SID_DISABLED_CONFLICT: Int32 = 2
LSA_NB_DISABLED_ADMIN: Int32 = 4
LSA_NB_DISABLED_CONFLICT: Int32 = 8
LSA_SCANNER_INFO_DISABLE_AUTH_TARGET_VALIDATION: Int32 = 1
LSA_SCANNER_INFO_ADMIN_ALL_FLAGS: Int32 = 1
MAX_RECORDS_IN_FOREST_TRUST_INFO: UInt32 = 4000
SECRET_SET_VALUE: Int32 = 1
SECRET_QUERY_VALUE: Int32 = 2
LSA_GLOBAL_SECRET_PREFIX: String = 'G$'
LSA_GLOBAL_SECRET_PREFIX_LENGTH: UInt32 = 2
LSA_LOCAL_SECRET_PREFIX: String = 'L$'
LSA_LOCAL_SECRET_PREFIX_LENGTH: UInt32 = 2
LSA_MACHINE_SECRET_PREFIX: String = 'M$'
LSA_SECRET_MAXIMUM_COUNT: Int32 = 4096
LSA_SECRET_MAXIMUM_LENGTH: Int32 = 512
MAXIMUM_CAPES_PER_CAP: UInt32 = 127
CENTRAL_ACCESS_POLICY_OWNER_RIGHTS_PRESENT_FLAG: UInt32 = 1
CENTRAL_ACCESS_POLICY_STAGED_OWNER_RIGHTS_PRESENT_FLAG: UInt32 = 256
CENTRAL_ACCESS_POLICY_STAGED_FLAG: UInt32 = 65536
LSASETCAPS_RELOAD_FLAG: UInt32 = 1
LSASETCAPS_VALID_FLAG_MASK: UInt32 = 1
SE_INTERACTIVE_LOGON_NAME: String = 'SeInteractiveLogonRight'
SE_NETWORK_LOGON_NAME: String = 'SeNetworkLogonRight'
SE_BATCH_LOGON_NAME: String = 'SeBatchLogonRight'
SE_SERVICE_LOGON_NAME: String = 'SeServiceLogonRight'
SE_DENY_INTERACTIVE_LOGON_NAME: String = 'SeDenyInteractiveLogonRight'
SE_DENY_NETWORK_LOGON_NAME: String = 'SeDenyNetworkLogonRight'
SE_DENY_BATCH_LOGON_NAME: String = 'SeDenyBatchLogonRight'
SE_DENY_SERVICE_LOGON_NAME: String = 'SeDenyServiceLogonRight'
SE_REMOTE_INTERACTIVE_LOGON_NAME: String = 'SeRemoteInteractiveLogonRight'
SE_DENY_REMOTE_INTERACTIVE_LOGON_NAME: String = 'SeDenyRemoteInteractiveLogonRight'
NEGOTIATE_MAX_PREFIX: UInt32 = 32
NEGOTIATE_ALLOW_NTLM: UInt32 = 268435456
NEGOTIATE_NEG_NTLM: UInt32 = 536870912
MAX_USER_RECORDS: UInt32 = 1000
Audit_System_SecurityStateChange: Guid = Guid('{0cce9210-69ae-11d9-bed3-505054503030}')
Audit_System_SecuritySubsystemExtension: Guid = Guid('{0cce9211-69ae-11d9-bed3-505054503030}')
Audit_System_Integrity: Guid = Guid('{0cce9212-69ae-11d9-bed3-505054503030}')
Audit_System_IPSecDriverEvents: Guid = Guid('{0cce9213-69ae-11d9-bed3-505054503030}')
Audit_System_Others: Guid = Guid('{0cce9214-69ae-11d9-bed3-505054503030}')
Audit_Logon_Logon: Guid = Guid('{0cce9215-69ae-11d9-bed3-505054503030}')
Audit_Logon_Logoff: Guid = Guid('{0cce9216-69ae-11d9-bed3-505054503030}')
Audit_Logon_AccountLockout: Guid = Guid('{0cce9217-69ae-11d9-bed3-505054503030}')
Audit_Logon_IPSecMainMode: Guid = Guid('{0cce9218-69ae-11d9-bed3-505054503030}')
Audit_Logon_IPSecQuickMode: Guid = Guid('{0cce9219-69ae-11d9-bed3-505054503030}')
Audit_Logon_IPSecUserMode: Guid = Guid('{0cce921a-69ae-11d9-bed3-505054503030}')
Audit_Logon_SpecialLogon: Guid = Guid('{0cce921b-69ae-11d9-bed3-505054503030}')
Audit_Logon_Others: Guid = Guid('{0cce921c-69ae-11d9-bed3-505054503030}')
Audit_ObjectAccess_FileSystem: Guid = Guid('{0cce921d-69ae-11d9-bed3-505054503030}')
Audit_ObjectAccess_Registry: Guid = Guid('{0cce921e-69ae-11d9-bed3-505054503030}')
Audit_ObjectAccess_Kernel: Guid = Guid('{0cce921f-69ae-11d9-bed3-505054503030}')
Audit_ObjectAccess_Sam: Guid = Guid('{0cce9220-69ae-11d9-bed3-505054503030}')
Audit_ObjectAccess_CertificationServices: Guid = Guid('{0cce9221-69ae-11d9-bed3-505054503030}')
Audit_ObjectAccess_ApplicationGenerated: Guid = Guid('{0cce9222-69ae-11d9-bed3-505054503030}')
Audit_ObjectAccess_Handle: Guid = Guid('{0cce9223-69ae-11d9-bed3-505054503030}')
Audit_ObjectAccess_Share: Guid = Guid('{0cce9224-69ae-11d9-bed3-505054503030}')
Audit_ObjectAccess_FirewallPacketDrops: Guid = Guid('{0cce9225-69ae-11d9-bed3-505054503030}')
Audit_ObjectAccess_FirewallConnection: Guid = Guid('{0cce9226-69ae-11d9-bed3-505054503030}')
Audit_ObjectAccess_Other: Guid = Guid('{0cce9227-69ae-11d9-bed3-505054503030}')
Audit_PrivilegeUse_Sensitive: Guid = Guid('{0cce9228-69ae-11d9-bed3-505054503030}')
Audit_PrivilegeUse_NonSensitive: Guid = Guid('{0cce9229-69ae-11d9-bed3-505054503030}')
Audit_PrivilegeUse_Others: Guid = Guid('{0cce922a-69ae-11d9-bed3-505054503030}')
Audit_DetailedTracking_ProcessCreation: Guid = Guid('{0cce922b-69ae-11d9-bed3-505054503030}')
Audit_DetailedTracking_ProcessTermination: Guid = Guid('{0cce922c-69ae-11d9-bed3-505054503030}')
Audit_DetailedTracking_DpapiActivity: Guid = Guid('{0cce922d-69ae-11d9-bed3-505054503030}')
Audit_DetailedTracking_RpcCall: Guid = Guid('{0cce922e-69ae-11d9-bed3-505054503030}')
Audit_PolicyChange_AuditPolicy: Guid = Guid('{0cce922f-69ae-11d9-bed3-505054503030}')
Audit_PolicyChange_AuthenticationPolicy: Guid = Guid('{0cce9230-69ae-11d9-bed3-505054503030}')
Audit_PolicyChange_AuthorizationPolicy: Guid = Guid('{0cce9231-69ae-11d9-bed3-505054503030}')
Audit_PolicyChange_MpsscvRulePolicy: Guid = Guid('{0cce9232-69ae-11d9-bed3-505054503030}')
Audit_PolicyChange_WfpIPSecPolicy: Guid = Guid('{0cce9233-69ae-11d9-bed3-505054503030}')
Audit_PolicyChange_Others: Guid = Guid('{0cce9234-69ae-11d9-bed3-505054503030}')
Audit_AccountManagement_UserAccount: Guid = Guid('{0cce9235-69ae-11d9-bed3-505054503030}')
Audit_AccountManagement_ComputerAccount: Guid = Guid('{0cce9236-69ae-11d9-bed3-505054503030}')
Audit_AccountManagement_SecurityGroup: Guid = Guid('{0cce9237-69ae-11d9-bed3-505054503030}')
Audit_AccountManagement_DistributionGroup: Guid = Guid('{0cce9238-69ae-11d9-bed3-505054503030}')
Audit_AccountManagement_ApplicationGroup: Guid = Guid('{0cce9239-69ae-11d9-bed3-505054503030}')
Audit_AccountManagement_Others: Guid = Guid('{0cce923a-69ae-11d9-bed3-505054503030}')
Audit_DSAccess_DSAccess: Guid = Guid('{0cce923b-69ae-11d9-bed3-505054503030}')
Audit_DsAccess_AdAuditChanges: Guid = Guid('{0cce923c-69ae-11d9-bed3-505054503030}')
Audit_Ds_Replication: Guid = Guid('{0cce923d-69ae-11d9-bed3-505054503030}')
Audit_Ds_DetailedReplication: Guid = Guid('{0cce923e-69ae-11d9-bed3-505054503030}')
Audit_AccountLogon_CredentialValidation: Guid = Guid('{0cce923f-69ae-11d9-bed3-505054503030}')
Audit_AccountLogon_Kerberos: Guid = Guid('{0cce9240-69ae-11d9-bed3-505054503030}')
Audit_AccountLogon_Others: Guid = Guid('{0cce9241-69ae-11d9-bed3-505054503030}')
Audit_AccountLogon_KerbCredentialValidation: Guid = Guid('{0cce9242-69ae-11d9-bed3-505054503030}')
Audit_Logon_NPS: Guid = Guid('{0cce9243-69ae-11d9-bed3-505054503030}')
Audit_ObjectAccess_DetailedFileShare: Guid = Guid('{0cce9244-69ae-11d9-bed3-505054503030}')
Audit_ObjectAccess_RemovableStorage: Guid = Guid('{0cce9245-69ae-11d9-bed3-505054503030}')
Audit_ObjectAccess_CbacStaging: Guid = Guid('{0cce9246-69ae-11d9-bed3-505054503030}')
Audit_Logon_Claims: Guid = Guid('{0cce9247-69ae-11d9-bed3-505054503030}')
Audit_DetailedTracking_PnpActivity: Guid = Guid('{0cce9248-69ae-11d9-bed3-505054503030}')
Audit_Logon_Groups: Guid = Guid('{0cce9249-69ae-11d9-bed3-505054503030}')
Audit_DetailedTracking_TokenRightAdjusted: Guid = Guid('{0cce924a-69ae-11d9-bed3-505054503030}')
Audit_System: Guid = Guid('{69979848-797a-11d9-bed3-505054503030}')
Audit_Logon: Guid = Guid('{69979849-797a-11d9-bed3-505054503030}')
Audit_ObjectAccess: Guid = Guid('{6997984a-797a-11d9-bed3-505054503030}')
Audit_PrivilegeUse: Guid = Guid('{6997984b-797a-11d9-bed3-505054503030}')
Audit_DetailedTracking: Guid = Guid('{6997984c-797a-11d9-bed3-505054503030}')
Audit_PolicyChange: Guid = Guid('{6997984d-797a-11d9-bed3-505054503030}')
Audit_AccountManagement: Guid = Guid('{6997984e-797a-11d9-bed3-505054503030}')
Audit_DirectoryServiceAccess: Guid = Guid('{6997984f-797a-11d9-bed3-505054503030}')
Audit_AccountLogon: Guid = Guid('{69979850-797a-11d9-bed3-505054503030}')
DOMAIN_NO_LM_OWF_CHANGE: Int32 = 64
SAM_PASSWORD_CHANGE_NOTIFY_ROUTINE: String = 'PasswordChangeNotify'
SAM_INIT_NOTIFICATION_ROUTINE: String = 'InitializeChangeNotify'
SAM_PASSWORD_FILTER_ROUTINE: String = 'PasswordFilter'
MSV1_0_PACKAGE_NAME: String = 'MICROSOFT_AUTHENTICATION_PACKAGE_V1_0'
MSV1_0_PACKAGE_NAMEW: String = 'MICROSOFT_AUTHENTICATION_PACKAGE_V1_0'
MSV1_0_SUBAUTHENTICATION_KEY: String = 'SYSTEM\\CurrentControlSet\\Control\\Lsa\\MSV1_0'
MSV1_0_SUBAUTHENTICATION_VALUE: String = 'Auth'
MSV1_0_CHALLENGE_LENGTH: UInt32 = 8
MSV1_0_USER_SESSION_KEY_LENGTH: UInt32 = 16
MSV1_0_LANMAN_SESSION_KEY_LENGTH: UInt32 = 8
MSV1_0_USE_CLIENT_CHALLENGE: UInt32 = 128
MSV1_0_DISABLE_PERSONAL_FALLBACK: UInt32 = 4096
MSV1_0_ALLOW_FORCE_GUEST: UInt32 = 8192
MSV1_0_CLEARTEXT_PASSWORD_SUPPLIED: UInt32 = 16384
MSV1_0_USE_DOMAIN_FOR_ROUTING_ONLY: UInt32 = 32768
MSV1_0_SUBAUTHENTICATION_DLL_EX: UInt32 = 1048576
MSV1_0_ALLOW_MSVCHAPV2: UInt32 = 65536
MSV1_0_S4U2SELF: UInt32 = 131072
MSV1_0_CHECK_LOGONHOURS_FOR_S4U: UInt32 = 262144
MSV1_0_INTERNET_DOMAIN: UInt32 = 524288
MSV1_0_SUBAUTHENTICATION_DLL: UInt32 = 4278190080
MSV1_0_SUBAUTHENTICATION_DLL_SHIFT: UInt32 = 24
MSV1_0_MNS_LOGON: UInt32 = 16777216
MSV1_0_SUBAUTHENTICATION_DLL_RAS: UInt32 = 2
MSV1_0_SUBAUTHENTICATION_DLL_IIS: UInt32 = 132
MSV1_0_S4U_LOGON_FLAG_CHECK_LOGONHOURS: UInt32 = 2
LOGON_NTLMV2_ENABLED: UInt32 = 256
LOGON_NT_V2: UInt32 = 2048
LOGON_LM_V2: UInt32 = 4096
LOGON_NTLM_V2: UInt32 = 8192
LOGON_OPTIMIZED: UInt32 = 16384
LOGON_WINLOGON: UInt32 = 32768
LOGON_PKINIT: UInt32 = 65536
LOGON_NO_OPTIMIZED: UInt32 = 131072
LOGON_NO_ELEVATION: UInt32 = 262144
LOGON_MANAGED_SERVICE: UInt32 = 524288
MSV1_0_SUBAUTHENTICATION_FLAGS: UInt32 = 4278190080
LOGON_GRACE_LOGON: UInt32 = 16777216
MSV1_0_OWF_PASSWORD_LENGTH: UInt32 = 16
MSV1_0_SHA_PASSWORD_LENGTH: UInt32 = 20
MSV1_0_CREDENTIAL_KEY_LENGTH: UInt32 = 20
MSV1_0_CRED_REMOVED: UInt32 = 4
MSV1_0_CRED_CREDKEY_PRESENT: UInt32 = 8
MSV1_0_CRED_SHA_PRESENT: UInt32 = 16
MSV1_0_CRED_VERSION_V2: UInt32 = 2
MSV1_0_CRED_VERSION_V3: UInt32 = 4
MSV1_0_CRED_VERSION_IUM: UInt32 = 4294901761
MSV1_0_CRED_VERSION_REMOTE: UInt32 = 4294901762
MSV1_0_CRED_VERSION_ARSO: UInt32 = 4294901763
MSV1_0_CRED_VERSION_RESERVED_1: UInt32 = 4294967294
MSV1_0_CRED_VERSION_INVALID: UInt32 = 4294967295
MSV1_0_NTLM3_RESPONSE_LENGTH: UInt32 = 16
MSV1_0_NTLM3_OWF_LENGTH: UInt32 = 16
MSV1_0_MAX_NTLM3_LIFE: UInt32 = 1800
MSV1_0_MAX_AVL_SIZE: UInt32 = 64000
MSV1_0_AV_FLAG_FORCE_GUEST: UInt32 = 1
MSV1_0_AV_FLAG_MIC_HANDSHAKE_MESSAGES: UInt32 = 2
MSV1_0_AV_FLAG_UNVERIFIED_TARGET: UInt32 = 4
RTL_ENCRYPT_MEMORY_SIZE: UInt32 = 8
RTL_ENCRYPT_OPTION_CROSS_PROCESS: UInt32 = 1
RTL_ENCRYPT_OPTION_SAME_LOGON: UInt32 = 2
RTL_ENCRYPT_OPTION_FOR_SYSTEM: UInt32 = 4
KERBEROS_VERSION: UInt32 = 5
KERBEROS_REVISION: UInt32 = 6
KERB_ETYPE_AES128_CTS_HMAC_SHA1_96: UInt32 = 17
KERB_ETYPE_AES256_CTS_HMAC_SHA1_96: UInt32 = 18
KERB_ETYPE_RC4_PLAIN2: Int32 = -129
KERB_ETYPE_RC4_LM: Int32 = -130
KERB_ETYPE_RC4_SHA: Int32 = -131
KERB_ETYPE_DES_PLAIN: Int32 = -132
KERB_ETYPE_RC4_HMAC_OLD: Int32 = -133
KERB_ETYPE_RC4_PLAIN_OLD: Int32 = -134
KERB_ETYPE_RC4_HMAC_OLD_EXP: Int32 = -135
KERB_ETYPE_RC4_PLAIN_OLD_EXP: Int32 = -136
KERB_ETYPE_RC4_PLAIN: Int32 = -140
KERB_ETYPE_RC4_PLAIN_EXP: Int32 = -141
KERB_ETYPE_AES128_CTS_HMAC_SHA1_96_PLAIN: Int32 = -148
KERB_ETYPE_AES256_CTS_HMAC_SHA1_96_PLAIN: Int32 = -149
KERB_ETYPE_DSA_SHA1_CMS: UInt32 = 9
KERB_ETYPE_RSA_MD5_CMS: UInt32 = 10
KERB_ETYPE_RSA_SHA1_CMS: UInt32 = 11
KERB_ETYPE_RC2_CBC_ENV: UInt32 = 12
KERB_ETYPE_RSA_ENV: UInt32 = 13
KERB_ETYPE_RSA_ES_OEAP_ENV: UInt32 = 14
KERB_ETYPE_DES_EDE3_CBC_ENV: UInt32 = 15
KERB_ETYPE_DSA_SIGN: UInt32 = 8
KERB_ETYPE_RSA_PRIV: UInt32 = 9
KERB_ETYPE_RSA_PUB: UInt32 = 10
KERB_ETYPE_RSA_PUB_MD5: UInt32 = 11
KERB_ETYPE_RSA_PUB_SHA1: UInt32 = 12
KERB_ETYPE_PKCS7_PUB: UInt32 = 13
KERB_ETYPE_DES3_CBC_MD5: UInt32 = 5
KERB_ETYPE_DES3_CBC_SHA1: UInt32 = 7
KERB_ETYPE_DES3_CBC_SHA1_KD: UInt32 = 16
KERB_ETYPE_DES_CBC_MD5_NT: UInt32 = 20
KERB_ETYPE_RC4_HMAC_NT_EXP: UInt32 = 24
KERB_CHECKSUM_NONE: UInt32 = 0
KERB_CHECKSUM_CRC32: UInt32 = 1
KERB_CHECKSUM_MD4: UInt32 = 2
KERB_CHECKSUM_KRB_DES_MAC: UInt32 = 4
KERB_CHECKSUM_KRB_DES_MAC_K: UInt32 = 5
KERB_CHECKSUM_MD5: UInt32 = 7
KERB_CHECKSUM_MD5_DES: UInt32 = 8
KERB_CHECKSUM_SHA1_NEW: UInt32 = 14
KERB_CHECKSUM_HMAC_SHA1_96_AES128: UInt32 = 15
KERB_CHECKSUM_HMAC_SHA1_96_AES256: UInt32 = 16
KERB_CHECKSUM_LM: Int32 = -130
KERB_CHECKSUM_SHA1: Int32 = -131
KERB_CHECKSUM_REAL_CRC32: Int32 = -132
KERB_CHECKSUM_DES_MAC: Int32 = -133
KERB_CHECKSUM_DES_MAC_MD5: Int32 = -134
KERB_CHECKSUM_MD25: Int32 = -135
KERB_CHECKSUM_RC4_MD5: Int32 = -136
KERB_CHECKSUM_MD5_HMAC: Int32 = -137
KERB_CHECKSUM_HMAC_MD5: Int32 = -138
KERB_CHECKSUM_SHA256: Int32 = -139
KERB_CHECKSUM_SHA384: Int32 = -140
KERB_CHECKSUM_SHA512: Int32 = -141
KERB_CHECKSUM_HMAC_SHA1_96_AES128_Ki: Int32 = -150
KERB_CHECKSUM_HMAC_SHA1_96_AES256_Ki: Int32 = -151
AUTH_REQ_ALLOW_FORWARDABLE: UInt32 = 1
AUTH_REQ_ALLOW_PROXIABLE: UInt32 = 2
AUTH_REQ_ALLOW_POSTDATE: UInt32 = 4
AUTH_REQ_ALLOW_RENEWABLE: UInt32 = 8
AUTH_REQ_ALLOW_NOADDRESS: UInt32 = 16
AUTH_REQ_ALLOW_ENC_TKT_IN_SKEY: UInt32 = 32
AUTH_REQ_ALLOW_VALIDATE: UInt32 = 64
AUTH_REQ_VALIDATE_CLIENT: UInt32 = 128
AUTH_REQ_OK_AS_DELEGATE: UInt32 = 256
AUTH_REQ_PREAUTH_REQUIRED: UInt32 = 512
AUTH_REQ_TRANSITIVE_TRUST: UInt32 = 1024
AUTH_REQ_ALLOW_S4U_DELEGATE: UInt32 = 2048
KERB_TICKET_FLAGS_name_canonicalize: UInt32 = 65536
KERB_TICKET_FLAGS_cname_in_pa_data: UInt32 = 262144
KERB_TICKET_FLAGS_enc_pa_rep: UInt32 = 65536
KRB_NT_UNKNOWN: UInt32 = 0
KRB_NT_PRINCIPAL: UInt32 = 1
KRB_NT_PRINCIPAL_AND_ID: Int32 = -131
KRB_NT_SRV_INST: UInt32 = 2
KRB_NT_SRV_INST_AND_ID: Int32 = -132
KRB_NT_SRV_HST: UInt32 = 3
KRB_NT_SRV_XHST: UInt32 = 4
KRB_NT_UID: UInt32 = 5
KRB_NT_ENTERPRISE_PRINCIPAL: UInt32 = 10
KRB_NT_WELLKNOWN: UInt32 = 11
KRB_NT_ENT_PRINCIPAL_AND_ID: Int32 = -130
KRB_NT_MS_PRINCIPAL: Int32 = -128
KRB_NT_MS_PRINCIPAL_AND_ID: Int32 = -129
KRB_NT_MS_BRANCH_ID: Int32 = -133
KRB_NT_X500_PRINCIPAL: UInt32 = 6
KRB_WELLKNOWN_STRING: String = 'WELLKNOWN'
KRB_ANONYMOUS_STRING: String = 'ANONYMOUS'
KERB_WRAP_NO_ENCRYPT: UInt32 = 2147483649
KERB_CERTIFICATE_LOGON_FLAG_CHECK_DUPLICATES: UInt32 = 1
KERB_CERTIFICATE_LOGON_FLAG_USE_CERTIFICATE_INFO: UInt32 = 2
KERB_CERTIFICATE_S4U_LOGON_FLAG_CHECK_DUPLICATES: UInt32 = 1
KERB_CERTIFICATE_S4U_LOGON_FLAG_CHECK_LOGONHOURS: UInt32 = 2
KERB_CERTIFICATE_S4U_LOGON_FLAG_FAIL_IF_NT_AUTH_POLICY_REQUIRED: UInt32 = 4
KERB_CERTIFICATE_S4U_LOGON_FLAG_IDENTIFY: UInt32 = 8
KERB_LOGON_FLAG_ALLOW_EXPIRED_TICKET: UInt32 = 1
KERB_LOGON_FLAG_REDIRECTED: UInt32 = 2
KERB_S4U_LOGON_FLAG_CHECK_LOGONHOURS: UInt32 = 2
KERB_S4U_LOGON_FLAG_IDENTIFY: UInt32 = 8
KERB_USE_DEFAULT_TICKET_FLAGS: UInt32 = 0
KERB_RETRIEVE_TICKET_DEFAULT: UInt32 = 0
KERB_RETRIEVE_TICKET_DONT_USE_CACHE: UInt32 = 1
KERB_RETRIEVE_TICKET_USE_CACHE_ONLY: UInt32 = 2
KERB_RETRIEVE_TICKET_USE_CREDHANDLE: UInt32 = 4
KERB_RETRIEVE_TICKET_AS_KERB_CRED: UInt32 = 8
KERB_RETRIEVE_TICKET_WITH_SEC_CRED: UInt32 = 16
KERB_RETRIEVE_TICKET_CACHE_TICKET: UInt32 = 32
KERB_RETRIEVE_TICKET_MAX_LIFETIME: UInt32 = 64
KERB_ETYPE_DEFAULT: UInt32 = 0
KERB_PURGE_ALL_TICKETS: UInt32 = 1
KERB_S4U2PROXY_CACHE_ENTRY_INFO_FLAG_NEGATIVE: UInt32 = 1
KERB_S4U2PROXY_CRED_FLAG_NEGATIVE: UInt32 = 1
KERB_REFRESH_POLICY_KERBEROS: UInt32 = 1
KERB_REFRESH_POLICY_KDC: UInt32 = 2
KERB_CLOUD_KERBEROS_DEBUG_DATA_VERSION: UInt32 = 1
DS_UNKNOWN_ADDRESS_TYPE: UInt32 = 0
KERB_SETPASS_USE_LOGONID: UInt32 = 1
KERB_SETPASS_USE_CREDHANDLE: UInt32 = 2
KERB_DECRYPT_FLAG_DEFAULT_KEY: UInt32 = 1
KERB_REFRESH_SCCRED_RELEASE: UInt32 = 0
KERB_REFRESH_SCCRED_GETTGT: UInt32 = 1
KERB_TRANSFER_CRED_WITH_TICKETS: UInt32 = 1
KERB_TRANSFER_CRED_CLEANUP_CREDENTIALS: UInt32 = 2
KERB_QUERY_DOMAIN_EXTENDED_POLICIES_RESPONSE_FLAG_DAC_DISABLED: UInt32 = 1
AUDIT_SET_SYSTEM_POLICY: UInt32 = 1
AUDIT_QUERY_SYSTEM_POLICY: UInt32 = 2
AUDIT_SET_USER_POLICY: UInt32 = 4
AUDIT_QUERY_USER_POLICY: UInt32 = 8
AUDIT_ENUMERATE_USERS: UInt32 = 16
AUDIT_SET_MISC_POLICY: UInt32 = 32
AUDIT_QUERY_MISC_POLICY: UInt32 = 64
PKU2U_PACKAGE_NAME_A: String = 'pku2u'
PKU2U_PACKAGE_NAME: String = 'pku2u'
PKU2U_PACKAGE_NAME_W: String = 'pku2u'
SAM_CREDENTIAL_UPDATE_NOTIFY_ROUTINE: String = 'CredentialUpdateNotify'
SAM_CREDENTIAL_UPDATE_REGISTER_ROUTINE: String = 'CredentialUpdateRegister'
SAM_CREDENTIAL_UPDATE_FREE_ROUTINE: String = 'CredentialUpdateFree'
SAM_CREDENTIAL_UPDATE_REGISTER_MAPPED_ENTRYPOINTS_ROUTINE: String = 'RegisterMappedEntrypoints'
SECPKG_CLIENT_PROCESS_TERMINATED: UInt32 = 1
SECPKG_CLIENT_THREAD_TERMINATED: UInt32 = 2
SECPKG_CALL_KERNEL_MODE: UInt32 = 1
SECPKG_CALL_ANSI: UInt32 = 2
SECPKG_CALL_URGENT: UInt32 = 4
SECPKG_CALL_RECURSIVE: UInt32 = 8
SECPKG_CALL_IN_PROC: UInt32 = 16
SECPKG_CALL_CLEANUP: UInt32 = 32
SECPKG_CALL_WOWCLIENT: UInt32 = 64
SECPKG_CALL_THREAD_TERM: UInt32 = 128
SECPKG_CALL_PROCESS_TERM: UInt32 = 256
SECPKG_CALL_IS_TCB: UInt32 = 512
SECPKG_CALL_NETWORK_ONLY: UInt32 = 1024
SECPKG_CALL_WINLOGON: UInt32 = 2048
SECPKG_CALL_ASYNC_UPDATE: UInt32 = 4096
SECPKG_CALL_SYSTEM_PROC: UInt32 = 8192
SECPKG_CALL_NEGO: UInt32 = 16384
SECPKG_CALL_NEGO_EXTENDER: UInt32 = 32768
SECPKG_CALL_BUFFER_MARSHAL: UInt32 = 65536
SECPKG_CALL_UNLOCK: UInt32 = 131072
SECPKG_CALL_CLOUDAP_CONNECT: UInt32 = 262144
SECPKG_CALL_WOWX86: UInt32 = 64
SECPKG_CALL_WOWA32: UInt32 = 262144
SECPKG_CREDENTIAL_VERSION: UInt32 = 201
SECPKG_CREDENTIAL_FLAGS_CALLER_HAS_TCB: UInt32 = 1
SECPKG_CREDENTIAL_FLAGS_CREDMAN_CRED: UInt32 = 2
SECPKG_SURROGATE_LOGON_VERSION_1: UInt32 = 1
SECBUFFER_UNMAPPED: UInt32 = 1073741824
SECBUFFER_KERNEL_MAP: UInt32 = 536870912
PRIMARY_CRED_CLEAR_PASSWORD: UInt32 = 1
PRIMARY_CRED_OWF_PASSWORD: UInt32 = 2
PRIMARY_CRED_UPDATE: UInt32 = 4
PRIMARY_CRED_CACHED_LOGON: UInt32 = 8
PRIMARY_CRED_LOGON_NO_TCB: UInt32 = 16
PRIMARY_CRED_LOGON_LUA: UInt32 = 32
PRIMARY_CRED_INTERACTIVE_SMARTCARD_LOGON: UInt32 = 64
PRIMARY_CRED_REFRESH_NEEDED: UInt32 = 128
PRIMARY_CRED_INTERNET_USER: UInt32 = 256
PRIMARY_CRED_AUTH_ID: UInt32 = 512
PRIMARY_CRED_DO_NOT_SPLIT: UInt32 = 1024
PRIMARY_CRED_PROTECTED_USER: UInt32 = 2048
PRIMARY_CRED_EX: UInt32 = 4096
PRIMARY_CRED_TRANSFER: UInt32 = 8192
PRIMARY_CRED_RESTRICTED_TS: UInt32 = 16384
PRIMARY_CRED_PACKED_CREDS: UInt32 = 32768
PRIMARY_CRED_ENTERPRISE_INTERNET_USER: UInt32 = 65536
PRIMARY_CRED_ENCRYPTED_CREDGUARD_PASSWORD: UInt32 = 131072
PRIMARY_CRED_CACHED_INTERACTIVE_LOGON: UInt32 = 262144
PRIMARY_CRED_INTERACTIVE_NGC_LOGON: UInt32 = 524288
PRIMARY_CRED_INTERACTIVE_FIDO_LOGON: UInt32 = 1048576
PRIMARY_CRED_ARSO_LOGON: UInt32 = 2097152
PRIMARY_CRED_SUPPLEMENTAL: UInt32 = 4194304
PRIMARY_CRED_FOR_PASSWORD_CHANGE: UInt32 = 8388608
PRIMARY_CRED_LOGON_PACKAGE_SHIFT: UInt32 = 24
PRIMARY_CRED_PACKAGE_MASK: UInt32 = 4278190080
SECPKG_PRIMARY_CRED_EX_FLAGS_EX_DELEGATION_TOKEN: UInt32 = 1
MAX_CRED_SIZE: UInt32 = 1024
SECPKG_STATE_ENCRYPTION_PERMITTED: UInt32 = 1
SECPKG_STATE_STRONG_ENCRYPTION_PERMITTED: UInt32 = 2
SECPKG_STATE_DOMAIN_CONTROLLER: UInt32 = 4
SECPKG_STATE_WORKSTATION: UInt32 = 8
SECPKG_STATE_STANDALONE: UInt32 = 16
SECPKG_STATE_CRED_ISOLATION_ENABLED: UInt32 = 32
SECPKG_STATE_RESERVED_1: UInt32 = 2147483648
SECPKG_MAX_OID_LENGTH: UInt32 = 32
SECPKG_MSVAV_FLAGS_VALID: UInt32 = 1
SECPKG_MSVAV_TIMESTAMP_VALID: UInt32 = 2
SECPKG_ATTR_SASL_CONTEXT: UInt32 = 65536
SECPKG_ATTR_THUNK_ALL: UInt32 = 65536
UNDERSTANDS_LONG_NAMES: UInt32 = 1
NO_LONG_NAMES: UInt32 = 2
SECPKG_CALL_PACKAGE_TRANSFER_CRED_REQUEST_FLAG_OPTIMISTIC_LOGON: UInt32 = 1
SECPKG_CALL_PACKAGE_TRANSFER_CRED_REQUEST_FLAG_CLEANUP_CREDENTIALS: UInt32 = 2
SECPKG_CALL_PACKAGE_TRANSFER_CRED_REQUEST_FLAG_TO_SSO_SESSION: UInt32 = 4
SECPKG_REDIRECTED_LOGON_GUID_INITIALIZER: Guid = Guid('{c2be5457-82eb-483e-ae4e-7468ef14d509}')
NOTIFIER_FLAG_NEW_THREAD: UInt32 = 1
NOTIFIER_FLAG_ONE_SHOT: UInt32 = 2
NOTIFIER_FLAG_SECONDS: UInt32 = 2147483648
NOTIFIER_TYPE_INTERVAL: UInt32 = 1
NOTIFIER_TYPE_HANDLE_WAIT: UInt32 = 2
NOTIFIER_TYPE_STATE_CHANGE: UInt32 = 3
NOTIFIER_TYPE_NOTIFY_EVENT: UInt32 = 4
NOTIFIER_TYPE_IMMEDIATE: UInt32 = 16
NOTIFY_CLASS_PACKAGE_CHANGE: UInt32 = 1
NOTIFY_CLASS_ROLE_CHANGE: UInt32 = 2
NOTIFY_CLASS_DOMAIN_CHANGE: UInt32 = 3
NOTIFY_CLASS_REGISTRY_CHANGE: UInt32 = 4
LSA_QUERY_CLIENT_PRELOGON_SESSION_ID: UInt32 = 1
CREDP_FLAGS_IN_PROCESS: UInt32 = 1
CREDP_FLAGS_USE_MIDL_HEAP: UInt32 = 2
CREDP_FLAGS_DONT_CACHE_TI: UInt32 = 4
CREDP_FLAGS_CLEAR_PASSWORD: UInt32 = 8
CREDP_FLAGS_USER_ENCRYPTED_PASSWORD: UInt32 = 16
CREDP_FLAGS_TRUSTED_CALLER: UInt32 = 32
CREDP_FLAGS_VALIDATE_PROXY_TARGET: UInt32 = 64
CRED_MARSHALED_TI_SIZE_SIZE: UInt32 = 12
LSA_AP_NAME_LOGON_USER_EX2: String = 'LsaApLogonUserEx2\x00'
SP_ACCEPT_CREDENTIALS_NAME: String = 'SpAcceptCredentials\x00'
SECPKG_UNICODE_ATTRIBUTE: UInt32 = 2147483648
SECPKG_ANSI_ATTRIBUTE: UInt32 = 0
SECPKG_CREDENTIAL_ATTRIBUTE: UInt32 = 0
SECPKG_LSAMODEINIT_NAME: String = 'SpLsaModeInitialize'
SECPKG_USERMODEINIT_NAME: String = 'SpUserModeInitialize'
SECPKG_INTERFACE_VERSION: UInt32 = 65536
SECPKG_INTERFACE_VERSION_2: UInt32 = 131072
SECPKG_INTERFACE_VERSION_3: UInt32 = 262144
SECPKG_INTERFACE_VERSION_4: UInt32 = 524288
SECPKG_INTERFACE_VERSION_5: UInt32 = 1048576
SECPKG_INTERFACE_VERSION_6: UInt32 = 2097152
SECPKG_INTERFACE_VERSION_7: UInt32 = 4194304
SECPKG_INTERFACE_VERSION_8: UInt32 = 8388608
SECPKG_INTERFACE_VERSION_9: UInt32 = 16777216
SECPKG_INTERFACE_VERSION_10: UInt32 = 33554432
SECPKG_INTERFACE_VERSION_11: UInt32 = 67108864
UNISP_NAME_A: String = 'Microsoft Unified Security Protocol Provider'
UNISP_NAME_W: String = 'Microsoft Unified Security Protocol Provider'
SSL2SP_NAME_A: String = 'Microsoft SSL 2.0'
SSL2SP_NAME_W: String = 'Microsoft SSL 2.0'
SSL3SP_NAME_A: String = 'Microsoft SSL 3.0'
SSL3SP_NAME_W: String = 'Microsoft SSL 3.0'
TLS1SP_NAME_A: String = 'Microsoft TLS 1.0'
TLS1SP_NAME_W: String = 'Microsoft TLS 1.0'
PCT1SP_NAME_A: String = 'Microsoft PCT 1.0'
PCT1SP_NAME_W: String = 'Microsoft PCT 1.0'
SCHANNEL_NAME_A: String = 'Schannel'
SCHANNEL_NAME_W: String = 'Schannel'
DEFAULT_TLS_SSP_NAME_A: String = 'Default TLS SSP'
DEFAULT_TLS_SSP_NAME_W: String = 'Default TLS SSP'
UNISP_NAME: String = 'Microsoft Unified Security Protocol Provider'
PCT1SP_NAME: String = 'Microsoft PCT 1.0'
SSL2SP_NAME: String = 'Microsoft SSL 2.0'
SSL3SP_NAME: String = 'Microsoft SSL 3.0'
TLS1SP_NAME: String = 'Microsoft TLS 1.0'
SCHANNEL_NAME: String = 'Schannel'
DEFAULT_TLS_SSP_NAME: String = 'Default TLS SSP'
UNISP_RPC_ID: UInt32 = 14
RCRED_STATUS_NOCRED: UInt32 = 0
RCRED_CRED_EXISTS: UInt32 = 1
RCRED_STATUS_UNKNOWN_ISSUER: UInt32 = 2
LCRED_STATUS_NOCRED: UInt32 = 0
LCRED_CRED_EXISTS: UInt32 = 1
LCRED_STATUS_UNKNOWN_ISSUER: UInt32 = 2
SECPKGCONTEXT_CONNECTION_INFO_EX_V1: UInt32 = 1
SECPKGCONTEXT_CIPHERINFO_V1: UInt32 = 1
SSL_SESSION_RECONNECT: UInt32 = 1
KERN_CONTEXT_CERT_INFO_V1: UInt32 = 0
ENABLE_TLS_CLIENT_EARLY_START: UInt32 = 1
SCH_CRED_V1: UInt32 = 1
SCH_CRED_V2: UInt32 = 2
SCH_CRED_VERSION: UInt32 = 2
SCH_CRED_V3: UInt32 = 3
SCHANNEL_CRED_VERSION: UInt32 = 4
SCH_CREDENTIALS_VERSION: UInt32 = 5
TLS_PARAMS_OPTIONAL: UInt32 = 1
SCH_CRED_MAX_SUPPORTED_PARAMETERS: UInt32 = 16
SCH_CRED_MAX_SUPPORTED_ALPN_IDS: UInt32 = 16
SCH_CRED_MAX_SUPPORTED_CRYPTO_SETTINGS: UInt32 = 16
SCH_CRED_MAX_SUPPORTED_CHAINING_MODES: UInt32 = 16
SCH_MAX_EXT_SUBSCRIPTIONS: UInt32 = 2
SCH_CRED_FORMAT_CERT_CONTEXT: UInt32 = 0
SCH_CRED_FORMAT_CERT_HASH: UInt32 = 1
SCH_CRED_FORMAT_CERT_HASH_STORE: UInt32 = 2
SCH_CRED_MAX_STORE_NAME_SIZE: UInt32 = 128
SCH_CRED_MAX_SUPPORTED_ALGS: UInt32 = 256
SCH_CRED_MAX_SUPPORTED_CERTS: UInt32 = 100
SCH_MACHINE_CERT_HASH: UInt32 = 1
SCH_CRED_DISABLE_RECONNECTS: UInt32 = 128
SCH_CRED_RESTRICTED_ROOTS: UInt32 = 8192
SCH_CRED_REVOCATION_CHECK_CACHE_ONLY: UInt32 = 16384
SCH_CRED_CACHE_ONLY_URL_RETRIEVAL: UInt32 = 32768
SCH_CRED_MEMORY_STORE_CERT: UInt32 = 65536
SCH_CRED_SNI_CREDENTIAL: UInt32 = 524288
SCH_CRED_SNI_ENABLE_OCSP: UInt32 = 1048576
SCH_USE_DTLS_ONLY: UInt32 = 16777216
SCH_ALLOW_NULL_ENCRYPTION: UInt32 = 33554432
SCH_CRED_DEFERRED_CRED_VALIDATION: UInt32 = 67108864
SCHANNEL_RENEGOTIATE: UInt32 = 0
SCHANNEL_SHUTDOWN: UInt32 = 1
SCHANNEL_ALERT: UInt32 = 2
SCHANNEL_SESSION: UInt32 = 3
TLS1_ALERT_CLOSE_NOTIFY: UInt32 = 0
TLS1_ALERT_UNEXPECTED_MESSAGE: UInt32 = 10
TLS1_ALERT_BAD_RECORD_MAC: UInt32 = 20
TLS1_ALERT_DECRYPTION_FAILED: UInt32 = 21
TLS1_ALERT_RECORD_OVERFLOW: UInt32 = 22
TLS1_ALERT_DECOMPRESSION_FAIL: UInt32 = 30
TLS1_ALERT_HANDSHAKE_FAILURE: UInt32 = 40
TLS1_ALERT_BAD_CERTIFICATE: UInt32 = 42
TLS1_ALERT_UNSUPPORTED_CERT: UInt32 = 43
TLS1_ALERT_CERTIFICATE_REVOKED: UInt32 = 44
TLS1_ALERT_CERTIFICATE_EXPIRED: UInt32 = 45
TLS1_ALERT_CERTIFICATE_UNKNOWN: UInt32 = 46
TLS1_ALERT_ILLEGAL_PARAMETER: UInt32 = 47
TLS1_ALERT_UNKNOWN_CA: UInt32 = 48
TLS1_ALERT_ACCESS_DENIED: UInt32 = 49
TLS1_ALERT_DECODE_ERROR: UInt32 = 50
TLS1_ALERT_DECRYPT_ERROR: UInt32 = 51
TLS1_ALERT_EXPORT_RESTRICTION: UInt32 = 60
TLS1_ALERT_PROTOCOL_VERSION: UInt32 = 70
TLS1_ALERT_INSUFFIENT_SECURITY: UInt32 = 71
TLS1_ALERT_INTERNAL_ERROR: UInt32 = 80
TLS1_ALERT_USER_CANCELED: UInt32 = 90
TLS1_ALERT_NO_RENEGOTIATION: UInt32 = 100
TLS1_ALERT_UNSUPPORTED_EXT: UInt32 = 110
TLS1_ALERT_UNKNOWN_PSK_IDENTITY: UInt32 = 115
TLS1_ALERT_NO_APP_PROTOCOL: UInt32 = 120
SP_PROT_PCT1_SERVER: UInt32 = 1
SP_PROT_PCT1_CLIENT: UInt32 = 2
SP_PROT_SSL2_SERVER: UInt32 = 4
SP_PROT_SSL2_CLIENT: UInt32 = 8
SP_PROT_SSL3_SERVER: UInt32 = 16
SP_PROT_SSL3_CLIENT: UInt32 = 32
SP_PROT_TLS1_SERVER: UInt32 = 64
SP_PROT_TLS1_CLIENT: UInt32 = 128
SP_PROT_UNI_SERVER: UInt32 = 1073741824
SP_PROT_UNI_CLIENT: UInt32 = 2147483648
SP_PROT_ALL: UInt32 = 4294967295
SP_PROT_NONE: UInt32 = 0
SP_PROT_TLS1_0_SERVER: UInt32 = 64
SP_PROT_TLS1_0_CLIENT: UInt32 = 128
SP_PROT_TLS1_1_SERVER: UInt32 = 256
SP_PROT_TLS1_1_CLIENT: UInt32 = 512
SP_PROT_TLS1_2_SERVER: UInt32 = 1024
SP_PROT_TLS1_2_CLIENT: UInt32 = 2048
SP_PROT_TLS1_3_SERVER: UInt32 = 4096
SP_PROT_TLS1_3_CLIENT: UInt32 = 8192
SP_PROT_DTLS_SERVER: UInt32 = 65536
SP_PROT_DTLS_CLIENT: UInt32 = 131072
SP_PROT_DTLS1_0_SERVER: UInt32 = 65536
SP_PROT_DTLS1_0_CLIENT: UInt32 = 131072
SP_PROT_DTLS1_2_SERVER: UInt32 = 262144
SP_PROT_DTLS1_2_CLIENT: UInt32 = 524288
SP_PROT_TLS1_3PLUS_SERVER: UInt32 = 4096
SP_PROT_TLS1_3PLUS_CLIENT: UInt32 = 8192
SCHANNEL_SECRET_TYPE_CAPI: UInt32 = 1
SCHANNEL_SECRET_PRIVKEY: UInt32 = 2
SCH_CRED_X509_CERTCHAIN: UInt32 = 1
SCH_CRED_X509_CAPI: UInt32 = 2
SCH_CRED_CERT_CONTEXT: UInt32 = 3
SSL_CRACK_CERTIFICATE_NAME: String = 'SslCrackCertificate'
SSL_FREE_CERTIFICATE_NAME: String = 'SslFreeCertificate'
SL_INFO_KEY_CHANNEL: String = 'Channel'
SL_INFO_KEY_NAME: String = 'Name'
SL_INFO_KEY_AUTHOR: String = 'Author'
SL_INFO_KEY_DESCRIPTION: String = 'Description'
SL_INFO_KEY_LICENSOR_URL: String = 'LicensorUrl'
SL_INFO_KEY_DIGITAL_PID: String = 'DigitalPID'
SL_INFO_KEY_DIGITAL_PID2: String = 'DigitalPID2'
SL_INFO_KEY_PARTIAL_PRODUCT_KEY: String = 'PartialProductKey'
SL_INFO_KEY_PRODUCT_SKU_ID: String = 'ProductSkuId'
SL_INFO_KEY_LICENSE_TYPE: String = 'LicenseType'
SL_INFO_KEY_VERSION: String = 'Version'
SL_INFO_KEY_SYSTEM_STATE: String = 'SystemState'
SL_INFO_KEY_ACTIVE_PLUGINS: String = 'ActivePlugins'
SL_INFO_KEY_SECURE_STORE_ID: String = 'SecureStoreId'
SL_INFO_KEY_BIOS_PKEY: String = 'BiosProductKey'
SL_INFO_KEY_BIOS_SLIC_STATE: String = 'BiosSlicState'
SL_INFO_KEY_BIOS_OA2_MINOR_VERSION: String = 'BiosOA2MinorVersion'
SL_INFO_KEY_BIOS_PKEY_DESCRIPTION: String = 'BiosProductKeyDescription'
SL_INFO_KEY_BIOS_PKEY_PKPN: String = 'BiosProductKeyPkPn'
SL_INFO_KEY_SECURE_PROCESSOR_ACTIVATION_URL: String = 'SPCURL'
SL_INFO_KEY_RIGHT_ACCOUNT_ACTIVATION_URL: String = 'RACURL'
SL_INFO_KEY_PRODUCT_KEY_ACTIVATION_URL: String = 'PKCURL'
SL_INFO_KEY_USE_LICENSE_ACTIVATION_URL: String = 'EULURL'
SL_INFO_KEY_IS_KMS: String = 'IsKeyManagementService'
SL_INFO_KEY_KMS_CURRENT_COUNT: String = 'KeyManagementServiceCurrentCount'
SL_INFO_KEY_KMS_REQUIRED_CLIENT_COUNT: String = 'KeyManagementServiceRequiredClientCount'
SL_INFO_KEY_KMS_UNLICENSED_REQUESTS: String = 'KeyManagementServiceUnlicensedRequests'
SL_INFO_KEY_KMS_LICENSED_REQUESTS: String = 'KeyManagementServiceLicensedRequests'
SL_INFO_KEY_KMS_OOB_GRACE_REQUESTS: String = 'KeyManagementServiceOOBGraceRequests'
SL_INFO_KEY_KMS_OOT_GRACE_REQUESTS: String = 'KeyManagementServiceOOTGraceRequests'
SL_INFO_KEY_KMS_NON_GENUINE_GRACE_REQUESTS: String = 'KeyManagementServiceNonGenuineGraceRequests'
SL_INFO_KEY_KMS_NOTIFICATION_REQUESTS: String = 'KeyManagementServiceNotificationRequests'
SL_INFO_KEY_KMS_TOTAL_REQUESTS: String = 'KeyManagementServiceTotalRequests'
SL_INFO_KEY_KMS_FAILED_REQUESTS: String = 'KeyManagementServiceFailedRequests'
SL_INFO_KEY_IS_PRS: String = 'IsPRS'
SL_PKEY_MS2005: String = 'msft:rm/algorithm/pkey/2005'
SL_PKEY_MS2009: String = 'msft:rm/algorithm/pkey/2009'
SL_PKEY_DETECT: String = 'msft:rm/algorithm/pkey/detect'
SL_EVENT_LICENSING_STATE_CHANGED: String = 'msft:rm/event/licensingstatechanged'
SL_EVENT_POLICY_CHANGED: String = 'msft:rm/event/policychanged'
SL_EVENT_USER_NOTIFICATION: String = 'msft:rm/event/usernotification'
SL_SYSTEM_STATE_REBOOT_POLICY_FOUND: UInt32 = 1
SL_SYSTEM_STATE_TAMPERED: UInt32 = 2
SL_REARM_REBOOT_REQUIRED: UInt32 = 1
SPP_MIGRATION_GATHER_MIGRATABLE_APPS: UInt32 = 1
SPP_MIGRATION_GATHER_ACTIVATED_WINDOWS_STATE: UInt32 = 2
SPP_MIGRATION_GATHER_ALL: UInt32 = 4294967295
SL_PROP_BRT_DATA: String = 'SL_BRT_DATA'
SL_PROP_BRT_COMMIT: String = 'SL_BRT_COMMIT'
SL_PROP_GENUINE_RESULT: String = 'SL_GENUINE_RESULT'
SL_PROP_NONGENUINE_GRACE_FLAG: String = 'SL_NONGENUINE_GRACE_FLAG'
SL_PROP_GET_GENUINE_AUTHZ: String = 'SL_GET_GENUINE_AUTHZ'
SL_PROP_GET_GENUINE_SERVER_AUTHZ: String = 'SL_GET_GENUINE_SERVER_AUTHZ'
SL_PROP_LAST_ACT_ATTEMPT_HRESULT: String = 'SL_LAST_ACT_ATTEMPT_HRESULT'
SL_PROP_LAST_ACT_ATTEMPT_TIME: String = 'SL_LAST_ACT_ATTEMPT_TIME'
SL_PROP_LAST_ACT_ATTEMPT_SERVER_FLAGS: String = 'SL_LAST_ACT_ATTEMPT_SERVER_FLAGS'
SL_PROP_ACTIVATION_VALIDATION_IN_PROGRESS: String = 'SL_ACTIVATION_VALIDATION_IN_PROGRESS'
SL_POLICY_EVALUATION_MODE_ENABLED: String = 'Security-SPP-EvaluationModeEnabled'
SL_DEFAULT_MIGRATION_ENCRYPTOR_URI: String = 'msft:spp/migrationencryptor/tokenact/1.0'
ID_CAP_SLAPI: String = 'slapiQueryLicenseValue'
USER_ACCOUNT_DISABLED: UInt32 = 1
USER_HOME_DIRECTORY_REQUIRED: UInt32 = 2
USER_PASSWORD_NOT_REQUIRED: UInt32 = 4
USER_TEMP_DUPLICATE_ACCOUNT: UInt32 = 8
USER_NORMAL_ACCOUNT: UInt32 = 16
USER_MNS_LOGON_ACCOUNT: UInt32 = 32
USER_INTERDOMAIN_TRUST_ACCOUNT: UInt32 = 64
USER_WORKSTATION_TRUST_ACCOUNT: UInt32 = 128
USER_SERVER_TRUST_ACCOUNT: UInt32 = 256
USER_DONT_EXPIRE_PASSWORD: UInt32 = 512
USER_ACCOUNT_AUTO_LOCKED: UInt32 = 1024
USER_ENCRYPTED_TEXT_PASSWORD_ALLOWED: UInt32 = 2048
USER_SMARTCARD_REQUIRED: UInt32 = 4096
USER_TRUSTED_FOR_DELEGATION: UInt32 = 8192
USER_NOT_DELEGATED: UInt32 = 16384
USER_USE_DES_KEY_ONLY: UInt32 = 32768
USER_DONT_REQUIRE_PREAUTH: UInt32 = 65536
USER_PASSWORD_EXPIRED: UInt32 = 131072
USER_TRUSTED_TO_AUTHENTICATE_FOR_DELEGATION: UInt32 = 262144
USER_NO_AUTH_DATA_REQUIRED: UInt32 = 524288
USER_PARTIAL_SECRETS_ACCOUNT: UInt32 = 1048576
USER_USE_AES_KEYS: UInt32 = 2097152
SAM_DAYS_PER_WEEK: UInt32 = 7
USER_ALL_PARAMETERS: UInt32 = 2097152
CLEAR_BLOCK_LENGTH: UInt32 = 8
CYPHER_BLOCK_LENGTH: UInt32 = 8
MSV1_0_VALIDATION_LOGOFF_TIME: UInt32 = 1
MSV1_0_VALIDATION_KICKOFF_TIME: UInt32 = 2
MSV1_0_VALIDATION_LOGON_SERVER: UInt32 = 4
MSV1_0_VALIDATION_LOGON_DOMAIN: UInt32 = 8
MSV1_0_VALIDATION_SESSION_KEY: UInt32 = 16
MSV1_0_VALIDATION_USER_FLAGS: UInt32 = 32
MSV1_0_VALIDATION_USER_ID: UInt32 = 64
MSV1_0_SUBAUTH_ACCOUNT_DISABLED: UInt32 = 1
MSV1_0_SUBAUTH_PASSWORD: UInt32 = 2
MSV1_0_SUBAUTH_WORKSTATIONS: UInt32 = 4
MSV1_0_SUBAUTH_LOGON_HOURS: UInt32 = 8
MSV1_0_SUBAUTH_ACCOUNT_EXPIRY: UInt32 = 16
MSV1_0_SUBAUTH_PASSWORD_EXPIRY: UInt32 = 32
MSV1_0_SUBAUTH_ACCOUNT_TYPE: UInt32 = 64
MSV1_0_SUBAUTH_LOCKOUT: UInt32 = 128
SL_MDOLLAR_ZONE: UInt32 = 40960
SL_SERVER_ZONE: UInt32 = 45056
SL_MSCH_ZONE: UInt32 = 49152
SL_INTERNAL_ZONE: UInt32 = 57344
SL_CLIENTAPI_ZONE: UInt32 = 61440
FACILITY_SL_ITF: UInt32 = 4
_FACILITY_WINDOWS_STORE: UInt32 = 63
SL_E_SRV_INVALID_PUBLISH_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -1073434623
SL_E_SRV_INVALID_PRODUCT_KEY_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -1073434622
SL_E_SRV_INVALID_RIGHTS_ACCOUNT_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -1073434621
SL_E_SRV_INVALID_LICENSE_STRUCTURE: win32more.Windows.Win32.Foundation.HRESULT = -1073434620
SL_E_SRV_AUTHORIZATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1073434619
SL_E_SRV_INVALID_BINDING: win32more.Windows.Win32.Foundation.HRESULT = -1073434618
SL_E_SRV_SERVER_PONG: win32more.Windows.Win32.Foundation.HRESULT = -1073434617
SL_E_SRV_INVALID_PAYLOAD: win32more.Windows.Win32.Foundation.HRESULT = -1073434616
SL_E_SRV_INVALID_SECURITY_PROCESSOR_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -1073434615
SL_E_SRV_BUSINESS_TOKEN_ENTRY_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073434608
SL_E_SRV_CLIENT_CLOCK_OUT_OF_SYNC: win32more.Windows.Win32.Foundation.HRESULT = -1073434607
SL_E_SRV_GENERAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1073434368
SL_E_CHPA_PRODUCT_KEY_OUT_OF_RANGE: win32more.Windows.Win32.Foundation.HRESULT = -1073430527
SL_E_CHPA_INVALID_BINDING: win32more.Windows.Win32.Foundation.HRESULT = -1073430526
SL_E_CHPA_PRODUCT_KEY_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -1073430525
SL_E_CHPA_INVALID_PRODUCT_KEY: win32more.Windows.Win32.Foundation.HRESULT = -1073430524
SL_E_CHPA_BINDING_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073430523
SL_E_CHPA_BINDING_MAPPING_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073430522
SL_E_CHPA_UNSUPPORTED_PRODUCT_KEY: win32more.Windows.Win32.Foundation.HRESULT = -1073430521
SL_E_CHPA_MAXIMUM_UNLOCK_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -1073430520
SL_E_CHPA_ACTCONFIG_ID_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073430519
SL_E_CHPA_INVALID_PRODUCT_DATA_ID: win32more.Windows.Win32.Foundation.HRESULT = -1073430518
SL_E_CHPA_INVALID_PRODUCT_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1073430517
SL_E_CHPA_SYSTEM_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1073430516
SL_E_CHPA_INVALID_ACTCONFIG_ID: win32more.Windows.Win32.Foundation.HRESULT = -1073430515
SL_E_CHPA_INVALID_PRODUCT_KEY_LENGTH: win32more.Windows.Win32.Foundation.HRESULT = -1073430514
SL_E_CHPA_INVALID_PRODUCT_KEY_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1073430513
SL_E_CHPA_INVALID_PRODUCT_KEY_CHAR: win32more.Windows.Win32.Foundation.HRESULT = -1073430512
SL_E_CHPA_INVALID_BINDING_URI: win32more.Windows.Win32.Foundation.HRESULT = -1073430511
SL_E_CHPA_NETWORK_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1073430510
SL_E_CHPA_DATABASE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1073430509
SL_E_CHPA_INVALID_ARGUMENT: win32more.Windows.Win32.Foundation.HRESULT = -1073430508
SL_E_CHPA_DMAK_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -1073430496
SL_E_CHPA_DMAK_EXTENSION_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -1073430495
SL_E_CHPA_REISSUANCE_LIMIT_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073430494
SL_E_CHPA_OVERRIDE_REQUEST_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073430493
SL_E_CHPA_OEM_SLP_COA0: win32more.Windows.Win32.Foundation.HRESULT = -1073430506
SL_E_CHPA_PRODUCT_KEY_BLOCKED_IPLOCATION: win32more.Windows.Win32.Foundation.HRESULT = -1073430505
SL_E_CHPA_RESPONSE_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1073430507
SL_E_CHPA_GENERAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1073430448
SL_E_CHPA_TIMEBASED_ACTIVATION_BEFORE_START_DATE: win32more.Windows.Win32.Foundation.HRESULT = -1073430480
SL_E_CHPA_TIMEBASED_ACTIVATION_AFTER_END_DATE: win32more.Windows.Win32.Foundation.HRESULT = -1073430479
SL_E_CHPA_TIMEBASED_ACTIVATION_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1073430478
SL_E_CHPA_TIMEBASED_PRODUCT_KEY_NOT_CONFIGURED: win32more.Windows.Win32.Foundation.HRESULT = -1073430477
SL_E_CHPA_NO_RULES_TO_ACTIVATE: win32more.Windows.Win32.Foundation.HRESULT = -1073430449
SL_E_CHPA_DIGITALMARKER_INVALID_BINDING: win32more.Windows.Win32.Foundation.HRESULT = -1073430447
SL_E_CHPA_DIGITALMARKER_BINDING_NOT_CONFIGURED: win32more.Windows.Win32.Foundation.HRESULT = -1073430446
SL_E_CHPA_DYNAMICALLY_BLOCKED_PRODUCT_KEY: win32more.Windows.Win32.Foundation.HRESULT = -1073430432
SL_E_CHPA_MSCH_RESPONSE_NOT_AVAILABLE_VGA: win32more.Windows.Win32.Foundation.HRESULT = -1073429505
SL_E_CHPA_BUSINESS_RULE_INPUT_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073428736
SL_E_CHPA_NULL_VALUE_FOR_PROPERTY_NAME_OR_ID: win32more.Windows.Win32.Foundation.HRESULT = -1073428656
SL_E_CHPA_UNKNOWN_PROPERTY_NAME: win32more.Windows.Win32.Foundation.HRESULT = -1073428655
SL_E_CHPA_UNKNOWN_PROPERTY_ID: win32more.Windows.Win32.Foundation.HRESULT = -1073428654
SL_E_CHPA_FAILED_TO_UPDATE_PRODUCTKEY_BINDING: win32more.Windows.Win32.Foundation.HRESULT = -1073428651
SL_E_CHPA_FAILED_TO_INSERT_PRODUCTKEY_BINDING: win32more.Windows.Win32.Foundation.HRESULT = -1073428650
SL_E_CHPA_FAILED_TO_DELETE_PRODUCTKEY_BINDING: win32more.Windows.Win32.Foundation.HRESULT = -1073428649
SL_E_CHPA_FAILED_TO_PROCESS_PRODUCT_KEY_BINDINGS_XML: win32more.Windows.Win32.Foundation.HRESULT = -1073428648
SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -1073428646
SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -1073428645
SL_E_CHPA_FAILED_TO_DELETE_PRODUCT_KEY_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -1073428644
SL_E_CHPA_UNKNOWN_PRODUCT_KEY_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -1073428636
SL_E_CHPA_PRODUCT_KEY_BEING_USED: win32more.Windows.Win32.Foundation.HRESULT = -1073428624
SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_RECORD: win32more.Windows.Win32.Foundation.HRESULT = -1073428608
SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_RECORD: win32more.Windows.Win32.Foundation.HRESULT = -1073428607
SL_E_INVALID_LICENSE_STATE_BREACH_GRACE: win32more.Windows.Win32.Foundation.HRESULT = -1073429871
SL_E_INVALID_LICENSE_STATE_BREACH_GRACE_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -1073429870
SL_E_INVALID_TEMPLATE_ID: win32more.Windows.Win32.Foundation.HRESULT = -1073429770
SL_E_INVALID_XML_BLOB: win32more.Windows.Win32.Foundation.HRESULT = -1073429766
SL_E_VALIDATION_BLOB_PARAM_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073429721
SL_E_INVALID_CLIENT_TOKEN: win32more.Windows.Win32.Foundation.HRESULT = -1073429720
SL_E_INVALID_OFFLINE_BLOB: win32more.Windows.Win32.Foundation.HRESULT = -1073429719
SL_E_OFFLINE_VALIDATION_BLOB_PARAM_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073429718
SL_E_INVALID_OSVERSION_TEMPLATEID: win32more.Windows.Win32.Foundation.HRESULT = -1073429717
SL_E_OFFLINE_GENUINE_BLOB_REVOKED: win32more.Windows.Win32.Foundation.HRESULT = -1073429716
SL_E_OFFLINE_GENUINE_BLOB_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073429715
SL_E_INVALID_OS_FOR_PRODUCT_KEY: win32more.Windows.Win32.Foundation.HRESULT = -1073429503
SL_E_INVALID_FILE_HASH: win32more.Windows.Win32.Foundation.HRESULT = -1073429343
SL_E_VALIDATION_BLOCKED_PRODUCT_KEY: win32more.Windows.Win32.Foundation.HRESULT = -1073429342
SL_E_MISMATCHED_KEY_TYPES: win32more.Windows.Win32.Foundation.HRESULT = -1073429340
SL_E_VALIDATION_INVALID_PRODUCT_KEY: win32more.Windows.Win32.Foundation.HRESULT = -1073429339
SL_E_INVALID_OEM_OR_VOLUME_BINDING_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1073429337
SL_E_INVALID_LICENSE_STATE: win32more.Windows.Win32.Foundation.HRESULT = -1073429336
SL_E_IP_LOCATION_FALIED: win32more.Windows.Win32.Foundation.HRESULT = -1073429335
SL_E_SOFTMOD_EXPLOIT_DETECTED: win32more.Windows.Win32.Foundation.HRESULT = -1073429333
SL_E_INVALID_TOKEN_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1073429332
SL_E_HEALTH_CHECK_FAILED_NEUTRAL_FILES: win32more.Windows.Win32.Foundation.HRESULT = -1073429331
SL_E_HEALTH_CHECK_FAILED_MUI_FILES: win32more.Windows.Win32.Foundation.HRESULT = -1073429330
SL_E_INVALID_AD_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1073429329
SL_E_INVALID_RSDP_COUNT: win32more.Windows.Win32.Foundation.HRESULT = -1073429328
SL_E_ENGINE_DETECTED_EXPLOIT: win32more.Windows.Win32.Foundation.HRESULT = -1073429327
SL_E_NON_GENUINE_STATUS_LAST: win32more.Windows.Win32.Foundation.HRESULT = -1073428992
SL_E_NOTIFICATION_BREACH_DETECTED: win32more.Windows.Win32.Foundation.HRESULT = -1073429199
SL_E_NOTIFICATION_GRACE_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -1073429198
SL_E_NOTIFICATION_OTHER_REASONS: win32more.Windows.Win32.Foundation.HRESULT = -1073429197
SL_E_INVALID_CONTEXT: win32more.Windows.Win32.Foundation.HRESULT = -1073422335
SL_E_TOKEN_STORE_INVALID_STATE: win32more.Windows.Win32.Foundation.HRESULT = -1073422334
SL_E_EVALUATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1073422333
SL_E_NOT_EVALUATED: win32more.Windows.Win32.Foundation.HRESULT = -1073422332
SL_E_NOT_ACTIVATED: win32more.Windows.Win32.Foundation.HRESULT = -1073422331
SL_E_INVALID_GUID: win32more.Windows.Win32.Foundation.HRESULT = -1073422330
SL_E_TOKSTO_TOKEN_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073422329
SL_E_TOKSTO_NO_PROPERTIES: win32more.Windows.Win32.Foundation.HRESULT = -1073422328
SL_E_TOKSTO_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -1073422327
SL_E_TOKSTO_ALREADY_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -1073422326
SL_E_TOKSTO_NO_ID_SET: win32more.Windows.Win32.Foundation.HRESULT = -1073422325
SL_E_TOKSTO_CANT_CREATE_FILE: win32more.Windows.Win32.Foundation.HRESULT = -1073422324
SL_E_TOKSTO_CANT_WRITE_TO_FILE: win32more.Windows.Win32.Foundation.HRESULT = -1073422323
SL_E_TOKSTO_CANT_READ_FILE: win32more.Windows.Win32.Foundation.HRESULT = -1073422322
SL_E_TOKSTO_CANT_PARSE_PROPERTIES: win32more.Windows.Win32.Foundation.HRESULT = -1073422321
SL_E_TOKSTO_PROPERTY_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073422320
SL_E_TOKSTO_INVALID_FILE: win32more.Windows.Win32.Foundation.HRESULT = -1073422319
SL_E_TOKSTO_CANT_CREATE_MUTEX: win32more.Windows.Win32.Foundation.HRESULT = -1073422318
SL_E_TOKSTO_CANT_ACQUIRE_MUTEX: win32more.Windows.Win32.Foundation.HRESULT = -1073422317
SL_E_TOKSTO_NO_TOKEN_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1073422316
SL_E_EUL_CONSUMPTION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1073422315
SL_E_PKEY_INVALID_CONFIG: win32more.Windows.Win32.Foundation.HRESULT = -1073422314
SL_E_PKEY_INVALID_UNIQUEID: win32more.Windows.Win32.Foundation.HRESULT = -1073422313
SL_E_PKEY_INVALID_ALGORITHM: win32more.Windows.Win32.Foundation.HRESULT = -1073422312
SL_E_PKEY_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1073422311
SL_E_LICENSE_INVALID_ADDON_INFO: win32more.Windows.Win32.Foundation.HRESULT = -1073422310
SL_E_HWID_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1073422309
SL_E_PKEY_INVALID_KEYCHANGE1: win32more.Windows.Win32.Foundation.HRESULT = -1073422308
SL_E_PKEY_INVALID_KEYCHANGE2: win32more.Windows.Win32.Foundation.HRESULT = -1073422307
SL_E_PKEY_INVALID_KEYCHANGE3: win32more.Windows.Win32.Foundation.HRESULT = -1073422306
SL_E_POLICY_OTHERINFO_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1073422304
SL_E_PRODUCT_UNIQUENESS_GROUP_ID_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -1073422303
SL_E_SECURE_STORE_ID_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1073422302
SL_E_INVALID_RULESET_RULE: win32more.Windows.Win32.Foundation.HRESULT = -1073422301
SL_E_INVALID_CONTEXT_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1073422300
SL_E_INVALID_HASH: win32more.Windows.Win32.Foundation.HRESULT = -1073422299
SL_E_INVALID_USE_OF_ADD_ON_PKEY: win32more.Windows.Win32.Foundation.HRESULT = -2147164122
SL_E_WINDOWS_VERSION_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1073422297
SL_E_ACTIVATION_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -1073422296
SL_E_STORE_UPGRADE_TOKEN_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -1073422295
SL_E_STORE_UPGRADE_TOKEN_WRONG_EDITION: win32more.Windows.Win32.Foundation.HRESULT = -1073422294
SL_E_STORE_UPGRADE_TOKEN_WRONG_PID: win32more.Windows.Win32.Foundation.HRESULT = -1073422293
SL_E_STORE_UPGRADE_TOKEN_NOT_PRS_SIGNED: win32more.Windows.Win32.Foundation.HRESULT = -1073422292
SL_E_STORE_UPGRADE_TOKEN_WRONG_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -1073422291
SL_E_STORE_UPGRADE_TOKEN_NOT_AUTHORIZED: win32more.Windows.Win32.Foundation.HRESULT = -1073422290
SL_E_SFS_INVALID_FS_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2147163903
SL_E_SFS_INVALID_FD_TABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147163902
SL_E_SFS_INVALID_SYNC: win32more.Windows.Win32.Foundation.HRESULT = -2147163901
SL_E_SFS_BAD_TOKEN_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2147163900
SL_E_SFS_BAD_TOKEN_EXT: win32more.Windows.Win32.Foundation.HRESULT = -2147163899
SL_E_SFS_DUPLICATE_TOKEN_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2147163898
SL_E_SFS_TOKEN_SIZE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2147163897
SL_E_SFS_INVALID_TOKEN_DATA_HASH: win32more.Windows.Win32.Foundation.HRESULT = -2147163896
SL_E_SFS_FILE_READ_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147163895
SL_E_SFS_FILE_WRITE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147163894
SL_E_SFS_INVALID_FILE_POSITION: win32more.Windows.Win32.Foundation.HRESULT = -2147163893
SL_E_SFS_NO_ACTIVE_TRANSACTION: win32more.Windows.Win32.Foundation.HRESULT = -2147163892
SL_E_SFS_INVALID_FS_HEADER: win32more.Windows.Win32.Foundation.HRESULT = -2147163891
SL_E_SFS_INVALID_TOKEN_DESCRIPTOR: win32more.Windows.Win32.Foundation.HRESULT = -2147163890
SL_E_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1073418239
SL_E_RIGHT_NOT_CONSUMED: win32more.Windows.Win32.Foundation.HRESULT = -1073418238
SL_E_USE_LICENSE_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -1073418237
SL_E_MISMATCHED_PKEY_RANGE: win32more.Windows.Win32.Foundation.HRESULT = -1073418236
SL_E_MISMATCHED_PID: win32more.Windows.Win32.Foundation.HRESULT = -1073418235
SL_E_EXTERNAL_SIGNATURE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073418234
SL_E_RAC_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1073418233
SL_E_SPC_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1073418232
SL_E_GRACE_TIME_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -1073418231
SL_E_MISMATCHED_APPID: win32more.Windows.Win32.Foundation.HRESULT = -1073418230
SL_E_NO_PID_CONFIG_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1073418229
SL_I_OOB_GRACE_PERIOD: win32more.Windows.Win32.Foundation.HRESULT = 1074065420
SL_I_OOT_GRACE_PERIOD: win32more.Windows.Win32.Foundation.HRESULT = 1074065421
SL_E_MISMATCHED_SECURITY_PROCESSOR: win32more.Windows.Win32.Foundation.HRESULT = -1073418226
SL_E_OUT_OF_TOLERANCE: win32more.Windows.Win32.Foundation.HRESULT = -1073418225
SL_E_INVALID_PKEY: win32more.Windows.Win32.Foundation.HRESULT = -1073418224
SL_E_LICENSE_FILE_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -1073418223
SL_E_VALUE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073418222
SL_E_RIGHT_NOT_GRANTED: win32more.Windows.Win32.Foundation.HRESULT = -1073418221
SL_E_PKEY_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -1073418220
SL_E_PRODUCT_SKU_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -1073418219
SL_E_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1073418218
SL_E_PUBLISHING_LICENSE_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -1073418217
SL_E_LICENSE_SERVER_URL_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073418216
SL_E_INVALID_EVENT_ID: win32more.Windows.Win32.Foundation.HRESULT = -1073418215
SL_E_EVENT_NOT_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -1073418214
SL_E_EVENT_ALREADY_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -1073418213
SL_E_DECRYPTION_LICENSES_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1073418212
SL_E_LICENSE_SIGNATURE_VERIFICATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1073418211
SL_E_DATATYPE_MISMATCHED: win32more.Windows.Win32.Foundation.HRESULT = -1073418210
SL_E_INVALID_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -1073418209
SL_E_INVALID_PACKAGE: win32more.Windows.Win32.Foundation.HRESULT = -1073418208
SL_E_VALIDITY_TIME_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -1073418207
SL_E_LICENSE_AUTHORIZATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1073418206
SL_E_LICENSE_DECRYPTION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1073418205
SL_E_WINDOWS_INVALID_LICENSE_STATE: win32more.Windows.Win32.Foundation.HRESULT = -1073418204
SL_E_LUA_ACCESSDENIED: win32more.Windows.Win32.Foundation.HRESULT = -1073418203
SL_E_PROXY_KEY_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073418202
SL_E_TAMPER_DETECTED: win32more.Windows.Win32.Foundation.HRESULT = -1073418201
SL_E_POLICY_CACHE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -1073418200
SL_E_INVALID_RUNNING_MODE: win32more.Windows.Win32.Foundation.HRESULT = -1073418199
SL_E_SLP_NOT_SIGNED: win32more.Windows.Win32.Foundation.HRESULT = -1073418198
SL_E_CIDIID_INVALID_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1073418196
SL_E_CIDIID_INVALID_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -1073418195
SL_E_CIDIID_VERSION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1073418194
SL_E_CIDIID_INVALID_DATA_LENGTH: win32more.Windows.Win32.Foundation.HRESULT = -1073418193
SL_E_CIDIID_NOT_DEPOSITED: win32more.Windows.Win32.Foundation.HRESULT = -1073418192
SL_E_CIDIID_MISMATCHED: win32more.Windows.Win32.Foundation.HRESULT = -1073418191
SL_E_INVALID_BINDING_BLOB: win32more.Windows.Win32.Foundation.HRESULT = -1073418190
SL_E_PRODUCT_KEY_INSTALLATION_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -1073418189
SL_E_EUL_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1073418188
SL_E_VL_NOT_WINDOWS_SLP: win32more.Windows.Win32.Foundation.HRESULT = -1073418187
SL_E_VL_NOT_ENOUGH_COUNT: win32more.Windows.Win32.Foundation.HRESULT = -1073418184
SL_E_VL_BINDING_SERVICE_NOT_ENABLED: win32more.Windows.Win32.Foundation.HRESULT = -1073418183
SL_E_VL_INFO_PRODUCT_USER_RIGHT: win32more.Windows.Win32.Foundation.HRESULT = 1074065472
SL_E_VL_KEY_MANAGEMENT_SERVICE_NOT_ACTIVATED: win32more.Windows.Win32.Foundation.HRESULT = -1073418175
SL_E_VL_KEY_MANAGEMENT_SERVICE_ID_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1073418174
SL_E_PROXY_POLICY_NOT_UPDATED: win32more.Windows.Win32.Foundation.HRESULT = -1073418169
SL_E_CIDIID_INVALID_CHECK_DIGITS: win32more.Windows.Win32.Foundation.HRESULT = -1073418163
SL_E_LICENSE_MANAGEMENT_DATA_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073418161
SL_E_INVALID_PRODUCT_KEY: win32more.Windows.Win32.Foundation.HRESULT = -1073418160
SL_E_BLOCKED_PRODUCT_KEY: win32more.Windows.Win32.Foundation.HRESULT = -1073418159
SL_E_DUPLICATE_POLICY: win32more.Windows.Win32.Foundation.HRESULT = -1073418158
SL_E_MISSING_OVERRIDE_ONLY_ATTRIBUTE: win32more.Windows.Win32.Foundation.HRESULT = -1073418157
SL_E_LICENSE_MANAGEMENT_DATA_DUPLICATED: win32more.Windows.Win32.Foundation.HRESULT = -1073418156
SL_E_BASE_SKU_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1073418155
SL_E_VL_MACHINE_NOT_BOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073418154
SL_E_SLP_MISSING_ACPI_SLIC: win32more.Windows.Win32.Foundation.HRESULT = -1073418153
SL_E_SLP_MISSING_SLP_MARKER: win32more.Windows.Win32.Foundation.HRESULT = -1073418152
SL_E_SLP_BAD_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1073418151
SL_E_INVALID_PACKAGE_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -1073418144
SL_E_PKEY_INVALID_UPGRADE: win32more.Windows.Win32.Foundation.HRESULT = -1073418143
SL_E_ISSUANCE_LICENSE_NOT_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = -1073418142
SL_E_SLP_OEM_CERT_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -1073418141
SL_E_NONGENUINE_GRACE_TIME_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -1073418140
SL_I_NONGENUINE_GRACE_PERIOD: win32more.Windows.Win32.Foundation.HRESULT = 1074065509
SL_E_DEPENDENT_PROPERTY_NOT_SET: win32more.Windows.Win32.Foundation.HRESULT = -1073418138
SL_E_NONGENUINE_GRACE_TIME_EXPIRED_2: win32more.Windows.Win32.Foundation.HRESULT = -1073418137
SL_I_NONGENUINE_GRACE_PERIOD_2: win32more.Windows.Win32.Foundation.HRESULT = 1074065512
SL_E_MISMATCHED_PRODUCT_SKU: win32more.Windows.Win32.Foundation.HRESULT = -1073418135
SL_E_OPERATION_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -1073418134
SL_E_VL_KEY_MANAGEMENT_SERVICE_VM_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1073418133
SL_E_VL_INVALID_TIMESTAMP: win32more.Windows.Win32.Foundation.HRESULT = -1073418132
SL_E_PLUGIN_INVALID_MANIFEST: win32more.Windows.Win32.Foundation.HRESULT = -1073418127
SL_E_APPLICATION_POLICIES_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -1073418126
SL_E_APPLICATION_POLICIES_NOT_LOADED: win32more.Windows.Win32.Foundation.HRESULT = -1073418125
SL_E_VL_BINDING_SERVICE_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1073418124
SL_E_SERVICE_STOPPING: win32more.Windows.Win32.Foundation.HRESULT = -1073418123
SL_E_PLUGIN_NOT_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -1073418122
SL_E_AUTHN_WRONG_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -1073418121
SL_E_AUTHN_MISMATCHED_KEY: win32more.Windows.Win32.Foundation.HRESULT = -1073418120
SL_E_AUTHN_CHALLENGE_NOT_SET: win32more.Windows.Win32.Foundation.HRESULT = -1073418119
SL_E_AUTHN_CANT_VERIFY: win32more.Windows.Win32.Foundation.HRESULT = -1073418118
SL_E_SERVICE_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -1073418117
SL_E_SLP_INVALID_MARKER_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -1073418116
SL_E_INVALID_PRODUCT_KEY_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -1073418115
SL_E_CIDIID_MISMATCHED_PKEY: win32more.Windows.Win32.Foundation.HRESULT = -1073418114
SL_E_CIDIID_NOT_BOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073418113
SL_E_LICENSE_NOT_BOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073418112
SL_E_VL_AD_AO_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073418111
SL_E_VL_AD_AO_NAME_TOO_LONG: win32more.Windows.Win32.Foundation.HRESULT = -1073418110
SL_E_VL_AD_SCHEMA_VERSION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -1073418109
SL_E_NOT_GENUINE: win32more.Windows.Win32.Foundation.HRESULT = -1073417728
SL_E_EDITION_MISMATCHED: win32more.Windows.Win32.Foundation.HRESULT = -1073417712
SL_E_HWID_CHANGED: win32more.Windows.Win32.Foundation.HRESULT = -1073417711
SL_E_OEM_KEY_EDITION_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1073417710
SL_E_NO_PRODUCT_KEY_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073417709
SL_E_DOWNLEVEL_SETUP_KEY: win32more.Windows.Win32.Foundation.HRESULT = -1073417708
SL_E_BIOS_KEY: win32more.Windows.Win32.Foundation.HRESULT = -1073417707
SL_E_TKA_CHALLENGE_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -1073417471
SL_E_TKA_SILENT_ACTIVATION_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1073417470
SL_E_TKA_INVALID_CERT_CHAIN: win32more.Windows.Win32.Foundation.HRESULT = -1073417469
SL_E_TKA_GRANT_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073417468
SL_E_TKA_CERT_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073417467
SL_E_TKA_INVALID_SKU_ID: win32more.Windows.Win32.Foundation.HRESULT = -1073417466
SL_E_TKA_INVALID_BLOB: win32more.Windows.Win32.Foundation.HRESULT = -1073417465
SL_E_TKA_TAMPERED_CERT_CHAIN: win32more.Windows.Win32.Foundation.HRESULT = -1073417464
SL_E_TKA_CHALLENGE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1073417463
SL_E_TKA_INVALID_CERTIFICATE: win32more.Windows.Win32.Foundation.HRESULT = -1073417462
SL_E_TKA_INVALID_SMARTCARD: win32more.Windows.Win32.Foundation.HRESULT = -1073417461
SL_E_TKA_FAILED_GRANT_PARSING: win32more.Windows.Win32.Foundation.HRESULT = -1073417460
SL_E_TKA_INVALID_THUMBPRINT: win32more.Windows.Win32.Foundation.HRESULT = -1073417459
SL_E_TKA_THUMBPRINT_CERT_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073417458
SL_E_TKA_CRITERIA_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1073417457
SL_E_TKA_TPID_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1073417456
SL_E_TKA_SOFT_CERT_DISALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -1073417455
SL_E_TKA_SOFT_CERT_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -1073417454
SL_E_TKA_CERT_CNG_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1073417453
SL_I_STORE_BASED_ACTIVATION: win32more.Windows.Win32.Foundation.HRESULT = 1074066433
E_RM_UNKNOWN_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -1073415165
SL_I_TIMEBASED_VALIDITY_PERIOD: win32more.Windows.Win32.Foundation.HRESULT = 1074068484
SL_I_PERPETUAL_OOB_GRACE_PERIOD: win32more.Windows.Win32.Foundation.HRESULT = 1074068485
SL_I_TIMEBASED_EXTENDED_GRACE_PERIOD: win32more.Windows.Win32.Foundation.HRESULT = 1074068486
SL_E_VALIDITY_PERIOD_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -1073415161
SL_E_IA_THROTTLE_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -1073414912
SL_E_IA_INVALID_VIRTUALIZATION_PLATFORM: win32more.Windows.Win32.Foundation.HRESULT = -1073414911
SL_E_IA_PARENT_PARTITION_NOT_ACTIVATED: win32more.Windows.Win32.Foundation.HRESULT = -1073414910
SL_E_IA_ID_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1073414909
SL_E_IA_MACHINE_NOT_BOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073414908
SL_E_TAMPER_RECOVERY_REQUIRES_ACTIVATION: win32more.Windows.Win32.Foundation.HRESULT = -1073414656
SL_REMAPPING_SP_PUB_GENERAL_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -1073426175
SL_REMAPPING_SP_STATUS_SYSTEM_TIME_SKEWED: win32more.Windows.Win32.Foundation.HRESULT = -2147167998
SL_REMAPPING_SP_STATUS_GENERIC_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -1073426173
SL_REMAPPING_SP_STATUS_INVALIDARG: win32more.Windows.Win32.Foundation.HRESULT = -1073426172
SL_REMAPPING_SP_STATUS_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -1073426171
SL_REMAPPING_SP_STATUS_INSUFFICIENT_BUFFER: win32more.Windows.Win32.Foundation.HRESULT = -1073426169
SL_REMAPPING_SP_STATUS_INVALIDDATA: win32more.Windows.Win32.Foundation.HRESULT = -1073426168
SL_REMAPPING_SP_STATUS_INVALID_SPAPI_CALL: win32more.Windows.Win32.Foundation.HRESULT = -1073426167
SL_REMAPPING_SP_STATUS_INVALID_SPAPI_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -1073426166
SL_REMAPPING_SP_STATUS_DEBUGGER_DETECTED: win32more.Windows.Win32.Foundation.HRESULT = -2147167989
SL_REMAPPING_SP_STATUS_NO_MORE_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1073426164
SL_REMAPPING_SP_PUB_CRYPTO_INVALID_KEYLENGTH: win32more.Windows.Win32.Foundation.HRESULT = -1073425919
SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCKLENGTH: win32more.Windows.Win32.Foundation.HRESULT = -1073425918
SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHER: win32more.Windows.Win32.Foundation.HRESULT = -1073425917
SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHERMODE: win32more.Windows.Win32.Foundation.HRESULT = -1073425916
SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_PROVIDERID: win32more.Windows.Win32.Foundation.HRESULT = -1073425915
SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_KEYID: win32more.Windows.Win32.Foundation.HRESULT = -1073425914
SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_HASHID: win32more.Windows.Win32.Foundation.HRESULT = -1073425913
SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_ATTRIBUTEID: win32more.Windows.Win32.Foundation.HRESULT = -1073425912
SL_REMAPPING_SP_PUB_CRYPTO_HASH_FINALIZED: win32more.Windows.Win32.Foundation.HRESULT = -1073425911
SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -1073425910
SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073425909
SL_REMAPPING_SP_PUB_CRYPTO_NOT_BLOCK_ALIGNED: win32more.Windows.Win32.Foundation.HRESULT = -1073425908
SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURELENGTH: win32more.Windows.Win32.Foundation.HRESULT = -1073425907
SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURE: win32more.Windows.Win32.Foundation.HRESULT = -1073425906
SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCK: win32more.Windows.Win32.Foundation.HRESULT = -1073425905
SL_REMAPPING_SP_PUB_CRYPTO_INVALID_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -1073425904
SL_REMAPPING_SP_PUB_CRYPTO_INVALID_PADDING: win32more.Windows.Win32.Foundation.HRESULT = -1073425903
SL_REMAPPING_SP_PUB_TS_TAMPERED: win32more.Windows.Win32.Foundation.HRESULT = -1073425663
SL_REMAPPING_SP_PUB_TS_REARMED: win32more.Windows.Win32.Foundation.HRESULT = -1073425662
SL_REMAPPING_SP_PUB_TS_RECREATED: win32more.Windows.Win32.Foundation.HRESULT = -1073425661
SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073425660
SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -1073425659
SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_SIZE_TOO_BIG: win32more.Windows.Win32.Foundation.HRESULT = -1073425658
SL_REMAPPING_SP_PUB_TS_MAX_REARM_REACHED: win32more.Windows.Win32.Foundation.HRESULT = -1073425657
SL_REMAPPING_SP_PUB_TS_DATA_SIZE_TOO_BIG: win32more.Windows.Win32.Foundation.HRESULT = -1073425656
SL_REMAPPING_SP_PUB_TS_INVALID_HW_BINDING: win32more.Windows.Win32.Foundation.HRESULT = -1073425655
SL_REMAPPING_SP_PUB_TIMER_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -1073425654
SL_REMAPPING_SP_PUB_TIMER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073425653
SL_REMAPPING_SP_PUB_TIMER_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -1073425652
SL_REMAPPING_SP_PUB_TIMER_NAME_SIZE_TOO_BIG: win32more.Windows.Win32.Foundation.HRESULT = -1073425651
SL_REMAPPING_SP_PUB_TS_FULL: win32more.Windows.Win32.Foundation.HRESULT = -1073425650
SL_REMAPPING_SP_PUB_TRUSTED_TIME_OK: win32more.Windows.Win32.Foundation.HRESULT = 1074057999
SL_REMAPPING_SP_PUB_TS_ENTRY_READ_ONLY: win32more.Windows.Win32.Foundation.HRESULT = -1073425648
SL_REMAPPING_SP_PUB_TIMER_READ_ONLY: win32more.Windows.Win32.Foundation.HRESULT = -1073425647
SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_READ_ONLY: win32more.Windows.Win32.Foundation.HRESULT = -1073425646
SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073425645
SL_REMAPPING_SP_PUB_TS_ACCESS_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -1073425644
SL_REMAPPING_SP_PUB_TS_NAMESPACE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -1073425643
SL_REMAPPING_SP_PUB_TS_NAMESPACE_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -1073425642
SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_LOAD_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -1073425641
SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_GENERATION: win32more.Windows.Win32.Foundation.HRESULT = -1073425640
SL_REMAPPING_SP_PUB_TS_TAMPERED_INVALID_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1073425639
SL_REMAPPING_SP_PUB_TS_TAMPERED_NO_DATA: win32more.Windows.Win32.Foundation.HRESULT = -1073425638
SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_BREADCRUMB_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1073425637
SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_VERSION_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -1073425636
SL_REMAPPING_SP_PUB_TAMPER_MODULE_AUTHENTICATION: win32more.Windows.Win32.Foundation.HRESULT = -1073425407
SL_REMAPPING_SP_PUB_TAMPER_SECURITY_PROCESSOR_PATCHED: win32more.Windows.Win32.Foundation.HRESULT = -1073425406
SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER: win32more.Windows.Win32.Foundation.HRESULT = -1073425151
SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER_RESTORE_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -1073425150
SL_REMAPPING_SP_PUB_KM_CACHE_IDENTICAL: win32more.Windows.Win32.Foundation.HRESULT = 1074058753
SL_REMAPPING_SP_PUB_KM_CACHE_POLICY_CHANGED: win32more.Windows.Win32.Foundation.HRESULT = 1074058754
SL_REMAPPING_SP_STATUS_PUSHKEY_CONFLICT: win32more.Windows.Win32.Foundation.HRESULT = -1073424639
SL_REMAPPING_SP_PUB_PROXY_SOFT_TAMPER: win32more.Windows.Win32.Foundation.HRESULT = -1073424638
SL_REMAPPING_SP_PUB_API_INVALID_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -1073426432
SL_REMAPPING_SP_PUB_API_INVALID_ALGORITHM_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -1073426423
SL_REMAPPING_SP_PUB_API_TOO_MANY_LOADED_ENVIRONMENTS: win32more.Windows.Win32.Foundation.HRESULT = -1073426420
SL_REMAPPING_SP_PUB_API_BAD_GET_INFO_QUERY: win32more.Windows.Win32.Foundation.HRESULT = -1073426414
SL_REMAPPING_SP_PUB_API_INVALID_HANDLE: win32more.Windows.Win32.Foundation.HRESULT = -1073426388
SL_REMAPPING_SP_PUB_API_INVALID_KEY_LENGTH: win32more.Windows.Win32.Foundation.HRESULT = -1073426347
SL_REMAPPING_SP_PUB_API_NO_AES_PROVIDER: win32more.Windows.Win32.Foundation.HRESULT = -1073426317
SL_REMAPPING_SP_PUB_API_HANDLE_NOT_COMMITED: win32more.Windows.Win32.Foundation.HRESULT = -1073426303
SL_REMAPPING_MDOLLAR_PRODUCT_KEY_OUT_OF_RANGE: win32more.Windows.Win32.Foundation.HRESULT = -2143313819
SL_REMAPPING_MDOLLAR_INVALID_BINDING: win32more.Windows.Win32.Foundation.HRESULT = -2143313818
SL_REMAPPING_MDOLLAR_PRODUCT_KEY_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2143313817
SL_REMAPPING_MDOLLAR_INVALID_PRODUCT_KEY: win32more.Windows.Win32.Foundation.HRESULT = -2143313816
SL_REMAPPING_MDOLLAR_UNSUPPORTED_PRODUCT_KEY: win32more.Windows.Win32.Foundation.HRESULT = -2143313812
SL_REMAPPING_MDOLLAR_MAXIMUM_UNLOCK_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2143313807
SL_REMAPPING_MDOLLAR_INVALID_PRODUCT_DATA_ID: win32more.Windows.Win32.Foundation.HRESULT = -2143313805
SL_REMAPPING_MDOLLAR_INVALID_PRODUCT_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2143313804
SL_REMAPPING_MDOLLAR_INVALID_ACTCONFIG_ID: win32more.Windows.Win32.Foundation.HRESULT = -2143313802
SL_REMAPPING_MDOLLAR_INVALID_PRODUCT_KEY_LENGTH: win32more.Windows.Win32.Foundation.HRESULT = -2143313801
SL_REMAPPING_MDOLLAR_INVALID_PRODUCT_KEY_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2143313800
SL_REMAPPING_MDOLLAR_INVALID_BINDING_URI: win32more.Windows.Win32.Foundation.HRESULT = -2143313798
SL_REMAPPING_MDOLLAR_INVALID_ARGUMENT: win32more.Windows.Win32.Foundation.HRESULT = -2143313795
SL_REMAPPING_MDOLLAR_DMAK_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2143313793
SL_REMAPPING_MDOLLAR_DMAK_EXTENSION_LIMIT_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2143313792
SL_REMAPPING_MDOLLAR_OEM_SLP_COA0: win32more.Windows.Win32.Foundation.HRESULT = -2143313789
SL_REMAPPING_MDOLLAR_CIDIID_INVALID_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2143313779
SL_REMAPPING_MDOLLAR_CIDIID_INVALID_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2143313778
SL_REMAPPING_MDOLLAR_CIDIID_INVALID_DATA_LENGTH: win32more.Windows.Win32.Foundation.HRESULT = -2143313777
SL_REMAPPING_MDOLLAR_CIDIID_INVALID_CHECK_DIGITS: win32more.Windows.Win32.Foundation.HRESULT = -2143313776
SL_REMAPPING_MDOLLAR_TIMEBASED_ACTIVATION_BEFORE_START_DATE: win32more.Windows.Win32.Foundation.HRESULT = -2143313769
SL_REMAPPING_MDOLLAR_TIMEBASED_ACTIVATION_AFTER_END_DATE: win32more.Windows.Win32.Foundation.HRESULT = -2143313768
SL_REMAPPING_MDOLLAR_TIMEBASED_ACTIVATION_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2143313767
SL_REMAPPING_MDOLLAR_TIMEBASED_PRODUCT_KEY_NOT_CONFIGURED: win32more.Windows.Win32.Foundation.HRESULT = -2143313766
SL_REMAPPING_MDOLLAR_NO_RULES_TO_ACTIVATE: win32more.Windows.Win32.Foundation.HRESULT = -2143313720
SL_REMAPPING_MDOLLAR_PRODUCT_KEY_BLOCKED_IPLOCATION: win32more.Windows.Win32.Foundation.HRESULT = -2143313717
SL_REMAPPING_MDOLLAR_DIGITALMARKER_INVALID_BINDING: win32more.Windows.Win32.Foundation.HRESULT = -2143313709
SL_REMAPPING_MDOLLAR_DIGITALMARKER_BINDING_NOT_CONFIGURED: win32more.Windows.Win32.Foundation.HRESULT = -2143313708
SL_REMAPPING_MDOLLAR_ROT_OVERRIDE_LIMIT_REACHED: win32more.Windows.Win32.Foundation.HRESULT = -2143313707
SL_REMAPPING_MDOLLAR_DMAK_OVERRIDE_LIMIT_REACHED: win32more.Windows.Win32.Foundation.HRESULT = -2143313706
SL_REMAPPING_MDOLLAR_FREE_OFFER_EXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -2143312896
SL_REMAPPING_MDOLLAR_OSR_DONOR_HWID_NO_ENTITLEMENT: win32more.Windows.Win32.Foundation.HRESULT = -2143310920
SL_REMAPPING_MDOLLAR_OSR_GENERIC_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2143310919
SL_REMAPPING_MDOLLAR_OSR_NO_ASSOCIATION: win32more.Windows.Win32.Foundation.HRESULT = -2143310918
SL_REMAPPING_MDOLLAR_OSR_NOT_ADMIN: win32more.Windows.Win32.Foundation.HRESULT = -2143310917
SL_REMAPPING_MDOLLAR_OSR_USER_THROTTLED: win32more.Windows.Win32.Foundation.HRESULT = -2143310916
SL_REMAPPING_MDOLLAR_OSR_LICENSE_THROTTLED: win32more.Windows.Win32.Foundation.HRESULT = -2143310915
SL_REMAPPING_MDOLLAR_OSR_DEVICE_THROTTLED: win32more.Windows.Win32.Foundation.HRESULT = -2143310914
SL_REMAPPING_MDOLLAR_OSR_GP_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2143310913
SL_REMAPPING_MDOLLAR_OSR_HARDWARE_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2143310912
SL_REMAPPING_MDOLLAR_OSR_USER_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2143310911
SL_REMAPPING_MDOLLAR_OSR_LICENSE_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2143310910
SL_REMAPPING_MDOLLAR_OSR_DEVICE_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2143310909
WINDOWS_SLID: Guid = Guid('{55c92734-d682-4d71-983e-d6ec3f16059f}')
WDIGEST_SP_NAME_A: String = 'WDigest'
WDIGEST_SP_NAME_W: String = 'WDigest'
WDIGEST_SP_NAME: String = 'WDigest'
@winfunctype('ADVAPI32.dll', entry_point='SystemFunction036')
def RtlGenRandom(RandomBuffer: VoidPtr, RandomBufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll', entry_point='SystemFunction040')
def RtlEncryptMemory(Memory: VoidPtr, MemorySize: UInt32, OptionFlags: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll', entry_point='SystemFunction041')
def RtlDecryptMemory(Memory: VoidPtr, MemorySize: UInt32, OptionFlags: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('SECUR32.dll')
def LsaRegisterLogonProcess(LogonProcessName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_STRING), LsaHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE), SecurityMode: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('SECUR32.dll')
def LsaLogonUser(LsaHandle: win32more.Windows.Win32.Foundation.HANDLE, OriginName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_STRING), LogonType: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_LOGON_TYPE, AuthenticationPackage: UInt32, AuthenticationInformation: VoidPtr, AuthenticationInformationLength: UInt32, LocalGroups: POINTER(win32more.Windows.Win32.Security.TOKEN_GROUPS), SourceContext: POINTER(win32more.Windows.Win32.Security.TOKEN_SOURCE), ProfileBuffer: POINTER(VoidPtr), ProfileBufferLength: POINTER(UInt32), LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), Token: POINTER(win32more.Windows.Win32.Foundation.HANDLE), Quotas: POINTER(win32more.Windows.Win32.Security.QUOTA_LIMITS), SubStatus: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('SECUR32.dll')
def LsaLookupAuthenticationPackage(LsaHandle: win32more.Windows.Win32.Foundation.HANDLE, PackageName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_STRING), AuthenticationPackage: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('SECUR32.dll')
def LsaFreeReturnBuffer(Buffer: VoidPtr) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('SECUR32.dll')
def LsaCallAuthenticationPackage(LsaHandle: win32more.Windows.Win32.Foundation.HANDLE, AuthenticationPackage: UInt32, ProtocolSubmitBuffer: VoidPtr, SubmitBufferLength: UInt32, ProtocolReturnBuffer: POINTER(VoidPtr), ReturnBufferLength: POINTER(UInt32), ProtocolStatus: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('SECUR32.dll')
def LsaDeregisterLogonProcess(LsaHandle: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('SECUR32.dll')
def LsaConnectUntrusted(LsaHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaFreeMemory(Buffer: VoidPtr) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaClose(ObjectHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('SECUR32.dll')
def LsaEnumerateLogonSessions(LogonSessionCount: POINTER(UInt32), LogonSessionList: POINTER(POINTER(win32more.Windows.Win32.Foundation.LUID))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('SECUR32.dll')
def LsaGetLogonSessionData(LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), ppLogonSessionData: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_LOGON_SESSION_DATA))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaOpenPolicy(SystemName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), ObjectAttributes: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_OBJECT_ATTRIBUTES), DesiredAccess: UInt32, PolicyHandle: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaSetCAPs(CAPDNs: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), CAPDNCount: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaGetAppliedCAPIDs(SystemName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), CAPIDs: POINTER(POINTER(win32more.Windows.Win32.Security.PSID)), CAPIDCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaQueryCAPs(CAPIDs: POINTER(win32more.Windows.Win32.Security.PSID), CAPIDCount: UInt32, CAPs: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.CENTRAL_ACCESS_POLICY)), CAPCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaQueryInformationPolicy(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, InformationClass: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS, Buffer: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaSetInformationPolicy(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, InformationClass: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS, Buffer: VoidPtr) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaQueryDomainInformationPolicy(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, InformationClass: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_DOMAIN_INFORMATION_CLASS, Buffer: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaSetDomainInformationPolicy(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, InformationClass: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_DOMAIN_INFORMATION_CLASS, Buffer: VoidPtr) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('SECUR32.dll')
def LsaRegisterPolicyChangeNotification(InformationClass: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_NOTIFICATION_INFORMATION_CLASS, NotificationEventHandle: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('SECUR32.dll')
def LsaUnregisterPolicyChangeNotification(InformationClass: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_NOTIFICATION_INFORMATION_CLASS, NotificationEventHandle: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaEnumerateTrustedDomains(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, EnumerationContext: POINTER(UInt32), Buffer: POINTER(VoidPtr), PreferedMaximumLength: UInt32, CountReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaLookupNames(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, Count: UInt32, Names: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), ReferencedDomains: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_REFERENCED_DOMAIN_LIST)), Sids: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_TRANSLATED_SID))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaLookupNames2(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, Flags: UInt32, Count: UInt32, Names: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), ReferencedDomains: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_REFERENCED_DOMAIN_LIST)), Sids: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_TRANSLATED_SID2))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaLookupSids(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, Count: UInt32, Sids: POINTER(win32more.Windows.Win32.Security.PSID), ReferencedDomains: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_REFERENCED_DOMAIN_LIST)), Names: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_TRANSLATED_NAME))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaLookupSids2(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, LookupOptions: UInt32, Count: UInt32, Sids: POINTER(win32more.Windows.Win32.Security.PSID), ReferencedDomains: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_REFERENCED_DOMAIN_LIST)), Names: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_TRANSLATED_NAME))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaEnumerateAccountsWithUserRight(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, UserRight: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), Buffer: POINTER(VoidPtr), CountReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaEnumerateAccountRights(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, AccountSid: win32more.Windows.Win32.Security.PSID, UserRights: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)), CountOfRights: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaAddAccountRights(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, AccountSid: win32more.Windows.Win32.Security.PSID, UserRights: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), CountOfRights: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaRemoveAccountRights(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, AccountSid: win32more.Windows.Win32.Security.PSID, AllRights: win32more.Windows.Win32.Foundation.BOOLEAN, UserRights: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), CountOfRights: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaOpenTrustedDomainByName(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, TrustedDomainName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), DesiredAccess: UInt32, TrustedDomainHandle: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaQueryTrustedDomainInfo(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, TrustedDomainSid: win32more.Windows.Win32.Security.PSID, InformationClass: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS, Buffer: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaSetTrustedDomainInformation(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, TrustedDomainSid: win32more.Windows.Win32.Security.PSID, InformationClass: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS, Buffer: VoidPtr) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaDeleteTrustedDomain(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, TrustedDomainSid: win32more.Windows.Win32.Security.PSID) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaQueryTrustedDomainInfoByName(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, TrustedDomainName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), InformationClass: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS, Buffer: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaSetTrustedDomainInfoByName(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, TrustedDomainName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), InformationClass: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS, Buffer: VoidPtr) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaEnumerateTrustedDomainsEx(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, EnumerationContext: POINTER(UInt32), Buffer: POINTER(VoidPtr), PreferedMaximumLength: UInt32, CountReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaCreateTrustedDomainEx(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, TrustedDomainInformation: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_INFORMATION_EX), AuthenticationInformation: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_AUTH_INFORMATION), DesiredAccess: UInt32, TrustedDomainHandle: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaQueryForestTrustInformation(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, TrustedDomainName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), ForestTrustInfo: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_INFORMATION))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaSetForestTrustInformation(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, TrustedDomainName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), ForestTrustInfo: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_INFORMATION), CheckOnly: win32more.Windows.Win32.Foundation.BOOLEAN, CollisionInfo: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_COLLISION_INFORMATION))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaStorePrivateData(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, KeyName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), PrivateData: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaRetrievePrivateData(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, KeyName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), PrivateData: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaNtStatusToWinError(Status: win32more.Windows.Win32.Foundation.NTSTATUS) -> UInt32: ...
@winfunctype('ADVAPI32.dll')
def LsaQueryForestTrustInformation2(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, TrustedDomainName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), HighestRecordType: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_RECORD_TYPE, ForestTrustInfo: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_INFORMATION2))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def LsaSetForestTrustInformation2(PolicyHandle: win32more.Windows.Win32.Security.Authentication.Identity.LSA_HANDLE, TrustedDomainName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), HighestRecordType: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_RECORD_TYPE, ForestTrustInfo: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_INFORMATION2), CheckOnly: win32more.Windows.Win32.Foundation.BOOLEAN, CollisionInfo: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_COLLISION_INFORMATION))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('ADVAPI32.dll')
def AuditSetSystemPolicy(pAuditPolicy: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.AUDIT_POLICY_INFORMATION), dwPolicyCount: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll')
def AuditSetPerUserPolicy(pSid: win32more.Windows.Win32.Security.PSID, pAuditPolicy: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.AUDIT_POLICY_INFORMATION), dwPolicyCount: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll')
def AuditQuerySystemPolicy(pSubCategoryGuids: POINTER(Guid), dwPolicyCount: UInt32, ppAuditPolicy: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.AUDIT_POLICY_INFORMATION))) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll')
def AuditQueryPerUserPolicy(pSid: win32more.Windows.Win32.Security.PSID, pSubCategoryGuids: POINTER(Guid), dwPolicyCount: UInt32, ppAuditPolicy: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.AUDIT_POLICY_INFORMATION))) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll')
def AuditEnumeratePerUserPolicy(ppAuditSidArray: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.POLICY_AUDIT_SID_ARRAY))) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll')
def AuditComputeEffectivePolicyBySid(pSid: win32more.Windows.Win32.Security.PSID, pSubCategoryGuids: POINTER(Guid), dwPolicyCount: UInt32, ppAuditPolicy: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.AUDIT_POLICY_INFORMATION))) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll')
def AuditComputeEffectivePolicyByToken(hTokenHandle: win32more.Windows.Win32.Foundation.HANDLE, pSubCategoryGuids: POINTER(Guid), dwPolicyCount: UInt32, ppAuditPolicy: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.AUDIT_POLICY_INFORMATION))) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll')
def AuditEnumerateCategories(ppAuditCategoriesArray: POINTER(POINTER(Guid)), pdwCountReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll')
def AuditEnumerateSubCategories(pAuditCategoryGuid: POINTER(Guid), bRetrieveAllSubCategories: win32more.Windows.Win32.Foundation.BOOLEAN, ppAuditSubCategoriesArray: POINTER(POINTER(Guid)), pdwCountReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll')
def AuditLookupCategoryNameW(pAuditCategoryGuid: POINTER(Guid), ppszCategoryName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
AuditLookupCategoryName = UnicodeAlias('AuditLookupCategoryNameW')
@winfunctype('ADVAPI32.dll')
def AuditLookupCategoryNameA(pAuditCategoryGuid: POINTER(Guid), ppszCategoryName: POINTER(win32more.Windows.Win32.Foundation.PSTR)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll')
def AuditLookupSubCategoryNameW(pAuditSubCategoryGuid: POINTER(Guid), ppszSubCategoryName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
AuditLookupSubCategoryName = UnicodeAlias('AuditLookupSubCategoryNameW')
@winfunctype('ADVAPI32.dll')
def AuditLookupSubCategoryNameA(pAuditSubCategoryGuid: POINTER(Guid), ppszSubCategoryName: POINTER(win32more.Windows.Win32.Foundation.PSTR)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll')
def AuditLookupCategoryIdFromCategoryGuid(pAuditCategoryGuid: POINTER(Guid), pAuditCategoryId: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.POLICY_AUDIT_EVENT_TYPE)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll')
def AuditLookupCategoryGuidFromCategoryId(AuditCategoryId: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_AUDIT_EVENT_TYPE, pAuditCategoryGuid: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll')
def AuditSetSecurity(SecurityInformation: win32more.Windows.Win32.Security.OBJECT_SECURITY_INFORMATION, pSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll')
def AuditQuerySecurity(SecurityInformation: win32more.Windows.Win32.Security.OBJECT_SECURITY_INFORMATION, ppSecurityDescriptor: POINTER(win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll')
def AuditSetGlobalSaclW(ObjectTypeName: win32more.Windows.Win32.Foundation.PWSTR, Acl: POINTER(win32more.Windows.Win32.Security.ACL)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
AuditSetGlobalSacl = UnicodeAlias('AuditSetGlobalSaclW')
@winfunctype('ADVAPI32.dll')
def AuditSetGlobalSaclA(ObjectTypeName: win32more.Windows.Win32.Foundation.PSTR, Acl: POINTER(win32more.Windows.Win32.Security.ACL)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll')
def AuditQueryGlobalSaclW(ObjectTypeName: win32more.Windows.Win32.Foundation.PWSTR, Acl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL))) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
AuditQueryGlobalSacl = UnicodeAlias('AuditQueryGlobalSaclW')
@winfunctype('ADVAPI32.dll')
def AuditQueryGlobalSaclA(ObjectTypeName: win32more.Windows.Win32.Foundation.PSTR, Acl: POINTER(POINTER(win32more.Windows.Win32.Security.ACL))) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('ADVAPI32.dll')
def AuditFree(Buffer: VoidPtr) -> Void: ...
@winfunctype('SECUR32.dll')
def AcquireCredentialsHandleW(pszPrincipal: win32more.Windows.Win32.Foundation.PWSTR, pszPackage: win32more.Windows.Win32.Foundation.PWSTR, fCredentialUse: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CRED, pvLogonId: VoidPtr, pAuthData: VoidPtr, pGetKeyFn: win32more.Windows.Win32.Security.Authentication.Identity.SEC_GET_KEY_FN, pvGetKeyArgument: VoidPtr, phCredential: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), ptsExpiry: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
AcquireCredentialsHandle = UnicodeAlias('AcquireCredentialsHandleW')
@winfunctype('SECUR32.dll')
def AcquireCredentialsHandleA(pszPrincipal: win32more.Windows.Win32.Foundation.PSTR, pszPackage: win32more.Windows.Win32.Foundation.PSTR, fCredentialUse: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CRED, pvLogonId: VoidPtr, pAuthData: VoidPtr, pGetKeyFn: win32more.Windows.Win32.Security.Authentication.Identity.SEC_GET_KEY_FN, pvGetKeyArgument: VoidPtr, phCredential: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), ptsExpiry: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def FreeCredentialsHandle(phCredential: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def AddCredentialsW(hCredentials: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pszPrincipal: win32more.Windows.Win32.Foundation.PWSTR, pszPackage: win32more.Windows.Win32.Foundation.PWSTR, fCredentialUse: UInt32, pAuthData: VoidPtr, pGetKeyFn: win32more.Windows.Win32.Security.Authentication.Identity.SEC_GET_KEY_FN, pvGetKeyArgument: VoidPtr, ptsExpiry: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
AddCredentials = UnicodeAlias('AddCredentialsW')
@winfunctype('SECUR32.dll')
def AddCredentialsA(hCredentials: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pszPrincipal: win32more.Windows.Win32.Foundation.PSTR, pszPackage: win32more.Windows.Win32.Foundation.PSTR, fCredentialUse: UInt32, pAuthData: VoidPtr, pGetKeyFn: win32more.Windows.Win32.Security.Authentication.Identity.SEC_GET_KEY_FN, pvGetKeyArgument: VoidPtr, ptsExpiry: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def ChangeAccountPasswordW(pszPackageName: POINTER(UInt16), pszDomainName: POINTER(UInt16), pszAccountName: POINTER(UInt16), pszOldPassword: POINTER(UInt16), pszNewPassword: POINTER(UInt16), bImpersonating: win32more.Windows.Win32.Foundation.BOOLEAN, dwReserved: UInt32, pOutput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
ChangeAccountPassword = UnicodeAlias('ChangeAccountPasswordW')
@winfunctype('SECUR32.dll')
def ChangeAccountPasswordA(pszPackageName: POINTER(SByte), pszDomainName: POINTER(SByte), pszAccountName: POINTER(SByte), pszOldPassword: POINTER(SByte), pszNewPassword: POINTER(SByte), bImpersonating: win32more.Windows.Win32.Foundation.BOOLEAN, dwReserved: UInt32, pOutput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def InitializeSecurityContextW(phCredential: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pszTargetName: POINTER(UInt16), fContextReq: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS, Reserved1: UInt32, TargetDataRep: UInt32, pInput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), Reserved2: UInt32, phNewContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pOutput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), pfContextAttr: POINTER(UInt32), ptsExpiry: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
InitializeSecurityContext = UnicodeAlias('InitializeSecurityContextW')
@winfunctype('SECUR32.dll')
def InitializeSecurityContextA(phCredential: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pszTargetName: POINTER(SByte), fContextReq: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS, Reserved1: UInt32, TargetDataRep: UInt32, pInput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), Reserved2: UInt32, phNewContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pOutput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), pfContextAttr: POINTER(UInt32), ptsExpiry: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def AcceptSecurityContext(phCredential: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pInput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), fContextReq: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS, TargetDataRep: UInt32, phNewContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pOutput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), pfContextAttr: POINTER(UInt32), ptsExpiry: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def CompleteAuthToken(phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pToken: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def ImpersonateSecurityContext(phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def RevertSecurityContext(phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def QuerySecurityContextToken(phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), Token: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def DeleteSecurityContext(phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def ApplyControlToken(phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pInput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def QueryContextAttributesW(phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), ulAttribute: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR, pBuffer: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
QueryContextAttributes = UnicodeAlias('QueryContextAttributesW')
@winfunctype('SspiCli.dll')
def QueryContextAttributesExW(phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), ulAttribute: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR, pBuffer: VoidPtr, cbBuffer: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
QueryContextAttributesEx = UnicodeAlias('QueryContextAttributesExW')
@winfunctype('SECUR32.dll')
def QueryContextAttributesA(phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), ulAttribute: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR, pBuffer: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SspiCli.dll')
def QueryContextAttributesExA(phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), ulAttribute: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR, pBuffer: VoidPtr, cbBuffer: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SetContextAttributesW(phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), ulAttribute: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR, pBuffer: VoidPtr, cbBuffer: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
SetContextAttributes = UnicodeAlias('SetContextAttributesW')
@winfunctype('SECUR32.dll')
def SetContextAttributesA(phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), ulAttribute: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR, pBuffer: VoidPtr, cbBuffer: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def QueryCredentialsAttributesW(phCredential: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), ulAttribute: UInt32, pBuffer: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
QueryCredentialsAttributes = UnicodeAlias('QueryCredentialsAttributesW')
@winfunctype('SspiCli.dll')
def QueryCredentialsAttributesExW(phCredential: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), ulAttribute: UInt32, pBuffer: VoidPtr, cbBuffer: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
QueryCredentialsAttributesEx = UnicodeAlias('QueryCredentialsAttributesExW')
@winfunctype('SECUR32.dll')
def QueryCredentialsAttributesA(phCredential: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), ulAttribute: UInt32, pBuffer: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SspiCli.dll')
def QueryCredentialsAttributesExA(phCredential: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), ulAttribute: UInt32, pBuffer: VoidPtr, cbBuffer: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SetCredentialsAttributesW(phCredential: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), ulAttribute: UInt32, pBuffer: VoidPtr, cbBuffer: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
SetCredentialsAttributes = UnicodeAlias('SetCredentialsAttributesW')
@winfunctype('SECUR32.dll')
def SetCredentialsAttributesA(phCredential: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), ulAttribute: UInt32, pBuffer: VoidPtr, cbBuffer: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def FreeContextBuffer(pvContextBuffer: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def MakeSignature(phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), fQOP: UInt32, pMessage: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), MessageSeqNo: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def VerifySignature(phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pMessage: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), MessageSeqNo: UInt32, pfQOP: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def EncryptMessage(phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), fQOP: UInt32, pMessage: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), MessageSeqNo: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def DecryptMessage(phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pMessage: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), MessageSeqNo: UInt32, pfQOP: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def EnumerateSecurityPackagesW(pcPackages: POINTER(UInt32), ppPackageInfo: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgInfoW))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
EnumerateSecurityPackages = UnicodeAlias('EnumerateSecurityPackagesW')
@winfunctype('SECUR32.dll')
def EnumerateSecurityPackagesA(pcPackages: POINTER(UInt32), ppPackageInfo: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgInfoA))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def QuerySecurityPackageInfoW(pszPackageName: win32more.Windows.Win32.Foundation.PWSTR, ppPackageInfo: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgInfoW))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
QuerySecurityPackageInfo = UnicodeAlias('QuerySecurityPackageInfoW')
@winfunctype('SECUR32.dll')
def QuerySecurityPackageInfoA(pszPackageName: win32more.Windows.Win32.Foundation.PSTR, ppPackageInfo: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgInfoA))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def ExportSecurityContext(phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), fFlags: win32more.Windows.Win32.Security.Authentication.Identity.EXPORT_SECURITY_CONTEXT_FLAGS, pPackedContext: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer), pToken: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def ImportSecurityContextW(pszPackage: win32more.Windows.Win32.Foundation.PWSTR, pPackedContext: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer), Token: VoidPtr, phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
ImportSecurityContext = UnicodeAlias('ImportSecurityContextW')
@winfunctype('SECUR32.dll')
def ImportSecurityContextA(pszPackage: win32more.Windows.Win32.Foundation.PSTR, pPackedContext: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer), Token: VoidPtr, phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def InitSecurityInterfaceA() -> POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecurityFunctionTableA): ...
@winfunctype('SECUR32.dll')
def InitSecurityInterfaceW() -> POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecurityFunctionTableW): ...
InitSecurityInterface = UnicodeAlias('InitSecurityInterfaceW')
@winfunctype('SECUR32.dll')
def SaslEnumerateProfilesA(ProfileList: POINTER(win32more.Windows.Win32.Foundation.PSTR), ProfileCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SaslEnumerateProfilesW(ProfileList: POINTER(win32more.Windows.Win32.Foundation.PWSTR), ProfileCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
SaslEnumerateProfiles = UnicodeAlias('SaslEnumerateProfilesW')
@winfunctype('SECUR32.dll')
def SaslGetProfilePackageA(ProfileName: win32more.Windows.Win32.Foundation.PSTR, PackageInfo: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgInfoA))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SaslGetProfilePackageW(ProfileName: win32more.Windows.Win32.Foundation.PWSTR, PackageInfo: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgInfoW))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
SaslGetProfilePackage = UnicodeAlias('SaslGetProfilePackageW')
@winfunctype('SECUR32.dll')
def SaslIdentifyPackageA(pInput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), PackageInfo: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgInfoA))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SaslIdentifyPackageW(pInput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), PackageInfo: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgInfoW))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
SaslIdentifyPackage = UnicodeAlias('SaslIdentifyPackageW')
@winfunctype('SECUR32.dll')
def SaslInitializeSecurityContextW(phCredential: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pszTargetName: win32more.Windows.Win32.Foundation.PWSTR, fContextReq: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS, Reserved1: UInt32, TargetDataRep: UInt32, pInput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), Reserved2: UInt32, phNewContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pOutput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), pfContextAttr: POINTER(UInt32), ptsExpiry: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
SaslInitializeSecurityContext = UnicodeAlias('SaslInitializeSecurityContextW')
@winfunctype('SECUR32.dll')
def SaslInitializeSecurityContextA(phCredential: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pszTargetName: win32more.Windows.Win32.Foundation.PSTR, fContextReq: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS, Reserved1: UInt32, TargetDataRep: UInt32, pInput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), Reserved2: UInt32, phNewContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pOutput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), pfContextAttr: POINTER(UInt32), ptsExpiry: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SaslAcceptSecurityContext(phCredential: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), phContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pInput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), fContextReq: win32more.Windows.Win32.Security.Authentication.Identity.ASC_REQ_FLAGS, TargetDataRep: UInt32, phNewContext: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), pOutput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), pfContextAttr: POINTER(UInt32), ptsExpiry: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SaslSetContextOption(ContextHandle: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), Option: UInt32, Value: VoidPtr, Size: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SaslGetContextOption(ContextHandle: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), Option: UInt32, Value: VoidPtr, Size: UInt32, Needed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('credui.dll')
def SspiPromptForCredentialsW(pszTargetName: win32more.Windows.Win32.Foundation.PWSTR, pUiInfo: VoidPtr, dwAuthError: UInt32, pszPackage: win32more.Windows.Win32.Foundation.PWSTR, pInputAuthIdentity: VoidPtr, ppAuthIdentity: POINTER(VoidPtr), pfSave: POINTER(Int32), dwFlags: UInt32) -> UInt32: ...
SspiPromptForCredentials = UnicodeAlias('SspiPromptForCredentialsW')
@winfunctype('credui.dll')
def SspiPromptForCredentialsA(pszTargetName: win32more.Windows.Win32.Foundation.PSTR, pUiInfo: VoidPtr, dwAuthError: UInt32, pszPackage: win32more.Windows.Win32.Foundation.PSTR, pInputAuthIdentity: VoidPtr, ppAuthIdentity: POINTER(VoidPtr), pfSave: POINTER(Int32), dwFlags: UInt32) -> UInt32: ...
@winfunctype('SECUR32.dll')
def SspiPrepareForCredRead(AuthIdentity: VoidPtr, pszTargetName: win32more.Windows.Win32.Foundation.PWSTR, pCredmanCredentialType: POINTER(UInt32), ppszCredmanTargetName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SspiPrepareForCredWrite(AuthIdentity: VoidPtr, pszTargetName: win32more.Windows.Win32.Foundation.PWSTR, pCredmanCredentialType: POINTER(UInt32), ppszCredmanTargetName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), ppszCredmanUserName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), ppCredentialBlob: POINTER(POINTER(Byte)), pCredentialBlobSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SspiEncryptAuthIdentity(AuthData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SspiCli.dll')
def SspiEncryptAuthIdentityEx(Options: UInt32, AuthData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SspiDecryptAuthIdentity(EncryptedAuthData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SspiCli.dll')
def SspiDecryptAuthIdentityEx(Options: UInt32, EncryptedAuthData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SspiIsAuthIdentityEncrypted(EncryptedAuthData: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('SECUR32.dll')
def SspiEncodeAuthIdentityAsStrings(pAuthIdentity: VoidPtr, ppszUserName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), ppszDomainName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), ppszPackedCredentialsString: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SspiValidateAuthIdentity(AuthData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SspiCopyAuthIdentity(AuthData: VoidPtr, AuthDataCopy: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SspiFreeAuthIdentity(AuthData: VoidPtr) -> Void: ...
@winfunctype('SECUR32.dll')
def SspiZeroAuthIdentity(AuthData: VoidPtr) -> Void: ...
@winfunctype('SECUR32.dll')
def SspiLocalFree(DataBuffer: VoidPtr) -> Void: ...
@winfunctype('SECUR32.dll')
def SspiEncodeStringsAsAuthIdentity(pszUserName: win32more.Windows.Win32.Foundation.PWSTR, pszDomainName: win32more.Windows.Win32.Foundation.PWSTR, pszPackedCredentialsString: win32more.Windows.Win32.Foundation.PWSTR, ppAuthIdentity: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SspiCompareAuthIdentities(AuthIdentity1: VoidPtr, AuthIdentity2: VoidPtr, SameSuppliedUser: POINTER(win32more.Windows.Win32.Foundation.BOOLEAN), SameSuppliedIdentity: POINTER(win32more.Windows.Win32.Foundation.BOOLEAN)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SspiMarshalAuthIdentity(AuthIdentity: VoidPtr, AuthIdentityLength: POINTER(UInt32), AuthIdentityByteArray: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SspiUnmarshalAuthIdentity(AuthIdentityLength: UInt32, AuthIdentityByteArray: win32more.Windows.Win32.Foundation.PSTR, ppAuthIdentity: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('credui.dll')
def SspiIsPromptingNeeded(ErrorOrNtStatus: UInt32) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('SECUR32.dll')
def SspiGetTargetHostName(pszTargetName: win32more.Windows.Win32.Foundation.PWSTR, pszHostName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def SspiExcludePackage(AuthIdentity: VoidPtr, pszPackageName: win32more.Windows.Win32.Foundation.PWSTR, ppNewAuthIdentity: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SspiCli.dll')
def SspiSetChannelBindingFlags(pBindings: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgContext_Bindings), flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def AddSecurityPackageA(pszPackageName: win32more.Windows.Win32.Foundation.PSTR, pOptions: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_PACKAGE_OPTIONS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def AddSecurityPackageW(pszPackageName: win32more.Windows.Win32.Foundation.PWSTR, pOptions: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_PACKAGE_OPTIONS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
AddSecurityPackage = UnicodeAlias('AddSecurityPackageW')
@winfunctype('SECUR32.dll')
def DeleteSecurityPackageA(pszPackageName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def DeleteSecurityPackageW(pszPackageName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
DeleteSecurityPackage = UnicodeAlias('DeleteSecurityPackageW')
@winfunctype('SECUR32.dll')
def CredMarshalTargetInfo(InTargetInfo: POINTER(win32more.Windows.Win32.Security.Credentials.CREDENTIAL_TARGET_INFORMATIONW), Buffer: POINTER(POINTER(UInt16)), BufferSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('SECUR32.dll')
def CredUnmarshalTargetInfo(Buffer: POINTER(UInt16), BufferSize: UInt32, RetTargetInfo: POINTER(POINTER(win32more.Windows.Win32.Security.Credentials.CREDENTIAL_TARGET_INFORMATIONW)), RetActualSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype('SCHANNEL.dll')
def SslEmptyCacheA(pszTargetName: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SCHANNEL.dll')
def SslEmptyCacheW(pszTargetName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
SslEmptyCache = UnicodeAlias('SslEmptyCacheW')
@winfunctype('SCHANNEL.dll')
def SslGenerateRandomBits(pRandomData: POINTER(Byte), cRandomData: Int32) -> Void: ...
@winfunctype('SCHANNEL.dll')
def SslCrackCertificate(pbCertificate: POINTER(Byte), cbCertificate: UInt32, dwFlags: UInt32, ppCertificate: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.X509Certificate))) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('SCHANNEL.dll')
def SslFreeCertificate(pCertificate: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.X509Certificate)) -> Void: ...
@winfunctype('SCHANNEL.dll')
def SslGetMaximumKeySize(Reserved: UInt32) -> UInt32: ...
@winfunctype('SCHANNEL.dll')
def SslGetServerIdentity(ClientHello: POINTER(Byte), ClientHelloSize: UInt32, ServerIdentity: POINTER(POINTER(Byte)), ServerIdentitySize: POINTER(UInt32), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SCHANNEL.dll')
def SslGetExtensions(clientHello: POINTER(Byte), clientHelloByteSize: UInt32, genericExtensions: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SCH_EXTENSION_DATA), genericExtensionsCount: Byte, bytesToRead: POINTER(UInt32), flags: win32more.Windows.Win32.Security.Authentication.Identity.SchGetExtensionsOptions) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SCHANNEL.dll')
def SslDeserializeCertificateStore(SerializedCertificateStore: win32more.Windows.Win32.Security.Cryptography.CRYPT_INTEGER_BLOB, ppCertContext: POINTER(POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_CONTEXT))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('TOKENBINDING.dll')
def TokenBindingGenerateBinding(keyType: win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_KEY_PARAMETERS_TYPE, targetURL: win32more.Windows.Win32.Foundation.PWSTR, bindingType: win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_TYPE, tlsEKM: VoidPtr, tlsEKMSize: UInt32, extensionFormat: win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_EXTENSION_FORMAT, extensionData: VoidPtr, tokenBinding: POINTER(VoidPtr), tokenBindingSize: POINTER(UInt32), resultData: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_RESULT_DATA))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('TOKENBINDING.dll')
def TokenBindingGenerateMessage(tokenBindings: POINTER(VoidPtr), tokenBindingsSize: POINTER(UInt32), tokenBindingsCount: UInt32, tokenBindingMessage: POINTER(VoidPtr), tokenBindingMessageSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('TOKENBINDING.dll')
def TokenBindingVerifyMessage(tokenBindingMessage: VoidPtr, tokenBindingMessageSize: UInt32, keyType: win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_KEY_PARAMETERS_TYPE, tlsEKM: VoidPtr, tlsEKMSize: UInt32, resultList: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_RESULT_LIST))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('TOKENBINDING.dll')
def TokenBindingGetKeyTypesClient(keyTypes: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_KEY_TYPES))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('TOKENBINDING.dll')
def TokenBindingGetKeyTypesServer(keyTypes: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_KEY_TYPES))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('TOKENBINDING.dll')
def TokenBindingDeleteBinding(targetURL: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('TOKENBINDING.dll')
def TokenBindingDeleteAllBindings() -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('TOKENBINDING.dll')
def TokenBindingGenerateID(keyType: win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_KEY_PARAMETERS_TYPE, publicKey: VoidPtr, publicKeySize: UInt32, resultData: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_RESULT_DATA))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('TOKENBINDING.dll')
def TokenBindingGenerateIDForUri(keyType: win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_KEY_PARAMETERS_TYPE, targetUri: win32more.Windows.Win32.Foundation.PWSTR, resultData: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_RESULT_DATA))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('TOKENBINDING.dll')
def TokenBindingGetHighestSupportedVersion(majorVersion: POINTER(Byte), minorVersion: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SECUR32.dll')
def GetUserNameExA(NameFormat: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT, lpNameBuffer: win32more.Windows.Win32.Foundation.PSTR, nSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('SECUR32.dll')
def GetUserNameExW(NameFormat: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT, lpNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, nSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
GetUserNameEx = UnicodeAlias('GetUserNameExW')
@winfunctype('SECUR32.dll')
def GetComputerObjectNameA(NameFormat: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT, lpNameBuffer: win32more.Windows.Win32.Foundation.PSTR, nSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('SECUR32.dll')
def GetComputerObjectNameW(NameFormat: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT, lpNameBuffer: win32more.Windows.Win32.Foundation.PWSTR, nSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
GetComputerObjectName = UnicodeAlias('GetComputerObjectNameW')
@winfunctype('SECUR32.dll')
def TranslateNameA(lpAccountName: win32more.Windows.Win32.Foundation.PSTR, AccountNameFormat: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT, DesiredNameFormat: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT, lpTranslatedName: win32more.Windows.Win32.Foundation.PSTR, nSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('SECUR32.dll')
def TranslateNameW(lpAccountName: win32more.Windows.Win32.Foundation.PWSTR, AccountNameFormat: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT, DesiredNameFormat: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT, lpTranslatedName: win32more.Windows.Win32.Foundation.PWSTR, nSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
TranslateName = UnicodeAlias('TranslateNameW')
@winfunctype('SLC.dll')
def SLOpen(phSLC: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLClose(hSLC: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLInstallProofOfPurchase(hSLC: VoidPtr, pwszPKeyAlgorithm: win32more.Windows.Win32.Foundation.PWSTR, pwszPKeyString: win32more.Windows.Win32.Foundation.PWSTR, cbPKeySpecificData: UInt32, pbPKeySpecificData: POINTER(Byte), pPkeyId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLUninstallProofOfPurchase(hSLC: VoidPtr, pPKeyId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLInstallLicense(hSLC: VoidPtr, cbLicenseBlob: UInt32, pbLicenseBlob: POINTER(Byte), pLicenseFileId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLUninstallLicense(hSLC: VoidPtr, pLicenseFileId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLConsumeRight(hSLC: VoidPtr, pAppId: POINTER(Guid), pProductSkuId: POINTER(Guid), pwszRightName: win32more.Windows.Win32.Foundation.PWSTR, pvReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGetProductSkuInformation(hSLC: VoidPtr, pProductSkuId: POINTER(Guid), pwszValueName: win32more.Windows.Win32.Foundation.PWSTR, peDataType: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SLDATATYPE), pcbValue: POINTER(UInt32), ppbValue: POINTER(POINTER(Byte))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGetPKeyInformation(hSLC: VoidPtr, pPKeyId: POINTER(Guid), pwszValueName: win32more.Windows.Win32.Foundation.PWSTR, peDataType: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SLDATATYPE), pcbValue: POINTER(UInt32), ppbValue: POINTER(POINTER(Byte))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGetLicenseInformation(hSLC: VoidPtr, pSLLicenseId: POINTER(Guid), pwszValueName: win32more.Windows.Win32.Foundation.PWSTR, peDataType: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SLDATATYPE), pcbValue: POINTER(UInt32), ppbValue: POINTER(POINTER(Byte))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGetLicensingStatusInformation(hSLC: VoidPtr, pAppID: POINTER(Guid), pProductSkuId: POINTER(Guid), pwszRightName: win32more.Windows.Win32.Foundation.PWSTR, pnStatusCount: POINTER(UInt32), ppLicensingStatus: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SL_LICENSING_STATUS))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGetPolicyInformation(hSLC: VoidPtr, pwszValueName: win32more.Windows.Win32.Foundation.PWSTR, peDataType: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SLDATATYPE), pcbValue: POINTER(UInt32), ppbValue: POINTER(POINTER(Byte))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGetPolicyInformationDWORD(hSLC: VoidPtr, pwszValueName: win32more.Windows.Win32.Foundation.PWSTR, pdwValue: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGetServiceInformation(hSLC: VoidPtr, pwszValueName: win32more.Windows.Win32.Foundation.PWSTR, peDataType: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SLDATATYPE), pcbValue: POINTER(UInt32), ppbValue: POINTER(POINTER(Byte))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGetApplicationInformation(hSLC: VoidPtr, pApplicationId: POINTER(Guid), pwszValueName: win32more.Windows.Win32.Foundation.PWSTR, peDataType: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SLDATATYPE), pcbValue: POINTER(UInt32), ppbValue: POINTER(POINTER(Byte))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('slcext.dll')
def SLActivateProduct(hSLC: VoidPtr, pProductSkuId: POINTER(Guid), cbAppSpecificData: UInt32, pvAppSpecificData: VoidPtr, pActivationInfo: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SL_ACTIVATION_INFO_HEADER), pwszProxyServer: win32more.Windows.Win32.Foundation.PWSTR, wProxyPort: UInt16) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('slcext.dll')
def SLGetServerStatus(pwszServerURL: win32more.Windows.Win32.Foundation.PWSTR, pwszAcquisitionType: win32more.Windows.Win32.Foundation.PWSTR, pwszProxyServer: win32more.Windows.Win32.Foundation.PWSTR, wProxyPort: UInt16, phrStatus: POINTER(win32more.Windows.Win32.Foundation.HRESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGenerateOfflineInstallationId(hSLC: VoidPtr, pProductSkuId: POINTER(Guid), ppwszInstallationId: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGenerateOfflineInstallationIdEx(hSLC: VoidPtr, pProductSkuId: POINTER(Guid), pActivationInfo: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SL_ACTIVATION_INFO_HEADER), ppwszInstallationId: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLDepositOfflineConfirmationId(hSLC: VoidPtr, pProductSkuId: POINTER(Guid), pwszInstallationId: win32more.Windows.Win32.Foundation.PWSTR, pwszConfirmationId: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLDepositOfflineConfirmationIdEx(hSLC: VoidPtr, pProductSkuId: POINTER(Guid), pActivationInfo: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SL_ACTIVATION_INFO_HEADER), pwszInstallationId: win32more.Windows.Win32.Foundation.PWSTR, pwszConfirmationId: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGetPKeyId(hSLC: VoidPtr, pwszPKeyAlgorithm: win32more.Windows.Win32.Foundation.PWSTR, pwszPKeyString: win32more.Windows.Win32.Foundation.PWSTR, cbPKeySpecificData: UInt32, pbPKeySpecificData: POINTER(Byte), pPKeyId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGetInstalledProductKeyIds(hSLC: VoidPtr, pProductSkuId: POINTER(Guid), pnProductKeyIds: POINTER(UInt32), ppProductKeyIds: POINTER(POINTER(Guid))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLSetCurrentProductKey(hSLC: VoidPtr, pProductSkuId: POINTER(Guid), pProductKeyId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGetSLIDList(hSLC: VoidPtr, eQueryIdType: win32more.Windows.Win32.Security.Authentication.Identity.SLIDTYPE, pQueryId: POINTER(Guid), eReturnIdType: win32more.Windows.Win32.Security.Authentication.Identity.SLIDTYPE, pnReturnIds: POINTER(UInt32), ppReturnIds: POINTER(POINTER(Guid))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGetLicenseFileId(hSLC: VoidPtr, cbLicenseBlob: UInt32, pbLicenseBlob: POINTER(Byte), pLicenseFileId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGetLicense(hSLC: VoidPtr, pLicenseFileId: POINTER(Guid), pcbLicenseFile: POINTER(UInt32), ppbLicenseFile: POINTER(POINTER(Byte))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLFireEvent(hSLC: VoidPtr, pwszEventId: win32more.Windows.Win32.Foundation.PWSTR, pApplicationId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLRegisterEvent(hSLC: VoidPtr, pwszEventId: win32more.Windows.Win32.Foundation.PWSTR, pApplicationId: POINTER(Guid), hEvent: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLUnregisterEvent(hSLC: VoidPtr, pwszEventId: win32more.Windows.Win32.Foundation.PWSTR, pApplicationId: POINTER(Guid), hEvent: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGetWindowsInformation(pwszValueName: win32more.Windows.Win32.Foundation.PWSTR, peDataType: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SLDATATYPE), pcbValue: POINTER(UInt32), ppbValue: POINTER(POINTER(Byte))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGetWindowsInformationDWORD(pwszValueName: win32more.Windows.Win32.Foundation.PWSTR, pdwValue: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLWGA.dll')
def SLIsGenuineLocal(pAppId: POINTER(Guid), pGenuineState: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SL_GENUINE_STATE), pUIOptions: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SL_NONGENUINE_UI_OPTIONS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('slcext.dll')
def SLAcquireGenuineTicket(ppTicketBlob: POINTER(VoidPtr), pcbTicketBlob: POINTER(UInt32), pwszTemplateId: win32more.Windows.Win32.Foundation.PWSTR, pwszServerUrl: win32more.Windows.Win32.Foundation.PWSTR, pwszClientToken: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLSetGenuineInformation(pQueryId: POINTER(Guid), pwszValueName: win32more.Windows.Win32.Foundation.PWSTR, eDataType: win32more.Windows.Win32.Security.Authentication.Identity.SLDATATYPE, cbValue: UInt32, pbValue: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('slcext.dll')
def SLGetReferralInformation(hSLC: VoidPtr, eReferralType: win32more.Windows.Win32.Security.Authentication.Identity.SLREFERRALTYPE, pSkuOrAppId: POINTER(Guid), pwszValueName: win32more.Windows.Win32.Foundation.PWSTR, ppwszValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SLC.dll')
def SLGetGenuineInformation(pQueryId: POINTER(Guid), pwszValueName: win32more.Windows.Win32.Foundation.PWSTR, peDataType: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SLDATATYPE), pcbValue: POINTER(UInt32), ppbValue: POINTER(POINTER(Byte))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-core-slapi-l1-1-0.dll')
def SLQueryLicenseValueFromApp(valueName: win32more.Windows.Win32.Foundation.PWSTR, valueType: POINTER(UInt32), dataBuffer: VoidPtr, dataSize: UInt32, resultDataSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('SAS.dll')
def SendSAS(AsUser: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
class CENTRAL_ACCESS_POLICY(Structure):
    CAPID: win32more.Windows.Win32.Security.PSID
    Name: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Description: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ChangeId: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Flags: UInt32
    CAPECount: UInt32
    CAPEs: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.CENTRAL_ACCESS_POLICY_ENTRY))
class CENTRAL_ACCESS_POLICY_ENTRY(Structure):
    Name: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Description: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ChangeId: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    LengthAppliesTo: UInt32
    AppliesTo: POINTER(Byte)
    LengthSD: UInt32
    SD: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR
    LengthStagedSD: UInt32
    StagedSD: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR
    Flags: UInt32
@winfunctype_pointer
def CHANGE_PASSWORD_FN_A(param0: POINTER(SByte), param1: POINTER(SByte), param2: POINTER(SByte), param3: POINTER(SByte), param4: POINTER(SByte), param5: win32more.Windows.Win32.Foundation.BOOLEAN, param6: UInt32, param7: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def CHANGE_PASSWORD_FN_W(param0: POINTER(UInt16), param1: POINTER(UInt16), param2: POINTER(UInt16), param3: POINTER(UInt16), param4: POINTER(UInt16), param5: win32more.Windows.Win32.Foundation.BOOLEAN, param6: UInt32, param7: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
CHANGE_PASSWORD_FN = UnicodeAlias('CHANGE_PASSWORD_FN_W')
class CLEAR_BLOCK(Structure):
    data: win32more.Windows.Win32.Foundation.CHAR * 8
@winfunctype_pointer
def COMPLETE_AUTH_TOKEN_FN(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
CRED_FETCH = Int32
CredFetchDefault: win32more.Windows.Win32.Security.Authentication.Identity.CRED_FETCH = 0
CredFetchDPAPI: win32more.Windows.Win32.Security.Authentication.Identity.CRED_FETCH = 1
CredFetchForced: win32more.Windows.Win32.Security.Authentication.Identity.CRED_FETCH = 2
class CRYPTO_SETTINGS(Structure):
    eAlgorithmUsage: win32more.Windows.Win32.Security.Authentication.Identity.eTlsAlgorithmUsage
    strCngAlgId: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    cChainingModes: UInt32
    rgstrChainingModes: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)
    dwMinBitLength: UInt32
    dwMaxBitLength: UInt32
@winfunctype_pointer
def CredFreeCredentialsFn(Count: UInt32, Credentials: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.ENCRYPTED_CREDENTIALW))) -> Void: ...
@winfunctype_pointer
def CredReadDomainCredentialsFn(LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), CredFlags: UInt32, TargetInfo: POINTER(win32more.Windows.Win32.Security.Credentials.CREDENTIAL_TARGET_INFORMATIONW), Flags: UInt32, Count: POINTER(UInt32), Credential: POINTER(POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.ENCRYPTED_CREDENTIALW)))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def CredReadFn(LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), CredFlags: UInt32, TargetName: win32more.Windows.Win32.Foundation.PWSTR, Type: UInt32, Flags: UInt32, Credential: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.ENCRYPTED_CREDENTIALW))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def CredWriteFn(LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), CredFlags: UInt32, Credential: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.ENCRYPTED_CREDENTIALW), Flags: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def CrediUnmarshalandDecodeStringFn(MarshaledString: win32more.Windows.Win32.Foundation.PWSTR, Blob: POINTER(POINTER(Byte)), BlobSize: POINTER(UInt32), IsFailureFatal: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def DECRYPT_MESSAGE_FN(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), param2: UInt32, param3: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def DELETE_SECURITY_CONTEXT_FN(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class DOMAIN_PASSWORD_INFORMATION(Structure):
    MinPasswordLength: UInt16
    PasswordHistoryLength: UInt16
    PasswordProperties: win32more.Windows.Win32.Security.Authentication.Identity.DOMAIN_PASSWORD_PROPERTIES
    MaxPasswordAge: Int64
    MinPasswordAge: Int64
DOMAIN_PASSWORD_PROPERTIES = UInt32
DOMAIN_PASSWORD_COMPLEX: win32more.Windows.Win32.Security.Authentication.Identity.DOMAIN_PASSWORD_PROPERTIES = 1
DOMAIN_PASSWORD_NO_ANON_CHANGE: win32more.Windows.Win32.Security.Authentication.Identity.DOMAIN_PASSWORD_PROPERTIES = 2
DOMAIN_PASSWORD_NO_CLEAR_CHANGE: win32more.Windows.Win32.Security.Authentication.Identity.DOMAIN_PASSWORD_PROPERTIES = 4
DOMAIN_LOCKOUT_ADMINS: win32more.Windows.Win32.Security.Authentication.Identity.DOMAIN_PASSWORD_PROPERTIES = 8
DOMAIN_PASSWORD_STORE_CLEARTEXT: win32more.Windows.Win32.Security.Authentication.Identity.DOMAIN_PASSWORD_PROPERTIES = 16
DOMAIN_REFUSE_PASSWORD_CHANGE: win32more.Windows.Win32.Security.Authentication.Identity.DOMAIN_PASSWORD_PROPERTIES = 32
class ENCRYPTED_CREDENTIALW(Structure):
    Cred: win32more.Windows.Win32.Security.Credentials.CREDENTIALW
    ClearCredentialBlobSize: UInt32
@winfunctype_pointer
def ENCRYPT_MESSAGE_FN(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: UInt32, param2: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def ENUMERATE_SECURITY_PACKAGES_FN_A(param0: POINTER(UInt32), param1: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgInfoA))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def ENUMERATE_SECURITY_PACKAGES_FN_W(param0: POINTER(UInt32), param1: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgInfoW))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
ENUMERATE_SECURITY_PACKAGES_FN = UnicodeAlias('ENUMERATE_SECURITY_PACKAGES_FN_W')
EXPORT_SECURITY_CONTEXT_FLAGS = UInt32
SECPKG_CONTEXT_EXPORT_RESET_NEW: win32more.Windows.Win32.Security.Authentication.Identity.EXPORT_SECURITY_CONTEXT_FLAGS = 1
SECPKG_CONTEXT_EXPORT_DELETE_OLD: win32more.Windows.Win32.Security.Authentication.Identity.EXPORT_SECURITY_CONTEXT_FLAGS = 2
SECPKG_CONTEXT_EXPORT_TO_KERNEL: win32more.Windows.Win32.Security.Authentication.Identity.EXPORT_SECURITY_CONTEXT_FLAGS = 4
@winfunctype_pointer
def EXPORT_SECURITY_CONTEXT_FN(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: UInt32, param2: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer), param3: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
EXTENDED_NAME_FORMAT = Int32
NameUnknown: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT = 0
NameFullyQualifiedDN: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT = 1
NameSamCompatible: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT = 2
NameDisplay: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT = 3
NameUniqueId: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT = 6
NameCanonical: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT = 7
NameUserPrincipal: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT = 8
NameCanonicalEx: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT = 9
NameServicePrincipal: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT = 10
NameDnsDomain: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT = 12
NameGivenName: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT = 13
NameSurname: win32more.Windows.Win32.Security.Authentication.Identity.EXTENDED_NAME_FORMAT = 14
@winfunctype_pointer
def FREE_CONTEXT_BUFFER_FN(param0: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def FREE_CREDENTIALS_HANDLE_FN(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICcgDomainAuthCredentials(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6ecda518-2010-4437-8bc3-46e752b7b172}')
    @commethod(3)
    def GetPasswordCredentials(self, pluginInput: win32more.Windows.Win32.Foundation.PWSTR, domainName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), username: POINTER(win32more.Windows.Win32.Foundation.PWSTR), password: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def IMPERSONATE_SECURITY_CONTEXT_FN(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def IMPORT_SECURITY_CONTEXT_FN_A(param0: POINTER(SByte), param1: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer), param2: VoidPtr, param3: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def IMPORT_SECURITY_CONTEXT_FN_W(param0: POINTER(UInt16), param1: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer), param2: VoidPtr, param3: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
IMPORT_SECURITY_CONTEXT_FN = UnicodeAlias('IMPORT_SECURITY_CONTEXT_FN_W')
@winfunctype_pointer
def INITIALIZE_SECURITY_CONTEXT_FN_A(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param2: POINTER(SByte), param3: UInt32, param4: UInt32, param5: UInt32, param6: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), param7: UInt32, param8: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param9: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), param10: POINTER(UInt32), param11: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def INITIALIZE_SECURITY_CONTEXT_FN_W(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param2: POINTER(UInt16), param3: UInt32, param4: UInt32, param5: UInt32, param6: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), param7: UInt32, param8: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param9: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), param10: POINTER(UInt32), param11: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
INITIALIZE_SECURITY_CONTEXT_FN = UnicodeAlias('INITIALIZE_SECURITY_CONTEXT_FN_W')
@winfunctype_pointer
def INIT_SECURITY_INTERFACE_A() -> POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecurityFunctionTableA): ...
@winfunctype_pointer
def INIT_SECURITY_INTERFACE_W() -> POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecurityFunctionTableW): ...
INIT_SECURITY_INTERFACE = UnicodeAlias('INIT_SECURITY_INTERFACE_W')
ISC_REQ_FLAGS = UInt32
ISC_REQ_DELEGATE: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 1
ISC_REQ_MUTUAL_AUTH: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 2
ISC_REQ_REPLAY_DETECT: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 4
ISC_REQ_SEQUENCE_DETECT: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 8
ISC_REQ_CONFIDENTIALITY: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 16
ISC_REQ_USE_SESSION_KEY: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 32
ISC_REQ_PROMPT_FOR_CREDS: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 64
ISC_REQ_USE_SUPPLIED_CREDS: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 128
ISC_REQ_ALLOCATE_MEMORY: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 256
ISC_REQ_USE_DCE_STYLE: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 512
ISC_REQ_DATAGRAM: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 1024
ISC_REQ_CONNECTION: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 2048
ISC_REQ_CALL_LEVEL: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 4096
ISC_REQ_FRAGMENT_SUPPLIED: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 8192
ISC_REQ_EXTENDED_ERROR: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 16384
ISC_REQ_STREAM: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 32768
ISC_REQ_INTEGRITY: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 65536
ISC_REQ_IDENTIFY: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 131072
ISC_REQ_NULL_SESSION: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 262144
ISC_REQ_MANUAL_CRED_VALIDATION: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 524288
ISC_REQ_RESERVED1: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 1048576
ISC_REQ_FRAGMENT_TO_FIT: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 2097152
ISC_REQ_FORWARD_CREDENTIALS: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 4194304
ISC_REQ_NO_INTEGRITY: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 8388608
ISC_REQ_USE_HTTP_STYLE: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 16777216
ISC_REQ_UNVERIFIED_TARGET_NAME: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 536870912
ISC_REQ_CONFIDENTIALITY_ONLY: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_FLAGS = 1073741824
ISC_REQ_HIGH_FLAGS = UInt64
ISC_REQ_MESSAGES: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_HIGH_FLAGS = 4294967296
ISC_REQ_DEFERRED_CRED_VALIDATION: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_HIGH_FLAGS = 8589934592
ISC_REQ_NO_POST_HANDSHAKE_AUTH: win32more.Windows.Win32.Security.Authentication.Identity.ISC_REQ_HIGH_FLAGS = 17179869184
class KDC_PROXY_CACHE_ENTRY_DATA(Structure):
    SinceLastUsed: UInt64
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ProxyServerName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ProxyServerVdir: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ProxyServerPort: UInt16
    LogonId: win32more.Windows.Win32.Foundation.LUID
    CredUserName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    CredDomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    GlobalCache: win32more.Windows.Win32.Foundation.BOOLEAN
KERB_ADDRESS_TYPE = UInt32
DS_INET_ADDRESS: win32more.Windows.Win32.Security.Authentication.Identity.KERB_ADDRESS_TYPE = 1
DS_NETBIOS_ADDRESS: win32more.Windows.Win32.Security.Authentication.Identity.KERB_ADDRESS_TYPE = 2
class KERB_ADD_BINDING_CACHE_ENTRY_EX_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    RealmName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    KdcAddress: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    AddressType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_ADDRESS_TYPE
    DcFlags: UInt32
class KERB_ADD_BINDING_CACHE_ENTRY_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    RealmName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    KdcAddress: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    AddressType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_ADDRESS_TYPE
class KERB_ADD_CREDENTIALS_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    UserName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Password: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    LogonId: win32more.Windows.Win32.Foundation.LUID
    Flags: win32more.Windows.Win32.Security.Authentication.Identity.KERB_REQUEST_FLAGS
class KERB_ADD_CREDENTIALS_REQUEST_EX(Structure):
    Credentials: win32more.Windows.Win32.Security.Authentication.Identity.KERB_ADD_CREDENTIALS_REQUEST
    PrincipalNameCount: UInt32
    PrincipalNames: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING * 1
class KERB_AUTH_DATA(Structure):
    Type: UInt32
    Length: UInt32
    Data: POINTER(Byte)
class KERB_BINDING_CACHE_ENTRY_DATA(Structure):
    DiscoveryTime: UInt64
    RealmName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    KdcAddress: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    AddressType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_ADDRESS_TYPE
    Flags: UInt32
    DcFlags: UInt32
    CacheFlags: UInt32
    KdcName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
class KERB_CERTIFICATE_HASHINFO(Structure):
    StoreNameLength: UInt16
    HashLength: UInt16
class KERB_CERTIFICATE_INFO(Structure):
    CertInfoSize: UInt32
    InfoType: UInt32
KERB_CERTIFICATE_INFO_TYPE = Int32
CertHashInfo: win32more.Windows.Win32.Security.Authentication.Identity.KERB_CERTIFICATE_INFO_TYPE = 1
class KERB_CERTIFICATE_LOGON(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    UserName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Pin: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Flags: UInt32
    CspDataLength: UInt32
    CspData: POINTER(Byte)
class KERB_CERTIFICATE_S4U_LOGON(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE
    Flags: UInt32
    UserPrincipalName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    CertificateLength: UInt32
    Certificate: POINTER(Byte)
class KERB_CERTIFICATE_UNLOCK_LOGON(Structure):
    Logon: win32more.Windows.Win32.Security.Authentication.Identity.KERB_CERTIFICATE_LOGON
    LogonId: win32more.Windows.Win32.Foundation.LUID
class KERB_CHANGEPASSWORD_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    AccountName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    OldPassword: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    NewPassword: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Impersonating: win32more.Windows.Win32.Foundation.BOOLEAN
class KERB_CLEANUP_MACHINE_PKINIT_CREDS_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    LogonId: win32more.Windows.Win32.Foundation.LUID
class KERB_CLOUD_KERBEROS_DEBUG_DATA(Structure):
    EnabledByPolicy: Annotated[UInt32, 1]
    AsRepCallbackPresent: Annotated[UInt32, 1]
    AsRepCallbackUsed: Annotated[UInt32, 1]
    CloudReferralTgtAvailable: Annotated[UInt32, 1]
    SpnOracleConfigured: Annotated[UInt32, 1]
    KdcProxyPresent: Annotated[UInt32, 1]
    PublicKeyCredsPresent: Annotated[UInt32, 1]
    PasswordKeysPresent: Annotated[UInt32, 1]
    PasswordPresent: Annotated[UInt32, 1]
    AsRepSourceCred: Annotated[UInt32, 8]
class KERB_CLOUD_KERBEROS_DEBUG_DATA_V0(Structure):
    EnabledByPolicy: Annotated[UInt32, 1]
    AsRepCallbackPresent: Annotated[UInt32, 1]
    AsRepCallbackUsed: Annotated[UInt32, 1]
    CloudReferralTgtAvailable: Annotated[UInt32, 1]
    SpnOracleConfigured: Annotated[UInt32, 1]
    KdcProxyPresent: Annotated[UInt32, 1]
class KERB_CLOUD_KERBEROS_DEBUG_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    LogonId: win32more.Windows.Win32.Foundation.LUID
class KERB_CLOUD_KERBEROS_DEBUG_RESPONSE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    Version: UInt32
    Length: UInt32
    Data: UInt32 * 1
class KERB_CRYPTO_KEY(Structure):
    KeyType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_CRYPTO_KEY_TYPE
    Length: UInt32
    Value: POINTER(Byte)
class KERB_CRYPTO_KEY32(Structure):
    KeyType: Int32
    Length: UInt32
    Offset: UInt32
KERB_CRYPTO_KEY_TYPE = Int32
KERB_ETYPE_DES_CBC_CRC: win32more.Windows.Win32.Security.Authentication.Identity.KERB_CRYPTO_KEY_TYPE = 1
KERB_ETYPE_DES_CBC_MD4: win32more.Windows.Win32.Security.Authentication.Identity.KERB_CRYPTO_KEY_TYPE = 2
KERB_ETYPE_DES_CBC_MD5: win32more.Windows.Win32.Security.Authentication.Identity.KERB_CRYPTO_KEY_TYPE = 3
KERB_ETYPE_NULL: win32more.Windows.Win32.Security.Authentication.Identity.KERB_CRYPTO_KEY_TYPE = 0
KERB_ETYPE_RC4_HMAC_NT: win32more.Windows.Win32.Security.Authentication.Identity.KERB_CRYPTO_KEY_TYPE = 23
KERB_ETYPE_RC4_MD4: win32more.Windows.Win32.Security.Authentication.Identity.KERB_CRYPTO_KEY_TYPE = -128
class KERB_DECRYPT_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    LogonId: win32more.Windows.Win32.Foundation.LUID
    Flags: UInt32
    CryptoType: Int32
    KeyUsage: Int32
    Key: win32more.Windows.Win32.Security.Authentication.Identity.KERB_CRYPTO_KEY
    EncryptedDataSize: UInt32
    InitialVectorSize: UInt32
    InitialVector: POINTER(Byte)
    EncryptedData: POINTER(Byte)
class KERB_DECRYPT_RESPONSE(Structure):
    DecryptedData: Byte * 1
class KERB_EXTERNAL_NAME(Structure):
    NameType: Int16
    NameCount: UInt16
    Names: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING * 1
class KERB_EXTERNAL_TICKET(Structure):
    ServiceName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.KERB_EXTERNAL_NAME)
    TargetName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.KERB_EXTERNAL_NAME)
    ClientName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.KERB_EXTERNAL_NAME)
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    TargetDomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    AltTargetDomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    SessionKey: win32more.Windows.Win32.Security.Authentication.Identity.KERB_CRYPTO_KEY
    TicketFlags: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_FLAGS
    Flags: UInt32
    KeyExpirationTime: Int64
    StartTime: Int64
    EndTime: Int64
    RenewUntil: Int64
    TimeSkew: Int64
    EncodedTicketSize: UInt32
    EncodedTicket: POINTER(Byte)
class KERB_INTERACTIVE_LOGON(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE
    LogonDomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    UserName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Password: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
class KERB_INTERACTIVE_PROFILE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROFILE_BUFFER_TYPE
    LogonCount: UInt16
    BadPasswordCount: UInt16
    LogonTime: Int64
    LogoffTime: Int64
    KickOffTime: Int64
    PasswordLastSet: Int64
    PasswordCanChange: Int64
    PasswordMustChange: Int64
    LogonScript: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    HomeDirectory: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    FullName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ProfilePath: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    HomeDirectoryDrive: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    LogonServer: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    UserFlags: UInt32
class KERB_INTERACTIVE_UNLOCK_LOGON(Structure):
    Logon: win32more.Windows.Win32.Security.Authentication.Identity.KERB_INTERACTIVE_LOGON
    LogonId: win32more.Windows.Win32.Foundation.LUID
KERB_LOGON_SUBMIT_TYPE = Int32
KerbInteractiveLogon: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE = 2
KerbSmartCardLogon: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE = 6
KerbWorkstationUnlockLogon: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE = 7
KerbSmartCardUnlockLogon: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE = 8
KerbProxyLogon: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE = 9
KerbTicketLogon: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE = 10
KerbTicketUnlockLogon: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE = 11
KerbS4ULogon: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE = 12
KerbCertificateLogon: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE = 13
KerbCertificateS4ULogon: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE = 14
KerbCertificateUnlockLogon: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE = 15
KerbNoElevationLogon: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE = 83
KerbLuidLogon: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE = 84
class KERB_NET_ADDRESS(Structure):
    Family: UInt32
    Length: UInt32
    Address: win32more.Windows.Win32.Foundation.PSTR
class KERB_NET_ADDRESSES(Structure):
    Number: UInt32
    Addresses: win32more.Windows.Win32.Security.Authentication.Identity.KERB_NET_ADDRESS * 1
KERB_PROFILE_BUFFER_TYPE = Int32
KerbInteractiveProfile: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROFILE_BUFFER_TYPE = 2
KerbSmartCardProfile: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROFILE_BUFFER_TYPE = 4
KerbTicketProfile: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROFILE_BUFFER_TYPE = 6
KERB_PROTOCOL_MESSAGE_TYPE = Int32
KerbDebugRequestMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 0
KerbQueryTicketCacheMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 1
KerbChangeMachinePasswordMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 2
KerbVerifyPacMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 3
KerbRetrieveTicketMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 4
KerbUpdateAddressesMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 5
KerbPurgeTicketCacheMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 6
KerbChangePasswordMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 7
KerbRetrieveEncodedTicketMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 8
KerbDecryptDataMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 9
KerbAddBindingCacheEntryMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 10
KerbSetPasswordMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 11
KerbSetPasswordExMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 12
KerbVerifyCredentialsMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 13
KerbQueryTicketCacheExMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 14
KerbPurgeTicketCacheExMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 15
KerbRefreshSmartcardCredentialsMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 16
KerbAddExtraCredentialsMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 17
KerbQuerySupplementalCredentialsMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 18
KerbTransferCredentialsMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 19
KerbQueryTicketCacheEx2Message: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 20
KerbSubmitTicketMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 21
KerbAddExtraCredentialsExMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 22
KerbQueryKdcProxyCacheMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 23
KerbPurgeKdcProxyCacheMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 24
KerbQueryTicketCacheEx3Message: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 25
KerbCleanupMachinePkinitCredsMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 26
KerbAddBindingCacheEntryExMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 27
KerbQueryBindingCacheMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 28
KerbPurgeBindingCacheMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 29
KerbPinKdcMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 30
KerbUnpinAllKdcsMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 31
KerbQueryDomainExtendedPoliciesMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 32
KerbQueryS4U2ProxyCacheMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 33
KerbRetrieveKeyTabMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 34
KerbRefreshPolicyMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 35
KerbPrintCloudKerberosDebugMessage: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE = 36
class KERB_PURGE_BINDING_CACHE_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
class KERB_PURGE_KDC_PROXY_CACHE_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    Flags: UInt32
    LogonId: win32more.Windows.Win32.Foundation.LUID
class KERB_PURGE_KDC_PROXY_CACHE_RESPONSE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    CountOfPurged: UInt32
class KERB_PURGE_TKT_CACHE_EX_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    LogonId: win32more.Windows.Win32.Foundation.LUID
    Flags: UInt32
    TicketTemplate: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_CACHE_INFO_EX
class KERB_PURGE_TKT_CACHE_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    LogonId: win32more.Windows.Win32.Foundation.LUID
    ServerName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    RealmName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
class KERB_QUERY_BINDING_CACHE_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
class KERB_QUERY_BINDING_CACHE_RESPONSE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    CountOfEntries: UInt32
    Entries: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.KERB_BINDING_CACHE_ENTRY_DATA)
class KERB_QUERY_DOMAIN_EXTENDED_POLICIES_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    Flags: UInt32
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
class KERB_QUERY_DOMAIN_EXTENDED_POLICIES_RESPONSE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    Flags: UInt32
    ExtendedPolicies: UInt32
    DsFlags: UInt32
class KERB_QUERY_KDC_PROXY_CACHE_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    Flags: UInt32
    LogonId: win32more.Windows.Win32.Foundation.LUID
class KERB_QUERY_KDC_PROXY_CACHE_RESPONSE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    CountOfEntries: UInt32
    Entries: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.KDC_PROXY_CACHE_ENTRY_DATA)
class KERB_QUERY_S4U2PROXY_CACHE_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    Flags: UInt32
    LogonId: win32more.Windows.Win32.Foundation.LUID
class KERB_QUERY_S4U2PROXY_CACHE_RESPONSE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    CountOfCreds: UInt32
    Creds: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.KERB_S4U2PROXY_CRED)
class KERB_QUERY_TKT_CACHE_EX2_RESPONSE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    CountOfTickets: UInt32
    Tickets: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_CACHE_INFO_EX2 * 1
class KERB_QUERY_TKT_CACHE_EX3_RESPONSE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    CountOfTickets: UInt32
    Tickets: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_CACHE_INFO_EX3 * 1
class KERB_QUERY_TKT_CACHE_EX_RESPONSE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    CountOfTickets: UInt32
    Tickets: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_CACHE_INFO_EX * 1
class KERB_QUERY_TKT_CACHE_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    LogonId: win32more.Windows.Win32.Foundation.LUID
class KERB_QUERY_TKT_CACHE_RESPONSE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    CountOfTickets: UInt32
    Tickets: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_CACHE_INFO * 1
class KERB_REFRESH_POLICY_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    Flags: UInt32
class KERB_REFRESH_POLICY_RESPONSE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    Flags: UInt32
class KERB_REFRESH_SCCRED_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    CredentialBlob: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    LogonId: win32more.Windows.Win32.Foundation.LUID
    Flags: UInt32
KERB_REQUEST_FLAGS = UInt32
KERB_REQUEST_ADD_CREDENTIAL: win32more.Windows.Win32.Security.Authentication.Identity.KERB_REQUEST_FLAGS = 1
KERB_REQUEST_REPLACE_CREDENTIAL: win32more.Windows.Win32.Security.Authentication.Identity.KERB_REQUEST_FLAGS = 2
KERB_REQUEST_REMOVE_CREDENTIAL: win32more.Windows.Win32.Security.Authentication.Identity.KERB_REQUEST_FLAGS = 4
class KERB_RETRIEVE_KEY_TAB_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    Flags: UInt32
    UserName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Password: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
class KERB_RETRIEVE_KEY_TAB_RESPONSE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    KeyTabLength: UInt32
    KeyTab: POINTER(Byte)
class KERB_RETRIEVE_TKT_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    LogonId: win32more.Windows.Win32.Foundation.LUID
    TargetName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    TicketFlags: UInt32
    CacheOptions: UInt32
    EncryptionType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_CRYPTO_KEY_TYPE
    CredentialsHandle: win32more.Windows.Win32.Security.Credentials.SecHandle
class KERB_RETRIEVE_TKT_RESPONSE(Structure):
    Ticket: win32more.Windows.Win32.Security.Authentication.Identity.KERB_EXTERNAL_TICKET
class KERB_S4U2PROXY_CACHE_ENTRY_INFO(Structure):
    ServerName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Flags: UInt32
    LastStatus: win32more.Windows.Win32.Foundation.NTSTATUS
    Expiry: Int64
class KERB_S4U2PROXY_CRED(Structure):
    UserName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Flags: UInt32
    LastStatus: win32more.Windows.Win32.Foundation.NTSTATUS
    Expiry: Int64
    CountOfEntries: UInt32
    Entries: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.KERB_S4U2PROXY_CACHE_ENTRY_INFO)
class KERB_S4U_LOGON(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE
    Flags: UInt32
    ClientUpn: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ClientRealm: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
class KERB_SETPASSWORD_EX_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    LogonId: win32more.Windows.Win32.Foundation.LUID
    CredentialsHandle: win32more.Windows.Win32.Security.Credentials.SecHandle
    Flags: UInt32
    AccountRealm: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    AccountName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Password: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ClientRealm: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ClientName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Impersonating: win32more.Windows.Win32.Foundation.BOOLEAN
    KdcAddress: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    KdcAddressType: UInt32
class KERB_SETPASSWORD_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    LogonId: win32more.Windows.Win32.Foundation.LUID
    CredentialsHandle: win32more.Windows.Win32.Security.Credentials.SecHandle
    Flags: UInt32
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    AccountName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Password: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
class KERB_SMART_CARD_LOGON(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE
    Pin: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    CspDataLength: UInt32
    CspData: POINTER(Byte)
class KERB_SMART_CARD_PROFILE(Structure):
    Profile: win32more.Windows.Win32.Security.Authentication.Identity.KERB_INTERACTIVE_PROFILE
    CertificateSize: UInt32
    CertificateData: POINTER(Byte)
class KERB_SMART_CARD_UNLOCK_LOGON(Structure):
    Logon: win32more.Windows.Win32.Security.Authentication.Identity.KERB_SMART_CARD_LOGON
    LogonId: win32more.Windows.Win32.Foundation.LUID
class KERB_SUBMIT_TKT_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    LogonId: win32more.Windows.Win32.Foundation.LUID
    Flags: UInt32
    Key: win32more.Windows.Win32.Security.Authentication.Identity.KERB_CRYPTO_KEY32
    KerbCredSize: UInt32
    KerbCredOffset: UInt32
class KERB_TICKET_CACHE_INFO(Structure):
    ServerName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    RealmName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    StartTime: Int64
    EndTime: Int64
    RenewTime: Int64
    EncryptionType: Int32
    TicketFlags: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_FLAGS
class KERB_TICKET_CACHE_INFO_EX(Structure):
    ClientName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ClientRealm: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ServerName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ServerRealm: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    StartTime: Int64
    EndTime: Int64
    RenewTime: Int64
    EncryptionType: Int32
    TicketFlags: UInt32
class KERB_TICKET_CACHE_INFO_EX2(Structure):
    ClientName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ClientRealm: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ServerName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ServerRealm: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    StartTime: Int64
    EndTime: Int64
    RenewTime: Int64
    EncryptionType: Int32
    TicketFlags: UInt32
    SessionKeyType: UInt32
    BranchId: UInt32
class KERB_TICKET_CACHE_INFO_EX3(Structure):
    ClientName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ClientRealm: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ServerName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ServerRealm: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    StartTime: Int64
    EndTime: Int64
    RenewTime: Int64
    EncryptionType: Int32
    TicketFlags: UInt32
    SessionKeyType: UInt32
    BranchId: UInt32
    CacheFlags: UInt32
    KdcCalled: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
KERB_TICKET_FLAGS = UInt32
KERB_TICKET_FLAGS_forwardable: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_FLAGS = 1073741824
KERB_TICKET_FLAGS_forwarded: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_FLAGS = 536870912
KERB_TICKET_FLAGS_hw_authent: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_FLAGS = 1048576
KERB_TICKET_FLAGS_initial: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_FLAGS = 4194304
KERB_TICKET_FLAGS_invalid: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_FLAGS = 16777216
KERB_TICKET_FLAGS_may_postdate: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_FLAGS = 67108864
KERB_TICKET_FLAGS_ok_as_delegate: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_FLAGS = 262144
KERB_TICKET_FLAGS_postdated: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_FLAGS = 33554432
KERB_TICKET_FLAGS_pre_authent: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_FLAGS = 2097152
KERB_TICKET_FLAGS_proxiable: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_FLAGS = 268435456
KERB_TICKET_FLAGS_proxy: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_FLAGS = 134217728
KERB_TICKET_FLAGS_renewable: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_FLAGS = 8388608
KERB_TICKET_FLAGS_reserved: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_FLAGS = 2147483648
KERB_TICKET_FLAGS_reserved1: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_FLAGS = 1
class KERB_TICKET_LOGON(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_LOGON_SUBMIT_TYPE
    Flags: UInt32
    ServiceTicketLength: UInt32
    TicketGrantingTicketLength: UInt32
    ServiceTicket: POINTER(Byte)
    TicketGrantingTicket: POINTER(Byte)
class KERB_TICKET_PROFILE(Structure):
    Profile: win32more.Windows.Win32.Security.Authentication.Identity.KERB_INTERACTIVE_PROFILE
    SessionKey: win32more.Windows.Win32.Security.Authentication.Identity.KERB_CRYPTO_KEY
class KERB_TICKET_UNLOCK_LOGON(Structure):
    Logon: win32more.Windows.Win32.Security.Authentication.Identity.KERB_TICKET_LOGON
    LogonId: win32more.Windows.Win32.Foundation.LUID
class KERB_TRANSFER_CRED_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.KERB_PROTOCOL_MESSAGE_TYPE
    OriginLogonId: win32more.Windows.Win32.Foundation.LUID
    DestinationLogonId: win32more.Windows.Win32.Foundation.LUID
    Flags: UInt32
KSEC_CONTEXT_TYPE = Int32
KSecPaged: win32more.Windows.Win32.Security.Authentication.Identity.KSEC_CONTEXT_TYPE = 0
KSecNonPaged: win32more.Windows.Win32.Security.Authentication.Identity.KSEC_CONTEXT_TYPE = 1
class KSEC_LIST_ENTRY(Structure):
    List: win32more.Windows.Win32.System.Kernel.LIST_ENTRY
    RefCount: Int32
    Signature: UInt32
    OwningList: VoidPtr
    Reserved: VoidPtr
@winfunctype_pointer
def KspCompleteTokenFn(ContextId: UIntPtr, Token: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def KspDeleteContextFn(ContextId: UIntPtr, LsaContextId: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def KspGetTokenFn(ContextId: UIntPtr, ImpersonationToken: POINTER(win32more.Windows.Win32.Foundation.HANDLE), RawToken: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def KspInitContextFn(ContextId: UIntPtr, ContextData: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer), NewContextId: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def KspInitPackageFn(FunctionTable: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_KERNEL_FUNCTIONS)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def KspMakeSignatureFn(ContextId: UIntPtr, fQOP: UInt32, Message: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), MessageSeqNo: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def KspMapHandleFn(ContextId: UIntPtr, LsaContextId: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def KspQueryAttributesFn(ContextId: UIntPtr, Attribute: UInt32, Buffer: VoidPtr) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def KspSealMessageFn(ContextId: UIntPtr, fQOP: UInt32, Message: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), MessageSeqNo: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def KspSerializeAuthDataFn(pvAuthData: VoidPtr, Size: POINTER(UInt32), SerializedData: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def KspSetPagingModeFn(PagingMode: win32more.Windows.Win32.Foundation.BOOLEAN) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def KspUnsealMessageFn(ContextId: UIntPtr, Message: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), MessageSeqNo: UInt32, pfQOP: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def KspVerifySignatureFn(ContextId: UIntPtr, Message: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), MessageSeqNo: UInt32, pfQOP: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
class LOGON_HOURS(Structure):
    UnitsPerWeek: UInt16
    LogonHours: POINTER(Byte)
@winfunctype_pointer
def LSA_AP_POST_LOGON_USER(PostLogonUserInfo: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_POST_LOGON_USER_INFO)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
class LSA_AUTH_INFORMATION(Structure):
    LastUpdateTime: Int64
    AuthType: win32more.Windows.Win32.Security.Authentication.Identity.LSA_AUTH_INFORMATION_AUTH_TYPE
    AuthInfoLength: UInt32
    AuthInfo: POINTER(Byte)
LSA_AUTH_INFORMATION_AUTH_TYPE = UInt32
TRUST_AUTH_TYPE_NONE: win32more.Windows.Win32.Security.Authentication.Identity.LSA_AUTH_INFORMATION_AUTH_TYPE = 0
TRUST_AUTH_TYPE_NT4OWF: win32more.Windows.Win32.Security.Authentication.Identity.LSA_AUTH_INFORMATION_AUTH_TYPE = 1
TRUST_AUTH_TYPE_CLEAR: win32more.Windows.Win32.Security.Authentication.Identity.LSA_AUTH_INFORMATION_AUTH_TYPE = 2
TRUST_AUTH_TYPE_VERSION: win32more.Windows.Win32.Security.Authentication.Identity.LSA_AUTH_INFORMATION_AUTH_TYPE = 3
class LSA_DISPATCH_TABLE(Structure):
    CreateLogonSession: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_CREATE_LOGON_SESSION
    DeleteLogonSession: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_DELETE_LOGON_SESSION
    AddCredential: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_ADD_CREDENTIAL
    GetCredentials: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_GET_CREDENTIALS
    DeleteCredential: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_DELETE_CREDENTIAL
    AllocateLsaHeap: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_ALLOCATE_LSA_HEAP
    FreeLsaHeap: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_FREE_LSA_HEAP
    AllocateClientBuffer: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_ALLOCATE_CLIENT_BUFFER
    FreeClientBuffer: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_FREE_CLIENT_BUFFER
    CopyToClientBuffer: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_COPY_TO_CLIENT_BUFFER
    CopyFromClientBuffer: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_COPY_FROM_CLIENT_BUFFER
class LSA_ENUMERATION_INFORMATION(Structure):
    Sid: win32more.Windows.Win32.Security.PSID
class LSA_FOREST_TRUST_BINARY_DATA(Structure):
    Length: UInt32
    Buffer: POINTER(Byte)
class LSA_FOREST_TRUST_COLLISION_INFORMATION(Structure):
    RecordCount: UInt32
    Entries: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_COLLISION_RECORD))
class LSA_FOREST_TRUST_COLLISION_RECORD(Structure):
    Index: UInt32
    Type: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_COLLISION_RECORD_TYPE
    Flags: UInt32
    Name: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
LSA_FOREST_TRUST_COLLISION_RECORD_TYPE = Int32
CollisionTdo: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_COLLISION_RECORD_TYPE = 0
CollisionXref: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_COLLISION_RECORD_TYPE = 1
CollisionOther: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_COLLISION_RECORD_TYPE = 2
class LSA_FOREST_TRUST_DOMAIN_INFO(Structure):
    Sid: win32more.Windows.Win32.Security.PSID
    DnsName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    NetbiosName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
class LSA_FOREST_TRUST_INFORMATION(Structure):
    RecordCount: UInt32
    Entries: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_RECORD))
class LSA_FOREST_TRUST_INFORMATION2(Structure):
    RecordCount: UInt32
    Entries: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_RECORD2))
class LSA_FOREST_TRUST_RECORD(Structure):
    Flags: UInt32
    ForestTrustType: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_RECORD_TYPE
    Time: Int64
    ForestTrustData: _ForestTrustData_e__Union
    class _ForestTrustData_e__Union(Union):
        TopLevelName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
        DomainInfo: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_DOMAIN_INFO
        Data: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_BINARY_DATA
class LSA_FOREST_TRUST_RECORD2(Structure):
    Flags: UInt32
    ForestTrustType: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_RECORD_TYPE
    Time: Int64
    ForestTrustData: _ForestTrustData_e__Union
    class _ForestTrustData_e__Union(Union):
        TopLevelName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
        DomainInfo: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_DOMAIN_INFO
        BinaryData: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_BINARY_DATA
        ScannerInfo: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_SCANNER_INFO
LSA_FOREST_TRUST_RECORD_TYPE = Int32
ForestTrustTopLevelName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_RECORD_TYPE = 0
ForestTrustTopLevelNameEx: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_RECORD_TYPE = 1
ForestTrustDomainInfo: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_RECORD_TYPE = 2
ForestTrustBinaryInfo: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_RECORD_TYPE = 3
ForestTrustScannerInfo: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_RECORD_TYPE = 4
ForestTrustRecordTypeLast: win32more.Windows.Win32.Security.Authentication.Identity.LSA_FOREST_TRUST_RECORD_TYPE = 4
class LSA_FOREST_TRUST_SCANNER_INFO(Structure):
    DomainSid: win32more.Windows.Win32.Security.PSID
    DnsName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    NetbiosName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
LSA_HANDLE = IntPtr
class LSA_LAST_INTER_LOGON_INFO(Structure):
    LastSuccessfulLogon: Int64
    LastFailedLogon: Int64
    FailedAttemptCountSinceLastSuccessfulLogon: UInt32
LSA_LOOKUP_DOMAIN_INFO_CLASS = Int32
AccountDomainInformation: win32more.Windows.Win32.Security.Authentication.Identity.LSA_LOOKUP_DOMAIN_INFO_CLASS = 5
DnsDomainInformation: win32more.Windows.Win32.Security.Authentication.Identity.LSA_LOOKUP_DOMAIN_INFO_CLASS = 12
class LSA_OBJECT_ATTRIBUTES(Structure):
    Length: UInt32
    RootDirectory: win32more.Windows.Win32.Foundation.HANDLE
    ObjectName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)
    Attributes: UInt32
    SecurityDescriptor: VoidPtr
    SecurityQualityOfService: VoidPtr
class LSA_REFERENCED_DOMAIN_LIST(Structure):
    Entries: UInt32
    Domains: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_TRUST_INFORMATION)
class LSA_SECPKG_FUNCTION_TABLE(Structure):
    CreateLogonSession: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_CREATE_LOGON_SESSION
    DeleteLogonSession: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_DELETE_LOGON_SESSION
    AddCredential: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_ADD_CREDENTIAL
    GetCredentials: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_GET_CREDENTIALS
    DeleteCredential: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_DELETE_CREDENTIAL
    AllocateLsaHeap: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_ALLOCATE_LSA_HEAP
    FreeLsaHeap: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_FREE_LSA_HEAP
    AllocateClientBuffer: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_ALLOCATE_CLIENT_BUFFER
    FreeClientBuffer: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_FREE_CLIENT_BUFFER
    CopyToClientBuffer: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_COPY_TO_CLIENT_BUFFER
    CopyFromClientBuffer: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_COPY_FROM_CLIENT_BUFFER
    ImpersonateClient: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_IMPERSONATE_CLIENT
    UnloadPackage: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_UNLOAD_PACKAGE
    DuplicateHandle: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_DUPLICATE_HANDLE
    SaveSupplementalCredentials: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_SAVE_SUPPLEMENTAL_CREDENTIALS
    CreateThread: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_CREATE_THREAD
    GetClientInfo: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_GET_CLIENT_INFO
    RegisterNotification: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_REGISTER_NOTIFICATION
    CancelNotification: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_CANCEL_NOTIFICATION
    MapBuffer: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_MAP_BUFFER
    CreateToken: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_CREATE_TOKEN
    AuditLogon: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_AUDIT_LOGON
    CallPackage: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_CALL_PACKAGE
    FreeReturnBuffer: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_FREE_LSA_HEAP
    GetCallInfo: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_GET_CALL_INFO
    CallPackageEx: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_CALL_PACKAGEEX
    CreateSharedMemory: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_CREATE_SHARED_MEMORY
    AllocateSharedMemory: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_ALLOCATE_SHARED_MEMORY
    FreeSharedMemory: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_FREE_SHARED_MEMORY
    DeleteSharedMemory: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_DELETE_SHARED_MEMORY
    OpenSamUser: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_OPEN_SAM_USER
    GetUserCredentials: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_GET_USER_CREDENTIALS
    GetUserAuthData: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_GET_USER_AUTH_DATA
    CloseSamUser: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_CLOSE_SAM_USER
    ConvertAuthDataToToken: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_CONVERT_AUTH_DATA_TO_TOKEN
    ClientCallback: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_CLIENT_CALLBACK
    UpdateCredentials: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_UPDATE_PRIMARY_CREDENTIALS
    GetAuthDataForUser: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_GET_AUTH_DATA_FOR_USER
    CrackSingleName: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_CRACK_SINGLE_NAME
    AuditAccountLogon: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_AUDIT_ACCOUNT_LOGON
    CallPackagePassthrough: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_CALL_PACKAGE_PASSTHROUGH
    CrediRead: win32more.Windows.Win32.Security.Authentication.Identity.CredReadFn
    CrediReadDomainCredentials: win32more.Windows.Win32.Security.Authentication.Identity.CredReadDomainCredentialsFn
    CrediFreeCredentials: win32more.Windows.Win32.Security.Authentication.Identity.CredFreeCredentialsFn
    LsaProtectMemory: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_PROTECT_MEMORY
    LsaUnprotectMemory: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_PROTECT_MEMORY
    OpenTokenByLogonId: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_OPEN_TOKEN_BY_LOGON_ID
    ExpandAuthDataForDomain: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_EXPAND_AUTH_DATA_FOR_DOMAIN
    AllocatePrivateHeap: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_ALLOCATE_PRIVATE_HEAP
    FreePrivateHeap: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_FREE_PRIVATE_HEAP
    CreateTokenEx: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_CREATE_TOKEN_EX
    CrediWrite: win32more.Windows.Win32.Security.Authentication.Identity.CredWriteFn
    CrediUnmarshalandDecodeString: win32more.Windows.Win32.Security.Authentication.Identity.CrediUnmarshalandDecodeStringFn
    DummyFunction6: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_PROTECT_MEMORY
    GetExtendedCallFlags: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_GET_EXTENDED_CALL_FLAGS
    DuplicateTokenHandle: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_DUPLICATE_HANDLE
    GetServiceAccountPassword: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_GET_SERVICE_ACCOUNT_PASSWORD
    DummyFunction7: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_PROTECT_MEMORY
    AuditLogonEx: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_AUDIT_LOGON_EX
    CheckProtectedUserByToken: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_CHECK_PROTECTED_USER_BY_TOKEN
    QueryClientRequest: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_QUERY_CLIENT_REQUEST
    GetAppModeInfo: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_GET_APP_MODE_INFO
    SetAppModeInfo: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_SET_APP_MODE_INFO
    GetClientInfoEx: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_GET_CLIENT_INFO_EX
class LSA_STRING(Structure):
    Length: UInt16
    MaximumLength: UInt16
    Buffer: win32more.Windows.Win32.Foundation.PSTR
class LSA_TOKEN_INFORMATION_NULL(Structure):
    ExpirationTime: Int64
    Groups: POINTER(win32more.Windows.Win32.Security.TOKEN_GROUPS)
LSA_TOKEN_INFORMATION_TYPE = Int32
LsaTokenInformationNull: win32more.Windows.Win32.Security.Authentication.Identity.LSA_TOKEN_INFORMATION_TYPE = 0
LsaTokenInformationV1: win32more.Windows.Win32.Security.Authentication.Identity.LSA_TOKEN_INFORMATION_TYPE = 1
LsaTokenInformationV2: win32more.Windows.Win32.Security.Authentication.Identity.LSA_TOKEN_INFORMATION_TYPE = 2
LsaTokenInformationV3: win32more.Windows.Win32.Security.Authentication.Identity.LSA_TOKEN_INFORMATION_TYPE = 3
class LSA_TOKEN_INFORMATION_V1(Structure):
    ExpirationTime: Int64
    User: win32more.Windows.Win32.Security.TOKEN_USER
    Groups: POINTER(win32more.Windows.Win32.Security.TOKEN_GROUPS)
    PrimaryGroup: win32more.Windows.Win32.Security.TOKEN_PRIMARY_GROUP
    Privileges: POINTER(win32more.Windows.Win32.Security.TOKEN_PRIVILEGES)
    Owner: win32more.Windows.Win32.Security.TOKEN_OWNER
    DefaultDacl: win32more.Windows.Win32.Security.TOKEN_DEFAULT_DACL
class LSA_TOKEN_INFORMATION_V3(Structure):
    ExpirationTime: Int64
    User: win32more.Windows.Win32.Security.TOKEN_USER
    Groups: POINTER(win32more.Windows.Win32.Security.TOKEN_GROUPS)
    PrimaryGroup: win32more.Windows.Win32.Security.TOKEN_PRIMARY_GROUP
    Privileges: POINTER(win32more.Windows.Win32.Security.TOKEN_PRIVILEGES)
    Owner: win32more.Windows.Win32.Security.TOKEN_OWNER
    DefaultDacl: win32more.Windows.Win32.Security.TOKEN_DEFAULT_DACL
    UserClaims: win32more.Windows.Win32.Security.TOKEN_USER_CLAIMS
    DeviceClaims: win32more.Windows.Win32.Security.TOKEN_DEVICE_CLAIMS
    DeviceGroups: POINTER(win32more.Windows.Win32.Security.TOKEN_GROUPS)
class LSA_TRANSLATED_NAME(Structure):
    Use: win32more.Windows.Win32.Security.SID_NAME_USE
    Name: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DomainIndex: Int32
class LSA_TRANSLATED_SID(Structure):
    Use: win32more.Windows.Win32.Security.SID_NAME_USE
    RelativeId: UInt32
    DomainIndex: Int32
class LSA_TRANSLATED_SID2(Structure):
    Use: win32more.Windows.Win32.Security.SID_NAME_USE
    Sid: win32more.Windows.Win32.Security.PSID
    DomainIndex: Int32
    Flags: UInt32
class LSA_TRUST_INFORMATION(Structure):
    Name: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Sid: win32more.Windows.Win32.Security.PSID
class LSA_UNICODE_STRING(Structure):
    Length: UInt16
    MaximumLength: UInt16
    Buffer: win32more.Windows.Win32.Foundation.PWSTR
@winfunctype_pointer
def MAKE_SIGNATURE_FN(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: UInt32, param2: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
MSV1_0 = UInt32
MSV1_0_PASSTHRU: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0 = 1
MSV1_0_GUEST_LOGON: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0 = 2
MSV1_0_AVID = Int32
MsvAvEOL: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_AVID = 0
MsvAvNbComputerName: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_AVID = 1
MsvAvNbDomainName: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_AVID = 2
MsvAvDnsComputerName: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_AVID = 3
MsvAvDnsDomainName: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_AVID = 4
MsvAvDnsTreeName: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_AVID = 5
MsvAvFlags: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_AVID = 6
MsvAvTimestamp: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_AVID = 7
MsvAvRestrictions: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_AVID = 8
MsvAvTargetName: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_AVID = 9
MsvAvChannelBindings: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_AVID = 10
class MSV1_0_AV_PAIR(Structure):
    AvId: UInt16
    AvLen: UInt16
class MSV1_0_CHANGEPASSWORD_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    AccountName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    OldPassword: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    NewPassword: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Impersonating: win32more.Windows.Win32.Foundation.BOOLEAN
class MSV1_0_CHANGEPASSWORD_RESPONSE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE
    PasswordInfoValid: win32more.Windows.Win32.Foundation.BOOLEAN
    DomainPasswordInfo: win32more.Windows.Win32.Security.Authentication.Identity.DOMAIN_PASSWORD_INFORMATION
class MSV1_0_CREDENTIAL_KEY(Structure):
    Data: Byte * 20
MSV1_0_CREDENTIAL_KEY_TYPE = Int32
InvalidCredKey: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_CREDENTIAL_KEY_TYPE = 0
DeprecatedIUMCredKey: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_CREDENTIAL_KEY_TYPE = 1
DomainUserCredKey: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_CREDENTIAL_KEY_TYPE = 2
LocalUserCredKey: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_CREDENTIAL_KEY_TYPE = 3
ExternallySuppliedCredKey: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_CREDENTIAL_KEY_TYPE = 4
class MSV1_0_INTERACTIVE_LOGON(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_LOGON_SUBMIT_TYPE
    LogonDomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    UserName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Password: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
class MSV1_0_INTERACTIVE_PROFILE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROFILE_BUFFER_TYPE
    LogonCount: UInt16
    BadPasswordCount: UInt16
    LogonTime: Int64
    LogoffTime: Int64
    KickOffTime: Int64
    PasswordLastSet: Int64
    PasswordCanChange: Int64
    PasswordMustChange: Int64
    LogonScript: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    HomeDirectory: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    FullName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ProfilePath: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    HomeDirectoryDrive: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    LogonServer: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    UserFlags: UInt32
class MSV1_0_IUM_SUPPLEMENTAL_CREDENTIAL(Structure):
    Version: UInt32
    EncryptedCredsSize: UInt32
    EncryptedCreds: Byte * 1
class MSV1_0_LM20_LOGON(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_LOGON_SUBMIT_TYPE
    LogonDomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    UserName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Workstation: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ChallengeToClient: Byte * 8
    CaseSensitiveChallengeResponse: win32more.Windows.Win32.Security.Authentication.Identity.LSA_STRING
    CaseInsensitiveChallengeResponse: win32more.Windows.Win32.Security.Authentication.Identity.LSA_STRING
    ParameterControl: UInt32
class MSV1_0_LM20_LOGON_PROFILE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROFILE_BUFFER_TYPE
    KickOffTime: Int64
    LogoffTime: Int64
    UserFlags: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUB_AUTHENTICATION_FILTER
    UserSessionKey: Byte * 16
    LogonDomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    LanmanSessionKey: Byte * 8
    LogonServer: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    UserParameters: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
MSV1_0_LOGON_SUBMIT_TYPE = Int32
MsV1_0InteractiveLogon: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_LOGON_SUBMIT_TYPE = 2
MsV1_0Lm20Logon: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_LOGON_SUBMIT_TYPE = 3
MsV1_0NetworkLogon: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_LOGON_SUBMIT_TYPE = 4
MsV1_0SubAuthLogon: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_LOGON_SUBMIT_TYPE = 5
MsV1_0WorkstationUnlockLogon: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_LOGON_SUBMIT_TYPE = 7
MsV1_0S4ULogon: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_LOGON_SUBMIT_TYPE = 12
MsV1_0VirtualLogon: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_LOGON_SUBMIT_TYPE = 82
MsV1_0NoElevationLogon: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_LOGON_SUBMIT_TYPE = 83
MsV1_0LuidLogon: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_LOGON_SUBMIT_TYPE = 84
class MSV1_0_NTLM3_RESPONSE(Structure):
    Response: Byte * 16
    RespType: Byte
    HiRespType: Byte
    Flags: UInt16
    MsgWord: UInt32
    TimeStamp: UInt64
    ChallengeFromClient: Byte * 8
    AvPairsOff: UInt32
    Buffer: Byte * 1
class MSV1_0_PASSTHROUGH_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    PackageName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DataLength: UInt32
    LogonData: POINTER(Byte)
    Pad: UInt32
class MSV1_0_PASSTHROUGH_RESPONSE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE
    Pad: UInt32
    DataLength: UInt32
    ValidationData: POINTER(Byte)
MSV1_0_PROFILE_BUFFER_TYPE = Int32
MsV1_0InteractiveProfile: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROFILE_BUFFER_TYPE = 2
MsV1_0Lm20LogonProfile: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROFILE_BUFFER_TYPE = 3
MsV1_0SmartCardProfile: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROFILE_BUFFER_TYPE = 4
MSV1_0_PROTOCOL_MESSAGE_TYPE = Int32
MsV1_0Lm20ChallengeRequest: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 0
MsV1_0Lm20GetChallengeResponse: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 1
MsV1_0EnumerateUsers: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 2
MsV1_0GetUserInfo: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 3
MsV1_0ReLogonUsers: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 4
MsV1_0ChangePassword: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 5
MsV1_0ChangeCachedPassword: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 6
MsV1_0GenericPassthrough: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 7
MsV1_0CacheLogon: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 8
MsV1_0SubAuth: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 9
MsV1_0DeriveCredential: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 10
MsV1_0CacheLookup: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 11
MsV1_0SetProcessOption: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 12
MsV1_0ConfigLocalAliases: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 13
MsV1_0ClearCachedCredentials: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 14
MsV1_0LookupToken: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 15
MsV1_0ValidateAuth: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 16
MsV1_0CacheLookupEx: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 17
MsV1_0GetCredentialKey: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 18
MsV1_0SetThreadOption: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 19
MsV1_0DecryptDpapiMasterKey: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 20
MsV1_0GetStrongCredentialKey: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 21
MsV1_0TransferCred: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 22
MsV1_0ProvisionTbal: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 23
MsV1_0DeleteTbalSecrets: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE = 24
class MSV1_0_REMOTE_SUPPLEMENTAL_CREDENTIAL(Structure):
    Version: UInt32
    Flags: UInt32
    CredentialKey: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_CREDENTIAL_KEY
    CredentialKeyType: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_CREDENTIAL_KEY_TYPE
    EncryptedCredsSize: UInt32
    EncryptedCreds: Byte * 1
    _pack_ = 1
class MSV1_0_S4U_LOGON(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_LOGON_SUBMIT_TYPE
    Flags: UInt32
    UserPrincipalName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
class MSV1_0_SUBAUTH_LOGON(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_LOGON_SUBMIT_TYPE
    LogonDomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    UserName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Workstation: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ChallengeToClient: Byte * 8
    AuthenticationInfo1: win32more.Windows.Win32.Security.Authentication.Identity.LSA_STRING
    AuthenticationInfo2: win32more.Windows.Win32.Security.Authentication.Identity.LSA_STRING
    ParameterControl: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUBAUTH_LOGON_PARAMETER_CONTROL
    SubAuthPackageId: UInt32
class MSV1_0_SUBAUTH_REQUEST(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE
    SubAuthPackageId: UInt32
    SubAuthInfoLength: UInt32
    SubAuthSubmitBuffer: POINTER(Byte)
class MSV1_0_SUBAUTH_RESPONSE(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_PROTOCOL_MESSAGE_TYPE
    SubAuthInfoLength: UInt32
    SubAuthReturnBuffer: POINTER(Byte)
class MSV1_0_SUPPLEMENTAL_CREDENTIAL(Structure):
    Version: UInt32
    Flags: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUPPLEMENTAL_CREDENTIAL_FLAGS
    LmPassword: Byte * 16
    NtPassword: Byte * 16
class MSV1_0_SUPPLEMENTAL_CREDENTIAL_V2(Structure):
    Version: UInt32
    Flags: UInt32
    NtPassword: Byte * 16
    CredentialKey: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_CREDENTIAL_KEY
class MSV1_0_SUPPLEMENTAL_CREDENTIAL_V3(Structure):
    Version: UInt32
    Flags: UInt32
    CredentialKeyType: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_CREDENTIAL_KEY_TYPE
    NtPassword: Byte * 16
    CredentialKey: win32more.Windows.Win32.Security.Authentication.Identity.MSV1_0_CREDENTIAL_KEY
    ShaPassword: Byte * 20
class MSV1_0_VALIDATION_INFO(Structure):
    LogoffTime: Int64
    KickoffTime: Int64
    LogonServer: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    LogonDomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    SessionKey: win32more.Windows.Win32.Security.Authentication.Identity.USER_SESSION_KEY
    Authoritative: win32more.Windows.Win32.Foundation.BOOLEAN
    UserFlags: UInt32
    WhichFields: UInt32
    UserId: UInt32
MSV_SUBAUTH_LOGON_PARAMETER_CONTROL = UInt32
MSV1_0_CLEARTEXT_PASSWORD_ALLOWED: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUBAUTH_LOGON_PARAMETER_CONTROL = 2
MSV1_0_UPDATE_LOGON_STATISTICS: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUBAUTH_LOGON_PARAMETER_CONTROL = 4
MSV1_0_RETURN_USER_PARAMETERS: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUBAUTH_LOGON_PARAMETER_CONTROL = 8
MSV1_0_DONT_TRY_GUEST_ACCOUNT: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUBAUTH_LOGON_PARAMETER_CONTROL = 16
MSV1_0_ALLOW_SERVER_TRUST_ACCOUNT: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUBAUTH_LOGON_PARAMETER_CONTROL = 32
MSV1_0_RETURN_PASSWORD_EXPIRY: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUBAUTH_LOGON_PARAMETER_CONTROL = 64
MSV1_0_ALLOW_WORKSTATION_TRUST_ACCOUNT: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUBAUTH_LOGON_PARAMETER_CONTROL = 2048
MSV1_0_TRY_GUEST_ACCOUNT_ONLY: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUBAUTH_LOGON_PARAMETER_CONTROL = 256
MSV1_0_RETURN_PROFILE_PATH: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUBAUTH_LOGON_PARAMETER_CONTROL = 512
MSV1_0_TRY_SPECIFIED_DOMAIN_ONLY: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUBAUTH_LOGON_PARAMETER_CONTROL = 1024
MSV_SUB_AUTHENTICATION_FILTER = UInt32
LOGON_GUEST: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUB_AUTHENTICATION_FILTER = 1
LOGON_NOENCRYPTION: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUB_AUTHENTICATION_FILTER = 2
LOGON_CACHED_ACCOUNT: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUB_AUTHENTICATION_FILTER = 4
LOGON_USED_LM_PASSWORD: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUB_AUTHENTICATION_FILTER = 8
LOGON_EXTRA_SIDS: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUB_AUTHENTICATION_FILTER = 32
LOGON_SUBAUTH_SESSION_KEY: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUB_AUTHENTICATION_FILTER = 64
LOGON_SERVER_TRUST_ACCOUNT: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUB_AUTHENTICATION_FILTER = 128
LOGON_PROFILE_PATH_RETURNED: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUB_AUTHENTICATION_FILTER = 1024
LOGON_RESOURCE_GROUPS: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUB_AUTHENTICATION_FILTER = 512
MSV_SUPPLEMENTAL_CREDENTIAL_FLAGS = UInt32
MSV1_0_CRED_LM_PRESENT: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUPPLEMENTAL_CREDENTIAL_FLAGS = 1
MSV1_0_CRED_NT_PRESENT: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUPPLEMENTAL_CREDENTIAL_FLAGS = 2
MSV1_0_CRED_VERSION: win32more.Windows.Win32.Security.Authentication.Identity.MSV_SUPPLEMENTAL_CREDENTIAL_FLAGS = 0
class NEGOTIATE_CALLER_NAME_REQUEST(Structure):
    MessageType: UInt32
    LogonId: win32more.Windows.Win32.Foundation.LUID
class NEGOTIATE_CALLER_NAME_RESPONSE(Structure):
    MessageType: UInt32
    CallerName: win32more.Windows.Win32.Foundation.PWSTR
NEGOTIATE_MESSAGES = Int32
NegEnumPackagePrefixes: win32more.Windows.Win32.Security.Authentication.Identity.NEGOTIATE_MESSAGES = 0
NegGetCallerName: win32more.Windows.Win32.Security.Authentication.Identity.NEGOTIATE_MESSAGES = 1
NegTransferCredentials: win32more.Windows.Win32.Security.Authentication.Identity.NEGOTIATE_MESSAGES = 2
NegMsgReserved1: win32more.Windows.Win32.Security.Authentication.Identity.NEGOTIATE_MESSAGES = 3
NegCallPackageMax: win32more.Windows.Win32.Security.Authentication.Identity.NEGOTIATE_MESSAGES = 4
class NEGOTIATE_PACKAGE_PREFIX(Structure):
    PackageId: UIntPtr
    PackageDataA: VoidPtr
    PackageDataW: VoidPtr
    PrefixLen: UIntPtr
    Prefix: Byte * 32
class NEGOTIATE_PACKAGE_PREFIXES(Structure):
    MessageType: UInt32
    PrefixCount: UInt32
    Offset: UInt32
    Pad: UInt32
class NETLOGON_GENERIC_INFO(Structure):
    Identity: win32more.Windows.Win32.Security.Authentication.Identity.NETLOGON_LOGON_IDENTITY_INFO
    PackageName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DataLength: UInt32
    LogonData: POINTER(Byte)
class NETLOGON_INTERACTIVE_INFO(Structure):
    Identity: win32more.Windows.Win32.Security.Authentication.Identity.NETLOGON_LOGON_IDENTITY_INFO
    LmOwfPassword: win32more.Windows.Win32.System.PasswordManagement.LM_OWF_PASSWORD
    NtOwfPassword: win32more.Windows.Win32.System.PasswordManagement.LM_OWF_PASSWORD
class NETLOGON_LOGON_IDENTITY_INFO(Structure):
    LogonDomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ParameterControl: UInt32
    LogonId: Int64
    UserName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Workstation: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
NETLOGON_LOGON_INFO_CLASS = Int32
NetlogonInteractiveInformation: win32more.Windows.Win32.Security.Authentication.Identity.NETLOGON_LOGON_INFO_CLASS = 1
NetlogonNetworkInformation: win32more.Windows.Win32.Security.Authentication.Identity.NETLOGON_LOGON_INFO_CLASS = 2
NetlogonServiceInformation: win32more.Windows.Win32.Security.Authentication.Identity.NETLOGON_LOGON_INFO_CLASS = 3
NetlogonGenericInformation: win32more.Windows.Win32.Security.Authentication.Identity.NETLOGON_LOGON_INFO_CLASS = 4
NetlogonInteractiveTransitiveInformation: win32more.Windows.Win32.Security.Authentication.Identity.NETLOGON_LOGON_INFO_CLASS = 5
NetlogonNetworkTransitiveInformation: win32more.Windows.Win32.Security.Authentication.Identity.NETLOGON_LOGON_INFO_CLASS = 6
NetlogonServiceTransitiveInformation: win32more.Windows.Win32.Security.Authentication.Identity.NETLOGON_LOGON_INFO_CLASS = 7
class NETLOGON_NETWORK_INFO(Structure):
    Identity: win32more.Windows.Win32.Security.Authentication.Identity.NETLOGON_LOGON_IDENTITY_INFO
    LmChallenge: win32more.Windows.Win32.Security.Authentication.Identity.CLEAR_BLOCK
    NtChallengeResponse: win32more.Windows.Win32.Security.Authentication.Identity.LSA_STRING
    LmChallengeResponse: win32more.Windows.Win32.Security.Authentication.Identity.LSA_STRING
class NETLOGON_SERVICE_INFO(Structure):
    Identity: win32more.Windows.Win32.Security.Authentication.Identity.NETLOGON_LOGON_IDENTITY_INFO
    LmOwfPassword: win32more.Windows.Win32.System.PasswordManagement.LM_OWF_PASSWORD
    NtOwfPassword: win32more.Windows.Win32.System.PasswordManagement.LM_OWF_PASSWORD
@winfunctype_pointer
def PKSEC_CREATE_CONTEXT_LIST(Type: win32more.Windows.Win32.Security.Authentication.Identity.KSEC_CONTEXT_TYPE) -> VoidPtr: ...
@winfunctype_pointer
def PKSEC_DEREFERENCE_LIST_ENTRY(Entry: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.KSEC_LIST_ENTRY), Delete: POINTER(Byte)) -> Void: ...
@winfunctype_pointer
def PKSEC_INSERT_LIST_ENTRY(List: VoidPtr, Entry: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.KSEC_LIST_ENTRY)) -> Void: ...
@winfunctype_pointer
def PKSEC_LOCATE_PKG_BY_ID(PackageId: UInt32) -> VoidPtr: ...
@winfunctype_pointer
def PKSEC_REFERENCE_LIST_ENTRY(Entry: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.KSEC_LIST_ENTRY), Signature: UInt32, RemoveNoRef: win32more.Windows.Win32.Foundation.BOOLEAN) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PKSEC_SERIALIZE_SCHANNEL_AUTH_DATA(pvAuthData: VoidPtr, Size: POINTER(UInt32), SerializedData: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PKSEC_SERIALIZE_WINNT_AUTH_DATA(pvAuthData: VoidPtr, Size: POINTER(UInt32), SerializedData: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
class PKU2U_CERTIFICATE_S4U_LOGON(Structure):
    MessageType: win32more.Windows.Win32.Security.Authentication.Identity.PKU2U_LOGON_SUBMIT_TYPE
    Flags: UInt32
    UserPrincipalName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    CertificateLength: UInt32
    Certificate: POINTER(Byte)
class PKU2U_CERT_BLOB(Structure):
    CertOffset: UInt32
    CertLength: UInt16
class PKU2U_CREDUI_CONTEXT(Structure):
    Version: UInt64
    cbHeaderLength: UInt16
    cbStructureLength: UInt32
    CertArrayCount: UInt16
    CertArrayOffset: UInt32
PKU2U_LOGON_SUBMIT_TYPE = Int32
Pku2uCertificateS4ULogon: win32more.Windows.Win32.Security.Authentication.Identity.PKU2U_LOGON_SUBMIT_TYPE = 14
@winfunctype_pointer
def PLSA_ADD_CREDENTIAL(LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), AuthenticationPackage: UInt32, PrimaryKeyValue: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_STRING), Credentials: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_STRING)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_ALLOCATE_CLIENT_BUFFER(ClientRequest: POINTER(VoidPtr), LengthRequired: UInt32, ClientBaseAddress: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_ALLOCATE_LSA_HEAP(Length: UInt32) -> VoidPtr: ...
@winfunctype_pointer
def PLSA_ALLOCATE_PRIVATE_HEAP(Length: UIntPtr) -> VoidPtr: ...
@winfunctype_pointer
def PLSA_ALLOCATE_SHARED_MEMORY(SharedMem: VoidPtr, Size: UInt32) -> VoidPtr: ...
@winfunctype_pointer
def PLSA_AP_CALL_PACKAGE(ClientRequest: POINTER(VoidPtr), ProtocolSubmitBuffer: VoidPtr, ClientBufferBase: VoidPtr, SubmitBufferLength: UInt32, ProtocolReturnBuffer: POINTER(VoidPtr), ReturnBufferLength: POINTER(UInt32), ProtocolStatus: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_AP_CALL_PACKAGE_PASSTHROUGH(ClientRequest: POINTER(VoidPtr), ProtocolSubmitBuffer: VoidPtr, ClientBufferBase: VoidPtr, SubmitBufferLength: UInt32, ProtocolReturnBuffer: POINTER(VoidPtr), ReturnBufferLength: POINTER(UInt32), ProtocolStatus: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_AP_INITIALIZE_PACKAGE(AuthenticationPackageId: UInt32, LsaDispatchTable: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_DISPATCH_TABLE), Database: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_STRING), Confidentiality: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_STRING), AuthenticationPackageName: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_STRING))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_AP_LOGON_TERMINATED(LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID)) -> Void: ...
@winfunctype_pointer
def PLSA_AP_LOGON_USER(ClientRequest: POINTER(VoidPtr), LogonType: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_LOGON_TYPE, AuthenticationInformation: VoidPtr, ClientAuthenticationBase: VoidPtr, AuthenticationInformationLength: UInt32, ProfileBuffer: POINTER(VoidPtr), ProfileBufferLength: POINTER(UInt32), LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), SubStatus: POINTER(Int32), TokenInformationType: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_TOKEN_INFORMATION_TYPE), TokenInformation: POINTER(VoidPtr), AccountName: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)), AuthenticatingAuthority: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_AP_LOGON_USER_EX(ClientRequest: POINTER(VoidPtr), LogonType: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_LOGON_TYPE, AuthenticationInformation: VoidPtr, ClientAuthenticationBase: VoidPtr, AuthenticationInformationLength: UInt32, ProfileBuffer: POINTER(VoidPtr), ProfileBufferLength: POINTER(UInt32), LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), SubStatus: POINTER(Int32), TokenInformationType: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_TOKEN_INFORMATION_TYPE), TokenInformation: POINTER(VoidPtr), AccountName: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)), AuthenticatingAuthority: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)), MachineName: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_AP_LOGON_USER_EX2(ClientRequest: POINTER(VoidPtr), LogonType: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_LOGON_TYPE, ProtocolSubmitBuffer: VoidPtr, ClientBufferBase: VoidPtr, SubmitBufferSize: UInt32, ProfileBuffer: POINTER(VoidPtr), ProfileBufferSize: POINTER(UInt32), LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), SubStatus: POINTER(Int32), TokenInformationType: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_TOKEN_INFORMATION_TYPE), TokenInformation: POINTER(VoidPtr), AccountName: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)), AuthenticatingAuthority: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)), MachineName: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)), PrimaryCredentials: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_PRIMARY_CRED), SupplementalCredentials: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_SUPPLEMENTAL_CRED_ARRAY))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_AP_LOGON_USER_EX3(ClientRequest: POINTER(VoidPtr), LogonType: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_LOGON_TYPE, ProtocolSubmitBuffer: VoidPtr, ClientBufferBase: VoidPtr, SubmitBufferSize: UInt32, SurrogateLogon: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_SURROGATE_LOGON), ProfileBuffer: POINTER(VoidPtr), ProfileBufferSize: POINTER(UInt32), LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), SubStatus: POINTER(Int32), TokenInformationType: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_TOKEN_INFORMATION_TYPE), TokenInformation: POINTER(VoidPtr), AccountName: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)), AuthenticatingAuthority: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)), MachineName: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)), PrimaryCredentials: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_PRIMARY_CRED), SupplementalCredentials: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_SUPPLEMENTAL_CRED_ARRAY))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_AP_POST_LOGON_USER_SURROGATE(ClientRequest: POINTER(VoidPtr), LogonType: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_LOGON_TYPE, ProtocolSubmitBuffer: VoidPtr, ClientBufferBase: VoidPtr, SubmitBufferSize: UInt32, SurrogateLogon: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_SURROGATE_LOGON), ProfileBuffer: VoidPtr, ProfileBufferSize: UInt32, LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), Status: win32more.Windows.Win32.Foundation.NTSTATUS, SubStatus: win32more.Windows.Win32.Foundation.NTSTATUS, TokenInformationType: win32more.Windows.Win32.Security.Authentication.Identity.LSA_TOKEN_INFORMATION_TYPE, TokenInformation: VoidPtr, AccountName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), AuthenticatingAuthority: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), MachineName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), PrimaryCredentials: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_PRIMARY_CRED), SupplementalCredentials: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_SUPPLEMENTAL_CRED_ARRAY)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_AP_PRE_LOGON_USER_SURROGATE(ClientRequest: POINTER(VoidPtr), LogonType: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_LOGON_TYPE, ProtocolSubmitBuffer: VoidPtr, ClientBufferBase: VoidPtr, SubmitBufferSize: UInt32, SurrogateLogon: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_SURROGATE_LOGON), SubStatus: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_AUDIT_ACCOUNT_LOGON(AuditId: UInt32, Success: win32more.Windows.Win32.Foundation.BOOLEAN, Source: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), ClientName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), MappedName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), Status: win32more.Windows.Win32.Foundation.NTSTATUS) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_AUDIT_LOGON(Status: win32more.Windows.Win32.Foundation.NTSTATUS, SubStatus: win32more.Windows.Win32.Foundation.NTSTATUS, AccountName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), AuthenticatingAuthority: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), WorkstationName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), UserSid: win32more.Windows.Win32.Security.PSID, LogonType: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_LOGON_TYPE, TokenSource: POINTER(win32more.Windows.Win32.Security.TOKEN_SOURCE), LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID)) -> Void: ...
@winfunctype_pointer
def PLSA_AUDIT_LOGON_EX(Status: win32more.Windows.Win32.Foundation.NTSTATUS, SubStatus: win32more.Windows.Win32.Foundation.NTSTATUS, AccountName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), AuthenticatingAuthority: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), WorkstationName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), UserSid: win32more.Windows.Win32.Security.PSID, LogonType: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_LOGON_TYPE, ImpersonationLevel: win32more.Windows.Win32.Security.SECURITY_IMPERSONATION_LEVEL, TokenSource: POINTER(win32more.Windows.Win32.Security.TOKEN_SOURCE), LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID)) -> Void: ...
@winfunctype_pointer
def PLSA_CALLBACK_FUNCTION(Argument1: UIntPtr, Argument2: UIntPtr, InputBuffer: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer), OutputBuffer: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_CALL_PACKAGE(AuthenticationPackage: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), ProtocolSubmitBuffer: VoidPtr, SubmitBufferLength: UInt32, ProtocolReturnBuffer: POINTER(VoidPtr), ReturnBufferLength: POINTER(UInt32), ProtocolStatus: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_CALL_PACKAGEEX(AuthenticationPackage: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), ClientBufferBase: VoidPtr, ProtocolSubmitBuffer: VoidPtr, SubmitBufferLength: UInt32, ProtocolReturnBuffer: POINTER(VoidPtr), ReturnBufferLength: POINTER(UInt32), ProtocolStatus: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_CALL_PACKAGE_PASSTHROUGH(AuthenticationPackage: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), ClientBufferBase: VoidPtr, ProtocolSubmitBuffer: VoidPtr, SubmitBufferLength: UInt32, ProtocolReturnBuffer: POINTER(VoidPtr), ReturnBufferLength: POINTER(UInt32), ProtocolStatus: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_CANCEL_NOTIFICATION(NotifyHandle: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_CHECK_PROTECTED_USER_BY_TOKEN(UserToken: win32more.Windows.Win32.Foundation.HANDLE, ProtectedUser: POINTER(win32more.Windows.Win32.Foundation.BOOLEAN)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_CLIENT_CALLBACK(Callback: win32more.Windows.Win32.Foundation.PSTR, Argument1: UIntPtr, Argument2: UIntPtr, Input: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer), Output: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_CLOSE_SAM_USER(UserHandle: VoidPtr) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_CONVERT_AUTH_DATA_TO_TOKEN(UserAuthData: VoidPtr, UserAuthDataSize: UInt32, ImpersonationLevel: win32more.Windows.Win32.Security.SECURITY_IMPERSONATION_LEVEL, TokenSource: POINTER(win32more.Windows.Win32.Security.TOKEN_SOURCE), LogonType: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_LOGON_TYPE, AuthorityName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), Token: POINTER(win32more.Windows.Win32.Foundation.HANDLE), LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), AccountName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), SubStatus: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_COPY_FROM_CLIENT_BUFFER(ClientRequest: POINTER(VoidPtr), Length: UInt32, BufferToCopy: VoidPtr, ClientBaseAddress: VoidPtr) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_COPY_TO_CLIENT_BUFFER(ClientRequest: POINTER(VoidPtr), Length: UInt32, ClientBaseAddress: VoidPtr, BufferToCopy: VoidPtr) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_CRACK_SINGLE_NAME(FormatOffered: UInt32, PerformAtGC: win32more.Windows.Win32.Foundation.BOOLEAN, NameInput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), Prefix: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), RequestedFormat: UInt32, CrackedName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), DnsDomainName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), SubStatus: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_CREATE_LOGON_SESSION(LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_CREATE_SHARED_MEMORY(MaxSize: UInt32, InitialSize: UInt32) -> VoidPtr: ...
@winfunctype_pointer
def PLSA_CREATE_THREAD(SecurityAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES), StackSize: UInt32, StartFunction: win32more.Windows.Win32.System.Threading.LPTHREAD_START_ROUTINE, ThreadParameter: VoidPtr, CreationFlags: UInt32, ThreadId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype_pointer
def PLSA_CREATE_TOKEN(LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), TokenSource: POINTER(win32more.Windows.Win32.Security.TOKEN_SOURCE), LogonType: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_LOGON_TYPE, ImpersonationLevel: win32more.Windows.Win32.Security.SECURITY_IMPERSONATION_LEVEL, TokenInformationType: win32more.Windows.Win32.Security.Authentication.Identity.LSA_TOKEN_INFORMATION_TYPE, TokenInformation: VoidPtr, TokenGroups: POINTER(win32more.Windows.Win32.Security.TOKEN_GROUPS), AccountName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), AuthorityName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), Workstation: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), ProfilePath: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), Token: POINTER(win32more.Windows.Win32.Foundation.HANDLE), SubStatus: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_CREATE_TOKEN_EX(LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), TokenSource: POINTER(win32more.Windows.Win32.Security.TOKEN_SOURCE), LogonType: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_LOGON_TYPE, ImpersonationLevel: win32more.Windows.Win32.Security.SECURITY_IMPERSONATION_LEVEL, TokenInformationType: win32more.Windows.Win32.Security.Authentication.Identity.LSA_TOKEN_INFORMATION_TYPE, TokenInformation: VoidPtr, TokenGroups: POINTER(win32more.Windows.Win32.Security.TOKEN_GROUPS), Workstation: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), ProfilePath: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), SessionInformation: VoidPtr, SessionInformationType: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_SESSIONINFO_TYPE, Token: POINTER(win32more.Windows.Win32.Foundation.HANDLE), SubStatus: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_DELETE_CREDENTIAL(LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), AuthenticationPackage: UInt32, PrimaryKeyValue: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_STRING)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_DELETE_LOGON_SESSION(LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_DELETE_SHARED_MEMORY(SharedMem: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype_pointer
def PLSA_DUPLICATE_HANDLE(SourceHandle: win32more.Windows.Win32.Foundation.HANDLE, DestionationHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_EXPAND_AUTH_DATA_FOR_DOMAIN(UserAuthData: POINTER(Byte), UserAuthDataSize: UInt32, Reserved: VoidPtr, ExpandedAuthData: POINTER(POINTER(Byte)), ExpandedAuthDataSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_FREE_CLIENT_BUFFER(ClientRequest: POINTER(VoidPtr), ClientBaseAddress: VoidPtr) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_FREE_LSA_HEAP(Base: VoidPtr) -> Void: ...
@winfunctype_pointer
def PLSA_FREE_PRIVATE_HEAP(Base: VoidPtr) -> Void: ...
@winfunctype_pointer
def PLSA_FREE_SHARED_MEMORY(SharedMem: VoidPtr, Memory: VoidPtr) -> Void: ...
@winfunctype_pointer
def PLSA_GET_APP_MODE_INFO(UserFunction: POINTER(UInt32), Argument1: POINTER(UIntPtr), Argument2: POINTER(UIntPtr), UserData: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer), ReturnToLsa: POINTER(win32more.Windows.Win32.Foundation.BOOLEAN)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_GET_AUTH_DATA_FOR_USER(Name: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_STRING), NameType: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_NAME_TYPE, Prefix: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_STRING), UserAuthData: POINTER(POINTER(Byte)), UserAuthDataSize: POINTER(UInt32), UserFlatName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_GET_CALL_INFO(Info: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CALL_INFO)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype_pointer
def PLSA_GET_CLIENT_INFO(ClientInfo: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CLIENT_INFO)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_GET_CLIENT_INFO_EX(ClientInfo: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CLIENT_INFO_EX), StructSize: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_GET_CREDENTIALS(LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), AuthenticationPackage: UInt32, QueryContext: POINTER(UInt32), RetrieveAllCredentials: win32more.Windows.Win32.Foundation.BOOLEAN, PrimaryKeyValue: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_STRING), PrimaryKeyLength: POINTER(UInt32), Credentials: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_STRING)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_GET_EXTENDED_CALL_FLAGS(Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_GET_SERVICE_ACCOUNT_PASSWORD(AccountName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), DomainName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), CredFetch: win32more.Windows.Win32.Security.Authentication.Identity.CRED_FETCH, FileTimeExpiry: POINTER(win32more.Windows.Win32.Foundation.FILETIME), CurrentPassword: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), PreviousPassword: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), FileTimeCurrPwdValidForOutbound: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_GET_USER_AUTH_DATA(UserHandle: VoidPtr, UserAuthData: POINTER(POINTER(Byte)), UserAuthDataSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_GET_USER_CREDENTIALS(UserHandle: VoidPtr, PrimaryCreds: POINTER(VoidPtr), PrimaryCredsSize: POINTER(UInt32), SupplementalCreds: POINTER(VoidPtr), SupplementalCredsSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_IMPERSONATE_CLIENT() -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_LOCATE_PKG_BY_ID(PackgeId: UInt32) -> VoidPtr: ...
@winfunctype_pointer
def PLSA_MAP_BUFFER(InputBuffer: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer), OutputBuffer: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_OPEN_SAM_USER(Name: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_STRING), NameType: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_NAME_TYPE, Prefix: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_STRING), AllowGuest: win32more.Windows.Win32.Foundation.BOOLEAN, Reserved: UInt32, UserHandle: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_OPEN_TOKEN_BY_LOGON_ID(LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), RetTokenHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_PROTECT_MEMORY(Buffer: VoidPtr, BufferSize: UInt32) -> Void: ...
@winfunctype_pointer
def PLSA_QUERY_CLIENT_REQUEST(ClientRequest: POINTER(VoidPtr), QueryType: UInt32, ReplyBuffer: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_REDIRECTED_LOGON_CALLBACK(RedirectedLogonHandle: win32more.Windows.Win32.Foundation.HANDLE, Buffer: VoidPtr, BufferLength: UInt32, ReturnBuffer: POINTER(VoidPtr), ReturnBufferLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_REDIRECTED_LOGON_CLEANUP_CALLBACK(RedirectedLogonHandle: win32more.Windows.Win32.Foundation.HANDLE) -> Void: ...
@winfunctype_pointer
def PLSA_REDIRECTED_LOGON_GET_LOGON_CREDS(RedirectedLogonHandle: win32more.Windows.Win32.Foundation.HANDLE, LogonBuffer: POINTER(POINTER(Byte)), LogonBufferLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_REDIRECTED_LOGON_GET_SID(RedirectedLogonHandle: win32more.Windows.Win32.Foundation.HANDLE, Sid: POINTER(win32more.Windows.Win32.Security.PSID)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_REDIRECTED_LOGON_GET_SUPP_CREDS(RedirectedLogonHandle: win32more.Windows.Win32.Foundation.HANDLE, SupplementalCredentials: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_SUPPLEMENTAL_CRED_ARRAY))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_REDIRECTED_LOGON_INIT(RedirectedLogonHandle: win32more.Windows.Win32.Foundation.HANDLE, PackageName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), SessionId: UInt32, LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_REGISTER_CALLBACK(CallbackId: UInt32, Callback: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_CALLBACK_FUNCTION) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_REGISTER_NOTIFICATION(StartFunction: win32more.Windows.Win32.System.Threading.LPTHREAD_START_ROUTINE, Parameter: VoidPtr, NotificationType: UInt32, NotificationClass: UInt32, NotificationFlags: UInt32, IntervalMinutes: UInt32, WaitEvent: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype_pointer
def PLSA_SAVE_SUPPLEMENTAL_CREDENTIALS(LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), SupplementalCredSize: UInt32, SupplementalCreds: VoidPtr, Synchronous: win32more.Windows.Win32.Foundation.BOOLEAN) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_SET_APP_MODE_INFO(UserFunction: UInt32, Argument1: UIntPtr, Argument2: UIntPtr, UserData: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer), ReturnToLsa: win32more.Windows.Win32.Foundation.BOOLEAN) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_UNLOAD_PACKAGE() -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PLSA_UPDATE_PRIMARY_CREDENTIALS(PrimaryCredentials: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_PRIMARY_CRED), Credentials: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_SUPPLEMENTAL_CRED_ARRAY)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
class POLICY_ACCOUNT_DOMAIN_INFO(Structure):
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DomainSid: win32more.Windows.Win32.Security.PSID
class POLICY_AUDIT_CATEGORIES_INFO(Structure):
    MaximumCategoryCount: UInt32
    SubCategoriesInfo: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.POLICY_AUDIT_SUBCATEGORIES_INFO)
class POLICY_AUDIT_EVENTS_INFO(Structure):
    AuditingMode: win32more.Windows.Win32.Foundation.BOOLEAN
    EventAuditingOptions: POINTER(UInt32)
    MaximumAuditEventCount: UInt32
POLICY_AUDIT_EVENT_TYPE = Int32
AuditCategorySystem: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_AUDIT_EVENT_TYPE = 0
AuditCategoryLogon: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_AUDIT_EVENT_TYPE = 1
AuditCategoryObjectAccess: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_AUDIT_EVENT_TYPE = 2
AuditCategoryPrivilegeUse: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_AUDIT_EVENT_TYPE = 3
AuditCategoryDetailedTracking: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_AUDIT_EVENT_TYPE = 4
AuditCategoryPolicyChange: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_AUDIT_EVENT_TYPE = 5
AuditCategoryAccountManagement: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_AUDIT_EVENT_TYPE = 6
AuditCategoryDirectoryServiceAccess: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_AUDIT_EVENT_TYPE = 7
AuditCategoryAccountLogon: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_AUDIT_EVENT_TYPE = 8
class POLICY_AUDIT_FULL_QUERY_INFO(Structure):
    ShutDownOnFull: win32more.Windows.Win32.Foundation.BOOLEAN
    LogIsFull: win32more.Windows.Win32.Foundation.BOOLEAN
class POLICY_AUDIT_FULL_SET_INFO(Structure):
    ShutDownOnFull: win32more.Windows.Win32.Foundation.BOOLEAN
class POLICY_AUDIT_LOG_INFO(Structure):
    AuditLogPercentFull: UInt32
    MaximumLogSize: UInt32
    AuditRetentionPeriod: Int64
    AuditLogFullShutdownInProgress: win32more.Windows.Win32.Foundation.BOOLEAN
    TimeToShutdown: Int64
    NextAuditRecordId: UInt32
class POLICY_AUDIT_SID_ARRAY(Structure):
    UsersCount: UInt32
    UserSidArray: POINTER(win32more.Windows.Win32.Security.PSID)
class POLICY_AUDIT_SUBCATEGORIES_INFO(Structure):
    MaximumSubCategoryCount: UInt32
    EventAuditingOptions: POINTER(UInt32)
class POLICY_DEFAULT_QUOTA_INFO(Structure):
    QuotaLimits: win32more.Windows.Win32.Security.QUOTA_LIMITS
class POLICY_DNS_DOMAIN_INFO(Structure):
    Name: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DnsDomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DnsForestName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DomainGuid: Guid
    Sid: win32more.Windows.Win32.Security.PSID
class POLICY_DOMAIN_EFS_INFO(Structure):
    InfoLength: UInt32
    EfsBlob: POINTER(Byte)
POLICY_DOMAIN_INFORMATION_CLASS = Int32
PolicyDomainEfsInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_DOMAIN_INFORMATION_CLASS = 2
PolicyDomainKerberosTicketInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_DOMAIN_INFORMATION_CLASS = 3
class POLICY_DOMAIN_KERBEROS_TICKET_INFO(Structure):
    AuthenticationOptions: UInt32
    MaxServiceTicketAge: Int64
    MaxTicketAge: Int64
    MaxRenewAge: Int64
    MaxClockSkew: Int64
    Reserved: Int64
POLICY_INFORMATION_CLASS = Int32
PolicyAuditLogInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS = 1
PolicyAuditEventsInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS = 2
PolicyPrimaryDomainInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS = 3
PolicyPdAccountInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS = 4
PolicyAccountDomainInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS = 5
PolicyLsaServerRoleInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS = 6
PolicyReplicaSourceInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS = 7
PolicyDefaultQuotaInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS = 8
PolicyModificationInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS = 9
PolicyAuditFullSetInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS = 10
PolicyAuditFullQueryInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS = 11
PolicyDnsDomainInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS = 12
PolicyDnsDomainInformationInt: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS = 13
PolicyLocalAccountDomainInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS = 14
PolicyMachineAccountInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS = 15
PolicyMachineAccountInformation2: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS = 16
PolicyLastEntry: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_INFORMATION_CLASS = 17
POLICY_LSA_SERVER_ROLE = Int32
PolicyServerRoleBackup: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_LSA_SERVER_ROLE = 2
PolicyServerRolePrimary: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_LSA_SERVER_ROLE = 3
class POLICY_LSA_SERVER_ROLE_INFO(Structure):
    LsaServerRole: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_LSA_SERVER_ROLE
class POLICY_MACHINE_ACCT_INFO(Structure):
    Rid: UInt32
    Sid: win32more.Windows.Win32.Security.PSID
class POLICY_MACHINE_ACCT_INFO2(Structure):
    Rid: UInt32
    Sid: win32more.Windows.Win32.Security.PSID
    ObjectGuid: Guid
class POLICY_MODIFICATION_INFO(Structure):
    ModifiedId: Int64
    DatabaseCreationTime: Int64
POLICY_NOTIFICATION_INFORMATION_CLASS = Int32
PolicyNotifyAuditEventsInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_NOTIFICATION_INFORMATION_CLASS = 1
PolicyNotifyAccountDomainInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_NOTIFICATION_INFORMATION_CLASS = 2
PolicyNotifyServerRoleInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_NOTIFICATION_INFORMATION_CLASS = 3
PolicyNotifyDnsDomainInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_NOTIFICATION_INFORMATION_CLASS = 4
PolicyNotifyDomainEfsInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_NOTIFICATION_INFORMATION_CLASS = 5
PolicyNotifyDomainKerberosTicketInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_NOTIFICATION_INFORMATION_CLASS = 6
PolicyNotifyMachineAccountPasswordInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_NOTIFICATION_INFORMATION_CLASS = 7
PolicyNotifyGlobalSaclInformation: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_NOTIFICATION_INFORMATION_CLASS = 8
PolicyNotifyMax: win32more.Windows.Win32.Security.Authentication.Identity.POLICY_NOTIFICATION_INFORMATION_CLASS = 9
class POLICY_PD_ACCOUNT_INFO(Structure):
    Name: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
class POLICY_PRIMARY_DOMAIN_INFO(Structure):
    Name: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Sid: win32more.Windows.Win32.Security.PSID
class POLICY_REPLICA_SOURCE_INFO(Structure):
    ReplicaSource: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ReplicaAccountName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
@winfunctype_pointer
def PSAM_CREDENTIAL_UPDATE_FREE_ROUTINE(p: VoidPtr) -> Void: ...
@winfunctype_pointer
def PSAM_CREDENTIAL_UPDATE_NOTIFY_ROUTINE(ClearPassword: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), OldCredentials: VoidPtr, OldCredentialSize: UInt32, UserAccountControl: UInt32, UPN: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), UserName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), NetbiosDomainName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), DnsDomainName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), NewCredentials: POINTER(VoidPtr), NewCredentialSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PSAM_CREDENTIAL_UPDATE_REGISTER_MAPPED_ENTRYPOINTS_ROUTINE(Table: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SAM_REGISTER_MAPPING_TABLE)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def PSAM_CREDENTIAL_UPDATE_REGISTER_ROUTINE(CredentialName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype_pointer
def PSAM_INIT_NOTIFICATION_ROUTINE() -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype_pointer
def PSAM_PASSWORD_FILTER_ROUTINE(AccountName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), FullName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), Password: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), SetOperation: win32more.Windows.Win32.Foundation.BOOLEAN) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype_pointer
def PSAM_PASSWORD_NOTIFICATION_ROUTINE(UserName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), RelativeId: UInt32, NewPassword: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
class PctPublicKey(Structure):
    Type: UInt32
    cbKey: UInt32
    pKey: Byte * 1
@winfunctype_pointer
def QUERY_CONTEXT_ATTRIBUTES_EX_FN_A(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: UInt32, param2: VoidPtr, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def QUERY_CONTEXT_ATTRIBUTES_EX_FN_W(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: UInt32, param2: VoidPtr, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
QUERY_CONTEXT_ATTRIBUTES_EX_FN = UnicodeAlias('QUERY_CONTEXT_ATTRIBUTES_EX_FN_W')
@winfunctype_pointer
def QUERY_CONTEXT_ATTRIBUTES_FN_A(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: UInt32, param2: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def QUERY_CONTEXT_ATTRIBUTES_FN_W(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: UInt32, param2: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
QUERY_CONTEXT_ATTRIBUTES_FN = UnicodeAlias('QUERY_CONTEXT_ATTRIBUTES_FN_W')
@winfunctype_pointer
def QUERY_CREDENTIALS_ATTRIBUTES_EX_FN_A(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: UInt32, param2: VoidPtr, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def QUERY_CREDENTIALS_ATTRIBUTES_EX_FN_W(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: UInt32, param2: VoidPtr, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
QUERY_CREDENTIALS_ATTRIBUTES_EX_FN = UnicodeAlias('QUERY_CREDENTIALS_ATTRIBUTES_EX_FN_W')
@winfunctype_pointer
def QUERY_CREDENTIALS_ATTRIBUTES_FN_A(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: UInt32, param2: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def QUERY_CREDENTIALS_ATTRIBUTES_FN_W(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: UInt32, param2: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
QUERY_CREDENTIALS_ATTRIBUTES_FN = UnicodeAlias('QUERY_CREDENTIALS_ATTRIBUTES_FN_W')
@winfunctype_pointer
def QUERY_SECURITY_CONTEXT_TOKEN_FN(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def QUERY_SECURITY_PACKAGE_INFO_FN_A(param0: POINTER(SByte), param1: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgInfoA))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def QUERY_SECURITY_PACKAGE_INFO_FN_W(param0: POINTER(UInt16), param1: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgInfoW))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
QUERY_SECURITY_PACKAGE_INFO_FN = UnicodeAlias('QUERY_SECURITY_PACKAGE_INFO_FN_W')
@winfunctype_pointer
def REVERT_SECURITY_CONTEXT_FN(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class SAM_REGISTER_MAPPING_ELEMENT(Structure):
    Original: win32more.Windows.Win32.Foundation.PSTR
    Mapped: win32more.Windows.Win32.Foundation.PSTR
    Continuable: win32more.Windows.Win32.Foundation.BOOLEAN
class SAM_REGISTER_MAPPING_LIST(Structure):
    Count: UInt32
    Elements: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SAM_REGISTER_MAPPING_ELEMENT)
class SAM_REGISTER_MAPPING_TABLE(Structure):
    Count: UInt32
    Lists: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SAM_REGISTER_MAPPING_LIST)
SASL_AUTHZID_STATE = Int32
Sasl_AuthZIDForbidden: win32more.Windows.Win32.Security.Authentication.Identity.SASL_AUTHZID_STATE = 0
Sasl_AuthZIDProcessed: win32more.Windows.Win32.Security.Authentication.Identity.SASL_AUTHZID_STATE = 1
class SCHANNEL_ALERT_TOKEN(Structure):
    dwTokenType: UInt32
    dwAlertType: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_ALERT_TOKEN_ALERT_TYPE
    dwAlertNumber: UInt32
SCHANNEL_ALERT_TOKEN_ALERT_TYPE = UInt32
TLS1_ALERT_WARNING: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_ALERT_TOKEN_ALERT_TYPE = 1
TLS1_ALERT_FATAL: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_ALERT_TOKEN_ALERT_TYPE = 2
class SCHANNEL_CERT_HASH(Structure):
    dwLength: UInt32
    dwFlags: UInt32
    hProv: UIntPtr
    ShaHash: Byte * 20
class SCHANNEL_CERT_HASH_STORE(Structure):
    dwLength: UInt32
    dwFlags: UInt32
    hProv: UIntPtr
    ShaHash: Byte * 20
    pwszStoreName: Char * 128
class SCHANNEL_CLIENT_SIGNATURE(Structure):
    cbLength: UInt32
    aiHash: win32more.Windows.Win32.Security.Cryptography.ALG_ID
    cbHash: UInt32
    HashValue: Byte * 36
    CertThumbprint: Byte * 20
class SCHANNEL_CRED(Structure):
    dwVersion: UInt32
    cCreds: UInt32
    paCred: POINTER(POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_CONTEXT))
    hRootStore: win32more.Windows.Win32.Security.Cryptography.HCERTSTORE
    cMappers: UInt32
    aphMappers: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity._HMAPPER))
    cSupportedAlgs: UInt32
    palgSupportedAlgs: POINTER(win32more.Windows.Win32.Security.Cryptography.ALG_ID)
    grbitEnabledProtocols: UInt32
    dwMinimumCipherStrength: UInt32
    dwMaximumCipherStrength: UInt32
    dwSessionLifespan: UInt32
    dwFlags: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS
    dwCredFormat: UInt32
SCHANNEL_CRED_FLAGS = UInt32
SCH_CRED_AUTO_CRED_VALIDATION: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS = 32
SCH_CRED_CACHE_ONLY_URL_RETRIEVAL_ON_CREATE: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS = 131072
SCH_DISABLE_RECONNECTS: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS = 128
SCH_CRED_IGNORE_NO_REVOCATION_CHECK: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS = 2048
SCH_CRED_IGNORE_REVOCATION_OFFLINE: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS = 4096
SCH_CRED_MANUAL_CRED_VALIDATION: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS = 8
SCH_CRED_NO_DEFAULT_CREDS: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS = 16
SCH_CRED_NO_SERVERNAME_CHECK: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS = 4
SCH_CRED_NO_SYSTEM_MAPPER: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS = 2
SCH_CRED_REVOCATION_CHECK_CHAIN: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS = 512
SCH_CRED_REVOCATION_CHECK_CHAIN_EXCLUDE_ROOT: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS = 1024
SCH_CRED_REVOCATION_CHECK_END_CERT: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS = 256
SCH_CRED_USE_DEFAULT_CREDS: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS = 64
SCH_SEND_AUX_RECORD: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS = 2097152
SCH_SEND_ROOT_CERT: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS = 262144
SCH_USE_STRONG_CRYPTO: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS = 4194304
SCH_USE_PRESHAREDKEY_ONLY: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_CRED_FLAGS = 8388608
class SCHANNEL_SESSION_TOKEN(Structure):
    dwTokenType: UInt32
    dwFlags: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_SESSION_TOKEN_FLAGS
SCHANNEL_SESSION_TOKEN_FLAGS = UInt32
SSL_SESSION_ENABLE_RECONNECTS: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_SESSION_TOKEN_FLAGS = 1
SSL_SESSION_DISABLE_RECONNECTS: win32more.Windows.Win32.Security.Authentication.Identity.SCHANNEL_SESSION_TOKEN_FLAGS = 2
class SCH_CRED(Structure):
    dwVersion: UInt32
    cCreds: UInt32
    paSecret: POINTER(VoidPtr)
    paPublic: POINTER(VoidPtr)
    cMappers: UInt32
    aphMappers: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity._HMAPPER))
class SCH_CREDENTIALS(Structure):
    dwVersion: UInt32
    dwCredFormat: UInt32
    cCreds: UInt32
    paCred: POINTER(POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_CONTEXT))
    hRootStore: win32more.Windows.Win32.Security.Cryptography.HCERTSTORE
    cMappers: UInt32
    aphMappers: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity._HMAPPER))
    dwSessionLifespan: UInt32
    dwFlags: UInt32
    cTlsParameters: UInt32
    pTlsParameters: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.TLS_PARAMETERS)
class SCH_CRED_PUBLIC_CERTCHAIN(Structure):
    dwType: UInt32
    cbCertChain: UInt32
    pCertChain: POINTER(Byte)
class SCH_CRED_SECRET_CAPI(Structure):
    dwType: UInt32
    hProv: UIntPtr
class SCH_CRED_SECRET_PRIVKEY(Structure):
    dwType: UInt32
    pPrivateKey: POINTER(Byte)
    cbPrivateKey: UInt32
    pszPassword: win32more.Windows.Win32.Foundation.PSTR
class SCH_EXTENSION_DATA(Structure):
    ExtensionType: UInt16
    pExtData: POINTER(Byte)
    cbExtData: UInt32
class SECPKG_APP_MODE_INFO(Structure):
    UserFunction: UInt32
    Argument1: UIntPtr
    Argument2: UIntPtr
    UserData: win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer
    ReturnToLsa: win32more.Windows.Win32.Foundation.BOOLEAN
SECPKG_ATTR = UInt32
SECPKG_ATTR_C_ACCESS_TOKEN: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 2147483666
SECPKG_ATTR_C_FULL_ACCESS_TOKEN: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 2147483778
SECPKG_ATTR_CERT_TRUST_STATUS: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 2147483780
SECPKG_ATTR_CREDS: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 2147483776
SECPKG_ATTR_CREDS_2: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 2147483782
SECPKG_ATTR_NEGOTIATION_PACKAGE: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 2147483777
SECPKG_ATTR_PACKAGE_INFO: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 10
SECPKG_ATTR_SERVER_AUTH_FLAGS: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 2147483779
SECPKG_ATTR_SIZES: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 0
SECPKG_ATTR_SUBJECT_SECURITY_ATTRIBUTES: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 124
SECPKG_ATTR_APP_DATA: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 94
SECPKG_ATTR_EAP_PRF_INFO: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 101
SECPKG_ATTR_EARLY_START: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 105
SECPKG_ATTR_DTLS_MTU: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 34
SECPKG_ATTR_KEYING_MATERIAL_INFO: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 106
SECPKG_ATTR_ACCESS_TOKEN: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 18
SECPKG_ATTR_AUTHORITY: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 6
SECPKG_ATTR_CLIENT_SPECIFIED_TARGET: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 27
SECPKG_ATTR_CONNECTION_INFO: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 90
SECPKG_ATTR_DCE_INFO: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 3
SECPKG_ATTR_ENDPOINT_BINDINGS: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 26
SECPKG_ATTR_EAP_KEY_BLOCK: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 91
SECPKG_ATTR_FLAGS: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 14
SECPKG_ATTR_ISSUER_LIST_EX: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 89
SECPKG_ATTR_KEY_INFO: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 5
SECPKG_ATTR_LAST_CLIENT_TOKEN_STATUS: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 30
SECPKG_ATTR_LIFESPAN: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 2
SECPKG_ATTR_LOCAL_CERT_CONTEXT: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 84
SECPKG_ATTR_LOCAL_CRED: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 82
SECPKG_ATTR_NAMES: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 1
SECPKG_ATTR_NATIVE_NAMES: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 13
SECPKG_ATTR_NEGOTIATION_INFO: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 12
SECPKG_ATTR_PASSWORD_EXPIRY: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 8
SECPKG_ATTR_REMOTE_CERT_CONTEXT: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 83
SECPKG_ATTR_ROOT_STORE: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 85
SECPKG_ATTR_SESSION_KEY: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 9
SECPKG_ATTR_SESSION_INFO: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 93
SECPKG_ATTR_STREAM_SIZES: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 4
SECPKG_ATTR_SUPPORTED_SIGNATURES: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 102
SECPKG_ATTR_TARGET_INFORMATION: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 17
SECPKG_ATTR_UNIQUE_BINDINGS: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR = 25
SECPKG_ATTR_LCT_STATUS = Int32
SecPkgAttrLastClientTokenYes: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR_LCT_STATUS = 0
SecPkgAttrLastClientTokenNo: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR_LCT_STATUS = 1
SecPkgAttrLastClientTokenMaybe: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR_LCT_STATUS = 2
class SECPKG_BYTE_VECTOR(Structure):
    ByteArrayOffset: UInt32
    ByteArrayLength: UInt16
class SECPKG_CALL_INFO(Structure):
    ProcessId: UInt32
    ThreadId: UInt32
    Attributes: UInt32
    CallCount: UInt32
    MechOid: VoidPtr
SECPKG_CALL_PACKAGE_MESSAGE_TYPE = Int32
SecPkgCallPackageMinMessage: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CALL_PACKAGE_MESSAGE_TYPE = 1024
SecPkgCallPackagePinDcMessage: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CALL_PACKAGE_MESSAGE_TYPE = 1024
SecPkgCallPackageUnpinAllDcsMessage: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CALL_PACKAGE_MESSAGE_TYPE = 1025
SecPkgCallPackageTransferCredMessage: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CALL_PACKAGE_MESSAGE_TYPE = 1026
SecPkgCallPackageMaxMessage: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CALL_PACKAGE_MESSAGE_TYPE = 1026
class SECPKG_CALL_PACKAGE_PIN_DC_REQUEST(Structure):
    MessageType: UInt32
    Flags: UInt32
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DcName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DcFlags: UInt32
class SECPKG_CALL_PACKAGE_TRANSFER_CRED_REQUEST(Structure):
    MessageType: UInt32
    OriginLogonId: win32more.Windows.Win32.Foundation.LUID
    DestinationLogonId: win32more.Windows.Win32.Foundation.LUID
    Flags: UInt32
class SECPKG_CALL_PACKAGE_UNPIN_ALL_DCS_REQUEST(Structure):
    MessageType: UInt32
    Flags: UInt32
class SECPKG_CLIENT_INFO(Structure):
    LogonId: win32more.Windows.Win32.Foundation.LUID
    ProcessID: UInt32
    ThreadID: UInt32
    HasTcbPrivilege: win32more.Windows.Win32.Foundation.BOOLEAN
    Impersonating: win32more.Windows.Win32.Foundation.BOOLEAN
    Restricted: win32more.Windows.Win32.Foundation.BOOLEAN
    ClientFlags: Byte
    ImpersonationLevel: win32more.Windows.Win32.Security.SECURITY_IMPERSONATION_LEVEL
    ClientToken: win32more.Windows.Win32.Foundation.HANDLE
class SECPKG_CLIENT_INFO_EX(Structure):
    LogonId: win32more.Windows.Win32.Foundation.LUID
    ProcessID: UInt32
    ThreadID: UInt32
    HasTcbPrivilege: win32more.Windows.Win32.Foundation.BOOLEAN
    Impersonating: win32more.Windows.Win32.Foundation.BOOLEAN
    Restricted: win32more.Windows.Win32.Foundation.BOOLEAN
    ClientFlags: Byte
    ImpersonationLevel: win32more.Windows.Win32.Security.SECURITY_IMPERSONATION_LEVEL
    ClientToken: win32more.Windows.Win32.Foundation.HANDLE
    IdentificationLogonId: win32more.Windows.Win32.Foundation.LUID
    IdentificationToken: win32more.Windows.Win32.Foundation.HANDLE
class SECPKG_CONTEXT_THUNKS(Structure):
    InfoLevelCount: UInt32
    Levels: UInt32 * 1
SECPKG_CRED = UInt32
SECPKG_CRED_INBOUND: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CRED = 1
SECPKG_CRED_OUTBOUND: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CRED = 2
class SECPKG_CREDENTIAL(Structure):
    Version: UInt64
    cbHeaderLength: UInt16
    cbStructureLength: UInt32
    ClientProcess: UInt32
    ClientThread: UInt32
    LogonId: win32more.Windows.Win32.Foundation.LUID
    ClientToken: win32more.Windows.Win32.Foundation.HANDLE
    SessionId: UInt32
    ModifiedId: win32more.Windows.Win32.Foundation.LUID
    fCredentials: UInt32
    Flags: UInt32
    PrincipalName: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_BYTE_VECTOR
    PackageList: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_BYTE_VECTOR
    MarshaledSuppliedCreds: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_BYTE_VECTOR
SECPKG_CRED_CLASS = Int32
SecPkgCredClass_None: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CRED_CLASS = 0
SecPkgCredClass_Ephemeral: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CRED_CLASS = 10
SecPkgCredClass_PersistedGeneric: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CRED_CLASS = 20
SecPkgCredClass_PersistedSpecific: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CRED_CLASS = 30
SecPkgCredClass_Explicit: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CRED_CLASS = 40
class SECPKG_DLL_FUNCTIONS(Structure):
    AllocateHeap: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_ALLOCATE_LSA_HEAP
    FreeHeap: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_FREE_LSA_HEAP
    RegisterCallback: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_REGISTER_CALLBACK
    LocatePackageById: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_LOCATE_PKG_BY_ID
class SECPKG_EVENT_NOTIFY(Structure):
    EventClass: UInt32
    Reserved: UInt32
    EventDataSize: UInt32
    EventData: VoidPtr
    PackageParameter: VoidPtr
class SECPKG_EVENT_PACKAGE_CHANGE(Structure):
    ChangeType: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_PACKAGE_CHANGE_TYPE
    PackageId: UIntPtr
    PackageName: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_STRING
class SECPKG_EVENT_ROLE_CHANGE(Structure):
    PreviousRole: UInt32
    NewRole: UInt32
class SECPKG_EXTENDED_INFORMATION(Structure):
    Class: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_EXTENDED_INFORMATION_CLASS
    Info: _Info_e__Union
    class _Info_e__Union(Union):
        GssInfo: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_GSS_INFO
        ContextThunks: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CONTEXT_THUNKS
        MutualAuthLevel: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_MUTUAL_AUTH_LEVEL
        WowClientDll: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_WOW_CLIENT_DLL
        ExtraOids: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_EXTRA_OIDS
        Nego2Info: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_NEGO2_INFO
SECPKG_EXTENDED_INFORMATION_CLASS = Int32
SecpkgGssInfo: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_EXTENDED_INFORMATION_CLASS = 1
SecpkgContextThunks: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_EXTENDED_INFORMATION_CLASS = 2
SecpkgMutualAuthLevel: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_EXTENDED_INFORMATION_CLASS = 3
SecpkgWowClientDll: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_EXTENDED_INFORMATION_CLASS = 4
SecpkgExtraOids: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_EXTENDED_INFORMATION_CLASS = 5
SecpkgMaxInfo: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_EXTENDED_INFORMATION_CLASS = 6
SecpkgNego2Info: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_EXTENDED_INFORMATION_CLASS = 7
class SECPKG_EXTRA_OIDS(Structure):
    OidCount: UInt32
    Oids: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_SERIALIZED_OID * 1
class SECPKG_FUNCTION_TABLE(Structure):
    InitializePackage: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_AP_INITIALIZE_PACKAGE
    LogonUserA: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_AP_LOGON_USER
    CallPackage: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_AP_CALL_PACKAGE
    LogonTerminated: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_AP_LOGON_TERMINATED
    CallPackageUntrusted: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_AP_CALL_PACKAGE
    CallPackagePassthrough: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_AP_CALL_PACKAGE_PASSTHROUGH
    LogonUserExA: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_AP_LOGON_USER_EX
    LogonUserEx2: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_AP_LOGON_USER_EX2
    Initialize: win32more.Windows.Win32.Security.Authentication.Identity.SpInitializeFn
    Shutdown: win32more.Windows.Win32.Security.Authentication.Identity.SpShutdownFn
    GetInfo: win32more.Windows.Win32.Security.Authentication.Identity.SpGetInfoFn
    AcceptCredentials: win32more.Windows.Win32.Security.Authentication.Identity.SpAcceptCredentialsFn
    AcquireCredentialsHandleA: win32more.Windows.Win32.Security.Authentication.Identity.SpAcquireCredentialsHandleFn
    QueryCredentialsAttributesA: win32more.Windows.Win32.Security.Authentication.Identity.SpQueryCredentialsAttributesFn
    FreeCredentialsHandle: win32more.Windows.Win32.Security.Authentication.Identity.SpFreeCredentialsHandleFn
    SaveCredentials: win32more.Windows.Win32.Security.Authentication.Identity.SpSaveCredentialsFn
    GetCredentials: win32more.Windows.Win32.Security.Authentication.Identity.SpGetCredentialsFn
    DeleteCredentials: win32more.Windows.Win32.Security.Authentication.Identity.SpDeleteCredentialsFn
    InitLsaModeContext: win32more.Windows.Win32.Security.Authentication.Identity.SpInitLsaModeContextFn
    AcceptLsaModeContext: win32more.Windows.Win32.Security.Authentication.Identity.SpAcceptLsaModeContextFn
    DeleteContext: win32more.Windows.Win32.Security.Authentication.Identity.SpDeleteContextFn
    ApplyControlToken: win32more.Windows.Win32.Security.Authentication.Identity.SpApplyControlTokenFn
    GetUserInfo: win32more.Windows.Win32.Security.Authentication.Identity.SpGetUserInfoFn
    GetExtendedInformation: win32more.Windows.Win32.Security.Authentication.Identity.SpGetExtendedInformationFn
    QueryContextAttributesA: win32more.Windows.Win32.Security.Authentication.Identity.SpQueryContextAttributesFn
    AddCredentialsA: win32more.Windows.Win32.Security.Authentication.Identity.SpAddCredentialsFn
    SetExtendedInformation: win32more.Windows.Win32.Security.Authentication.Identity.SpSetExtendedInformationFn
    SetContextAttributesA: win32more.Windows.Win32.Security.Authentication.Identity.SpSetContextAttributesFn
    SetCredentialsAttributesA: win32more.Windows.Win32.Security.Authentication.Identity.SpSetCredentialsAttributesFn
    ChangeAccountPasswordA: win32more.Windows.Win32.Security.Authentication.Identity.SpChangeAccountPasswordFn
    QueryMetaData: win32more.Windows.Win32.Security.Authentication.Identity.SpQueryMetaDataFn
    ExchangeMetaData: win32more.Windows.Win32.Security.Authentication.Identity.SpExchangeMetaDataFn
    GetCredUIContext: win32more.Windows.Win32.Security.Authentication.Identity.SpGetCredUIContextFn
    UpdateCredentials: win32more.Windows.Win32.Security.Authentication.Identity.SpUpdateCredentialsFn
    ValidateTargetInfo: win32more.Windows.Win32.Security.Authentication.Identity.SpValidateTargetInfoFn
    PostLogonUser: win32more.Windows.Win32.Security.Authentication.Identity.LSA_AP_POST_LOGON_USER
    GetRemoteCredGuardLogonBuffer: win32more.Windows.Win32.Security.Authentication.Identity.SpGetRemoteCredGuardLogonBufferFn
    GetRemoteCredGuardSupplementalCreds: win32more.Windows.Win32.Security.Authentication.Identity.SpGetRemoteCredGuardSupplementalCredsFn
    GetTbalSupplementalCreds: win32more.Windows.Win32.Security.Authentication.Identity.SpGetTbalSupplementalCredsFn
    LogonUserEx3: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_AP_LOGON_USER_EX3
    PreLogonUserSurrogate: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_AP_PRE_LOGON_USER_SURROGATE
    PostLogonUserSurrogate: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_AP_POST_LOGON_USER_SURROGATE
    ExtractTargetInfo: win32more.Windows.Win32.Security.Authentication.Identity.SpExtractTargetInfoFn
class SECPKG_GSS_INFO(Structure):
    EncodedIdLength: UInt32
    EncodedId: Byte * 4
class SECPKG_KERNEL_FUNCTIONS(Structure):
    AllocateHeap: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_ALLOCATE_LSA_HEAP
    FreeHeap: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_FREE_LSA_HEAP
    CreateContextList: win32more.Windows.Win32.Security.Authentication.Identity.PKSEC_CREATE_CONTEXT_LIST
    InsertListEntry: win32more.Windows.Win32.Security.Authentication.Identity.PKSEC_INSERT_LIST_ENTRY
    ReferenceListEntry: win32more.Windows.Win32.Security.Authentication.Identity.PKSEC_REFERENCE_LIST_ENTRY
    DereferenceListEntry: win32more.Windows.Win32.Security.Authentication.Identity.PKSEC_DEREFERENCE_LIST_ENTRY
    SerializeWinntAuthData: win32more.Windows.Win32.Security.Authentication.Identity.PKSEC_SERIALIZE_WINNT_AUTH_DATA
    SerializeSchannelAuthData: win32more.Windows.Win32.Security.Authentication.Identity.PKSEC_SERIALIZE_SCHANNEL_AUTH_DATA
    LocatePackageById: win32more.Windows.Win32.Security.Authentication.Identity.PKSEC_LOCATE_PKG_BY_ID
class SECPKG_KERNEL_FUNCTION_TABLE(Structure):
    Initialize: win32more.Windows.Win32.Security.Authentication.Identity.KspInitPackageFn
    DeleteContext: win32more.Windows.Win32.Security.Authentication.Identity.KspDeleteContextFn
    InitContext: win32more.Windows.Win32.Security.Authentication.Identity.KspInitContextFn
    MapHandle: win32more.Windows.Win32.Security.Authentication.Identity.KspMapHandleFn
    Sign: win32more.Windows.Win32.Security.Authentication.Identity.KspMakeSignatureFn
    Verify: win32more.Windows.Win32.Security.Authentication.Identity.KspVerifySignatureFn
    Seal: win32more.Windows.Win32.Security.Authentication.Identity.KspSealMessageFn
    Unseal: win32more.Windows.Win32.Security.Authentication.Identity.KspUnsealMessageFn
    GetToken: win32more.Windows.Win32.Security.Authentication.Identity.KspGetTokenFn
    QueryAttributes: win32more.Windows.Win32.Security.Authentication.Identity.KspQueryAttributesFn
    CompleteToken: win32more.Windows.Win32.Security.Authentication.Identity.KspCompleteTokenFn
    ExportContext: win32more.Windows.Win32.Security.Authentication.Identity.SpExportSecurityContextFn
    ImportContext: win32more.Windows.Win32.Security.Authentication.Identity.SpImportSecurityContextFn
    SetPackagePagingMode: win32more.Windows.Win32.Security.Authentication.Identity.KspSetPagingModeFn
    SerializeAuthData: win32more.Windows.Win32.Security.Authentication.Identity.KspSerializeAuthDataFn
class SECPKG_MUTUAL_AUTH_LEVEL(Structure):
    MutualAuthLevel: UInt32
SECPKG_NAME_TYPE = Int32
SecNameSamCompatible: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_NAME_TYPE = 0
SecNameAlternateId: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_NAME_TYPE = 1
SecNameFlat: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_NAME_TYPE = 2
SecNameDN: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_NAME_TYPE = 3
SecNameSPN: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_NAME_TYPE = 4
class SECPKG_NEGO2_INFO(Structure):
    AuthScheme: Byte * 16
    PackageFlags: UInt32
class SECPKG_NTLM_TARGETINFO(Structure):
    Flags: UInt32
    MsvAvNbComputerName: win32more.Windows.Win32.Foundation.PWSTR
    MsvAvNbDomainName: win32more.Windows.Win32.Foundation.PWSTR
    MsvAvDnsComputerName: win32more.Windows.Win32.Foundation.PWSTR
    MsvAvDnsDomainName: win32more.Windows.Win32.Foundation.PWSTR
    MsvAvDnsTreeName: win32more.Windows.Win32.Foundation.PWSTR
    MsvAvFlags: UInt32
    MsvAvTimestamp: win32more.Windows.Win32.Foundation.FILETIME
    MsvAvTargetName: win32more.Windows.Win32.Foundation.PWSTR
SECPKG_PACKAGE_CHANGE_TYPE = UInt32
SECPKG_PACKAGE_CHANGE_LOAD: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_PACKAGE_CHANGE_TYPE = 0
SECPKG_PACKAGE_CHANGE_UNLOAD: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_PACKAGE_CHANGE_TYPE = 1
SECPKG_PACKAGE_CHANGE_SELECT: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_PACKAGE_CHANGE_TYPE = 2
class SECPKG_PARAMETERS(Structure):
    Version: UInt32
    MachineState: UInt32
    SetupMode: UInt32
    DomainSid: win32more.Windows.Win32.Security.PSID
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DnsDomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DomainGuid: Guid
class SECPKG_POST_LOGON_USER_INFO(Structure):
    Flags: UInt32
    LogonId: win32more.Windows.Win32.Foundation.LUID
    LinkedLogonId: win32more.Windows.Win32.Foundation.LUID
class SECPKG_PRIMARY_CRED(Structure):
    LogonId: win32more.Windows.Win32.Foundation.LUID
    DownlevelName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Password: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    OldPassword: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    UserSid: win32more.Windows.Win32.Security.PSID
    Flags: UInt32
    DnsDomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Upn: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    LogonServer: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Spare1: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Spare2: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Spare3: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Spare4: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
class SECPKG_PRIMARY_CRED_EX(Structure):
    LogonId: win32more.Windows.Win32.Foundation.LUID
    DownlevelName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Password: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    OldPassword: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    UserSid: win32more.Windows.Win32.Security.PSID
    Flags: UInt32
    DnsDomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Upn: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    LogonServer: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Spare1: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Spare2: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Spare3: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Spare4: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    PackageId: UIntPtr
    PrevLogonId: win32more.Windows.Win32.Foundation.LUID
    FlagsEx: UInt32
class SECPKG_REDIRECTED_LOGON_BUFFER(Structure):
    RedirectedLogonGuid: Guid
    RedirectedLogonHandle: win32more.Windows.Win32.Foundation.HANDLE
    Init: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_REDIRECTED_LOGON_INIT
    Callback: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_REDIRECTED_LOGON_CALLBACK
    CleanupCallback: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_REDIRECTED_LOGON_CLEANUP_CALLBACK
    GetLogonCreds: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_REDIRECTED_LOGON_GET_LOGON_CREDS
    GetSupplementalCreds: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_REDIRECTED_LOGON_GET_SUPP_CREDS
    GetRedirectedLogonSid: win32more.Windows.Win32.Security.Authentication.Identity.PLSA_REDIRECTED_LOGON_GET_SID
class SECPKG_SERIALIZED_OID(Structure):
    OidLength: UInt32
    OidAttributes: UInt32
    OidValue: Byte * 32
SECPKG_SESSIONINFO_TYPE = Int32
SecSessionPrimaryCred: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_SESSIONINFO_TYPE = 0
class SECPKG_SHORT_VECTOR(Structure):
    ShortArrayOffset: UInt32
    ShortArrayCount: UInt16
class SECPKG_SUPPLEMENTAL_CRED(Structure):
    PackageName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    CredentialSize: UInt32
    Credentials: POINTER(Byte)
class SECPKG_SUPPLEMENTAL_CRED_ARRAY(Structure):
    CredentialCount: UInt32
    Credentials: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_SUPPLEMENTAL_CRED * 1
class SECPKG_SUPPLIED_CREDENTIAL(Structure):
    cbHeaderLength: UInt16
    cbStructureLength: UInt16
    UserName: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_SHORT_VECTOR
    DomainName: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_SHORT_VECTOR
    PackedCredentials: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_BYTE_VECTOR
    CredFlags: UInt32
class SECPKG_SURROGATE_LOGON(Structure):
    Version: UInt32
    SurrogateLogonID: win32more.Windows.Win32.Foundation.LUID
    EntryCount: UInt32
    Entries: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_SURROGATE_LOGON_ENTRY)
class SECPKG_SURROGATE_LOGON_ENTRY(Structure):
    Type: Guid
    Data: VoidPtr
class SECPKG_TARGETINFO(Structure):
    DomainSid: win32more.Windows.Win32.Security.PSID
    ComputerName: win32more.Windows.Win32.Foundation.PWSTR
class SECPKG_USER_FUNCTION_TABLE(Structure):
    InstanceInit: win32more.Windows.Win32.Security.Authentication.Identity.SpInstanceInitFn
    InitUserModeContext: win32more.Windows.Win32.Security.Authentication.Identity.SpInitUserModeContextFn
    MakeSignature: win32more.Windows.Win32.Security.Authentication.Identity.SpMakeSignatureFn
    VerifySignature: win32more.Windows.Win32.Security.Authentication.Identity.SpVerifySignatureFn
    SealMessage: win32more.Windows.Win32.Security.Authentication.Identity.SpSealMessageFn
    UnsealMessage: win32more.Windows.Win32.Security.Authentication.Identity.SpUnsealMessageFn
    GetContextToken: win32more.Windows.Win32.Security.Authentication.Identity.SpGetContextTokenFn
    QueryContextAttributesA: win32more.Windows.Win32.Security.Authentication.Identity.SpQueryContextAttributesFn
    CompleteAuthToken: win32more.Windows.Win32.Security.Authentication.Identity.SpCompleteAuthTokenFn
    DeleteUserModeContext: win32more.Windows.Win32.Security.Authentication.Identity.SpDeleteContextFn
    FormatCredentials: win32more.Windows.Win32.Security.Authentication.Identity.SpFormatCredentialsFn
    MarshallSupplementalCreds: win32more.Windows.Win32.Security.Authentication.Identity.SpMarshallSupplementalCredsFn
    ExportContext: win32more.Windows.Win32.Security.Authentication.Identity.SpExportSecurityContextFn
    ImportContext: win32more.Windows.Win32.Security.Authentication.Identity.SpImportSecurityContextFn
    MarshalAttributeData: win32more.Windows.Win32.Security.Authentication.Identity.SpMarshalAttributeDataFn
class SECPKG_WOW_CLIENT_DLL(Structure):
    WowClientDllPath: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_STRING
class SECURITY_LOGON_SESSION_DATA(Structure):
    Size: UInt32
    LogonId: win32more.Windows.Win32.Foundation.LUID
    UserName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    LogonDomain: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    AuthenticationPackage: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    LogonType: UInt32
    Session: UInt32
    Sid: win32more.Windows.Win32.Security.PSID
    LogonTime: Int64
    LogonServer: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    DnsDomainName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Upn: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    UserFlags: UInt32
    LastLogonInfo: win32more.Windows.Win32.Security.Authentication.Identity.LSA_LAST_INTER_LOGON_INFO
    LogonScript: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ProfilePath: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    HomeDirectory: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    HomeDirectoryDrive: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    LogoffTime: Int64
    KickOffTime: Int64
    PasswordLastSet: Int64
    PasswordCanChange: Int64
    PasswordMustChange: Int64
class SECURITY_LOGON_TYPE(Enum, Int32):
    UndefinedLogonType = 0
    Interactive = 2
    Network = 3
    Batch = 4
    Service = 5
    Proxy = 6
    Unlock = 7
    NetworkCleartext = 8
    NewCredentials = 9
    RemoteInteractive = 10
    CachedInteractive = 11
    CachedRemoteInteractive = 12
    CachedUnlock = 13
class SECURITY_PACKAGE_OPTIONS(Structure):
    Size: UInt32
    Type: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_PACKAGE_OPTIONS_TYPE
    Flags: UInt32
    SignatureSize: UInt32
    Signature: VoidPtr
SECURITY_PACKAGE_OPTIONS_TYPE = UInt32
SECPKG_OPTIONS_TYPE_UNKNOWN: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_PACKAGE_OPTIONS_TYPE = 0
SECPKG_OPTIONS_TYPE_LSA: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_PACKAGE_OPTIONS_TYPE = 1
SECPKG_OPTIONS_TYPE_SSPI: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_PACKAGE_OPTIONS_TYPE = 2
class SECURITY_STRING(Structure):
    Length: UInt16
    MaximumLength: UInt16
    Buffer: POINTER(UInt16)
class SECURITY_USER_DATA(Structure):
    UserName: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_STRING
    LogonDomainName: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_STRING
    LogonServer: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_STRING
    pSid: win32more.Windows.Win32.Security.PSID
class SEC_APPLICATION_PROTOCOLS(Structure):
    ProtocolListsSize: UInt32
    ProtocolLists: win32more.Windows.Win32.Security.Authentication.Identity.SEC_APPLICATION_PROTOCOL_LIST * 1
class SEC_APPLICATION_PROTOCOL_LIST(Structure):
    ProtoNegoExt: win32more.Windows.Win32.Security.Authentication.Identity.SEC_APPLICATION_PROTOCOL_NEGOTIATION_EXT
    ProtocolListSize: UInt16
    ProtocolList: Byte * 1
SEC_APPLICATION_PROTOCOL_NEGOTIATION_EXT = Int32
SecApplicationProtocolNegotiationExt_None: win32more.Windows.Win32.Security.Authentication.Identity.SEC_APPLICATION_PROTOCOL_NEGOTIATION_EXT = 0
SecApplicationProtocolNegotiationExt_NPN: win32more.Windows.Win32.Security.Authentication.Identity.SEC_APPLICATION_PROTOCOL_NEGOTIATION_EXT = 1
SecApplicationProtocolNegotiationExt_ALPN: win32more.Windows.Win32.Security.Authentication.Identity.SEC_APPLICATION_PROTOCOL_NEGOTIATION_EXT = 2
SEC_APPLICATION_PROTOCOL_NEGOTIATION_STATUS = Int32
SecApplicationProtocolNegotiationStatus_None: win32more.Windows.Win32.Security.Authentication.Identity.SEC_APPLICATION_PROTOCOL_NEGOTIATION_STATUS = 0
SecApplicationProtocolNegotiationStatus_Success: win32more.Windows.Win32.Security.Authentication.Identity.SEC_APPLICATION_PROTOCOL_NEGOTIATION_STATUS = 1
SecApplicationProtocolNegotiationStatus_SelectedClientOnly: win32more.Windows.Win32.Security.Authentication.Identity.SEC_APPLICATION_PROTOCOL_NEGOTIATION_STATUS = 2
class SEC_CERTIFICATE_REQUEST_CONTEXT(Structure):
    cbCertificateRequestContext: Byte
    rgCertificateRequestContext: Byte * 1
class SEC_CHANNEL_BINDINGS(Structure):
    dwInitiatorAddrType: UInt32
    cbInitiatorLength: UInt32
    dwInitiatorOffset: UInt32
    dwAcceptorAddrType: UInt32
    cbAcceptorLength: UInt32
    dwAcceptorOffset: UInt32
    cbApplicationDataLength: UInt32
    dwApplicationDataOffset: UInt32
class SEC_CHANNEL_BINDINGS_EX(Structure):
    magicNumber: UInt32
    flags: UInt32
    cbHeaderLength: UInt32
    cbStructureLength: UInt32
    dwInitiatorAddrType: UInt32
    cbInitiatorLength: UInt32
    dwInitiatorOffset: UInt32
    dwAcceptorAddrType: UInt32
    cbAcceptorLength: UInt32
    dwAcceptorOffset: UInt32
    cbApplicationDataLength: UInt32
    dwApplicationDataOffset: UInt32
class SEC_CHANNEL_BINDINGS_RESULT(Structure):
    flags: UInt32
class SEC_DTLS_MTU(Structure):
    PathMTU: UInt16
class SEC_FLAGS(Structure):
    Flags: UInt64
@winfunctype_pointer
def SEC_GET_KEY_FN(Arg: VoidPtr, Principal: VoidPtr, KeyVer: UInt32, Key: POINTER(VoidPtr), Status: POINTER(win32more.Windows.Win32.Foundation.HRESULT)) -> Void: ...
class SEC_NEGOTIATION_INFO(Structure):
    Size: UInt32
    NameLength: UInt32
    Name: POINTER(UInt16)
    Reserved: VoidPtr
class SEC_PRESHAREDKEY(Structure):
    KeySize: UInt16
    Key: Byte * 1
class SEC_PRESHAREDKEY_IDENTITY(Structure):
    KeyIdentitySize: UInt16
    KeyIdentity: Byte * 1
class SEC_SRTP_MASTER_KEY_IDENTIFIER(Structure):
    MasterKeyIdentifierSize: Byte
    MasterKeyIdentifier: Byte * 1
class SEC_SRTP_PROTECTION_PROFILES(Structure):
    ProfilesSize: UInt16
    ProfilesList: UInt16 * 1
class SEC_TOKEN_BINDING(Structure):
    MajorVersion: Byte
    MinorVersion: Byte
    KeyParametersSize: UInt16
    KeyParameters: Byte * 1
class SEC_TRAFFIC_SECRETS(Structure):
    SymmetricAlgId: Char * 64
    ChainingMode: Char * 64
    HashAlgId: Char * 64
    KeySize: UInt16
    IvSize: UInt16
    MsgSequenceStart: UInt16
    MsgSequenceEnd: UInt16
    TrafficSecretType: win32more.Windows.Win32.Security.Authentication.Identity.SEC_TRAFFIC_SECRET_TYPE
    TrafficSecretSize: UInt16
    TrafficSecret: Byte * 1
SEC_TRAFFIC_SECRET_TYPE = Int32
SecTrafficSecret_None: win32more.Windows.Win32.Security.Authentication.Identity.SEC_TRAFFIC_SECRET_TYPE = 0
SecTrafficSecret_Client: win32more.Windows.Win32.Security.Authentication.Identity.SEC_TRAFFIC_SECRET_TYPE = 1
SecTrafficSecret_Server: win32more.Windows.Win32.Security.Authentication.Identity.SEC_TRAFFIC_SECRET_TYPE = 2
class SEC_WINNT_AUTH_IDENTITY32(Structure):
    User: UInt32
    UserLength: UInt32
    Domain: UInt32
    DomainLength: UInt32
    Password: UInt32
    PasswordLength: UInt32
    Flags: UInt32
class SEC_WINNT_AUTH_IDENTITY_EX2(Structure):
    Version: UInt32
    cbHeaderLength: UInt16
    cbStructureLength: UInt32
    UserOffset: UInt32
    UserLength: UInt16
    DomainOffset: UInt32
    DomainLength: UInt16
    PackedCredentialsOffset: UInt32
    PackedCredentialsLength: UInt16
    Flags: UInt32
    PackageListOffset: UInt32
    PackageListLength: UInt16
class SEC_WINNT_AUTH_IDENTITY_EX32(Structure):
    Version: UInt32
    Length: UInt32
    User: UInt32
    UserLength: UInt32
    Domain: UInt32
    DomainLength: UInt32
    Password: UInt32
    PasswordLength: UInt32
    Flags: UInt32
    PackageList: UInt32
    PackageListLength: UInt32
class SEC_WINNT_AUTH_IDENTITY_EXA(Structure):
    Version: UInt32
    Length: UInt32
    User: POINTER(Byte)
    UserLength: UInt32
    Domain: POINTER(Byte)
    DomainLength: UInt32
    Password: POINTER(Byte)
    PasswordLength: UInt32
    Flags: UInt32
    PackageList: POINTER(Byte)
    PackageListLength: UInt32
class SEC_WINNT_AUTH_IDENTITY_EXW(Structure):
    Version: UInt32
    Length: UInt32
    User: POINTER(UInt16)
    UserLength: UInt32
    Domain: POINTER(UInt16)
    DomainLength: UInt32
    Password: POINTER(UInt16)
    PasswordLength: UInt32
    Flags: UInt32
    PackageList: POINTER(UInt16)
    PackageListLength: UInt32
SEC_WINNT_AUTH_IDENTITY_EX = UnicodeAlias('SEC_WINNT_AUTH_IDENTITY_EXW')
class SEC_WINNT_AUTH_IDENTITY_INFO(Union):
    AuthIdExw: win32more.Windows.Win32.Security.Authentication.Identity.SEC_WINNT_AUTH_IDENTITY_EXW
    AuthIdExa: win32more.Windows.Win32.Security.Authentication.Identity.SEC_WINNT_AUTH_IDENTITY_EXA
    AuthId_a: win32more.Windows.Win32.System.Rpc.SEC_WINNT_AUTH_IDENTITY_A
    AuthId_w: win32more.Windows.Win32.System.Rpc.SEC_WINNT_AUTH_IDENTITY_W
    AuthIdEx2: win32more.Windows.Win32.Security.Authentication.Identity.SEC_WINNT_AUTH_IDENTITY_EX2
class SEND_GENERIC_TLS_EXTENSION(Structure):
    ExtensionType: UInt16
    HandshakeType: UInt16
    Flags: UInt32
    BufferSize: UInt16
    Buffer: Byte * 1
@winfunctype_pointer
def SET_CONTEXT_ATTRIBUTES_FN_A(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: UInt32, param2: VoidPtr, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def SET_CONTEXT_ATTRIBUTES_FN_W(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: UInt32, param2: VoidPtr, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
SET_CONTEXT_ATTRIBUTES_FN = UnicodeAlias('SET_CONTEXT_ATTRIBUTES_FN_W')
@winfunctype_pointer
def SET_CREDENTIALS_ATTRIBUTES_FN_A(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: UInt32, param2: VoidPtr, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def SET_CREDENTIALS_ATTRIBUTES_FN_W(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: UInt32, param2: VoidPtr, param3: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
SET_CREDENTIALS_ATTRIBUTES_FN = UnicodeAlias('SET_CREDENTIALS_ATTRIBUTES_FN_W')
class SE_ADT_ACCESS_REASON(Structure):
    AccessMask: UInt32
    AccessReasons: UInt32 * 32
    ObjectTypeIndex: UInt32
    AccessGranted: UInt32
    SecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR
class SE_ADT_CLAIMS(Structure):
    Length: UInt32
    Claims: VoidPtr
class SE_ADT_OBJECT_TYPE(Structure):
    ObjectType: Guid
    Flags: UInt16
    Level: UInt16
    AccessMask: UInt32
class SE_ADT_PARAMETER_ARRAY(Structure):
    CategoryId: UInt32
    AuditId: UInt32
    ParameterCount: UInt32
    Length: UInt32
    FlatSubCategoryId: UInt16
    Type: UInt16
    Flags: UInt32
    Parameters: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_ARRAY_ENTRY * 32
class SE_ADT_PARAMETER_ARRAY_ENTRY(Structure):
    Type: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE
    Length: UInt32
    Data: UIntPtr * 2
    Address: VoidPtr
class SE_ADT_PARAMETER_ARRAY_EX(Structure):
    CategoryId: UInt32
    AuditId: UInt32
    Version: UInt32
    ParameterCount: UInt32
    Length: UInt32
    FlatSubCategoryId: UInt16
    Type: UInt16
    Flags: UInt32
    Parameters: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_ARRAY_ENTRY * 32
SE_ADT_PARAMETER_TYPE = Int32
SeAdtParmTypeNone: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 0
SeAdtParmTypeString: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 1
SeAdtParmTypeFileSpec: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 2
SeAdtParmTypeUlong: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 3
SeAdtParmTypeSid: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 4
SeAdtParmTypeLogonId: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 5
SeAdtParmTypeNoLogonId: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 6
SeAdtParmTypeAccessMask: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 7
SeAdtParmTypePrivs: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 8
SeAdtParmTypeObjectTypes: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 9
SeAdtParmTypeHexUlong: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 10
SeAdtParmTypePtr: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 11
SeAdtParmTypeTime: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 12
SeAdtParmTypeGuid: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 13
SeAdtParmTypeLuid: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 14
SeAdtParmTypeHexInt64: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 15
SeAdtParmTypeStringList: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 16
SeAdtParmTypeSidList: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 17
SeAdtParmTypeDuration: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 18
SeAdtParmTypeUserAccountControl: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 19
SeAdtParmTypeNoUac: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 20
SeAdtParmTypeMessage: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 21
SeAdtParmTypeDateTime: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 22
SeAdtParmTypeSockAddr: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 23
SeAdtParmTypeSD: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 24
SeAdtParmTypeLogonHours: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 25
SeAdtParmTypeLogonIdNoSid: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 26
SeAdtParmTypeUlongNoConv: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 27
SeAdtParmTypeSockAddrNoPort: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 28
SeAdtParmTypeAccessReason: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 29
SeAdtParmTypeStagingReason: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 30
SeAdtParmTypeResourceAttribute: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 31
SeAdtParmTypeClaims: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 32
SeAdtParmTypeLogonIdAsSid: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 33
SeAdtParmTypeMultiSzString: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 34
SeAdtParmTypeLogonIdEx: win32more.Windows.Win32.Security.Authentication.Identity.SE_ADT_PARAMETER_TYPE = 35
SLDATATYPE = UInt32
SL_DATA_NONE: win32more.Windows.Win32.Security.Authentication.Identity.SLDATATYPE = 0
SL_DATA_SZ: win32more.Windows.Win32.Security.Authentication.Identity.SLDATATYPE = 1
SL_DATA_DWORD: win32more.Windows.Win32.Security.Authentication.Identity.SLDATATYPE = 4
SL_DATA_BINARY: win32more.Windows.Win32.Security.Authentication.Identity.SLDATATYPE = 3
SL_DATA_MULTI_SZ: win32more.Windows.Win32.Security.Authentication.Identity.SLDATATYPE = 7
SL_DATA_SUM: win32more.Windows.Win32.Security.Authentication.Identity.SLDATATYPE = 100
SLIDTYPE = Int32
SL_ID_APPLICATION: win32more.Windows.Win32.Security.Authentication.Identity.SLIDTYPE = 0
SL_ID_PRODUCT_SKU: win32more.Windows.Win32.Security.Authentication.Identity.SLIDTYPE = 1
SL_ID_LICENSE_FILE: win32more.Windows.Win32.Security.Authentication.Identity.SLIDTYPE = 2
SL_ID_LICENSE: win32more.Windows.Win32.Security.Authentication.Identity.SLIDTYPE = 3
SL_ID_PKEY: win32more.Windows.Win32.Security.Authentication.Identity.SLIDTYPE = 4
SL_ID_ALL_LICENSES: win32more.Windows.Win32.Security.Authentication.Identity.SLIDTYPE = 5
SL_ID_ALL_LICENSE_FILES: win32more.Windows.Win32.Security.Authentication.Identity.SLIDTYPE = 6
SL_ID_STORE_TOKEN: win32more.Windows.Win32.Security.Authentication.Identity.SLIDTYPE = 7
SL_ID_LAST: win32more.Windows.Win32.Security.Authentication.Identity.SLIDTYPE = 8
SLLICENSINGSTATUS = Int32
SL_LICENSING_STATUS_UNLICENSED: win32more.Windows.Win32.Security.Authentication.Identity.SLLICENSINGSTATUS = 0
SL_LICENSING_STATUS_LICENSED: win32more.Windows.Win32.Security.Authentication.Identity.SLLICENSINGSTATUS = 1
SL_LICENSING_STATUS_IN_GRACE_PERIOD: win32more.Windows.Win32.Security.Authentication.Identity.SLLICENSINGSTATUS = 2
SL_LICENSING_STATUS_NOTIFICATION: win32more.Windows.Win32.Security.Authentication.Identity.SLLICENSINGSTATUS = 3
SL_LICENSING_STATUS_LAST: win32more.Windows.Win32.Security.Authentication.Identity.SLLICENSINGSTATUS = 4
SLREFERRALTYPE = Int32
SL_REFERRALTYPE_SKUID: win32more.Windows.Win32.Security.Authentication.Identity.SLREFERRALTYPE = 0
SL_REFERRALTYPE_APPID: win32more.Windows.Win32.Security.Authentication.Identity.SLREFERRALTYPE = 1
SL_REFERRALTYPE_OVERRIDE_SKUID: win32more.Windows.Win32.Security.Authentication.Identity.SLREFERRALTYPE = 2
SL_REFERRALTYPE_OVERRIDE_APPID: win32more.Windows.Win32.Security.Authentication.Identity.SLREFERRALTYPE = 3
SL_REFERRALTYPE_BEST_MATCH: win32more.Windows.Win32.Security.Authentication.Identity.SLREFERRALTYPE = 4
class SL_ACTIVATION_INFO_HEADER(Structure):
    cbSize: UInt32
    type: win32more.Windows.Win32.Security.Authentication.Identity.SL_ACTIVATION_TYPE
SL_ACTIVATION_TYPE = Int32
SL_ACTIVATION_TYPE_DEFAULT: win32more.Windows.Win32.Security.Authentication.Identity.SL_ACTIVATION_TYPE = 0
SL_ACTIVATION_TYPE_ACTIVE_DIRECTORY: win32more.Windows.Win32.Security.Authentication.Identity.SL_ACTIVATION_TYPE = 1
class SL_AD_ACTIVATION_INFO(Structure):
    header: win32more.Windows.Win32.Security.Authentication.Identity.SL_ACTIVATION_INFO_HEADER
    pwszProductKey: win32more.Windows.Win32.Foundation.PWSTR
    pwszActivationObjectName: win32more.Windows.Win32.Foundation.PWSTR
SL_GENUINE_STATE = Int32
SL_GEN_STATE_IS_GENUINE: win32more.Windows.Win32.Security.Authentication.Identity.SL_GENUINE_STATE = 0
SL_GEN_STATE_INVALID_LICENSE: win32more.Windows.Win32.Security.Authentication.Identity.SL_GENUINE_STATE = 1
SL_GEN_STATE_TAMPERED: win32more.Windows.Win32.Security.Authentication.Identity.SL_GENUINE_STATE = 2
SL_GEN_STATE_OFFLINE: win32more.Windows.Win32.Security.Authentication.Identity.SL_GENUINE_STATE = 3
SL_GEN_STATE_LAST: win32more.Windows.Win32.Security.Authentication.Identity.SL_GENUINE_STATE = 4
class SL_LICENSING_STATUS(Structure):
    SkuId: Guid
    eStatus: win32more.Windows.Win32.Security.Authentication.Identity.SLLICENSINGSTATUS
    dwGraceTime: UInt32
    dwTotalGraceDays: UInt32
    hrReason: win32more.Windows.Win32.Foundation.HRESULT
    qwValidityExpiration: UInt64
class SL_NONGENUINE_UI_OPTIONS(Structure):
    cbSize: UInt32
    pComponentId: POINTER(Guid)
    hResultUI: win32more.Windows.Win32.Foundation.HRESULT
class SL_SYSTEM_POLICY_INFORMATION(Structure):
    Reserved1: VoidPtr * 2
    Reserved2: UInt32 * 3
class SR_SECURITY_DESCRIPTOR(Structure):
    Length: UInt32
    SecurityDescriptor: POINTER(Byte)
@winfunctype_pointer
def SSL_CRACK_CERTIFICATE_FN(pbCertificate: POINTER(Byte), cbCertificate: UInt32, VerifySignature: win32more.Windows.Win32.Foundation.BOOL, ppCertificate: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.X509Certificate))) -> win32more.Windows.Win32.Foundation.BOOL: ...
class SSL_CREDENTIAL_CERTIFICATE(Structure):
    cbPrivateKey: UInt32
    pPrivateKey: POINTER(Byte)
    cbCertificate: UInt32
    pCertificate: POINTER(Byte)
    pszPassword: win32more.Windows.Win32.Foundation.PSTR
@winfunctype_pointer
def SSL_EMPTY_CACHE_FN_A(pszTargetName: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def SSL_EMPTY_CACHE_FN_W(pszTargetName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
SSL_EMPTY_CACHE_FN = UnicodeAlias('SSL_EMPTY_CACHE_FN_W')
@winfunctype_pointer
def SSL_FREE_CERTIFICATE_FN(pCertificate: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.X509Certificate)) -> Void: ...
class SUBSCRIBE_GENERIC_TLS_EXTENSION(Structure):
    Flags: UInt32
    SubscriptionsCount: UInt32
    Subscriptions: win32more.Windows.Win32.Security.Authentication.Identity.TLS_EXTENSION_SUBSCRIPTION * 1
SchGetExtensionsOptions = Int32
SCH_EXTENSIONS_OPTIONS_NONE: win32more.Windows.Win32.Security.Authentication.Identity.SchGetExtensionsOptions = 0
SCH_NO_RECORD_HEADER: win32more.Windows.Win32.Security.Authentication.Identity.SchGetExtensionsOptions = 1
class SecBuffer(Structure):
    cbBuffer: UInt32
    BufferType: UInt32
    pvBuffer: VoidPtr
class SecBufferDesc(Structure):
    ulVersion: UInt32
    cBuffers: UInt32
    pBuffers: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer)
SecDelegationType = Int32
SecFull: win32more.Windows.Win32.Security.Authentication.Identity.SecDelegationType = 0
SecService: win32more.Windows.Win32.Security.Authentication.Identity.SecDelegationType = 1
SecTree: win32more.Windows.Win32.Security.Authentication.Identity.SecDelegationType = 2
SecDirectory: win32more.Windows.Win32.Security.Authentication.Identity.SecDelegationType = 3
SecObject: win32more.Windows.Win32.Security.Authentication.Identity.SecDelegationType = 4
class SecPkgContext_AccessToken(Structure):
    AccessToken: VoidPtr
class SecPkgContext_ApplicationProtocol(Structure):
    ProtoNegoStatus: win32more.Windows.Win32.Security.Authentication.Identity.SEC_APPLICATION_PROTOCOL_NEGOTIATION_STATUS
    ProtoNegoExt: win32more.Windows.Win32.Security.Authentication.Identity.SEC_APPLICATION_PROTOCOL_NEGOTIATION_EXT
    ProtocolIdSize: Byte
    ProtocolId: Byte * 255
class SecPkgContext_AuthorityA(Structure):
    sAuthorityName: POINTER(SByte)
class SecPkgContext_AuthorityW(Structure):
    sAuthorityName: POINTER(UInt16)
SecPkgContext_Authority = UnicodeAlias('SecPkgContext_AuthorityW')
class SecPkgContext_AuthzID(Structure):
    AuthzIDLength: UInt32
    AuthzID: win32more.Windows.Win32.Foundation.PSTR
class SecPkgContext_Bindings(Structure):
    BindingsLength: UInt32
    Bindings: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SEC_CHANNEL_BINDINGS)
class SecPkgContext_CertInfo(Structure):
    dwVersion: UInt32
    cbSubjectName: UInt32
    pwszSubjectName: win32more.Windows.Win32.Foundation.PWSTR
    cbIssuerName: UInt32
    pwszIssuerName: win32more.Windows.Win32.Foundation.PWSTR
    dwKeySize: UInt32
class SecPkgContext_CertificateValidationResult(Structure):
    dwChainErrorStatus: UInt32
    hrVerifyChainStatus: win32more.Windows.Win32.Foundation.HRESULT
class SecPkgContext_Certificates(Structure):
    cCertificates: UInt32
    cbCertificateChain: UInt32
    pbCertificateChain: POINTER(Byte)
class SecPkgContext_CipherInfo(Structure):
    dwVersion: UInt32
    dwProtocol: UInt32
    dwCipherSuite: UInt32
    dwBaseCipherSuite: UInt32
    szCipherSuite: Char * 64
    szCipher: Char * 64
    dwCipherLen: UInt32
    dwCipherBlockLen: UInt32
    szHash: Char * 64
    dwHashLen: UInt32
    szExchange: Char * 64
    dwMinExchangeLen: UInt32
    dwMaxExchangeLen: UInt32
    szCertificate: Char * 64
    dwKeyType: UInt32
class SecPkgContext_ClientCertPolicyResult(Structure):
    dwPolicyResult: win32more.Windows.Win32.Foundation.HRESULT
    guidPolicyId: Guid
class SecPkgContext_ClientSpecifiedTarget(Structure):
    sTargetName: POINTER(UInt16)
class SecPkgContext_ConnectionInfo(Structure):
    dwProtocol: UInt32
    aiCipher: win32more.Windows.Win32.Security.Cryptography.ALG_ID
    dwCipherStrength: UInt32
    aiHash: win32more.Windows.Win32.Security.Cryptography.ALG_ID
    dwHashStrength: UInt32
    aiExch: win32more.Windows.Win32.Security.Cryptography.ALG_ID
    dwExchStrength: UInt32
class SecPkgContext_ConnectionInfoEx(Structure):
    dwVersion: UInt32
    dwProtocol: UInt32
    szCipher: Char * 64
    dwCipherStrength: UInt32
    szHash: Char * 64
    dwHashStrength: UInt32
    szExchange: Char * 64
    dwExchStrength: UInt32
class SecPkgContext_CredInfo(Structure):
    CredClass: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_CRED_CLASS
    IsPromptingNeeded: UInt32
class SecPkgContext_CredentialNameA(Structure):
    CredentialType: UInt32
    sCredentialName: POINTER(SByte)
class SecPkgContext_CredentialNameW(Structure):
    CredentialType: UInt32
    sCredentialName: POINTER(UInt16)
SecPkgContext_CredentialName = UnicodeAlias('SecPkgContext_CredentialNameW')
class SecPkgContext_DceInfo(Structure):
    AuthzSvc: UInt32
    pPac: VoidPtr
class SecPkgContext_EapKeyBlock(Structure):
    rgbKeys: Byte * 128
    rgbIVs: Byte * 64
class SecPkgContext_EapPrfInfo(Structure):
    dwVersion: UInt32
    cbPrfData: UInt32
    pbPrfData: POINTER(Byte)
class SecPkgContext_EarlyStart(Structure):
    dwEarlyStartFlags: UInt32
class SecPkgContext_Flags(Structure):
    Flags: UInt32
class SecPkgContext_IssuerListInfoEx(Structure):
    aIssuers: POINTER(win32more.Windows.Win32.Security.Cryptography.CRYPT_INTEGER_BLOB)
    cIssuers: UInt32
class SecPkgContext_KeyInfoA(Structure):
    sSignatureAlgorithmName: POINTER(SByte)
    sEncryptAlgorithmName: POINTER(SByte)
    KeySize: UInt32
    SignatureAlgorithm: UInt32
    EncryptAlgorithm: UInt32
class SecPkgContext_KeyInfoW(Structure):
    sSignatureAlgorithmName: POINTER(UInt16)
    sEncryptAlgorithmName: POINTER(UInt16)
    KeySize: UInt32
    SignatureAlgorithm: UInt32
    EncryptAlgorithm: UInt32
SecPkgContext_KeyInfo = UnicodeAlias('SecPkgContext_KeyInfoW')
class SecPkgContext_KeyingMaterial(Structure):
    cbKeyingMaterial: UInt32
    pbKeyingMaterial: POINTER(Byte)
class SecPkgContext_KeyingMaterialInfo(Structure):
    cbLabel: UInt16
    pszLabel: win32more.Windows.Win32.Foundation.PSTR
    cbContextValue: UInt16
    pbContextValue: POINTER(Byte)
    cbKeyingMaterial: UInt32
class SecPkgContext_KeyingMaterial_Inproc(Structure):
    cbLabel: UInt16
    pszLabel: win32more.Windows.Win32.Foundation.PSTR
    cbContextValue: UInt16
    pbContextValue: POINTER(Byte)
    cbKeyingMaterial: UInt32
    pbKeyingMaterial: POINTER(Byte)
class SecPkgContext_LastClientTokenStatus(Structure):
    LastClientTokenStatus: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_ATTR_LCT_STATUS
class SecPkgContext_Lifespan(Structure):
    tsStart: Int64
    tsExpiry: Int64
class SecPkgContext_LocalCredentialInfo(Structure):
    cbCertificateChain: UInt32
    pbCertificateChain: POINTER(Byte)
    cCertificates: UInt32
    fFlags: UInt32
    dwBits: UInt32
class SecPkgContext_LogoffTime(Structure):
    tsLogoffTime: Int64
class SecPkgContext_MappedCredAttr(Structure):
    dwAttribute: UInt32
    pvBuffer: VoidPtr
class SecPkgContext_NamesA(Structure):
    sUserName: POINTER(SByte)
class SecPkgContext_NamesW(Structure):
    sUserName: POINTER(UInt16)
SecPkgContext_Names = UnicodeAlias('SecPkgContext_NamesW')
class SecPkgContext_NativeNamesA(Structure):
    sClientName: POINTER(SByte)
    sServerName: POINTER(SByte)
class SecPkgContext_NativeNamesW(Structure):
    sClientName: POINTER(UInt16)
    sServerName: POINTER(UInt16)
SecPkgContext_NativeNames = UnicodeAlias('SecPkgContext_NativeNamesW')
class SecPkgContext_NegoKeys(Structure):
    KeyType: UInt32
    KeyLength: UInt16
    KeyValue: POINTER(Byte)
    VerifyKeyType: UInt32
    VerifyKeyLength: UInt16
    VerifyKeyValue: POINTER(Byte)
class SecPkgContext_NegoPackageInfo(Structure):
    PackageMask: UInt32
class SecPkgContext_NegoStatus(Structure):
    LastStatus: UInt32
class SecPkgContext_NegotiatedTlsExtensions(Structure):
    ExtensionsCount: UInt32
    Extensions: POINTER(UInt16)
class SecPkgContext_NegotiationInfoA(Structure):
    PackageInfo: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgInfoA)
    NegotiationState: UInt32
class SecPkgContext_NegotiationInfoW(Structure):
    PackageInfo: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgInfoW)
    NegotiationState: UInt32
SecPkgContext_NegotiationInfo = UnicodeAlias('SecPkgContext_NegotiationInfoW')
class SecPkgContext_PackageInfoA(Structure):
    PackageInfo: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgInfoA)
class SecPkgContext_PackageInfoW(Structure):
    PackageInfo: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgInfoW)
SecPkgContext_PackageInfo = UnicodeAlias('SecPkgContext_PackageInfoW')
class SecPkgContext_PasswordExpiry(Structure):
    tsPasswordExpires: Int64
class SecPkgContext_ProtoInfoA(Structure):
    sProtocolName: POINTER(SByte)
    majorVersion: UInt32
    minorVersion: UInt32
class SecPkgContext_ProtoInfoW(Structure):
    sProtocolName: POINTER(UInt16)
    majorVersion: UInt32
    minorVersion: UInt32
SecPkgContext_ProtoInfo = UnicodeAlias('SecPkgContext_ProtoInfoW')
class SecPkgContext_RemoteCredentialInfo(Structure):
    cbCertificateChain: UInt32
    pbCertificateChain: POINTER(Byte)
    cCertificates: UInt32
    fFlags: UInt32
    dwBits: UInt32
class SecPkgContext_SaslContext(Structure):
    SaslContext: VoidPtr
class SecPkgContext_SessionAppData(Structure):
    dwFlags: UInt32
    cbAppData: UInt32
    pbAppData: POINTER(Byte)
class SecPkgContext_SessionInfo(Structure):
    dwFlags: UInt32
    cbSessionId: UInt32
    rgbSessionId: Byte * 32
class SecPkgContext_SessionKey(Structure):
    SessionKeyLength: UInt32
    SessionKey: POINTER(Byte)
class SecPkgContext_Sizes(Structure):
    cbMaxToken: UInt32
    cbMaxSignature: UInt32
    cbBlockSize: UInt32
    cbSecurityTrailer: UInt32
class SecPkgContext_SrtpParameters(Structure):
    ProtectionProfile: UInt16
    MasterKeyIdentifierSize: Byte
    MasterKeyIdentifier: POINTER(Byte)
class SecPkgContext_StreamSizes(Structure):
    cbHeader: UInt32
    cbTrailer: UInt32
    cbMaximumMessage: UInt32
    cBuffers: UInt32
    cbBlockSize: UInt32
class SecPkgContext_SubjectAttributes(Structure):
    AttributeInfo: VoidPtr
class SecPkgContext_SupportedSignatures(Structure):
    cSignatureAndHashAlgorithms: UInt16
    pSignatureAndHashAlgorithms: POINTER(UInt16)
class SecPkgContext_Target(Structure):
    TargetLength: UInt32
    Target: win32more.Windows.Win32.Foundation.PSTR
class SecPkgContext_TargetInformation(Structure):
    MarshalledTargetInfoLength: UInt32
    MarshalledTargetInfo: POINTER(Byte)
class SecPkgContext_TokenBinding(Structure):
    MajorVersion: Byte
    MinorVersion: Byte
    KeyParametersSize: UInt16
    KeyParameters: POINTER(Byte)
class SecPkgContext_UiInfo(Structure):
    hParentWindow: win32more.Windows.Win32.Foundation.HWND
class SecPkgContext_UserFlags(Structure):
    UserFlags: UInt32
class SecPkgCred_CipherStrengths(Structure):
    dwMinimumCipherStrength: UInt32
    dwMaximumCipherStrength: UInt32
class SecPkgCred_ClientCertPolicy(Structure):
    dwFlags: UInt32
    guidPolicyId: Guid
    dwCertFlags: UInt32
    dwUrlRetrievalTimeout: UInt32
    fCheckRevocationFreshnessTime: win32more.Windows.Win32.Foundation.BOOL
    dwRevocationFreshnessTime: UInt32
    fOmitUsageCheck: win32more.Windows.Win32.Foundation.BOOL
    pwszSslCtlStoreName: win32more.Windows.Win32.Foundation.PWSTR
    pwszSslCtlIdentifier: win32more.Windows.Win32.Foundation.PWSTR
class SecPkgCred_SessionTicketKey(Structure):
    TicketInfoVersion: UInt32
    KeyId: Byte * 16
    KeyingMaterial: Byte * 64
    KeyingMaterialSize: Byte
class SecPkgCred_SessionTicketKeys(Structure):
    cSessionTicketKeys: UInt32
    pSessionTicketKeys: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgCred_SessionTicketKey)
class SecPkgCred_SupportedAlgs(Structure):
    cSupportedAlgs: UInt32
    palgSupportedAlgs: POINTER(win32more.Windows.Win32.Security.Cryptography.ALG_ID)
class SecPkgCred_SupportedProtocols(Structure):
    grbitProtocol: UInt32
class SecPkgCredentials_Cert(Structure):
    EncodedCertSize: UInt32
    EncodedCert: POINTER(Byte)
class SecPkgCredentials_KdcProxySettingsW(Structure):
    Version: UInt32
    Flags: UInt32
    ProxyServerOffset: UInt16
    ProxyServerLength: UInt16
    ClientTlsCredOffset: UInt16
    ClientTlsCredLength: UInt16
class SecPkgCredentials_NamesA(Structure):
    sUserName: POINTER(SByte)
class SecPkgCredentials_NamesW(Structure):
    sUserName: POINTER(UInt16)
SecPkgCredentials_Names = UnicodeAlias('SecPkgCredentials_NamesW')
class SecPkgCredentials_SSIProviderA(Structure):
    sProviderName: POINTER(SByte)
    ProviderInfoLength: UInt32
    ProviderInfo: win32more.Windows.Win32.Foundation.PSTR
class SecPkgCredentials_SSIProviderW(Structure):
    sProviderName: POINTER(UInt16)
    ProviderInfoLength: UInt32
    ProviderInfo: win32more.Windows.Win32.Foundation.PSTR
SecPkgCredentials_SSIProvider = UnicodeAlias('SecPkgCredentials_SSIProviderW')
class SecPkgInfoA(Structure):
    fCapabilities: UInt32
    wVersion: UInt16
    wRPCID: UInt16
    cbMaxToken: UInt32
    Name: POINTER(SByte)
    Comment: POINTER(SByte)
class SecPkgInfoW(Structure):
    fCapabilities: UInt32
    wVersion: UInt16
    wRPCID: UInt16
    cbMaxToken: UInt32
    Name: POINTER(UInt16)
    Comment: POINTER(UInt16)
SecPkgInfo = UnicodeAlias('SecPkgInfoW')
class SecurityFunctionTableA(Structure):
    dwVersion: UInt32
    EnumerateSecurityPackagesA: win32more.Windows.Win32.Security.Authentication.Identity.ENUMERATE_SECURITY_PACKAGES_FN_A
    QueryCredentialsAttributesA: win32more.Windows.Win32.Security.Authentication.Identity.QUERY_CREDENTIALS_ATTRIBUTES_FN_A
    AcquireCredentialsHandleA: win32more.Windows.Win32.Security.Authentication.Identity.ACQUIRE_CREDENTIALS_HANDLE_FN_A
    FreeCredentialsHandle: win32more.Windows.Win32.Security.Authentication.Identity.FREE_CREDENTIALS_HANDLE_FN
    Reserved2: VoidPtr
    InitializeSecurityContextA: win32more.Windows.Win32.Security.Authentication.Identity.INITIALIZE_SECURITY_CONTEXT_FN_A
    AcceptSecurityContext: win32more.Windows.Win32.Security.Authentication.Identity.ACCEPT_SECURITY_CONTEXT_FN
    CompleteAuthToken: win32more.Windows.Win32.Security.Authentication.Identity.COMPLETE_AUTH_TOKEN_FN
    DeleteSecurityContext: win32more.Windows.Win32.Security.Authentication.Identity.DELETE_SECURITY_CONTEXT_FN
    ApplyControlToken: win32more.Windows.Win32.Security.Authentication.Identity.APPLY_CONTROL_TOKEN_FN
    QueryContextAttributesA: win32more.Windows.Win32.Security.Authentication.Identity.QUERY_CONTEXT_ATTRIBUTES_FN_A
    ImpersonateSecurityContext: win32more.Windows.Win32.Security.Authentication.Identity.IMPERSONATE_SECURITY_CONTEXT_FN
    RevertSecurityContext: win32more.Windows.Win32.Security.Authentication.Identity.REVERT_SECURITY_CONTEXT_FN
    MakeSignature: win32more.Windows.Win32.Security.Authentication.Identity.MAKE_SIGNATURE_FN
    VerifySignature: win32more.Windows.Win32.Security.Authentication.Identity.VERIFY_SIGNATURE_FN
    FreeContextBuffer: win32more.Windows.Win32.Security.Authentication.Identity.FREE_CONTEXT_BUFFER_FN
    QuerySecurityPackageInfoA: win32more.Windows.Win32.Security.Authentication.Identity.QUERY_SECURITY_PACKAGE_INFO_FN_A
    Reserved3: VoidPtr
    Reserved4: VoidPtr
    ExportSecurityContext: win32more.Windows.Win32.Security.Authentication.Identity.EXPORT_SECURITY_CONTEXT_FN
    ImportSecurityContextA: win32more.Windows.Win32.Security.Authentication.Identity.IMPORT_SECURITY_CONTEXT_FN_A
    AddCredentialsA: win32more.Windows.Win32.Security.Authentication.Identity.ADD_CREDENTIALS_FN_A
    Reserved8: VoidPtr
    QuerySecurityContextToken: win32more.Windows.Win32.Security.Authentication.Identity.QUERY_SECURITY_CONTEXT_TOKEN_FN
    EncryptMessage: win32more.Windows.Win32.Security.Authentication.Identity.ENCRYPT_MESSAGE_FN
    DecryptMessage: win32more.Windows.Win32.Security.Authentication.Identity.DECRYPT_MESSAGE_FN
    SetContextAttributesA: win32more.Windows.Win32.Security.Authentication.Identity.SET_CONTEXT_ATTRIBUTES_FN_A
    SetCredentialsAttributesA: win32more.Windows.Win32.Security.Authentication.Identity.SET_CREDENTIALS_ATTRIBUTES_FN_A
    ChangeAccountPasswordA: win32more.Windows.Win32.Security.Authentication.Identity.CHANGE_PASSWORD_FN_A
    QueryContextAttributesExA: win32more.Windows.Win32.Security.Authentication.Identity.QUERY_CONTEXT_ATTRIBUTES_EX_FN_A
    QueryCredentialsAttributesExA: win32more.Windows.Win32.Security.Authentication.Identity.QUERY_CREDENTIALS_ATTRIBUTES_EX_FN_A
class SecurityFunctionTableW(Structure):
    dwVersion: UInt32
    EnumerateSecurityPackagesW: win32more.Windows.Win32.Security.Authentication.Identity.ENUMERATE_SECURITY_PACKAGES_FN_W
    QueryCredentialsAttributesW: win32more.Windows.Win32.Security.Authentication.Identity.QUERY_CREDENTIALS_ATTRIBUTES_FN_W
    AcquireCredentialsHandleW: win32more.Windows.Win32.Security.Authentication.Identity.ACQUIRE_CREDENTIALS_HANDLE_FN_W
    FreeCredentialsHandle: win32more.Windows.Win32.Security.Authentication.Identity.FREE_CREDENTIALS_HANDLE_FN
    Reserved2: VoidPtr
    InitializeSecurityContextW: win32more.Windows.Win32.Security.Authentication.Identity.INITIALIZE_SECURITY_CONTEXT_FN_W
    AcceptSecurityContext: win32more.Windows.Win32.Security.Authentication.Identity.ACCEPT_SECURITY_CONTEXT_FN
    CompleteAuthToken: win32more.Windows.Win32.Security.Authentication.Identity.COMPLETE_AUTH_TOKEN_FN
    DeleteSecurityContext: win32more.Windows.Win32.Security.Authentication.Identity.DELETE_SECURITY_CONTEXT_FN
    ApplyControlToken: win32more.Windows.Win32.Security.Authentication.Identity.APPLY_CONTROL_TOKEN_FN
    QueryContextAttributesW: win32more.Windows.Win32.Security.Authentication.Identity.QUERY_CONTEXT_ATTRIBUTES_FN_W
    ImpersonateSecurityContext: win32more.Windows.Win32.Security.Authentication.Identity.IMPERSONATE_SECURITY_CONTEXT_FN
    RevertSecurityContext: win32more.Windows.Win32.Security.Authentication.Identity.REVERT_SECURITY_CONTEXT_FN
    MakeSignature: win32more.Windows.Win32.Security.Authentication.Identity.MAKE_SIGNATURE_FN
    VerifySignature: win32more.Windows.Win32.Security.Authentication.Identity.VERIFY_SIGNATURE_FN
    FreeContextBuffer: win32more.Windows.Win32.Security.Authentication.Identity.FREE_CONTEXT_BUFFER_FN
    QuerySecurityPackageInfoW: win32more.Windows.Win32.Security.Authentication.Identity.QUERY_SECURITY_PACKAGE_INFO_FN_W
    Reserved3: VoidPtr
    Reserved4: VoidPtr
    ExportSecurityContext: win32more.Windows.Win32.Security.Authentication.Identity.EXPORT_SECURITY_CONTEXT_FN
    ImportSecurityContextW: win32more.Windows.Win32.Security.Authentication.Identity.IMPORT_SECURITY_CONTEXT_FN_W
    AddCredentialsW: win32more.Windows.Win32.Security.Authentication.Identity.ADD_CREDENTIALS_FN_W
    Reserved8: VoidPtr
    QuerySecurityContextToken: win32more.Windows.Win32.Security.Authentication.Identity.QUERY_SECURITY_CONTEXT_TOKEN_FN
    EncryptMessage: win32more.Windows.Win32.Security.Authentication.Identity.ENCRYPT_MESSAGE_FN
    DecryptMessage: win32more.Windows.Win32.Security.Authentication.Identity.DECRYPT_MESSAGE_FN
    SetContextAttributesW: win32more.Windows.Win32.Security.Authentication.Identity.SET_CONTEXT_ATTRIBUTES_FN_W
    SetCredentialsAttributesW: win32more.Windows.Win32.Security.Authentication.Identity.SET_CREDENTIALS_ATTRIBUTES_FN_W
    ChangeAccountPasswordW: win32more.Windows.Win32.Security.Authentication.Identity.CHANGE_PASSWORD_FN_W
    QueryContextAttributesExW: win32more.Windows.Win32.Security.Authentication.Identity.QUERY_CONTEXT_ATTRIBUTES_EX_FN_W
    QueryCredentialsAttributesExW: win32more.Windows.Win32.Security.Authentication.Identity.QUERY_CREDENTIALS_ATTRIBUTES_EX_FN_W
SecurityFunctionTable = UnicodeAlias('SecurityFunctionTableW')
@winfunctype_pointer
def SpAcceptCredentialsFn(LogonType: win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_LOGON_TYPE, AccountName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), PrimaryCredentials: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_PRIMARY_CRED), SupplementalCredentials: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_SUPPLEMENTAL_CRED)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpAcceptLsaModeContextFn(CredentialHandle: UIntPtr, ContextHandle: UIntPtr, InputBuffer: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), ContextRequirements: UInt32, TargetDataRep: UInt32, NewContextHandle: POINTER(UIntPtr), OutputBuffer: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), ContextAttributes: POINTER(UInt32), ExpirationTime: POINTER(Int64), MappedContext: POINTER(win32more.Windows.Win32.Foundation.BOOLEAN), ContextData: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpAcquireCredentialsHandleFn(PrincipalName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), CredentialUseFlags: UInt32, LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), AuthorizationData: VoidPtr, GetKeyFunciton: VoidPtr, GetKeyArgument: VoidPtr, CredentialHandle: POINTER(UIntPtr), ExpirationTime: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpAddCredentialsFn(CredentialHandle: UIntPtr, PrincipalName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), Package: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), CredentialUseFlags: UInt32, AuthorizationData: VoidPtr, GetKeyFunciton: VoidPtr, GetKeyArgument: VoidPtr, ExpirationTime: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpApplyControlTokenFn(ContextHandle: UIntPtr, ControlToken: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpChangeAccountPasswordFn(pDomainName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), pAccountName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), pOldPassword: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), pNewPassword: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), Impersonating: win32more.Windows.Win32.Foundation.BOOLEAN, pOutput: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpCompleteAuthTokenFn(ContextHandle: UIntPtr, InputBuffer: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpDeleteContextFn(ContextHandle: UIntPtr) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpDeleteCredentialsFn(CredentialHandle: UIntPtr, Key: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpExchangeMetaDataFn(CredentialHandle: UIntPtr, TargetName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), ContextRequirements: UInt32, MetaDataLength: UInt32, MetaData: POINTER(Byte), ContextHandle: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpExportSecurityContextFn(phContext: UIntPtr, fFlags: UInt32, pPackedContext: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer), pToken: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpExtractTargetInfoFn(ClientRequest: POINTER(VoidPtr), ProtocolSubmitBuffer: VoidPtr, ClientBufferBase: VoidPtr, SubmitBufferLength: UInt32, ppvTargetInfo: POINTER(VoidPtr), pcbTargetInfo: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpFormatCredentialsFn(Credentials: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer), FormattedCredentials: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpFreeCredentialsHandleFn(CredentialHandle: UIntPtr) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpGetContextTokenFn(ContextHandle: UIntPtr, ImpersonationToken: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpGetCredUIContextFn(ContextHandle: UIntPtr, CredType: POINTER(Guid), FlatCredUIContextLength: POINTER(UInt32), FlatCredUIContext: POINTER(POINTER(Byte))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpGetCredentialsFn(CredentialHandle: UIntPtr, Credentials: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpGetExtendedInformationFn(Class: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_EXTENDED_INFORMATION_CLASS, ppInformation: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_EXTENDED_INFORMATION))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpGetInfoFn(PackageInfo: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecPkgInfoA)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpGetRemoteCredGuardLogonBufferFn(CredHandle: UIntPtr, ContextHandle: UIntPtr, TargetName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), RedirectedLogonHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE), Callback: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.PLSA_REDIRECTED_LOGON_CALLBACK), CleanupCallback: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.PLSA_REDIRECTED_LOGON_CLEANUP_CALLBACK), LogonBufferSize: POINTER(UInt32), LogonBuffer: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpGetRemoteCredGuardSupplementalCredsFn(CredHandle: UIntPtr, TargetName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), RedirectedLogonHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE), Callback: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.PLSA_REDIRECTED_LOGON_CALLBACK), CleanupCallback: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.PLSA_REDIRECTED_LOGON_CLEANUP_CALLBACK), SupplementalCredsSize: POINTER(UInt32), SupplementalCreds: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpGetTbalSupplementalCredsFn(LogonId: win32more.Windows.Win32.Foundation.LUID, SupplementalCredsSize: POINTER(UInt32), SupplementalCreds: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpGetUserInfoFn(LogonId: POINTER(win32more.Windows.Win32.Foundation.LUID), Flags: UInt32, UserData: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECURITY_USER_DATA))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpImportSecurityContextFn(pPackedContext: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer), Token: win32more.Windows.Win32.Foundation.HANDLE, phContext: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpInitLsaModeContextFn(CredentialHandle: UIntPtr, ContextHandle: UIntPtr, TargetName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), ContextRequirements: UInt32, TargetDataRep: UInt32, InputBuffers: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), NewContextHandle: POINTER(UIntPtr), OutputBuffers: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), ContextAttributes: POINTER(UInt32), ExpirationTime: POINTER(Int64), MappedContext: POINTER(win32more.Windows.Win32.Foundation.BOOLEAN), ContextData: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpInitUserModeContextFn(ContextHandle: UIntPtr, PackedContext: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpInitializeFn(PackageId: UIntPtr, Parameters: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_PARAMETERS), FunctionTable: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_SECPKG_FUNCTION_TABLE)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpInstanceInitFn(Version: UInt32, FunctionTable: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_DLL_FUNCTIONS), UserFunctions: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpLsaModeInitializeFn(LsaVersion: UInt32, PackageVersion: POINTER(UInt32), ppTables: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_FUNCTION_TABLE)), pcTables: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpMakeSignatureFn(ContextHandle: UIntPtr, QualityOfProtection: UInt32, MessageBuffers: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), MessageSequenceNumber: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpMarshalAttributeDataFn(AttributeInfo: UInt32, Attribute: UInt32, AttributeDataSize: UInt32, AttributeData: POINTER(Byte), MarshaledAttributeDataSize: POINTER(UInt32), MarshaledAttributeData: POINTER(POINTER(Byte))) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpMarshallSupplementalCredsFn(CredentialSize: UInt32, Credentials: POINTER(Byte), MarshalledCredSize: POINTER(UInt32), MarshalledCreds: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpQueryContextAttributesFn(ContextHandle: UIntPtr, ContextAttribute: UInt32, Buffer: VoidPtr) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpQueryCredentialsAttributesFn(CredentialHandle: UIntPtr, CredentialAttribute: UInt32, Buffer: VoidPtr) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpQueryMetaDataFn(CredentialHandle: UIntPtr, TargetName: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING), ContextRequirements: UInt32, MetaDataLength: POINTER(UInt32), MetaData: POINTER(POINTER(Byte)), ContextHandle: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpSaveCredentialsFn(CredentialHandle: UIntPtr, Credentials: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBuffer)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpSealMessageFn(ContextHandle: UIntPtr, QualityOfProtection: UInt32, MessageBuffers: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), MessageSequenceNumber: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpSetContextAttributesFn(ContextHandle: UIntPtr, ContextAttribute: UInt32, Buffer: VoidPtr, BufferSize: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpSetCredentialsAttributesFn(CredentialHandle: UIntPtr, CredentialAttribute: UInt32, Buffer: VoidPtr, BufferSize: UInt32) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpSetExtendedInformationFn(Class: win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_EXTENDED_INFORMATION_CLASS, Info: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_EXTENDED_INFORMATION)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpShutdownFn() -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpUnsealMessageFn(ContextHandle: UIntPtr, MessageBuffers: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), MessageSequenceNumber: UInt32, QualityOfProtection: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpUpdateCredentialsFn(ContextHandle: UIntPtr, CredType: POINTER(Guid), FlatCredUIContextLength: UInt32, FlatCredUIContext: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpUserModeInitializeFn(LsaVersion: UInt32, PackageVersion: POINTER(UInt32), ppTables: POINTER(POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_USER_FUNCTION_TABLE)), pcTables: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpValidateTargetInfoFn(ClientRequest: POINTER(VoidPtr), ProtocolSubmitBuffer: VoidPtr, ClientBufferBase: VoidPtr, SubmitBufferLength: UInt32, TargetInfo: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SECPKG_TARGETINFO)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SpVerifySignatureFn(ContextHandle: UIntPtr, MessageBuffers: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), MessageSequenceNumber: UInt32, QualityOfProtection: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.NTSTATUS: ...
@winfunctype_pointer
def SslDeserializeCertificateStoreFn(SerializedCertificateStore: win32more.Windows.Win32.Security.Cryptography.CRYPT_INTEGER_BLOB, ppCertContext: POINTER(POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_CONTEXT))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def SslGetExtensionsFn(clientHello: POINTER(Byte), clientHelloByteSize: UInt32, genericExtensions: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SCH_EXTENSION_DATA), genericExtensionsCount: Byte, bytesToRead: POINTER(UInt32), flags: win32more.Windows.Win32.Security.Authentication.Identity.SchGetExtensionsOptions) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def SslGetServerIdentityFn(ClientHello: POINTER(Byte), ClientHelloSize: UInt32, ServerIdentity: POINTER(POINTER(Byte)), ServerIdentitySize: POINTER(UInt32), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class TLS_EXTENSION_SUBSCRIPTION(Structure):
    ExtensionType: UInt16
    HandshakeType: UInt16
class TLS_PARAMETERS(Structure):
    cAlpnIds: UInt32
    rgstrAlpnIds: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)
    grbitDisabledProtocols: UInt32
    cDisabledCrypto: UInt32
    pDisabledCrypto: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.CRYPTO_SETTINGS)
    dwFlags: UInt32
TOKENBINDING_EXTENSION_FORMAT = Int32
TOKENBINDING_EXTENSION_FORMAT_UNDEFINED: win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_EXTENSION_FORMAT = 0
class TOKENBINDING_IDENTIFIER(Structure):
    keyType: Byte
TOKENBINDING_KEY_PARAMETERS_TYPE = Int32
TOKENBINDING_KEY_PARAMETERS_TYPE_RSA2048_PKCS: win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_KEY_PARAMETERS_TYPE = 0
TOKENBINDING_KEY_PARAMETERS_TYPE_RSA2048_PSS: win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_KEY_PARAMETERS_TYPE = 1
TOKENBINDING_KEY_PARAMETERS_TYPE_ECDSAP256: win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_KEY_PARAMETERS_TYPE = 2
TOKENBINDING_KEY_PARAMETERS_TYPE_ANYEXISTING: win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_KEY_PARAMETERS_TYPE = 255
class TOKENBINDING_KEY_TYPES(Structure):
    keyCount: UInt32
    keyType: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_KEY_PARAMETERS_TYPE)
class TOKENBINDING_RESULT_DATA(Structure):
    bindingType: win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_TYPE
    identifierSize: UInt32
    identifierData: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_IDENTIFIER)
    extensionFormat: win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_EXTENSION_FORMAT
    extensionSize: UInt32
    extensionData: VoidPtr
class TOKENBINDING_RESULT_LIST(Structure):
    resultCount: UInt32
    resultData: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_RESULT_DATA)
TOKENBINDING_TYPE = Int32
TOKENBINDING_TYPE_PROVIDED: win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_TYPE = 0
TOKENBINDING_TYPE_REFERRED: win32more.Windows.Win32.Security.Authentication.Identity.TOKENBINDING_TYPE = 1
class TRUSTED_CONTROLLERS_INFO(Structure):
    Entries: UInt32
    Names: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING)
class TRUSTED_DOMAIN_AUTH_INFORMATION(Structure):
    IncomingAuthInfos: UInt32
    IncomingAuthenticationInformation: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_AUTH_INFORMATION)
    IncomingPreviousAuthenticationInformation: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_AUTH_INFORMATION)
    OutgoingAuthInfos: UInt32
    OutgoingAuthenticationInformation: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_AUTH_INFORMATION)
    OutgoingPreviousAuthenticationInformation: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.LSA_AUTH_INFORMATION)
class TRUSTED_DOMAIN_FULL_INFORMATION(Structure):
    Information: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_INFORMATION_EX
    PosixOffset: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_POSIX_OFFSET_INFO
    AuthInformation: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_AUTH_INFORMATION
class TRUSTED_DOMAIN_FULL_INFORMATION2(Structure):
    Information: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_INFORMATION_EX2
    PosixOffset: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_POSIX_OFFSET_INFO
    AuthInformation: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_AUTH_INFORMATION
class TRUSTED_DOMAIN_INFORMATION_EX(Structure):
    Name: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    FlatName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Sid: win32more.Windows.Win32.Security.PSID
    TrustDirection: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_DIRECTION
    TrustType: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_TYPE
    TrustAttributes: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_ATTRIBUTES
class TRUSTED_DOMAIN_INFORMATION_EX2(Structure):
    Name: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    FlatName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Sid: win32more.Windows.Win32.Security.PSID
    TrustDirection: UInt32
    TrustType: UInt32
    TrustAttributes: UInt32
    ForestTrustLength: UInt32
    ForestTrustInfo: POINTER(Byte)
class TRUSTED_DOMAIN_NAME_INFO(Structure):
    Name: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
class TRUSTED_DOMAIN_SUPPORTED_ENCRYPTION_TYPES(Structure):
    SupportedEncryptionTypes: UInt32
TRUSTED_DOMAIN_TRUST_ATTRIBUTES = UInt32
TRUST_ATTRIBUTE_NON_TRANSITIVE: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_ATTRIBUTES = 1
TRUST_ATTRIBUTE_UPLEVEL_ONLY: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_ATTRIBUTES = 2
TRUST_ATTRIBUTE_FILTER_SIDS: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_ATTRIBUTES = 4
TRUST_ATTRIBUTE_FOREST_TRANSITIVE: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_ATTRIBUTES = 8
TRUST_ATTRIBUTE_CROSS_ORGANIZATION: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_ATTRIBUTES = 16
TRUST_ATTRIBUTE_TREAT_AS_EXTERNAL: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_ATTRIBUTES = 64
TRUST_ATTRIBUTE_WITHIN_FOREST: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_ATTRIBUTES = 32
TRUSTED_DOMAIN_TRUST_DIRECTION = UInt32
TRUST_DIRECTION_DISABLED: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_DIRECTION = 0
TRUST_DIRECTION_INBOUND: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_DIRECTION = 1
TRUST_DIRECTION_OUTBOUND: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_DIRECTION = 2
TRUST_DIRECTION_BIDIRECTIONAL: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_DIRECTION = 3
TRUSTED_DOMAIN_TRUST_TYPE = UInt32
TRUST_TYPE_DOWNLEVEL: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_TYPE = 1
TRUST_TYPE_UPLEVEL: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_TYPE = 2
TRUST_TYPE_MIT: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_TYPE = 3
TRUST_TYPE_DCE: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_DOMAIN_TRUST_TYPE = 4
TRUSTED_INFORMATION_CLASS = Int32
TrustedDomainNameInformation: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS = 1
TrustedControllersInformation: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS = 2
TrustedPosixOffsetInformation: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS = 3
TrustedPasswordInformation: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS = 4
TrustedDomainInformationBasic: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS = 5
TrustedDomainInformationEx: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS = 6
TrustedDomainAuthInformation: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS = 7
TrustedDomainFullInformation: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS = 8
TrustedDomainAuthInformationInternal: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS = 9
TrustedDomainFullInformationInternal: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS = 10
TrustedDomainInformationEx2Internal: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS = 11
TrustedDomainFullInformation2Internal: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS = 12
TrustedDomainSupportedEncryptionTypes: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS = 13
TrustedDomainAuthInformationInternalAes: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS = 14
TrustedDomainFullInformationInternalAes: win32more.Windows.Win32.Security.Authentication.Identity.TRUSTED_INFORMATION_CLASS = 15
class TRUSTED_PASSWORD_INFO(Structure):
    Password: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    OldPassword: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
class TRUSTED_POSIX_OFFSET_INFO(Structure):
    Offset: UInt32
class USER_ALL_INFORMATION(Structure):
    LastLogon: Int64
    LastLogoff: Int64
    PasswordLastSet: Int64
    AccountExpires: Int64
    PasswordCanChange: Int64
    PasswordMustChange: Int64
    UserName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    FullName: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    HomeDirectory: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    HomeDirectoryDrive: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ScriptPath: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    ProfilePath: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    AdminComment: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    WorkStations: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    UserComment: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    Parameters: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    LmPassword: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    NtPassword: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    PrivateData: win32more.Windows.Win32.Security.Authentication.Identity.LSA_UNICODE_STRING
    SecurityDescriptor: win32more.Windows.Win32.Security.Authentication.Identity.SR_SECURITY_DESCRIPTOR
    UserId: UInt32
    PrimaryGroupId: UInt32
    UserAccountControl: UInt32
    WhichFields: UInt32
    LogonHours: win32more.Windows.Win32.Security.Authentication.Identity.LOGON_HOURS
    BadPasswordCount: UInt16
    LogonCount: UInt16
    CountryCode: UInt16
    CodePage: UInt16
    LmPasswordPresent: win32more.Windows.Win32.Foundation.BOOLEAN
    NtPasswordPresent: win32more.Windows.Win32.Foundation.BOOLEAN
    PasswordExpired: win32more.Windows.Win32.Foundation.BOOLEAN
    PrivateDataSensitive: win32more.Windows.Win32.Foundation.BOOLEAN
    _pack_ = 4
class USER_SESSION_KEY(Structure):
    data: win32more.Windows.Win32.System.PasswordManagement.CYPHER_BLOCK * 2
@winfunctype_pointer
def VERIFY_SIGNATURE_FN(param0: POINTER(win32more.Windows.Win32.Security.Credentials.SecHandle), param1: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.SecBufferDesc), param2: UInt32, param3: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class X509Certificate(Structure):
    Version: UInt32
    SerialNumber: UInt32 * 4
    SignatureAlgorithm: win32more.Windows.Win32.Security.Cryptography.ALG_ID
    ValidFrom: win32more.Windows.Win32.Foundation.FILETIME
    ValidUntil: win32more.Windows.Win32.Foundation.FILETIME
    pszIssuer: win32more.Windows.Win32.Foundation.PSTR
    pszSubject: win32more.Windows.Win32.Foundation.PSTR
    pPublicKey: POINTER(win32more.Windows.Win32.Security.Authentication.Identity.PctPublicKey)
_HMAPPER = IntPtr
eTlsAlgorithmUsage = Int32
TlsParametersCngAlgUsageKeyExchange: win32more.Windows.Win32.Security.Authentication.Identity.eTlsAlgorithmUsage = 0
TlsParametersCngAlgUsageSignature: win32more.Windows.Win32.Security.Authentication.Identity.eTlsAlgorithmUsage = 1
TlsParametersCngAlgUsageCipher: win32more.Windows.Win32.Security.Authentication.Identity.eTlsAlgorithmUsage = 2
TlsParametersCngAlgUsageDigest: win32more.Windows.Win32.Security.Authentication.Identity.eTlsAlgorithmUsage = 3
TlsParametersCngAlgUsageCertSig: win32more.Windows.Win32.Security.Authentication.Identity.eTlsAlgorithmUsage = 4
eTlsHashAlgorithm = Int32
TlsHashAlgorithm_None: win32more.Windows.Win32.Security.Authentication.Identity.eTlsHashAlgorithm = 0
TlsHashAlgorithm_Md5: win32more.Windows.Win32.Security.Authentication.Identity.eTlsHashAlgorithm = 1
TlsHashAlgorithm_Sha1: win32more.Windows.Win32.Security.Authentication.Identity.eTlsHashAlgorithm = 2
TlsHashAlgorithm_Sha224: win32more.Windows.Win32.Security.Authentication.Identity.eTlsHashAlgorithm = 3
TlsHashAlgorithm_Sha256: win32more.Windows.Win32.Security.Authentication.Identity.eTlsHashAlgorithm = 4
TlsHashAlgorithm_Sha384: win32more.Windows.Win32.Security.Authentication.Identity.eTlsHashAlgorithm = 5
TlsHashAlgorithm_Sha512: win32more.Windows.Win32.Security.Authentication.Identity.eTlsHashAlgorithm = 6
eTlsSignatureAlgorithm = Int32
TlsSignatureAlgorithm_Anonymous: win32more.Windows.Win32.Security.Authentication.Identity.eTlsSignatureAlgorithm = 0
TlsSignatureAlgorithm_Rsa: win32more.Windows.Win32.Security.Authentication.Identity.eTlsSignatureAlgorithm = 1
TlsSignatureAlgorithm_Dsa: win32more.Windows.Win32.Security.Authentication.Identity.eTlsSignatureAlgorithm = 2
TlsSignatureAlgorithm_Ecdsa: win32more.Windows.Win32.Security.Authentication.Identity.eTlsSignatureAlgorithm = 3


make_ready(__name__)
