from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Globalization
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.System.Com
LANG_SYSTEM_DEFAULT: Int32 = 2048
LANG_USER_DEFAULT: Int32 = 1024
LOCALE_SYSTEM_DEFAULT: UInt32 = 2048
LOCALE_USER_DEFAULT: UInt32 = 1024
ALL_SERVICE_TYPES: UInt32 = 0
HIGHLEVEL_SERVICE_TYPES: UInt32 = 1
LOWLEVEL_SERVICE_TYPES: UInt32 = 2
ALL_SERVICES: UInt32 = 0
ONLINE_SERVICES: UInt32 = 1
OFFLINE_SERVICES: UInt32 = 2
MAX_LEADBYTES: UInt32 = 12
MAX_DEFAULTCHAR: UInt32 = 2
HIGH_SURROGATE_START: UInt32 = 55296
HIGH_SURROGATE_END: UInt32 = 56319
LOW_SURROGATE_START: UInt32 = 56320
LOW_SURROGATE_END: UInt32 = 57343
WC_COMPOSITECHECK: UInt32 = 512
WC_DISCARDNS: UInt32 = 16
WC_SEPCHARS: UInt32 = 32
WC_DEFAULTCHAR: UInt32 = 64
WC_ERR_INVALID_CHARS: UInt32 = 128
WC_NO_BEST_FIT_CHARS: UInt32 = 1024
CT_CTYPE1: UInt32 = 1
CT_CTYPE2: UInt32 = 2
CT_CTYPE3: UInt32 = 4
C1_UPPER: UInt32 = 1
C1_LOWER: UInt32 = 2
C1_DIGIT: UInt32 = 4
C1_SPACE: UInt32 = 8
C1_PUNCT: UInt32 = 16
C1_CNTRL: UInt32 = 32
C1_BLANK: UInt32 = 64
C1_XDIGIT: UInt32 = 128
C1_ALPHA: UInt32 = 256
C1_DEFINED: UInt32 = 512
C2_LEFTTORIGHT: UInt32 = 1
C2_RIGHTTOLEFT: UInt32 = 2
C2_EUROPENUMBER: UInt32 = 3
C2_EUROPESEPARATOR: UInt32 = 4
C2_EUROPETERMINATOR: UInt32 = 5
C2_ARABICNUMBER: UInt32 = 6
C2_COMMONSEPARATOR: UInt32 = 7
C2_BLOCKSEPARATOR: UInt32 = 8
C2_SEGMENTSEPARATOR: UInt32 = 9
C2_WHITESPACE: UInt32 = 10
C2_OTHERNEUTRAL: UInt32 = 11
C2_NOTAPPLICABLE: UInt32 = 0
C3_NONSPACING: UInt32 = 1
C3_DIACRITIC: UInt32 = 2
C3_VOWELMARK: UInt32 = 4
C3_SYMBOL: UInt32 = 8
C3_KATAKANA: UInt32 = 16
C3_HIRAGANA: UInt32 = 32
C3_HALFWIDTH: UInt32 = 64
C3_FULLWIDTH: UInt32 = 128
C3_IDEOGRAPH: UInt32 = 256
C3_KASHIDA: UInt32 = 512
C3_LEXICAL: UInt32 = 1024
C3_HIGHSURROGATE: UInt32 = 2048
C3_LOWSURROGATE: UInt32 = 4096
C3_ALPHA: UInt32 = 32768
C3_NOTAPPLICABLE: UInt32 = 0
LCMAP_LOWERCASE: UInt32 = 256
LCMAP_UPPERCASE: UInt32 = 512
LCMAP_TITLECASE: UInt32 = 768
LCMAP_SORTKEY: UInt32 = 1024
LCMAP_BYTEREV: UInt32 = 2048
LCMAP_HIRAGANA: UInt32 = 1048576
LCMAP_KATAKANA: UInt32 = 2097152
LCMAP_HALFWIDTH: UInt32 = 4194304
LCMAP_FULLWIDTH: UInt32 = 8388608
LCMAP_LINGUISTIC_CASING: UInt32 = 16777216
LCMAP_SIMPLIFIED_CHINESE: UInt32 = 33554432
LCMAP_TRADITIONAL_CHINESE: UInt32 = 67108864
LCMAP_SORTHANDLE: UInt32 = 536870912
LCMAP_HASH: UInt32 = 262144
FIND_STARTSWITH: UInt32 = 1048576
FIND_ENDSWITH: UInt32 = 2097152
FIND_FROMSTART: UInt32 = 4194304
FIND_FROMEND: UInt32 = 8388608
LCID_ALTERNATE_SORTS: UInt32 = 4
LOCALE_ALL: UInt32 = 0
LOCALE_WINDOWS: UInt32 = 1
LOCALE_SUPPLEMENTAL: UInt32 = 2
LOCALE_ALTERNATE_SORTS: UInt32 = 4
LOCALE_REPLACEMENT: UInt32 = 8
LOCALE_NEUTRALDATA: UInt32 = 16
LOCALE_SPECIFICDATA: UInt32 = 32
CP_ACP: UInt32 = 0
CP_OEMCP: UInt32 = 1
CP_MACCP: UInt32 = 2
CP_THREAD_ACP: UInt32 = 3
CP_SYMBOL: UInt32 = 42
CP_UTF7: UInt32 = 65000
CP_UTF8: UInt32 = 65001
CTRY_DEFAULT: UInt32 = 0
CTRY_ALBANIA: UInt32 = 355
CTRY_ALGERIA: UInt32 = 213
CTRY_ARGENTINA: UInt32 = 54
CTRY_ARMENIA: UInt32 = 374
CTRY_AUSTRALIA: UInt32 = 61
CTRY_AUSTRIA: UInt32 = 43
CTRY_AZERBAIJAN: UInt32 = 994
CTRY_BAHRAIN: UInt32 = 973
CTRY_BELARUS: UInt32 = 375
CTRY_BELGIUM: UInt32 = 32
CTRY_BELIZE: UInt32 = 501
CTRY_BOLIVIA: UInt32 = 591
CTRY_BRAZIL: UInt32 = 55
CTRY_BRUNEI_DARUSSALAM: UInt32 = 673
CTRY_BULGARIA: UInt32 = 359
CTRY_CANADA: UInt32 = 2
CTRY_CARIBBEAN: UInt32 = 1
CTRY_CHILE: UInt32 = 56
CTRY_COLOMBIA: UInt32 = 57
CTRY_COSTA_RICA: UInt32 = 506
CTRY_CROATIA: UInt32 = 385
CTRY_CZECH: UInt32 = 420
CTRY_DENMARK: UInt32 = 45
CTRY_DOMINICAN_REPUBLIC: UInt32 = 1
CTRY_ECUADOR: UInt32 = 593
CTRY_EGYPT: UInt32 = 20
CTRY_EL_SALVADOR: UInt32 = 503
CTRY_ESTONIA: UInt32 = 372
CTRY_FAEROE_ISLANDS: UInt32 = 298
CTRY_FINLAND: UInt32 = 358
CTRY_FRANCE: UInt32 = 33
CTRY_GEORGIA: UInt32 = 995
CTRY_GERMANY: UInt32 = 49
CTRY_GREECE: UInt32 = 30
CTRY_GUATEMALA: UInt32 = 502
CTRY_HONDURAS: UInt32 = 504
CTRY_HONG_KONG: UInt32 = 852
CTRY_HUNGARY: UInt32 = 36
CTRY_ICELAND: UInt32 = 354
CTRY_INDIA: UInt32 = 91
CTRY_INDONESIA: UInt32 = 62
CTRY_IRAN: UInt32 = 981
CTRY_IRAQ: UInt32 = 964
CTRY_IRELAND: UInt32 = 353
CTRY_ISRAEL: UInt32 = 972
CTRY_ITALY: UInt32 = 39
CTRY_JAMAICA: UInt32 = 1
CTRY_JAPAN: UInt32 = 81
CTRY_JORDAN: UInt32 = 962
CTRY_KAZAKSTAN: UInt32 = 7
CTRY_KENYA: UInt32 = 254
CTRY_KUWAIT: UInt32 = 965
CTRY_KYRGYZSTAN: UInt32 = 996
CTRY_LATVIA: UInt32 = 371
CTRY_LEBANON: UInt32 = 961
CTRY_LIBYA: UInt32 = 218
CTRY_LIECHTENSTEIN: UInt32 = 41
CTRY_LITHUANIA: UInt32 = 370
CTRY_LUXEMBOURG: UInt32 = 352
CTRY_MACAU: UInt32 = 853
CTRY_MACEDONIA: UInt32 = 389
CTRY_MALAYSIA: UInt32 = 60
CTRY_MALDIVES: UInt32 = 960
CTRY_MEXICO: UInt32 = 52
CTRY_MONACO: UInt32 = 33
CTRY_MONGOLIA: UInt32 = 976
CTRY_MOROCCO: UInt32 = 212
CTRY_NETHERLANDS: UInt32 = 31
CTRY_NEW_ZEALAND: UInt32 = 64
CTRY_NICARAGUA: UInt32 = 505
CTRY_NORWAY: UInt32 = 47
CTRY_OMAN: UInt32 = 968
CTRY_PAKISTAN: UInt32 = 92
CTRY_PANAMA: UInt32 = 507
CTRY_PARAGUAY: UInt32 = 595
CTRY_PERU: UInt32 = 51
CTRY_PHILIPPINES: UInt32 = 63
CTRY_POLAND: UInt32 = 48
CTRY_PORTUGAL: UInt32 = 351
CTRY_PRCHINA: UInt32 = 86
CTRY_PUERTO_RICO: UInt32 = 1
CTRY_QATAR: UInt32 = 974
CTRY_ROMANIA: UInt32 = 40
CTRY_RUSSIA: UInt32 = 7
CTRY_SAUDI_ARABIA: UInt32 = 966
CTRY_SERBIA: UInt32 = 381
CTRY_SINGAPORE: UInt32 = 65
CTRY_SLOVAK: UInt32 = 421
CTRY_SLOVENIA: UInt32 = 386
CTRY_SOUTH_AFRICA: UInt32 = 27
CTRY_SOUTH_KOREA: UInt32 = 82
CTRY_SPAIN: UInt32 = 34
CTRY_SWEDEN: UInt32 = 46
CTRY_SWITZERLAND: UInt32 = 41
CTRY_SYRIA: UInt32 = 963
CTRY_TAIWAN: UInt32 = 886
CTRY_TATARSTAN: UInt32 = 7
CTRY_THAILAND: UInt32 = 66
CTRY_TRINIDAD_Y_TOBAGO: UInt32 = 1
CTRY_TUNISIA: UInt32 = 216
CTRY_TURKEY: UInt32 = 90
CTRY_UAE: UInt32 = 971
CTRY_UKRAINE: UInt32 = 380
CTRY_UNITED_KINGDOM: UInt32 = 44
CTRY_UNITED_STATES: UInt32 = 1
CTRY_URUGUAY: UInt32 = 598
CTRY_UZBEKISTAN: UInt32 = 7
CTRY_VENEZUELA: UInt32 = 58
CTRY_VIET_NAM: UInt32 = 84
CTRY_YEMEN: UInt32 = 967
CTRY_ZIMBABWE: UInt32 = 263
LOCALE_NOUSEROVERRIDE: UInt32 = 2147483648
LOCALE_USE_CP_ACP: UInt32 = 1073741824
LOCALE_RETURN_NUMBER: UInt32 = 536870912
LOCALE_RETURN_GENITIVE_NAMES: UInt32 = 268435456
LOCALE_ALLOW_NEUTRAL_NAMES: UInt32 = 134217728
LOCALE_SLOCALIZEDDISPLAYNAME: UInt32 = 2
LOCALE_SENGLISHDISPLAYNAME: UInt32 = 114
LOCALE_SNATIVEDISPLAYNAME: UInt32 = 115
LOCALE_SLOCALIZEDLANGUAGENAME: UInt32 = 111
LOCALE_SENGLISHLANGUAGENAME: UInt32 = 4097
LOCALE_SNATIVELANGUAGENAME: UInt32 = 4
LOCALE_SLOCALIZEDCOUNTRYNAME: UInt32 = 6
LOCALE_SENGLISHCOUNTRYNAME: UInt32 = 4098
LOCALE_SNATIVECOUNTRYNAME: UInt32 = 8
LOCALE_IDIALINGCODE: UInt32 = 5
LOCALE_SLIST: UInt32 = 12
LOCALE_IMEASURE: UInt32 = 13
LOCALE_SDECIMAL: UInt32 = 14
LOCALE_STHOUSAND: UInt32 = 15
LOCALE_SGROUPING: UInt32 = 16
LOCALE_IDIGITS: UInt32 = 17
LOCALE_ILZERO: UInt32 = 18
LOCALE_INEGNUMBER: UInt32 = 4112
LOCALE_SNATIVEDIGITS: UInt32 = 19
LOCALE_SCURRENCY: UInt32 = 20
LOCALE_SINTLSYMBOL: UInt32 = 21
LOCALE_SMONDECIMALSEP: UInt32 = 22
LOCALE_SMONTHOUSANDSEP: UInt32 = 23
LOCALE_SMONGROUPING: UInt32 = 24
LOCALE_ICURRDIGITS: UInt32 = 25
LOCALE_ICURRENCY: UInt32 = 27
LOCALE_INEGCURR: UInt32 = 28
LOCALE_SSHORTDATE: UInt32 = 31
LOCALE_SLONGDATE: UInt32 = 32
LOCALE_STIMEFORMAT: UInt32 = 4099
LOCALE_SAM: UInt32 = 40
LOCALE_SPM: UInt32 = 41
LOCALE_ICALENDARTYPE: UInt32 = 4105
LOCALE_IOPTIONALCALENDAR: UInt32 = 4107
LOCALE_IFIRSTDAYOFWEEK: UInt32 = 4108
LOCALE_IFIRSTWEEKOFYEAR: UInt32 = 4109
LOCALE_SDAYNAME1: UInt32 = 42
LOCALE_SDAYNAME2: UInt32 = 43
LOCALE_SDAYNAME3: UInt32 = 44
LOCALE_SDAYNAME4: UInt32 = 45
LOCALE_SDAYNAME5: UInt32 = 46
LOCALE_SDAYNAME6: UInt32 = 47
LOCALE_SDAYNAME7: UInt32 = 48
LOCALE_SABBREVDAYNAME1: UInt32 = 49
LOCALE_SABBREVDAYNAME2: UInt32 = 50
LOCALE_SABBREVDAYNAME3: UInt32 = 51
LOCALE_SABBREVDAYNAME4: UInt32 = 52
LOCALE_SABBREVDAYNAME5: UInt32 = 53
LOCALE_SABBREVDAYNAME6: UInt32 = 54
LOCALE_SABBREVDAYNAME7: UInt32 = 55
LOCALE_SMONTHNAME1: UInt32 = 56
LOCALE_SMONTHNAME2: UInt32 = 57
LOCALE_SMONTHNAME3: UInt32 = 58
LOCALE_SMONTHNAME4: UInt32 = 59
LOCALE_SMONTHNAME5: UInt32 = 60
LOCALE_SMONTHNAME6: UInt32 = 61
LOCALE_SMONTHNAME7: UInt32 = 62
LOCALE_SMONTHNAME8: UInt32 = 63
LOCALE_SMONTHNAME9: UInt32 = 64
LOCALE_SMONTHNAME10: UInt32 = 65
LOCALE_SMONTHNAME11: UInt32 = 66
LOCALE_SMONTHNAME12: UInt32 = 67
LOCALE_SMONTHNAME13: UInt32 = 4110
LOCALE_SABBREVMONTHNAME1: UInt32 = 68
LOCALE_SABBREVMONTHNAME2: UInt32 = 69
LOCALE_SABBREVMONTHNAME3: UInt32 = 70
LOCALE_SABBREVMONTHNAME4: UInt32 = 71
LOCALE_SABBREVMONTHNAME5: UInt32 = 72
LOCALE_SABBREVMONTHNAME6: UInt32 = 73
LOCALE_SABBREVMONTHNAME7: UInt32 = 74
LOCALE_SABBREVMONTHNAME8: UInt32 = 75
LOCALE_SABBREVMONTHNAME9: UInt32 = 76
LOCALE_SABBREVMONTHNAME10: UInt32 = 77
LOCALE_SABBREVMONTHNAME11: UInt32 = 78
LOCALE_SABBREVMONTHNAME12: UInt32 = 79
LOCALE_SABBREVMONTHNAME13: UInt32 = 4111
LOCALE_SPOSITIVESIGN: UInt32 = 80
LOCALE_SNEGATIVESIGN: UInt32 = 81
LOCALE_IPOSSIGNPOSN: UInt32 = 82
LOCALE_INEGSIGNPOSN: UInt32 = 83
LOCALE_IPOSSYMPRECEDES: UInt32 = 84
LOCALE_IPOSSEPBYSPACE: UInt32 = 85
LOCALE_INEGSYMPRECEDES: UInt32 = 86
LOCALE_INEGSEPBYSPACE: UInt32 = 87
LOCALE_FONTSIGNATURE: UInt32 = 88
LOCALE_SISO639LANGNAME: UInt32 = 89
LOCALE_SISO3166CTRYNAME: UInt32 = 90
LOCALE_IPAPERSIZE: UInt32 = 4106
LOCALE_SENGCURRNAME: UInt32 = 4103
LOCALE_SNATIVECURRNAME: UInt32 = 4104
LOCALE_SYEARMONTH: UInt32 = 4102
LOCALE_SSORTNAME: UInt32 = 4115
LOCALE_IDIGITSUBSTITUTION: UInt32 = 4116
LOCALE_SNAME: UInt32 = 92
LOCALE_SDURATION: UInt32 = 93
LOCALE_SSHORTESTDAYNAME1: UInt32 = 96
LOCALE_SSHORTESTDAYNAME2: UInt32 = 97
LOCALE_SSHORTESTDAYNAME3: UInt32 = 98
LOCALE_SSHORTESTDAYNAME4: UInt32 = 99
LOCALE_SSHORTESTDAYNAME5: UInt32 = 100
LOCALE_SSHORTESTDAYNAME6: UInt32 = 101
LOCALE_SSHORTESTDAYNAME7: UInt32 = 102
LOCALE_SISO639LANGNAME2: UInt32 = 103
LOCALE_SISO3166CTRYNAME2: UInt32 = 104
LOCALE_SNAN: UInt32 = 105
LOCALE_SPOSINFINITY: UInt32 = 106
LOCALE_SNEGINFINITY: UInt32 = 107
LOCALE_SSCRIPTS: UInt32 = 108
LOCALE_SPARENT: UInt32 = 109
LOCALE_SCONSOLEFALLBACKNAME: UInt32 = 110
LOCALE_IREADINGLAYOUT: UInt32 = 112
LOCALE_INEUTRAL: UInt32 = 113
LOCALE_INEGATIVEPERCENT: UInt32 = 116
LOCALE_IPOSITIVEPERCENT: UInt32 = 117
LOCALE_SPERCENT: UInt32 = 118
LOCALE_SPERMILLE: UInt32 = 119
LOCALE_SMONTHDAY: UInt32 = 120
LOCALE_SSHORTTIME: UInt32 = 121
LOCALE_SOPENTYPELANGUAGETAG: UInt32 = 122
LOCALE_SSORTLOCALE: UInt32 = 123
LOCALE_SRELATIVELONGDATE: UInt32 = 124
LOCALE_ICONSTRUCTEDLOCALE: UInt32 = 125
LOCALE_SSHORTESTAM: UInt32 = 126
LOCALE_SSHORTESTPM: UInt32 = 127
LOCALE_IUSEUTF8LEGACYACP: UInt32 = 1638
LOCALE_IUSEUTF8LEGACYOEMCP: UInt32 = 2457
LOCALE_IDEFAULTCODEPAGE: UInt32 = 11
LOCALE_IDEFAULTANSICODEPAGE: UInt32 = 4100
LOCALE_IDEFAULTMACCODEPAGE: UInt32 = 4113
LOCALE_IDEFAULTEBCDICCODEPAGE: UInt32 = 4114
LOCALE_ILANGUAGE: UInt32 = 1
LOCALE_SABBREVLANGNAME: UInt32 = 3
LOCALE_SABBREVCTRYNAME: UInt32 = 7
LOCALE_IGEOID: UInt32 = 91
LOCALE_IDEFAULTLANGUAGE: UInt32 = 9
LOCALE_IDEFAULTCOUNTRY: UInt32 = 10
LOCALE_IINTLCURRDIGITS: UInt32 = 26
LOCALE_SDATE: UInt32 = 29
LOCALE_STIME: UInt32 = 30
LOCALE_IDATE: UInt32 = 33
LOCALE_ILDATE: UInt32 = 34
LOCALE_ITIME: UInt32 = 35
LOCALE_ITIMEMARKPOSN: UInt32 = 4101
LOCALE_ICENTURY: UInt32 = 36
LOCALE_ITLZERO: UInt32 = 37
LOCALE_IDAYLZERO: UInt32 = 38
LOCALE_IMONLZERO: UInt32 = 39
LOCALE_SKEYBOARDSTOINSTALL: UInt32 = 94
LOCALE_SLANGUAGE: UInt32 = 2
LOCALE_SLANGDISPLAYNAME: UInt32 = 111
LOCALE_SENGLANGUAGE: UInt32 = 4097
LOCALE_SNATIVELANGNAME: UInt32 = 4
LOCALE_SCOUNTRY: UInt32 = 6
LOCALE_SENGCOUNTRY: UInt32 = 4098
LOCALE_SNATIVECTRYNAME: UInt32 = 8
LOCALE_ICOUNTRY: UInt32 = 5
LOCALE_S1159: UInt32 = 40
LOCALE_S2359: UInt32 = 41
CAL_NOUSEROVERRIDE: UInt32 = 2147483648
CAL_USE_CP_ACP: UInt32 = 1073741824
CAL_RETURN_NUMBER: UInt32 = 536870912
CAL_RETURN_GENITIVE_NAMES: UInt32 = 268435456
CAL_ICALINTVALUE: UInt32 = 1
CAL_SCALNAME: UInt32 = 2
CAL_IYEAROFFSETRANGE: UInt32 = 3
CAL_SERASTRING: UInt32 = 4
CAL_SSHORTDATE: UInt32 = 5
CAL_SLONGDATE: UInt32 = 6
CAL_SDAYNAME1: UInt32 = 7
CAL_SDAYNAME2: UInt32 = 8
CAL_SDAYNAME3: UInt32 = 9
CAL_SDAYNAME4: UInt32 = 10
CAL_SDAYNAME5: UInt32 = 11
CAL_SDAYNAME6: UInt32 = 12
CAL_SDAYNAME7: UInt32 = 13
CAL_SABBREVDAYNAME1: UInt32 = 14
CAL_SABBREVDAYNAME2: UInt32 = 15
CAL_SABBREVDAYNAME3: UInt32 = 16
CAL_SABBREVDAYNAME4: UInt32 = 17
CAL_SABBREVDAYNAME5: UInt32 = 18
CAL_SABBREVDAYNAME6: UInt32 = 19
CAL_SABBREVDAYNAME7: UInt32 = 20
CAL_SMONTHNAME1: UInt32 = 21
CAL_SMONTHNAME2: UInt32 = 22
CAL_SMONTHNAME3: UInt32 = 23
CAL_SMONTHNAME4: UInt32 = 24
CAL_SMONTHNAME5: UInt32 = 25
CAL_SMONTHNAME6: UInt32 = 26
CAL_SMONTHNAME7: UInt32 = 27
CAL_SMONTHNAME8: UInt32 = 28
CAL_SMONTHNAME9: UInt32 = 29
CAL_SMONTHNAME10: UInt32 = 30
CAL_SMONTHNAME11: UInt32 = 31
CAL_SMONTHNAME12: UInt32 = 32
CAL_SMONTHNAME13: UInt32 = 33
CAL_SABBREVMONTHNAME1: UInt32 = 34
CAL_SABBREVMONTHNAME2: UInt32 = 35
CAL_SABBREVMONTHNAME3: UInt32 = 36
CAL_SABBREVMONTHNAME4: UInt32 = 37
CAL_SABBREVMONTHNAME5: UInt32 = 38
CAL_SABBREVMONTHNAME6: UInt32 = 39
CAL_SABBREVMONTHNAME7: UInt32 = 40
CAL_SABBREVMONTHNAME8: UInt32 = 41
CAL_SABBREVMONTHNAME9: UInt32 = 42
CAL_SABBREVMONTHNAME10: UInt32 = 43
CAL_SABBREVMONTHNAME11: UInt32 = 44
CAL_SABBREVMONTHNAME12: UInt32 = 45
CAL_SABBREVMONTHNAME13: UInt32 = 46
CAL_SYEARMONTH: UInt32 = 47
CAL_ITWODIGITYEARMAX: UInt32 = 48
CAL_SSHORTESTDAYNAME1: UInt32 = 49
CAL_SSHORTESTDAYNAME2: UInt32 = 50
CAL_SSHORTESTDAYNAME3: UInt32 = 51
CAL_SSHORTESTDAYNAME4: UInt32 = 52
CAL_SSHORTESTDAYNAME5: UInt32 = 53
CAL_SSHORTESTDAYNAME6: UInt32 = 54
CAL_SSHORTESTDAYNAME7: UInt32 = 55
CAL_SMONTHDAY: UInt32 = 56
CAL_SABBREVERASTRING: UInt32 = 57
CAL_SRELATIVELONGDATE: UInt32 = 58
CAL_SENGLISHERANAME: UInt32 = 59
CAL_SENGLISHABBREVERANAME: UInt32 = 60
CAL_SJAPANESEERAFIRSTYEAR: UInt32 = 61
ENUM_ALL_CALENDARS: UInt32 = 4294967295
CAL_GREGORIAN: UInt32 = 1
CAL_GREGORIAN_US: UInt32 = 2
CAL_JAPAN: UInt32 = 3
CAL_TAIWAN: UInt32 = 4
CAL_KOREA: UInt32 = 5
CAL_HIJRI: UInt32 = 6
CAL_THAI: UInt32 = 7
CAL_HEBREW: UInt32 = 8
CAL_GREGORIAN_ME_FRENCH: UInt32 = 9
CAL_GREGORIAN_ARABIC: UInt32 = 10
CAL_GREGORIAN_XLIT_ENGLISH: UInt32 = 11
CAL_GREGORIAN_XLIT_FRENCH: UInt32 = 12
CAL_PERSIAN: UInt32 = 22
CAL_UMALQURA: UInt32 = 23
LGRPID_WESTERN_EUROPE: UInt32 = 1
LGRPID_CENTRAL_EUROPE: UInt32 = 2
LGRPID_BALTIC: UInt32 = 3
LGRPID_GREEK: UInt32 = 4
LGRPID_CYRILLIC: UInt32 = 5
LGRPID_TURKIC: UInt32 = 6
LGRPID_TURKISH: UInt32 = 6
LGRPID_JAPANESE: UInt32 = 7
LGRPID_KOREAN: UInt32 = 8
LGRPID_TRADITIONAL_CHINESE: UInt32 = 9
LGRPID_SIMPLIFIED_CHINESE: UInt32 = 10
LGRPID_THAI: UInt32 = 11
LGRPID_HEBREW: UInt32 = 12
LGRPID_ARABIC: UInt32 = 13
LGRPID_VIETNAMESE: UInt32 = 14
LGRPID_INDIC: UInt32 = 15
LGRPID_GEORGIAN: UInt32 = 16
LGRPID_ARMENIAN: UInt32 = 17
MUI_LANGUAGE_ID: UInt32 = 4
MUI_LANGUAGE_NAME: UInt32 = 8
MUI_MERGE_SYSTEM_FALLBACK: UInt32 = 16
MUI_MERGE_USER_FALLBACK: UInt32 = 32
MUI_THREAD_LANGUAGES: UInt32 = 64
MUI_CONSOLE_FILTER: UInt32 = 256
MUI_COMPLEX_SCRIPT_FILTER: UInt32 = 512
MUI_RESET_FILTERS: UInt32 = 1
MUI_USER_PREFERRED_UI_LANGUAGES: UInt32 = 16
MUI_USE_INSTALLED_LANGUAGES: UInt32 = 32
MUI_USE_SEARCH_ALL_LANGUAGES: UInt32 = 64
MUI_LANG_NEUTRAL_PE_FILE: UInt32 = 256
MUI_NON_LANG_NEUTRAL_FILE: UInt32 = 512
MUI_MACHINE_LANGUAGE_SETTINGS: UInt32 = 1024
MUI_FILETYPE_NOT_LANGUAGE_NEUTRAL: UInt32 = 1
MUI_FILETYPE_LANGUAGE_NEUTRAL_MAIN: UInt32 = 2
MUI_FILETYPE_LANGUAGE_NEUTRAL_MUI: UInt32 = 4
MUI_QUERY_TYPE: UInt32 = 1
MUI_QUERY_CHECKSUM: UInt32 = 2
MUI_QUERY_LANGUAGE_NAME: UInt32 = 4
MUI_QUERY_RESOURCE_TYPES: UInt32 = 8
MUI_FILEINFO_VERSION: UInt32 = 1
MUI_FULL_LANGUAGE: UInt32 = 1
MUI_PARTIAL_LANGUAGE: UInt32 = 2
MUI_LIP_LANGUAGE: UInt32 = 4
MUI_LANGUAGE_INSTALLED: UInt32 = 32
MUI_LANGUAGE_LICENSED: UInt32 = 64
GEOID_NOT_AVAILABLE: Int32 = -1
SORTING_PARADIGM_NLS: UInt32 = 0
SORTING_PARADIGM_ICU: UInt32 = 16777216
IDN_ALLOW_UNASSIGNED: UInt32 = 1
IDN_USE_STD3_ASCII_RULES: UInt32 = 2
IDN_EMAIL_ADDRESS: UInt32 = 4
IDN_RAW_PUNYCODE: UInt32 = 8
VS_ALLOW_LATIN: UInt32 = 1
GSS_ALLOW_INHERITED_COMMON: UInt32 = 1
MUI_FORMAT_REG_COMPAT: UInt32 = 1
MUI_FORMAT_INF_COMPAT: UInt32 = 2
MUI_VERIFY_FILE_EXISTS: UInt32 = 4
MUI_SKIP_STRING_CACHE: UInt32 = 8
MUI_IMMUTABLE_LOOKUP: UInt32 = 16
LOCALE_NAME_INVARIANT: String = ''
LOCALE_NAME_SYSTEM_DEFAULT: String = '!x-sys-default-locale'
MIN_SPELLING_NTDDI: UInt32 = 100794368
SCRIPT_UNDEFINED: UInt32 = 0
USP_E_SCRIPT_NOT_IN_FONT: win32more.Windows.Win32.Foundation.HRESULT = -2147220992
SGCM_RTL: UInt32 = 1
SSA_PASSWORD: UInt32 = 1
SSA_TAB: UInt32 = 2
SSA_CLIP: UInt32 = 4
SSA_FIT: UInt32 = 8
SSA_DZWG: UInt32 = 16
SSA_FALLBACK: UInt32 = 32
SSA_BREAK: UInt32 = 64
SSA_GLYPHS: UInt32 = 128
SSA_RTL: UInt32 = 256
SSA_GCP: UInt32 = 512
SSA_HOTKEY: UInt32 = 1024
SSA_METAFILE: UInt32 = 2048
SSA_LINK: UInt32 = 4096
SSA_HIDEHOTKEY: UInt32 = 8192
SSA_HOTKEYONLY: UInt32 = 9216
SSA_FULLMEASURE: UInt32 = 67108864
SSA_LPKANSIFALLBACK: UInt32 = 134217728
SSA_PIDX: UInt32 = 268435456
SSA_LAYOUTRTL: UInt32 = 536870912
SSA_DONTGLYPH: UInt32 = 1073741824
SSA_NOKASHIDA: UInt32 = 2147483648
SCRIPT_DIGITSUBSTITUTE_CONTEXT: UInt32 = 0
SCRIPT_DIGITSUBSTITUTE_NONE: UInt32 = 1
SCRIPT_DIGITSUBSTITUTE_NATIONAL: UInt32 = 2
SCRIPT_DIGITSUBSTITUTE_TRADITIONAL: UInt32 = 3
UNISCRIBE_OPENTYPE: UInt32 = 256
SCRIPT_TAG_UNKNOWN: UInt32 = 0
MUI_LANGUAGE_EXACT: UInt32 = 16
NLS_CP_CPINFO: UInt32 = 268435456
NLS_CP_MBTOWC: UInt32 = 1073741824
NLS_CP_WCTOMB: UInt32 = 2147483648
U_DISABLE_RENAMING: UInt32 = 1
U_SHOW_CPLUSPLUS_API: UInt32 = 0
U_DEFAULT_SHOW_DRAFT: UInt32 = 0
U_HIDE_DRAFT_API: UInt32 = 1
U_HIDE_DEPRECATED_API: UInt32 = 1
U_HIDE_OBSOLETE_API: UInt32 = 1
U_HIDE_INTERNAL_API: UInt32 = 1
U_NO_DEFAULT_INCLUDE_UTF_HEADERS: UInt32 = 1
U_DEBUG: UInt32 = 1
UCLN_NO_AUTO_CLEANUP: UInt32 = 1
U_OVERRIDE_CXX_ALLOCATION: UInt32 = 1
U_ENABLE_TRACING: UInt32 = 0
UCONFIG_ENABLE_PLUGINS: UInt32 = 0
U_ENABLE_DYLOAD: UInt32 = 1
U_CHECK_DYLOAD: UInt32 = 1
U_HAVE_LIB_SUFFIX: UInt32 = 1
U_LIB_SUFFIX_C_NAME_STRING: String = ''
UCONFIG_ONLY_COLLATION: UInt32 = 0
UCONFIG_NO_BREAK_ITERATION: UInt32 = 1
UCONFIG_NO_IDNA: UInt32 = 1
UCONFIG_NO_FORMATTING: UInt32 = 1
UCONFIG_NO_TRANSLITERATION: UInt32 = 1
UCONFIG_NO_REGULAR_EXPRESSIONS: UInt32 = 1
UCONFIG_NO_FILE_IO: UInt32 = 0
UCONFIG_NO_CONVERSION: UInt32 = 0
UCONFIG_NO_LEGACY_CONVERSION: UInt32 = 1
UCONFIG_ONLY_HTML_CONVERSION: UInt32 = 0
UCONFIG_NO_NORMALIZATION: UInt32 = 0
UCONFIG_NO_COLLATION: UInt32 = 1
UCONFIG_NO_SERVICE: UInt32 = 0
UCONFIG_HAVE_PARSEALLINPUT: UInt32 = 1
UCONFIG_NO_FILTERED_BREAK_ITERATION: UInt32 = 0
U_PF_UNKNOWN: UInt32 = 0
U_PF_WINDOWS: UInt32 = 1000
U_PF_MINGW: UInt32 = 1800
U_PF_CYGWIN: UInt32 = 1900
U_PF_HPUX: UInt32 = 2100
U_PF_SOLARIS: UInt32 = 2600
U_PF_BSD: UInt32 = 3000
U_PF_AIX: UInt32 = 3100
U_PF_IRIX: UInt32 = 3200
U_PF_DARWIN: UInt32 = 3500
U_PF_IPHONE: UInt32 = 3550
U_PF_QNX: UInt32 = 3700
U_PF_LINUX: UInt32 = 4000
U_PF_BROWSER_NATIVE_CLIENT: UInt32 = 4020
U_PF_ANDROID: UInt32 = 4050
U_PF_FUCHSIA: UInt32 = 4100
U_PF_EMSCRIPTEN: UInt32 = 5010
U_PF_OS390: UInt32 = 9000
U_PF_OS400: UInt32 = 9400
U_PLATFORM: UInt32 = 1800
U_PLATFORM_USES_ONLY_WIN32_API: UInt32 = 1
U_PLATFORM_HAS_WIN32_API: UInt32 = 1
U_PLATFORM_IMPLEMENTS_POSIX: UInt32 = 0
U_PLATFORM_IS_LINUX_BASED: UInt32 = 1
U_PLATFORM_IS_DARWIN_BASED: UInt32 = 1
U_HAVE_STDINT_H: UInt32 = 1
U_HAVE_INTTYPES_H: UInt32 = 1
U_GCC_MAJOR_MINOR: UInt32 = 0
U_IS_BIG_ENDIAN: UInt32 = 0
U_HAVE_PLACEMENT_NEW: UInt32 = 0
U_HAVE_DEBUG_LOCATION_NEW: UInt32 = 1
U_CPLUSPLUS_VERSION: UInt32 = 0
U_ASCII_FAMILY: UInt32 = 0
U_EBCDIC_FAMILY: UInt32 = 1
U_CHARSET_FAMILY: UInt32 = 1
U_CHARSET_IS_UTF8: UInt32 = 1
U_HAVE_WCHAR_H: UInt32 = 0
U_SIZEOF_WCHAR_T: UInt32 = 1
U_HAVE_WCSCPY: UInt32 = 0
U_HAVE_CHAR16_T: UInt32 = 1
U_DEFINE_FALSE_AND_TRUE: UInt32 = 1
U_SIZEOF_UCHAR: UInt32 = 2
U_CHAR16_IS_TYPEDEF: UInt32 = 1
U_SENTINEL: Int32 = -1
U8_LEAD3_T1_BITS: String = ' 000000000000\x1000'
U8_LEAD4_T1_BITS: String = '\x00\x00\x00\x00\x00\x00\x00\x00\x1e\x0f\x0f\x0f\x00\x00\x00\x00'
U8_MAX_LENGTH: UInt32 = 4
U16_MAX_LENGTH: UInt32 = 2
U_HIDE_OBSOLETE_UTF_OLD_H: UInt32 = 0
UTF_SIZE: UInt32 = 16
UTF8_ERROR_VALUE_1: UInt32 = 21
UTF8_ERROR_VALUE_2: UInt32 = 159
UTF_ERROR_VALUE: UInt32 = 65535
UTF8_MAX_CHAR_LENGTH: UInt32 = 4
UTF16_MAX_CHAR_LENGTH: UInt32 = 2
UTF32_MAX_CHAR_LENGTH: UInt32 = 1
UTF_MAX_CHAR_LENGTH: UInt32 = 2
U_COPYRIGHT_STRING_LENGTH: UInt32 = 128
U_MAX_VERSION_LENGTH: UInt32 = 4
U_MAX_VERSION_STRING_LENGTH: UInt32 = 20
U_MILLIS_PER_SECOND: UInt32 = 1000
U_MILLIS_PER_MINUTE: UInt32 = 60000
U_MILLIS_PER_HOUR: UInt32 = 3600000
U_MILLIS_PER_DAY: UInt32 = 86400000
U_COMBINED_IMPLEMENTATION: UInt32 = 1
U_SHAPE_LENGTH_GROW_SHRINK: UInt32 = 0
U_SHAPE_LAMALEF_RESIZE: UInt32 = 0
U_SHAPE_LENGTH_FIXED_SPACES_NEAR: UInt32 = 1
U_SHAPE_LAMALEF_NEAR: UInt32 = 1
U_SHAPE_LENGTH_FIXED_SPACES_AT_END: UInt32 = 2
U_SHAPE_LAMALEF_END: UInt32 = 2
U_SHAPE_LENGTH_FIXED_SPACES_AT_BEGINNING: UInt32 = 3
U_SHAPE_LAMALEF_BEGIN: UInt32 = 3
U_SHAPE_LAMALEF_AUTO: UInt32 = 65536
U_SHAPE_LENGTH_MASK: UInt32 = 65539
U_SHAPE_LAMALEF_MASK: UInt32 = 65539
U_SHAPE_TEXT_DIRECTION_LOGICAL: UInt32 = 0
U_SHAPE_TEXT_DIRECTION_VISUAL_RTL: UInt32 = 0
U_SHAPE_TEXT_DIRECTION_VISUAL_LTR: UInt32 = 4
U_SHAPE_TEXT_DIRECTION_MASK: UInt32 = 4
U_SHAPE_LETTERS_NOOP: UInt32 = 0
U_SHAPE_LETTERS_SHAPE: UInt32 = 8
U_SHAPE_LETTERS_UNSHAPE: UInt32 = 16
U_SHAPE_LETTERS_SHAPE_TASHKEEL_ISOLATED: UInt32 = 24
U_SHAPE_LETTERS_MASK: UInt32 = 24
U_SHAPE_DIGITS_NOOP: UInt32 = 0
U_SHAPE_DIGITS_EN2AN: UInt32 = 32
U_SHAPE_DIGITS_AN2EN: UInt32 = 64
U_SHAPE_DIGITS_ALEN2AN_INIT_LR: UInt32 = 96
U_SHAPE_DIGITS_ALEN2AN_INIT_AL: UInt32 = 128
U_SHAPE_DIGITS_RESERVED: UInt32 = 160
U_SHAPE_DIGITS_MASK: UInt32 = 224
U_SHAPE_DIGIT_TYPE_AN: UInt32 = 0
U_SHAPE_DIGIT_TYPE_AN_EXTENDED: UInt32 = 256
U_SHAPE_DIGIT_TYPE_RESERVED: UInt32 = 512
U_SHAPE_DIGIT_TYPE_MASK: UInt32 = 768
U_SHAPE_AGGREGATE_TASHKEEL: UInt32 = 16384
U_SHAPE_AGGREGATE_TASHKEEL_NOOP: UInt32 = 0
U_SHAPE_AGGREGATE_TASHKEEL_MASK: UInt32 = 16384
U_SHAPE_PRESERVE_PRESENTATION: UInt32 = 32768
U_SHAPE_PRESERVE_PRESENTATION_NOOP: UInt32 = 0
U_SHAPE_PRESERVE_PRESENTATION_MASK: UInt32 = 32768
U_SHAPE_SEEN_TWOCELL_NEAR: UInt32 = 2097152
U_SHAPE_SEEN_MASK: UInt32 = 7340032
U_SHAPE_YEHHAMZA_TWOCELL_NEAR: UInt32 = 16777216
U_SHAPE_YEHHAMZA_MASK: UInt32 = 58720256
U_SHAPE_TASHKEEL_BEGIN: UInt32 = 262144
U_SHAPE_TASHKEEL_END: UInt32 = 393216
U_SHAPE_TASHKEEL_RESIZE: UInt32 = 524288
U_SHAPE_TASHKEEL_REPLACE_BY_TATWEEL: UInt32 = 786432
U_SHAPE_TASHKEEL_MASK: UInt32 = 917504
U_SHAPE_SPACES_RELATIVE_TO_TEXT_BEGIN_END: UInt32 = 67108864
U_SHAPE_SPACES_RELATIVE_TO_TEXT_MASK: UInt32 = 67108864
U_SHAPE_TAIL_NEW_UNICODE: UInt32 = 134217728
U_SHAPE_TAIL_TYPE_MASK: UInt32 = 134217728
ULOC_CHINESE: String = 'zh'
ULOC_ENGLISH: String = 'en'
ULOC_FRENCH: String = 'fr'
ULOC_GERMAN: String = 'de'
ULOC_ITALIAN: String = 'it'
ULOC_JAPANESE: String = 'ja'
ULOC_KOREAN: String = 'ko'
ULOC_SIMPLIFIED_CHINESE: String = 'zh_CN'
ULOC_TRADITIONAL_CHINESE: String = 'zh_TW'
ULOC_CANADA: String = 'en_CA'
ULOC_CANADA_FRENCH: String = 'fr_CA'
ULOC_CHINA: String = 'zh_CN'
ULOC_PRC: String = 'zh_CN'
ULOC_FRANCE: String = 'fr_FR'
ULOC_GERMANY: String = 'de_DE'
ULOC_ITALY: String = 'it_IT'
ULOC_JAPAN: String = 'ja_JP'
ULOC_KOREA: String = 'ko_KR'
ULOC_TAIWAN: String = 'zh_TW'
ULOC_UK: String = 'en_GB'
ULOC_US: String = 'en_US'
ULOC_LANG_CAPACITY: UInt32 = 12
ULOC_COUNTRY_CAPACITY: UInt32 = 4
ULOC_FULLNAME_CAPACITY: UInt32 = 157
ULOC_SCRIPT_CAPACITY: UInt32 = 6
ULOC_KEYWORDS_CAPACITY: UInt32 = 96
ULOC_KEYWORD_AND_VALUES_CAPACITY: UInt32 = 100
ULOC_KEYWORD_SEPARATOR_UNICODE: UInt32 = 64
ULOC_KEYWORD_ASSIGN_UNICODE: UInt32 = 61
ULOC_KEYWORD_ITEM_SEPARATOR_UNICODE: UInt32 = 59
UCNV_SUB_STOP_ON_ILLEGAL: String = 'i'
UCNV_SKIP_STOP_ON_ILLEGAL: String = 'i'
UCNV_ESCAPE_JAVA: String = 'J'
UCNV_ESCAPE_C: String = 'C'
UCNV_ESCAPE_XML_DEC: String = 'D'
UCNV_ESCAPE_XML_HEX: String = 'X'
UCNV_ESCAPE_UNICODE: String = 'U'
UCNV_ESCAPE_CSS2: String = 'S'
UCNV_MAX_CONVERTER_NAME_LENGTH: UInt32 = 60
UCNV_SI: UInt32 = 15
UCNV_SO: UInt32 = 14
UCNV_OPTION_SEP_STRING: String = ','
UCNV_VALUE_SEP_STRING: String = '='
UCNV_LOCALE_OPTION_STRING: String = ',locale='
UCNV_VERSION_OPTION_STRING: String = ',version='
UCNV_SWAP_LFNL_OPTION_STRING: String = ',swaplfnl'
U_FOLD_CASE_DEFAULT: UInt32 = 0
U_FOLD_CASE_EXCLUDE_SPECIAL_I: UInt32 = 1
U_TITLECASE_WHOLE_STRING: UInt32 = 32
U_TITLECASE_SENTENCES: UInt32 = 64
U_TITLECASE_NO_LOWERCASE: UInt32 = 256
U_TITLECASE_NO_BREAK_ADJUSTMENT: UInt32 = 512
U_TITLECASE_ADJUST_TO_CASED: UInt32 = 1024
U_EDITS_NO_RESET: UInt32 = 8192
U_OMIT_UNCHANGED_TEXT: UInt32 = 16384
U_COMPARE_CODE_POINT_ORDER: UInt32 = 32768
U_COMPARE_IGNORE_CASE: UInt32 = 65536
UNORM_INPUT_IS_FCD: UInt32 = 131072
UCHAR_MIN_VALUE: UInt32 = 0
UCHAR_MAX_VALUE: UInt32 = 1114111
UBIDI_DEFAULT_LTR: UInt32 = 254
UBIDI_DEFAULT_RTL: UInt32 = 255
UBIDI_MAX_EXPLICIT_LEVEL: UInt32 = 125
UBIDI_LEVEL_OVERRIDE: UInt32 = 128
UBIDI_MAP_NOWHERE: Int32 = -1
UBIDI_KEEP_BASE_COMBINING: UInt32 = 1
UBIDI_DO_MIRRORING: UInt32 = 2
UBIDI_INSERT_LRM_FOR_NUMERIC: UInt32 = 4
UBIDI_REMOVE_BIDI_CONTROLS: UInt32 = 8
UBIDI_OUTPUT_REVERSE: UInt32 = 16
USPREP_DEFAULT: UInt32 = 0
USPREP_ALLOW_UNASSIGNED: UInt32 = 1
U_ICU_VERSION_BUNDLE: String = 'icuver'
U_ICU_DATA_KEY: String = 'DataVersion'
UCAL_UNKNOWN_ZONE_ID: String = 'Etc/Unknown'
UDAT_YEAR: String = 'y'
UDAT_QUARTER: String = 'QQQQ'
UDAT_ABBR_QUARTER: String = 'QQQ'
UDAT_YEAR_QUARTER: String = 'yQQQQ'
UDAT_YEAR_ABBR_QUARTER: String = 'yQQQ'
UDAT_MONTH: String = 'MMMM'
UDAT_ABBR_MONTH: String = 'MMM'
UDAT_NUM_MONTH: String = 'M'
UDAT_YEAR_MONTH: String = 'yMMMM'
UDAT_YEAR_ABBR_MONTH: String = 'yMMM'
UDAT_YEAR_NUM_MONTH: String = 'yM'
UDAT_DAY: String = 'd'
UDAT_YEAR_MONTH_DAY: String = 'yMMMMd'
UDAT_YEAR_ABBR_MONTH_DAY: String = 'yMMMd'
UDAT_YEAR_NUM_MONTH_DAY: String = 'yMd'
UDAT_WEEKDAY: String = 'EEEE'
UDAT_ABBR_WEEKDAY: String = 'E'
UDAT_YEAR_MONTH_WEEKDAY_DAY: String = 'yMMMMEEEEd'
UDAT_YEAR_ABBR_MONTH_WEEKDAY_DAY: String = 'yMMMEd'
UDAT_YEAR_NUM_MONTH_WEEKDAY_DAY: String = 'yMEd'
UDAT_MONTH_DAY: String = 'MMMMd'
UDAT_ABBR_MONTH_DAY: String = 'MMMd'
UDAT_NUM_MONTH_DAY: String = 'Md'
UDAT_MONTH_WEEKDAY_DAY: String = 'MMMMEEEEd'
UDAT_ABBR_MONTH_WEEKDAY_DAY: String = 'MMMEd'
UDAT_NUM_MONTH_WEEKDAY_DAY: String = 'MEd'
UDAT_HOUR: String = 'j'
UDAT_HOUR24: String = 'H'
UDAT_MINUTE: String = 'm'
UDAT_HOUR_MINUTE: String = 'jm'
UDAT_HOUR24_MINUTE: String = 'Hm'
UDAT_SECOND: String = 's'
UDAT_HOUR_MINUTE_SECOND: String = 'jms'
UDAT_HOUR24_MINUTE_SECOND: String = 'Hms'
UDAT_MINUTE_SECOND: String = 'ms'
UDAT_LOCATION_TZ: String = 'VVVV'
UDAT_GENERIC_TZ: String = 'vvvv'
UDAT_ABBR_GENERIC_TZ: String = 'v'
UDAT_SPECIFIC_TZ: String = 'zzzz'
UDAT_ABBR_SPECIFIC_TZ: String = 'z'
UDAT_ABBR_UTC_TZ: String = 'ZZZZ'
USEARCH_DONE: Int32 = -1
U_HAVE_STD_STRING: UInt32 = 0
UCONFIG_FORMAT_FASTPATHS_49: UInt32 = 1
U_PLATFORM_HAS_WINUWP_API: UInt32 = 0
U_IOSTREAM_SOURCE: UInt32 = 199711
U_HAVE_RVALUE_REFERENCES: UInt32 = 1
U_USING_ICU_NAMESPACE: UInt32 = 1
U_ICUDATA_TYPE_LETTER: String = 'e'
U_UNICODE_VERSION: String = '8.0'
CANITER_SKIP_ZEROES: UInt32 = 1
NUMSYS_NAME_CAPACITY: UInt32 = 8
U_HAVE_RBNF: UInt32 = 0
MAX_MIMECP_NAME: UInt32 = 64
MAX_MIMECSET_NAME: UInt32 = 50
MAX_MIMEFACE_NAME: UInt32 = 32
MAX_RFC1766_NAME: UInt32 = 6
MAX_LOCALE_NAME: UInt32 = 32
MAX_SCRIPT_NAME: UInt32 = 48
CPIOD_PEEK: Int32 = 1073741824
CPIOD_FORCE_PROMPT: Int32 = -2147483648
UITER_UNKNOWN_INDEX: Int32 = -2
UCPTRIE_FAST_SHIFT: Int32 = 6
UCPTRIE_FAST_DATA_BLOCK_LENGTH: Int32 = 64
UCPTRIE_FAST_DATA_MASK: Int32 = 63
UCPTRIE_SMALL_MAX: Int32 = 4095
UCPTRIE_ERROR_VALUE_NEG_DATA_OFFSET: Int32 = 1
UCPTRIE_HIGH_VALUE_NEG_DATA_OFFSET: Int32 = 2
UTEXT_PROVIDER_LENGTH_IS_EXPENSIVE: Int32 = 1
UTEXT_PROVIDER_STABLE_CHUNKS: Int32 = 2
UTEXT_PROVIDER_WRITABLE: Int32 = 3
UTEXT_PROVIDER_HAS_META_DATA: Int32 = 4
UTEXT_PROVIDER_OWNS_TEXT: Int32 = 5
UTEXT_MAGIC: Int32 = 878368812
USET_IGNORE_SPACE: Int32 = 1
USET_CASE_INSENSITIVE: Int32 = 2
USET_ADD_CASE_MAPPINGS: Int32 = 4
USET_SERIALIZED_STATIC_ARRAY_CAPACITY: Int32 = 8
U_PARSE_CONTEXT_LEN: Int32 = 16
UIDNA_DEFAULT: Int32 = 0
UIDNA_USE_STD3_RULES: Int32 = 2
UIDNA_CHECK_BIDI: Int32 = 4
UIDNA_CHECK_CONTEXTJ: Int32 = 8
UIDNA_NONTRANSITIONAL_TO_ASCII: Int32 = 16
UIDNA_NONTRANSITIONAL_TO_UNICODE: Int32 = 32
UIDNA_CHECK_CONTEXTO: Int32 = 64
UIDNA_ERROR_EMPTY_LABEL: Int32 = 1
UIDNA_ERROR_LABEL_TOO_LONG: Int32 = 2
UIDNA_ERROR_DOMAIN_NAME_TOO_LONG: Int32 = 4
UIDNA_ERROR_LEADING_HYPHEN: Int32 = 8
UIDNA_ERROR_TRAILING_HYPHEN: Int32 = 16
UIDNA_ERROR_HYPHEN_3_4: Int32 = 32
UIDNA_ERROR_LEADING_COMBINING_MARK: Int32 = 64
UIDNA_ERROR_DISALLOWED: Int32 = 128
UIDNA_ERROR_PUNYCODE: Int32 = 256
UIDNA_ERROR_LABEL_HAS_DOT: Int32 = 512
UIDNA_ERROR_INVALID_ACE_LABEL: Int32 = 1024
UIDNA_ERROR_BIDI: Int32 = 2048
UIDNA_ERROR_CONTEXTJ: Int32 = 4096
UIDNA_ERROR_CONTEXTO_PUNCTUATION: Int32 = 8192
UIDNA_ERROR_CONTEXTO_DIGITS: Int32 = 16384
ELS_GUID_LANGUAGE_DETECTION: Guid = Guid('{cf7e00b1-909b-4d95-a8f4-611f7c377702}')
ELS_GUID_SCRIPT_DETECTION: Guid = Guid('{2d64b439-6caf-4f6b-b688-e5d0f4faa7d7}')
ELS_GUID_TRANSLITERATION_HANT_TO_HANS: Guid = Guid('{a3a8333b-f4fc-42f6-a0c4-0462fe7317cb}')
ELS_GUID_TRANSLITERATION_HANS_TO_HANT: Guid = Guid('{3caccdc8-5590-42dc-9a7b-b5a6b5b3b63b}')
ELS_GUID_TRANSLITERATION_MALAYALAM_TO_LATIN: Guid = Guid('{d8b983b1-f8bf-4a2b-bcd5-5b5ea20613e1}')
ELS_GUID_TRANSLITERATION_DEVANAGARI_TO_LATIN: Guid = Guid('{c4a4dcfe-2661-4d02-9835-f48187109803}')
ELS_GUID_TRANSLITERATION_CYRILLIC_TO_LATIN: Guid = Guid('{3dd12a98-5afd-4903-a13f-e17e6c0bfe01}')
ELS_GUID_TRANSLITERATION_BENGALI_TO_LATIN: Guid = Guid('{f4dfd825-91a4-489f-855e-9ad9bee55727}')
ELS_GUID_TRANSLITERATION_HANGUL_DECOMPOSITION: Guid = Guid('{4ba2a721-e43d-41b7-b330-536ae1e48863}')
UMSGPAT_ARG_NAME_NOT_NUMBER: Int32 = -1
UMSGPAT_ARG_NAME_NOT_VALID: Int32 = -2
@winfunctype('GDI32.dll')
def GetTextCharset(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> Int32: ...
@winfunctype('GDI32.dll')
def GetTextCharsetInfo(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, lpSig: POINTER(win32more.Windows.Win32.Globalization.FONTSIGNATURE), dwFlags: UInt32) -> Int32: ...
@winfunctype('GDI32.dll')
def TranslateCharsetInfo(lpSrc: POINTER(UInt32), lpCs: POINTER(win32more.Windows.Win32.Globalization.CHARSETINFO), dwFlags: win32more.Windows.Win32.Globalization.TRANSLATE_CHARSET_INFO_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetDateFormatA(Locale: UInt32, dwFlags: UInt32, lpDate: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), lpFormat: win32more.Windows.Win32.Foundation.PSTR, lpDateStr: win32more.Windows.Win32.Foundation.PSTR, cchDate: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetDateFormatW(Locale: UInt32, dwFlags: UInt32, lpDate: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), lpFormat: win32more.Windows.Win32.Foundation.PWSTR, lpDateStr: win32more.Windows.Win32.Foundation.PWSTR, cchDate: Int32) -> Int32: ...
GetDateFormat = UnicodeAlias('GetDateFormatW')
@winfunctype('KERNEL32.dll')
def GetTimeFormatA(Locale: UInt32, dwFlags: UInt32, lpTime: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), lpFormat: win32more.Windows.Win32.Foundation.PSTR, lpTimeStr: win32more.Windows.Win32.Foundation.PSTR, cchTime: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetTimeFormatW(Locale: UInt32, dwFlags: UInt32, lpTime: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), lpFormat: win32more.Windows.Win32.Foundation.PWSTR, lpTimeStr: win32more.Windows.Win32.Foundation.PWSTR, cchTime: Int32) -> Int32: ...
GetTimeFormat = UnicodeAlias('GetTimeFormatW')
@winfunctype('KERNEL32.dll')
def GetTimeFormatEx(lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: win32more.Windows.Win32.Globalization.TIME_FORMAT_FLAGS, lpTime: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), lpFormat: win32more.Windows.Win32.Foundation.PWSTR, lpTimeStr: win32more.Windows.Win32.Foundation.PWSTR, cchTime: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetDateFormatEx(lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: win32more.Windows.Win32.Globalization.ENUM_DATE_FORMATS_FLAGS, lpDate: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), lpFormat: win32more.Windows.Win32.Foundation.PWSTR, lpDateStr: win32more.Windows.Win32.Foundation.PWSTR, cchDate: Int32, lpCalendar: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetDurationFormatEx(lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, lpDuration: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), ullDuration: UInt64, lpFormat: win32more.Windows.Win32.Foundation.PWSTR, lpDurationStr: win32more.Windows.Win32.Foundation.PWSTR, cchDuration: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def CompareStringEx(lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, dwCmpFlags: win32more.Windows.Win32.Globalization.COMPARE_STRING_FLAGS, lpString1: win32more.Windows.Win32.Foundation.PWSTR, cchCount1: Int32, lpString2: win32more.Windows.Win32.Foundation.PWSTR, cchCount2: Int32, lpVersionInformation: POINTER(win32more.Windows.Win32.Globalization.NLSVERSIONINFO), lpReserved: VoidPtr, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Globalization.COMPARESTRING_RESULT: ...
@winfunctype('KERNEL32.dll')
def CompareStringOrdinal(lpString1: win32more.Windows.Win32.Foundation.PWSTR, cchCount1: Int32, lpString2: win32more.Windows.Win32.Foundation.PWSTR, cchCount2: Int32, bIgnoreCase: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Globalization.COMPARESTRING_RESULT: ...
@winfunctype('KERNEL32.dll')
def CompareStringW(Locale: UInt32, dwCmpFlags: UInt32, lpString1: win32more.Windows.Win32.Foundation.PWSTR, cchCount1: Int32, lpString2: win32more.Windows.Win32.Foundation.PWSTR, cchCount2: Int32) -> win32more.Windows.Win32.Globalization.COMPARESTRING_RESULT: ...
CompareString = UnicodeAlias('CompareStringW')
@winfunctype('KERNEL32.dll')
def FoldStringW(dwMapFlags: win32more.Windows.Win32.Globalization.FOLD_STRING_MAP_FLAGS, lpSrcStr: win32more.Windows.Win32.Foundation.PWSTR, cchSrc: Int32, lpDestStr: win32more.Windows.Win32.Foundation.PWSTR, cchDest: Int32) -> Int32: ...
FoldString = UnicodeAlias('FoldStringW')
@winfunctype('KERNEL32.dll')
def GetStringTypeExW(Locale: UInt32, dwInfoType: UInt32, lpSrcStr: win32more.Windows.Win32.Foundation.PWSTR, cchSrc: Int32, lpCharType: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetStringTypeEx = UnicodeAlias('GetStringTypeExW')
@winfunctype('KERNEL32.dll')
def GetStringTypeW(dwInfoType: UInt32, lpSrcStr: win32more.Windows.Win32.Foundation.PWSTR, cchSrc: Int32, lpCharType: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetStringType = UnicodeAlias('GetStringTypeW')
@winfunctype('KERNEL32.dll')
def MultiByteToWideChar(CodePage: UInt32, dwFlags: win32more.Windows.Win32.Globalization.MULTI_BYTE_TO_WIDE_CHAR_FLAGS, lpMultiByteStr: win32more.Windows.Win32.Foundation.PSTR, cbMultiByte: Int32, lpWideCharStr: win32more.Windows.Win32.Foundation.PWSTR, cchWideChar: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def WideCharToMultiByte(CodePage: UInt32, dwFlags: UInt32, lpWideCharStr: win32more.Windows.Win32.Foundation.PWSTR, cchWideChar: Int32, lpMultiByteStr: win32more.Windows.Win32.Foundation.PSTR, cbMultiByte: Int32, lpDefaultChar: win32more.Windows.Win32.Foundation.PSTR, lpUsedDefaultChar: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> Int32: ...
@winfunctype('KERNEL32.dll')
def IsValidCodePage(CodePage: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetACP() -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetOEMCP() -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetCPInfo(CodePage: UInt32, lpCPInfo: POINTER(win32more.Windows.Win32.Globalization.CPINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetCPInfoExA(CodePage: UInt32, dwFlags: UInt32, lpCPInfoEx: POINTER(win32more.Windows.Win32.Globalization.CPINFOEXA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetCPInfoExW(CodePage: UInt32, dwFlags: UInt32, lpCPInfoEx: POINTER(win32more.Windows.Win32.Globalization.CPINFOEXW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetCPInfoEx = UnicodeAlias('GetCPInfoExW')
@winfunctype('KERNEL32.dll')
def CompareStringA(Locale: UInt32, dwCmpFlags: UInt32, lpString1: POINTER(SByte), cchCount1: Int32, lpString2: POINTER(SByte), cchCount2: Int32) -> win32more.Windows.Win32.Globalization.COMPARESTRING_RESULT: ...
@winfunctype('KERNEL32.dll')
def FindNLSString(Locale: UInt32, dwFindNLSStringFlags: UInt32, lpStringSource: win32more.Windows.Win32.Foundation.PWSTR, cchSource: Int32, lpStringValue: win32more.Windows.Win32.Foundation.PWSTR, cchValue: Int32, pcchFound: POINTER(Int32)) -> Int32: ...
@winfunctype('KERNEL32.dll')
def LCMapStringW(Locale: UInt32, dwMapFlags: UInt32, lpSrcStr: win32more.Windows.Win32.Foundation.PWSTR, cchSrc: Int32, lpDestStr: win32more.Windows.Win32.Foundation.PWSTR, cchDest: Int32) -> Int32: ...
LCMapString = UnicodeAlias('LCMapStringW')
@winfunctype('KERNEL32.dll')
def LCMapStringA(Locale: UInt32, dwMapFlags: UInt32, lpSrcStr: win32more.Windows.Win32.Foundation.PSTR, cchSrc: Int32, lpDestStr: win32more.Windows.Win32.Foundation.PSTR, cchDest: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetLocaleInfoW(Locale: UInt32, LCType: UInt32, lpLCData: win32more.Windows.Win32.Foundation.PWSTR, cchData: Int32) -> Int32: ...
GetLocaleInfo = UnicodeAlias('GetLocaleInfoW')
@winfunctype('KERNEL32.dll')
def GetLocaleInfoA(Locale: UInt32, LCType: UInt32, lpLCData: win32more.Windows.Win32.Foundation.PSTR, cchData: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def SetLocaleInfoA(Locale: UInt32, LCType: UInt32, lpLCData: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetLocaleInfoW(Locale: UInt32, LCType: UInt32, lpLCData: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetLocaleInfo = UnicodeAlias('SetLocaleInfoW')
@winfunctype('KERNEL32.dll')
def GetCalendarInfoA(Locale: UInt32, Calendar: UInt32, CalType: UInt32, lpCalData: win32more.Windows.Win32.Foundation.PSTR, cchData: Int32, lpValue: POINTER(UInt32)) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetCalendarInfoW(Locale: UInt32, Calendar: UInt32, CalType: UInt32, lpCalData: win32more.Windows.Win32.Foundation.PWSTR, cchData: Int32, lpValue: POINTER(UInt32)) -> Int32: ...
GetCalendarInfo = UnicodeAlias('GetCalendarInfoW')
@winfunctype('KERNEL32.dll')
def SetCalendarInfoA(Locale: UInt32, Calendar: UInt32, CalType: UInt32, lpCalData: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetCalendarInfoW(Locale: UInt32, Calendar: UInt32, CalType: UInt32, lpCalData: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetCalendarInfo = UnicodeAlias('SetCalendarInfoW')
@winfunctype('KERNEL32.dll')
def IsDBCSLeadByte(TestChar: Byte) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def IsDBCSLeadByteEx(CodePage: UInt32, TestChar: Byte) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def LocaleNameToLCID(lpName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def LCIDToLocaleName(Locale: UInt32, lpName: win32more.Windows.Win32.Foundation.PWSTR, cchName: Int32, dwFlags: UInt32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetDurationFormat(Locale: UInt32, dwFlags: UInt32, lpDuration: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), ullDuration: UInt64, lpFormat: win32more.Windows.Win32.Foundation.PWSTR, lpDurationStr: win32more.Windows.Win32.Foundation.PWSTR, cchDuration: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetNumberFormatA(Locale: UInt32, dwFlags: UInt32, lpValue: win32more.Windows.Win32.Foundation.PSTR, lpFormat: POINTER(win32more.Windows.Win32.Globalization.NUMBERFMTA), lpNumberStr: win32more.Windows.Win32.Foundation.PSTR, cchNumber: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetNumberFormatW(Locale: UInt32, dwFlags: UInt32, lpValue: win32more.Windows.Win32.Foundation.PWSTR, lpFormat: POINTER(win32more.Windows.Win32.Globalization.NUMBERFMTW), lpNumberStr: win32more.Windows.Win32.Foundation.PWSTR, cchNumber: Int32) -> Int32: ...
GetNumberFormat = UnicodeAlias('GetNumberFormatW')
@winfunctype('KERNEL32.dll')
def GetCurrencyFormatA(Locale: UInt32, dwFlags: UInt32, lpValue: win32more.Windows.Win32.Foundation.PSTR, lpFormat: POINTER(win32more.Windows.Win32.Globalization.CURRENCYFMTA), lpCurrencyStr: win32more.Windows.Win32.Foundation.PSTR, cchCurrency: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetCurrencyFormatW(Locale: UInt32, dwFlags: UInt32, lpValue: win32more.Windows.Win32.Foundation.PWSTR, lpFormat: POINTER(win32more.Windows.Win32.Globalization.CURRENCYFMTW), lpCurrencyStr: win32more.Windows.Win32.Foundation.PWSTR, cchCurrency: Int32) -> Int32: ...
GetCurrencyFormat = UnicodeAlias('GetCurrencyFormatW')
@winfunctype('KERNEL32.dll')
def EnumCalendarInfoA(lpCalInfoEnumProc: win32more.Windows.Win32.Globalization.CALINFO_ENUMPROCA, Locale: UInt32, Calendar: UInt32, CalType: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumCalendarInfoW(lpCalInfoEnumProc: win32more.Windows.Win32.Globalization.CALINFO_ENUMPROCW, Locale: UInt32, Calendar: UInt32, CalType: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumCalendarInfo = UnicodeAlias('EnumCalendarInfoW')
@winfunctype('KERNEL32.dll')
def EnumCalendarInfoExA(lpCalInfoEnumProcEx: win32more.Windows.Win32.Globalization.CALINFO_ENUMPROCEXA, Locale: UInt32, Calendar: UInt32, CalType: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumCalendarInfoExW(lpCalInfoEnumProcEx: win32more.Windows.Win32.Globalization.CALINFO_ENUMPROCEXW, Locale: UInt32, Calendar: UInt32, CalType: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumCalendarInfoEx = UnicodeAlias('EnumCalendarInfoExW')
@winfunctype('KERNEL32.dll')
def EnumTimeFormatsA(lpTimeFmtEnumProc: win32more.Windows.Win32.Globalization.TIMEFMT_ENUMPROCA, Locale: UInt32, dwFlags: win32more.Windows.Win32.Globalization.TIME_FORMAT_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumTimeFormatsW(lpTimeFmtEnumProc: win32more.Windows.Win32.Globalization.TIMEFMT_ENUMPROCW, Locale: UInt32, dwFlags: win32more.Windows.Win32.Globalization.TIME_FORMAT_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumTimeFormats = UnicodeAlias('EnumTimeFormatsW')
@winfunctype('KERNEL32.dll')
def EnumDateFormatsA(lpDateFmtEnumProc: win32more.Windows.Win32.Globalization.DATEFMT_ENUMPROCA, Locale: UInt32, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumDateFormatsW(lpDateFmtEnumProc: win32more.Windows.Win32.Globalization.DATEFMT_ENUMPROCW, Locale: UInt32, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumDateFormats = UnicodeAlias('EnumDateFormatsW')
@winfunctype('KERNEL32.dll')
def EnumDateFormatsExA(lpDateFmtEnumProcEx: win32more.Windows.Win32.Globalization.DATEFMT_ENUMPROCEXA, Locale: UInt32, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumDateFormatsExW(lpDateFmtEnumProcEx: win32more.Windows.Win32.Globalization.DATEFMT_ENUMPROCEXW, Locale: UInt32, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumDateFormatsEx = UnicodeAlias('EnumDateFormatsExW')
@winfunctype('KERNEL32.dll')
def IsValidLanguageGroup(LanguageGroup: UInt32, dwFlags: win32more.Windows.Win32.Globalization.ENUM_SYSTEM_LANGUAGE_GROUPS_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetNLSVersion(Function: UInt32, Locale: UInt32, lpVersionInformation: POINTER(win32more.Windows.Win32.Globalization.NLSVERSIONINFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def IsValidLocale(Locale: UInt32, dwFlags: win32more.Windows.Win32.Globalization.IS_VALID_LOCALE_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetGeoInfoA(Location: Int32, GeoType: win32more.Windows.Win32.Globalization.SYSGEOTYPE, lpGeoData: win32more.Windows.Win32.Foundation.PSTR, cchData: Int32, LangId: UInt16) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetGeoInfoW(Location: Int32, GeoType: win32more.Windows.Win32.Globalization.SYSGEOTYPE, lpGeoData: win32more.Windows.Win32.Foundation.PWSTR, cchData: Int32, LangId: UInt16) -> Int32: ...
GetGeoInfo = UnicodeAlias('GetGeoInfoW')
@winfunctype('KERNEL32.dll')
def GetGeoInfoEx(location: win32more.Windows.Win32.Foundation.PWSTR, geoType: win32more.Windows.Win32.Globalization.SYSGEOTYPE, geoData: win32more.Windows.Win32.Foundation.PWSTR, geoDataCount: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def EnumSystemGeoID(GeoClass: UInt32, ParentGeoId: Int32, lpGeoEnumProc: win32more.Windows.Win32.Globalization.GEO_ENUMPROC) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumSystemGeoNames(geoClass: UInt32, geoEnumProc: win32more.Windows.Win32.Globalization.GEO_ENUMNAMEPROC, data: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetUserGeoID(GeoClass: win32more.Windows.Win32.Globalization.SYSGEOCLASS) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetUserDefaultGeoName(geoName: win32more.Windows.Win32.Foundation.PWSTR, geoNameCount: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def SetUserGeoID(GeoId: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetUserGeoName(geoName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def ConvertDefaultLocale(Locale: UInt32) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetSystemDefaultUILanguage() -> UInt16: ...
@winfunctype('KERNEL32.dll')
def GetThreadLocale() -> UInt32: ...
@winfunctype('KERNEL32.dll')
def SetThreadLocale(Locale: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetUserDefaultUILanguage() -> UInt16: ...
@winfunctype('KERNEL32.dll')
def GetUserDefaultLangID() -> UInt16: ...
@winfunctype('KERNEL32.dll')
def GetSystemDefaultLangID() -> UInt16: ...
@winfunctype('KERNEL32.dll')
def GetSystemDefaultLCID() -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetUserDefaultLCID() -> UInt32: ...
@winfunctype('KERNEL32.dll')
def SetThreadUILanguage(LangId: UInt16) -> UInt16: ...
@winfunctype('KERNEL32.dll')
def GetThreadUILanguage() -> UInt16: ...
@winfunctype('KERNEL32.dll')
def GetProcessPreferredUILanguages(dwFlags: UInt32, pulNumLanguages: POINTER(UInt32), pwszLanguagesBuffer: win32more.Windows.Win32.Foundation.PWSTR, pcchLanguagesBuffer: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetProcessPreferredUILanguages(dwFlags: UInt32, pwszLanguagesBuffer: win32more.Windows.Win32.Foundation.PWSTR, pulNumLanguages: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetUserPreferredUILanguages(dwFlags: UInt32, pulNumLanguages: POINTER(UInt32), pwszLanguagesBuffer: win32more.Windows.Win32.Foundation.PWSTR, pcchLanguagesBuffer: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetSystemPreferredUILanguages(dwFlags: UInt32, pulNumLanguages: POINTER(UInt32), pwszLanguagesBuffer: win32more.Windows.Win32.Foundation.PWSTR, pcchLanguagesBuffer: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetThreadPreferredUILanguages(dwFlags: UInt32, pulNumLanguages: POINTER(UInt32), pwszLanguagesBuffer: win32more.Windows.Win32.Foundation.PWSTR, pcchLanguagesBuffer: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetThreadPreferredUILanguages(dwFlags: UInt32, pwszLanguagesBuffer: win32more.Windows.Win32.Foundation.PWSTR, pulNumLanguages: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetFileMUIInfo(dwFlags: UInt32, pcwszFilePath: win32more.Windows.Win32.Foundation.PWSTR, pFileMUIInfo: POINTER(win32more.Windows.Win32.Globalization.FILEMUIINFO), pcbFileMUIInfo: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetFileMUIPath(dwFlags: UInt32, pcwszFilePath: win32more.Windows.Win32.Foundation.PWSTR, pwszLanguage: win32more.Windows.Win32.Foundation.PWSTR, pcchLanguage: POINTER(UInt32), pwszFileMUIPath: win32more.Windows.Win32.Foundation.PWSTR, pcchFileMUIPath: POINTER(UInt32), pululEnumerator: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetUILanguageInfo(dwFlags: UInt32, pwmszLanguage: win32more.Windows.Win32.Foundation.PWSTR, pwszFallbackLanguages: win32more.Windows.Win32.Foundation.PWSTR, pcchFallbackLanguages: POINTER(UInt32), pAttributes: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetThreadPreferredUILanguages2(flags: UInt32, languages: win32more.Windows.Win32.Foundation.PWSTR, numLanguagesSet: POINTER(UInt32), snapshot: POINTER(win32more.Windows.Win32.Globalization.HSAVEDUILANGUAGES)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def RestoreThreadPreferredUILanguages(snapshot: win32more.Windows.Win32.Globalization.HSAVEDUILANGUAGES) -> Void: ...
@winfunctype('KERNEL32.dll')
def NotifyUILanguageChange(dwFlags: UInt32, pcwstrNewLanguage: win32more.Windows.Win32.Foundation.PWSTR, pcwstrPreviousLanguage: win32more.Windows.Win32.Foundation.PWSTR, dwReserved: UInt32, pdwStatusRtrn: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetStringTypeExA(Locale: UInt32, dwInfoType: UInt32, lpSrcStr: win32more.Windows.Win32.Foundation.PSTR, cchSrc: Int32, lpCharType: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetStringTypeA(Locale: UInt32, dwInfoType: UInt32, lpSrcStr: win32more.Windows.Win32.Foundation.PSTR, cchSrc: Int32, lpCharType: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def FoldStringA(dwMapFlags: win32more.Windows.Win32.Globalization.FOLD_STRING_MAP_FLAGS, lpSrcStr: win32more.Windows.Win32.Foundation.PSTR, cchSrc: Int32, lpDestStr: win32more.Windows.Win32.Foundation.PSTR, cchDest: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def EnumSystemLocalesA(lpLocaleEnumProc: win32more.Windows.Win32.Globalization.LOCALE_ENUMPROCA, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumSystemLocalesW(lpLocaleEnumProc: win32more.Windows.Win32.Globalization.LOCALE_ENUMPROCW, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumSystemLocales = UnicodeAlias('EnumSystemLocalesW')
@winfunctype('KERNEL32.dll')
def EnumSystemLanguageGroupsA(lpLanguageGroupEnumProc: win32more.Windows.Win32.Globalization.LANGUAGEGROUP_ENUMPROCA, dwFlags: win32more.Windows.Win32.Globalization.ENUM_SYSTEM_LANGUAGE_GROUPS_FLAGS, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumSystemLanguageGroupsW(lpLanguageGroupEnumProc: win32more.Windows.Win32.Globalization.LANGUAGEGROUP_ENUMPROCW, dwFlags: win32more.Windows.Win32.Globalization.ENUM_SYSTEM_LANGUAGE_GROUPS_FLAGS, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumSystemLanguageGroups = UnicodeAlias('EnumSystemLanguageGroupsW')
@winfunctype('KERNEL32.dll')
def EnumLanguageGroupLocalesA(lpLangGroupLocaleEnumProc: win32more.Windows.Win32.Globalization.LANGGROUPLOCALE_ENUMPROCA, LanguageGroup: UInt32, dwFlags: UInt32, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumLanguageGroupLocalesW(lpLangGroupLocaleEnumProc: win32more.Windows.Win32.Globalization.LANGGROUPLOCALE_ENUMPROCW, LanguageGroup: UInt32, dwFlags: UInt32, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumLanguageGroupLocales = UnicodeAlias('EnumLanguageGroupLocalesW')
@winfunctype('KERNEL32.dll')
def EnumUILanguagesA(lpUILanguageEnumProc: win32more.Windows.Win32.Globalization.UILANGUAGE_ENUMPROCA, dwFlags: UInt32, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumUILanguagesW(lpUILanguageEnumProc: win32more.Windows.Win32.Globalization.UILANGUAGE_ENUMPROCW, dwFlags: UInt32, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumUILanguages = UnicodeAlias('EnumUILanguagesW')
@winfunctype('KERNEL32.dll')
def EnumSystemCodePagesA(lpCodePageEnumProc: win32more.Windows.Win32.Globalization.CODEPAGE_ENUMPROCA, dwFlags: win32more.Windows.Win32.Globalization.ENUM_SYSTEM_CODE_PAGES_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumSystemCodePagesW(lpCodePageEnumProc: win32more.Windows.Win32.Globalization.CODEPAGE_ENUMPROCW, dwFlags: win32more.Windows.Win32.Globalization.ENUM_SYSTEM_CODE_PAGES_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumSystemCodePages = UnicodeAlias('EnumSystemCodePagesW')
@winfunctype('NORMALIZ.dll')
def IdnToAscii(dwFlags: UInt32, lpUnicodeCharStr: win32more.Windows.Win32.Foundation.PWSTR, cchUnicodeChar: Int32, lpASCIICharStr: win32more.Windows.Win32.Foundation.PWSTR, cchASCIIChar: Int32) -> Int32: ...
@winfunctype('NORMALIZ.dll')
def IdnToUnicode(dwFlags: UInt32, lpASCIICharStr: win32more.Windows.Win32.Foundation.PWSTR, cchASCIIChar: Int32, lpUnicodeCharStr: win32more.Windows.Win32.Foundation.PWSTR, cchUnicodeChar: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def IdnToNameprepUnicode(dwFlags: UInt32, lpUnicodeCharStr: win32more.Windows.Win32.Foundation.PWSTR, cchUnicodeChar: Int32, lpNameprepCharStr: win32more.Windows.Win32.Foundation.PWSTR, cchNameprepChar: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def NormalizeString(NormForm: win32more.Windows.Win32.Globalization.NORM_FORM, lpSrcString: win32more.Windows.Win32.Foundation.PWSTR, cwSrcLength: Int32, lpDstString: win32more.Windows.Win32.Foundation.PWSTR, cwDstLength: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def IsNormalizedString(NormForm: win32more.Windows.Win32.Globalization.NORM_FORM, lpString: win32more.Windows.Win32.Foundation.PWSTR, cwLength: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def VerifyScripts(dwFlags: UInt32, lpLocaleScripts: win32more.Windows.Win32.Foundation.PWSTR, cchLocaleScripts: Int32, lpTestScripts: win32more.Windows.Win32.Foundation.PWSTR, cchTestScripts: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetStringScripts(dwFlags: UInt32, lpString: win32more.Windows.Win32.Foundation.PWSTR, cchString: Int32, lpScripts: win32more.Windows.Win32.Foundation.PWSTR, cchScripts: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetLocaleInfoEx(lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, LCType: UInt32, lpLCData: win32more.Windows.Win32.Foundation.PWSTR, cchData: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetCalendarInfoEx(lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, Calendar: UInt32, lpReserved: win32more.Windows.Win32.Foundation.PWSTR, CalType: UInt32, lpCalData: win32more.Windows.Win32.Foundation.PWSTR, cchData: Int32, lpValue: POINTER(UInt32)) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetNumberFormatEx(lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, lpValue: win32more.Windows.Win32.Foundation.PWSTR, lpFormat: POINTER(win32more.Windows.Win32.Globalization.NUMBERFMTW), lpNumberStr: win32more.Windows.Win32.Foundation.PWSTR, cchNumber: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetCurrencyFormatEx(lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, lpValue: win32more.Windows.Win32.Foundation.PWSTR, lpFormat: POINTER(win32more.Windows.Win32.Globalization.CURRENCYFMTW), lpCurrencyStr: win32more.Windows.Win32.Foundation.PWSTR, cchCurrency: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetUserDefaultLocaleName(lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, cchLocaleName: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def GetSystemDefaultLocaleName(lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, cchLocaleName: Int32) -> Int32: ...
@winfunctype('KERNEL32.dll')
def IsNLSDefinedString(Function: UInt32, dwFlags: UInt32, lpVersionInformation: POINTER(win32more.Windows.Win32.Globalization.NLSVERSIONINFO), lpString: win32more.Windows.Win32.Foundation.PWSTR, cchStr: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetNLSVersionEx(function: UInt32, lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, lpVersionInformation: POINTER(win32more.Windows.Win32.Globalization.NLSVERSIONINFOEX)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def IsValidNLSVersion(function: UInt32, lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, lpVersionInformation: POINTER(win32more.Windows.Win32.Globalization.NLSVERSIONINFOEX)) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def FindNLSStringEx(lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, dwFindNLSStringFlags: UInt32, lpStringSource: win32more.Windows.Win32.Foundation.PWSTR, cchSource: Int32, lpStringValue: win32more.Windows.Win32.Foundation.PWSTR, cchValue: Int32, pcchFound: POINTER(Int32), lpVersionInformation: POINTER(win32more.Windows.Win32.Globalization.NLSVERSIONINFO), lpReserved: VoidPtr, sortHandle: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype('KERNEL32.dll')
def LCMapStringEx(lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, dwMapFlags: UInt32, lpSrcStr: win32more.Windows.Win32.Foundation.PWSTR, cchSrc: Int32, lpDestStr: win32more.Windows.Win32.Foundation.PWSTR, cchDest: Int32, lpVersionInformation: POINTER(win32more.Windows.Win32.Globalization.NLSVERSIONINFO), lpReserved: VoidPtr, sortHandle: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype('KERNEL32.dll')
def IsValidLocaleName(lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumCalendarInfoExEx(pCalInfoEnumProcExEx: win32more.Windows.Win32.Globalization.CALINFO_ENUMPROCEXEX, lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, Calendar: UInt32, lpReserved: win32more.Windows.Win32.Foundation.PWSTR, CalType: UInt32, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumDateFormatsExEx(lpDateFmtEnumProcExEx: win32more.Windows.Win32.Globalization.DATEFMT_ENUMPROCEXEX, lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: win32more.Windows.Win32.Globalization.ENUM_DATE_FORMATS_FLAGS, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumTimeFormatsEx(lpTimeFmtEnumProcEx: win32more.Windows.Win32.Globalization.TIMEFMT_ENUMPROCEX, lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumSystemLocalesEx(lpLocaleEnumProcEx: win32more.Windows.Win32.Globalization.LOCALE_ENUMPROCEX, dwFlags: UInt32, lParam: win32more.Windows.Win32.Foundation.LPARAM, lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def ResolveLocaleName(lpNameToResolve: win32more.Windows.Win32.Foundation.PWSTR, lpLocaleName: win32more.Windows.Win32.Foundation.PWSTR, cchLocaleName: Int32) -> Int32: ...
@winfunctype('elscore.dll')
def MappingGetServices(pOptions: POINTER(win32more.Windows.Win32.Globalization.MAPPING_ENUM_OPTIONS), prgServices: POINTER(POINTER(win32more.Windows.Win32.Globalization.MAPPING_SERVICE_INFO)), pdwServicesCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('elscore.dll')
def MappingFreeServices(pServiceInfo: POINTER(win32more.Windows.Win32.Globalization.MAPPING_SERVICE_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('elscore.dll')
def MappingRecognizeText(pServiceInfo: POINTER(win32more.Windows.Win32.Globalization.MAPPING_SERVICE_INFO), pszText: win32more.Windows.Win32.Foundation.PWSTR, dwLength: UInt32, dwIndex: UInt32, pOptions: POINTER(win32more.Windows.Win32.Globalization.MAPPING_OPTIONS), pbag: POINTER(win32more.Windows.Win32.Globalization.MAPPING_PROPERTY_BAG)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('elscore.dll')
def MappingDoAction(pBag: POINTER(win32more.Windows.Win32.Globalization.MAPPING_PROPERTY_BAG), dwRangeIndex: UInt32, pszActionId: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('elscore.dll')
def MappingFreePropertyBag(pBag: POINTER(win32more.Windows.Win32.Globalization.MAPPING_PROPERTY_BAG)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptFreeCache(psc: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptItemize(pwcInChars: win32more.Windows.Win32.Foundation.PWSTR, cInChars: Int32, cMaxItems: Int32, psControl: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_CONTROL), psState: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_STATE), pItems: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ITEM), pcItems: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptLayout(cRuns: Int32, pbLevel: POINTER(Byte), piVisualToLogical: POINTER(Int32), piLogicalToVisual: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptShape(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, psc: POINTER(VoidPtr), pwcChars: win32more.Windows.Win32.Foundation.PWSTR, cChars: Int32, cMaxGlyphs: Int32, psa: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ANALYSIS), pwOutGlyphs: POINTER(UInt16), pwLogClust: POINTER(UInt16), psva: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_VISATTR), pcGlyphs: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptPlace(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, psc: POINTER(VoidPtr), pwGlyphs: POINTER(UInt16), cGlyphs: Int32, psva: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_VISATTR), psa: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ANALYSIS), piAdvance: POINTER(Int32), pGoffset: POINTER(win32more.Windows.Win32.Globalization.GOFFSET), pABC: POINTER(win32more.Windows.Win32.Graphics.Gdi.ABC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptTextOut(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, psc: POINTER(VoidPtr), x: Int32, y: Int32, fuOptions: UInt32, lprc: POINTER(win32more.Windows.Win32.Foundation.RECT), psa: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ANALYSIS), pwcReserved: win32more.Windows.Win32.Foundation.PWSTR, iReserved: Int32, pwGlyphs: POINTER(UInt16), cGlyphs: Int32, piAdvance: POINTER(Int32), piJustify: POINTER(Int32), pGoffset: POINTER(win32more.Windows.Win32.Globalization.GOFFSET)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptJustify(psva: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_VISATTR), piAdvance: POINTER(Int32), cGlyphs: Int32, iDx: Int32, iMinKashida: Int32, piJustify: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptBreak(pwcChars: win32more.Windows.Win32.Foundation.PWSTR, cChars: Int32, psa: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ANALYSIS), psla: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_LOGATTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptCPtoX(iCP: Int32, fTrailing: win32more.Windows.Win32.Foundation.BOOL, cChars: Int32, cGlyphs: Int32, pwLogClust: POINTER(UInt16), psva: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_VISATTR), piAdvance: POINTER(Int32), psa: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ANALYSIS), piX: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptXtoCP(iX: Int32, cChars: Int32, cGlyphs: Int32, pwLogClust: POINTER(UInt16), psva: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_VISATTR), piAdvance: POINTER(Int32), psa: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ANALYSIS), piCP: POINTER(Int32), piTrailing: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptGetLogicalWidths(psa: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ANALYSIS), cChars: Int32, cGlyphs: Int32, piGlyphWidth: POINTER(Int32), pwLogClust: POINTER(UInt16), psva: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_VISATTR), piDx: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptApplyLogicalWidth(piDx: POINTER(Int32), cChars: Int32, cGlyphs: Int32, pwLogClust: POINTER(UInt16), psva: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_VISATTR), piAdvance: POINTER(Int32), psa: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ANALYSIS), pABC: POINTER(win32more.Windows.Win32.Graphics.Gdi.ABC), piJustify: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptGetCMap(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, psc: POINTER(VoidPtr), pwcInChars: win32more.Windows.Win32.Foundation.PWSTR, cChars: Int32, dwFlags: UInt32, pwOutGlyphs: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptGetGlyphABCWidth(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, psc: POINTER(VoidPtr), wGlyph: UInt16, pABC: POINTER(win32more.Windows.Win32.Graphics.Gdi.ABC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptGetProperties(ppSp: POINTER(POINTER(POINTER(win32more.Windows.Win32.Globalization.SCRIPT_PROPERTIES))), piNumScripts: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptGetFontProperties(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, psc: POINTER(VoidPtr), sfp: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_FONTPROPERTIES)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptCacheGetHeight(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, psc: POINTER(VoidPtr), tmHeight: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptStringAnalyse(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, pString: VoidPtr, cString: Int32, cGlyphs: Int32, iCharset: Int32, dwFlags: UInt32, iReqWidth: Int32, psControl: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_CONTROL), psState: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_STATE), piDx: POINTER(Int32), pTabdef: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_TABDEF), pbInClass: POINTER(Byte), pssa: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptStringFree(pssa: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptString_pSize(ssa: VoidPtr) -> POINTER(win32more.Windows.Win32.Foundation.SIZE): ...
@winfunctype('USP10.dll')
def ScriptString_pcOutChars(ssa: VoidPtr) -> POINTER(Int32): ...
@winfunctype('USP10.dll')
def ScriptString_pLogAttr(ssa: VoidPtr) -> POINTER(win32more.Windows.Win32.Globalization.SCRIPT_LOGATTR): ...
@winfunctype('USP10.dll')
def ScriptStringGetOrder(ssa: VoidPtr, puOrder: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptStringCPtoX(ssa: VoidPtr, icp: Int32, fTrailing: win32more.Windows.Win32.Foundation.BOOL, pX: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptStringXtoCP(ssa: VoidPtr, iX: Int32, piCh: POINTER(Int32), piTrailing: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptStringGetLogicalWidths(ssa: VoidPtr, piDx: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptStringValidate(ssa: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptStringOut(ssa: VoidPtr, iX: Int32, iY: Int32, uOptions: win32more.Windows.Win32.Graphics.Gdi.ETO_OPTIONS, prc: POINTER(win32more.Windows.Win32.Foundation.RECT), iMinSel: Int32, iMaxSel: Int32, fDisabled: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptIsComplex(pwcInChars: win32more.Windows.Win32.Foundation.PWSTR, cInChars: Int32, dwFlags: win32more.Windows.Win32.Globalization.SCRIPT_IS_COMPLEX_FLAGS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptRecordDigitSubstitution(Locale: UInt32, psds: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_DIGITSUBSTITUTE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptApplyDigitSubstitution(psds: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_DIGITSUBSTITUTE), psc: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_CONTROL), pss: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_STATE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptShapeOpenType(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, psc: POINTER(VoidPtr), psa: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ANALYSIS), tagScript: UInt32, tagLangSys: UInt32, rcRangeChars: POINTER(Int32), rpRangeProperties: POINTER(POINTER(win32more.Windows.Win32.Globalization.TEXTRANGE_PROPERTIES)), cRanges: Int32, pwcChars: win32more.Windows.Win32.Foundation.PWSTR, cChars: Int32, cMaxGlyphs: Int32, pwLogClust: POINTER(UInt16), pCharProps: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_CHARPROP), pwOutGlyphs: POINTER(UInt16), pOutGlyphProps: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_GLYPHPROP), pcGlyphs: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptPlaceOpenType(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, psc: POINTER(VoidPtr), psa: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ANALYSIS), tagScript: UInt32, tagLangSys: UInt32, rcRangeChars: POINTER(Int32), rpRangeProperties: POINTER(POINTER(win32more.Windows.Win32.Globalization.TEXTRANGE_PROPERTIES)), cRanges: Int32, pwcChars: win32more.Windows.Win32.Foundation.PWSTR, pwLogClust: POINTER(UInt16), pCharProps: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_CHARPROP), cChars: Int32, pwGlyphs: POINTER(UInt16), pGlyphProps: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_GLYPHPROP), cGlyphs: Int32, piAdvance: POINTER(Int32), pGoffset: POINTER(win32more.Windows.Win32.Globalization.GOFFSET), pABC: POINTER(win32more.Windows.Win32.Graphics.Gdi.ABC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptItemizeOpenType(pwcInChars: win32more.Windows.Win32.Foundation.PWSTR, cInChars: Int32, cMaxItems: Int32, psControl: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_CONTROL), psState: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_STATE), pItems: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ITEM), pScriptTags: POINTER(UInt32), pcItems: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptGetFontScriptTags(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, psc: POINTER(VoidPtr), psa: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ANALYSIS), cMaxTags: Int32, pScriptTags: POINTER(UInt32), pcTags: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptGetFontLanguageTags(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, psc: POINTER(VoidPtr), psa: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ANALYSIS), tagScript: UInt32, cMaxTags: Int32, pLangsysTags: POINTER(UInt32), pcTags: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptGetFontFeatureTags(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, psc: POINTER(VoidPtr), psa: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ANALYSIS), tagScript: UInt32, tagLangSys: UInt32, cMaxTags: Int32, pFeatureTags: POINTER(UInt32), pcTags: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptGetFontAlternateGlyphs(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, psc: POINTER(VoidPtr), psa: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ANALYSIS), tagScript: UInt32, tagLangSys: UInt32, tagFeature: UInt32, wGlyphId: UInt16, cMaxAlternates: Int32, pAlternateGlyphs: POINTER(UInt16), pcAlternates: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptSubstituteSingleGlyph(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, psc: POINTER(VoidPtr), psa: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ANALYSIS), tagScript: UInt32, tagLangSys: UInt32, tagFeature: UInt32, lParameter: Int32, wGlyphId: UInt16, pwOutGlyphId: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('USP10.dll')
def ScriptPositionSingleGlyph(hdc: win32more.Windows.Win32.Graphics.Gdi.HDC, psc: POINTER(VoidPtr), psa: POINTER(win32more.Windows.Win32.Globalization.SCRIPT_ANALYSIS), tagScript: UInt32, tagLangSys: UInt32, tagFeature: UInt32, lParameter: Int32, wGlyphId: UInt16, iAdvance: Int32, GOffset: win32more.Windows.Win32.Globalization.GOFFSET, piOutAdvance: POINTER(Int32), pOutGoffset: POINTER(win32more.Windows.Win32.Globalization.GOFFSET)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@cfunctype('icuuc.dll')
def utf8_nextCharSafeBody(s: POINTER(Byte), pi: POINTER(Int32), length: Int32, c: Int32, strict: SByte) -> Int32: ...
@cfunctype('icuuc.dll')
def utf8_appendCharSafeBody(s: POINTER(Byte), i: Int32, length: Int32, c: Int32, pIsError: POINTER(SByte)) -> Int32: ...
@cfunctype('icuuc.dll')
def utf8_prevCharSafeBody(s: POINTER(Byte), start: Int32, pi: POINTER(Int32), c: Int32, strict: SByte) -> Int32: ...
@cfunctype('icuuc.dll')
def utf8_back1SafeBody(s: POINTER(Byte), start: Int32, i: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def u_versionFromString(versionArray: POINTER(Byte), versionString: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@cfunctype('icuuc.dll')
def u_versionFromUString(versionArray: POINTER(Byte), versionString: POINTER(UInt16)) -> Void: ...
@cfunctype('icuuc.dll')
def u_versionToString(versionArray: POINTER(Byte), versionString: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@cfunctype('icuuc.dll')
def u_getVersion(versionArray: POINTER(Byte)) -> Void: ...
@cfunctype('icuuc.dll')
def u_errorName(code: win32more.Windows.Win32.Globalization.UErrorCode) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def utrace_setLevel(traceLevel: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def utrace_getLevel() -> Int32: ...
@cfunctype('icuuc.dll')
def utrace_setFunctions(context: VoidPtr, e: win32more.Windows.Win32.Globalization.UTraceEntry, x: win32more.Windows.Win32.Globalization.UTraceExit, d: win32more.Windows.Win32.Globalization.UTraceData) -> Void: ...
@cfunctype('icuuc.dll')
def utrace_getFunctions(context: POINTER(VoidPtr), e: POINTER(win32more.Windows.Win32.Globalization.UTraceEntry), x: POINTER(win32more.Windows.Win32.Globalization.UTraceExit), d: POINTER(win32more.Windows.Win32.Globalization.UTraceData)) -> Void: ...
@cfunctype('icuuc.dll')
def utrace_vformat(outBuf: win32more.Windows.Win32.Foundation.PSTR, capacity: Int32, indent: Int32, fmt: win32more.Windows.Win32.Foundation.PSTR, args: POINTER(SByte)) -> Int32: ...
@cfunctype('icuuc.dll', variadic=True)
def utrace_format(outBuf: win32more.Windows.Win32.Foundation.PSTR, capacity: Int32, indent: Int32, fmt: win32more.Windows.Win32.Foundation.PSTR, *__arglist) -> Int32: ...
@cfunctype('icuuc.dll')
def utrace_functionName(fnNumber: Int32) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def u_shapeArabic(source: POINTER(UInt16), sourceLength: Int32, dest: POINTER(UInt16), destSize: Int32, options: UInt32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uscript_getCode(nameOrAbbrOrLocale: win32more.Windows.Win32.Foundation.PSTR, fillIn: POINTER(win32more.Windows.Win32.Globalization.UScriptCode), capacity: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uscript_getName(scriptCode: win32more.Windows.Win32.Globalization.UScriptCode) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def uscript_getShortName(scriptCode: win32more.Windows.Win32.Globalization.UScriptCode) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def uscript_getScript(codepoint: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Globalization.UScriptCode: ...
@cfunctype('icuuc.dll')
def uscript_hasScript(c: Int32, sc: win32more.Windows.Win32.Globalization.UScriptCode) -> SByte: ...
@cfunctype('icuuc.dll')
def uscript_getScriptExtensions(c: Int32, scripts: POINTER(win32more.Windows.Win32.Globalization.UScriptCode), capacity: Int32, errorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uscript_getSampleString(script: win32more.Windows.Win32.Globalization.UScriptCode, dest: POINTER(UInt16), capacity: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uscript_getUsage(script: win32more.Windows.Win32.Globalization.UScriptCode) -> win32more.Windows.Win32.Globalization.UScriptUsage: ...
@cfunctype('icuuc.dll')
def uscript_isRightToLeft(script: win32more.Windows.Win32.Globalization.UScriptCode) -> SByte: ...
@cfunctype('icuuc.dll')
def uscript_breaksBetweenLetters(script: win32more.Windows.Win32.Globalization.UScriptCode) -> SByte: ...
@cfunctype('icuuc.dll')
def uscript_isCased(script: win32more.Windows.Win32.Globalization.UScriptCode) -> SByte: ...
@cfunctype('icuuc.dll')
def uiter_current32(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator)) -> Int32: ...
@cfunctype('icuuc.dll')
def uiter_next32(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator)) -> Int32: ...
@cfunctype('icuuc.dll')
def uiter_previous32(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator)) -> Int32: ...
@cfunctype('icuuc.dll')
def uiter_getState(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator)) -> UInt32: ...
@cfunctype('icuuc.dll')
def uiter_setState(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator), state: UInt32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def uiter_setString(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator), s: POINTER(UInt16), length: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def uiter_setUTF16BE(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator), s: win32more.Windows.Win32.Foundation.PSTR, length: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def uiter_setUTF8(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator), s: win32more.Windows.Win32.Foundation.PSTR, length: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def uenum_close(en: POINTER(win32more.Windows.Win32.Globalization.UEnumeration)) -> Void: ...
@cfunctype('icuuc.dll')
def uenum_count(en: POINTER(win32more.Windows.Win32.Globalization.UEnumeration), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uenum_unext(en: POINTER(win32more.Windows.Win32.Globalization.UEnumeration), resultLength: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def uenum_next(en: POINTER(win32more.Windows.Win32.Globalization.UEnumeration), resultLength: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def uenum_reset(en: POINTER(win32more.Windows.Win32.Globalization.UEnumeration), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def uenum_openUCharStringsEnumeration(strings: POINTER(POINTER(UInt16)), count: Int32, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuuc.dll')
def uenum_openCharStringsEnumeration(strings: POINTER(POINTER(SByte)), count: Int32, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuuc.dll')
def uloc_getDefault() -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def uloc_setDefault(localeID: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def uloc_getLanguage(localeID: win32more.Windows.Win32.Foundation.PSTR, language: win32more.Windows.Win32.Foundation.PSTR, languageCapacity: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_getScript(localeID: win32more.Windows.Win32.Foundation.PSTR, script: win32more.Windows.Win32.Foundation.PSTR, scriptCapacity: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_getCountry(localeID: win32more.Windows.Win32.Foundation.PSTR, country: win32more.Windows.Win32.Foundation.PSTR, countryCapacity: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_getVariant(localeID: win32more.Windows.Win32.Foundation.PSTR, variant: win32more.Windows.Win32.Foundation.PSTR, variantCapacity: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_getName(localeID: win32more.Windows.Win32.Foundation.PSTR, name: win32more.Windows.Win32.Foundation.PSTR, nameCapacity: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_canonicalize(localeID: win32more.Windows.Win32.Foundation.PSTR, name: win32more.Windows.Win32.Foundation.PSTR, nameCapacity: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_getISO3Language(localeID: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def uloc_getISO3Country(localeID: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def uloc_getLCID(localeID: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@cfunctype('icuuc.dll')
def uloc_getDisplayLanguage(locale: win32more.Windows.Win32.Foundation.PSTR, displayLocale: win32more.Windows.Win32.Foundation.PSTR, language: POINTER(UInt16), languageCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_getDisplayScript(locale: win32more.Windows.Win32.Foundation.PSTR, displayLocale: win32more.Windows.Win32.Foundation.PSTR, script: POINTER(UInt16), scriptCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_getDisplayCountry(locale: win32more.Windows.Win32.Foundation.PSTR, displayLocale: win32more.Windows.Win32.Foundation.PSTR, country: POINTER(UInt16), countryCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_getDisplayVariant(locale: win32more.Windows.Win32.Foundation.PSTR, displayLocale: win32more.Windows.Win32.Foundation.PSTR, variant: POINTER(UInt16), variantCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_getDisplayKeyword(keyword: win32more.Windows.Win32.Foundation.PSTR, displayLocale: win32more.Windows.Win32.Foundation.PSTR, dest: POINTER(UInt16), destCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_getDisplayKeywordValue(locale: win32more.Windows.Win32.Foundation.PSTR, keyword: win32more.Windows.Win32.Foundation.PSTR, displayLocale: win32more.Windows.Win32.Foundation.PSTR, dest: POINTER(UInt16), destCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_getDisplayName(localeID: win32more.Windows.Win32.Foundation.PSTR, inLocaleID: win32more.Windows.Win32.Foundation.PSTR, result: POINTER(UInt16), maxResultSize: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_getAvailable(n: Int32) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def uloc_countAvailable() -> Int32: ...
@cfunctype('icu.dll')
def uloc_openAvailableByType(type: win32more.Windows.Win32.Globalization.ULocAvailableType, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuuc.dll')
def uloc_getISOLanguages() -> POINTER(POINTER(SByte)): ...
@cfunctype('icuuc.dll')
def uloc_getISOCountries() -> POINTER(POINTER(SByte)): ...
@cfunctype('icuuc.dll')
def uloc_getParent(localeID: win32more.Windows.Win32.Foundation.PSTR, parent: win32more.Windows.Win32.Foundation.PSTR, parentCapacity: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_getBaseName(localeID: win32more.Windows.Win32.Foundation.PSTR, name: win32more.Windows.Win32.Foundation.PSTR, nameCapacity: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_openKeywords(localeID: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuuc.dll')
def uloc_getKeywordValue(localeID: win32more.Windows.Win32.Foundation.PSTR, keywordName: win32more.Windows.Win32.Foundation.PSTR, buffer: win32more.Windows.Win32.Foundation.PSTR, bufferCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_setKeywordValue(keywordName: win32more.Windows.Win32.Foundation.PSTR, keywordValue: win32more.Windows.Win32.Foundation.PSTR, buffer: win32more.Windows.Win32.Foundation.PSTR, bufferCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_isRightToLeft(locale: win32more.Windows.Win32.Foundation.PSTR) -> SByte: ...
@cfunctype('icuuc.dll')
def uloc_getCharacterOrientation(localeId: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Globalization.ULayoutType: ...
@cfunctype('icuuc.dll')
def uloc_getLineOrientation(localeId: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Globalization.ULayoutType: ...
@cfunctype('icuuc.dll')
def uloc_acceptLanguageFromHTTP(result: win32more.Windows.Win32.Foundation.PSTR, resultAvailable: Int32, outResult: POINTER(win32more.Windows.Win32.Globalization.UAcceptResult), httpAcceptLanguage: win32more.Windows.Win32.Foundation.PSTR, availableLocales: POINTER(win32more.Windows.Win32.Globalization.UEnumeration), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_acceptLanguage(result: win32more.Windows.Win32.Foundation.PSTR, resultAvailable: Int32, outResult: POINTER(win32more.Windows.Win32.Globalization.UAcceptResult), acceptList: POINTER(POINTER(SByte)), acceptListCount: Int32, availableLocales: POINTER(win32more.Windows.Win32.Globalization.UEnumeration), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_getLocaleForLCID(hostID: UInt32, locale: win32more.Windows.Win32.Foundation.PSTR, localeCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_addLikelySubtags(localeID: win32more.Windows.Win32.Foundation.PSTR, maximizedLocaleID: win32more.Windows.Win32.Foundation.PSTR, maximizedLocaleIDCapacity: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_minimizeSubtags(localeID: win32more.Windows.Win32.Foundation.PSTR, minimizedLocaleID: win32more.Windows.Win32.Foundation.PSTR, minimizedLocaleIDCapacity: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_forLanguageTag(langtag: win32more.Windows.Win32.Foundation.PSTR, localeID: win32more.Windows.Win32.Foundation.PSTR, localeIDCapacity: Int32, parsedLength: POINTER(Int32), err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_toLanguageTag(localeID: win32more.Windows.Win32.Foundation.PSTR, langtag: win32more.Windows.Win32.Foundation.PSTR, langtagCapacity: Int32, strict: SByte, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uloc_toUnicodeLocaleKey(keyword: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def uloc_toUnicodeLocaleType(keyword: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def uloc_toLegacyKey(keyword: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def uloc_toLegacyType(keyword: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def ures_open(packageName: win32more.Windows.Win32.Foundation.PSTR, locale: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UResourceBundle): ...
@cfunctype('icuuc.dll')
def ures_openDirect(packageName: win32more.Windows.Win32.Foundation.PSTR, locale: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UResourceBundle): ...
@cfunctype('icuuc.dll')
def ures_openU(packageName: POINTER(UInt16), locale: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UResourceBundle): ...
@cfunctype('icuuc.dll')
def ures_close(resourceBundle: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle)) -> Void: ...
@cfunctype('icuuc.dll')
def ures_getVersion(resB: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), versionInfo: POINTER(Byte)) -> Void: ...
@cfunctype('icuuc.dll')
def ures_getLocaleByType(resourceBundle: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), type: win32more.Windows.Win32.Globalization.ULocDataLocaleType, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def ures_getString(resourceBundle: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), len: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def ures_getUTF8String(resB: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), dest: win32more.Windows.Win32.Foundation.PSTR, length: POINTER(Int32), forceCopy: SByte, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def ures_getBinary(resourceBundle: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), len: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(Byte): ...
@cfunctype('icuuc.dll')
def ures_getIntVector(resourceBundle: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), len: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(Int32): ...
@cfunctype('icuuc.dll')
def ures_getUInt(resourceBundle: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> UInt32: ...
@cfunctype('icuuc.dll')
def ures_getInt(resourceBundle: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ures_getSize(resourceBundle: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle)) -> Int32: ...
@cfunctype('icuuc.dll')
def ures_getType(resourceBundle: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle)) -> win32more.Windows.Win32.Globalization.UResType: ...
@cfunctype('icuuc.dll')
def ures_getKey(resourceBundle: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def ures_resetIterator(resourceBundle: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle)) -> Void: ...
@cfunctype('icuuc.dll')
def ures_hasNext(resourceBundle: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle)) -> SByte: ...
@cfunctype('icuuc.dll')
def ures_getNextResource(resourceBundle: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), fillIn: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UResourceBundle): ...
@cfunctype('icuuc.dll')
def ures_getNextString(resourceBundle: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), len: POINTER(Int32), key: POINTER(POINTER(SByte)), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def ures_getByIndex(resourceBundle: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), indexR: Int32, fillIn: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UResourceBundle): ...
@cfunctype('icuuc.dll')
def ures_getStringByIndex(resourceBundle: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), indexS: Int32, len: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def ures_getUTF8StringByIndex(resB: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), stringIndex: Int32, dest: win32more.Windows.Win32.Foundation.PSTR, pLength: POINTER(Int32), forceCopy: SByte, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def ures_getByKey(resourceBundle: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), key: win32more.Windows.Win32.Foundation.PSTR, fillIn: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UResourceBundle): ...
@cfunctype('icuuc.dll')
def ures_getStringByKey(resB: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), key: win32more.Windows.Win32.Foundation.PSTR, len: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def ures_getUTF8StringByKey(resB: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), key: win32more.Windows.Win32.Foundation.PSTR, dest: win32more.Windows.Win32.Foundation.PSTR, pLength: POINTER(Int32), forceCopy: SByte, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def ures_openAvailableLocales(packageName: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuuc.dll')
def uldn_open(locale: win32more.Windows.Win32.Foundation.PSTR, dialectHandling: win32more.Windows.Win32.Globalization.UDialectHandling, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.ULocaleDisplayNames): ...
@cfunctype('icuuc.dll')
def uldn_close(ldn: POINTER(win32more.Windows.Win32.Globalization.ULocaleDisplayNames)) -> Void: ...
@cfunctype('icuuc.dll')
def uldn_getLocale(ldn: POINTER(win32more.Windows.Win32.Globalization.ULocaleDisplayNames)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def uldn_getDialectHandling(ldn: POINTER(win32more.Windows.Win32.Globalization.ULocaleDisplayNames)) -> win32more.Windows.Win32.Globalization.UDialectHandling: ...
@cfunctype('icuuc.dll')
def uldn_localeDisplayName(ldn: POINTER(win32more.Windows.Win32.Globalization.ULocaleDisplayNames), locale: win32more.Windows.Win32.Foundation.PSTR, result: POINTER(UInt16), maxResultSize: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uldn_languageDisplayName(ldn: POINTER(win32more.Windows.Win32.Globalization.ULocaleDisplayNames), lang: win32more.Windows.Win32.Foundation.PSTR, result: POINTER(UInt16), maxResultSize: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uldn_scriptDisplayName(ldn: POINTER(win32more.Windows.Win32.Globalization.ULocaleDisplayNames), script: win32more.Windows.Win32.Foundation.PSTR, result: POINTER(UInt16), maxResultSize: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uldn_scriptCodeDisplayName(ldn: POINTER(win32more.Windows.Win32.Globalization.ULocaleDisplayNames), scriptCode: win32more.Windows.Win32.Globalization.UScriptCode, result: POINTER(UInt16), maxResultSize: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uldn_regionDisplayName(ldn: POINTER(win32more.Windows.Win32.Globalization.ULocaleDisplayNames), region: win32more.Windows.Win32.Foundation.PSTR, result: POINTER(UInt16), maxResultSize: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uldn_variantDisplayName(ldn: POINTER(win32more.Windows.Win32.Globalization.ULocaleDisplayNames), variant: win32more.Windows.Win32.Foundation.PSTR, result: POINTER(UInt16), maxResultSize: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uldn_keyDisplayName(ldn: POINTER(win32more.Windows.Win32.Globalization.ULocaleDisplayNames), key: win32more.Windows.Win32.Foundation.PSTR, result: POINTER(UInt16), maxResultSize: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uldn_keyValueDisplayName(ldn: POINTER(win32more.Windows.Win32.Globalization.ULocaleDisplayNames), key: win32more.Windows.Win32.Foundation.PSTR, value: win32more.Windows.Win32.Foundation.PSTR, result: POINTER(UInt16), maxResultSize: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uldn_openForContext(locale: win32more.Windows.Win32.Foundation.PSTR, contexts: POINTER(win32more.Windows.Win32.Globalization.UDisplayContext), length: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.ULocaleDisplayNames): ...
@cfunctype('icuuc.dll')
def uldn_getContext(ldn: POINTER(win32more.Windows.Win32.Globalization.ULocaleDisplayNames), type: win32more.Windows.Win32.Globalization.UDisplayContextType, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Globalization.UDisplayContext: ...
@cfunctype('icuuc.dll')
def ucurr_forLocale(locale: win32more.Windows.Win32.Foundation.PSTR, buff: POINTER(UInt16), buffCapacity: Int32, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucurr_register(isoCode: POINTER(UInt16), locale: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> VoidPtr: ...
@cfunctype('icuuc.dll')
def ucurr_unregister(key: VoidPtr, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuuc.dll')
def ucurr_getName(currency: POINTER(UInt16), locale: win32more.Windows.Win32.Foundation.PSTR, nameStyle: win32more.Windows.Win32.Globalization.UCurrNameStyle, isChoiceFormat: POINTER(SByte), len: POINTER(Int32), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def ucurr_getPluralName(currency: POINTER(UInt16), locale: win32more.Windows.Win32.Foundation.PSTR, isChoiceFormat: POINTER(SByte), pluralCount: win32more.Windows.Win32.Foundation.PSTR, len: POINTER(Int32), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def ucurr_getDefaultFractionDigits(currency: POINTER(UInt16), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucurr_getDefaultFractionDigitsForUsage(currency: POINTER(UInt16), usage: win32more.Windows.Win32.Globalization.UCurrencyUsage, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucurr_getRoundingIncrement(currency: POINTER(UInt16), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Double: ...
@cfunctype('icuuc.dll')
def ucurr_getRoundingIncrementForUsage(currency: POINTER(UInt16), usage: win32more.Windows.Win32.Globalization.UCurrencyUsage, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Double: ...
@cfunctype('icuuc.dll')
def ucurr_openISOCurrencies(currType: UInt32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuuc.dll')
def ucurr_isAvailable(isoCode: POINTER(UInt16), from_: Double, to: Double, errorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuuc.dll')
def ucurr_countCurrencies(locale: win32more.Windows.Win32.Foundation.PSTR, date: Double, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucurr_forLocaleAndDate(locale: win32more.Windows.Win32.Foundation.PSTR, date: Double, index: Int32, buff: POINTER(UInt16), buffCapacity: Int32, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucurr_getKeywordValuesForLocale(key: win32more.Windows.Win32.Foundation.PSTR, locale: win32more.Windows.Win32.Foundation.PSTR, commonlyUsed: SByte, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuuc.dll')
def ucurr_getNumericCode(currency: POINTER(UInt16)) -> Int32: ...
@cfunctype('icu.dll')
def ucpmap_get(map: POINTER(win32more.Windows.Win32.Globalization.UCPMap), c: Int32) -> UInt32: ...
@cfunctype('icu.dll')
def ucpmap_getRange(map: POINTER(win32more.Windows.Win32.Globalization.UCPMap), start: Int32, option: win32more.Windows.Win32.Globalization.UCPMapRangeOption, surrogateValue: UInt32, filter: POINTER(win32more.Windows.Win32.Globalization.UCPMapValueFilter), context: VoidPtr, pValue: POINTER(UInt32)) -> Int32: ...
@cfunctype('icu.dll')
def ucptrie_openFromBinary(type: win32more.Windows.Win32.Globalization.UCPTrieType, valueWidth: win32more.Windows.Win32.Globalization.UCPTrieValueWidth, data: VoidPtr, length: Int32, pActualLength: POINTER(Int32), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UCPTrie): ...
@cfunctype('icu.dll')
def ucptrie_close(trie: POINTER(win32more.Windows.Win32.Globalization.UCPTrie)) -> Void: ...
@cfunctype('icu.dll')
def ucptrie_getType(trie: POINTER(win32more.Windows.Win32.Globalization.UCPTrie)) -> win32more.Windows.Win32.Globalization.UCPTrieType: ...
@cfunctype('icu.dll')
def ucptrie_getValueWidth(trie: POINTER(win32more.Windows.Win32.Globalization.UCPTrie)) -> win32more.Windows.Win32.Globalization.UCPTrieValueWidth: ...
@cfunctype('icu.dll')
def ucptrie_get(trie: POINTER(win32more.Windows.Win32.Globalization.UCPTrie), c: Int32) -> UInt32: ...
@cfunctype('icu.dll')
def ucptrie_getRange(trie: POINTER(win32more.Windows.Win32.Globalization.UCPTrie), start: Int32, option: win32more.Windows.Win32.Globalization.UCPMapRangeOption, surrogateValue: UInt32, filter: POINTER(win32more.Windows.Win32.Globalization.UCPMapValueFilter), context: VoidPtr, pValue: POINTER(UInt32)) -> Int32: ...
@cfunctype('icu.dll')
def ucptrie_toBinary(trie: POINTER(win32more.Windows.Win32.Globalization.UCPTrie), data: VoidPtr, capacity: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icu.dll')
def ucptrie_internalSmallIndex(trie: POINTER(win32more.Windows.Win32.Globalization.UCPTrie), c: Int32) -> Int32: ...
@cfunctype('icu.dll')
def ucptrie_internalSmallU8Index(trie: POINTER(win32more.Windows.Win32.Globalization.UCPTrie), lt1: Int32, t2: Byte, t3: Byte) -> Int32: ...
@cfunctype('icu.dll')
def ucptrie_internalU8PrevIndex(trie: POINTER(win32more.Windows.Win32.Globalization.UCPTrie), c: Int32, start: POINTER(Byte), src: POINTER(Byte)) -> Int32: ...
@cfunctype('icu.dll')
def umutablecptrie_open(initialValue: UInt32, errorValue: UInt32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UMutableCPTrie): ...
@cfunctype('icu.dll')
def umutablecptrie_clone(other: POINTER(win32more.Windows.Win32.Globalization.UMutableCPTrie), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UMutableCPTrie): ...
@cfunctype('icu.dll')
def umutablecptrie_close(trie: POINTER(win32more.Windows.Win32.Globalization.UMutableCPTrie)) -> Void: ...
@cfunctype('icu.dll')
def umutablecptrie_fromUCPMap(map: POINTER(win32more.Windows.Win32.Globalization.UCPMap), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UMutableCPTrie): ...
@cfunctype('icu.dll')
def umutablecptrie_fromUCPTrie(trie: POINTER(win32more.Windows.Win32.Globalization.UCPTrie), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UMutableCPTrie): ...
@cfunctype('icu.dll')
def umutablecptrie_get(trie: POINTER(win32more.Windows.Win32.Globalization.UMutableCPTrie), c: Int32) -> UInt32: ...
@cfunctype('icu.dll')
def umutablecptrie_getRange(trie: POINTER(win32more.Windows.Win32.Globalization.UMutableCPTrie), start: Int32, option: win32more.Windows.Win32.Globalization.UCPMapRangeOption, surrogateValue: UInt32, filter: POINTER(win32more.Windows.Win32.Globalization.UCPMapValueFilter), context: VoidPtr, pValue: POINTER(UInt32)) -> Int32: ...
@cfunctype('icu.dll')
def umutablecptrie_set(trie: POINTER(win32more.Windows.Win32.Globalization.UMutableCPTrie), c: Int32, value: UInt32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icu.dll')
def umutablecptrie_setRange(trie: POINTER(win32more.Windows.Win32.Globalization.UMutableCPTrie), start: Int32, end: Int32, value: UInt32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icu.dll')
def umutablecptrie_buildImmutable(trie: POINTER(win32more.Windows.Win32.Globalization.UMutableCPTrie), type: win32more.Windows.Win32.Globalization.UCPTrieType, valueWidth: win32more.Windows.Win32.Globalization.UCPTrieValueWidth, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UCPTrie): ...
@cfunctype('icuuc.dll')
def UCNV_FROM_U_CALLBACK_STOP(context: VoidPtr, fromUArgs: POINTER(win32more.Windows.Win32.Globalization.UConverterFromUnicodeArgs), codeUnits: POINTER(UInt16), length: Int32, codePoint: Int32, reason: win32more.Windows.Win32.Globalization.UConverterCallbackReason, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def UCNV_TO_U_CALLBACK_STOP(context: VoidPtr, toUArgs: POINTER(win32more.Windows.Win32.Globalization.UConverterToUnicodeArgs), codeUnits: win32more.Windows.Win32.Foundation.PSTR, length: Int32, reason: win32more.Windows.Win32.Globalization.UConverterCallbackReason, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def UCNV_FROM_U_CALLBACK_SKIP(context: VoidPtr, fromUArgs: POINTER(win32more.Windows.Win32.Globalization.UConverterFromUnicodeArgs), codeUnits: POINTER(UInt16), length: Int32, codePoint: Int32, reason: win32more.Windows.Win32.Globalization.UConverterCallbackReason, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def UCNV_FROM_U_CALLBACK_SUBSTITUTE(context: VoidPtr, fromUArgs: POINTER(win32more.Windows.Win32.Globalization.UConverterFromUnicodeArgs), codeUnits: POINTER(UInt16), length: Int32, codePoint: Int32, reason: win32more.Windows.Win32.Globalization.UConverterCallbackReason, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def UCNV_FROM_U_CALLBACK_ESCAPE(context: VoidPtr, fromUArgs: POINTER(win32more.Windows.Win32.Globalization.UConverterFromUnicodeArgs), codeUnits: POINTER(UInt16), length: Int32, codePoint: Int32, reason: win32more.Windows.Win32.Globalization.UConverterCallbackReason, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def UCNV_TO_U_CALLBACK_SKIP(context: VoidPtr, toUArgs: POINTER(win32more.Windows.Win32.Globalization.UConverterToUnicodeArgs), codeUnits: win32more.Windows.Win32.Foundation.PSTR, length: Int32, reason: win32more.Windows.Win32.Globalization.UConverterCallbackReason, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def UCNV_TO_U_CALLBACK_SUBSTITUTE(context: VoidPtr, toUArgs: POINTER(win32more.Windows.Win32.Globalization.UConverterToUnicodeArgs), codeUnits: win32more.Windows.Win32.Foundation.PSTR, length: Int32, reason: win32more.Windows.Win32.Globalization.UConverterCallbackReason, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def UCNV_TO_U_CALLBACK_ESCAPE(context: VoidPtr, toUArgs: POINTER(win32more.Windows.Win32.Globalization.UConverterToUnicodeArgs), codeUnits: win32more.Windows.Win32.Foundation.PSTR, length: Int32, reason: win32more.Windows.Win32.Globalization.UConverterCallbackReason, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_compareNames(name1: win32more.Windows.Win32.Foundation.PSTR, name2: win32more.Windows.Win32.Foundation.PSTR) -> Int32: ...
@cfunctype('icuuc.dll')
def ucnv_open(converterName: win32more.Windows.Win32.Foundation.PSTR, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UConverter): ...
@cfunctype('icuuc.dll')
def ucnv_openU(name: POINTER(UInt16), err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UConverter): ...
@cfunctype('icuuc.dll')
def ucnv_openCCSID(codepage: Int32, platform: win32more.Windows.Win32.Globalization.UConverterPlatform, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UConverter): ...
@cfunctype('icuuc.dll')
def ucnv_openPackage(packageName: win32more.Windows.Win32.Foundation.PSTR, converterName: win32more.Windows.Win32.Foundation.PSTR, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UConverter): ...
@cfunctype('icuuc.dll')
def ucnv_safeClone(cnv: POINTER(win32more.Windows.Win32.Globalization.UConverter), stackBuffer: VoidPtr, pBufferSize: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UConverter): ...
@cfunctype('icuuc.dll')
def ucnv_close(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_getSubstChars(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter), subChars: win32more.Windows.Win32.Foundation.PSTR, len: POINTER(SByte), err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_setSubstChars(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter), subChars: win32more.Windows.Win32.Foundation.PSTR, len: SByte, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_setSubstString(cnv: POINTER(win32more.Windows.Win32.Globalization.UConverter), s: POINTER(UInt16), length: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_getInvalidChars(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter), errBytes: win32more.Windows.Win32.Foundation.PSTR, len: POINTER(SByte), err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_getInvalidUChars(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter), errUChars: POINTER(UInt16), len: POINTER(SByte), err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_reset(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_resetToUnicode(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_resetFromUnicode(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_getMaxCharSize(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter)) -> SByte: ...
@cfunctype('icuuc.dll')
def ucnv_getMinCharSize(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter)) -> SByte: ...
@cfunctype('icuuc.dll')
def ucnv_getDisplayName(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter), displayLocale: win32more.Windows.Win32.Foundation.PSTR, displayName: POINTER(UInt16), displayNameCapacity: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucnv_getName(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter), err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def ucnv_getCCSID(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter), err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucnv_getPlatform(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter), err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Globalization.UConverterPlatform: ...
@cfunctype('icuuc.dll')
def ucnv_getType(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter)) -> win32more.Windows.Win32.Globalization.UConverterType: ...
@cfunctype('icuuc.dll')
def ucnv_getStarters(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter), starters: POINTER(SByte), err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_getUnicodeSet(cnv: POINTER(win32more.Windows.Win32.Globalization.UConverter), setFillIn: POINTER(win32more.Windows.Win32.Globalization.USet), whichSet: win32more.Windows.Win32.Globalization.UConverterUnicodeSet, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_getToUCallBack(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter), action: POINTER(win32more.Windows.Win32.Globalization.UConverterToUCallback), context: POINTER(VoidPtr)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_getFromUCallBack(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter), action: POINTER(win32more.Windows.Win32.Globalization.UConverterFromUCallback), context: POINTER(VoidPtr)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_setToUCallBack(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter), newAction: win32more.Windows.Win32.Globalization.UConverterToUCallback, newContext: VoidPtr, oldAction: POINTER(win32more.Windows.Win32.Globalization.UConverterToUCallback), oldContext: POINTER(VoidPtr), err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_setFromUCallBack(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter), newAction: win32more.Windows.Win32.Globalization.UConverterFromUCallback, newContext: VoidPtr, oldAction: POINTER(win32more.Windows.Win32.Globalization.UConverterFromUCallback), oldContext: POINTER(VoidPtr), err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_fromUnicode(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter), target: POINTER(POINTER(SByte)), targetLimit: win32more.Windows.Win32.Foundation.PSTR, source: POINTER(POINTER(UInt16)), sourceLimit: POINTER(UInt16), offsets: POINTER(Int32), flush: SByte, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_toUnicode(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter), target: POINTER(POINTER(UInt16)), targetLimit: POINTER(UInt16), source: POINTER(POINTER(SByte)), sourceLimit: win32more.Windows.Win32.Foundation.PSTR, offsets: POINTER(Int32), flush: SByte, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_fromUChars(cnv: POINTER(win32more.Windows.Win32.Globalization.UConverter), dest: win32more.Windows.Win32.Foundation.PSTR, destCapacity: Int32, src: POINTER(UInt16), srcLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucnv_toUChars(cnv: POINTER(win32more.Windows.Win32.Globalization.UConverter), dest: POINTER(UInt16), destCapacity: Int32, src: win32more.Windows.Win32.Foundation.PSTR, srcLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucnv_getNextUChar(converter: POINTER(win32more.Windows.Win32.Globalization.UConverter), source: POINTER(POINTER(SByte)), sourceLimit: win32more.Windows.Win32.Foundation.PSTR, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucnv_convertEx(targetCnv: POINTER(win32more.Windows.Win32.Globalization.UConverter), sourceCnv: POINTER(win32more.Windows.Win32.Globalization.UConverter), target: POINTER(POINTER(SByte)), targetLimit: win32more.Windows.Win32.Foundation.PSTR, source: POINTER(POINTER(SByte)), sourceLimit: win32more.Windows.Win32.Foundation.PSTR, pivotStart: POINTER(UInt16), pivotSource: POINTER(POINTER(UInt16)), pivotTarget: POINTER(POINTER(UInt16)), pivotLimit: POINTER(UInt16), reset: SByte, flush: SByte, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_convert(toConverterName: win32more.Windows.Win32.Foundation.PSTR, fromConverterName: win32more.Windows.Win32.Foundation.PSTR, target: win32more.Windows.Win32.Foundation.PSTR, targetCapacity: Int32, source: win32more.Windows.Win32.Foundation.PSTR, sourceLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucnv_toAlgorithmic(algorithmicType: win32more.Windows.Win32.Globalization.UConverterType, cnv: POINTER(win32more.Windows.Win32.Globalization.UConverter), target: win32more.Windows.Win32.Foundation.PSTR, targetCapacity: Int32, source: win32more.Windows.Win32.Foundation.PSTR, sourceLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucnv_fromAlgorithmic(cnv: POINTER(win32more.Windows.Win32.Globalization.UConverter), algorithmicType: win32more.Windows.Win32.Globalization.UConverterType, target: win32more.Windows.Win32.Foundation.PSTR, targetCapacity: Int32, source: win32more.Windows.Win32.Foundation.PSTR, sourceLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucnv_flushCache() -> Int32: ...
@cfunctype('icuuc.dll')
def ucnv_countAvailable() -> Int32: ...
@cfunctype('icuuc.dll')
def ucnv_getAvailableName(n: Int32) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def ucnv_openAllNames(pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuuc.dll')
def ucnv_countAliases(alias: win32more.Windows.Win32.Foundation.PSTR, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> UInt16: ...
@cfunctype('icuuc.dll')
def ucnv_getAlias(alias: win32more.Windows.Win32.Foundation.PSTR, n: UInt16, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def ucnv_getAliases(alias: win32more.Windows.Win32.Foundation.PSTR, aliases: POINTER(POINTER(SByte)), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_openStandardNames(convName: win32more.Windows.Win32.Foundation.PSTR, standard: win32more.Windows.Win32.Foundation.PSTR, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuuc.dll')
def ucnv_countStandards() -> UInt16: ...
@cfunctype('icuuc.dll')
def ucnv_getStandard(n: UInt16, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def ucnv_getStandardName(name: win32more.Windows.Win32.Foundation.PSTR, standard: win32more.Windows.Win32.Foundation.PSTR, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def ucnv_getCanonicalName(alias: win32more.Windows.Win32.Foundation.PSTR, standard: win32more.Windows.Win32.Foundation.PSTR, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def ucnv_getDefaultName() -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def ucnv_setDefaultName(name: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_fixFileSeparator(cnv: POINTER(win32more.Windows.Win32.Globalization.UConverter), source: POINTER(UInt16), sourceLen: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_isAmbiguous(cnv: POINTER(win32more.Windows.Win32.Globalization.UConverter)) -> SByte: ...
@cfunctype('icuuc.dll')
def ucnv_setFallback(cnv: POINTER(win32more.Windows.Win32.Globalization.UConverter), usesFallback: SByte) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_usesFallback(cnv: POINTER(win32more.Windows.Win32.Globalization.UConverter)) -> SByte: ...
@cfunctype('icuuc.dll')
def ucnv_detectUnicodeSignature(source: win32more.Windows.Win32.Foundation.PSTR, sourceLength: Int32, signatureLength: POINTER(Int32), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def ucnv_fromUCountPending(cnv: POINTER(win32more.Windows.Win32.Globalization.UConverter), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucnv_toUCountPending(cnv: POINTER(win32more.Windows.Win32.Globalization.UConverter), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucnv_isFixedWidth(cnv: POINTER(win32more.Windows.Win32.Globalization.UConverter), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuuc.dll')
def ucnv_cbFromUWriteBytes(args: POINTER(win32more.Windows.Win32.Globalization.UConverterFromUnicodeArgs), source: win32more.Windows.Win32.Foundation.PSTR, length: Int32, offsetIndex: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_cbFromUWriteSub(args: POINTER(win32more.Windows.Win32.Globalization.UConverterFromUnicodeArgs), offsetIndex: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_cbFromUWriteUChars(args: POINTER(win32more.Windows.Win32.Globalization.UConverterFromUnicodeArgs), source: POINTER(POINTER(UInt16)), sourceLimit: POINTER(UInt16), offsetIndex: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_cbToUWriteUChars(args: POINTER(win32more.Windows.Win32.Globalization.UConverterToUnicodeArgs), source: POINTER(UInt16), length: Int32, offsetIndex: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnv_cbToUWriteSub(args: POINTER(win32more.Windows.Win32.Globalization.UConverterToUnicodeArgs), offsetIndex: Int32, err: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def u_init(status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def u_cleanup() -> Void: ...
@cfunctype('icuuc.dll')
def u_setMemoryFunctions(context: VoidPtr, a: POINTER(win32more.Windows.Win32.Globalization.UMemAllocFn), r: POINTER(win32more.Windows.Win32.Globalization.UMemReallocFn), f: POINTER(win32more.Windows.Win32.Globalization.UMemFreeFn), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def u_catopen(name: win32more.Windows.Win32.Foundation.PSTR, locale: win32more.Windows.Win32.Foundation.PSTR, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UResourceBundle): ...
@cfunctype('icuuc.dll')
def u_catclose(catd: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle)) -> Void: ...
@cfunctype('icuuc.dll')
def u_catgets(catd: POINTER(win32more.Windows.Win32.Globalization.UResourceBundle), set_num: Int32, msg_num: Int32, s: POINTER(UInt16), len: POINTER(Int32), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_hasBinaryProperty(c: Int32, which: win32more.Windows.Win32.Globalization.UProperty) -> SByte: ...
@cfunctype('icu.dll')
def u_getBinaryPropertySet(property: win32more.Windows.Win32.Globalization.UProperty, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.USet): ...
@cfunctype('icuuc.dll')
def u_isUAlphabetic(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isULowercase(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isUUppercase(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isUWhiteSpace(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_getIntPropertyValue(c: Int32, which: win32more.Windows.Win32.Globalization.UProperty) -> Int32: ...
@cfunctype('icuuc.dll')
def u_getIntPropertyMinValue(which: win32more.Windows.Win32.Globalization.UProperty) -> Int32: ...
@cfunctype('icuuc.dll')
def u_getIntPropertyMaxValue(which: win32more.Windows.Win32.Globalization.UProperty) -> Int32: ...
@cfunctype('icu.dll')
def u_getIntPropertyMap(property: win32more.Windows.Win32.Globalization.UProperty, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UCPMap): ...
@cfunctype('icuuc.dll')
def u_getNumericValue(c: Int32) -> Double: ...
@cfunctype('icuuc.dll')
def u_islower(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isupper(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_istitle(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isdigit(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isalpha(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isalnum(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isxdigit(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_ispunct(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isgraph(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isblank(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isdefined(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isspace(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isJavaSpaceChar(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isWhitespace(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_iscntrl(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isISOControl(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isprint(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isbase(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_charDirection(c: Int32) -> win32more.Windows.Win32.Globalization.UCharDirection: ...
@cfunctype('icuuc.dll')
def u_isMirrored(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_charMirror(c: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def u_getBidiPairedBracket(c: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def u_charType(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_enumCharTypes(enumRange: POINTER(win32more.Windows.Win32.Globalization.UCharEnumTypeRange), context: VoidPtr) -> Void: ...
@cfunctype('icuuc.dll')
def u_getCombiningClass(c: Int32) -> Byte: ...
@cfunctype('icuuc.dll')
def u_charDigitValue(c: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def ublock_getCode(c: Int32) -> win32more.Windows.Win32.Globalization.UBlockCode: ...
@cfunctype('icuuc.dll')
def u_charName(code: Int32, nameChoice: win32more.Windows.Win32.Globalization.UCharNameChoice, buffer: win32more.Windows.Win32.Foundation.PSTR, bufferLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def u_charFromName(nameChoice: win32more.Windows.Win32.Globalization.UCharNameChoice, name: win32more.Windows.Win32.Foundation.PSTR, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def u_enumCharNames(start: Int32, limit: Int32, fn: POINTER(win32more.Windows.Win32.Globalization.UEnumCharNamesFn), context: VoidPtr, nameChoice: win32more.Windows.Win32.Globalization.UCharNameChoice, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def u_getPropertyName(property: win32more.Windows.Win32.Globalization.UProperty, nameChoice: win32more.Windows.Win32.Globalization.UPropertyNameChoice) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def u_getPropertyEnum(alias: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Globalization.UProperty: ...
@cfunctype('icuuc.dll')
def u_getPropertyValueName(property: win32more.Windows.Win32.Globalization.UProperty, value: Int32, nameChoice: win32more.Windows.Win32.Globalization.UPropertyNameChoice) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def u_getPropertyValueEnum(property: win32more.Windows.Win32.Globalization.UProperty, alias: win32more.Windows.Win32.Foundation.PSTR) -> Int32: ...
@cfunctype('icuuc.dll')
def u_isIDStart(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isIDPart(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isIDIgnorable(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isJavaIDStart(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_isJavaIDPart(c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_tolower(c: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def u_toupper(c: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def u_totitle(c: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def u_foldCase(c: Int32, options: UInt32) -> Int32: ...
@cfunctype('icuuc.dll')
def u_digit(ch: Int32, radix: SByte) -> Int32: ...
@cfunctype('icuuc.dll')
def u_forDigit(digit: Int32, radix: SByte) -> Int32: ...
@cfunctype('icuuc.dll')
def u_charAge(c: Int32, versionArray: POINTER(Byte)) -> Void: ...
@cfunctype('icuuc.dll')
def u_getUnicodeVersion(versionArray: POINTER(Byte)) -> Void: ...
@cfunctype('icuuc.dll')
def u_getFC_NFKC_Closure(c: Int32, dest: POINTER(UInt16), destCapacity: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubidi_open() -> POINTER(win32more.Windows.Win32.Globalization.UBiDi): ...
@cfunctype('icuuc.dll')
def ubidi_openSized(maxLength: Int32, maxRunCount: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UBiDi): ...
@cfunctype('icuuc.dll')
def ubidi_close(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi)) -> Void: ...
@cfunctype('icuuc.dll')
def ubidi_setInverse(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), isInverse: SByte) -> Void: ...
@cfunctype('icuuc.dll')
def ubidi_isInverse(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi)) -> SByte: ...
@cfunctype('icuuc.dll')
def ubidi_orderParagraphsLTR(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), orderParagraphsLTR: SByte) -> Void: ...
@cfunctype('icuuc.dll')
def ubidi_isOrderParagraphsLTR(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi)) -> SByte: ...
@cfunctype('icuuc.dll')
def ubidi_setReorderingMode(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), reorderingMode: win32more.Windows.Win32.Globalization.UBiDiReorderingMode) -> Void: ...
@cfunctype('icuuc.dll')
def ubidi_getReorderingMode(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi)) -> win32more.Windows.Win32.Globalization.UBiDiReorderingMode: ...
@cfunctype('icuuc.dll')
def ubidi_setReorderingOptions(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), reorderingOptions: UInt32) -> Void: ...
@cfunctype('icuuc.dll')
def ubidi_getReorderingOptions(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi)) -> UInt32: ...
@cfunctype('icuuc.dll')
def ubidi_setContext(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), prologue: POINTER(UInt16), proLength: Int32, epilogue: POINTER(UInt16), epiLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ubidi_setPara(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), text: POINTER(UInt16), length: Int32, paraLevel: Byte, embeddingLevels: POINTER(Byte), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ubidi_setLine(pParaBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), start: Int32, limit: Int32, pLineBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ubidi_getDirection(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi)) -> win32more.Windows.Win32.Globalization.UBiDiDirection: ...
@cfunctype('icuuc.dll')
def ubidi_getBaseDirection(text: POINTER(UInt16), length: Int32) -> win32more.Windows.Win32.Globalization.UBiDiDirection: ...
@cfunctype('icuuc.dll')
def ubidi_getText(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def ubidi_getLength(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubidi_getParaLevel(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi)) -> Byte: ...
@cfunctype('icuuc.dll')
def ubidi_countParagraphs(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubidi_getParagraph(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), charIndex: Int32, pParaStart: POINTER(Int32), pParaLimit: POINTER(Int32), pParaLevel: POINTER(Byte), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubidi_getParagraphByIndex(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), paraIndex: Int32, pParaStart: POINTER(Int32), pParaLimit: POINTER(Int32), pParaLevel: POINTER(Byte), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ubidi_getLevelAt(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), charIndex: Int32) -> Byte: ...
@cfunctype('icuuc.dll')
def ubidi_getLevels(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(Byte): ...
@cfunctype('icuuc.dll')
def ubidi_getLogicalRun(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), logicalPosition: Int32, pLogicalLimit: POINTER(Int32), pLevel: POINTER(Byte)) -> Void: ...
@cfunctype('icuuc.dll')
def ubidi_countRuns(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubidi_getVisualRun(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), runIndex: Int32, pLogicalStart: POINTER(Int32), pLength: POINTER(Int32)) -> win32more.Windows.Win32.Globalization.UBiDiDirection: ...
@cfunctype('icuuc.dll')
def ubidi_getVisualIndex(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), logicalIndex: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubidi_getLogicalIndex(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), visualIndex: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubidi_getLogicalMap(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), indexMap: POINTER(Int32), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ubidi_getVisualMap(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), indexMap: POINTER(Int32), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ubidi_reorderLogical(levels: POINTER(Byte), length: Int32, indexMap: POINTER(Int32)) -> Void: ...
@cfunctype('icuuc.dll')
def ubidi_reorderVisual(levels: POINTER(Byte), length: Int32, indexMap: POINTER(Int32)) -> Void: ...
@cfunctype('icuuc.dll')
def ubidi_invertMap(srcMap: POINTER(Int32), destMap: POINTER(Int32), length: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def ubidi_getProcessedLength(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubidi_getResultLength(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubidi_getCustomizedClass(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), c: Int32) -> win32more.Windows.Win32.Globalization.UCharDirection: ...
@cfunctype('icuuc.dll')
def ubidi_setClassCallback(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), newFn: win32more.Windows.Win32.Globalization.UBiDiClassCallback, newContext: VoidPtr, oldFn: POINTER(win32more.Windows.Win32.Globalization.UBiDiClassCallback), oldContext: POINTER(VoidPtr), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ubidi_getClassCallback(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), fn: POINTER(win32more.Windows.Win32.Globalization.UBiDiClassCallback), context: POINTER(VoidPtr)) -> Void: ...
@cfunctype('icuuc.dll')
def ubidi_writeReordered(pBiDi: POINTER(win32more.Windows.Win32.Globalization.UBiDi), dest: POINTER(UInt16), destSize: Int32, options: UInt16, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubidi_writeReverse(src: POINTER(UInt16), srcLength: Int32, dest: POINTER(UInt16), destSize: Int32, options: UInt16, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubiditransform_transform(pBiDiTransform: POINTER(win32more.Windows.Win32.Globalization.UBiDiTransform), src: POINTER(UInt16), srcLength: Int32, dest: POINTER(UInt16), destSize: Int32, inParaLevel: Byte, inOrder: win32more.Windows.Win32.Globalization.UBiDiOrder, outParaLevel: Byte, outOrder: win32more.Windows.Win32.Globalization.UBiDiOrder, doMirroring: win32more.Windows.Win32.Globalization.UBiDiMirroring, shapingOptions: UInt32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> UInt32: ...
@cfunctype('icuuc.dll')
def ubiditransform_open(pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UBiDiTransform): ...
@cfunctype('icuuc.dll')
def ubiditransform_close(pBidiTransform: POINTER(win32more.Windows.Win32.Globalization.UBiDiTransform)) -> Void: ...
@cfunctype('icuuc.dll')
def utext_close(ut: POINTER(win32more.Windows.Win32.Globalization.UText)) -> POINTER(win32more.Windows.Win32.Globalization.UText): ...
@cfunctype('icuuc.dll')
def utext_openUTF8(ut: POINTER(win32more.Windows.Win32.Globalization.UText), s: win32more.Windows.Win32.Foundation.PSTR, length: Int64, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UText): ...
@cfunctype('icuuc.dll')
def utext_openUChars(ut: POINTER(win32more.Windows.Win32.Globalization.UText), s: POINTER(UInt16), length: Int64, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UText): ...
@cfunctype('icuuc.dll')
def utext_clone(dest: POINTER(win32more.Windows.Win32.Globalization.UText), src: POINTER(win32more.Windows.Win32.Globalization.UText), deep: SByte, readOnly: SByte, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UText): ...
@cfunctype('icuuc.dll')
def utext_equals(a: POINTER(win32more.Windows.Win32.Globalization.UText), b: POINTER(win32more.Windows.Win32.Globalization.UText)) -> SByte: ...
@cfunctype('icuuc.dll')
def utext_nativeLength(ut: POINTER(win32more.Windows.Win32.Globalization.UText)) -> Int64: ...
@cfunctype('icuuc.dll')
def utext_isLengthExpensive(ut: POINTER(win32more.Windows.Win32.Globalization.UText)) -> SByte: ...
@cfunctype('icuuc.dll')
def utext_char32At(ut: POINTER(win32more.Windows.Win32.Globalization.UText), nativeIndex: Int64) -> Int32: ...
@cfunctype('icuuc.dll')
def utext_current32(ut: POINTER(win32more.Windows.Win32.Globalization.UText)) -> Int32: ...
@cfunctype('icuuc.dll')
def utext_next32(ut: POINTER(win32more.Windows.Win32.Globalization.UText)) -> Int32: ...
@cfunctype('icuuc.dll')
def utext_previous32(ut: POINTER(win32more.Windows.Win32.Globalization.UText)) -> Int32: ...
@cfunctype('icuuc.dll')
def utext_next32From(ut: POINTER(win32more.Windows.Win32.Globalization.UText), nativeIndex: Int64) -> Int32: ...
@cfunctype('icuuc.dll')
def utext_previous32From(ut: POINTER(win32more.Windows.Win32.Globalization.UText), nativeIndex: Int64) -> Int32: ...
@cfunctype('icuuc.dll')
def utext_getNativeIndex(ut: POINTER(win32more.Windows.Win32.Globalization.UText)) -> Int64: ...
@cfunctype('icuuc.dll')
def utext_setNativeIndex(ut: POINTER(win32more.Windows.Win32.Globalization.UText), nativeIndex: Int64) -> Void: ...
@cfunctype('icuuc.dll')
def utext_moveIndex32(ut: POINTER(win32more.Windows.Win32.Globalization.UText), delta: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def utext_getPreviousNativeIndex(ut: POINTER(win32more.Windows.Win32.Globalization.UText)) -> Int64: ...
@cfunctype('icuuc.dll')
def utext_extract(ut: POINTER(win32more.Windows.Win32.Globalization.UText), nativeStart: Int64, nativeLimit: Int64, dest: POINTER(UInt16), destCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def utext_isWritable(ut: POINTER(win32more.Windows.Win32.Globalization.UText)) -> SByte: ...
@cfunctype('icuuc.dll')
def utext_hasMetaData(ut: POINTER(win32more.Windows.Win32.Globalization.UText)) -> SByte: ...
@cfunctype('icuuc.dll')
def utext_replace(ut: POINTER(win32more.Windows.Win32.Globalization.UText), nativeStart: Int64, nativeLimit: Int64, replacementText: POINTER(UInt16), replacementLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def utext_copy(ut: POINTER(win32more.Windows.Win32.Globalization.UText), nativeStart: Int64, nativeLimit: Int64, destIndex: Int64, move: SByte, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def utext_freeze(ut: POINTER(win32more.Windows.Win32.Globalization.UText)) -> Void: ...
@cfunctype('icuuc.dll')
def utext_setup(ut: POINTER(win32more.Windows.Win32.Globalization.UText), extraSpace: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UText): ...
@cfunctype('icuuc.dll')
def uset_openEmpty() -> POINTER(win32more.Windows.Win32.Globalization.USet): ...
@cfunctype('icuuc.dll')
def uset_open(start: Int32, end: Int32) -> POINTER(win32more.Windows.Win32.Globalization.USet): ...
@cfunctype('icuuc.dll')
def uset_openPattern(pattern: POINTER(UInt16), patternLength: Int32, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.USet): ...
@cfunctype('icuuc.dll')
def uset_openPatternOptions(pattern: POINTER(UInt16), patternLength: Int32, options: UInt32, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.USet): ...
@cfunctype('icuuc.dll')
def uset_close(set: POINTER(win32more.Windows.Win32.Globalization.USet)) -> Void: ...
@cfunctype('icuuc.dll')
def uset_clone(set: POINTER(win32more.Windows.Win32.Globalization.USet)) -> POINTER(win32more.Windows.Win32.Globalization.USet): ...
@cfunctype('icuuc.dll')
def uset_isFrozen(set: POINTER(win32more.Windows.Win32.Globalization.USet)) -> SByte: ...
@cfunctype('icuuc.dll')
def uset_freeze(set: POINTER(win32more.Windows.Win32.Globalization.USet)) -> Void: ...
@cfunctype('icuuc.dll')
def uset_cloneAsThawed(set: POINTER(win32more.Windows.Win32.Globalization.USet)) -> POINTER(win32more.Windows.Win32.Globalization.USet): ...
@cfunctype('icuuc.dll')
def uset_set(set: POINTER(win32more.Windows.Win32.Globalization.USet), start: Int32, end: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def uset_applyPattern(set: POINTER(win32more.Windows.Win32.Globalization.USet), pattern: POINTER(UInt16), patternLength: Int32, options: UInt32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uset_applyIntPropertyValue(set: POINTER(win32more.Windows.Win32.Globalization.USet), prop: win32more.Windows.Win32.Globalization.UProperty, value: Int32, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def uset_applyPropertyAlias(set: POINTER(win32more.Windows.Win32.Globalization.USet), prop: POINTER(UInt16), propLength: Int32, value: POINTER(UInt16), valueLength: Int32, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def uset_resemblesPattern(pattern: POINTER(UInt16), patternLength: Int32, pos: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def uset_toPattern(set: POINTER(win32more.Windows.Win32.Globalization.USet), result: POINTER(UInt16), resultCapacity: Int32, escapeUnprintable: SByte, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uset_add(set: POINTER(win32more.Windows.Win32.Globalization.USet), c: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def uset_addAll(set: POINTER(win32more.Windows.Win32.Globalization.USet), additionalSet: POINTER(win32more.Windows.Win32.Globalization.USet)) -> Void: ...
@cfunctype('icuuc.dll')
def uset_addRange(set: POINTER(win32more.Windows.Win32.Globalization.USet), start: Int32, end: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def uset_addString(set: POINTER(win32more.Windows.Win32.Globalization.USet), str: POINTER(UInt16), strLen: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def uset_addAllCodePoints(set: POINTER(win32more.Windows.Win32.Globalization.USet), str: POINTER(UInt16), strLen: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def uset_remove(set: POINTER(win32more.Windows.Win32.Globalization.USet), c: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def uset_removeRange(set: POINTER(win32more.Windows.Win32.Globalization.USet), start: Int32, end: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def uset_removeString(set: POINTER(win32more.Windows.Win32.Globalization.USet), str: POINTER(UInt16), strLen: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def uset_removeAll(set: POINTER(win32more.Windows.Win32.Globalization.USet), removeSet: POINTER(win32more.Windows.Win32.Globalization.USet)) -> Void: ...
@cfunctype('icuuc.dll')
def uset_retain(set: POINTER(win32more.Windows.Win32.Globalization.USet), start: Int32, end: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def uset_retainAll(set: POINTER(win32more.Windows.Win32.Globalization.USet), retain: POINTER(win32more.Windows.Win32.Globalization.USet)) -> Void: ...
@cfunctype('icuuc.dll')
def uset_compact(set: POINTER(win32more.Windows.Win32.Globalization.USet)) -> Void: ...
@cfunctype('icuuc.dll')
def uset_complement(set: POINTER(win32more.Windows.Win32.Globalization.USet)) -> Void: ...
@cfunctype('icuuc.dll')
def uset_complementAll(set: POINTER(win32more.Windows.Win32.Globalization.USet), complement: POINTER(win32more.Windows.Win32.Globalization.USet)) -> Void: ...
@cfunctype('icuuc.dll')
def uset_clear(set: POINTER(win32more.Windows.Win32.Globalization.USet)) -> Void: ...
@cfunctype('icuuc.dll')
def uset_closeOver(set: POINTER(win32more.Windows.Win32.Globalization.USet), attributes: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def uset_removeAllStrings(set: POINTER(win32more.Windows.Win32.Globalization.USet)) -> Void: ...
@cfunctype('icuuc.dll')
def uset_isEmpty(set: POINTER(win32more.Windows.Win32.Globalization.USet)) -> SByte: ...
@cfunctype('icuuc.dll')
def uset_contains(set: POINTER(win32more.Windows.Win32.Globalization.USet), c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def uset_containsRange(set: POINTER(win32more.Windows.Win32.Globalization.USet), start: Int32, end: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def uset_containsString(set: POINTER(win32more.Windows.Win32.Globalization.USet), str: POINTER(UInt16), strLen: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def uset_indexOf(set: POINTER(win32more.Windows.Win32.Globalization.USet), c: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def uset_charAt(set: POINTER(win32more.Windows.Win32.Globalization.USet), charIndex: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def uset_size(set: POINTER(win32more.Windows.Win32.Globalization.USet)) -> Int32: ...
@cfunctype('icuuc.dll')
def uset_getItemCount(set: POINTER(win32more.Windows.Win32.Globalization.USet)) -> Int32: ...
@cfunctype('icuuc.dll')
def uset_getItem(set: POINTER(win32more.Windows.Win32.Globalization.USet), itemIndex: Int32, start: POINTER(Int32), end: POINTER(Int32), str: POINTER(UInt16), strCapacity: Int32, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uset_containsAll(set1: POINTER(win32more.Windows.Win32.Globalization.USet), set2: POINTER(win32more.Windows.Win32.Globalization.USet)) -> SByte: ...
@cfunctype('icuuc.dll')
def uset_containsAllCodePoints(set: POINTER(win32more.Windows.Win32.Globalization.USet), str: POINTER(UInt16), strLen: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def uset_containsNone(set1: POINTER(win32more.Windows.Win32.Globalization.USet), set2: POINTER(win32more.Windows.Win32.Globalization.USet)) -> SByte: ...
@cfunctype('icuuc.dll')
def uset_containsSome(set1: POINTER(win32more.Windows.Win32.Globalization.USet), set2: POINTER(win32more.Windows.Win32.Globalization.USet)) -> SByte: ...
@cfunctype('icuuc.dll')
def uset_span(set: POINTER(win32more.Windows.Win32.Globalization.USet), s: POINTER(UInt16), length: Int32, spanCondition: win32more.Windows.Win32.Globalization.USetSpanCondition) -> Int32: ...
@cfunctype('icuuc.dll')
def uset_spanBack(set: POINTER(win32more.Windows.Win32.Globalization.USet), s: POINTER(UInt16), length: Int32, spanCondition: win32more.Windows.Win32.Globalization.USetSpanCondition) -> Int32: ...
@cfunctype('icuuc.dll')
def uset_spanUTF8(set: POINTER(win32more.Windows.Win32.Globalization.USet), s: win32more.Windows.Win32.Foundation.PSTR, length: Int32, spanCondition: win32more.Windows.Win32.Globalization.USetSpanCondition) -> Int32: ...
@cfunctype('icuuc.dll')
def uset_spanBackUTF8(set: POINTER(win32more.Windows.Win32.Globalization.USet), s: win32more.Windows.Win32.Foundation.PSTR, length: Int32, spanCondition: win32more.Windows.Win32.Globalization.USetSpanCondition) -> Int32: ...
@cfunctype('icuuc.dll')
def uset_equals(set1: POINTER(win32more.Windows.Win32.Globalization.USet), set2: POINTER(win32more.Windows.Win32.Globalization.USet)) -> SByte: ...
@cfunctype('icuuc.dll')
def uset_serialize(set: POINTER(win32more.Windows.Win32.Globalization.USet), dest: POINTER(UInt16), destCapacity: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uset_getSerializedSet(fillSet: POINTER(win32more.Windows.Win32.Globalization.USerializedSet), src: POINTER(UInt16), srcLength: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def uset_setSerializedToOne(fillSet: POINTER(win32more.Windows.Win32.Globalization.USerializedSet), c: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def uset_serializedContains(set: POINTER(win32more.Windows.Win32.Globalization.USerializedSet), c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def uset_getSerializedRangeCount(set: POINTER(win32more.Windows.Win32.Globalization.USerializedSet)) -> Int32: ...
@cfunctype('icuuc.dll')
def uset_getSerializedRange(set: POINTER(win32more.Windows.Win32.Globalization.USerializedSet), rangeIndex: Int32, pStart: POINTER(Int32), pEnd: POINTER(Int32)) -> SByte: ...
@cfunctype('icuuc.dll')
def unorm2_getNFCInstance(pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UNormalizer2): ...
@cfunctype('icuuc.dll')
def unorm2_getNFDInstance(pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UNormalizer2): ...
@cfunctype('icuuc.dll')
def unorm2_getNFKCInstance(pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UNormalizer2): ...
@cfunctype('icuuc.dll')
def unorm2_getNFKDInstance(pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UNormalizer2): ...
@cfunctype('icuuc.dll')
def unorm2_getNFKCCasefoldInstance(pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UNormalizer2): ...
@cfunctype('icuuc.dll')
def unorm2_getInstance(packageName: win32more.Windows.Win32.Foundation.PSTR, name: win32more.Windows.Win32.Foundation.PSTR, mode: win32more.Windows.Win32.Globalization.UNormalization2Mode, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UNormalizer2): ...
@cfunctype('icuuc.dll')
def unorm2_openFiltered(norm2: POINTER(win32more.Windows.Win32.Globalization.UNormalizer2), filterSet: POINTER(win32more.Windows.Win32.Globalization.USet), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UNormalizer2): ...
@cfunctype('icuuc.dll')
def unorm2_close(norm2: POINTER(win32more.Windows.Win32.Globalization.UNormalizer2)) -> Void: ...
@cfunctype('icuuc.dll')
def unorm2_normalize(norm2: POINTER(win32more.Windows.Win32.Globalization.UNormalizer2), src: POINTER(UInt16), length: Int32, dest: POINTER(UInt16), capacity: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def unorm2_normalizeSecondAndAppend(norm2: POINTER(win32more.Windows.Win32.Globalization.UNormalizer2), first: POINTER(UInt16), firstLength: Int32, firstCapacity: Int32, second: POINTER(UInt16), secondLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def unorm2_append(norm2: POINTER(win32more.Windows.Win32.Globalization.UNormalizer2), first: POINTER(UInt16), firstLength: Int32, firstCapacity: Int32, second: POINTER(UInt16), secondLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def unorm2_getDecomposition(norm2: POINTER(win32more.Windows.Win32.Globalization.UNormalizer2), c: Int32, decomposition: POINTER(UInt16), capacity: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def unorm2_getRawDecomposition(norm2: POINTER(win32more.Windows.Win32.Globalization.UNormalizer2), c: Int32, decomposition: POINTER(UInt16), capacity: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def unorm2_composePair(norm2: POINTER(win32more.Windows.Win32.Globalization.UNormalizer2), a: Int32, b: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def unorm2_getCombiningClass(norm2: POINTER(win32more.Windows.Win32.Globalization.UNormalizer2), c: Int32) -> Byte: ...
@cfunctype('icuuc.dll')
def unorm2_isNormalized(norm2: POINTER(win32more.Windows.Win32.Globalization.UNormalizer2), s: POINTER(UInt16), length: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuuc.dll')
def unorm2_quickCheck(norm2: POINTER(win32more.Windows.Win32.Globalization.UNormalizer2), s: POINTER(UInt16), length: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Globalization.UNormalizationCheckResult: ...
@cfunctype('icuuc.dll')
def unorm2_spanQuickCheckYes(norm2: POINTER(win32more.Windows.Win32.Globalization.UNormalizer2), s: POINTER(UInt16), length: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def unorm2_hasBoundaryBefore(norm2: POINTER(win32more.Windows.Win32.Globalization.UNormalizer2), c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def unorm2_hasBoundaryAfter(norm2: POINTER(win32more.Windows.Win32.Globalization.UNormalizer2), c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def unorm2_isInert(norm2: POINTER(win32more.Windows.Win32.Globalization.UNormalizer2), c: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def unorm_compare(s1: POINTER(UInt16), length1: Int32, s2: POINTER(UInt16), length2: Int32, options: UInt32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucnvsel_open(converterList: POINTER(POINTER(SByte)), converterListSize: Int32, excludedCodePoints: POINTER(win32more.Windows.Win32.Globalization.USet), whichSet: win32more.Windows.Win32.Globalization.UConverterUnicodeSet, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UConverterSelector): ...
@cfunctype('icuuc.dll')
def ucnvsel_close(sel: POINTER(win32more.Windows.Win32.Globalization.UConverterSelector)) -> Void: ...
@cfunctype('icuuc.dll')
def ucnvsel_openFromSerialized(buffer: VoidPtr, length: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UConverterSelector): ...
@cfunctype('icuuc.dll')
def ucnvsel_serialize(sel: POINTER(win32more.Windows.Win32.Globalization.UConverterSelector), buffer: VoidPtr, bufferCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucnvsel_selectForString(sel: POINTER(win32more.Windows.Win32.Globalization.UConverterSelector), s: POINTER(UInt16), length: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuuc.dll')
def ucnvsel_selectForUTF8(sel: POINTER(win32more.Windows.Win32.Globalization.UConverterSelector), s: win32more.Windows.Win32.Foundation.PSTR, length: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuuc.dll')
def u_charsToUChars(cs: win32more.Windows.Win32.Foundation.PSTR, us: POINTER(UInt16), length: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def u_UCharsToChars(us: POINTER(UInt16), cs: win32more.Windows.Win32.Foundation.PSTR, length: Int32) -> Void: ...
@cfunctype('icuuc.dll')
def u_strlen(s: POINTER(UInt16)) -> Int32: ...
@cfunctype('icuuc.dll')
def u_countChar32(s: POINTER(UInt16), length: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def u_strHasMoreChar32Than(s: POINTER(UInt16), length: Int32, number: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def u_strcat(dst: POINTER(UInt16), src: POINTER(UInt16)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strncat(dst: POINTER(UInt16), src: POINTER(UInt16), n: Int32) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strstr(s: POINTER(UInt16), substring: POINTER(UInt16)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strFindFirst(s: POINTER(UInt16), length: Int32, substring: POINTER(UInt16), subLength: Int32) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strchr(s: POINTER(UInt16), c: UInt16) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strchr32(s: POINTER(UInt16), c: Int32) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strrstr(s: POINTER(UInt16), substring: POINTER(UInt16)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strFindLast(s: POINTER(UInt16), length: Int32, substring: POINTER(UInt16), subLength: Int32) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strrchr(s: POINTER(UInt16), c: UInt16) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strrchr32(s: POINTER(UInt16), c: Int32) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strpbrk(string: POINTER(UInt16), matchSet: POINTER(UInt16)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strcspn(string: POINTER(UInt16), matchSet: POINTER(UInt16)) -> Int32: ...
@cfunctype('icuuc.dll')
def u_strspn(string: POINTER(UInt16), matchSet: POINTER(UInt16)) -> Int32: ...
@cfunctype('icuuc.dll')
def u_strtok_r(src: POINTER(UInt16), delim: POINTER(UInt16), saveState: POINTER(POINTER(UInt16))) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strcmp(s1: POINTER(UInt16), s2: POINTER(UInt16)) -> Int32: ...
@cfunctype('icuuc.dll')
def u_strcmpCodePointOrder(s1: POINTER(UInt16), s2: POINTER(UInt16)) -> Int32: ...
@cfunctype('icuuc.dll')
def u_strCompare(s1: POINTER(UInt16), length1: Int32, s2: POINTER(UInt16), length2: Int32, codePointOrder: SByte) -> Int32: ...
@cfunctype('icuuc.dll')
def u_strCompareIter(iter1: POINTER(win32more.Windows.Win32.Globalization.UCharIterator), iter2: POINTER(win32more.Windows.Win32.Globalization.UCharIterator), codePointOrder: SByte) -> Int32: ...
@cfunctype('icuuc.dll')
def u_strCaseCompare(s1: POINTER(UInt16), length1: Int32, s2: POINTER(UInt16), length2: Int32, options: UInt32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def u_strncmp(ucs1: POINTER(UInt16), ucs2: POINTER(UInt16), n: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def u_strncmpCodePointOrder(s1: POINTER(UInt16), s2: POINTER(UInt16), n: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def u_strcasecmp(s1: POINTER(UInt16), s2: POINTER(UInt16), options: UInt32) -> Int32: ...
@cfunctype('icuuc.dll')
def u_strncasecmp(s1: POINTER(UInt16), s2: POINTER(UInt16), n: Int32, options: UInt32) -> Int32: ...
@cfunctype('icuuc.dll')
def u_memcasecmp(s1: POINTER(UInt16), s2: POINTER(UInt16), length: Int32, options: UInt32) -> Int32: ...
@cfunctype('icuuc.dll')
def u_strcpy(dst: POINTER(UInt16), src: POINTER(UInt16)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strncpy(dst: POINTER(UInt16), src: POINTER(UInt16), n: Int32) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_uastrcpy(dst: POINTER(UInt16), src: win32more.Windows.Win32.Foundation.PSTR) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_uastrncpy(dst: POINTER(UInt16), src: win32more.Windows.Win32.Foundation.PSTR, n: Int32) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_austrcpy(dst: win32more.Windows.Win32.Foundation.PSTR, src: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def u_austrncpy(dst: win32more.Windows.Win32.Foundation.PSTR, src: POINTER(UInt16), n: Int32) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def u_memcpy(dest: POINTER(UInt16), src: POINTER(UInt16), count: Int32) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_memmove(dest: POINTER(UInt16), src: POINTER(UInt16), count: Int32) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_memset(dest: POINTER(UInt16), c: UInt16, count: Int32) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_memcmp(buf1: POINTER(UInt16), buf2: POINTER(UInt16), count: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def u_memcmpCodePointOrder(s1: POINTER(UInt16), s2: POINTER(UInt16), count: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def u_memchr(s: POINTER(UInt16), c: UInt16, count: Int32) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_memchr32(s: POINTER(UInt16), c: Int32, count: Int32) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_memrchr(s: POINTER(UInt16), c: UInt16, count: Int32) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_memrchr32(s: POINTER(UInt16), c: Int32, count: Int32) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_unescape(src: win32more.Windows.Win32.Foundation.PSTR, dest: POINTER(UInt16), destCapacity: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def u_unescapeAt(charAt: win32more.Windows.Win32.Globalization.UNESCAPE_CHAR_AT, offset: POINTER(Int32), length: Int32, context: VoidPtr) -> Int32: ...
@cfunctype('icuuc.dll')
def u_strToUpper(dest: POINTER(UInt16), destCapacity: Int32, src: POINTER(UInt16), srcLength: Int32, locale: win32more.Windows.Win32.Foundation.PSTR, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def u_strToLower(dest: POINTER(UInt16), destCapacity: Int32, src: POINTER(UInt16), srcLength: Int32, locale: win32more.Windows.Win32.Foundation.PSTR, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def u_strToTitle(dest: POINTER(UInt16), destCapacity: Int32, src: POINTER(UInt16), srcLength: Int32, titleIter: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator), locale: win32more.Windows.Win32.Foundation.PSTR, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def u_strFoldCase(dest: POINTER(UInt16), destCapacity: Int32, src: POINTER(UInt16), srcLength: Int32, options: UInt32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def u_strToWCS(dest: win32more.Windows.Win32.Foundation.PWSTR, destCapacity: Int32, pDestLength: POINTER(Int32), src: POINTER(UInt16), srcLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PWSTR: ...
@cfunctype('icuuc.dll')
def u_strFromWCS(dest: POINTER(UInt16), destCapacity: Int32, pDestLength: POINTER(Int32), src: win32more.Windows.Win32.Foundation.PWSTR, srcLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strToUTF8(dest: win32more.Windows.Win32.Foundation.PSTR, destCapacity: Int32, pDestLength: POINTER(Int32), src: POINTER(UInt16), srcLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def u_strFromUTF8(dest: POINTER(UInt16), destCapacity: Int32, pDestLength: POINTER(Int32), src: win32more.Windows.Win32.Foundation.PSTR, srcLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strToUTF8WithSub(dest: win32more.Windows.Win32.Foundation.PSTR, destCapacity: Int32, pDestLength: POINTER(Int32), src: POINTER(UInt16), srcLength: Int32, subchar: Int32, pNumSubstitutions: POINTER(Int32), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def u_strFromUTF8WithSub(dest: POINTER(UInt16), destCapacity: Int32, pDestLength: POINTER(Int32), src: win32more.Windows.Win32.Foundation.PSTR, srcLength: Int32, subchar: Int32, pNumSubstitutions: POINTER(Int32), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strFromUTF8Lenient(dest: POINTER(UInt16), destCapacity: Int32, pDestLength: POINTER(Int32), src: win32more.Windows.Win32.Foundation.PSTR, srcLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strToUTF32(dest: POINTER(Int32), destCapacity: Int32, pDestLength: POINTER(Int32), src: POINTER(UInt16), srcLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(Int32): ...
@cfunctype('icuuc.dll')
def u_strFromUTF32(dest: POINTER(UInt16), destCapacity: Int32, pDestLength: POINTER(Int32), src: POINTER(Int32), srcLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strToUTF32WithSub(dest: POINTER(Int32), destCapacity: Int32, pDestLength: POINTER(Int32), src: POINTER(UInt16), srcLength: Int32, subchar: Int32, pNumSubstitutions: POINTER(Int32), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(Int32): ...
@cfunctype('icuuc.dll')
def u_strFromUTF32WithSub(dest: POINTER(UInt16), destCapacity: Int32, pDestLength: POINTER(Int32), src: POINTER(Int32), srcLength: Int32, subchar: Int32, pNumSubstitutions: POINTER(Int32), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def u_strToJavaModifiedUTF8(dest: win32more.Windows.Win32.Foundation.PSTR, destCapacity: Int32, pDestLength: POINTER(Int32), src: POINTER(UInt16), srcLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def u_strFromJavaModifiedUTF8WithSub(dest: POINTER(UInt16), destCapacity: Int32, pDestLength: POINTER(Int32), src: win32more.Windows.Win32.Foundation.PSTR, srcLength: Int32, subchar: Int32, pNumSubstitutions: POINTER(Int32), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuuc.dll')
def ucasemap_open(locale: win32more.Windows.Win32.Foundation.PSTR, options: UInt32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UCaseMap): ...
@cfunctype('icuuc.dll')
def ucasemap_close(csm: POINTER(win32more.Windows.Win32.Globalization.UCaseMap)) -> Void: ...
@cfunctype('icuuc.dll')
def ucasemap_getLocale(csm: POINTER(win32more.Windows.Win32.Globalization.UCaseMap)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def ucasemap_getOptions(csm: POINTER(win32more.Windows.Win32.Globalization.UCaseMap)) -> UInt32: ...
@cfunctype('icuuc.dll')
def ucasemap_setLocale(csm: POINTER(win32more.Windows.Win32.Globalization.UCaseMap), locale: win32more.Windows.Win32.Foundation.PSTR, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucasemap_setOptions(csm: POINTER(win32more.Windows.Win32.Globalization.UCaseMap), options: UInt32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucasemap_getBreakIterator(csm: POINTER(win32more.Windows.Win32.Globalization.UCaseMap)) -> POINTER(win32more.Windows.Win32.Globalization.UBreakIterator): ...
@cfunctype('icuuc.dll')
def ucasemap_setBreakIterator(csm: POINTER(win32more.Windows.Win32.Globalization.UCaseMap), iterToAdopt: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ucasemap_toTitle(csm: POINTER(win32more.Windows.Win32.Globalization.UCaseMap), dest: POINTER(UInt16), destCapacity: Int32, src: POINTER(UInt16), srcLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucasemap_utf8ToLower(csm: POINTER(win32more.Windows.Win32.Globalization.UCaseMap), dest: win32more.Windows.Win32.Foundation.PSTR, destCapacity: Int32, src: win32more.Windows.Win32.Foundation.PSTR, srcLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucasemap_utf8ToUpper(csm: POINTER(win32more.Windows.Win32.Globalization.UCaseMap), dest: win32more.Windows.Win32.Foundation.PSTR, destCapacity: Int32, src: win32more.Windows.Win32.Foundation.PSTR, srcLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucasemap_utf8ToTitle(csm: POINTER(win32more.Windows.Win32.Globalization.UCaseMap), dest: win32more.Windows.Win32.Foundation.PSTR, destCapacity: Int32, src: win32more.Windows.Win32.Foundation.PSTR, srcLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ucasemap_utf8FoldCase(csm: POINTER(win32more.Windows.Win32.Globalization.UCaseMap), dest: win32more.Windows.Win32.Foundation.PSTR, destCapacity: Int32, src: win32more.Windows.Win32.Foundation.PSTR, srcLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def usprep_open(path: win32more.Windows.Win32.Foundation.PSTR, fileName: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UStringPrepProfile): ...
@cfunctype('icuuc.dll')
def usprep_openByType(type: win32more.Windows.Win32.Globalization.UStringPrepProfileType, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UStringPrepProfile): ...
@cfunctype('icuuc.dll')
def usprep_close(profile: POINTER(win32more.Windows.Win32.Globalization.UStringPrepProfile)) -> Void: ...
@cfunctype('icuuc.dll')
def usprep_prepare(prep: POINTER(win32more.Windows.Win32.Globalization.UStringPrepProfile), src: POINTER(UInt16), srcLength: Int32, dest: POINTER(UInt16), destCapacity: Int32, options: Int32, parseError: POINTER(win32more.Windows.Win32.Globalization.UParseError), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uidna_openUTS46(options: UInt32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UIDNA): ...
@cfunctype('icuuc.dll')
def uidna_close(idna: POINTER(win32more.Windows.Win32.Globalization.UIDNA)) -> Void: ...
@cfunctype('icuuc.dll')
def uidna_labelToASCII(idna: POINTER(win32more.Windows.Win32.Globalization.UIDNA), label: POINTER(UInt16), length: Int32, dest: POINTER(UInt16), capacity: Int32, pInfo: POINTER(win32more.Windows.Win32.Globalization.UIDNAInfo), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uidna_labelToUnicode(idna: POINTER(win32more.Windows.Win32.Globalization.UIDNA), label: POINTER(UInt16), length: Int32, dest: POINTER(UInt16), capacity: Int32, pInfo: POINTER(win32more.Windows.Win32.Globalization.UIDNAInfo), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uidna_nameToASCII(idna: POINTER(win32more.Windows.Win32.Globalization.UIDNA), name: POINTER(UInt16), length: Int32, dest: POINTER(UInt16), capacity: Int32, pInfo: POINTER(win32more.Windows.Win32.Globalization.UIDNAInfo), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uidna_nameToUnicode(idna: POINTER(win32more.Windows.Win32.Globalization.UIDNA), name: POINTER(UInt16), length: Int32, dest: POINTER(UInt16), capacity: Int32, pInfo: POINTER(win32more.Windows.Win32.Globalization.UIDNAInfo), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uidna_labelToASCII_UTF8(idna: POINTER(win32more.Windows.Win32.Globalization.UIDNA), label: win32more.Windows.Win32.Foundation.PSTR, length: Int32, dest: win32more.Windows.Win32.Foundation.PSTR, capacity: Int32, pInfo: POINTER(win32more.Windows.Win32.Globalization.UIDNAInfo), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uidna_labelToUnicodeUTF8(idna: POINTER(win32more.Windows.Win32.Globalization.UIDNA), label: win32more.Windows.Win32.Foundation.PSTR, length: Int32, dest: win32more.Windows.Win32.Foundation.PSTR, capacity: Int32, pInfo: POINTER(win32more.Windows.Win32.Globalization.UIDNAInfo), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uidna_nameToASCII_UTF8(idna: POINTER(win32more.Windows.Win32.Globalization.UIDNA), name: win32more.Windows.Win32.Foundation.PSTR, length: Int32, dest: win32more.Windows.Win32.Foundation.PSTR, capacity: Int32, pInfo: POINTER(win32more.Windows.Win32.Globalization.UIDNAInfo), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def uidna_nameToUnicodeUTF8(idna: POINTER(win32more.Windows.Win32.Globalization.UIDNA), name: win32more.Windows.Win32.Foundation.PSTR, length: Int32, dest: win32more.Windows.Win32.Foundation.PSTR, capacity: Int32, pInfo: POINTER(win32more.Windows.Win32.Globalization.UIDNAInfo), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubrk_open(type: win32more.Windows.Win32.Globalization.UBreakIteratorType, locale: win32more.Windows.Win32.Foundation.PSTR, text: POINTER(UInt16), textLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UBreakIterator): ...
@cfunctype('icuuc.dll')
def ubrk_openRules(rules: POINTER(UInt16), rulesLength: Int32, text: POINTER(UInt16), textLength: Int32, parseErr: POINTER(win32more.Windows.Win32.Globalization.UParseError), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UBreakIterator): ...
@cfunctype('icuuc.dll')
def ubrk_openBinaryRules(binaryRules: POINTER(Byte), rulesLength: Int32, text: POINTER(UInt16), textLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UBreakIterator): ...
@cfunctype('icuuc.dll')
def ubrk_safeClone(bi: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator), stackBuffer: VoidPtr, pBufferSize: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UBreakIterator): ...
@cfunctype('icuuc.dll')
def ubrk_close(bi: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator)) -> Void: ...
@cfunctype('icuuc.dll')
def ubrk_setText(bi: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator), text: POINTER(UInt16), textLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ubrk_setUText(bi: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator), text: POINTER(win32more.Windows.Win32.Globalization.UText), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ubrk_current(bi: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubrk_next(bi: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubrk_previous(bi: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubrk_first(bi: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubrk_last(bi: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubrk_preceding(bi: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator), offset: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def ubrk_following(bi: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator), offset: Int32) -> Int32: ...
@cfunctype('icuuc.dll')
def ubrk_getAvailable(index: Int32) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def ubrk_countAvailable() -> Int32: ...
@cfunctype('icuuc.dll')
def ubrk_isBoundary(bi: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator), offset: Int32) -> SByte: ...
@cfunctype('icuuc.dll')
def ubrk_getRuleStatus(bi: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubrk_getRuleStatusVec(bi: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator), fillInVec: POINTER(Int32), capacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def ubrk_getLocaleByType(bi: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator), type: win32more.Windows.Win32.Globalization.ULocDataLocaleType, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuuc.dll')
def ubrk_refreshUText(bi: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator), text: POINTER(win32more.Windows.Win32.Globalization.UText), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuuc.dll')
def ubrk_getBinaryRules(bi: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator), binaryRules: POINTER(Byte), rulesCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuuc.dll')
def u_getDataVersion(dataVersionFillin: POINTER(Byte), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ucal_openTimeZoneIDEnumeration(zoneType: win32more.Windows.Win32.Globalization.USystemTimeZoneType, region: win32more.Windows.Win32.Foundation.PSTR, rawOffset: POINTER(Int32), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def ucal_openTimeZones(ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def ucal_openCountryTimeZones(country: win32more.Windows.Win32.Foundation.PSTR, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def ucal_getDefaultTimeZone(result: POINTER(UInt16), resultCapacity: Int32, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucal_setDefaultTimeZone(zoneID: POINTER(UInt16), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icu.dll')
def ucal_getHostTimeZone(result: POINTER(UInt16), resultCapacity: Int32, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucal_getDSTSavings(zoneID: POINTER(UInt16), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucal_getNow() -> Double: ...
@cfunctype('icuin.dll')
def ucal_open(zoneID: POINTER(UInt16), len: Int32, locale: win32more.Windows.Win32.Foundation.PSTR, type: win32more.Windows.Win32.Globalization.UCalendarType, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def ucal_close(cal: POINTER(VoidPtr)) -> Void: ...
@cfunctype('icuin.dll')
def ucal_clone(cal: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def ucal_setTimeZone(cal: POINTER(VoidPtr), zoneID: POINTER(UInt16), len: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ucal_getTimeZoneID(cal: POINTER(VoidPtr), result: POINTER(UInt16), resultLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucal_getTimeZoneDisplayName(cal: POINTER(VoidPtr), type: win32more.Windows.Win32.Globalization.UCalendarDisplayNameType, locale: win32more.Windows.Win32.Foundation.PSTR, result: POINTER(UInt16), resultLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucal_inDaylightTime(cal: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuin.dll')
def ucal_setGregorianChange(cal: POINTER(VoidPtr), date: Double, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ucal_getGregorianChange(cal: POINTER(VoidPtr), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Double: ...
@cfunctype('icuin.dll')
def ucal_getAttribute(cal: POINTER(VoidPtr), attr: win32more.Windows.Win32.Globalization.UCalendarAttribute) -> Int32: ...
@cfunctype('icuin.dll')
def ucal_setAttribute(cal: POINTER(VoidPtr), attr: win32more.Windows.Win32.Globalization.UCalendarAttribute, newValue: Int32) -> Void: ...
@cfunctype('icuin.dll')
def ucal_getAvailable(localeIndex: Int32) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuin.dll')
def ucal_countAvailable() -> Int32: ...
@cfunctype('icuin.dll')
def ucal_getMillis(cal: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Double: ...
@cfunctype('icuin.dll')
def ucal_setMillis(cal: POINTER(VoidPtr), dateTime: Double, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ucal_setDate(cal: POINTER(VoidPtr), year: Int32, month: Int32, date: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ucal_setDateTime(cal: POINTER(VoidPtr), year: Int32, month: Int32, date: Int32, hour: Int32, minute: Int32, second: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ucal_equivalentTo(cal1: POINTER(VoidPtr), cal2: POINTER(VoidPtr)) -> SByte: ...
@cfunctype('icuin.dll')
def ucal_add(cal: POINTER(VoidPtr), field: win32more.Windows.Win32.Globalization.UCalendarDateFields, amount: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ucal_roll(cal: POINTER(VoidPtr), field: win32more.Windows.Win32.Globalization.UCalendarDateFields, amount: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ucal_get(cal: POINTER(VoidPtr), field: win32more.Windows.Win32.Globalization.UCalendarDateFields, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucal_set(cal: POINTER(VoidPtr), field: win32more.Windows.Win32.Globalization.UCalendarDateFields, value: Int32) -> Void: ...
@cfunctype('icuin.dll')
def ucal_isSet(cal: POINTER(VoidPtr), field: win32more.Windows.Win32.Globalization.UCalendarDateFields) -> SByte: ...
@cfunctype('icuin.dll')
def ucal_clearField(cal: POINTER(VoidPtr), field: win32more.Windows.Win32.Globalization.UCalendarDateFields) -> Void: ...
@cfunctype('icuin.dll')
def ucal_clear(calendar: POINTER(VoidPtr)) -> Void: ...
@cfunctype('icuin.dll')
def ucal_getLimit(cal: POINTER(VoidPtr), field: win32more.Windows.Win32.Globalization.UCalendarDateFields, type: win32more.Windows.Win32.Globalization.UCalendarLimitType, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucal_getLocaleByType(cal: POINTER(VoidPtr), type: win32more.Windows.Win32.Globalization.ULocDataLocaleType, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuin.dll')
def ucal_getTZDataVersion(status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuin.dll')
def ucal_getCanonicalTimeZoneID(id: POINTER(UInt16), len: Int32, result: POINTER(UInt16), resultCapacity: Int32, isSystemID: POINTER(SByte), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucal_getType(cal: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuin.dll')
def ucal_getKeywordValuesForLocale(key: win32more.Windows.Win32.Foundation.PSTR, locale: win32more.Windows.Win32.Foundation.PSTR, commonlyUsed: SByte, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def ucal_getDayOfWeekType(cal: POINTER(VoidPtr), dayOfWeek: win32more.Windows.Win32.Globalization.UCalendarDaysOfWeek, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Globalization.UCalendarWeekdayType: ...
@cfunctype('icuin.dll')
def ucal_getWeekendTransition(cal: POINTER(VoidPtr), dayOfWeek: win32more.Windows.Win32.Globalization.UCalendarDaysOfWeek, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucal_isWeekend(cal: POINTER(VoidPtr), date: Double, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuin.dll')
def ucal_getFieldDifference(cal: POINTER(VoidPtr), target: Double, field: win32more.Windows.Win32.Globalization.UCalendarDateFields, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucal_getTimeZoneTransitionDate(cal: POINTER(VoidPtr), type: win32more.Windows.Win32.Globalization.UTimeZoneTransitionType, transition: POINTER(Double), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuin.dll')
def ucal_getWindowsTimeZoneID(id: POINTER(UInt16), len: Int32, winid: POINTER(UInt16), winidCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucal_getTimeZoneIDForWindowsID(winid: POINTER(UInt16), len: Int32, region: win32more.Windows.Win32.Foundation.PSTR, id: POINTER(UInt16), idCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_open(loc: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UCollator): ...
@cfunctype('icuin.dll')
def ucol_openRules(rules: POINTER(UInt16), rulesLength: Int32, normalizationMode: win32more.Windows.Win32.Globalization.UColAttributeValue, strength: win32more.Windows.Win32.Globalization.UColAttributeValue, parseError: POINTER(win32more.Windows.Win32.Globalization.UParseError), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UCollator): ...
@cfunctype('icuin.dll')
def ucol_getContractionsAndExpansions(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), contractions: POINTER(win32more.Windows.Win32.Globalization.USet), expansions: POINTER(win32more.Windows.Win32.Globalization.USet), addPrefixes: SByte, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ucol_close(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator)) -> Void: ...
@cfunctype('icuin.dll')
def ucol_strcoll(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), source: POINTER(UInt16), sourceLength: Int32, target: POINTER(UInt16), targetLength: Int32) -> win32more.Windows.Win32.Globalization.UCollationResult: ...
@cfunctype('icuin.dll')
def ucol_strcollUTF8(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), source: win32more.Windows.Win32.Foundation.PSTR, sourceLength: Int32, target: win32more.Windows.Win32.Foundation.PSTR, targetLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Globalization.UCollationResult: ...
@cfunctype('icuin.dll')
def ucol_greater(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), source: POINTER(UInt16), sourceLength: Int32, target: POINTER(UInt16), targetLength: Int32) -> SByte: ...
@cfunctype('icuin.dll')
def ucol_greaterOrEqual(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), source: POINTER(UInt16), sourceLength: Int32, target: POINTER(UInt16), targetLength: Int32) -> SByte: ...
@cfunctype('icuin.dll')
def ucol_equal(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), source: POINTER(UInt16), sourceLength: Int32, target: POINTER(UInt16), targetLength: Int32) -> SByte: ...
@cfunctype('icuin.dll')
def ucol_strcollIter(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), sIter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator), tIter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Globalization.UCollationResult: ...
@cfunctype('icuin.dll')
def ucol_getStrength(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator)) -> win32more.Windows.Win32.Globalization.UColAttributeValue: ...
@cfunctype('icuin.dll')
def ucol_setStrength(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), strength: win32more.Windows.Win32.Globalization.UColAttributeValue) -> Void: ...
@cfunctype('icuin.dll')
def ucol_getReorderCodes(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), dest: POINTER(Int32), destCapacity: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_setReorderCodes(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), reorderCodes: POINTER(Int32), reorderCodesLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ucol_getEquivalentReorderCodes(reorderCode: Int32, dest: POINTER(Int32), destCapacity: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_getDisplayName(objLoc: win32more.Windows.Win32.Foundation.PSTR, dispLoc: win32more.Windows.Win32.Foundation.PSTR, result: POINTER(UInt16), resultLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_getAvailable(localeIndex: Int32) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuin.dll')
def ucol_countAvailable() -> Int32: ...
@cfunctype('icuin.dll')
def ucol_openAvailableLocales(status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def ucol_getKeywords(status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def ucol_getKeywordValues(keyword: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def ucol_getKeywordValuesForLocale(key: win32more.Windows.Win32.Foundation.PSTR, locale: win32more.Windows.Win32.Foundation.PSTR, commonlyUsed: SByte, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def ucol_getFunctionalEquivalent(result: win32more.Windows.Win32.Foundation.PSTR, resultCapacity: Int32, keyword: win32more.Windows.Win32.Foundation.PSTR, locale: win32more.Windows.Win32.Foundation.PSTR, isAvailable: POINTER(SByte), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_getRules(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), length: POINTER(Int32)) -> POINTER(UInt16): ...
@cfunctype('icuin.dll')
def ucol_getSortKey(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), source: POINTER(UInt16), sourceLength: Int32, result: POINTER(Byte), resultLength: Int32) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_nextSortKeyPart(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator), state: POINTER(UInt32), dest: POINTER(Byte), count: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_getBound(source: POINTER(Byte), sourceLength: Int32, boundType: win32more.Windows.Win32.Globalization.UColBoundMode, noOfLevels: UInt32, result: POINTER(Byte), resultLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_getVersion(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), info: POINTER(Byte)) -> Void: ...
@cfunctype('icuin.dll')
def ucol_getUCAVersion(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), info: POINTER(Byte)) -> Void: ...
@cfunctype('icuin.dll')
def ucol_mergeSortkeys(src1: POINTER(Byte), src1Length: Int32, src2: POINTER(Byte), src2Length: Int32, dest: POINTER(Byte), destCapacity: Int32) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_setAttribute(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), attr: win32more.Windows.Win32.Globalization.UColAttribute, value: win32more.Windows.Win32.Globalization.UColAttributeValue, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ucol_getAttribute(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), attr: win32more.Windows.Win32.Globalization.UColAttribute, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Globalization.UColAttributeValue: ...
@cfunctype('icuin.dll')
def ucol_setMaxVariable(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), group: win32more.Windows.Win32.Globalization.UColReorderCode, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ucol_getMaxVariable(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator)) -> win32more.Windows.Win32.Globalization.UColReorderCode: ...
@cfunctype('icuin.dll')
def ucol_getVariableTop(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> UInt32: ...
@cfunctype('icuin.dll')
def ucol_safeClone(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), stackBuffer: VoidPtr, pBufferSize: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UCollator): ...
@cfunctype('icuin.dll')
def ucol_getRulesEx(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), delta: win32more.Windows.Win32.Globalization.UColRuleOption, buffer: POINTER(UInt16), bufferLen: Int32) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_getLocaleByType(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), type: win32more.Windows.Win32.Globalization.ULocDataLocaleType, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuin.dll')
def ucol_getTailoredSet(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.USet): ...
@cfunctype('icuin.dll')
def ucol_cloneBinary(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), buffer: POINTER(Byte), capacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_openBinary(bin: POINTER(Byte), length: Int32, base: POINTER(win32more.Windows.Win32.Globalization.UCollator), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UCollator): ...
@cfunctype('icuin.dll')
def ucol_openElements(coll: POINTER(win32more.Windows.Win32.Globalization.UCollator), text: POINTER(UInt16), textLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UCollationElements): ...
@cfunctype('icuin.dll')
def ucol_keyHashCode(key: POINTER(Byte), length: Int32) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_closeElements(elems: POINTER(win32more.Windows.Win32.Globalization.UCollationElements)) -> Void: ...
@cfunctype('icuin.dll')
def ucol_reset(elems: POINTER(win32more.Windows.Win32.Globalization.UCollationElements)) -> Void: ...
@cfunctype('icuin.dll')
def ucol_next(elems: POINTER(win32more.Windows.Win32.Globalization.UCollationElements), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_previous(elems: POINTER(win32more.Windows.Win32.Globalization.UCollationElements), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_getMaxExpansion(elems: POINTER(win32more.Windows.Win32.Globalization.UCollationElements), order: Int32) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_setText(elems: POINTER(win32more.Windows.Win32.Globalization.UCollationElements), text: POINTER(UInt16), textLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ucol_getOffset(elems: POINTER(win32more.Windows.Win32.Globalization.UCollationElements)) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_setOffset(elems: POINTER(win32more.Windows.Win32.Globalization.UCollationElements), offset: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ucol_primaryOrder(order: Int32) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_secondaryOrder(order: Int32) -> Int32: ...
@cfunctype('icuin.dll')
def ucol_tertiaryOrder(order: Int32) -> Int32: ...
@cfunctype('icuin.dll')
def ucsdet_open(status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UCharsetDetector): ...
@cfunctype('icuin.dll')
def ucsdet_close(ucsd: POINTER(win32more.Windows.Win32.Globalization.UCharsetDetector)) -> Void: ...
@cfunctype('icuin.dll')
def ucsdet_setText(ucsd: POINTER(win32more.Windows.Win32.Globalization.UCharsetDetector), textIn: win32more.Windows.Win32.Foundation.PSTR, len: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ucsdet_setDeclaredEncoding(ucsd: POINTER(win32more.Windows.Win32.Globalization.UCharsetDetector), encoding: win32more.Windows.Win32.Foundation.PSTR, length: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ucsdet_detect(ucsd: POINTER(win32more.Windows.Win32.Globalization.UCharsetDetector), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UCharsetMatch): ...
@cfunctype('icuin.dll')
def ucsdet_detectAll(ucsd: POINTER(win32more.Windows.Win32.Globalization.UCharsetDetector), matchesFound: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(POINTER(win32more.Windows.Win32.Globalization.UCharsetMatch)): ...
@cfunctype('icuin.dll')
def ucsdet_getName(ucsm: POINTER(win32more.Windows.Win32.Globalization.UCharsetMatch), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuin.dll')
def ucsdet_getConfidence(ucsm: POINTER(win32more.Windows.Win32.Globalization.UCharsetMatch), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucsdet_getLanguage(ucsm: POINTER(win32more.Windows.Win32.Globalization.UCharsetMatch), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuin.dll')
def ucsdet_getUChars(ucsm: POINTER(win32more.Windows.Win32.Globalization.UCharsetMatch), buf: POINTER(UInt16), cap: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ucsdet_getAllDetectableCharsets(ucsd: POINTER(win32more.Windows.Win32.Globalization.UCharsetDetector), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def ucsdet_isInputFilterEnabled(ucsd: POINTER(win32more.Windows.Win32.Globalization.UCharsetDetector)) -> SByte: ...
@cfunctype('icuin.dll')
def ucsdet_enableInputFilter(ucsd: POINTER(win32more.Windows.Win32.Globalization.UCharsetDetector), filter: SByte) -> SByte: ...
@cfunctype('icuin.dll')
def ufieldpositer_open(status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UFieldPositionIterator): ...
@cfunctype('icuin.dll')
def ufieldpositer_close(fpositer: POINTER(win32more.Windows.Win32.Globalization.UFieldPositionIterator)) -> Void: ...
@cfunctype('icuin.dll')
def ufieldpositer_next(fpositer: POINTER(win32more.Windows.Win32.Globalization.UFieldPositionIterator), beginIndex: POINTER(Int32), endIndex: POINTER(Int32)) -> Int32: ...
@cfunctype('icuin.dll')
def ufmt_open(status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def ufmt_close(fmt: POINTER(VoidPtr)) -> Void: ...
@cfunctype('icuin.dll')
def ufmt_getType(fmt: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Globalization.UFormattableType: ...
@cfunctype('icuin.dll')
def ufmt_isNumeric(fmt: POINTER(VoidPtr)) -> SByte: ...
@cfunctype('icuin.dll')
def ufmt_getDate(fmt: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Double: ...
@cfunctype('icuin.dll')
def ufmt_getDouble(fmt: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Double: ...
@cfunctype('icuin.dll')
def ufmt_getLong(fmt: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ufmt_getInt64(fmt: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int64: ...
@cfunctype('icuin.dll')
def ufmt_getObject(fmt: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> VoidPtr: ...
@cfunctype('icuin.dll')
def ufmt_getUChars(fmt: POINTER(VoidPtr), len: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuin.dll')
def ufmt_getArrayLength(fmt: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ufmt_getArrayItemByIndex(fmt: POINTER(VoidPtr), n: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def ufmt_getDecNumChars(fmt: POINTER(VoidPtr), len: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icu.dll')
def ucfpos_open(ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UConstrainedFieldPosition): ...
@cfunctype('icu.dll')
def ucfpos_reset(ucfpos: POINTER(win32more.Windows.Win32.Globalization.UConstrainedFieldPosition), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icu.dll')
def ucfpos_close(ucfpos: POINTER(win32more.Windows.Win32.Globalization.UConstrainedFieldPosition)) -> Void: ...
@cfunctype('icu.dll')
def ucfpos_constrainCategory(ucfpos: POINTER(win32more.Windows.Win32.Globalization.UConstrainedFieldPosition), category: Int32, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icu.dll')
def ucfpos_constrainField(ucfpos: POINTER(win32more.Windows.Win32.Globalization.UConstrainedFieldPosition), category: Int32, field: Int32, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icu.dll')
def ucfpos_getCategory(ucfpos: POINTER(win32more.Windows.Win32.Globalization.UConstrainedFieldPosition), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icu.dll')
def ucfpos_getField(ucfpos: POINTER(win32more.Windows.Win32.Globalization.UConstrainedFieldPosition), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icu.dll')
def ucfpos_getIndexes(ucfpos: POINTER(win32more.Windows.Win32.Globalization.UConstrainedFieldPosition), pStart: POINTER(Int32), pLimit: POINTER(Int32), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icu.dll')
def ucfpos_getInt64IterationContext(ucfpos: POINTER(win32more.Windows.Win32.Globalization.UConstrainedFieldPosition), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int64: ...
@cfunctype('icu.dll')
def ucfpos_setInt64IterationContext(ucfpos: POINTER(win32more.Windows.Win32.Globalization.UConstrainedFieldPosition), context: Int64, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icu.dll')
def ucfpos_matchesField(ucfpos: POINTER(win32more.Windows.Win32.Globalization.UConstrainedFieldPosition), category: Int32, field: Int32, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icu.dll')
def ucfpos_setState(ucfpos: POINTER(win32more.Windows.Win32.Globalization.UConstrainedFieldPosition), category: Int32, field: Int32, start: Int32, limit: Int32, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icu.dll')
def ufmtval_getString(ufmtval: POINTER(win32more.Windows.Win32.Globalization.UFormattedValue), pLength: POINTER(Int32), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icu.dll')
def ufmtval_nextPosition(ufmtval: POINTER(win32more.Windows.Win32.Globalization.UFormattedValue), ucfpos: POINTER(win32more.Windows.Win32.Globalization.UConstrainedFieldPosition), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuin.dll')
def udtitvfmt_open(locale: win32more.Windows.Win32.Foundation.PSTR, skeleton: POINTER(UInt16), skeletonLength: Int32, tzID: POINTER(UInt16), tzIDLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UDateIntervalFormat): ...
@cfunctype('icuin.dll')
def udtitvfmt_close(formatter: POINTER(win32more.Windows.Win32.Globalization.UDateIntervalFormat)) -> Void: ...
@cfunctype('icu.dll')
def udtitvfmt_openResult(ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UFormattedDateInterval): ...
@cfunctype('icu.dll')
def udtitvfmt_resultAsValue(uresult: POINTER(win32more.Windows.Win32.Globalization.UFormattedDateInterval), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UFormattedValue): ...
@cfunctype('icu.dll')
def udtitvfmt_closeResult(uresult: POINTER(win32more.Windows.Win32.Globalization.UFormattedDateInterval)) -> Void: ...
@cfunctype('icuin.dll')
def udtitvfmt_format(formatter: POINTER(win32more.Windows.Win32.Globalization.UDateIntervalFormat), fromDate: Double, toDate: Double, result: POINTER(UInt16), resultCapacity: Int32, position: POINTER(win32more.Windows.Win32.Globalization.UFieldPosition), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ugender_getInstance(locale: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UGenderInfo): ...
@cfunctype('icuin.dll')
def ugender_getListGender(genderInfo: POINTER(win32more.Windows.Win32.Globalization.UGenderInfo), genders: POINTER(win32more.Windows.Win32.Globalization.UGender), size: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Globalization.UGender: ...
@cfunctype('icuuc.dll')
def ulistfmt_open(locale: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UListFormatter): ...
@cfunctype('icu.dll')
def ulistfmt_openForType(locale: win32more.Windows.Win32.Foundation.PSTR, type: win32more.Windows.Win32.Globalization.UListFormatterType, width: win32more.Windows.Win32.Globalization.UListFormatterWidth, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UListFormatter): ...
@cfunctype('icuuc.dll')
def ulistfmt_close(listfmt: POINTER(win32more.Windows.Win32.Globalization.UListFormatter)) -> Void: ...
@cfunctype('icu.dll')
def ulistfmt_openResult(ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UFormattedList): ...
@cfunctype('icu.dll')
def ulistfmt_resultAsValue(uresult: POINTER(win32more.Windows.Win32.Globalization.UFormattedList), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UFormattedValue): ...
@cfunctype('icu.dll')
def ulistfmt_closeResult(uresult: POINTER(win32more.Windows.Win32.Globalization.UFormattedList)) -> Void: ...
@cfunctype('icuuc.dll')
def ulistfmt_format(listfmt: POINTER(win32more.Windows.Win32.Globalization.UListFormatter), strings: POINTER(POINTER(UInt16)), stringLengths: POINTER(Int32), stringCount: Int32, result: POINTER(UInt16), resultCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icu.dll')
def ulistfmt_formatStringsToResult(listfmt: POINTER(win32more.Windows.Win32.Globalization.UListFormatter), strings: POINTER(POINTER(UInt16)), stringLengths: POINTER(Int32), stringCount: Int32, uresult: POINTER(win32more.Windows.Win32.Globalization.UFormattedList), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ulocdata_open(localeID: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.ULocaleData): ...
@cfunctype('icuin.dll')
def ulocdata_close(uld: POINTER(win32more.Windows.Win32.Globalization.ULocaleData)) -> Void: ...
@cfunctype('icuin.dll')
def ulocdata_setNoSubstitute(uld: POINTER(win32more.Windows.Win32.Globalization.ULocaleData), setting: SByte) -> Void: ...
@cfunctype('icuin.dll')
def ulocdata_getNoSubstitute(uld: POINTER(win32more.Windows.Win32.Globalization.ULocaleData)) -> SByte: ...
@cfunctype('icuin.dll')
def ulocdata_getExemplarSet(uld: POINTER(win32more.Windows.Win32.Globalization.ULocaleData), fillIn: POINTER(win32more.Windows.Win32.Globalization.USet), options: UInt32, extype: win32more.Windows.Win32.Globalization.ULocaleDataExemplarSetType, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.USet): ...
@cfunctype('icuin.dll')
def ulocdata_getDelimiter(uld: POINTER(win32more.Windows.Win32.Globalization.ULocaleData), type: win32more.Windows.Win32.Globalization.ULocaleDataDelimiterType, result: POINTER(UInt16), resultLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ulocdata_getMeasurementSystem(localeID: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Globalization.UMeasurementSystem: ...
@cfunctype('icuin.dll')
def ulocdata_getPaperSize(localeID: win32more.Windows.Win32.Foundation.PSTR, height: POINTER(Int32), width: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ulocdata_getCLDRVersion(versionArray: POINTER(Byte), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ulocdata_getLocaleDisplayPattern(uld: POINTER(win32more.Windows.Win32.Globalization.ULocaleData), pattern: POINTER(UInt16), patternCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def ulocdata_getLocaleSeparator(uld: POINTER(win32more.Windows.Win32.Globalization.ULocaleData), separator: POINTER(UInt16), separatorCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll', variadic=True)
def u_formatMessage(locale: win32more.Windows.Win32.Foundation.PSTR, pattern: POINTER(UInt16), patternLength: Int32, result: POINTER(UInt16), resultLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode), *__arglist) -> Int32: ...
@cfunctype('icuin.dll')
def u_vformatMessage(locale: win32more.Windows.Win32.Foundation.PSTR, pattern: POINTER(UInt16), patternLength: Int32, result: POINTER(UInt16), resultLength: Int32, ap: POINTER(SByte), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll', variadic=True)
def u_parseMessage(locale: win32more.Windows.Win32.Foundation.PSTR, pattern: POINTER(UInt16), patternLength: Int32, source: POINTER(UInt16), sourceLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode), *__arglist) -> Void: ...
@cfunctype('icuin.dll')
def u_vparseMessage(locale: win32more.Windows.Win32.Foundation.PSTR, pattern: POINTER(UInt16), patternLength: Int32, source: POINTER(UInt16), sourceLength: Int32, ap: POINTER(SByte), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll', variadic=True)
def u_formatMessageWithError(locale: win32more.Windows.Win32.Foundation.PSTR, pattern: POINTER(UInt16), patternLength: Int32, result: POINTER(UInt16), resultLength: Int32, parseError: POINTER(win32more.Windows.Win32.Globalization.UParseError), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode), *__arglist) -> Int32: ...
@cfunctype('icuin.dll')
def u_vformatMessageWithError(locale: win32more.Windows.Win32.Foundation.PSTR, pattern: POINTER(UInt16), patternLength: Int32, result: POINTER(UInt16), resultLength: Int32, parseError: POINTER(win32more.Windows.Win32.Globalization.UParseError), ap: POINTER(SByte), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll', variadic=True)
def u_parseMessageWithError(locale: win32more.Windows.Win32.Foundation.PSTR, pattern: POINTER(UInt16), patternLength: Int32, source: POINTER(UInt16), sourceLength: Int32, parseError: POINTER(win32more.Windows.Win32.Globalization.UParseError), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode), *__arglist) -> Void: ...
@cfunctype('icuin.dll')
def u_vparseMessageWithError(locale: win32more.Windows.Win32.Foundation.PSTR, pattern: POINTER(UInt16), patternLength: Int32, source: POINTER(UInt16), sourceLength: Int32, ap: POINTER(SByte), parseError: POINTER(win32more.Windows.Win32.Globalization.UParseError), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def umsg_open(pattern: POINTER(UInt16), patternLength: Int32, locale: win32more.Windows.Win32.Foundation.PSTR, parseError: POINTER(win32more.Windows.Win32.Globalization.UParseError), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def umsg_close(format: POINTER(VoidPtr)) -> Void: ...
@cfunctype('icuin.dll')
def umsg_clone(fmt: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> VoidPtr: ...
@cfunctype('icuin.dll')
def umsg_setLocale(fmt: POINTER(VoidPtr), locale: win32more.Windows.Win32.Foundation.PSTR) -> Void: ...
@cfunctype('icuin.dll')
def umsg_getLocale(fmt: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuin.dll')
def umsg_applyPattern(fmt: POINTER(VoidPtr), pattern: POINTER(UInt16), patternLength: Int32, parseError: POINTER(win32more.Windows.Win32.Globalization.UParseError), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def umsg_toPattern(fmt: POINTER(VoidPtr), result: POINTER(UInt16), resultLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll', variadic=True)
def umsg_format(fmt: POINTER(VoidPtr), result: POINTER(UInt16), resultLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode), *__arglist) -> Int32: ...
@cfunctype('icuin.dll')
def umsg_vformat(fmt: POINTER(VoidPtr), result: POINTER(UInt16), resultLength: Int32, ap: POINTER(SByte), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll', variadic=True)
def umsg_parse(fmt: POINTER(VoidPtr), source: POINTER(UInt16), sourceLength: Int32, count: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode), *__arglist) -> Void: ...
@cfunctype('icuin.dll')
def umsg_vparse(fmt: POINTER(VoidPtr), source: POINTER(UInt16), sourceLength: Int32, count: POINTER(Int32), ap: POINTER(SByte), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def umsg_autoQuoteApostrophe(pattern: POINTER(UInt16), patternLength: Int32, dest: POINTER(UInt16), destCapacity: Int32, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def unum_open(style: win32more.Windows.Win32.Globalization.UNumberFormatStyle, pattern: POINTER(UInt16), patternLength: Int32, locale: win32more.Windows.Win32.Foundation.PSTR, parseErr: POINTER(win32more.Windows.Win32.Globalization.UParseError), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def unum_close(fmt: POINTER(VoidPtr)) -> Void: ...
@cfunctype('icuin.dll')
def unum_clone(fmt: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def unum_format(fmt: POINTER(VoidPtr), number: Int32, result: POINTER(UInt16), resultLength: Int32, pos: POINTER(win32more.Windows.Win32.Globalization.UFieldPosition), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def unum_formatInt64(fmt: POINTER(VoidPtr), number: Int64, result: POINTER(UInt16), resultLength: Int32, pos: POINTER(win32more.Windows.Win32.Globalization.UFieldPosition), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def unum_formatDouble(fmt: POINTER(VoidPtr), number: Double, result: POINTER(UInt16), resultLength: Int32, pos: POINTER(win32more.Windows.Win32.Globalization.UFieldPosition), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def unum_formatDoubleForFields(format: POINTER(VoidPtr), number: Double, result: POINTER(UInt16), resultLength: Int32, fpositer: POINTER(win32more.Windows.Win32.Globalization.UFieldPositionIterator), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def unum_formatDecimal(fmt: POINTER(VoidPtr), number: win32more.Windows.Win32.Foundation.PSTR, length: Int32, result: POINTER(UInt16), resultLength: Int32, pos: POINTER(win32more.Windows.Win32.Globalization.UFieldPosition), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def unum_formatDoubleCurrency(fmt: POINTER(VoidPtr), number: Double, currency: POINTER(UInt16), result: POINTER(UInt16), resultLength: Int32, pos: POINTER(win32more.Windows.Win32.Globalization.UFieldPosition), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def unum_formatUFormattable(fmt: POINTER(VoidPtr), number: POINTER(VoidPtr), result: POINTER(UInt16), resultLength: Int32, pos: POINTER(win32more.Windows.Win32.Globalization.UFieldPosition), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def unum_parse(fmt: POINTER(VoidPtr), text: POINTER(UInt16), textLength: Int32, parsePos: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def unum_parseInt64(fmt: POINTER(VoidPtr), text: POINTER(UInt16), textLength: Int32, parsePos: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int64: ...
@cfunctype('icuin.dll')
def unum_parseDouble(fmt: POINTER(VoidPtr), text: POINTER(UInt16), textLength: Int32, parsePos: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Double: ...
@cfunctype('icuin.dll')
def unum_parseDecimal(fmt: POINTER(VoidPtr), text: POINTER(UInt16), textLength: Int32, parsePos: POINTER(Int32), outBuf: win32more.Windows.Win32.Foundation.PSTR, outBufLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def unum_parseDoubleCurrency(fmt: POINTER(VoidPtr), text: POINTER(UInt16), textLength: Int32, parsePos: POINTER(Int32), currency: POINTER(UInt16), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Double: ...
@cfunctype('icuin.dll')
def unum_parseToUFormattable(fmt: POINTER(VoidPtr), result: POINTER(VoidPtr), text: POINTER(UInt16), textLength: Int32, parsePos: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def unum_applyPattern(format: POINTER(VoidPtr), localized: SByte, pattern: POINTER(UInt16), patternLength: Int32, parseError: POINTER(win32more.Windows.Win32.Globalization.UParseError), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def unum_getAvailable(localeIndex: Int32) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuin.dll')
def unum_countAvailable() -> Int32: ...
@cfunctype('icuin.dll')
def unum_getAttribute(fmt: POINTER(VoidPtr), attr: win32more.Windows.Win32.Globalization.UNumberFormatAttribute) -> Int32: ...
@cfunctype('icuin.dll')
def unum_setAttribute(fmt: POINTER(VoidPtr), attr: win32more.Windows.Win32.Globalization.UNumberFormatAttribute, newValue: Int32) -> Void: ...
@cfunctype('icuin.dll')
def unum_getDoubleAttribute(fmt: POINTER(VoidPtr), attr: win32more.Windows.Win32.Globalization.UNumberFormatAttribute) -> Double: ...
@cfunctype('icuin.dll')
def unum_setDoubleAttribute(fmt: POINTER(VoidPtr), attr: win32more.Windows.Win32.Globalization.UNumberFormatAttribute, newValue: Double) -> Void: ...
@cfunctype('icuin.dll')
def unum_getTextAttribute(fmt: POINTER(VoidPtr), tag: win32more.Windows.Win32.Globalization.UNumberFormatTextAttribute, result: POINTER(UInt16), resultLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def unum_setTextAttribute(fmt: POINTER(VoidPtr), tag: win32more.Windows.Win32.Globalization.UNumberFormatTextAttribute, newValue: POINTER(UInt16), newValueLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def unum_toPattern(fmt: POINTER(VoidPtr), isPatternLocalized: SByte, result: POINTER(UInt16), resultLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def unum_getSymbol(fmt: POINTER(VoidPtr), symbol: win32more.Windows.Win32.Globalization.UNumberFormatSymbol, buffer: POINTER(UInt16), size: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def unum_setSymbol(fmt: POINTER(VoidPtr), symbol: win32more.Windows.Win32.Globalization.UNumberFormatSymbol, value: POINTER(UInt16), length: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def unum_getLocaleByType(fmt: POINTER(VoidPtr), type: win32more.Windows.Win32.Globalization.ULocDataLocaleType, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuin.dll')
def unum_setContext(fmt: POINTER(VoidPtr), value: win32more.Windows.Win32.Globalization.UDisplayContext, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def unum_getContext(fmt: POINTER(VoidPtr), type: win32more.Windows.Win32.Globalization.UDisplayContextType, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Globalization.UDisplayContext: ...
@cfunctype('icuin.dll')
def udat_toCalendarDateField(field: win32more.Windows.Win32.Globalization.UDateFormatField) -> win32more.Windows.Win32.Globalization.UCalendarDateFields: ...
@cfunctype('icuin.dll')
def udat_open(timeStyle: win32more.Windows.Win32.Globalization.UDateFormatStyle, dateStyle: win32more.Windows.Win32.Globalization.UDateFormatStyle, locale: win32more.Windows.Win32.Foundation.PSTR, tzID: POINTER(UInt16), tzIDLength: Int32, pattern: POINTER(UInt16), patternLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def udat_close(format: POINTER(VoidPtr)) -> Void: ...
@cfunctype('icuin.dll')
def udat_getBooleanAttribute(fmt: POINTER(VoidPtr), attr: win32more.Windows.Win32.Globalization.UDateFormatBooleanAttribute, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuin.dll')
def udat_setBooleanAttribute(fmt: POINTER(VoidPtr), attr: win32more.Windows.Win32.Globalization.UDateFormatBooleanAttribute, newValue: SByte, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def udat_clone(fmt: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def udat_format(format: POINTER(VoidPtr), dateToFormat: Double, result: POINTER(UInt16), resultLength: Int32, position: POINTER(win32more.Windows.Win32.Globalization.UFieldPosition), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def udat_formatCalendar(format: POINTER(VoidPtr), calendar: POINTER(VoidPtr), result: POINTER(UInt16), capacity: Int32, position: POINTER(win32more.Windows.Win32.Globalization.UFieldPosition), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def udat_formatForFields(format: POINTER(VoidPtr), dateToFormat: Double, result: POINTER(UInt16), resultLength: Int32, fpositer: POINTER(win32more.Windows.Win32.Globalization.UFieldPositionIterator), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def udat_formatCalendarForFields(format: POINTER(VoidPtr), calendar: POINTER(VoidPtr), result: POINTER(UInt16), capacity: Int32, fpositer: POINTER(win32more.Windows.Win32.Globalization.UFieldPositionIterator), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def udat_parse(format: POINTER(VoidPtr), text: POINTER(UInt16), textLength: Int32, parsePos: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Double: ...
@cfunctype('icuin.dll')
def udat_parseCalendar(format: POINTER(VoidPtr), calendar: POINTER(VoidPtr), text: POINTER(UInt16), textLength: Int32, parsePos: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def udat_isLenient(fmt: POINTER(VoidPtr)) -> SByte: ...
@cfunctype('icuin.dll')
def udat_setLenient(fmt: POINTER(VoidPtr), isLenient: SByte) -> Void: ...
@cfunctype('icuin.dll')
def udat_getCalendar(fmt: POINTER(VoidPtr)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def udat_setCalendar(fmt: POINTER(VoidPtr), calendarToSet: POINTER(VoidPtr)) -> Void: ...
@cfunctype('icuin.dll')
def udat_getNumberFormat(fmt: POINTER(VoidPtr)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def udat_getNumberFormatForField(fmt: POINTER(VoidPtr), field: UInt16) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def udat_adoptNumberFormatForFields(fmt: POINTER(VoidPtr), fields: POINTER(UInt16), numberFormatToSet: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def udat_setNumberFormat(fmt: POINTER(VoidPtr), numberFormatToSet: POINTER(VoidPtr)) -> Void: ...
@cfunctype('icuin.dll')
def udat_adoptNumberFormat(fmt: POINTER(VoidPtr), numberFormatToAdopt: POINTER(VoidPtr)) -> Void: ...
@cfunctype('icuin.dll')
def udat_getAvailable(localeIndex: Int32) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuin.dll')
def udat_countAvailable() -> Int32: ...
@cfunctype('icuin.dll')
def udat_get2DigitYearStart(fmt: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Double: ...
@cfunctype('icuin.dll')
def udat_set2DigitYearStart(fmt: POINTER(VoidPtr), d: Double, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def udat_toPattern(fmt: POINTER(VoidPtr), localized: SByte, result: POINTER(UInt16), resultLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def udat_applyPattern(format: POINTER(VoidPtr), localized: SByte, pattern: POINTER(UInt16), patternLength: Int32) -> Void: ...
@cfunctype('icuin.dll')
def udat_getSymbols(fmt: POINTER(VoidPtr), type: win32more.Windows.Win32.Globalization.UDateFormatSymbolType, symbolIndex: Int32, result: POINTER(UInt16), resultLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def udat_countSymbols(fmt: POINTER(VoidPtr), type: win32more.Windows.Win32.Globalization.UDateFormatSymbolType) -> Int32: ...
@cfunctype('icuin.dll')
def udat_setSymbols(format: POINTER(VoidPtr), type: win32more.Windows.Win32.Globalization.UDateFormatSymbolType, symbolIndex: Int32, value: POINTER(UInt16), valueLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def udat_getLocaleByType(fmt: POINTER(VoidPtr), type: win32more.Windows.Win32.Globalization.ULocDataLocaleType, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuin.dll')
def udat_setContext(fmt: POINTER(VoidPtr), value: win32more.Windows.Win32.Globalization.UDisplayContext, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def udat_getContext(fmt: POINTER(VoidPtr), type: win32more.Windows.Win32.Globalization.UDisplayContextType, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Globalization.UDisplayContext: ...
@cfunctype('icuin.dll')
def udatpg_open(locale: win32more.Windows.Win32.Foundation.PSTR, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def udatpg_openEmpty(pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def udatpg_close(dtpg: POINTER(VoidPtr)) -> Void: ...
@cfunctype('icuin.dll')
def udatpg_clone(dtpg: POINTER(VoidPtr), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def udatpg_getBestPattern(dtpg: POINTER(VoidPtr), skeleton: POINTER(UInt16), length: Int32, bestPattern: POINTER(UInt16), capacity: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def udatpg_getBestPatternWithOptions(dtpg: POINTER(VoidPtr), skeleton: POINTER(UInt16), length: Int32, options: win32more.Windows.Win32.Globalization.UDateTimePatternMatchOptions, bestPattern: POINTER(UInt16), capacity: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def udatpg_getSkeleton(unusedDtpg: POINTER(VoidPtr), pattern: POINTER(UInt16), length: Int32, skeleton: POINTER(UInt16), capacity: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def udatpg_getBaseSkeleton(unusedDtpg: POINTER(VoidPtr), pattern: POINTER(UInt16), length: Int32, baseSkeleton: POINTER(UInt16), capacity: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def udatpg_addPattern(dtpg: POINTER(VoidPtr), pattern: POINTER(UInt16), patternLength: Int32, override: SByte, conflictingPattern: POINTER(UInt16), capacity: Int32, pLength: POINTER(Int32), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Globalization.UDateTimePatternConflict: ...
@cfunctype('icuin.dll')
def udatpg_setAppendItemFormat(dtpg: POINTER(VoidPtr), field: win32more.Windows.Win32.Globalization.UDateTimePatternField, value: POINTER(UInt16), length: Int32) -> Void: ...
@cfunctype('icuin.dll')
def udatpg_getAppendItemFormat(dtpg: POINTER(VoidPtr), field: win32more.Windows.Win32.Globalization.UDateTimePatternField, pLength: POINTER(Int32)) -> POINTER(UInt16): ...
@cfunctype('icuin.dll')
def udatpg_setAppendItemName(dtpg: POINTER(VoidPtr), field: win32more.Windows.Win32.Globalization.UDateTimePatternField, value: POINTER(UInt16), length: Int32) -> Void: ...
@cfunctype('icuin.dll')
def udatpg_getAppendItemName(dtpg: POINTER(VoidPtr), field: win32more.Windows.Win32.Globalization.UDateTimePatternField, pLength: POINTER(Int32)) -> POINTER(UInt16): ...
@cfunctype('icu.dll')
def udatpg_getFieldDisplayName(dtpg: POINTER(VoidPtr), field: win32more.Windows.Win32.Globalization.UDateTimePatternField, width: win32more.Windows.Win32.Globalization.UDateTimePGDisplayWidth, fieldName: POINTER(UInt16), capacity: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def udatpg_setDateTimeFormat(dtpg: POINTER(VoidPtr), dtFormat: POINTER(UInt16), length: Int32) -> Void: ...
@cfunctype('icuin.dll')
def udatpg_getDateTimeFormat(dtpg: POINTER(VoidPtr), pLength: POINTER(Int32)) -> POINTER(UInt16): ...
@cfunctype('icuin.dll')
def udatpg_setDecimal(dtpg: POINTER(VoidPtr), decimal: POINTER(UInt16), length: Int32) -> Void: ...
@cfunctype('icuin.dll')
def udatpg_getDecimal(dtpg: POINTER(VoidPtr), pLength: POINTER(Int32)) -> POINTER(UInt16): ...
@cfunctype('icuin.dll')
def udatpg_replaceFieldTypes(dtpg: POINTER(VoidPtr), pattern: POINTER(UInt16), patternLength: Int32, skeleton: POINTER(UInt16), skeletonLength: Int32, dest: POINTER(UInt16), destCapacity: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def udatpg_replaceFieldTypesWithOptions(dtpg: POINTER(VoidPtr), pattern: POINTER(UInt16), patternLength: Int32, skeleton: POINTER(UInt16), skeletonLength: Int32, options: win32more.Windows.Win32.Globalization.UDateTimePatternMatchOptions, dest: POINTER(UInt16), destCapacity: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def udatpg_openSkeletons(dtpg: POINTER(VoidPtr), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def udatpg_openBaseSkeletons(dtpg: POINTER(VoidPtr), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def udatpg_getPatternForSkeleton(dtpg: POINTER(VoidPtr), skeleton: POINTER(UInt16), skeletonLength: Int32, pLength: POINTER(Int32)) -> POINTER(UInt16): ...
@cfunctype('icu.dll')
def unumf_openForSkeletonAndLocale(skeleton: POINTER(UInt16), skeletonLen: Int32, locale: win32more.Windows.Win32.Foundation.PSTR, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UNumberFormatter): ...
@cfunctype('icu.dll')
def unumf_openForSkeletonAndLocaleWithError(skeleton: POINTER(UInt16), skeletonLen: Int32, locale: win32more.Windows.Win32.Foundation.PSTR, perror: POINTER(win32more.Windows.Win32.Globalization.UParseError), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UNumberFormatter): ...
@cfunctype('icu.dll')
def unumf_openResult(ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UFormattedNumber): ...
@cfunctype('icu.dll')
def unumf_formatInt(uformatter: POINTER(win32more.Windows.Win32.Globalization.UNumberFormatter), value: Int64, uresult: POINTER(win32more.Windows.Win32.Globalization.UFormattedNumber), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icu.dll')
def unumf_formatDouble(uformatter: POINTER(win32more.Windows.Win32.Globalization.UNumberFormatter), value: Double, uresult: POINTER(win32more.Windows.Win32.Globalization.UFormattedNumber), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icu.dll')
def unumf_formatDecimal(uformatter: POINTER(win32more.Windows.Win32.Globalization.UNumberFormatter), value: win32more.Windows.Win32.Foundation.PSTR, valueLen: Int32, uresult: POINTER(win32more.Windows.Win32.Globalization.UFormattedNumber), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icu.dll')
def unumf_resultAsValue(uresult: POINTER(win32more.Windows.Win32.Globalization.UFormattedNumber), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UFormattedValue): ...
@cfunctype('icu.dll')
def unumf_resultToString(uresult: POINTER(win32more.Windows.Win32.Globalization.UFormattedNumber), buffer: POINTER(UInt16), bufferCapacity: Int32, ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icu.dll')
def unumf_resultNextFieldPosition(uresult: POINTER(win32more.Windows.Win32.Globalization.UFormattedNumber), ufpos: POINTER(win32more.Windows.Win32.Globalization.UFieldPosition), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icu.dll')
def unumf_resultGetAllFieldPositions(uresult: POINTER(win32more.Windows.Win32.Globalization.UFormattedNumber), ufpositer: POINTER(win32more.Windows.Win32.Globalization.UFieldPositionIterator), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icu.dll')
def unumf_close(uformatter: POINTER(win32more.Windows.Win32.Globalization.UNumberFormatter)) -> Void: ...
@cfunctype('icu.dll')
def unumf_closeResult(uresult: POINTER(win32more.Windows.Win32.Globalization.UFormattedNumber)) -> Void: ...
@cfunctype('icuin.dll')
def unumsys_open(locale: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UNumberingSystem): ...
@cfunctype('icuin.dll')
def unumsys_openByName(name: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UNumberingSystem): ...
@cfunctype('icuin.dll')
def unumsys_close(unumsys: POINTER(win32more.Windows.Win32.Globalization.UNumberingSystem)) -> Void: ...
@cfunctype('icuin.dll')
def unumsys_openAvailableNames(status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def unumsys_getName(unumsys: POINTER(win32more.Windows.Win32.Globalization.UNumberingSystem)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuin.dll')
def unumsys_isAlgorithmic(unumsys: POINTER(win32more.Windows.Win32.Globalization.UNumberingSystem)) -> SByte: ...
@cfunctype('icuin.dll')
def unumsys_getRadix(unumsys: POINTER(win32more.Windows.Win32.Globalization.UNumberingSystem)) -> Int32: ...
@cfunctype('icuin.dll')
def unumsys_getDescription(unumsys: POINTER(win32more.Windows.Win32.Globalization.UNumberingSystem), result: POINTER(UInt16), resultLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uplrules_open(locale: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UPluralRules): ...
@cfunctype('icuin.dll')
def uplrules_openForType(locale: win32more.Windows.Win32.Foundation.PSTR, type: win32more.Windows.Win32.Globalization.UPluralType, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UPluralRules): ...
@cfunctype('icuin.dll')
def uplrules_close(uplrules: POINTER(win32more.Windows.Win32.Globalization.UPluralRules)) -> Void: ...
@cfunctype('icuin.dll')
def uplrules_select(uplrules: POINTER(win32more.Windows.Win32.Globalization.UPluralRules), number: Double, keyword: POINTER(UInt16), capacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icu.dll')
def uplrules_selectFormatted(uplrules: POINTER(win32more.Windows.Win32.Globalization.UPluralRules), number: POINTER(win32more.Windows.Win32.Globalization.UFormattedNumber), keyword: POINTER(UInt16), capacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uplrules_getKeywords(uplrules: POINTER(win32more.Windows.Win32.Globalization.UPluralRules), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def uregex_open(pattern: POINTER(UInt16), patternLength: Int32, flags: UInt32, pe: POINTER(win32more.Windows.Win32.Globalization.UParseError), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.URegularExpression): ...
@cfunctype('icuin.dll')
def uregex_openUText(pattern: POINTER(win32more.Windows.Win32.Globalization.UText), flags: UInt32, pe: POINTER(win32more.Windows.Win32.Globalization.UParseError), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.URegularExpression): ...
@cfunctype('icuin.dll')
def uregex_openC(pattern: win32more.Windows.Win32.Foundation.PSTR, flags: UInt32, pe: POINTER(win32more.Windows.Win32.Globalization.UParseError), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.URegularExpression): ...
@cfunctype('icuin.dll')
def uregex_close(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression)) -> Void: ...
@cfunctype('icuin.dll')
def uregex_clone(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.URegularExpression): ...
@cfunctype('icuin.dll')
def uregex_pattern(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), patLength: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuin.dll')
def uregex_patternUText(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UText): ...
@cfunctype('icuin.dll')
def uregex_flags(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uregex_setText(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), text: POINTER(UInt16), textLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uregex_setUText(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), text: POINTER(win32more.Windows.Win32.Globalization.UText), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uregex_getText(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), textLength: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(UInt16): ...
@cfunctype('icuin.dll')
def uregex_getUText(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), dest: POINTER(win32more.Windows.Win32.Globalization.UText), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UText): ...
@cfunctype('icuin.dll')
def uregex_refreshUText(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), text: POINTER(win32more.Windows.Win32.Globalization.UText), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uregex_matches(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), startIndex: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuin.dll')
def uregex_matches64(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), startIndex: Int64, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuin.dll')
def uregex_lookingAt(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), startIndex: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuin.dll')
def uregex_lookingAt64(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), startIndex: Int64, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuin.dll')
def uregex_find(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), startIndex: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuin.dll')
def uregex_find64(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), startIndex: Int64, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuin.dll')
def uregex_findNext(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuin.dll')
def uregex_groupCount(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uregex_groupNumberFromName(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), groupName: POINTER(UInt16), nameLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uregex_groupNumberFromCName(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), groupName: win32more.Windows.Win32.Foundation.PSTR, nameLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uregex_group(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), groupNum: Int32, dest: POINTER(UInt16), destCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uregex_groupUText(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), groupNum: Int32, dest: POINTER(win32more.Windows.Win32.Globalization.UText), groupLength: POINTER(Int64), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UText): ...
@cfunctype('icuin.dll')
def uregex_start(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), groupNum: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uregex_start64(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), groupNum: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int64: ...
@cfunctype('icuin.dll')
def uregex_end(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), groupNum: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uregex_end64(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), groupNum: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int64: ...
@cfunctype('icuin.dll')
def uregex_reset(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), index: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uregex_reset64(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), index: Int64, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uregex_setRegion(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), regionStart: Int32, regionLimit: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uregex_setRegion64(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), regionStart: Int64, regionLimit: Int64, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uregex_setRegionAndStart(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), regionStart: Int64, regionLimit: Int64, startIndex: Int64, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uregex_regionStart(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uregex_regionStart64(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int64: ...
@cfunctype('icuin.dll')
def uregex_regionEnd(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uregex_regionEnd64(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int64: ...
@cfunctype('icuin.dll')
def uregex_hasTransparentBounds(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuin.dll')
def uregex_useTransparentBounds(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), b: SByte, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uregex_hasAnchoringBounds(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuin.dll')
def uregex_useAnchoringBounds(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), b: SByte, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uregex_hitEnd(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuin.dll')
def uregex_requireEnd(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> SByte: ...
@cfunctype('icuin.dll')
def uregex_replaceAll(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), replacementText: POINTER(UInt16), replacementLength: Int32, destBuf: POINTER(UInt16), destCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uregex_replaceAllUText(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), replacement: POINTER(win32more.Windows.Win32.Globalization.UText), dest: POINTER(win32more.Windows.Win32.Globalization.UText), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UText): ...
@cfunctype('icuin.dll')
def uregex_replaceFirst(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), replacementText: POINTER(UInt16), replacementLength: Int32, destBuf: POINTER(UInt16), destCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uregex_replaceFirstUText(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), replacement: POINTER(win32more.Windows.Win32.Globalization.UText), dest: POINTER(win32more.Windows.Win32.Globalization.UText), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UText): ...
@cfunctype('icuin.dll')
def uregex_appendReplacement(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), replacementText: POINTER(UInt16), replacementLength: Int32, destBuf: POINTER(POINTER(UInt16)), destCapacity: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uregex_appendReplacementUText(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), replacementText: POINTER(win32more.Windows.Win32.Globalization.UText), dest: POINTER(win32more.Windows.Win32.Globalization.UText), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uregex_appendTail(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), destBuf: POINTER(POINTER(UInt16)), destCapacity: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uregex_appendTailUText(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), dest: POINTER(win32more.Windows.Win32.Globalization.UText), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UText): ...
@cfunctype('icuin.dll')
def uregex_split(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), destBuf: POINTER(UInt16), destCapacity: Int32, requiredCapacity: POINTER(Int32), destFields: POINTER(POINTER(UInt16)), destFieldsCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uregex_splitUText(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), destFields: POINTER(POINTER(win32more.Windows.Win32.Globalization.UText)), destFieldsCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uregex_setTimeLimit(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), limit: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uregex_getTimeLimit(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uregex_setStackLimit(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), limit: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uregex_getStackLimit(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uregex_setMatchCallback(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), callback: win32more.Windows.Win32.Globalization.URegexMatchCallback, context: VoidPtr, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uregex_getMatchCallback(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), callback: POINTER(win32more.Windows.Win32.Globalization.URegexMatchCallback), context: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uregex_setFindProgressCallback(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), callback: win32more.Windows.Win32.Globalization.URegexFindProgressCallback, context: VoidPtr, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uregex_getFindProgressCallback(regexp: POINTER(win32more.Windows.Win32.Globalization.URegularExpression), callback: POINTER(win32more.Windows.Win32.Globalization.URegexFindProgressCallback), context: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uregion_getRegionFromCode(regionCode: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.URegion): ...
@cfunctype('icuin.dll')
def uregion_getRegionFromNumericCode(code: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.URegion): ...
@cfunctype('icuin.dll')
def uregion_getAvailable(type: win32more.Windows.Win32.Globalization.URegionType, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def uregion_areEqual(uregion: POINTER(win32more.Windows.Win32.Globalization.URegion), otherRegion: POINTER(win32more.Windows.Win32.Globalization.URegion)) -> SByte: ...
@cfunctype('icuin.dll')
def uregion_getContainingRegion(uregion: POINTER(win32more.Windows.Win32.Globalization.URegion)) -> POINTER(win32more.Windows.Win32.Globalization.URegion): ...
@cfunctype('icuin.dll')
def uregion_getContainingRegionOfType(uregion: POINTER(win32more.Windows.Win32.Globalization.URegion), type: win32more.Windows.Win32.Globalization.URegionType) -> POINTER(win32more.Windows.Win32.Globalization.URegion): ...
@cfunctype('icuin.dll')
def uregion_getContainedRegions(uregion: POINTER(win32more.Windows.Win32.Globalization.URegion), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def uregion_getContainedRegionsOfType(uregion: POINTER(win32more.Windows.Win32.Globalization.URegion), type: win32more.Windows.Win32.Globalization.URegionType, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def uregion_contains(uregion: POINTER(win32more.Windows.Win32.Globalization.URegion), otherRegion: POINTER(win32more.Windows.Win32.Globalization.URegion)) -> SByte: ...
@cfunctype('icuin.dll')
def uregion_getPreferredValues(uregion: POINTER(win32more.Windows.Win32.Globalization.URegion), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def uregion_getRegionCode(uregion: POINTER(win32more.Windows.Win32.Globalization.URegion)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuin.dll')
def uregion_getNumericCode(uregion: POINTER(win32more.Windows.Win32.Globalization.URegion)) -> Int32: ...
@cfunctype('icuin.dll')
def uregion_getType(uregion: POINTER(win32more.Windows.Win32.Globalization.URegion)) -> win32more.Windows.Win32.Globalization.URegionType: ...
@cfunctype('icuin.dll')
def ureldatefmt_open(locale: win32more.Windows.Win32.Foundation.PSTR, nfToAdopt: POINTER(VoidPtr), width: win32more.Windows.Win32.Globalization.UDateRelativeDateTimeFormatterStyle, capitalizationContext: win32more.Windows.Win32.Globalization.UDisplayContext, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.URelativeDateTimeFormatter): ...
@cfunctype('icuin.dll')
def ureldatefmt_close(reldatefmt: POINTER(win32more.Windows.Win32.Globalization.URelativeDateTimeFormatter)) -> Void: ...
@cfunctype('icu.dll')
def ureldatefmt_openResult(ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UFormattedRelativeDateTime): ...
@cfunctype('icu.dll')
def ureldatefmt_resultAsValue(ufrdt: POINTER(win32more.Windows.Win32.Globalization.UFormattedRelativeDateTime), ec: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UFormattedValue): ...
@cfunctype('icu.dll')
def ureldatefmt_closeResult(ufrdt: POINTER(win32more.Windows.Win32.Globalization.UFormattedRelativeDateTime)) -> Void: ...
@cfunctype('icuin.dll')
def ureldatefmt_formatNumeric(reldatefmt: POINTER(win32more.Windows.Win32.Globalization.URelativeDateTimeFormatter), offset: Double, unit: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit, result: POINTER(UInt16), resultCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icu.dll')
def ureldatefmt_formatNumericToResult(reldatefmt: POINTER(win32more.Windows.Win32.Globalization.URelativeDateTimeFormatter), offset: Double, unit: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit, result: POINTER(win32more.Windows.Win32.Globalization.UFormattedRelativeDateTime), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ureldatefmt_format(reldatefmt: POINTER(win32more.Windows.Win32.Globalization.URelativeDateTimeFormatter), offset: Double, unit: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit, result: POINTER(UInt16), resultCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icu.dll')
def ureldatefmt_formatToResult(reldatefmt: POINTER(win32more.Windows.Win32.Globalization.URelativeDateTimeFormatter), offset: Double, unit: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit, result: POINTER(win32more.Windows.Win32.Globalization.UFormattedRelativeDateTime), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def ureldatefmt_combineDateAndTime(reldatefmt: POINTER(win32more.Windows.Win32.Globalization.URelativeDateTimeFormatter), relativeDateString: POINTER(UInt16), relativeDateStringLen: Int32, timeString: POINTER(UInt16), timeStringLen: Int32, result: POINTER(UInt16), resultCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def usearch_open(pattern: POINTER(UInt16), patternlength: Int32, text: POINTER(UInt16), textlength: Int32, locale: win32more.Windows.Win32.Foundation.PSTR, breakiter: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UStringSearch): ...
@cfunctype('icuin.dll')
def usearch_openFromCollator(pattern: POINTER(UInt16), patternlength: Int32, text: POINTER(UInt16), textlength: Int32, collator: POINTER(win32more.Windows.Win32.Globalization.UCollator), breakiter: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UStringSearch): ...
@cfunctype('icuin.dll')
def usearch_close(searchiter: POINTER(win32more.Windows.Win32.Globalization.UStringSearch)) -> Void: ...
@cfunctype('icuin.dll')
def usearch_setOffset(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch), position: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def usearch_getOffset(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch)) -> Int32: ...
@cfunctype('icuin.dll')
def usearch_setAttribute(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch), attribute: win32more.Windows.Win32.Globalization.USearchAttribute, value: win32more.Windows.Win32.Globalization.USearchAttributeValue, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def usearch_getAttribute(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch), attribute: win32more.Windows.Win32.Globalization.USearchAttribute) -> win32more.Windows.Win32.Globalization.USearchAttributeValue: ...
@cfunctype('icuin.dll')
def usearch_getMatchedStart(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch)) -> Int32: ...
@cfunctype('icuin.dll')
def usearch_getMatchedLength(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch)) -> Int32: ...
@cfunctype('icuin.dll')
def usearch_getMatchedText(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch), result: POINTER(UInt16), resultCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def usearch_setBreakIterator(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch), breakiter: POINTER(win32more.Windows.Win32.Globalization.UBreakIterator), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def usearch_getBreakIterator(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch)) -> POINTER(win32more.Windows.Win32.Globalization.UBreakIterator): ...
@cfunctype('icuin.dll')
def usearch_setText(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch), text: POINTER(UInt16), textlength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def usearch_getText(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch), length: POINTER(Int32)) -> POINTER(UInt16): ...
@cfunctype('icuin.dll')
def usearch_getCollator(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch)) -> POINTER(win32more.Windows.Win32.Globalization.UCollator): ...
@cfunctype('icuin.dll')
def usearch_setCollator(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch), collator: POINTER(win32more.Windows.Win32.Globalization.UCollator), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def usearch_setPattern(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch), pattern: POINTER(UInt16), patternlength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def usearch_getPattern(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch), length: POINTER(Int32)) -> POINTER(UInt16): ...
@cfunctype('icuin.dll')
def usearch_first(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def usearch_following(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch), position: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def usearch_last(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def usearch_preceding(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch), position: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def usearch_next(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def usearch_previous(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def usearch_reset(strsrch: POINTER(win32more.Windows.Win32.Globalization.UStringSearch)) -> Void: ...
@cfunctype('icuin.dll')
def uspoof_open(status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.USpoofChecker): ...
@cfunctype('icuin.dll')
def uspoof_openFromSerialized(data: VoidPtr, length: Int32, pActualLength: POINTER(Int32), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.USpoofChecker): ...
@cfunctype('icuin.dll')
def uspoof_openFromSource(confusables: win32more.Windows.Win32.Foundation.PSTR, confusablesLen: Int32, confusablesWholeScript: win32more.Windows.Win32.Foundation.PSTR, confusablesWholeScriptLen: Int32, errType: POINTER(Int32), pe: POINTER(win32more.Windows.Win32.Globalization.UParseError), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.USpoofChecker): ...
@cfunctype('icuin.dll')
def uspoof_close(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker)) -> Void: ...
@cfunctype('icuin.dll')
def uspoof_clone(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.USpoofChecker): ...
@cfunctype('icuin.dll')
def uspoof_setChecks(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker), checks: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uspoof_getChecks(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uspoof_setRestrictionLevel(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker), restrictionLevel: win32more.Windows.Win32.Globalization.URestrictionLevel) -> Void: ...
@cfunctype('icuin.dll')
def uspoof_getRestrictionLevel(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker)) -> win32more.Windows.Win32.Globalization.URestrictionLevel: ...
@cfunctype('icuin.dll')
def uspoof_setAllowedLocales(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker), localesList: win32more.Windows.Win32.Foundation.PSTR, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uspoof_getAllowedLocales(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@cfunctype('icuin.dll')
def uspoof_setAllowedChars(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker), chars: POINTER(win32more.Windows.Win32.Globalization.USet), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def uspoof_getAllowedChars(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.USet): ...
@cfunctype('icuin.dll')
def uspoof_check(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker), id: POINTER(UInt16), length: Int32, position: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uspoof_checkUTF8(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker), id: win32more.Windows.Win32.Foundation.PSTR, length: Int32, position: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uspoof_check2(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker), id: POINTER(UInt16), length: Int32, checkResult: POINTER(win32more.Windows.Win32.Globalization.USpoofCheckResult), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uspoof_check2UTF8(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker), id: win32more.Windows.Win32.Foundation.PSTR, length: Int32, checkResult: POINTER(win32more.Windows.Win32.Globalization.USpoofCheckResult), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uspoof_openCheckResult(status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.USpoofCheckResult): ...
@cfunctype('icuin.dll')
def uspoof_closeCheckResult(checkResult: POINTER(win32more.Windows.Win32.Globalization.USpoofCheckResult)) -> Void: ...
@cfunctype('icuin.dll')
def uspoof_getCheckResultChecks(checkResult: POINTER(win32more.Windows.Win32.Globalization.USpoofCheckResult), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uspoof_getCheckResultRestrictionLevel(checkResult: POINTER(win32more.Windows.Win32.Globalization.USpoofCheckResult), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> win32more.Windows.Win32.Globalization.URestrictionLevel: ...
@cfunctype('icuin.dll')
def uspoof_getCheckResultNumerics(checkResult: POINTER(win32more.Windows.Win32.Globalization.USpoofCheckResult), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.USet): ...
@cfunctype('icuin.dll')
def uspoof_areConfusable(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker), id1: POINTER(UInt16), length1: Int32, id2: POINTER(UInt16), length2: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uspoof_areConfusableUTF8(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker), id1: win32more.Windows.Win32.Foundation.PSTR, length1: Int32, id2: win32more.Windows.Win32.Foundation.PSTR, length2: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uspoof_getSkeleton(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker), type: UInt32, id: POINTER(UInt16), length: Int32, dest: POINTER(UInt16), destCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uspoof_getSkeletonUTF8(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker), type: UInt32, id: win32more.Windows.Win32.Foundation.PSTR, length: Int32, dest: win32more.Windows.Win32.Foundation.PSTR, destCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def uspoof_getInclusionSet(status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.USet): ...
@cfunctype('icuin.dll')
def uspoof_getRecommendedSet(status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.USet): ...
@cfunctype('icuin.dll')
def uspoof_serialize(sc: POINTER(win32more.Windows.Win32.Globalization.USpoofChecker), data: VoidPtr, capacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def utmscale_getTimeScaleValue(timeScale: win32more.Windows.Win32.Globalization.UDateTimeScale, value: win32more.Windows.Win32.Globalization.UTimeScaleValue, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int64: ...
@cfunctype('icuin.dll')
def utmscale_fromInt64(otherTime: Int64, timeScale: win32more.Windows.Win32.Globalization.UDateTimeScale, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int64: ...
@cfunctype('icuin.dll')
def utmscale_toInt64(universalTime: Int64, timeScale: win32more.Windows.Win32.Globalization.UDateTimeScale, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int64: ...
@cfunctype('icuin.dll')
def utrans_openU(id: POINTER(UInt16), idLength: Int32, dir: win32more.Windows.Win32.Globalization.UTransDirection, rules: POINTER(UInt16), rulesLength: Int32, parseError: POINTER(win32more.Windows.Win32.Globalization.UParseError), pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def utrans_openInverse(trans: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def utrans_clone(trans: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(VoidPtr): ...
@cfunctype('icuin.dll')
def utrans_close(trans: POINTER(VoidPtr)) -> Void: ...
@cfunctype('icuin.dll')
def utrans_getUnicodeID(trans: POINTER(VoidPtr), resultLength: POINTER(Int32)) -> POINTER(UInt16): ...
@cfunctype('icuin.dll')
def utrans_register(adoptedTrans: POINTER(VoidPtr), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def utrans_unregisterID(id: POINTER(UInt16), idLength: Int32) -> Void: ...
@cfunctype('icuin.dll')
def utrans_setFilter(trans: POINTER(VoidPtr), filterPattern: POINTER(UInt16), filterPatternLen: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def utrans_countAvailableIDs() -> Int32: ...
@cfunctype('icuin.dll')
def utrans_openIDs(pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UEnumeration): ...
@cfunctype('icuin.dll')
def utrans_trans(trans: POINTER(VoidPtr), rep: POINTER(VoidPtr), repFunc: POINTER(win32more.Windows.Win32.Globalization.UReplaceableCallbacks), start: Int32, limit: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def utrans_transIncremental(trans: POINTER(VoidPtr), rep: POINTER(VoidPtr), repFunc: POINTER(win32more.Windows.Win32.Globalization.UReplaceableCallbacks), pos: POINTER(win32more.Windows.Win32.Globalization.UTransPosition), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def utrans_transUChars(trans: POINTER(VoidPtr), text: POINTER(UInt16), textLength: POINTER(Int32), textCapacity: Int32, start: Int32, limit: POINTER(Int32), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def utrans_transIncrementalUChars(trans: POINTER(VoidPtr), text: POINTER(UInt16), textLength: POINTER(Int32), textCapacity: Int32, pos: POINTER(win32more.Windows.Win32.Globalization.UTransPosition), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype('icuin.dll')
def utrans_toRules(trans: POINTER(VoidPtr), escapeUnprintable: SByte, result: POINTER(UInt16), resultLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
@cfunctype('icuin.dll')
def utrans_getSourceSet(trans: POINTER(VoidPtr), ignoreFilter: SByte, fillIn: POINTER(win32more.Windows.Win32.Globalization.USet), status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.USet): ...
@winfunctype('bcp47mrm.dll')
def GetDistanceOfClosestLanguageInList(pszLanguage: win32more.Windows.Win32.Foundation.PWSTR, pszLanguagesList: win32more.Windows.Win32.Foundation.PWSTR, wchListDelimiter: Char, pClosestDistance: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('bcp47mrm.dll')
def IsWellFormedTag(pszTag: win32more.Windows.Win32.Foundation.PWSTR) -> Byte: ...
@winfunctype('KERNEL32.dll')
def GetCalendarSupportedDateRange(Calendar: UInt32, lpCalMinDateTime: POINTER(win32more.Windows.Win32.Globalization.CALDATETIME), lpCalMaxDateTime: POINTER(win32more.Windows.Win32.Globalization.CALDATETIME)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetCalendarDateFormatEx(lpszLocale: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, lpCalDateTime: POINTER(win32more.Windows.Win32.Globalization.CALDATETIME), lpFormat: win32more.Windows.Win32.Foundation.PWSTR, lpDateStr: win32more.Windows.Win32.Foundation.PWSTR, cchDate: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def ConvertSystemTimeToCalDateTime(lpSysTime: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), calId: UInt32, lpCalDateTime: POINTER(win32more.Windows.Win32.Globalization.CALDATETIME)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def UpdateCalendarDayOfWeek(lpCalDateTime: POINTER(win32more.Windows.Win32.Globalization.CALDATETIME)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def AdjustCalendarDate(lpCalDateTime: POINTER(win32more.Windows.Win32.Globalization.CALDATETIME), calUnit: win32more.Windows.Win32.Globalization.CALDATETIME_DATEUNIT, amount: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def ConvertCalDateTimeToSystemTime(lpCalDateTime: POINTER(win32more.Windows.Win32.Globalization.CALDATETIME), lpSysTime: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def IsCalendarLeapYear(calId: UInt32, year: UInt32, era: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def FindStringOrdinal(dwFindStringOrdinalFlags: UInt32, lpStringSource: win32more.Windows.Win32.Foundation.PWSTR, cchSource: Int32, lpStringValue: win32more.Windows.Win32.Foundation.PWSTR, cchValue: Int32, bIgnoreCase: win32more.Windows.Win32.Foundation.BOOL) -> Int32: ...
@winfunctype('KERNEL32.dll')
def lstrcmpA(lpString1: win32more.Windows.Win32.Foundation.PSTR, lpString2: win32more.Windows.Win32.Foundation.PSTR) -> Int32: ...
@winfunctype('KERNEL32.dll')
def lstrcmpW(lpString1: win32more.Windows.Win32.Foundation.PWSTR, lpString2: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
lstrcmp = UnicodeAlias('lstrcmpW')
@winfunctype('KERNEL32.dll')
def lstrcmpiA(lpString1: win32more.Windows.Win32.Foundation.PSTR, lpString2: win32more.Windows.Win32.Foundation.PSTR) -> Int32: ...
@winfunctype('KERNEL32.dll')
def lstrcmpiW(lpString1: win32more.Windows.Win32.Foundation.PWSTR, lpString2: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
lstrcmpi = UnicodeAlias('lstrcmpiW')
@winfunctype('KERNEL32.dll')
def lstrcpynA(lpString1: win32more.Windows.Win32.Foundation.PSTR, lpString2: win32more.Windows.Win32.Foundation.PSTR, iMaxLength: Int32) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('KERNEL32.dll')
def lstrcpynW(lpString1: win32more.Windows.Win32.Foundation.PWSTR, lpString2: win32more.Windows.Win32.Foundation.PWSTR, iMaxLength: Int32) -> win32more.Windows.Win32.Foundation.PWSTR: ...
lstrcpyn = UnicodeAlias('lstrcpynW')
@winfunctype('KERNEL32.dll')
def lstrcpyA(lpString1: win32more.Windows.Win32.Foundation.PSTR, lpString2: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('KERNEL32.dll')
def lstrcpyW(lpString1: win32more.Windows.Win32.Foundation.PWSTR, lpString2: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.PWSTR: ...
lstrcpy = UnicodeAlias('lstrcpyW')
@winfunctype('KERNEL32.dll')
def lstrcatA(lpString1: win32more.Windows.Win32.Foundation.PSTR, lpString2: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('KERNEL32.dll')
def lstrcatW(lpString1: win32more.Windows.Win32.Foundation.PWSTR, lpString2: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.PWSTR: ...
lstrcat = UnicodeAlias('lstrcatW')
@winfunctype('KERNEL32.dll')
def lstrlenA(lpString: win32more.Windows.Win32.Foundation.PSTR) -> Int32: ...
@winfunctype('KERNEL32.dll')
def lstrlenW(lpString: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
lstrlen = UnicodeAlias('lstrlenW')
@winfunctype('ADVAPI32.dll')
def IsTextUnicode(lpv: VoidPtr, iSize: Int32, lpiResult: POINTER(win32more.Windows.Win32.Globalization.IS_TEXT_UNICODE_RESULT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
class CALDATETIME(Structure):
    CalId: UInt32
    Era: UInt32
    Year: UInt32
    Month: UInt32
    Day: UInt32
    DayOfWeek: UInt32
    Hour: UInt32
    Minute: UInt32
    Second: UInt32
    Tick: UInt32
CALDATETIME_DATEUNIT = Int32
EraUnit: win32more.Windows.Win32.Globalization.CALDATETIME_DATEUNIT = 0
YearUnit: win32more.Windows.Win32.Globalization.CALDATETIME_DATEUNIT = 1
MonthUnit: win32more.Windows.Win32.Globalization.CALDATETIME_DATEUNIT = 2
WeekUnit: win32more.Windows.Win32.Globalization.CALDATETIME_DATEUNIT = 3
DayUnit: win32more.Windows.Win32.Globalization.CALDATETIME_DATEUNIT = 4
HourUnit: win32more.Windows.Win32.Globalization.CALDATETIME_DATEUNIT = 5
MinuteUnit: win32more.Windows.Win32.Globalization.CALDATETIME_DATEUNIT = 6
SecondUnit: win32more.Windows.Win32.Globalization.CALDATETIME_DATEUNIT = 7
TickUnit: win32more.Windows.Win32.Globalization.CALDATETIME_DATEUNIT = 8
@winfunctype_pointer
def CALINFO_ENUMPROCA(param0: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def CALINFO_ENUMPROCEXA(param0: win32more.Windows.Win32.Foundation.PSTR, param1: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def CALINFO_ENUMPROCEXEX(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: UInt32, param2: win32more.Windows.Win32.Foundation.PWSTR, param3: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def CALINFO_ENUMPROCEXW(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
CALINFO_ENUMPROCEX = UnicodeAlias('CALINFO_ENUMPROCEXW')
@winfunctype_pointer
def CALINFO_ENUMPROCW(param0: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
CALINFO_ENUMPROC = UnicodeAlias('CALINFO_ENUMPROCW')
class CHARSETINFO(Structure):
    ciCharset: UInt32
    ciACP: UInt32
    fs: win32more.Windows.Win32.Globalization.FONTSIGNATURE
CMLangConvertCharset = Guid('{d66d6f99-cdaa-11d0-b822-00c04fc9b31f}')
CMLangString = Guid('{c04d65cf-b70d-11d0-b188-00aa0038c969}')
CMultiLanguage = Guid('{275c23e2-3747-11d0-9fea-00aa003f8646}')
@winfunctype_pointer
def CODEPAGE_ENUMPROCA(param0: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def CODEPAGE_ENUMPROCW(param0: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
CODEPAGE_ENUMPROC = UnicodeAlias('CODEPAGE_ENUMPROCW')
COMPARESTRING_RESULT = Int32
CSTR_LESS_THAN: win32more.Windows.Win32.Globalization.COMPARESTRING_RESULT = 1
CSTR_EQUAL: win32more.Windows.Win32.Globalization.COMPARESTRING_RESULT = 2
CSTR_GREATER_THAN: win32more.Windows.Win32.Globalization.COMPARESTRING_RESULT = 3
COMPARE_STRING_FLAGS = UInt32
LINGUISTIC_IGNORECASE: win32more.Windows.Win32.Globalization.COMPARE_STRING_FLAGS = 16
LINGUISTIC_IGNOREDIACRITIC: win32more.Windows.Win32.Globalization.COMPARE_STRING_FLAGS = 32
NORM_IGNORECASE: win32more.Windows.Win32.Globalization.COMPARE_STRING_FLAGS = 1
NORM_IGNOREKANATYPE: win32more.Windows.Win32.Globalization.COMPARE_STRING_FLAGS = 65536
NORM_IGNORENONSPACE: win32more.Windows.Win32.Globalization.COMPARE_STRING_FLAGS = 2
NORM_IGNORESYMBOLS: win32more.Windows.Win32.Globalization.COMPARE_STRING_FLAGS = 4
NORM_IGNOREWIDTH: win32more.Windows.Win32.Globalization.COMPARE_STRING_FLAGS = 131072
NORM_LINGUISTIC_CASING: win32more.Windows.Win32.Globalization.COMPARE_STRING_FLAGS = 134217728
SORT_DIGITSASNUMBERS: win32more.Windows.Win32.Globalization.COMPARE_STRING_FLAGS = 8
SORT_STRINGSORT: win32more.Windows.Win32.Globalization.COMPARE_STRING_FLAGS = 4096
CORRECTIVE_ACTION = Int32
CORRECTIVE_ACTION_NONE: win32more.Windows.Win32.Globalization.CORRECTIVE_ACTION = 0
CORRECTIVE_ACTION_GET_SUGGESTIONS: win32more.Windows.Win32.Globalization.CORRECTIVE_ACTION = 1
CORRECTIVE_ACTION_REPLACE: win32more.Windows.Win32.Globalization.CORRECTIVE_ACTION = 2
CORRECTIVE_ACTION_DELETE: win32more.Windows.Win32.Globalization.CORRECTIVE_ACTION = 3
class CPINFO(Structure):
    MaxCharSize: UInt32
    DefaultChar: Byte * 2
    LeadByte: Byte * 12
class CPINFOEXA(Structure):
    MaxCharSize: UInt32
    DefaultChar: Byte * 2
    LeadByte: Byte * 12
    UnicodeDefaultChar: Char
    CodePage: UInt32
    CodePageName: win32more.Windows.Win32.Foundation.CHAR * 260
class CPINFOEXW(Structure):
    MaxCharSize: UInt32
    DefaultChar: Byte * 2
    LeadByte: Byte * 12
    UnicodeDefaultChar: Char
    CodePage: UInt32
    CodePageName: Char * 260
CPINFOEX = UnicodeAlias('CPINFOEXW')
class CURRENCYFMTA(Structure):
    NumDigits: UInt32
    LeadingZero: UInt32
    Grouping: UInt32
    lpDecimalSep: win32more.Windows.Win32.Foundation.PSTR
    lpThousandSep: win32more.Windows.Win32.Foundation.PSTR
    NegativeOrder: UInt32
    PositiveOrder: UInt32
    lpCurrencySymbol: win32more.Windows.Win32.Foundation.PSTR
class CURRENCYFMTW(Structure):
    NumDigits: UInt32
    LeadingZero: UInt32
    Grouping: UInt32
    lpDecimalSep: win32more.Windows.Win32.Foundation.PWSTR
    lpThousandSep: win32more.Windows.Win32.Foundation.PWSTR
    NegativeOrder: UInt32
    PositiveOrder: UInt32
    lpCurrencySymbol: win32more.Windows.Win32.Foundation.PWSTR
CURRENCYFMT = UnicodeAlias('CURRENCYFMTW')
@winfunctype_pointer
def DATEFMT_ENUMPROCA(param0: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def DATEFMT_ENUMPROCEXA(param0: win32more.Windows.Win32.Foundation.PSTR, param1: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def DATEFMT_ENUMPROCEXEX(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: UInt32, param2: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def DATEFMT_ENUMPROCEXW(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
DATEFMT_ENUMPROCEX = UnicodeAlias('DATEFMT_ENUMPROCEXW')
@winfunctype_pointer
def DATEFMT_ENUMPROCW(param0: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
DATEFMT_ENUMPROC = UnicodeAlias('DATEFMT_ENUMPROCW')
class DetectEncodingInfo(Structure):
    nLangID: UInt32
    nCodePage: UInt32
    nDocPercent: Int32
    nConfidence: Int32
class ENUMTEXTMETRICA(Structure):
    etmNewTextMetricEx: win32more.Windows.Win32.Globalization.NEWTEXTMETRICEXA
    etmAxesList: win32more.Windows.Win32.Graphics.Gdi.AXESLISTA
class ENUMTEXTMETRICW(Structure):
    etmNewTextMetricEx: win32more.Windows.Win32.Globalization.NEWTEXTMETRICEXW
    etmAxesList: win32more.Windows.Win32.Graphics.Gdi.AXESLISTW
ENUMTEXTMETRIC = UnicodeAlias('ENUMTEXTMETRICW')
ENUM_DATE_FORMATS_FLAGS = UInt32
DATE_SHORTDATE: win32more.Windows.Win32.Globalization.ENUM_DATE_FORMATS_FLAGS = 1
DATE_LONGDATE: win32more.Windows.Win32.Globalization.ENUM_DATE_FORMATS_FLAGS = 2
DATE_YEARMONTH: win32more.Windows.Win32.Globalization.ENUM_DATE_FORMATS_FLAGS = 8
DATE_MONTHDAY: win32more.Windows.Win32.Globalization.ENUM_DATE_FORMATS_FLAGS = 128
DATE_AUTOLAYOUT: win32more.Windows.Win32.Globalization.ENUM_DATE_FORMATS_FLAGS = 64
DATE_LTRREADING: win32more.Windows.Win32.Globalization.ENUM_DATE_FORMATS_FLAGS = 16
DATE_RTLREADING: win32more.Windows.Win32.Globalization.ENUM_DATE_FORMATS_FLAGS = 32
DATE_USE_ALT_CALENDAR: win32more.Windows.Win32.Globalization.ENUM_DATE_FORMATS_FLAGS = 4
ENUM_SYSTEM_CODE_PAGES_FLAGS = UInt32
CP_INSTALLED: win32more.Windows.Win32.Globalization.ENUM_SYSTEM_CODE_PAGES_FLAGS = 1
CP_SUPPORTED: win32more.Windows.Win32.Globalization.ENUM_SYSTEM_CODE_PAGES_FLAGS = 2
ENUM_SYSTEM_LANGUAGE_GROUPS_FLAGS = UInt32
LGRPID_INSTALLED: win32more.Windows.Win32.Globalization.ENUM_SYSTEM_LANGUAGE_GROUPS_FLAGS = 1
LGRPID_SUPPORTED: win32more.Windows.Win32.Globalization.ENUM_SYSTEM_LANGUAGE_GROUPS_FLAGS = 2
class FILEMUIINFO(Structure):
    dwSize: UInt32
    dwVersion: UInt32
    dwFileType: UInt32
    pChecksum: Byte * 16
    pServiceChecksum: Byte * 16
    dwLanguageNameOffset: UInt32
    dwTypeIDMainSize: UInt32
    dwTypeIDMainOffset: UInt32
    dwTypeNameMainOffset: UInt32
    dwTypeIDMUISize: UInt32
    dwTypeIDMUIOffset: UInt32
    dwTypeNameMUIOffset: UInt32
    abBuffer: Byte * 8
FOLD_STRING_MAP_FLAGS = UInt32
MAP_COMPOSITE: win32more.Windows.Win32.Globalization.FOLD_STRING_MAP_FLAGS = 64
MAP_EXPAND_LIGATURES: win32more.Windows.Win32.Globalization.FOLD_STRING_MAP_FLAGS = 8192
MAP_FOLDCZONE: win32more.Windows.Win32.Globalization.FOLD_STRING_MAP_FLAGS = 16
MAP_FOLDDIGITS: win32more.Windows.Win32.Globalization.FOLD_STRING_MAP_FLAGS = 128
MAP_PRECOMPOSED: win32more.Windows.Win32.Globalization.FOLD_STRING_MAP_FLAGS = 32
class FONTSIGNATURE(Structure):
    fsUsb: UInt32 * 4
    fsCsb: UInt32 * 2
@winfunctype_pointer
def GEO_ENUMNAMEPROC(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def GEO_ENUMPROC(param0: Int32) -> win32more.Windows.Win32.Foundation.BOOL: ...
class GOFFSET(Structure):
    du: Int32
    dv: Int32
HSAVEDUILANGUAGES = VoidPtr
class IComprehensiveSpellCheckProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0c58f8de-8e94-479e-9717-70c42c4ad2c3}')
    @commethod(3)
    def ComprehensiveCheck(self, text: win32more.Windows.Win32.Foundation.PWSTR, value: POINTER(win32more.Windows.Win32.Globalization.IEnumSpellingError)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumCodePage(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{275c23e3-3747-11d0-9fea-00aa003f8646}')
    @commethod(3)
    def Clone(self, ppEnum: POINTER(win32more.Windows.Win32.Globalization.IEnumCodePage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Next(self, celt: UInt32, rgelt: POINTER(win32more.Windows.Win32.Globalization.MIMECPINFO), pceltFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Skip(self, celt: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumRfc1766(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3dc39d1d-c030-11d0-b81b-00c04fc9b31f}')
    @commethod(3)
    def Clone(self, ppEnum: POINTER(win32more.Windows.Win32.Globalization.IEnumRfc1766)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Next(self, celt: UInt32, rgelt: POINTER(win32more.Windows.Win32.Globalization.RFC1766INFO), pceltFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Skip(self, celt: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumScript(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ae5f1430-388b-11d2-8380-00c04f8f5da1}')
    @commethod(3)
    def Clone(self, ppEnum: POINTER(win32more.Windows.Win32.Globalization.IEnumScript)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Next(self, celt: UInt32, rgelt: POINTER(win32more.Windows.Win32.Globalization.SCRIPTINFO), pceltFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Skip(self, celt: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumSpellingError(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{803e3bd4-2828-4410-8290-418d1d73c762}')
    @commethod(3)
    def Next(self, value: POINTER(win32more.Windows.Win32.Globalization.ISpellingError)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLangCodePages(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{359f3443-bd4a-11d0-b188-00aa0038c969}')
    @commethod(3)
    def GetCharCodePages(self, chSrc: Char, pdwCodePages: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetStrCodePages(self, pszSrc: win32more.Windows.Win32.Foundation.PWSTR, cchSrc: Int32, dwPriorityCodePages: UInt32, pdwCodePages: POINTER(UInt32), pcchCodePages: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CodePageToCodePages(self, uCodePage: UInt32, pdwCodePages: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CodePagesToCodePage(self, dwCodePages: UInt32, uDefaultCodePage: UInt32, puCodePage: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLangConvertCharset(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d66d6f98-cdaa-11d0-b822-00c04fc9b31f}')
    @commethod(3)
    def Initialize(self, uiSrcCodePage: UInt32, uiDstCodePage: UInt32, dwProperty: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetSourceCodePage(self, puiSrcCodePage: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetDestinationCodePage(self, puiDstCodePage: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetProperty(self, pdwProperty: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def DoConversion(self, pSrcStr: POINTER(Byte), pcSrcSize: POINTER(UInt32), pDstStr: POINTER(Byte), pcDstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DoConversionToUnicode(self, pSrcStr: win32more.Windows.Win32.Foundation.PSTR, pcSrcSize: POINTER(UInt32), pDstStr: win32more.Windows.Win32.Foundation.PWSTR, pcDstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def DoConversionFromUnicode(self, pSrcStr: win32more.Windows.Win32.Foundation.PWSTR, pcSrcSize: POINTER(UInt32), pDstStr: win32more.Windows.Win32.Foundation.PSTR, pcDstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLangFontLink(ComPtr):
    extends: win32more.Windows.Win32.Globalization.IMLangCodePages
    _iid_ = Guid('{359f3441-bd4a-11d0-b188-00aa0038c969}')
    @commethod(7)
    def GetFontCodePages(self, hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, hFont: win32more.Windows.Win32.Graphics.Gdi.HFONT, pdwCodePages: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def MapFont(self, hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, dwCodePages: UInt32, hSrcFont: win32more.Windows.Win32.Graphics.Gdi.HFONT, phDestFont: POINTER(win32more.Windows.Win32.Graphics.Gdi.HFONT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def ReleaseFont(self, hFont: win32more.Windows.Win32.Graphics.Gdi.HFONT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def ResetFontMapping(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLangFontLink2(ComPtr):
    extends: win32more.Windows.Win32.Globalization.IMLangCodePages
    _iid_ = Guid('{dccfc162-2b38-11d2-b7ec-00c04f8f5d9a}')
    @commethod(7)
    def GetFontCodePages(self, hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, hFont: win32more.Windows.Win32.Graphics.Gdi.HFONT, pdwCodePages: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def ReleaseFont(self, hFont: win32more.Windows.Win32.Graphics.Gdi.HFONT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def ResetFontMapping(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def MapFont(self, hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, dwCodePages: UInt32, chSrc: Char, pFont: POINTER(win32more.Windows.Win32.Graphics.Gdi.HFONT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetFontUnicodeRanges(self, hDC: win32more.Windows.Win32.Graphics.Gdi.HDC, puiRanges: POINTER(UInt32), pUranges: POINTER(win32more.Windows.Win32.Globalization.UNICODERANGE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetScriptFontInfo(self, sid: Byte, dwFlags: UInt32, puiFonts: POINTER(UInt32), pScriptFont: POINTER(win32more.Windows.Win32.Globalization.SCRIPTFONTINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CodePageToScriptID(self, uiCodePage: UInt32, pSid: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLangLineBreakConsole(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f5be2ee1-bfd7-11d0-b188-00aa0038c969}')
    @commethod(3)
    def BreakLineML(self, pSrcMLStr: win32more.Windows.Win32.Globalization.IMLangString, lSrcPos: Int32, lSrcLen: Int32, cMinColumns: Int32, cMaxColumns: Int32, plLineLen: POINTER(Int32), plSkipLen: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def BreakLineW(self, locale: UInt32, pszSrc: win32more.Windows.Win32.Foundation.PWSTR, cchSrc: Int32, cMaxColumns: Int32, pcchLine: POINTER(Int32), pcchSkip: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def BreakLineA(self, locale: UInt32, uCodePage: UInt32, pszSrc: win32more.Windows.Win32.Foundation.PSTR, cchSrc: Int32, cMaxColumns: Int32, pcchLine: POINTER(Int32), pcchSkip: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLangString(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c04d65ce-b70d-11d0-b188-00aa0038c969}')
    @commethod(3)
    def Sync(self, fNoAccess: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetLength(self, plLen: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetMLStr(self, lDestPos: Int32, lDestLen: Int32, pSrcMLStr: win32more.Windows.Win32.System.Com.IUnknown, lSrcPos: Int32, lSrcLen: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetMLStr(self, lSrcPos: Int32, lSrcLen: Int32, pUnkOuter: win32more.Windows.Win32.System.Com.IUnknown, dwClsContext: UInt32, piid: POINTER(Guid), ppDestMLStr: POINTER(win32more.Windows.Win32.System.Com.IUnknown), plDestPos: POINTER(Int32), plDestLen: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLangStringAStr(ComPtr):
    extends: win32more.Windows.Win32.Globalization.IMLangString
    _iid_ = Guid('{c04d65d2-b70d-11d0-b188-00aa0038c969}')
    @commethod(7)
    def SetAStr(self, lDestPos: Int32, lDestLen: Int32, uCodePage: UInt32, pszSrc: win32more.Windows.Win32.Foundation.PSTR, cchSrc: Int32, pcchActual: POINTER(Int32), plActualLen: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetStrBufA(self, lDestPos: Int32, lDestLen: Int32, uCodePage: UInt32, pSrcBuf: win32more.Windows.Win32.Globalization.IMLangStringBufA, pcchActual: POINTER(Int32), plActualLen: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetAStr(self, lSrcPos: Int32, lSrcLen: Int32, uCodePageIn: UInt32, puCodePageOut: POINTER(UInt32), pszDest: win32more.Windows.Win32.Foundation.PSTR, cchDest: Int32, pcchActual: POINTER(Int32), plActualLen: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetStrBufA(self, lSrcPos: Int32, lSrcMaxLen: Int32, puDestCodePage: POINTER(UInt32), ppDestBuf: POINTER(win32more.Windows.Win32.Globalization.IMLangStringBufA), plDestLen: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def LockAStr(self, lSrcPos: Int32, lSrcLen: Int32, lFlags: Int32, uCodePageIn: UInt32, cchRequest: Int32, puCodePageOut: POINTER(UInt32), ppszDest: POINTER(win32more.Windows.Win32.Foundation.PSTR), pcchDest: POINTER(Int32), plDestLen: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def UnlockAStr(self, pszSrc: win32more.Windows.Win32.Foundation.PSTR, cchSrc: Int32, pcchActual: POINTER(Int32), plActualLen: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetLocale(self, lDestPos: Int32, lDestLen: Int32, locale: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetLocale(self, lSrcPos: Int32, lSrcMaxLen: Int32, plocale: POINTER(UInt32), plLocalePos: POINTER(Int32), plLocaleLen: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLangStringBufA(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d24acd23-ba72-11d0-b188-00aa0038c969}')
    @commethod(3)
    def GetStatus(self, plFlags: POINTER(Int32), pcchBuf: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def LockBuf(self, cchOffset: Int32, cchMaxLock: Int32, ppszBuf: POINTER(POINTER(win32more.Windows.Win32.Foundation.CHAR)), pcchBuf: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def UnlockBuf(self, pszBuf: win32more.Windows.Win32.Foundation.PSTR, cchOffset: Int32, cchWrite: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Insert(self, cchOffset: Int32, cchMaxInsert: Int32, pcchActual: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Delete(self, cchOffset: Int32, cchDelete: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLangStringBufW(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d24acd21-ba72-11d0-b188-00aa0038c969}')
    @commethod(3)
    def GetStatus(self, plFlags: POINTER(Int32), pcchBuf: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def LockBuf(self, cchOffset: Int32, cchMaxLock: Int32, ppszBuf: POINTER(POINTER(UInt16)), pcchBuf: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def UnlockBuf(self, pszBuf: win32more.Windows.Win32.Foundation.PWSTR, cchOffset: Int32, cchWrite: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Insert(self, cchOffset: Int32, cchMaxInsert: Int32, pcchActual: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Delete(self, cchOffset: Int32, cchDelete: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
IMLangStringBuf = UnicodeAlias('IMLangStringBufW')
class IMLangStringWStr(ComPtr):
    extends: win32more.Windows.Win32.Globalization.IMLangString
    _iid_ = Guid('{c04d65d0-b70d-11d0-b188-00aa0038c969}')
    @commethod(7)
    def SetWStr(self, lDestPos: Int32, lDestLen: Int32, pszSrc: win32more.Windows.Win32.Foundation.PWSTR, cchSrc: Int32, pcchActual: POINTER(Int32), plActualLen: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetStrBufW(self, lDestPos: Int32, lDestLen: Int32, pSrcBuf: win32more.Windows.Win32.Globalization.IMLangStringBufW, pcchActual: POINTER(Int32), plActualLen: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetWStr(self, lSrcPos: Int32, lSrcLen: Int32, pszDest: win32more.Windows.Win32.Foundation.PWSTR, cchDest: Int32, pcchActual: POINTER(Int32), plActualLen: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetStrBufW(self, lSrcPos: Int32, lSrcMaxLen: Int32, ppDestBuf: POINTER(win32more.Windows.Win32.Globalization.IMLangStringBufW), plDestLen: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def LockWStr(self, lSrcPos: Int32, lSrcLen: Int32, lFlags: Int32, cchRequest: Int32, ppszDest: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pcchDest: POINTER(Int32), plDestLen: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def UnlockWStr(self, pszSrc: win32more.Windows.Win32.Foundation.PWSTR, cchSrc: Int32, pcchActual: POINTER(Int32), plActualLen: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetLocale(self, lDestPos: Int32, lDestLen: Int32, locale: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetLocale(self, lSrcPos: Int32, lSrcMaxLen: Int32, plocale: POINTER(UInt32), plLocalePos: POINTER(Int32), plLocaleLen: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMultiLanguage(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{275c23e1-3747-11d0-9fea-00aa003f8646}')
    @commethod(3)
    def GetNumberOfCodePageInfo(self, pcCodePage: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetCodePageInfo(self, uiCodePage: UInt32, pCodePageInfo: POINTER(win32more.Windows.Win32.Globalization.MIMECPINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetFamilyCodePage(self, uiCodePage: UInt32, puiFamilyCodePage: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def EnumCodePages(self, grfFlags: UInt32, ppEnumCodePage: POINTER(win32more.Windows.Win32.Globalization.IEnumCodePage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetCharsetInfo(self, Charset: win32more.Windows.Win32.Foundation.BSTR, pCharsetInfo: POINTER(win32more.Windows.Win32.Globalization.MIMECSETINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def IsConvertible(self, dwSrcEncoding: UInt32, dwDstEncoding: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def ConvertString(self, pdwMode: POINTER(UInt32), dwSrcEncoding: UInt32, dwDstEncoding: UInt32, pSrcStr: POINTER(Byte), pcSrcSize: POINTER(UInt32), pDstStr: POINTER(Byte), pcDstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def ConvertStringToUnicode(self, pdwMode: POINTER(UInt32), dwEncoding: UInt32, pSrcStr: win32more.Windows.Win32.Foundation.PSTR, pcSrcSize: POINTER(UInt32), pDstStr: win32more.Windows.Win32.Foundation.PWSTR, pcDstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def ConvertStringFromUnicode(self, pdwMode: POINTER(UInt32), dwEncoding: UInt32, pSrcStr: win32more.Windows.Win32.Foundation.PWSTR, pcSrcSize: POINTER(UInt32), pDstStr: win32more.Windows.Win32.Foundation.PSTR, pcDstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def ConvertStringReset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetRfc1766FromLcid(self, Locale: UInt32, pbstrRfc1766: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetLcidFromRfc1766(self, pLocale: POINTER(UInt32), bstrRfc1766: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def EnumRfc1766(self, ppEnumRfc1766: POINTER(win32more.Windows.Win32.Globalization.IEnumRfc1766)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetRfc1766Info(self, Locale: UInt32, pRfc1766Info: POINTER(win32more.Windows.Win32.Globalization.RFC1766INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def CreateConvertCharset(self, uiSrcCodePage: UInt32, uiDstCodePage: UInt32, dwProperty: UInt32, ppMLangConvertCharset: POINTER(win32more.Windows.Win32.Globalization.IMLangConvertCharset)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMultiLanguage2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{dccfc164-2b38-11d2-b7ec-00c04f8f5d9a}')
    @commethod(3)
    def GetNumberOfCodePageInfo(self, pcCodePage: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetCodePageInfo(self, uiCodePage: UInt32, LangId: UInt16, pCodePageInfo: POINTER(win32more.Windows.Win32.Globalization.MIMECPINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetFamilyCodePage(self, uiCodePage: UInt32, puiFamilyCodePage: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def EnumCodePages(self, grfFlags: UInt32, LangId: UInt16, ppEnumCodePage: POINTER(win32more.Windows.Win32.Globalization.IEnumCodePage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetCharsetInfo(self, Charset: win32more.Windows.Win32.Foundation.BSTR, pCharsetInfo: POINTER(win32more.Windows.Win32.Globalization.MIMECSETINFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def IsConvertible(self, dwSrcEncoding: UInt32, dwDstEncoding: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def ConvertString(self, pdwMode: POINTER(UInt32), dwSrcEncoding: UInt32, dwDstEncoding: UInt32, pSrcStr: POINTER(Byte), pcSrcSize: POINTER(UInt32), pDstStr: POINTER(Byte), pcDstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def ConvertStringToUnicode(self, pdwMode: POINTER(UInt32), dwEncoding: UInt32, pSrcStr: win32more.Windows.Win32.Foundation.PSTR, pcSrcSize: POINTER(UInt32), pDstStr: win32more.Windows.Win32.Foundation.PWSTR, pcDstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def ConvertStringFromUnicode(self, pdwMode: POINTER(UInt32), dwEncoding: UInt32, pSrcStr: win32more.Windows.Win32.Foundation.PWSTR, pcSrcSize: POINTER(UInt32), pDstStr: win32more.Windows.Win32.Foundation.PSTR, pcDstSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def ConvertStringReset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetRfc1766FromLcid(self, Locale: UInt32, pbstrRfc1766: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetLcidFromRfc1766(self, pLocale: POINTER(UInt32), bstrRfc1766: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def EnumRfc1766(self, LangId: UInt16, ppEnumRfc1766: POINTER(win32more.Windows.Win32.Globalization.IEnumRfc1766)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetRfc1766Info(self, Locale: UInt32, LangId: UInt16, pRfc1766Info: POINTER(win32more.Windows.Win32.Globalization.RFC1766INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def CreateConvertCharset(self, uiSrcCodePage: UInt32, uiDstCodePage: UInt32, dwProperty: UInt32, ppMLangConvertCharset: POINTER(win32more.Windows.Win32.Globalization.IMLangConvertCharset)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def ConvertStringInIStream(self, pdwMode: POINTER(UInt32), dwFlag: UInt32, lpFallBack: win32more.Windows.Win32.Foundation.PWSTR, dwSrcEncoding: UInt32, dwDstEncoding: UInt32, pstmIn: win32more.Windows.Win32.System.Com.IStream, pstmOut: win32more.Windows.Win32.System.Com.IStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def ConvertStringToUnicodeEx(self, pdwMode: POINTER(UInt32), dwEncoding: UInt32, pSrcStr: win32more.Windows.Win32.Foundation.PSTR, pcSrcSize: POINTER(UInt32), pDstStr: win32more.Windows.Win32.Foundation.PWSTR, pcDstSize: POINTER(UInt32), dwFlag: UInt32, lpFallBack: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def ConvertStringFromUnicodeEx(self, pdwMode: POINTER(UInt32), dwEncoding: UInt32, pSrcStr: win32more.Windows.Win32.Foundation.PWSTR, pcSrcSize: POINTER(UInt32), pDstStr: win32more.Windows.Win32.Foundation.PSTR, pcDstSize: POINTER(UInt32), dwFlag: UInt32, lpFallBack: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def DetectCodepageInIStream(self, dwFlag: UInt32, dwPrefWinCodePage: UInt32, pstmIn: win32more.Windows.Win32.System.Com.IStream, lpEncoding: POINTER(win32more.Windows.Win32.Globalization.DetectEncodingInfo), pnScores: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def DetectInputCodepage(self, dwFlag: UInt32, dwPrefWinCodePage: UInt32, pSrcStr: win32more.Windows.Win32.Foundation.PSTR, pcSrcSize: POINTER(Int32), lpEncoding: POINTER(win32more.Windows.Win32.Globalization.DetectEncodingInfo), pnScores: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def ValidateCodePage(self, uiCodePage: UInt32, hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetCodePageDescription(self, uiCodePage: UInt32, lcid: UInt32, lpWideCharStr: win32more.Windows.Win32.Foundation.PWSTR, cchWideChar: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def IsCodePageInstallable(self, uiCodePage: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def SetMimeDBSource(self, dwSource: win32more.Windows.Win32.Globalization.MIMECONTF) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def GetNumberOfScripts(self, pnScripts: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def EnumScripts(self, dwFlags: UInt32, LangId: UInt16, ppEnumScript: POINTER(win32more.Windows.Win32.Globalization.IEnumScript)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def ValidateCodePageEx(self, uiCodePage: UInt32, hwnd: win32more.Windows.Win32.Foundation.HWND, dwfIODControl: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMultiLanguage3(ComPtr):
    extends: win32more.Windows.Win32.Globalization.IMultiLanguage2
    _iid_ = Guid('{4e5868ab-b157-4623-9acc-6a1d9caebe04}')
    @commethod(30)
    def DetectOutboundCodePage(self, dwFlags: UInt32, lpWideCharStr: win32more.Windows.Win32.Foundation.PWSTR, cchWideChar: UInt32, puiPreferredCodePages: POINTER(UInt32), nPreferredCodePages: UInt32, puiDetectedCodePages: POINTER(UInt32), pnDetectedCodePages: POINTER(UInt32), lpSpecialChar: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def DetectOutboundCodePageInIStream(self, dwFlags: UInt32, pStrIn: win32more.Windows.Win32.System.Com.IStream, puiPreferredCodePages: POINTER(UInt32), nPreferredCodePages: UInt32, puiDetectedCodePages: POINTER(UInt32), pnDetectedCodePages: POINTER(UInt32), lpSpecialChar: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOptionDescription(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{432e5f85-35cf-4606-a801-6f70277e1d7a}')
    @commethod(3)
    def get_Id(self, value: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_Heading(self, value: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_Description(self, value: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def get_Labels(self, value: POINTER(win32more.Windows.Win32.System.Com.IEnumString)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
IS_TEXT_UNICODE_RESULT = UInt32
IS_TEXT_UNICODE_ASCII16: win32more.Windows.Win32.Globalization.IS_TEXT_UNICODE_RESULT = 1
IS_TEXT_UNICODE_REVERSE_ASCII16: win32more.Windows.Win32.Globalization.IS_TEXT_UNICODE_RESULT = 16
IS_TEXT_UNICODE_STATISTICS: win32more.Windows.Win32.Globalization.IS_TEXT_UNICODE_RESULT = 2
IS_TEXT_UNICODE_REVERSE_STATISTICS: win32more.Windows.Win32.Globalization.IS_TEXT_UNICODE_RESULT = 32
IS_TEXT_UNICODE_CONTROLS: win32more.Windows.Win32.Globalization.IS_TEXT_UNICODE_RESULT = 4
IS_TEXT_UNICODE_REVERSE_CONTROLS: win32more.Windows.Win32.Globalization.IS_TEXT_UNICODE_RESULT = 64
IS_TEXT_UNICODE_SIGNATURE: win32more.Windows.Win32.Globalization.IS_TEXT_UNICODE_RESULT = 8
IS_TEXT_UNICODE_REVERSE_SIGNATURE: win32more.Windows.Win32.Globalization.IS_TEXT_UNICODE_RESULT = 128
IS_TEXT_UNICODE_ILLEGAL_CHARS: win32more.Windows.Win32.Globalization.IS_TEXT_UNICODE_RESULT = 256
IS_TEXT_UNICODE_ODD_LENGTH: win32more.Windows.Win32.Globalization.IS_TEXT_UNICODE_RESULT = 512
IS_TEXT_UNICODE_NULL_BYTES: win32more.Windows.Win32.Globalization.IS_TEXT_UNICODE_RESULT = 4096
IS_TEXT_UNICODE_UNICODE_MASK: win32more.Windows.Win32.Globalization.IS_TEXT_UNICODE_RESULT = 15
IS_TEXT_UNICODE_REVERSE_MASK: win32more.Windows.Win32.Globalization.IS_TEXT_UNICODE_RESULT = 240
IS_TEXT_UNICODE_NOT_UNICODE_MASK: win32more.Windows.Win32.Globalization.IS_TEXT_UNICODE_RESULT = 3840
IS_TEXT_UNICODE_NOT_ASCII_MASK: win32more.Windows.Win32.Globalization.IS_TEXT_UNICODE_RESULT = 61440
IS_VALID_LOCALE_FLAGS = UInt32
LCID_INSTALLED: win32more.Windows.Win32.Globalization.IS_VALID_LOCALE_FLAGS = 1
LCID_SUPPORTED: win32more.Windows.Win32.Globalization.IS_VALID_LOCALE_FLAGS = 2
class ISpellCheckProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{73e976e0-8ed4-4eb1-80d7-1be0a16b0c38}')
    @commethod(3)
    def get_LanguageTag(self, value: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Check(self, text: win32more.Windows.Win32.Foundation.PWSTR, value: POINTER(win32more.Windows.Win32.Globalization.IEnumSpellingError)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Suggest(self, word: win32more.Windows.Win32.Foundation.PWSTR, value: POINTER(win32more.Windows.Win32.System.Com.IEnumString)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetOptionValue(self, optionId: win32more.Windows.Win32.Foundation.PWSTR, value: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetOptionValue(self, optionId: win32more.Windows.Win32.Foundation.PWSTR, value: Byte) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_OptionIds(self, value: POINTER(win32more.Windows.Win32.System.Com.IEnumString)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Id(self, value: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_LocalizedName(self, value: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetOptionDescription(self, optionId: win32more.Windows.Win32.Foundation.PWSTR, value: POINTER(win32more.Windows.Win32.Globalization.IOptionDescription)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def InitializeWordlist(self, wordlistType: win32more.Windows.Win32.Globalization.WORDLIST_TYPE, words: win32more.Windows.Win32.System.Com.IEnumString) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISpellCheckProviderFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9f671e11-77d6-4c92-aefb-615215e3a4be}')
    @commethod(3)
    def get_SupportedLanguages(self, value: POINTER(win32more.Windows.Win32.System.Com.IEnumString)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def IsSupported(self, languageTag: win32more.Windows.Win32.Foundation.PWSTR, value: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateSpellCheckProvider(self, languageTag: win32more.Windows.Win32.Foundation.PWSTR, value: POINTER(win32more.Windows.Win32.Globalization.ISpellCheckProvider)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISpellChecker(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b6fd0b71-e2bc-4653-8d05-f197e412770b}')
    @commethod(3)
    def get_LanguageTag(self, value: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Check(self, text: win32more.Windows.Win32.Foundation.PWSTR, value: POINTER(win32more.Windows.Win32.Globalization.IEnumSpellingError)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Suggest(self, word: win32more.Windows.Win32.Foundation.PWSTR, value: POINTER(win32more.Windows.Win32.System.Com.IEnumString)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Add(self, word: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Ignore(self, word: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def AutoCorrect(self, from_: win32more.Windows.Win32.Foundation.PWSTR, to: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetOptionValue(self, optionId: win32more.Windows.Win32.Foundation.PWSTR, value: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_OptionIds(self, value: POINTER(win32more.Windows.Win32.System.Com.IEnumString)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_Id(self, value: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_LocalizedName(self, value: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def add_SpellCheckerChanged(self, handler: win32more.Windows.Win32.Globalization.ISpellCheckerChangedEventHandler, eventCookie: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def remove_SpellCheckerChanged(self, eventCookie: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetOptionDescription(self, optionId: win32more.Windows.Win32.Foundation.PWSTR, value: POINTER(win32more.Windows.Win32.Globalization.IOptionDescription)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def ComprehensiveCheck(self, text: win32more.Windows.Win32.Foundation.PWSTR, value: POINTER(win32more.Windows.Win32.Globalization.IEnumSpellingError)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISpellChecker2(ComPtr):
    extends: win32more.Windows.Win32.Globalization.ISpellChecker
    _iid_ = Guid('{e7ed1c71-87f7-4378-a840-c9200dacee47}')
    @commethod(17)
    def Remove(self, word: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISpellCheckerChangedEventHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0b83a5b0-792f-4eab-9799-acf52c5ed08a}')
    @commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.Globalization.ISpellChecker) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISpellCheckerFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8e018a9d-2415-4677-bf08-794ea61f94bb}')
    @commethod(3)
    def get_SupportedLanguages(self, value: POINTER(win32more.Windows.Win32.System.Com.IEnumString)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def IsSupported(self, languageTag: win32more.Windows.Win32.Foundation.PWSTR, value: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateSpellChecker(self, languageTag: win32more.Windows.Win32.Foundation.PWSTR, value: POINTER(win32more.Windows.Win32.Globalization.ISpellChecker)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISpellingError(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b7c82d61-fbe8-4b47-9b27-6c0d2e0de0a3}')
    @commethod(3)
    def get_StartIndex(self, value: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_Length(self, value: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_CorrectiveAction(self, value: POINTER(win32more.Windows.Win32.Globalization.CORRECTIVE_ACTION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def get_Replacement(self, value: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUserDictionariesRegistrar(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{aa176b85-0e12-4844-8e1a-eef1da77f586}')
    @commethod(3)
    def RegisterUserDictionary(self, dictionaryPath: win32more.Windows.Win32.Foundation.PWSTR, languageTag: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def UnregisterUserDictionary(self, dictionaryPath: win32more.Windows.Win32.Foundation.PWSTR, languageTag: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def LANGGROUPLOCALE_ENUMPROCA(param0: UInt32, param1: UInt32, param2: win32more.Windows.Win32.Foundation.PSTR, param3: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LANGGROUPLOCALE_ENUMPROCW(param0: UInt32, param1: UInt32, param2: win32more.Windows.Win32.Foundation.PWSTR, param3: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
LANGGROUPLOCALE_ENUMPROC = UnicodeAlias('LANGGROUPLOCALE_ENUMPROCW')
@winfunctype_pointer
def LANGUAGEGROUP_ENUMPROCA(param0: UInt32, param1: win32more.Windows.Win32.Foundation.PSTR, param2: win32more.Windows.Win32.Foundation.PSTR, param3: UInt32, param4: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LANGUAGEGROUP_ENUMPROCW(param0: UInt32, param1: win32more.Windows.Win32.Foundation.PWSTR, param2: win32more.Windows.Win32.Foundation.PWSTR, param3: UInt32, param4: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
LANGUAGEGROUP_ENUMPROC = UnicodeAlias('LANGUAGEGROUP_ENUMPROCW')
class LOCALESIGNATURE(Structure):
    lsUsb: UInt32 * 4
    lsCsbDefault: UInt32 * 2
    lsCsbSupported: UInt32 * 2
@winfunctype_pointer
def LOCALE_ENUMPROCA(param0: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LOCALE_ENUMPROCEX(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: UInt32, param2: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def LOCALE_ENUMPROCW(param0: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
LOCALE_ENUMPROC = UnicodeAlias('LOCALE_ENUMPROCW')
class MAPPING_DATA_RANGE(Structure):
    dwStartIndex: UInt32
    dwEndIndex: UInt32
    pszDescription: win32more.Windows.Win32.Foundation.PWSTR
    dwDescriptionLength: UInt32
    pData: VoidPtr
    dwDataSize: UInt32
    pszContentType: win32more.Windows.Win32.Foundation.PWSTR
    prgActionIds: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
    dwActionsCount: UInt32
    prgActionDisplayNames: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
class MAPPING_ENUM_OPTIONS(Structure):
    Size: UIntPtr
    pszCategory: win32more.Windows.Win32.Foundation.PWSTR
    pszInputLanguage: win32more.Windows.Win32.Foundation.PWSTR
    pszOutputLanguage: win32more.Windows.Win32.Foundation.PWSTR
    pszInputScript: win32more.Windows.Win32.Foundation.PWSTR
    pszOutputScript: win32more.Windows.Win32.Foundation.PWSTR
    pszInputContentType: win32more.Windows.Win32.Foundation.PWSTR
    pszOutputContentType: win32more.Windows.Win32.Foundation.PWSTR
    pGuid: POINTER(Guid)
    OnlineService: Annotated[UInt32, 2]
    ServiceType: Annotated[UInt32, 2]
class MAPPING_OPTIONS(Structure):
    Size: UIntPtr
    pszInputLanguage: win32more.Windows.Win32.Foundation.PWSTR
    pszOutputLanguage: win32more.Windows.Win32.Foundation.PWSTR
    pszInputScript: win32more.Windows.Win32.Foundation.PWSTR
    pszOutputScript: win32more.Windows.Win32.Foundation.PWSTR
    pszInputContentType: win32more.Windows.Win32.Foundation.PWSTR
    pszOutputContentType: win32more.Windows.Win32.Foundation.PWSTR
    pszUILanguage: win32more.Windows.Win32.Foundation.PWSTR
    pfnRecognizeCallback: win32more.Windows.Win32.Globalization.PFN_MAPPINGCALLBACKPROC
    pRecognizeCallerData: VoidPtr
    dwRecognizeCallerDataSize: UInt32
    pfnActionCallback: win32more.Windows.Win32.Globalization.PFN_MAPPINGCALLBACKPROC
    pActionCallerData: VoidPtr
    dwActionCallerDataSize: UInt32
    dwServiceFlag: UInt32
    GetActionDisplayName: Annotated[UInt32, 1]
class MAPPING_PROPERTY_BAG(Structure):
    Size: UIntPtr
    prgResultRanges: POINTER(win32more.Windows.Win32.Globalization.MAPPING_DATA_RANGE)
    dwRangesCount: UInt32
    pServiceData: VoidPtr
    dwServiceDataSize: UInt32
    pCallerData: VoidPtr
    dwCallerDataSize: UInt32
    pContext: VoidPtr
class MAPPING_SERVICE_INFO(Structure):
    Size: UIntPtr
    pszCopyright: win32more.Windows.Win32.Foundation.PWSTR
    wMajorVersion: UInt16
    wMinorVersion: UInt16
    wBuildVersion: UInt16
    wStepVersion: UInt16
    dwInputContentTypesCount: UInt32
    prgInputContentTypes: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
    dwOutputContentTypesCount: UInt32
    prgOutputContentTypes: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
    dwInputLanguagesCount: UInt32
    prgInputLanguages: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
    dwOutputLanguagesCount: UInt32
    prgOutputLanguages: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
    dwInputScriptsCount: UInt32
    prgInputScripts: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
    dwOutputScriptsCount: UInt32
    prgOutputScripts: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
    guid: Guid
    pszCategory: win32more.Windows.Win32.Foundation.PWSTR
    pszDescription: win32more.Windows.Win32.Foundation.PWSTR
    dwPrivateDataSize: UInt32
    pPrivateData: VoidPtr
    pContext: VoidPtr
    IsOneToOneLanguageMapping: Annotated[UInt32, 1]
    HasSubservices: Annotated[UInt32, 1]
    OnlineOnly: Annotated[UInt32, 1]
    ServiceType: Annotated[UInt32, 2]
MIMECONTF = Int32
MIMECONTF_MAILNEWS: win32more.Windows.Win32.Globalization.MIMECONTF = 1
MIMECONTF_BROWSER: win32more.Windows.Win32.Globalization.MIMECONTF = 2
MIMECONTF_MINIMAL: win32more.Windows.Win32.Globalization.MIMECONTF = 4
MIMECONTF_IMPORT: win32more.Windows.Win32.Globalization.MIMECONTF = 8
MIMECONTF_SAVABLE_MAILNEWS: win32more.Windows.Win32.Globalization.MIMECONTF = 256
MIMECONTF_SAVABLE_BROWSER: win32more.Windows.Win32.Globalization.MIMECONTF = 512
MIMECONTF_EXPORT: win32more.Windows.Win32.Globalization.MIMECONTF = 1024
MIMECONTF_PRIVCONVERTER: win32more.Windows.Win32.Globalization.MIMECONTF = 65536
MIMECONTF_VALID: win32more.Windows.Win32.Globalization.MIMECONTF = 131072
MIMECONTF_VALID_NLS: win32more.Windows.Win32.Globalization.MIMECONTF = 262144
MIMECONTF_MIME_IE4: win32more.Windows.Win32.Globalization.MIMECONTF = 268435456
MIMECONTF_MIME_LATEST: win32more.Windows.Win32.Globalization.MIMECONTF = 536870912
MIMECONTF_MIME_REGISTRY: win32more.Windows.Win32.Globalization.MIMECONTF = 1073741824
class MIMECPINFO(Structure):
    dwFlags: UInt32
    uiCodePage: UInt32
    uiFamilyCodePage: UInt32
    wszDescription: Char * 64
    wszWebCharset: Char * 50
    wszHeaderCharset: Char * 50
    wszBodyCharset: Char * 50
    wszFixedWidthFont: Char * 32
    wszProportionalFont: Char * 32
    bGDICharset: Byte
class MIMECSETINFO(Structure):
    uiCodePage: UInt32
    uiInternetEncoding: UInt32
    wszCharset: Char * 50
MLCONVCHAR = Int32
MLCONVCHARF_AUTODETECT: win32more.Windows.Win32.Globalization.MLCONVCHAR = 1
MLCONVCHARF_ENTITIZE: win32more.Windows.Win32.Globalization.MLCONVCHAR = 2
MLCONVCHARF_NCR_ENTITIZE: win32more.Windows.Win32.Globalization.MLCONVCHAR = 2
MLCONVCHARF_NAME_ENTITIZE: win32more.Windows.Win32.Globalization.MLCONVCHAR = 4
MLCONVCHARF_USEDEFCHAR: win32more.Windows.Win32.Globalization.MLCONVCHAR = 8
MLCONVCHARF_NOBESTFITCHARS: win32more.Windows.Win32.Globalization.MLCONVCHAR = 16
MLCONVCHARF_DETECTJPN: win32more.Windows.Win32.Globalization.MLCONVCHAR = 32
MLCP = Int32
MLDETECTF_MAILNEWS: win32more.Windows.Win32.Globalization.MLCP = 1
MLDETECTF_BROWSER: win32more.Windows.Win32.Globalization.MLCP = 2
MLDETECTF_VALID: win32more.Windows.Win32.Globalization.MLCP = 4
MLDETECTF_VALID_NLS: win32more.Windows.Win32.Globalization.MLCP = 8
MLDETECTF_PRESERVE_ORDER: win32more.Windows.Win32.Globalization.MLCP = 16
MLDETECTF_PREFERRED_ONLY: win32more.Windows.Win32.Globalization.MLCP = 32
MLDETECTF_FILTER_SPECIALCHAR: win32more.Windows.Win32.Globalization.MLCP = 64
MLDETECTF_EURO_UTF8: win32more.Windows.Win32.Globalization.MLCP = 128
MLDETECTCP = Int32
MLDETECTCP_NONE: win32more.Windows.Win32.Globalization.MLDETECTCP = 0
MLDETECTCP_7BIT: win32more.Windows.Win32.Globalization.MLDETECTCP = 1
MLDETECTCP_8BIT: win32more.Windows.Win32.Globalization.MLDETECTCP = 2
MLDETECTCP_DBCS: win32more.Windows.Win32.Globalization.MLDETECTCP = 4
MLDETECTCP_HTML: win32more.Windows.Win32.Globalization.MLDETECTCP = 8
MLDETECTCP_NUMBER: win32more.Windows.Win32.Globalization.MLDETECTCP = 16
MLSTR_FLAGS = Int32
MLSTR_READ: win32more.Windows.Win32.Globalization.MLSTR_FLAGS = 1
MLSTR_WRITE: win32more.Windows.Win32.Globalization.MLSTR_FLAGS = 2
MULTI_BYTE_TO_WIDE_CHAR_FLAGS = UInt32
MB_COMPOSITE: win32more.Windows.Win32.Globalization.MULTI_BYTE_TO_WIDE_CHAR_FLAGS = 2
MB_ERR_INVALID_CHARS: win32more.Windows.Win32.Globalization.MULTI_BYTE_TO_WIDE_CHAR_FLAGS = 8
MB_PRECOMPOSED: win32more.Windows.Win32.Globalization.MULTI_BYTE_TO_WIDE_CHAR_FLAGS = 1
MB_USEGLYPHCHARS: win32more.Windows.Win32.Globalization.MULTI_BYTE_TO_WIDE_CHAR_FLAGS = 4
class NEWTEXTMETRICEXA(Structure):
    ntmTm: win32more.Windows.Win32.Graphics.Gdi.NEWTEXTMETRICA
    ntmFontSig: win32more.Windows.Win32.Globalization.FONTSIGNATURE
class NEWTEXTMETRICEXW(Structure):
    ntmTm: win32more.Windows.Win32.Graphics.Gdi.NEWTEXTMETRICW
    ntmFontSig: win32more.Windows.Win32.Globalization.FONTSIGNATURE
NEWTEXTMETRICEX = UnicodeAlias('NEWTEXTMETRICEXW')
class NLSVERSIONINFO(Structure):
    dwNLSVersionInfoSize: UInt32
    dwNLSVersion: UInt32
    dwDefinedVersion: UInt32
    dwEffectiveId: UInt32
    guidCustomVersion: Guid
class NLSVERSIONINFOEX(Structure):
    dwNLSVersionInfoSize: UInt32
    dwNLSVersion: UInt32
    dwDefinedVersion: UInt32
    dwEffectiveId: UInt32
    guidCustomVersion: Guid
NORM_FORM = Int32
NormalizationOther: win32more.Windows.Win32.Globalization.NORM_FORM = 0
NormalizationC: win32more.Windows.Win32.Globalization.NORM_FORM = 1
NormalizationD: win32more.Windows.Win32.Globalization.NORM_FORM = 2
NormalizationKC: win32more.Windows.Win32.Globalization.NORM_FORM = 5
NormalizationKD: win32more.Windows.Win32.Globalization.NORM_FORM = 6
class NUMBERFMTA(Structure):
    NumDigits: UInt32
    LeadingZero: UInt32
    Grouping: UInt32
    lpDecimalSep: win32more.Windows.Win32.Foundation.PSTR
    lpThousandSep: win32more.Windows.Win32.Foundation.PSTR
    NegativeOrder: UInt32
class NUMBERFMTW(Structure):
    NumDigits: UInt32
    LeadingZero: UInt32
    Grouping: UInt32
    lpDecimalSep: win32more.Windows.Win32.Foundation.PWSTR
    lpThousandSep: win32more.Windows.Win32.Foundation.PWSTR
    NegativeOrder: UInt32
NUMBERFMT = UnicodeAlias('NUMBERFMTW')
class OPENTYPE_FEATURE_RECORD(Structure):
    tagFeature: UInt32
    lParameter: Int32
@winfunctype_pointer
def PFN_MAPPINGCALLBACKPROC(pBag: POINTER(win32more.Windows.Win32.Globalization.MAPPING_PROPERTY_BAG), data: VoidPtr, dwDataSize: UInt32, Result: win32more.Windows.Win32.Foundation.HRESULT) -> Void: ...
class RFC1766INFO(Structure):
    lcid: UInt32
    wszRfc1766: Char * 6
    wszLocaleName: Char * 32
SCRIPTCONTF = Int32
sidDefault: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 0
sidMerge: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 1
sidAsciiSym: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 2
sidAsciiLatin: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 3
sidLatin: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 4
sidGreek: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 5
sidCyrillic: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 6
sidArmenian: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 7
sidHebrew: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 8
sidArabic: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 9
sidDevanagari: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 10
sidBengali: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 11
sidGurmukhi: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 12
sidGujarati: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 13
sidOriya: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 14
sidTamil: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 15
sidTelugu: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 16
sidKannada: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 17
sidMalayalam: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 18
sidThai: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 19
sidLao: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 20
sidTibetan: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 21
sidGeorgian: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 22
sidHangul: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 23
sidKana: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 24
sidBopomofo: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 25
sidHan: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 26
sidEthiopic: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 27
sidCanSyllabic: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 28
sidCherokee: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 29
sidYi: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 30
sidBraille: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 31
sidRunic: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 32
sidOgham: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 33
sidSinhala: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 34
sidSyriac: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 35
sidBurmese: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 36
sidKhmer: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 37
sidThaana: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 38
sidMongolian: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 39
sidUserDefined: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 40
sidLim: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 41
sidFEFirst: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 23
sidFELast: win32more.Windows.Win32.Globalization.SCRIPTCONTF = 26
SCRIPTFONTCONTF = Int32
SCRIPTCONTF_FIXED_FONT: win32more.Windows.Win32.Globalization.SCRIPTFONTCONTF = 1
SCRIPTCONTF_PROPORTIONAL_FONT: win32more.Windows.Win32.Globalization.SCRIPTFONTCONTF = 2
SCRIPTCONTF_SCRIPT_USER: win32more.Windows.Win32.Globalization.SCRIPTFONTCONTF = 65536
SCRIPTCONTF_SCRIPT_HIDE: win32more.Windows.Win32.Globalization.SCRIPTFONTCONTF = 131072
SCRIPTCONTF_SCRIPT_SYSTEM: win32more.Windows.Win32.Globalization.SCRIPTFONTCONTF = 262144
class SCRIPTFONTINFO(Structure):
    scripts: Int64
    wszFont: Char * 32
class SCRIPTINFO(Structure):
    ScriptId: Byte
    uiCodePage: UInt32
    wszDescription: Char * 48
    wszFixedWidthFont: Char * 32
    wszProportionalFont: Char * 32
class SCRIPT_ANALYSIS(Structure):
    eScript: Annotated[UInt16, 10]
    fRTL: Annotated[UInt16, 1]
    fLayoutRTL: Annotated[UInt16, 1]
    fLinkBefore: Annotated[UInt16, 1]
    fLinkAfter: Annotated[UInt16, 1]
    fLogicalOrder: Annotated[UInt16, 1]
    fNoGlyphIndex: Annotated[UInt16, 1]
    s: win32more.Windows.Win32.Globalization.SCRIPT_STATE
class SCRIPT_CHARPROP(Structure):
    fCanGlyphAlone: Annotated[UInt16, 1]
    reserved: Annotated[UInt16, 15]
class SCRIPT_CONTROL(Structure):
    uDefaultLanguage: Annotated[UInt32, 16]
    fContextDigits: Annotated[UInt32, 1]
    fInvertPreBoundDir: Annotated[UInt32, 1]
    fInvertPostBoundDir: Annotated[UInt32, 1]
    fLinkStringBefore: Annotated[UInt32, 1]
    fLinkStringAfter: Annotated[UInt32, 1]
    fNeutralOverride: Annotated[UInt32, 1]
    fNumericOverride: Annotated[UInt32, 1]
    fLegacyBidiClass: Annotated[UInt32, 1]
    fMergeNeutralItems: Annotated[UInt32, 1]
    fUseStandardBidi: Annotated[UInt32, 1]
    fReserved: Annotated[UInt32, 6]
class SCRIPT_DIGITSUBSTITUTE(Structure):
    NationalDigitLanguage: Annotated[UInt32, 16]
    TraditionalDigitLanguage: Annotated[UInt32, 16]
    DigitSubstitute: Annotated[UInt32, 8]
    dwReserved: UInt32
class SCRIPT_FONTPROPERTIES(Structure):
    cBytes: Int32
    wgBlank: UInt16
    wgDefault: UInt16
    wgInvalid: UInt16
    wgKashida: UInt16
    iKashidaWidth: Int32
class SCRIPT_GLYPHPROP(Structure):
    sva: win32more.Windows.Win32.Globalization.SCRIPT_VISATTR
    reserved: UInt16
SCRIPT_IS_COMPLEX_FLAGS = UInt32
SIC_ASCIIDIGIT: win32more.Windows.Win32.Globalization.SCRIPT_IS_COMPLEX_FLAGS = 2
SIC_COMPLEX: win32more.Windows.Win32.Globalization.SCRIPT_IS_COMPLEX_FLAGS = 1
SIC_NEUTRAL: win32more.Windows.Win32.Globalization.SCRIPT_IS_COMPLEX_FLAGS = 4
class SCRIPT_ITEM(Structure):
    iCharPos: Int32
    a: win32more.Windows.Win32.Globalization.SCRIPT_ANALYSIS
SCRIPT_JUSTIFY = Int32
SCRIPT_JUSTIFY_NONE: win32more.Windows.Win32.Globalization.SCRIPT_JUSTIFY = 0
SCRIPT_JUSTIFY_ARABIC_BLANK: win32more.Windows.Win32.Globalization.SCRIPT_JUSTIFY = 1
SCRIPT_JUSTIFY_CHARACTER: win32more.Windows.Win32.Globalization.SCRIPT_JUSTIFY = 2
SCRIPT_JUSTIFY_RESERVED1: win32more.Windows.Win32.Globalization.SCRIPT_JUSTIFY = 3
SCRIPT_JUSTIFY_BLANK: win32more.Windows.Win32.Globalization.SCRIPT_JUSTIFY = 4
SCRIPT_JUSTIFY_RESERVED2: win32more.Windows.Win32.Globalization.SCRIPT_JUSTIFY = 5
SCRIPT_JUSTIFY_RESERVED3: win32more.Windows.Win32.Globalization.SCRIPT_JUSTIFY = 6
SCRIPT_JUSTIFY_ARABIC_NORMAL: win32more.Windows.Win32.Globalization.SCRIPT_JUSTIFY = 7
SCRIPT_JUSTIFY_ARABIC_KASHIDA: win32more.Windows.Win32.Globalization.SCRIPT_JUSTIFY = 8
SCRIPT_JUSTIFY_ARABIC_ALEF: win32more.Windows.Win32.Globalization.SCRIPT_JUSTIFY = 9
SCRIPT_JUSTIFY_ARABIC_HA: win32more.Windows.Win32.Globalization.SCRIPT_JUSTIFY = 10
SCRIPT_JUSTIFY_ARABIC_RA: win32more.Windows.Win32.Globalization.SCRIPT_JUSTIFY = 11
SCRIPT_JUSTIFY_ARABIC_BA: win32more.Windows.Win32.Globalization.SCRIPT_JUSTIFY = 12
SCRIPT_JUSTIFY_ARABIC_BARA: win32more.Windows.Win32.Globalization.SCRIPT_JUSTIFY = 13
SCRIPT_JUSTIFY_ARABIC_SEEN: win32more.Windows.Win32.Globalization.SCRIPT_JUSTIFY = 14
SCRIPT_JUSTIFY_ARABIC_SEEN_M: win32more.Windows.Win32.Globalization.SCRIPT_JUSTIFY = 15
class SCRIPT_LOGATTR(Structure):
    fSoftBreak: Annotated[Byte, 1]
    fWhiteSpace: Annotated[Byte, 1]
    fCharStop: Annotated[Byte, 1]
    fWordStop: Annotated[Byte, 1]
    fInvalid: Annotated[Byte, 1]
    fReserved: Annotated[Byte, 3]
class SCRIPT_PROPERTIES(Structure):
    langid: Annotated[UInt32, 16]
    fNumeric: Annotated[UInt32, 1]
    fComplex: Annotated[UInt32, 1]
    fNeedsWordBreaking: Annotated[UInt32, 1]
    fNeedsCaretInfo: Annotated[UInt32, 1]
    bCharSet: Annotated[UInt32, 8]
    fControl: Annotated[UInt32, 1]
    fPrivateUseArea: Annotated[UInt32, 1]
    fNeedsCharacterJustify: Annotated[UInt32, 1]
    fInvalidGlyph: Annotated[UInt32, 1]
    fInvalidLogAttr: Annotated[UInt32, 1]
    fCDM: Annotated[UInt32, 1]
    fAmbiguousCharSet: Annotated[UInt32, 1]
    fClusterSizeVaries: Annotated[UInt32, 1]
    fRejectInvalid: Annotated[UInt32, 1]
class SCRIPT_STATE(Structure):
    uBidiLevel: Annotated[UInt16, 5]
    fOverrideDirection: Annotated[UInt16, 1]
    fInhibitSymSwap: Annotated[UInt16, 1]
    fCharShape: Annotated[UInt16, 1]
    fDigitSubstitute: Annotated[UInt16, 1]
    fInhibitLigate: Annotated[UInt16, 1]
    fDisplayZWG: Annotated[UInt16, 1]
    fArabicNumContext: Annotated[UInt16, 1]
    fGcpClusters: Annotated[UInt16, 1]
    fReserved: Annotated[UInt16, 1]
    fEngineReserved: Annotated[UInt16, 2]
class SCRIPT_TABDEF(Structure):
    cTabStops: Int32
    iScale: Int32
    pTabStops: POINTER(Int32)
    iTabOrigin: Int32
class SCRIPT_VISATTR(Structure):
    uJustification: Annotated[UInt16, 4]
    fClusterStart: Annotated[UInt16, 1]
    fDiacritic: Annotated[UInt16, 1]
    fZeroWidth: Annotated[UInt16, 1]
    fReserved: Annotated[UInt16, 1]
    fShapeReserved: Annotated[UInt16, 8]
SYSGEOCLASS = Int32
GEOCLASS_NATION: win32more.Windows.Win32.Globalization.SYSGEOCLASS = 16
GEOCLASS_REGION: win32more.Windows.Win32.Globalization.SYSGEOCLASS = 14
GEOCLASS_ALL: win32more.Windows.Win32.Globalization.SYSGEOCLASS = 0
SYSGEOTYPE = Int32
GEO_NATION: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 1
GEO_LATITUDE: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 2
GEO_LONGITUDE: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 3
GEO_ISO2: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 4
GEO_ISO3: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 5
GEO_RFC1766: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 6
GEO_LCID: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 7
GEO_FRIENDLYNAME: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 8
GEO_OFFICIALNAME: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 9
GEO_TIMEZONES: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 10
GEO_OFFICIALLANGUAGES: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 11
GEO_ISO_UN_NUMBER: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 12
GEO_PARENT: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 13
GEO_DIALINGCODE: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 14
GEO_CURRENCYCODE: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 15
GEO_CURRENCYSYMBOL: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 16
GEO_NAME: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 17
GEO_ID: win32more.Windows.Win32.Globalization.SYSGEOTYPE = 18
SYSNLS_FUNCTION = Int32
COMPARE_STRING: win32more.Windows.Win32.Globalization.SYSNLS_FUNCTION = 1
SpellCheckerFactory = Guid('{7ab36653-1796-484b-bdfa-e74f1db7c1dc}')
class TEXTRANGE_PROPERTIES(Structure):
    potfRecords: POINTER(win32more.Windows.Win32.Globalization.OPENTYPE_FEATURE_RECORD)
    cotfRecords: Int32
@winfunctype_pointer
def TIMEFMT_ENUMPROCA(param0: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def TIMEFMT_ENUMPROCEX(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def TIMEFMT_ENUMPROCW(param0: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
TIMEFMT_ENUMPROC = UnicodeAlias('TIMEFMT_ENUMPROCW')
TIME_FORMAT_FLAGS = UInt32
TIME_NOMINUTESORSECONDS: win32more.Windows.Win32.Globalization.TIME_FORMAT_FLAGS = 1
TIME_NOSECONDS: win32more.Windows.Win32.Globalization.TIME_FORMAT_FLAGS = 2
TIME_NOTIMEMARKER: win32more.Windows.Win32.Globalization.TIME_FORMAT_FLAGS = 4
TIME_FORCE24HOURFORMAT: win32more.Windows.Win32.Globalization.TIME_FORMAT_FLAGS = 8
TRANSLATE_CHARSET_INFO_FLAGS = UInt32
TCI_SRCCHARSET: win32more.Windows.Win32.Globalization.TRANSLATE_CHARSET_INFO_FLAGS = 1
TCI_SRCCODEPAGE: win32more.Windows.Win32.Globalization.TRANSLATE_CHARSET_INFO_FLAGS = 2
TCI_SRCFONTSIG: win32more.Windows.Win32.Globalization.TRANSLATE_CHARSET_INFO_FLAGS = 3
TCI_SRCLOCALE: win32more.Windows.Win32.Globalization.TRANSLATE_CHARSET_INFO_FLAGS = 4096
UAcceptResult = Int32
ULOC_ACCEPT_FAILED: win32more.Windows.Win32.Globalization.UAcceptResult = 0
ULOC_ACCEPT_VALID: win32more.Windows.Win32.Globalization.UAcceptResult = 1
ULOC_ACCEPT_FALLBACK: win32more.Windows.Win32.Globalization.UAcceptResult = 2
UAlphabeticIndexLabelType = Int32
U_ALPHAINDEX_NORMAL: win32more.Windows.Win32.Globalization.UAlphabeticIndexLabelType = 0
U_ALPHAINDEX_UNDERFLOW: win32more.Windows.Win32.Globalization.UAlphabeticIndexLabelType = 1
U_ALPHAINDEX_INFLOW: win32more.Windows.Win32.Globalization.UAlphabeticIndexLabelType = 2
U_ALPHAINDEX_OVERFLOW: win32more.Windows.Win32.Globalization.UAlphabeticIndexLabelType = 3
UBiDi = IntPtr
@cfunctype_pointer
def UBiDiClassCallback(context: VoidPtr, c: Int32) -> win32more.Windows.Win32.Globalization.UCharDirection: ...
UBiDiDirection = Int32
UBIDI_LTR: win32more.Windows.Win32.Globalization.UBiDiDirection = 0
UBIDI_RTL: win32more.Windows.Win32.Globalization.UBiDiDirection = 1
UBIDI_MIXED: win32more.Windows.Win32.Globalization.UBiDiDirection = 2
UBIDI_NEUTRAL: win32more.Windows.Win32.Globalization.UBiDiDirection = 3
UBiDiMirroring = Int32
UBIDI_MIRRORING_OFF: win32more.Windows.Win32.Globalization.UBiDiMirroring = 0
UBIDI_MIRRORING_ON: win32more.Windows.Win32.Globalization.UBiDiMirroring = 1
UBiDiOrder = Int32
UBIDI_LOGICAL: win32more.Windows.Win32.Globalization.UBiDiOrder = 0
UBIDI_VISUAL: win32more.Windows.Win32.Globalization.UBiDiOrder = 1
UBiDiReorderingMode = Int32
UBIDI_REORDER_DEFAULT: win32more.Windows.Win32.Globalization.UBiDiReorderingMode = 0
UBIDI_REORDER_NUMBERS_SPECIAL: win32more.Windows.Win32.Globalization.UBiDiReorderingMode = 1
UBIDI_REORDER_GROUP_NUMBERS_WITH_R: win32more.Windows.Win32.Globalization.UBiDiReorderingMode = 2
UBIDI_REORDER_RUNS_ONLY: win32more.Windows.Win32.Globalization.UBiDiReorderingMode = 3
UBIDI_REORDER_INVERSE_NUMBERS_AS_L: win32more.Windows.Win32.Globalization.UBiDiReorderingMode = 4
UBIDI_REORDER_INVERSE_LIKE_DIRECT: win32more.Windows.Win32.Globalization.UBiDiReorderingMode = 5
UBIDI_REORDER_INVERSE_FOR_NUMBERS_SPECIAL: win32more.Windows.Win32.Globalization.UBiDiReorderingMode = 6
UBiDiReorderingOption = Int32
UBIDI_OPTION_DEFAULT: win32more.Windows.Win32.Globalization.UBiDiReorderingOption = 0
UBIDI_OPTION_INSERT_MARKS: win32more.Windows.Win32.Globalization.UBiDiReorderingOption = 1
UBIDI_OPTION_REMOVE_CONTROLS: win32more.Windows.Win32.Globalization.UBiDiReorderingOption = 2
UBIDI_OPTION_STREAMING: win32more.Windows.Win32.Globalization.UBiDiReorderingOption = 4
UBiDiTransform = IntPtr
UBidiPairedBracketType = Int32
U_BPT_NONE: win32more.Windows.Win32.Globalization.UBidiPairedBracketType = 0
U_BPT_OPEN: win32more.Windows.Win32.Globalization.UBidiPairedBracketType = 1
U_BPT_CLOSE: win32more.Windows.Win32.Globalization.UBidiPairedBracketType = 2
UBlockCode = Int32
UBLOCK_NO_BLOCK: win32more.Windows.Win32.Globalization.UBlockCode = 0
UBLOCK_BASIC_LATIN: win32more.Windows.Win32.Globalization.UBlockCode = 1
UBLOCK_LATIN_1_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 2
UBLOCK_LATIN_EXTENDED_A: win32more.Windows.Win32.Globalization.UBlockCode = 3
UBLOCK_LATIN_EXTENDED_B: win32more.Windows.Win32.Globalization.UBlockCode = 4
UBLOCK_IPA_EXTENSIONS: win32more.Windows.Win32.Globalization.UBlockCode = 5
UBLOCK_SPACING_MODIFIER_LETTERS: win32more.Windows.Win32.Globalization.UBlockCode = 6
UBLOCK_COMBINING_DIACRITICAL_MARKS: win32more.Windows.Win32.Globalization.UBlockCode = 7
UBLOCK_GREEK: win32more.Windows.Win32.Globalization.UBlockCode = 8
UBLOCK_CYRILLIC: win32more.Windows.Win32.Globalization.UBlockCode = 9
UBLOCK_ARMENIAN: win32more.Windows.Win32.Globalization.UBlockCode = 10
UBLOCK_HEBREW: win32more.Windows.Win32.Globalization.UBlockCode = 11
UBLOCK_ARABIC: win32more.Windows.Win32.Globalization.UBlockCode = 12
UBLOCK_SYRIAC: win32more.Windows.Win32.Globalization.UBlockCode = 13
UBLOCK_THAANA: win32more.Windows.Win32.Globalization.UBlockCode = 14
UBLOCK_DEVANAGARI: win32more.Windows.Win32.Globalization.UBlockCode = 15
UBLOCK_BENGALI: win32more.Windows.Win32.Globalization.UBlockCode = 16
UBLOCK_GURMUKHI: win32more.Windows.Win32.Globalization.UBlockCode = 17
UBLOCK_GUJARATI: win32more.Windows.Win32.Globalization.UBlockCode = 18
UBLOCK_ORIYA: win32more.Windows.Win32.Globalization.UBlockCode = 19
UBLOCK_TAMIL: win32more.Windows.Win32.Globalization.UBlockCode = 20
UBLOCK_TELUGU: win32more.Windows.Win32.Globalization.UBlockCode = 21
UBLOCK_KANNADA: win32more.Windows.Win32.Globalization.UBlockCode = 22
UBLOCK_MALAYALAM: win32more.Windows.Win32.Globalization.UBlockCode = 23
UBLOCK_SINHALA: win32more.Windows.Win32.Globalization.UBlockCode = 24
UBLOCK_THAI: win32more.Windows.Win32.Globalization.UBlockCode = 25
UBLOCK_LAO: win32more.Windows.Win32.Globalization.UBlockCode = 26
UBLOCK_TIBETAN: win32more.Windows.Win32.Globalization.UBlockCode = 27
UBLOCK_MYANMAR: win32more.Windows.Win32.Globalization.UBlockCode = 28
UBLOCK_GEORGIAN: win32more.Windows.Win32.Globalization.UBlockCode = 29
UBLOCK_HANGUL_JAMO: win32more.Windows.Win32.Globalization.UBlockCode = 30
UBLOCK_ETHIOPIC: win32more.Windows.Win32.Globalization.UBlockCode = 31
UBLOCK_CHEROKEE: win32more.Windows.Win32.Globalization.UBlockCode = 32
UBLOCK_UNIFIED_CANADIAN_ABORIGINAL_SYLLABICS: win32more.Windows.Win32.Globalization.UBlockCode = 33
UBLOCK_OGHAM: win32more.Windows.Win32.Globalization.UBlockCode = 34
UBLOCK_RUNIC: win32more.Windows.Win32.Globalization.UBlockCode = 35
UBLOCK_KHMER: win32more.Windows.Win32.Globalization.UBlockCode = 36
UBLOCK_MONGOLIAN: win32more.Windows.Win32.Globalization.UBlockCode = 37
UBLOCK_LATIN_EXTENDED_ADDITIONAL: win32more.Windows.Win32.Globalization.UBlockCode = 38
UBLOCK_GREEK_EXTENDED: win32more.Windows.Win32.Globalization.UBlockCode = 39
UBLOCK_GENERAL_PUNCTUATION: win32more.Windows.Win32.Globalization.UBlockCode = 40
UBLOCK_SUPERSCRIPTS_AND_SUBSCRIPTS: win32more.Windows.Win32.Globalization.UBlockCode = 41
UBLOCK_CURRENCY_SYMBOLS: win32more.Windows.Win32.Globalization.UBlockCode = 42
UBLOCK_COMBINING_MARKS_FOR_SYMBOLS: win32more.Windows.Win32.Globalization.UBlockCode = 43
UBLOCK_LETTERLIKE_SYMBOLS: win32more.Windows.Win32.Globalization.UBlockCode = 44
UBLOCK_NUMBER_FORMS: win32more.Windows.Win32.Globalization.UBlockCode = 45
UBLOCK_ARROWS: win32more.Windows.Win32.Globalization.UBlockCode = 46
UBLOCK_MATHEMATICAL_OPERATORS: win32more.Windows.Win32.Globalization.UBlockCode = 47
UBLOCK_MISCELLANEOUS_TECHNICAL: win32more.Windows.Win32.Globalization.UBlockCode = 48
UBLOCK_CONTROL_PICTURES: win32more.Windows.Win32.Globalization.UBlockCode = 49
UBLOCK_OPTICAL_CHARACTER_RECOGNITION: win32more.Windows.Win32.Globalization.UBlockCode = 50
UBLOCK_ENCLOSED_ALPHANUMERICS: win32more.Windows.Win32.Globalization.UBlockCode = 51
UBLOCK_BOX_DRAWING: win32more.Windows.Win32.Globalization.UBlockCode = 52
UBLOCK_BLOCK_ELEMENTS: win32more.Windows.Win32.Globalization.UBlockCode = 53
UBLOCK_GEOMETRIC_SHAPES: win32more.Windows.Win32.Globalization.UBlockCode = 54
UBLOCK_MISCELLANEOUS_SYMBOLS: win32more.Windows.Win32.Globalization.UBlockCode = 55
UBLOCK_DINGBATS: win32more.Windows.Win32.Globalization.UBlockCode = 56
UBLOCK_BRAILLE_PATTERNS: win32more.Windows.Win32.Globalization.UBlockCode = 57
UBLOCK_CJK_RADICALS_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 58
UBLOCK_KANGXI_RADICALS: win32more.Windows.Win32.Globalization.UBlockCode = 59
UBLOCK_IDEOGRAPHIC_DESCRIPTION_CHARACTERS: win32more.Windows.Win32.Globalization.UBlockCode = 60
UBLOCK_CJK_SYMBOLS_AND_PUNCTUATION: win32more.Windows.Win32.Globalization.UBlockCode = 61
UBLOCK_HIRAGANA: win32more.Windows.Win32.Globalization.UBlockCode = 62
UBLOCK_KATAKANA: win32more.Windows.Win32.Globalization.UBlockCode = 63
UBLOCK_BOPOMOFO: win32more.Windows.Win32.Globalization.UBlockCode = 64
UBLOCK_HANGUL_COMPATIBILITY_JAMO: win32more.Windows.Win32.Globalization.UBlockCode = 65
UBLOCK_KANBUN: win32more.Windows.Win32.Globalization.UBlockCode = 66
UBLOCK_BOPOMOFO_EXTENDED: win32more.Windows.Win32.Globalization.UBlockCode = 67
UBLOCK_ENCLOSED_CJK_LETTERS_AND_MONTHS: win32more.Windows.Win32.Globalization.UBlockCode = 68
UBLOCK_CJK_COMPATIBILITY: win32more.Windows.Win32.Globalization.UBlockCode = 69
UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_A: win32more.Windows.Win32.Globalization.UBlockCode = 70
UBLOCK_CJK_UNIFIED_IDEOGRAPHS: win32more.Windows.Win32.Globalization.UBlockCode = 71
UBLOCK_YI_SYLLABLES: win32more.Windows.Win32.Globalization.UBlockCode = 72
UBLOCK_YI_RADICALS: win32more.Windows.Win32.Globalization.UBlockCode = 73
UBLOCK_HANGUL_SYLLABLES: win32more.Windows.Win32.Globalization.UBlockCode = 74
UBLOCK_HIGH_SURROGATES: win32more.Windows.Win32.Globalization.UBlockCode = 75
UBLOCK_HIGH_PRIVATE_USE_SURROGATES: win32more.Windows.Win32.Globalization.UBlockCode = 76
UBLOCK_LOW_SURROGATES: win32more.Windows.Win32.Globalization.UBlockCode = 77
UBLOCK_PRIVATE_USE_AREA: win32more.Windows.Win32.Globalization.UBlockCode = 78
UBLOCK_PRIVATE_USE: win32more.Windows.Win32.Globalization.UBlockCode = 78
UBLOCK_CJK_COMPATIBILITY_IDEOGRAPHS: win32more.Windows.Win32.Globalization.UBlockCode = 79
UBLOCK_ALPHABETIC_PRESENTATION_FORMS: win32more.Windows.Win32.Globalization.UBlockCode = 80
UBLOCK_ARABIC_PRESENTATION_FORMS_A: win32more.Windows.Win32.Globalization.UBlockCode = 81
UBLOCK_COMBINING_HALF_MARKS: win32more.Windows.Win32.Globalization.UBlockCode = 82
UBLOCK_CJK_COMPATIBILITY_FORMS: win32more.Windows.Win32.Globalization.UBlockCode = 83
UBLOCK_SMALL_FORM_VARIANTS: win32more.Windows.Win32.Globalization.UBlockCode = 84
UBLOCK_ARABIC_PRESENTATION_FORMS_B: win32more.Windows.Win32.Globalization.UBlockCode = 85
UBLOCK_SPECIALS: win32more.Windows.Win32.Globalization.UBlockCode = 86
UBLOCK_HALFWIDTH_AND_FULLWIDTH_FORMS: win32more.Windows.Win32.Globalization.UBlockCode = 87
UBLOCK_OLD_ITALIC: win32more.Windows.Win32.Globalization.UBlockCode = 88
UBLOCK_GOTHIC: win32more.Windows.Win32.Globalization.UBlockCode = 89
UBLOCK_DESERET: win32more.Windows.Win32.Globalization.UBlockCode = 90
UBLOCK_BYZANTINE_MUSICAL_SYMBOLS: win32more.Windows.Win32.Globalization.UBlockCode = 91
UBLOCK_MUSICAL_SYMBOLS: win32more.Windows.Win32.Globalization.UBlockCode = 92
UBLOCK_MATHEMATICAL_ALPHANUMERIC_SYMBOLS: win32more.Windows.Win32.Globalization.UBlockCode = 93
UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_B: win32more.Windows.Win32.Globalization.UBlockCode = 94
UBLOCK_CJK_COMPATIBILITY_IDEOGRAPHS_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 95
UBLOCK_TAGS: win32more.Windows.Win32.Globalization.UBlockCode = 96
UBLOCK_CYRILLIC_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 97
UBLOCK_CYRILLIC_SUPPLEMENTARY: win32more.Windows.Win32.Globalization.UBlockCode = 97
UBLOCK_TAGALOG: win32more.Windows.Win32.Globalization.UBlockCode = 98
UBLOCK_HANUNOO: win32more.Windows.Win32.Globalization.UBlockCode = 99
UBLOCK_BUHID: win32more.Windows.Win32.Globalization.UBlockCode = 100
UBLOCK_TAGBANWA: win32more.Windows.Win32.Globalization.UBlockCode = 101
UBLOCK_MISCELLANEOUS_MATHEMATICAL_SYMBOLS_A: win32more.Windows.Win32.Globalization.UBlockCode = 102
UBLOCK_SUPPLEMENTAL_ARROWS_A: win32more.Windows.Win32.Globalization.UBlockCode = 103
UBLOCK_SUPPLEMENTAL_ARROWS_B: win32more.Windows.Win32.Globalization.UBlockCode = 104
UBLOCK_MISCELLANEOUS_MATHEMATICAL_SYMBOLS_B: win32more.Windows.Win32.Globalization.UBlockCode = 105
UBLOCK_SUPPLEMENTAL_MATHEMATICAL_OPERATORS: win32more.Windows.Win32.Globalization.UBlockCode = 106
UBLOCK_KATAKANA_PHONETIC_EXTENSIONS: win32more.Windows.Win32.Globalization.UBlockCode = 107
UBLOCK_VARIATION_SELECTORS: win32more.Windows.Win32.Globalization.UBlockCode = 108
UBLOCK_SUPPLEMENTARY_PRIVATE_USE_AREA_A: win32more.Windows.Win32.Globalization.UBlockCode = 109
UBLOCK_SUPPLEMENTARY_PRIVATE_USE_AREA_B: win32more.Windows.Win32.Globalization.UBlockCode = 110
UBLOCK_LIMBU: win32more.Windows.Win32.Globalization.UBlockCode = 111
UBLOCK_TAI_LE: win32more.Windows.Win32.Globalization.UBlockCode = 112
UBLOCK_KHMER_SYMBOLS: win32more.Windows.Win32.Globalization.UBlockCode = 113
UBLOCK_PHONETIC_EXTENSIONS: win32more.Windows.Win32.Globalization.UBlockCode = 114
UBLOCK_MISCELLANEOUS_SYMBOLS_AND_ARROWS: win32more.Windows.Win32.Globalization.UBlockCode = 115
UBLOCK_YIJING_HEXAGRAM_SYMBOLS: win32more.Windows.Win32.Globalization.UBlockCode = 116
UBLOCK_LINEAR_B_SYLLABARY: win32more.Windows.Win32.Globalization.UBlockCode = 117
UBLOCK_LINEAR_B_IDEOGRAMS: win32more.Windows.Win32.Globalization.UBlockCode = 118
UBLOCK_AEGEAN_NUMBERS: win32more.Windows.Win32.Globalization.UBlockCode = 119
UBLOCK_UGARITIC: win32more.Windows.Win32.Globalization.UBlockCode = 120
UBLOCK_SHAVIAN: win32more.Windows.Win32.Globalization.UBlockCode = 121
UBLOCK_OSMANYA: win32more.Windows.Win32.Globalization.UBlockCode = 122
UBLOCK_CYPRIOT_SYLLABARY: win32more.Windows.Win32.Globalization.UBlockCode = 123
UBLOCK_TAI_XUAN_JING_SYMBOLS: win32more.Windows.Win32.Globalization.UBlockCode = 124
UBLOCK_VARIATION_SELECTORS_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 125
UBLOCK_ANCIENT_GREEK_MUSICAL_NOTATION: win32more.Windows.Win32.Globalization.UBlockCode = 126
UBLOCK_ANCIENT_GREEK_NUMBERS: win32more.Windows.Win32.Globalization.UBlockCode = 127
UBLOCK_ARABIC_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 128
UBLOCK_BUGINESE: win32more.Windows.Win32.Globalization.UBlockCode = 129
UBLOCK_CJK_STROKES: win32more.Windows.Win32.Globalization.UBlockCode = 130
UBLOCK_COMBINING_DIACRITICAL_MARKS_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 131
UBLOCK_COPTIC: win32more.Windows.Win32.Globalization.UBlockCode = 132
UBLOCK_ETHIOPIC_EXTENDED: win32more.Windows.Win32.Globalization.UBlockCode = 133
UBLOCK_ETHIOPIC_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 134
UBLOCK_GEORGIAN_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 135
UBLOCK_GLAGOLITIC: win32more.Windows.Win32.Globalization.UBlockCode = 136
UBLOCK_KHAROSHTHI: win32more.Windows.Win32.Globalization.UBlockCode = 137
UBLOCK_MODIFIER_TONE_LETTERS: win32more.Windows.Win32.Globalization.UBlockCode = 138
UBLOCK_NEW_TAI_LUE: win32more.Windows.Win32.Globalization.UBlockCode = 139
UBLOCK_OLD_PERSIAN: win32more.Windows.Win32.Globalization.UBlockCode = 140
UBLOCK_PHONETIC_EXTENSIONS_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 141
UBLOCK_SUPPLEMENTAL_PUNCTUATION: win32more.Windows.Win32.Globalization.UBlockCode = 142
UBLOCK_SYLOTI_NAGRI: win32more.Windows.Win32.Globalization.UBlockCode = 143
UBLOCK_TIFINAGH: win32more.Windows.Win32.Globalization.UBlockCode = 144
UBLOCK_VERTICAL_FORMS: win32more.Windows.Win32.Globalization.UBlockCode = 145
UBLOCK_NKO: win32more.Windows.Win32.Globalization.UBlockCode = 146
UBLOCK_BALINESE: win32more.Windows.Win32.Globalization.UBlockCode = 147
UBLOCK_LATIN_EXTENDED_C: win32more.Windows.Win32.Globalization.UBlockCode = 148
UBLOCK_LATIN_EXTENDED_D: win32more.Windows.Win32.Globalization.UBlockCode = 149
UBLOCK_PHAGS_PA: win32more.Windows.Win32.Globalization.UBlockCode = 150
UBLOCK_PHOENICIAN: win32more.Windows.Win32.Globalization.UBlockCode = 151
UBLOCK_CUNEIFORM: win32more.Windows.Win32.Globalization.UBlockCode = 152
UBLOCK_CUNEIFORM_NUMBERS_AND_PUNCTUATION: win32more.Windows.Win32.Globalization.UBlockCode = 153
UBLOCK_COUNTING_ROD_NUMERALS: win32more.Windows.Win32.Globalization.UBlockCode = 154
UBLOCK_SUNDANESE: win32more.Windows.Win32.Globalization.UBlockCode = 155
UBLOCK_LEPCHA: win32more.Windows.Win32.Globalization.UBlockCode = 156
UBLOCK_OL_CHIKI: win32more.Windows.Win32.Globalization.UBlockCode = 157
UBLOCK_CYRILLIC_EXTENDED_A: win32more.Windows.Win32.Globalization.UBlockCode = 158
UBLOCK_VAI: win32more.Windows.Win32.Globalization.UBlockCode = 159
UBLOCK_CYRILLIC_EXTENDED_B: win32more.Windows.Win32.Globalization.UBlockCode = 160
UBLOCK_SAURASHTRA: win32more.Windows.Win32.Globalization.UBlockCode = 161
UBLOCK_KAYAH_LI: win32more.Windows.Win32.Globalization.UBlockCode = 162
UBLOCK_REJANG: win32more.Windows.Win32.Globalization.UBlockCode = 163
UBLOCK_CHAM: win32more.Windows.Win32.Globalization.UBlockCode = 164
UBLOCK_ANCIENT_SYMBOLS: win32more.Windows.Win32.Globalization.UBlockCode = 165
UBLOCK_PHAISTOS_DISC: win32more.Windows.Win32.Globalization.UBlockCode = 166
UBLOCK_LYCIAN: win32more.Windows.Win32.Globalization.UBlockCode = 167
UBLOCK_CARIAN: win32more.Windows.Win32.Globalization.UBlockCode = 168
UBLOCK_LYDIAN: win32more.Windows.Win32.Globalization.UBlockCode = 169
UBLOCK_MAHJONG_TILES: win32more.Windows.Win32.Globalization.UBlockCode = 170
UBLOCK_DOMINO_TILES: win32more.Windows.Win32.Globalization.UBlockCode = 171
UBLOCK_SAMARITAN: win32more.Windows.Win32.Globalization.UBlockCode = 172
UBLOCK_UNIFIED_CANADIAN_ABORIGINAL_SYLLABICS_EXTENDED: win32more.Windows.Win32.Globalization.UBlockCode = 173
UBLOCK_TAI_THAM: win32more.Windows.Win32.Globalization.UBlockCode = 174
UBLOCK_VEDIC_EXTENSIONS: win32more.Windows.Win32.Globalization.UBlockCode = 175
UBLOCK_LISU: win32more.Windows.Win32.Globalization.UBlockCode = 176
UBLOCK_BAMUM: win32more.Windows.Win32.Globalization.UBlockCode = 177
UBLOCK_COMMON_INDIC_NUMBER_FORMS: win32more.Windows.Win32.Globalization.UBlockCode = 178
UBLOCK_DEVANAGARI_EXTENDED: win32more.Windows.Win32.Globalization.UBlockCode = 179
UBLOCK_HANGUL_JAMO_EXTENDED_A: win32more.Windows.Win32.Globalization.UBlockCode = 180
UBLOCK_JAVANESE: win32more.Windows.Win32.Globalization.UBlockCode = 181
UBLOCK_MYANMAR_EXTENDED_A: win32more.Windows.Win32.Globalization.UBlockCode = 182
UBLOCK_TAI_VIET: win32more.Windows.Win32.Globalization.UBlockCode = 183
UBLOCK_MEETEI_MAYEK: win32more.Windows.Win32.Globalization.UBlockCode = 184
UBLOCK_HANGUL_JAMO_EXTENDED_B: win32more.Windows.Win32.Globalization.UBlockCode = 185
UBLOCK_IMPERIAL_ARAMAIC: win32more.Windows.Win32.Globalization.UBlockCode = 186
UBLOCK_OLD_SOUTH_ARABIAN: win32more.Windows.Win32.Globalization.UBlockCode = 187
UBLOCK_AVESTAN: win32more.Windows.Win32.Globalization.UBlockCode = 188
UBLOCK_INSCRIPTIONAL_PARTHIAN: win32more.Windows.Win32.Globalization.UBlockCode = 189
UBLOCK_INSCRIPTIONAL_PAHLAVI: win32more.Windows.Win32.Globalization.UBlockCode = 190
UBLOCK_OLD_TURKIC: win32more.Windows.Win32.Globalization.UBlockCode = 191
UBLOCK_RUMI_NUMERAL_SYMBOLS: win32more.Windows.Win32.Globalization.UBlockCode = 192
UBLOCK_KAITHI: win32more.Windows.Win32.Globalization.UBlockCode = 193
UBLOCK_EGYPTIAN_HIEROGLYPHS: win32more.Windows.Win32.Globalization.UBlockCode = 194
UBLOCK_ENCLOSED_ALPHANUMERIC_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 195
UBLOCK_ENCLOSED_IDEOGRAPHIC_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 196
UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_C: win32more.Windows.Win32.Globalization.UBlockCode = 197
UBLOCK_MANDAIC: win32more.Windows.Win32.Globalization.UBlockCode = 198
UBLOCK_BATAK: win32more.Windows.Win32.Globalization.UBlockCode = 199
UBLOCK_ETHIOPIC_EXTENDED_A: win32more.Windows.Win32.Globalization.UBlockCode = 200
UBLOCK_BRAHMI: win32more.Windows.Win32.Globalization.UBlockCode = 201
UBLOCK_BAMUM_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 202
UBLOCK_KANA_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 203
UBLOCK_PLAYING_CARDS: win32more.Windows.Win32.Globalization.UBlockCode = 204
UBLOCK_MISCELLANEOUS_SYMBOLS_AND_PICTOGRAPHS: win32more.Windows.Win32.Globalization.UBlockCode = 205
UBLOCK_EMOTICONS: win32more.Windows.Win32.Globalization.UBlockCode = 206
UBLOCK_TRANSPORT_AND_MAP_SYMBOLS: win32more.Windows.Win32.Globalization.UBlockCode = 207
UBLOCK_ALCHEMICAL_SYMBOLS: win32more.Windows.Win32.Globalization.UBlockCode = 208
UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_D: win32more.Windows.Win32.Globalization.UBlockCode = 209
UBLOCK_ARABIC_EXTENDED_A: win32more.Windows.Win32.Globalization.UBlockCode = 210
UBLOCK_ARABIC_MATHEMATICAL_ALPHABETIC_SYMBOLS: win32more.Windows.Win32.Globalization.UBlockCode = 211
UBLOCK_CHAKMA: win32more.Windows.Win32.Globalization.UBlockCode = 212
UBLOCK_MEETEI_MAYEK_EXTENSIONS: win32more.Windows.Win32.Globalization.UBlockCode = 213
UBLOCK_MEROITIC_CURSIVE: win32more.Windows.Win32.Globalization.UBlockCode = 214
UBLOCK_MEROITIC_HIEROGLYPHS: win32more.Windows.Win32.Globalization.UBlockCode = 215
UBLOCK_MIAO: win32more.Windows.Win32.Globalization.UBlockCode = 216
UBLOCK_SHARADA: win32more.Windows.Win32.Globalization.UBlockCode = 217
UBLOCK_SORA_SOMPENG: win32more.Windows.Win32.Globalization.UBlockCode = 218
UBLOCK_SUNDANESE_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 219
UBLOCK_TAKRI: win32more.Windows.Win32.Globalization.UBlockCode = 220
UBLOCK_BASSA_VAH: win32more.Windows.Win32.Globalization.UBlockCode = 221
UBLOCK_CAUCASIAN_ALBANIAN: win32more.Windows.Win32.Globalization.UBlockCode = 222
UBLOCK_COPTIC_EPACT_NUMBERS: win32more.Windows.Win32.Globalization.UBlockCode = 223
UBLOCK_COMBINING_DIACRITICAL_MARKS_EXTENDED: win32more.Windows.Win32.Globalization.UBlockCode = 224
UBLOCK_DUPLOYAN: win32more.Windows.Win32.Globalization.UBlockCode = 225
UBLOCK_ELBASAN: win32more.Windows.Win32.Globalization.UBlockCode = 226
UBLOCK_GEOMETRIC_SHAPES_EXTENDED: win32more.Windows.Win32.Globalization.UBlockCode = 227
UBLOCK_GRANTHA: win32more.Windows.Win32.Globalization.UBlockCode = 228
UBLOCK_KHOJKI: win32more.Windows.Win32.Globalization.UBlockCode = 229
UBLOCK_KHUDAWADI: win32more.Windows.Win32.Globalization.UBlockCode = 230
UBLOCK_LATIN_EXTENDED_E: win32more.Windows.Win32.Globalization.UBlockCode = 231
UBLOCK_LINEAR_A: win32more.Windows.Win32.Globalization.UBlockCode = 232
UBLOCK_MAHAJANI: win32more.Windows.Win32.Globalization.UBlockCode = 233
UBLOCK_MANICHAEAN: win32more.Windows.Win32.Globalization.UBlockCode = 234
UBLOCK_MENDE_KIKAKUI: win32more.Windows.Win32.Globalization.UBlockCode = 235
UBLOCK_MODI: win32more.Windows.Win32.Globalization.UBlockCode = 236
UBLOCK_MRO: win32more.Windows.Win32.Globalization.UBlockCode = 237
UBLOCK_MYANMAR_EXTENDED_B: win32more.Windows.Win32.Globalization.UBlockCode = 238
UBLOCK_NABATAEAN: win32more.Windows.Win32.Globalization.UBlockCode = 239
UBLOCK_OLD_NORTH_ARABIAN: win32more.Windows.Win32.Globalization.UBlockCode = 240
UBLOCK_OLD_PERMIC: win32more.Windows.Win32.Globalization.UBlockCode = 241
UBLOCK_ORNAMENTAL_DINGBATS: win32more.Windows.Win32.Globalization.UBlockCode = 242
UBLOCK_PAHAWH_HMONG: win32more.Windows.Win32.Globalization.UBlockCode = 243
UBLOCK_PALMYRENE: win32more.Windows.Win32.Globalization.UBlockCode = 244
UBLOCK_PAU_CIN_HAU: win32more.Windows.Win32.Globalization.UBlockCode = 245
UBLOCK_PSALTER_PAHLAVI: win32more.Windows.Win32.Globalization.UBlockCode = 246
UBLOCK_SHORTHAND_FORMAT_CONTROLS: win32more.Windows.Win32.Globalization.UBlockCode = 247
UBLOCK_SIDDHAM: win32more.Windows.Win32.Globalization.UBlockCode = 248
UBLOCK_SINHALA_ARCHAIC_NUMBERS: win32more.Windows.Win32.Globalization.UBlockCode = 249
UBLOCK_SUPPLEMENTAL_ARROWS_C: win32more.Windows.Win32.Globalization.UBlockCode = 250
UBLOCK_TIRHUTA: win32more.Windows.Win32.Globalization.UBlockCode = 251
UBLOCK_WARANG_CITI: win32more.Windows.Win32.Globalization.UBlockCode = 252
UBLOCK_AHOM: win32more.Windows.Win32.Globalization.UBlockCode = 253
UBLOCK_ANATOLIAN_HIEROGLYPHS: win32more.Windows.Win32.Globalization.UBlockCode = 254
UBLOCK_CHEROKEE_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 255
UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_E: win32more.Windows.Win32.Globalization.UBlockCode = 256
UBLOCK_EARLY_DYNASTIC_CUNEIFORM: win32more.Windows.Win32.Globalization.UBlockCode = 257
UBLOCK_HATRAN: win32more.Windows.Win32.Globalization.UBlockCode = 258
UBLOCK_MULTANI: win32more.Windows.Win32.Globalization.UBlockCode = 259
UBLOCK_OLD_HUNGARIAN: win32more.Windows.Win32.Globalization.UBlockCode = 260
UBLOCK_SUPPLEMENTAL_SYMBOLS_AND_PICTOGRAPHS: win32more.Windows.Win32.Globalization.UBlockCode = 261
UBLOCK_SUTTON_SIGNWRITING: win32more.Windows.Win32.Globalization.UBlockCode = 262
UBLOCK_ADLAM: win32more.Windows.Win32.Globalization.UBlockCode = 263
UBLOCK_BHAIKSUKI: win32more.Windows.Win32.Globalization.UBlockCode = 264
UBLOCK_CYRILLIC_EXTENDED_C: win32more.Windows.Win32.Globalization.UBlockCode = 265
UBLOCK_GLAGOLITIC_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 266
UBLOCK_IDEOGRAPHIC_SYMBOLS_AND_PUNCTUATION: win32more.Windows.Win32.Globalization.UBlockCode = 267
UBLOCK_MARCHEN: win32more.Windows.Win32.Globalization.UBlockCode = 268
UBLOCK_MONGOLIAN_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 269
UBLOCK_NEWA: win32more.Windows.Win32.Globalization.UBlockCode = 270
UBLOCK_OSAGE: win32more.Windows.Win32.Globalization.UBlockCode = 271
UBLOCK_TANGUT: win32more.Windows.Win32.Globalization.UBlockCode = 272
UBLOCK_TANGUT_COMPONENTS: win32more.Windows.Win32.Globalization.UBlockCode = 273
UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_F: win32more.Windows.Win32.Globalization.UBlockCode = 274
UBLOCK_KANA_EXTENDED_A: win32more.Windows.Win32.Globalization.UBlockCode = 275
UBLOCK_MASARAM_GONDI: win32more.Windows.Win32.Globalization.UBlockCode = 276
UBLOCK_NUSHU: win32more.Windows.Win32.Globalization.UBlockCode = 277
UBLOCK_SOYOMBO: win32more.Windows.Win32.Globalization.UBlockCode = 278
UBLOCK_SYRIAC_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 279
UBLOCK_ZANABAZAR_SQUARE: win32more.Windows.Win32.Globalization.UBlockCode = 280
UBLOCK_CHESS_SYMBOLS: win32more.Windows.Win32.Globalization.UBlockCode = 281
UBLOCK_DOGRA: win32more.Windows.Win32.Globalization.UBlockCode = 282
UBLOCK_GEORGIAN_EXTENDED: win32more.Windows.Win32.Globalization.UBlockCode = 283
UBLOCK_GUNJALA_GONDI: win32more.Windows.Win32.Globalization.UBlockCode = 284
UBLOCK_HANIFI_ROHINGYA: win32more.Windows.Win32.Globalization.UBlockCode = 285
UBLOCK_INDIC_SIYAQ_NUMBERS: win32more.Windows.Win32.Globalization.UBlockCode = 286
UBLOCK_MAKASAR: win32more.Windows.Win32.Globalization.UBlockCode = 287
UBLOCK_MAYAN_NUMERALS: win32more.Windows.Win32.Globalization.UBlockCode = 288
UBLOCK_MEDEFAIDRIN: win32more.Windows.Win32.Globalization.UBlockCode = 289
UBLOCK_OLD_SOGDIAN: win32more.Windows.Win32.Globalization.UBlockCode = 290
UBLOCK_SOGDIAN: win32more.Windows.Win32.Globalization.UBlockCode = 291
UBLOCK_EGYPTIAN_HIEROGLYPH_FORMAT_CONTROLS: win32more.Windows.Win32.Globalization.UBlockCode = 292
UBLOCK_ELYMAIC: win32more.Windows.Win32.Globalization.UBlockCode = 293
UBLOCK_NANDINAGARI: win32more.Windows.Win32.Globalization.UBlockCode = 294
UBLOCK_NYIAKENG_PUACHUE_HMONG: win32more.Windows.Win32.Globalization.UBlockCode = 295
UBLOCK_OTTOMAN_SIYAQ_NUMBERS: win32more.Windows.Win32.Globalization.UBlockCode = 296
UBLOCK_SMALL_KANA_EXTENSION: win32more.Windows.Win32.Globalization.UBlockCode = 297
UBLOCK_SYMBOLS_AND_PICTOGRAPHS_EXTENDED_A: win32more.Windows.Win32.Globalization.UBlockCode = 298
UBLOCK_TAMIL_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 299
UBLOCK_WANCHO: win32more.Windows.Win32.Globalization.UBlockCode = 300
UBLOCK_CHORASMIAN: win32more.Windows.Win32.Globalization.UBlockCode = 301
UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_G: win32more.Windows.Win32.Globalization.UBlockCode = 302
UBLOCK_DIVES_AKURU: win32more.Windows.Win32.Globalization.UBlockCode = 303
UBLOCK_KHITAN_SMALL_SCRIPT: win32more.Windows.Win32.Globalization.UBlockCode = 304
UBLOCK_LISU_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 305
UBLOCK_SYMBOLS_FOR_LEGACY_COMPUTING: win32more.Windows.Win32.Globalization.UBlockCode = 306
UBLOCK_TANGUT_SUPPLEMENT: win32more.Windows.Win32.Globalization.UBlockCode = 307
UBLOCK_YEZIDI: win32more.Windows.Win32.Globalization.UBlockCode = 308
UBLOCK_INVALID_CODE: win32more.Windows.Win32.Globalization.UBlockCode = -1
UBreakIterator = IntPtr
UBreakIteratorType = Int32
UBRK_CHARACTER: win32more.Windows.Win32.Globalization.UBreakIteratorType = 0
UBRK_WORD: win32more.Windows.Win32.Globalization.UBreakIteratorType = 1
UBRK_LINE: win32more.Windows.Win32.Globalization.UBreakIteratorType = 2
UBRK_SENTENCE: win32more.Windows.Win32.Globalization.UBreakIteratorType = 3
UCPMap = IntPtr
UCPMapRangeOption = Int32
UCPMAP_RANGE_NORMAL: win32more.Windows.Win32.Globalization.UCPMapRangeOption = 0
UCPMAP_RANGE_FIXED_LEAD_SURROGATES: win32more.Windows.Win32.Globalization.UCPMapRangeOption = 1
UCPMAP_RANGE_FIXED_ALL_SURROGATES: win32more.Windows.Win32.Globalization.UCPMapRangeOption = 2
@cfunctype_pointer
def UCPMapValueFilter(context: VoidPtr, value: UInt32) -> UInt32: ...
class UCPTrie(Structure):
    index: POINTER(UInt16)
    data: win32more.Windows.Win32.Globalization.UCPTrieData
    indexLength: Int32
    dataLength: Int32
    highStart: Int32
    shifted12HighStart: UInt16
    type: SByte
    valueWidth: SByte
    reserved32: UInt32
    reserved16: UInt16
    index3NullOffset: UInt16
    dataNullOffset: Int32
    nullValue: UInt32
class UCPTrieData(Union):
    ptr0: VoidPtr
    ptr16: POINTER(UInt16)
    ptr32: POINTER(UInt32)
    ptr8: POINTER(Byte)
UCPTrieType = Int32
UCPTRIE_TYPE_ANY: win32more.Windows.Win32.Globalization.UCPTrieType = -1
UCPTRIE_TYPE_FAST: win32more.Windows.Win32.Globalization.UCPTrieType = 0
UCPTRIE_TYPE_SMALL: win32more.Windows.Win32.Globalization.UCPTrieType = 1
UCPTrieValueWidth = Int32
UCPTRIE_VALUE_BITS_ANY: win32more.Windows.Win32.Globalization.UCPTrieValueWidth = -1
UCPTRIE_VALUE_BITS_16: win32more.Windows.Win32.Globalization.UCPTrieValueWidth = 0
UCPTRIE_VALUE_BITS_32: win32more.Windows.Win32.Globalization.UCPTrieValueWidth = 1
UCPTRIE_VALUE_BITS_8: win32more.Windows.Win32.Globalization.UCPTrieValueWidth = 2
UCalendarAMPMs = Int32
UCAL_AM: win32more.Windows.Win32.Globalization.UCalendarAMPMs = 0
UCAL_PM: win32more.Windows.Win32.Globalization.UCalendarAMPMs = 1
UCalendarAttribute = Int32
UCAL_LENIENT: win32more.Windows.Win32.Globalization.UCalendarAttribute = 0
UCAL_FIRST_DAY_OF_WEEK: win32more.Windows.Win32.Globalization.UCalendarAttribute = 1
UCAL_MINIMAL_DAYS_IN_FIRST_WEEK: win32more.Windows.Win32.Globalization.UCalendarAttribute = 2
UCAL_REPEATED_WALL_TIME: win32more.Windows.Win32.Globalization.UCalendarAttribute = 3
UCAL_SKIPPED_WALL_TIME: win32more.Windows.Win32.Globalization.UCalendarAttribute = 4
UCalendarDateFields = Int32
UCAL_ERA: win32more.Windows.Win32.Globalization.UCalendarDateFields = 0
UCAL_YEAR: win32more.Windows.Win32.Globalization.UCalendarDateFields = 1
UCAL_MONTH: win32more.Windows.Win32.Globalization.UCalendarDateFields = 2
UCAL_WEEK_OF_YEAR: win32more.Windows.Win32.Globalization.UCalendarDateFields = 3
UCAL_WEEK_OF_MONTH: win32more.Windows.Win32.Globalization.UCalendarDateFields = 4
UCAL_DATE: win32more.Windows.Win32.Globalization.UCalendarDateFields = 5
UCAL_DAY_OF_YEAR: win32more.Windows.Win32.Globalization.UCalendarDateFields = 6
UCAL_DAY_OF_WEEK: win32more.Windows.Win32.Globalization.UCalendarDateFields = 7
UCAL_DAY_OF_WEEK_IN_MONTH: win32more.Windows.Win32.Globalization.UCalendarDateFields = 8
UCAL_AM_PM: win32more.Windows.Win32.Globalization.UCalendarDateFields = 9
UCAL_HOUR: win32more.Windows.Win32.Globalization.UCalendarDateFields = 10
UCAL_HOUR_OF_DAY: win32more.Windows.Win32.Globalization.UCalendarDateFields = 11
UCAL_MINUTE: win32more.Windows.Win32.Globalization.UCalendarDateFields = 12
UCAL_SECOND: win32more.Windows.Win32.Globalization.UCalendarDateFields = 13
UCAL_MILLISECOND: win32more.Windows.Win32.Globalization.UCalendarDateFields = 14
UCAL_ZONE_OFFSET: win32more.Windows.Win32.Globalization.UCalendarDateFields = 15
UCAL_DST_OFFSET: win32more.Windows.Win32.Globalization.UCalendarDateFields = 16
UCAL_YEAR_WOY: win32more.Windows.Win32.Globalization.UCalendarDateFields = 17
UCAL_DOW_LOCAL: win32more.Windows.Win32.Globalization.UCalendarDateFields = 18
UCAL_EXTENDED_YEAR: win32more.Windows.Win32.Globalization.UCalendarDateFields = 19
UCAL_JULIAN_DAY: win32more.Windows.Win32.Globalization.UCalendarDateFields = 20
UCAL_MILLISECONDS_IN_DAY: win32more.Windows.Win32.Globalization.UCalendarDateFields = 21
UCAL_IS_LEAP_MONTH: win32more.Windows.Win32.Globalization.UCalendarDateFields = 22
UCAL_FIELD_COUNT: win32more.Windows.Win32.Globalization.UCalendarDateFields = 23
UCAL_DAY_OF_MONTH: win32more.Windows.Win32.Globalization.UCalendarDateFields = 5
UCalendarDaysOfWeek = Int32
UCAL_SUNDAY: win32more.Windows.Win32.Globalization.UCalendarDaysOfWeek = 1
UCAL_MONDAY: win32more.Windows.Win32.Globalization.UCalendarDaysOfWeek = 2
UCAL_TUESDAY: win32more.Windows.Win32.Globalization.UCalendarDaysOfWeek = 3
UCAL_WEDNESDAY: win32more.Windows.Win32.Globalization.UCalendarDaysOfWeek = 4
UCAL_THURSDAY: win32more.Windows.Win32.Globalization.UCalendarDaysOfWeek = 5
UCAL_FRIDAY: win32more.Windows.Win32.Globalization.UCalendarDaysOfWeek = 6
UCAL_SATURDAY: win32more.Windows.Win32.Globalization.UCalendarDaysOfWeek = 7
UCalendarDisplayNameType = Int32
UCAL_STANDARD: win32more.Windows.Win32.Globalization.UCalendarDisplayNameType = 0
UCAL_SHORT_STANDARD: win32more.Windows.Win32.Globalization.UCalendarDisplayNameType = 1
UCAL_DST: win32more.Windows.Win32.Globalization.UCalendarDisplayNameType = 2
UCAL_SHORT_DST: win32more.Windows.Win32.Globalization.UCalendarDisplayNameType = 3
UCalendarLimitType = Int32
UCAL_MINIMUM: win32more.Windows.Win32.Globalization.UCalendarLimitType = 0
UCAL_MAXIMUM: win32more.Windows.Win32.Globalization.UCalendarLimitType = 1
UCAL_GREATEST_MINIMUM: win32more.Windows.Win32.Globalization.UCalendarLimitType = 2
UCAL_LEAST_MAXIMUM: win32more.Windows.Win32.Globalization.UCalendarLimitType = 3
UCAL_ACTUAL_MINIMUM: win32more.Windows.Win32.Globalization.UCalendarLimitType = 4
UCAL_ACTUAL_MAXIMUM: win32more.Windows.Win32.Globalization.UCalendarLimitType = 5
UCalendarMonths = Int32
UCAL_JANUARY: win32more.Windows.Win32.Globalization.UCalendarMonths = 0
UCAL_FEBRUARY: win32more.Windows.Win32.Globalization.UCalendarMonths = 1
UCAL_MARCH: win32more.Windows.Win32.Globalization.UCalendarMonths = 2
UCAL_APRIL: win32more.Windows.Win32.Globalization.UCalendarMonths = 3
UCAL_MAY: win32more.Windows.Win32.Globalization.UCalendarMonths = 4
UCAL_JUNE: win32more.Windows.Win32.Globalization.UCalendarMonths = 5
UCAL_JULY: win32more.Windows.Win32.Globalization.UCalendarMonths = 6
UCAL_AUGUST: win32more.Windows.Win32.Globalization.UCalendarMonths = 7
UCAL_SEPTEMBER: win32more.Windows.Win32.Globalization.UCalendarMonths = 8
UCAL_OCTOBER: win32more.Windows.Win32.Globalization.UCalendarMonths = 9
UCAL_NOVEMBER: win32more.Windows.Win32.Globalization.UCalendarMonths = 10
UCAL_DECEMBER: win32more.Windows.Win32.Globalization.UCalendarMonths = 11
UCAL_UNDECIMBER: win32more.Windows.Win32.Globalization.UCalendarMonths = 12
UCalendarType = Int32
UCAL_TRADITIONAL: win32more.Windows.Win32.Globalization.UCalendarType = 0
UCAL_DEFAULT: win32more.Windows.Win32.Globalization.UCalendarType = 0
UCAL_GREGORIAN: win32more.Windows.Win32.Globalization.UCalendarType = 1
UCalendarWallTimeOption = Int32
UCAL_WALLTIME_LAST: win32more.Windows.Win32.Globalization.UCalendarWallTimeOption = 0
UCAL_WALLTIME_FIRST: win32more.Windows.Win32.Globalization.UCalendarWallTimeOption = 1
UCAL_WALLTIME_NEXT_VALID: win32more.Windows.Win32.Globalization.UCalendarWallTimeOption = 2
UCalendarWeekdayType = Int32
UCAL_WEEKDAY: win32more.Windows.Win32.Globalization.UCalendarWeekdayType = 0
UCAL_WEEKEND: win32more.Windows.Win32.Globalization.UCalendarWeekdayType = 1
UCAL_WEEKEND_ONSET: win32more.Windows.Win32.Globalization.UCalendarWeekdayType = 2
UCAL_WEEKEND_CEASE: win32more.Windows.Win32.Globalization.UCalendarWeekdayType = 3
UCaseMap = IntPtr
UCharCategory = Int32
U_UNASSIGNED: win32more.Windows.Win32.Globalization.UCharCategory = 0
U_GENERAL_OTHER_TYPES: win32more.Windows.Win32.Globalization.UCharCategory = 0
U_UPPERCASE_LETTER: win32more.Windows.Win32.Globalization.UCharCategory = 1
U_LOWERCASE_LETTER: win32more.Windows.Win32.Globalization.UCharCategory = 2
U_TITLECASE_LETTER: win32more.Windows.Win32.Globalization.UCharCategory = 3
U_MODIFIER_LETTER: win32more.Windows.Win32.Globalization.UCharCategory = 4
U_OTHER_LETTER: win32more.Windows.Win32.Globalization.UCharCategory = 5
U_NON_SPACING_MARK: win32more.Windows.Win32.Globalization.UCharCategory = 6
U_ENCLOSING_MARK: win32more.Windows.Win32.Globalization.UCharCategory = 7
U_COMBINING_SPACING_MARK: win32more.Windows.Win32.Globalization.UCharCategory = 8
U_DECIMAL_DIGIT_NUMBER: win32more.Windows.Win32.Globalization.UCharCategory = 9
U_LETTER_NUMBER: win32more.Windows.Win32.Globalization.UCharCategory = 10
U_OTHER_NUMBER: win32more.Windows.Win32.Globalization.UCharCategory = 11
U_SPACE_SEPARATOR: win32more.Windows.Win32.Globalization.UCharCategory = 12
U_LINE_SEPARATOR: win32more.Windows.Win32.Globalization.UCharCategory = 13
U_PARAGRAPH_SEPARATOR: win32more.Windows.Win32.Globalization.UCharCategory = 14
U_CONTROL_CHAR: win32more.Windows.Win32.Globalization.UCharCategory = 15
U_FORMAT_CHAR: win32more.Windows.Win32.Globalization.UCharCategory = 16
U_PRIVATE_USE_CHAR: win32more.Windows.Win32.Globalization.UCharCategory = 17
U_SURROGATE: win32more.Windows.Win32.Globalization.UCharCategory = 18
U_DASH_PUNCTUATION: win32more.Windows.Win32.Globalization.UCharCategory = 19
U_START_PUNCTUATION: win32more.Windows.Win32.Globalization.UCharCategory = 20
U_END_PUNCTUATION: win32more.Windows.Win32.Globalization.UCharCategory = 21
U_CONNECTOR_PUNCTUATION: win32more.Windows.Win32.Globalization.UCharCategory = 22
U_OTHER_PUNCTUATION: win32more.Windows.Win32.Globalization.UCharCategory = 23
U_MATH_SYMBOL: win32more.Windows.Win32.Globalization.UCharCategory = 24
U_CURRENCY_SYMBOL: win32more.Windows.Win32.Globalization.UCharCategory = 25
U_MODIFIER_SYMBOL: win32more.Windows.Win32.Globalization.UCharCategory = 26
U_OTHER_SYMBOL: win32more.Windows.Win32.Globalization.UCharCategory = 27
U_INITIAL_PUNCTUATION: win32more.Windows.Win32.Globalization.UCharCategory = 28
U_FINAL_PUNCTUATION: win32more.Windows.Win32.Globalization.UCharCategory = 29
U_CHAR_CATEGORY_COUNT: win32more.Windows.Win32.Globalization.UCharCategory = 30
UCharDirection = Int32
U_LEFT_TO_RIGHT: win32more.Windows.Win32.Globalization.UCharDirection = 0
U_RIGHT_TO_LEFT: win32more.Windows.Win32.Globalization.UCharDirection = 1
U_EUROPEAN_NUMBER: win32more.Windows.Win32.Globalization.UCharDirection = 2
U_EUROPEAN_NUMBER_SEPARATOR: win32more.Windows.Win32.Globalization.UCharDirection = 3
U_EUROPEAN_NUMBER_TERMINATOR: win32more.Windows.Win32.Globalization.UCharDirection = 4
U_ARABIC_NUMBER: win32more.Windows.Win32.Globalization.UCharDirection = 5
U_COMMON_NUMBER_SEPARATOR: win32more.Windows.Win32.Globalization.UCharDirection = 6
U_BLOCK_SEPARATOR: win32more.Windows.Win32.Globalization.UCharDirection = 7
U_SEGMENT_SEPARATOR: win32more.Windows.Win32.Globalization.UCharDirection = 8
U_WHITE_SPACE_NEUTRAL: win32more.Windows.Win32.Globalization.UCharDirection = 9
U_OTHER_NEUTRAL: win32more.Windows.Win32.Globalization.UCharDirection = 10
U_LEFT_TO_RIGHT_EMBEDDING: win32more.Windows.Win32.Globalization.UCharDirection = 11
U_LEFT_TO_RIGHT_OVERRIDE: win32more.Windows.Win32.Globalization.UCharDirection = 12
U_RIGHT_TO_LEFT_ARABIC: win32more.Windows.Win32.Globalization.UCharDirection = 13
U_RIGHT_TO_LEFT_EMBEDDING: win32more.Windows.Win32.Globalization.UCharDirection = 14
U_RIGHT_TO_LEFT_OVERRIDE: win32more.Windows.Win32.Globalization.UCharDirection = 15
U_POP_DIRECTIONAL_FORMAT: win32more.Windows.Win32.Globalization.UCharDirection = 16
U_DIR_NON_SPACING_MARK: win32more.Windows.Win32.Globalization.UCharDirection = 17
U_BOUNDARY_NEUTRAL: win32more.Windows.Win32.Globalization.UCharDirection = 18
U_FIRST_STRONG_ISOLATE: win32more.Windows.Win32.Globalization.UCharDirection = 19
U_LEFT_TO_RIGHT_ISOLATE: win32more.Windows.Win32.Globalization.UCharDirection = 20
U_RIGHT_TO_LEFT_ISOLATE: win32more.Windows.Win32.Globalization.UCharDirection = 21
U_POP_DIRECTIONAL_ISOLATE: win32more.Windows.Win32.Globalization.UCharDirection = 22
@cfunctype_pointer
def UCharEnumTypeRange(context: VoidPtr, start: Int32, limit: Int32, type: win32more.Windows.Win32.Globalization.UCharCategory) -> SByte: ...
class UCharIterator(Structure):
    context: VoidPtr
    length: Int32
    start: Int32
    index: Int32
    limit: Int32
    reservedField: Int32
    getIndex: win32more.Windows.Win32.Globalization.UCharIteratorGetIndex
    move: win32more.Windows.Win32.Globalization.UCharIteratorMove
    hasNext: win32more.Windows.Win32.Globalization.UCharIteratorHasNext
    hasPrevious: win32more.Windows.Win32.Globalization.UCharIteratorHasPrevious
    current: win32more.Windows.Win32.Globalization.UCharIteratorCurrent
    next: win32more.Windows.Win32.Globalization.UCharIteratorNext
    previous: win32more.Windows.Win32.Globalization.UCharIteratorPrevious
    reservedFn: win32more.Windows.Win32.Globalization.UCharIteratorReserved
    getState: win32more.Windows.Win32.Globalization.UCharIteratorGetState
    setState: win32more.Windows.Win32.Globalization.UCharIteratorSetState
@cfunctype_pointer
def UCharIteratorCurrent(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator)) -> Int32: ...
@cfunctype_pointer
def UCharIteratorGetIndex(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator), origin: win32more.Windows.Win32.Globalization.UCharIteratorOrigin) -> Int32: ...
@cfunctype_pointer
def UCharIteratorGetState(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator)) -> UInt32: ...
@cfunctype_pointer
def UCharIteratorHasNext(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator)) -> SByte: ...
@cfunctype_pointer
def UCharIteratorHasPrevious(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator)) -> SByte: ...
@cfunctype_pointer
def UCharIteratorMove(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator), delta: Int32, origin: win32more.Windows.Win32.Globalization.UCharIteratorOrigin) -> Int32: ...
@cfunctype_pointer
def UCharIteratorNext(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator)) -> Int32: ...
UCharIteratorOrigin = Int32
UITER_START: win32more.Windows.Win32.Globalization.UCharIteratorOrigin = 0
UITER_CURRENT: win32more.Windows.Win32.Globalization.UCharIteratorOrigin = 1
UITER_LIMIT: win32more.Windows.Win32.Globalization.UCharIteratorOrigin = 2
UITER_ZERO: win32more.Windows.Win32.Globalization.UCharIteratorOrigin = 3
UITER_LENGTH: win32more.Windows.Win32.Globalization.UCharIteratorOrigin = 4
@cfunctype_pointer
def UCharIteratorPrevious(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator)) -> Int32: ...
@cfunctype_pointer
def UCharIteratorReserved(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator), something: Int32) -> Int32: ...
@cfunctype_pointer
def UCharIteratorSetState(iter: POINTER(win32more.Windows.Win32.Globalization.UCharIterator), state: UInt32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
UCharNameChoice = Int32
U_UNICODE_CHAR_NAME: win32more.Windows.Win32.Globalization.UCharNameChoice = 0
U_EXTENDED_CHAR_NAME: win32more.Windows.Win32.Globalization.UCharNameChoice = 2
U_CHAR_NAME_ALIAS: win32more.Windows.Win32.Globalization.UCharNameChoice = 3
UCharsetDetector = IntPtr
UCharsetMatch = IntPtr
UColAttribute = Int32
UCOL_FRENCH_COLLATION: win32more.Windows.Win32.Globalization.UColAttribute = 0
UCOL_ALTERNATE_HANDLING: win32more.Windows.Win32.Globalization.UColAttribute = 1
UCOL_CASE_FIRST: win32more.Windows.Win32.Globalization.UColAttribute = 2
UCOL_CASE_LEVEL: win32more.Windows.Win32.Globalization.UColAttribute = 3
UCOL_NORMALIZATION_MODE: win32more.Windows.Win32.Globalization.UColAttribute = 4
UCOL_DECOMPOSITION_MODE: win32more.Windows.Win32.Globalization.UColAttribute = 4
UCOL_STRENGTH: win32more.Windows.Win32.Globalization.UColAttribute = 5
UCOL_NUMERIC_COLLATION: win32more.Windows.Win32.Globalization.UColAttribute = 7
UCOL_ATTRIBUTE_COUNT: win32more.Windows.Win32.Globalization.UColAttribute = 8
UColAttributeValue = Int32
UCOL_DEFAULT: win32more.Windows.Win32.Globalization.UColAttributeValue = -1
UCOL_PRIMARY: win32more.Windows.Win32.Globalization.UColAttributeValue = 0
UCOL_SECONDARY: win32more.Windows.Win32.Globalization.UColAttributeValue = 1
UCOL_TERTIARY: win32more.Windows.Win32.Globalization.UColAttributeValue = 2
UCOL_DEFAULT_STRENGTH: win32more.Windows.Win32.Globalization.UColAttributeValue = 2
UCOL_CE_STRENGTH_LIMIT: win32more.Windows.Win32.Globalization.UColAttributeValue = 3
UCOL_QUATERNARY: win32more.Windows.Win32.Globalization.UColAttributeValue = 3
UCOL_IDENTICAL: win32more.Windows.Win32.Globalization.UColAttributeValue = 15
UCOL_STRENGTH_LIMIT: win32more.Windows.Win32.Globalization.UColAttributeValue = 16
UCOL_OFF: win32more.Windows.Win32.Globalization.UColAttributeValue = 16
UCOL_ON: win32more.Windows.Win32.Globalization.UColAttributeValue = 17
UCOL_SHIFTED: win32more.Windows.Win32.Globalization.UColAttributeValue = 20
UCOL_NON_IGNORABLE: win32more.Windows.Win32.Globalization.UColAttributeValue = 21
UCOL_LOWER_FIRST: win32more.Windows.Win32.Globalization.UColAttributeValue = 24
UCOL_UPPER_FIRST: win32more.Windows.Win32.Globalization.UColAttributeValue = 25
UColBoundMode = Int32
UCOL_BOUND_LOWER: win32more.Windows.Win32.Globalization.UColBoundMode = 0
UCOL_BOUND_UPPER: win32more.Windows.Win32.Globalization.UColBoundMode = 1
UCOL_BOUND_UPPER_LONG: win32more.Windows.Win32.Globalization.UColBoundMode = 2
UColReorderCode = Int32
UCOL_REORDER_CODE_DEFAULT: win32more.Windows.Win32.Globalization.UColReorderCode = -1
UCOL_REORDER_CODE_NONE: win32more.Windows.Win32.Globalization.UColReorderCode = 103
UCOL_REORDER_CODE_OTHERS: win32more.Windows.Win32.Globalization.UColReorderCode = 103
UCOL_REORDER_CODE_SPACE: win32more.Windows.Win32.Globalization.UColReorderCode = 4096
UCOL_REORDER_CODE_FIRST: win32more.Windows.Win32.Globalization.UColReorderCode = 4096
UCOL_REORDER_CODE_PUNCTUATION: win32more.Windows.Win32.Globalization.UColReorderCode = 4097
UCOL_REORDER_CODE_SYMBOL: win32more.Windows.Win32.Globalization.UColReorderCode = 4098
UCOL_REORDER_CODE_CURRENCY: win32more.Windows.Win32.Globalization.UColReorderCode = 4099
UCOL_REORDER_CODE_DIGIT: win32more.Windows.Win32.Globalization.UColReorderCode = 4100
UColRuleOption = Int32
UCOL_TAILORING_ONLY: win32more.Windows.Win32.Globalization.UColRuleOption = 0
UCOL_FULL_RULES: win32more.Windows.Win32.Globalization.UColRuleOption = 1
UCollationElements = IntPtr
UCollationResult = Int32
UCOL_EQUAL: win32more.Windows.Win32.Globalization.UCollationResult = 0
UCOL_GREATER: win32more.Windows.Win32.Globalization.UCollationResult = 1
UCOL_LESS: win32more.Windows.Win32.Globalization.UCollationResult = -1
UCollator = IntPtr
UConstrainedFieldPosition = IntPtr
UConverter = IntPtr
UConverterCallbackReason = Int32
UCNV_UNASSIGNED: win32more.Windows.Win32.Globalization.UConverterCallbackReason = 0
UCNV_ILLEGAL: win32more.Windows.Win32.Globalization.UConverterCallbackReason = 1
UCNV_IRREGULAR: win32more.Windows.Win32.Globalization.UConverterCallbackReason = 2
UCNV_RESET: win32more.Windows.Win32.Globalization.UConverterCallbackReason = 3
UCNV_CLOSE: win32more.Windows.Win32.Globalization.UConverterCallbackReason = 4
UCNV_CLONE: win32more.Windows.Win32.Globalization.UConverterCallbackReason = 5
@cfunctype_pointer
def UConverterFromUCallback(context: VoidPtr, args: POINTER(win32more.Windows.Win32.Globalization.UConverterFromUnicodeArgs), codeUnits: POINTER(UInt16), length: Int32, codePoint: Int32, reason: win32more.Windows.Win32.Globalization.UConverterCallbackReason, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
class UConverterFromUnicodeArgs(Structure):
    size: UInt16
    flush: SByte
    converter: POINTER(win32more.Windows.Win32.Globalization.UConverter)
    source: POINTER(UInt16)
    sourceLimit: POINTER(UInt16)
    target: win32more.Windows.Win32.Foundation.PSTR
    targetLimit: win32more.Windows.Win32.Foundation.PSTR
    offsets: POINTER(Int32)
UConverterPlatform = Int32
UCNV_UNKNOWN: win32more.Windows.Win32.Globalization.UConverterPlatform = -1
UCNV_IBM: win32more.Windows.Win32.Globalization.UConverterPlatform = 0
UConverterSelector = IntPtr
@cfunctype_pointer
def UConverterToUCallback(context: VoidPtr, args: POINTER(win32more.Windows.Win32.Globalization.UConverterToUnicodeArgs), codeUnits: win32more.Windows.Win32.Foundation.PSTR, length: Int32, reason: win32more.Windows.Win32.Globalization.UConverterCallbackReason, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
class UConverterToUnicodeArgs(Structure):
    size: UInt16
    flush: SByte
    converter: POINTER(win32more.Windows.Win32.Globalization.UConverter)
    source: win32more.Windows.Win32.Foundation.PSTR
    sourceLimit: win32more.Windows.Win32.Foundation.PSTR
    target: POINTER(UInt16)
    targetLimit: POINTER(UInt16)
    offsets: POINTER(Int32)
UConverterType = Int32
UCNV_UNSUPPORTED_CONVERTER: win32more.Windows.Win32.Globalization.UConverterType = -1
UCNV_SBCS: win32more.Windows.Win32.Globalization.UConverterType = 0
UCNV_DBCS: win32more.Windows.Win32.Globalization.UConverterType = 1
UCNV_MBCS: win32more.Windows.Win32.Globalization.UConverterType = 2
UCNV_LATIN_1: win32more.Windows.Win32.Globalization.UConverterType = 3
UCNV_UTF8: win32more.Windows.Win32.Globalization.UConverterType = 4
UCNV_UTF16_BigEndian: win32more.Windows.Win32.Globalization.UConverterType = 5
UCNV_UTF16_LittleEndian: win32more.Windows.Win32.Globalization.UConverterType = 6
UCNV_UTF32_BigEndian: win32more.Windows.Win32.Globalization.UConverterType = 7
UCNV_UTF32_LittleEndian: win32more.Windows.Win32.Globalization.UConverterType = 8
UCNV_EBCDIC_STATEFUL: win32more.Windows.Win32.Globalization.UConverterType = 9
UCNV_ISO_2022: win32more.Windows.Win32.Globalization.UConverterType = 10
UCNV_LMBCS_1: win32more.Windows.Win32.Globalization.UConverterType = 11
UCNV_LMBCS_2: win32more.Windows.Win32.Globalization.UConverterType = 12
UCNV_LMBCS_3: win32more.Windows.Win32.Globalization.UConverterType = 13
UCNV_LMBCS_4: win32more.Windows.Win32.Globalization.UConverterType = 14
UCNV_LMBCS_5: win32more.Windows.Win32.Globalization.UConverterType = 15
UCNV_LMBCS_6: win32more.Windows.Win32.Globalization.UConverterType = 16
UCNV_LMBCS_8: win32more.Windows.Win32.Globalization.UConverterType = 17
UCNV_LMBCS_11: win32more.Windows.Win32.Globalization.UConverterType = 18
UCNV_LMBCS_16: win32more.Windows.Win32.Globalization.UConverterType = 19
UCNV_LMBCS_17: win32more.Windows.Win32.Globalization.UConverterType = 20
UCNV_LMBCS_18: win32more.Windows.Win32.Globalization.UConverterType = 21
UCNV_LMBCS_19: win32more.Windows.Win32.Globalization.UConverterType = 22
UCNV_LMBCS_LAST: win32more.Windows.Win32.Globalization.UConverterType = 22
UCNV_HZ: win32more.Windows.Win32.Globalization.UConverterType = 23
UCNV_SCSU: win32more.Windows.Win32.Globalization.UConverterType = 24
UCNV_ISCII: win32more.Windows.Win32.Globalization.UConverterType = 25
UCNV_US_ASCII: win32more.Windows.Win32.Globalization.UConverterType = 26
UCNV_UTF7: win32more.Windows.Win32.Globalization.UConverterType = 27
UCNV_BOCU1: win32more.Windows.Win32.Globalization.UConverterType = 28
UCNV_UTF16: win32more.Windows.Win32.Globalization.UConverterType = 29
UCNV_UTF32: win32more.Windows.Win32.Globalization.UConverterType = 30
UCNV_CESU8: win32more.Windows.Win32.Globalization.UConverterType = 31
UCNV_IMAP_MAILBOX: win32more.Windows.Win32.Globalization.UConverterType = 32
UCNV_COMPOUND_TEXT: win32more.Windows.Win32.Globalization.UConverterType = 33
UCNV_NUMBER_OF_SUPPORTED_CONVERTER_TYPES: win32more.Windows.Win32.Globalization.UConverterType = 34
UConverterUnicodeSet = Int32
UCNV_ROUNDTRIP_SET: win32more.Windows.Win32.Globalization.UConverterUnicodeSet = 0
UCNV_ROUNDTRIP_AND_FALLBACK_SET: win32more.Windows.Win32.Globalization.UConverterUnicodeSet = 1
UCurrCurrencyType = Int32
UCURR_ALL: win32more.Windows.Win32.Globalization.UCurrCurrencyType = 2147483647
UCURR_COMMON: win32more.Windows.Win32.Globalization.UCurrCurrencyType = 1
UCURR_UNCOMMON: win32more.Windows.Win32.Globalization.UCurrCurrencyType = 2
UCURR_DEPRECATED: win32more.Windows.Win32.Globalization.UCurrCurrencyType = 4
UCURR_NON_DEPRECATED: win32more.Windows.Win32.Globalization.UCurrCurrencyType = 8
UCurrNameStyle = Int32
UCURR_SYMBOL_NAME: win32more.Windows.Win32.Globalization.UCurrNameStyle = 0
UCURR_LONG_NAME: win32more.Windows.Win32.Globalization.UCurrNameStyle = 1
UCURR_NARROW_SYMBOL_NAME: win32more.Windows.Win32.Globalization.UCurrNameStyle = 2
UCurrencySpacing = Int32
UNUM_CURRENCY_MATCH: win32more.Windows.Win32.Globalization.UCurrencySpacing = 0
UNUM_CURRENCY_SURROUNDING_MATCH: win32more.Windows.Win32.Globalization.UCurrencySpacing = 1
UNUM_CURRENCY_INSERT: win32more.Windows.Win32.Globalization.UCurrencySpacing = 2
UNUM_CURRENCY_SPACING_COUNT: win32more.Windows.Win32.Globalization.UCurrencySpacing = 3
UCurrencyUsage = Int32
UCURR_USAGE_STANDARD: win32more.Windows.Win32.Globalization.UCurrencyUsage = 0
UCURR_USAGE_CASH: win32more.Windows.Win32.Globalization.UCurrencyUsage = 1
UDateAbsoluteUnit = Int32
UDAT_ABSOLUTE_SUNDAY: win32more.Windows.Win32.Globalization.UDateAbsoluteUnit = 0
UDAT_ABSOLUTE_MONDAY: win32more.Windows.Win32.Globalization.UDateAbsoluteUnit = 1
UDAT_ABSOLUTE_TUESDAY: win32more.Windows.Win32.Globalization.UDateAbsoluteUnit = 2
UDAT_ABSOLUTE_WEDNESDAY: win32more.Windows.Win32.Globalization.UDateAbsoluteUnit = 3
UDAT_ABSOLUTE_THURSDAY: win32more.Windows.Win32.Globalization.UDateAbsoluteUnit = 4
UDAT_ABSOLUTE_FRIDAY: win32more.Windows.Win32.Globalization.UDateAbsoluteUnit = 5
UDAT_ABSOLUTE_SATURDAY: win32more.Windows.Win32.Globalization.UDateAbsoluteUnit = 6
UDAT_ABSOLUTE_DAY: win32more.Windows.Win32.Globalization.UDateAbsoluteUnit = 7
UDAT_ABSOLUTE_WEEK: win32more.Windows.Win32.Globalization.UDateAbsoluteUnit = 8
UDAT_ABSOLUTE_MONTH: win32more.Windows.Win32.Globalization.UDateAbsoluteUnit = 9
UDAT_ABSOLUTE_YEAR: win32more.Windows.Win32.Globalization.UDateAbsoluteUnit = 10
UDAT_ABSOLUTE_NOW: win32more.Windows.Win32.Globalization.UDateAbsoluteUnit = 11
UDAT_ABSOLUTE_UNIT_COUNT: win32more.Windows.Win32.Globalization.UDateAbsoluteUnit = 12
UDateDirection = Int32
UDAT_DIRECTION_LAST_2: win32more.Windows.Win32.Globalization.UDateDirection = 0
UDAT_DIRECTION_LAST: win32more.Windows.Win32.Globalization.UDateDirection = 1
UDAT_DIRECTION_THIS: win32more.Windows.Win32.Globalization.UDateDirection = 2
UDAT_DIRECTION_NEXT: win32more.Windows.Win32.Globalization.UDateDirection = 3
UDAT_DIRECTION_NEXT_2: win32more.Windows.Win32.Globalization.UDateDirection = 4
UDAT_DIRECTION_PLAIN: win32more.Windows.Win32.Globalization.UDateDirection = 5
UDAT_DIRECTION_COUNT: win32more.Windows.Win32.Globalization.UDateDirection = 6
UDateFormatBooleanAttribute = Int32
UDAT_PARSE_ALLOW_WHITESPACE: win32more.Windows.Win32.Globalization.UDateFormatBooleanAttribute = 0
UDAT_PARSE_ALLOW_NUMERIC: win32more.Windows.Win32.Globalization.UDateFormatBooleanAttribute = 1
UDAT_PARSE_PARTIAL_LITERAL_MATCH: win32more.Windows.Win32.Globalization.UDateFormatBooleanAttribute = 2
UDAT_PARSE_MULTIPLE_PATTERNS_FOR_MATCH: win32more.Windows.Win32.Globalization.UDateFormatBooleanAttribute = 3
UDAT_BOOLEAN_ATTRIBUTE_COUNT: win32more.Windows.Win32.Globalization.UDateFormatBooleanAttribute = 4
UDateFormatField = Int32
UDAT_ERA_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 0
UDAT_YEAR_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 1
UDAT_MONTH_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 2
UDAT_DATE_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 3
UDAT_HOUR_OF_DAY1_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 4
UDAT_HOUR_OF_DAY0_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 5
UDAT_MINUTE_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 6
UDAT_SECOND_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 7
UDAT_FRACTIONAL_SECOND_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 8
UDAT_DAY_OF_WEEK_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 9
UDAT_DAY_OF_YEAR_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 10
UDAT_DAY_OF_WEEK_IN_MONTH_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 11
UDAT_WEEK_OF_YEAR_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 12
UDAT_WEEK_OF_MONTH_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 13
UDAT_AM_PM_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 14
UDAT_HOUR1_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 15
UDAT_HOUR0_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 16
UDAT_TIMEZONE_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 17
UDAT_YEAR_WOY_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 18
UDAT_DOW_LOCAL_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 19
UDAT_EXTENDED_YEAR_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 20
UDAT_JULIAN_DAY_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 21
UDAT_MILLISECONDS_IN_DAY_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 22
UDAT_TIMEZONE_RFC_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 23
UDAT_TIMEZONE_GENERIC_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 24
UDAT_STANDALONE_DAY_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 25
UDAT_STANDALONE_MONTH_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 26
UDAT_QUARTER_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 27
UDAT_STANDALONE_QUARTER_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 28
UDAT_TIMEZONE_SPECIAL_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 29
UDAT_YEAR_NAME_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 30
UDAT_TIMEZONE_LOCALIZED_GMT_OFFSET_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 31
UDAT_TIMEZONE_ISO_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 32
UDAT_TIMEZONE_ISO_LOCAL_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 33
UDAT_AM_PM_MIDNIGHT_NOON_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 35
UDAT_FLEXIBLE_DAY_PERIOD_FIELD: win32more.Windows.Win32.Globalization.UDateFormatField = 36
UDateFormatStyle = Int32
UDAT_FULL: win32more.Windows.Win32.Globalization.UDateFormatStyle = 0
UDAT_LONG: win32more.Windows.Win32.Globalization.UDateFormatStyle = 1
UDAT_MEDIUM: win32more.Windows.Win32.Globalization.UDateFormatStyle = 2
UDAT_SHORT: win32more.Windows.Win32.Globalization.UDateFormatStyle = 3
UDAT_DEFAULT: win32more.Windows.Win32.Globalization.UDateFormatStyle = 2
UDAT_RELATIVE: win32more.Windows.Win32.Globalization.UDateFormatStyle = 128
UDAT_FULL_RELATIVE: win32more.Windows.Win32.Globalization.UDateFormatStyle = 128
UDAT_LONG_RELATIVE: win32more.Windows.Win32.Globalization.UDateFormatStyle = 129
UDAT_MEDIUM_RELATIVE: win32more.Windows.Win32.Globalization.UDateFormatStyle = 130
UDAT_SHORT_RELATIVE: win32more.Windows.Win32.Globalization.UDateFormatStyle = 131
UDAT_NONE: win32more.Windows.Win32.Globalization.UDateFormatStyle = -1
UDAT_PATTERN: win32more.Windows.Win32.Globalization.UDateFormatStyle = -2
UDateFormatSymbolType = Int32
UDAT_ERAS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 0
UDAT_MONTHS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 1
UDAT_SHORT_MONTHS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 2
UDAT_WEEKDAYS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 3
UDAT_SHORT_WEEKDAYS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 4
UDAT_AM_PMS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 5
UDAT_LOCALIZED_CHARS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 6
UDAT_ERA_NAMES: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 7
UDAT_NARROW_MONTHS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 8
UDAT_NARROW_WEEKDAYS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 9
UDAT_STANDALONE_MONTHS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 10
UDAT_STANDALONE_SHORT_MONTHS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 11
UDAT_STANDALONE_NARROW_MONTHS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 12
UDAT_STANDALONE_WEEKDAYS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 13
UDAT_STANDALONE_SHORT_WEEKDAYS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 14
UDAT_STANDALONE_NARROW_WEEKDAYS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 15
UDAT_QUARTERS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 16
UDAT_SHORT_QUARTERS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 17
UDAT_STANDALONE_QUARTERS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 18
UDAT_STANDALONE_SHORT_QUARTERS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 19
UDAT_SHORTER_WEEKDAYS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 20
UDAT_STANDALONE_SHORTER_WEEKDAYS: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 21
UDAT_CYCLIC_YEARS_WIDE: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 22
UDAT_CYCLIC_YEARS_ABBREVIATED: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 23
UDAT_CYCLIC_YEARS_NARROW: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 24
UDAT_ZODIAC_NAMES_WIDE: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 25
UDAT_ZODIAC_NAMES_ABBREVIATED: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 26
UDAT_ZODIAC_NAMES_NARROW: win32more.Windows.Win32.Globalization.UDateFormatSymbolType = 27
UDateFormatSymbols = IntPtr
UDateIntervalFormat = IntPtr
UDateRelativeDateTimeFormatterStyle = Int32
UDAT_STYLE_LONG: win32more.Windows.Win32.Globalization.UDateRelativeDateTimeFormatterStyle = 0
UDAT_STYLE_SHORT: win32more.Windows.Win32.Globalization.UDateRelativeDateTimeFormatterStyle = 1
UDAT_STYLE_NARROW: win32more.Windows.Win32.Globalization.UDateRelativeDateTimeFormatterStyle = 2
UDateRelativeUnit = Int32
UDAT_RELATIVE_SECONDS: win32more.Windows.Win32.Globalization.UDateRelativeUnit = 0
UDAT_RELATIVE_MINUTES: win32more.Windows.Win32.Globalization.UDateRelativeUnit = 1
UDAT_RELATIVE_HOURS: win32more.Windows.Win32.Globalization.UDateRelativeUnit = 2
UDAT_RELATIVE_DAYS: win32more.Windows.Win32.Globalization.UDateRelativeUnit = 3
UDAT_RELATIVE_WEEKS: win32more.Windows.Win32.Globalization.UDateRelativeUnit = 4
UDAT_RELATIVE_MONTHS: win32more.Windows.Win32.Globalization.UDateRelativeUnit = 5
UDAT_RELATIVE_YEARS: win32more.Windows.Win32.Globalization.UDateRelativeUnit = 6
UDAT_RELATIVE_UNIT_COUNT: win32more.Windows.Win32.Globalization.UDateRelativeUnit = 7
UDateTimePGDisplayWidth = Int32
UDATPG_WIDE: win32more.Windows.Win32.Globalization.UDateTimePGDisplayWidth = 0
UDATPG_ABBREVIATED: win32more.Windows.Win32.Globalization.UDateTimePGDisplayWidth = 1
UDATPG_NARROW: win32more.Windows.Win32.Globalization.UDateTimePGDisplayWidth = 2
UDateTimePatternConflict = Int32
UDATPG_NO_CONFLICT: win32more.Windows.Win32.Globalization.UDateTimePatternConflict = 0
UDATPG_BASE_CONFLICT: win32more.Windows.Win32.Globalization.UDateTimePatternConflict = 1
UDATPG_CONFLICT: win32more.Windows.Win32.Globalization.UDateTimePatternConflict = 2
UDateTimePatternField = Int32
UDATPG_ERA_FIELD: win32more.Windows.Win32.Globalization.UDateTimePatternField = 0
UDATPG_YEAR_FIELD: win32more.Windows.Win32.Globalization.UDateTimePatternField = 1
UDATPG_QUARTER_FIELD: win32more.Windows.Win32.Globalization.UDateTimePatternField = 2
UDATPG_MONTH_FIELD: win32more.Windows.Win32.Globalization.UDateTimePatternField = 3
UDATPG_WEEK_OF_YEAR_FIELD: win32more.Windows.Win32.Globalization.UDateTimePatternField = 4
UDATPG_WEEK_OF_MONTH_FIELD: win32more.Windows.Win32.Globalization.UDateTimePatternField = 5
UDATPG_WEEKDAY_FIELD: win32more.Windows.Win32.Globalization.UDateTimePatternField = 6
UDATPG_DAY_OF_YEAR_FIELD: win32more.Windows.Win32.Globalization.UDateTimePatternField = 7
UDATPG_DAY_OF_WEEK_IN_MONTH_FIELD: win32more.Windows.Win32.Globalization.UDateTimePatternField = 8
UDATPG_DAY_FIELD: win32more.Windows.Win32.Globalization.UDateTimePatternField = 9
UDATPG_DAYPERIOD_FIELD: win32more.Windows.Win32.Globalization.UDateTimePatternField = 10
UDATPG_HOUR_FIELD: win32more.Windows.Win32.Globalization.UDateTimePatternField = 11
UDATPG_MINUTE_FIELD: win32more.Windows.Win32.Globalization.UDateTimePatternField = 12
UDATPG_SECOND_FIELD: win32more.Windows.Win32.Globalization.UDateTimePatternField = 13
UDATPG_FRACTIONAL_SECOND_FIELD: win32more.Windows.Win32.Globalization.UDateTimePatternField = 14
UDATPG_ZONE_FIELD: win32more.Windows.Win32.Globalization.UDateTimePatternField = 15
UDATPG_FIELD_COUNT: win32more.Windows.Win32.Globalization.UDateTimePatternField = 16
UDateTimePatternMatchOptions = Int32
UDATPG_MATCH_NO_OPTIONS: win32more.Windows.Win32.Globalization.UDateTimePatternMatchOptions = 0
UDATPG_MATCH_HOUR_FIELD_LENGTH: win32more.Windows.Win32.Globalization.UDateTimePatternMatchOptions = 2048
UDATPG_MATCH_ALL_FIELDS_LENGTH: win32more.Windows.Win32.Globalization.UDateTimePatternMatchOptions = 65535
UDateTimeScale = Int32
UDTS_JAVA_TIME: win32more.Windows.Win32.Globalization.UDateTimeScale = 0
UDTS_UNIX_TIME: win32more.Windows.Win32.Globalization.UDateTimeScale = 1
UDTS_ICU4C_TIME: win32more.Windows.Win32.Globalization.UDateTimeScale = 2
UDTS_WINDOWS_FILE_TIME: win32more.Windows.Win32.Globalization.UDateTimeScale = 3
UDTS_DOTNET_DATE_TIME: win32more.Windows.Win32.Globalization.UDateTimeScale = 4
UDTS_MAC_OLD_TIME: win32more.Windows.Win32.Globalization.UDateTimeScale = 5
UDTS_MAC_TIME: win32more.Windows.Win32.Globalization.UDateTimeScale = 6
UDTS_EXCEL_TIME: win32more.Windows.Win32.Globalization.UDateTimeScale = 7
UDTS_DB2_TIME: win32more.Windows.Win32.Globalization.UDateTimeScale = 8
UDTS_UNIX_MICROSECONDS_TIME: win32more.Windows.Win32.Globalization.UDateTimeScale = 9
UDecompositionType = Int32
U_DT_NONE: win32more.Windows.Win32.Globalization.UDecompositionType = 0
U_DT_CANONICAL: win32more.Windows.Win32.Globalization.UDecompositionType = 1
U_DT_COMPAT: win32more.Windows.Win32.Globalization.UDecompositionType = 2
U_DT_CIRCLE: win32more.Windows.Win32.Globalization.UDecompositionType = 3
U_DT_FINAL: win32more.Windows.Win32.Globalization.UDecompositionType = 4
U_DT_FONT: win32more.Windows.Win32.Globalization.UDecompositionType = 5
U_DT_FRACTION: win32more.Windows.Win32.Globalization.UDecompositionType = 6
U_DT_INITIAL: win32more.Windows.Win32.Globalization.UDecompositionType = 7
U_DT_ISOLATED: win32more.Windows.Win32.Globalization.UDecompositionType = 8
U_DT_MEDIAL: win32more.Windows.Win32.Globalization.UDecompositionType = 9
U_DT_NARROW: win32more.Windows.Win32.Globalization.UDecompositionType = 10
U_DT_NOBREAK: win32more.Windows.Win32.Globalization.UDecompositionType = 11
U_DT_SMALL: win32more.Windows.Win32.Globalization.UDecompositionType = 12
U_DT_SQUARE: win32more.Windows.Win32.Globalization.UDecompositionType = 13
U_DT_SUB: win32more.Windows.Win32.Globalization.UDecompositionType = 14
U_DT_SUPER: win32more.Windows.Win32.Globalization.UDecompositionType = 15
U_DT_VERTICAL: win32more.Windows.Win32.Globalization.UDecompositionType = 16
U_DT_WIDE: win32more.Windows.Win32.Globalization.UDecompositionType = 17
UDialectHandling = Int32
ULDN_STANDARD_NAMES: win32more.Windows.Win32.Globalization.UDialectHandling = 0
ULDN_DIALECT_NAMES: win32more.Windows.Win32.Globalization.UDialectHandling = 1
UDisplayContext = Int32
UDISPCTX_STANDARD_NAMES: win32more.Windows.Win32.Globalization.UDisplayContext = 0
UDISPCTX_DIALECT_NAMES: win32more.Windows.Win32.Globalization.UDisplayContext = 1
UDISPCTX_CAPITALIZATION_NONE: win32more.Windows.Win32.Globalization.UDisplayContext = 256
UDISPCTX_CAPITALIZATION_FOR_MIDDLE_OF_SENTENCE: win32more.Windows.Win32.Globalization.UDisplayContext = 257
UDISPCTX_CAPITALIZATION_FOR_BEGINNING_OF_SENTENCE: win32more.Windows.Win32.Globalization.UDisplayContext = 258
UDISPCTX_CAPITALIZATION_FOR_UI_LIST_OR_MENU: win32more.Windows.Win32.Globalization.UDisplayContext = 259
UDISPCTX_CAPITALIZATION_FOR_STANDALONE: win32more.Windows.Win32.Globalization.UDisplayContext = 260
UDISPCTX_LENGTH_FULL: win32more.Windows.Win32.Globalization.UDisplayContext = 512
UDISPCTX_LENGTH_SHORT: win32more.Windows.Win32.Globalization.UDisplayContext = 513
UDISPCTX_SUBSTITUTE: win32more.Windows.Win32.Globalization.UDisplayContext = 768
UDISPCTX_NO_SUBSTITUTE: win32more.Windows.Win32.Globalization.UDisplayContext = 769
UDisplayContextType = Int32
UDISPCTX_TYPE_DIALECT_HANDLING: win32more.Windows.Win32.Globalization.UDisplayContextType = 0
UDISPCTX_TYPE_CAPITALIZATION: win32more.Windows.Win32.Globalization.UDisplayContextType = 1
UDISPCTX_TYPE_DISPLAY_LENGTH: win32more.Windows.Win32.Globalization.UDisplayContextType = 2
UDISPCTX_TYPE_SUBSTITUTE_HANDLING: win32more.Windows.Win32.Globalization.UDisplayContextType = 3
UEastAsianWidth = Int32
U_EA_NEUTRAL: win32more.Windows.Win32.Globalization.UEastAsianWidth = 0
U_EA_AMBIGUOUS: win32more.Windows.Win32.Globalization.UEastAsianWidth = 1
U_EA_HALFWIDTH: win32more.Windows.Win32.Globalization.UEastAsianWidth = 2
U_EA_FULLWIDTH: win32more.Windows.Win32.Globalization.UEastAsianWidth = 3
U_EA_NARROW: win32more.Windows.Win32.Globalization.UEastAsianWidth = 4
U_EA_WIDE: win32more.Windows.Win32.Globalization.UEastAsianWidth = 5
@cfunctype_pointer
def UEnumCharNamesFn(context: VoidPtr, code: Int32, nameChoice: win32more.Windows.Win32.Globalization.UCharNameChoice, name: win32more.Windows.Win32.Foundation.PSTR, length: Int32) -> SByte: ...
UEnumeration = IntPtr
UErrorCode = Int32
U_USING_FALLBACK_WARNING: win32more.Windows.Win32.Globalization.UErrorCode = -128
U_ERROR_WARNING_START: win32more.Windows.Win32.Globalization.UErrorCode = -128
U_USING_DEFAULT_WARNING: win32more.Windows.Win32.Globalization.UErrorCode = -127
U_SAFECLONE_ALLOCATED_WARNING: win32more.Windows.Win32.Globalization.UErrorCode = -126
U_STATE_OLD_WARNING: win32more.Windows.Win32.Globalization.UErrorCode = -125
U_STRING_NOT_TERMINATED_WARNING: win32more.Windows.Win32.Globalization.UErrorCode = -124
U_SORT_KEY_TOO_SHORT_WARNING: win32more.Windows.Win32.Globalization.UErrorCode = -123
U_AMBIGUOUS_ALIAS_WARNING: win32more.Windows.Win32.Globalization.UErrorCode = -122
U_DIFFERENT_UCA_VERSION: win32more.Windows.Win32.Globalization.UErrorCode = -121
U_PLUGIN_CHANGED_LEVEL_WARNING: win32more.Windows.Win32.Globalization.UErrorCode = -120
U_ZERO_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 0
U_ILLEGAL_ARGUMENT_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 1
U_MISSING_RESOURCE_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 2
U_INVALID_FORMAT_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 3
U_FILE_ACCESS_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 4
U_INTERNAL_PROGRAM_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 5
U_MESSAGE_PARSE_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 6
U_MEMORY_ALLOCATION_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 7
U_INDEX_OUTOFBOUNDS_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 8
U_PARSE_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 9
U_INVALID_CHAR_FOUND: win32more.Windows.Win32.Globalization.UErrorCode = 10
U_TRUNCATED_CHAR_FOUND: win32more.Windows.Win32.Globalization.UErrorCode = 11
U_ILLEGAL_CHAR_FOUND: win32more.Windows.Win32.Globalization.UErrorCode = 12
U_INVALID_TABLE_FORMAT: win32more.Windows.Win32.Globalization.UErrorCode = 13
U_INVALID_TABLE_FILE: win32more.Windows.Win32.Globalization.UErrorCode = 14
U_BUFFER_OVERFLOW_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 15
U_UNSUPPORTED_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 16
U_RESOURCE_TYPE_MISMATCH: win32more.Windows.Win32.Globalization.UErrorCode = 17
U_ILLEGAL_ESCAPE_SEQUENCE: win32more.Windows.Win32.Globalization.UErrorCode = 18
U_UNSUPPORTED_ESCAPE_SEQUENCE: win32more.Windows.Win32.Globalization.UErrorCode = 19
U_NO_SPACE_AVAILABLE: win32more.Windows.Win32.Globalization.UErrorCode = 20
U_CE_NOT_FOUND_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 21
U_PRIMARY_TOO_LONG_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 22
U_STATE_TOO_OLD_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 23
U_TOO_MANY_ALIASES_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 24
U_ENUM_OUT_OF_SYNC_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 25
U_INVARIANT_CONVERSION_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 26
U_INVALID_STATE_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 27
U_COLLATOR_VERSION_MISMATCH: win32more.Windows.Win32.Globalization.UErrorCode = 28
U_USELESS_COLLATOR_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 29
U_NO_WRITE_PERMISSION: win32more.Windows.Win32.Globalization.UErrorCode = 30
U_BAD_VARIABLE_DEFINITION: win32more.Windows.Win32.Globalization.UErrorCode = 65536
U_PARSE_ERROR_START: win32more.Windows.Win32.Globalization.UErrorCode = 65536
U_MALFORMED_RULE: win32more.Windows.Win32.Globalization.UErrorCode = 65537
U_MALFORMED_SET: win32more.Windows.Win32.Globalization.UErrorCode = 65538
U_MALFORMED_SYMBOL_REFERENCE: win32more.Windows.Win32.Globalization.UErrorCode = 65539
U_MALFORMED_UNICODE_ESCAPE: win32more.Windows.Win32.Globalization.UErrorCode = 65540
U_MALFORMED_VARIABLE_DEFINITION: win32more.Windows.Win32.Globalization.UErrorCode = 65541
U_MALFORMED_VARIABLE_REFERENCE: win32more.Windows.Win32.Globalization.UErrorCode = 65542
U_MISMATCHED_SEGMENT_DELIMITERS: win32more.Windows.Win32.Globalization.UErrorCode = 65543
U_MISPLACED_ANCHOR_START: win32more.Windows.Win32.Globalization.UErrorCode = 65544
U_MISPLACED_CURSOR_OFFSET: win32more.Windows.Win32.Globalization.UErrorCode = 65545
U_MISPLACED_QUANTIFIER: win32more.Windows.Win32.Globalization.UErrorCode = 65546
U_MISSING_OPERATOR: win32more.Windows.Win32.Globalization.UErrorCode = 65547
U_MISSING_SEGMENT_CLOSE: win32more.Windows.Win32.Globalization.UErrorCode = 65548
U_MULTIPLE_ANTE_CONTEXTS: win32more.Windows.Win32.Globalization.UErrorCode = 65549
U_MULTIPLE_CURSORS: win32more.Windows.Win32.Globalization.UErrorCode = 65550
U_MULTIPLE_POST_CONTEXTS: win32more.Windows.Win32.Globalization.UErrorCode = 65551
U_TRAILING_BACKSLASH: win32more.Windows.Win32.Globalization.UErrorCode = 65552
U_UNDEFINED_SEGMENT_REFERENCE: win32more.Windows.Win32.Globalization.UErrorCode = 65553
U_UNDEFINED_VARIABLE: win32more.Windows.Win32.Globalization.UErrorCode = 65554
U_UNQUOTED_SPECIAL: win32more.Windows.Win32.Globalization.UErrorCode = 65555
U_UNTERMINATED_QUOTE: win32more.Windows.Win32.Globalization.UErrorCode = 65556
U_RULE_MASK_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 65557
U_MISPLACED_COMPOUND_FILTER: win32more.Windows.Win32.Globalization.UErrorCode = 65558
U_MULTIPLE_COMPOUND_FILTERS: win32more.Windows.Win32.Globalization.UErrorCode = 65559
U_INVALID_RBT_SYNTAX: win32more.Windows.Win32.Globalization.UErrorCode = 65560
U_INVALID_PROPERTY_PATTERN: win32more.Windows.Win32.Globalization.UErrorCode = 65561
U_MALFORMED_PRAGMA: win32more.Windows.Win32.Globalization.UErrorCode = 65562
U_UNCLOSED_SEGMENT: win32more.Windows.Win32.Globalization.UErrorCode = 65563
U_ILLEGAL_CHAR_IN_SEGMENT: win32more.Windows.Win32.Globalization.UErrorCode = 65564
U_VARIABLE_RANGE_EXHAUSTED: win32more.Windows.Win32.Globalization.UErrorCode = 65565
U_VARIABLE_RANGE_OVERLAP: win32more.Windows.Win32.Globalization.UErrorCode = 65566
U_ILLEGAL_CHARACTER: win32more.Windows.Win32.Globalization.UErrorCode = 65567
U_INTERNAL_TRANSLITERATOR_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 65568
U_INVALID_ID: win32more.Windows.Win32.Globalization.UErrorCode = 65569
U_INVALID_FUNCTION: win32more.Windows.Win32.Globalization.UErrorCode = 65570
U_UNEXPECTED_TOKEN: win32more.Windows.Win32.Globalization.UErrorCode = 65792
U_FMT_PARSE_ERROR_START: win32more.Windows.Win32.Globalization.UErrorCode = 65792
U_MULTIPLE_DECIMAL_SEPARATORS: win32more.Windows.Win32.Globalization.UErrorCode = 65793
U_MULTIPLE_DECIMAL_SEPERATORS: win32more.Windows.Win32.Globalization.UErrorCode = 65793
U_MULTIPLE_EXPONENTIAL_SYMBOLS: win32more.Windows.Win32.Globalization.UErrorCode = 65794
U_MALFORMED_EXPONENTIAL_PATTERN: win32more.Windows.Win32.Globalization.UErrorCode = 65795
U_MULTIPLE_PERCENT_SYMBOLS: win32more.Windows.Win32.Globalization.UErrorCode = 65796
U_MULTIPLE_PERMILL_SYMBOLS: win32more.Windows.Win32.Globalization.UErrorCode = 65797
U_MULTIPLE_PAD_SPECIFIERS: win32more.Windows.Win32.Globalization.UErrorCode = 65798
U_PATTERN_SYNTAX_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 65799
U_ILLEGAL_PAD_POSITION: win32more.Windows.Win32.Globalization.UErrorCode = 65800
U_UNMATCHED_BRACES: win32more.Windows.Win32.Globalization.UErrorCode = 65801
U_UNSUPPORTED_PROPERTY: win32more.Windows.Win32.Globalization.UErrorCode = 65802
U_UNSUPPORTED_ATTRIBUTE: win32more.Windows.Win32.Globalization.UErrorCode = 65803
U_ARGUMENT_TYPE_MISMATCH: win32more.Windows.Win32.Globalization.UErrorCode = 65804
U_DUPLICATE_KEYWORD: win32more.Windows.Win32.Globalization.UErrorCode = 65805
U_UNDEFINED_KEYWORD: win32more.Windows.Win32.Globalization.UErrorCode = 65806
U_DEFAULT_KEYWORD_MISSING: win32more.Windows.Win32.Globalization.UErrorCode = 65807
U_DECIMAL_NUMBER_SYNTAX_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 65808
U_FORMAT_INEXACT_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 65809
U_NUMBER_ARG_OUTOFBOUNDS_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 65810
U_NUMBER_SKELETON_SYNTAX_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 65811
U_BRK_INTERNAL_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 66048
U_BRK_ERROR_START: win32more.Windows.Win32.Globalization.UErrorCode = 66048
U_BRK_HEX_DIGITS_EXPECTED: win32more.Windows.Win32.Globalization.UErrorCode = 66049
U_BRK_SEMICOLON_EXPECTED: win32more.Windows.Win32.Globalization.UErrorCode = 66050
U_BRK_RULE_SYNTAX: win32more.Windows.Win32.Globalization.UErrorCode = 66051
U_BRK_UNCLOSED_SET: win32more.Windows.Win32.Globalization.UErrorCode = 66052
U_BRK_ASSIGN_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 66053
U_BRK_VARIABLE_REDFINITION: win32more.Windows.Win32.Globalization.UErrorCode = 66054
U_BRK_MISMATCHED_PAREN: win32more.Windows.Win32.Globalization.UErrorCode = 66055
U_BRK_NEW_LINE_IN_QUOTED_STRING: win32more.Windows.Win32.Globalization.UErrorCode = 66056
U_BRK_UNDEFINED_VARIABLE: win32more.Windows.Win32.Globalization.UErrorCode = 66057
U_BRK_INIT_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 66058
U_BRK_RULE_EMPTY_SET: win32more.Windows.Win32.Globalization.UErrorCode = 66059
U_BRK_UNRECOGNIZED_OPTION: win32more.Windows.Win32.Globalization.UErrorCode = 66060
U_BRK_MALFORMED_RULE_TAG: win32more.Windows.Win32.Globalization.UErrorCode = 66061
U_REGEX_INTERNAL_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 66304
U_REGEX_ERROR_START: win32more.Windows.Win32.Globalization.UErrorCode = 66304
U_REGEX_RULE_SYNTAX: win32more.Windows.Win32.Globalization.UErrorCode = 66305
U_REGEX_INVALID_STATE: win32more.Windows.Win32.Globalization.UErrorCode = 66306
U_REGEX_BAD_ESCAPE_SEQUENCE: win32more.Windows.Win32.Globalization.UErrorCode = 66307
U_REGEX_PROPERTY_SYNTAX: win32more.Windows.Win32.Globalization.UErrorCode = 66308
U_REGEX_UNIMPLEMENTED: win32more.Windows.Win32.Globalization.UErrorCode = 66309
U_REGEX_MISMATCHED_PAREN: win32more.Windows.Win32.Globalization.UErrorCode = 66310
U_REGEX_NUMBER_TOO_BIG: win32more.Windows.Win32.Globalization.UErrorCode = 66311
U_REGEX_BAD_INTERVAL: win32more.Windows.Win32.Globalization.UErrorCode = 66312
U_REGEX_MAX_LT_MIN: win32more.Windows.Win32.Globalization.UErrorCode = 66313
U_REGEX_INVALID_BACK_REF: win32more.Windows.Win32.Globalization.UErrorCode = 66314
U_REGEX_INVALID_FLAG: win32more.Windows.Win32.Globalization.UErrorCode = 66315
U_REGEX_LOOK_BEHIND_LIMIT: win32more.Windows.Win32.Globalization.UErrorCode = 66316
U_REGEX_SET_CONTAINS_STRING: win32more.Windows.Win32.Globalization.UErrorCode = 66317
U_REGEX_MISSING_CLOSE_BRACKET: win32more.Windows.Win32.Globalization.UErrorCode = 66319
U_REGEX_INVALID_RANGE: win32more.Windows.Win32.Globalization.UErrorCode = 66320
U_REGEX_STACK_OVERFLOW: win32more.Windows.Win32.Globalization.UErrorCode = 66321
U_REGEX_TIME_OUT: win32more.Windows.Win32.Globalization.UErrorCode = 66322
U_REGEX_STOPPED_BY_CALLER: win32more.Windows.Win32.Globalization.UErrorCode = 66323
U_REGEX_PATTERN_TOO_BIG: win32more.Windows.Win32.Globalization.UErrorCode = 66324
U_REGEX_INVALID_CAPTURE_GROUP_NAME: win32more.Windows.Win32.Globalization.UErrorCode = 66325
U_IDNA_PROHIBITED_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 66560
U_IDNA_ERROR_START: win32more.Windows.Win32.Globalization.UErrorCode = 66560
U_IDNA_UNASSIGNED_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 66561
U_IDNA_CHECK_BIDI_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 66562
U_IDNA_STD3_ASCII_RULES_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 66563
U_IDNA_ACE_PREFIX_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 66564
U_IDNA_VERIFICATION_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 66565
U_IDNA_LABEL_TOO_LONG_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 66566
U_IDNA_ZERO_LENGTH_LABEL_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 66567
U_IDNA_DOMAIN_NAME_TOO_LONG_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 66568
U_STRINGPREP_PROHIBITED_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 66560
U_STRINGPREP_UNASSIGNED_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 66561
U_STRINGPREP_CHECK_BIDI_ERROR: win32more.Windows.Win32.Globalization.UErrorCode = 66562
U_PLUGIN_ERROR_START: win32more.Windows.Win32.Globalization.UErrorCode = 66816
U_PLUGIN_TOO_HIGH: win32more.Windows.Win32.Globalization.UErrorCode = 66816
U_PLUGIN_DIDNT_SET_LEVEL: win32more.Windows.Win32.Globalization.UErrorCode = 66817
UFieldCategory = Int32
UFIELD_CATEGORY_UNDEFINED: win32more.Windows.Win32.Globalization.UFieldCategory = 0
UFIELD_CATEGORY_DATE: win32more.Windows.Win32.Globalization.UFieldCategory = 1
UFIELD_CATEGORY_NUMBER: win32more.Windows.Win32.Globalization.UFieldCategory = 2
UFIELD_CATEGORY_LIST: win32more.Windows.Win32.Globalization.UFieldCategory = 3
UFIELD_CATEGORY_RELATIVE_DATETIME: win32more.Windows.Win32.Globalization.UFieldCategory = 4
UFIELD_CATEGORY_DATE_INTERVAL: win32more.Windows.Win32.Globalization.UFieldCategory = 5
UFIELD_CATEGORY_LIST_SPAN: win32more.Windows.Win32.Globalization.UFieldCategory = 4099
UFIELD_CATEGORY_DATE_INTERVAL_SPAN: win32more.Windows.Win32.Globalization.UFieldCategory = 4101
class UFieldPosition(Structure):
    field: Int32
    beginIndex: Int32
    endIndex: Int32
UFieldPositionIterator = IntPtr
UFormattableType = Int32
UFMT_DATE: win32more.Windows.Win32.Globalization.UFormattableType = 0
UFMT_DOUBLE: win32more.Windows.Win32.Globalization.UFormattableType = 1
UFMT_LONG: win32more.Windows.Win32.Globalization.UFormattableType = 2
UFMT_STRING: win32more.Windows.Win32.Globalization.UFormattableType = 3
UFMT_ARRAY: win32more.Windows.Win32.Globalization.UFormattableType = 4
UFMT_INT64: win32more.Windows.Win32.Globalization.UFormattableType = 5
UFMT_OBJECT: win32more.Windows.Win32.Globalization.UFormattableType = 6
UFormattedDateInterval = IntPtr
UFormattedList = IntPtr
UFormattedNumber = IntPtr
UFormattedNumberRange = IntPtr
UFormattedRelativeDateTime = IntPtr
UFormattedValue = IntPtr
UGender = Int32
UGENDER_MALE: win32more.Windows.Win32.Globalization.UGender = 0
UGENDER_FEMALE: win32more.Windows.Win32.Globalization.UGender = 1
UGENDER_OTHER: win32more.Windows.Win32.Globalization.UGender = 2
UGenderInfo = IntPtr
UGraphemeClusterBreak = Int32
U_GCB_OTHER: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 0
U_GCB_CONTROL: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 1
U_GCB_CR: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 2
U_GCB_EXTEND: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 3
U_GCB_L: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 4
U_GCB_LF: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 5
U_GCB_LV: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 6
U_GCB_LVT: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 7
U_GCB_T: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 8
U_GCB_V: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 9
U_GCB_SPACING_MARK: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 10
U_GCB_PREPEND: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 11
U_GCB_REGIONAL_INDICATOR: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 12
U_GCB_E_BASE: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 13
U_GCB_E_BASE_GAZ: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 14
U_GCB_E_MODIFIER: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 15
U_GCB_GLUE_AFTER_ZWJ: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 16
U_GCB_ZWJ: win32more.Windows.Win32.Globalization.UGraphemeClusterBreak = 17
UHangulSyllableType = Int32
U_HST_NOT_APPLICABLE: win32more.Windows.Win32.Globalization.UHangulSyllableType = 0
U_HST_LEADING_JAMO: win32more.Windows.Win32.Globalization.UHangulSyllableType = 1
U_HST_VOWEL_JAMO: win32more.Windows.Win32.Globalization.UHangulSyllableType = 2
U_HST_TRAILING_JAMO: win32more.Windows.Win32.Globalization.UHangulSyllableType = 3
U_HST_LV_SYLLABLE: win32more.Windows.Win32.Globalization.UHangulSyllableType = 4
U_HST_LVT_SYLLABLE: win32more.Windows.Win32.Globalization.UHangulSyllableType = 5
UHashtable = IntPtr
UIDNA = IntPtr
class UIDNAInfo(Structure):
    size: Int16
    isTransitionalDifferent: SByte
    reservedB3: SByte
    errors: UInt32
    reservedI2: Int32
    reservedI3: Int32
@winfunctype_pointer
def UILANGUAGE_ENUMPROCA(param0: win32more.Windows.Win32.Foundation.PSTR, param1: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def UILANGUAGE_ENUMPROCW(param0: win32more.Windows.Win32.Foundation.PWSTR, param1: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
UILANGUAGE_ENUMPROC = UnicodeAlias('UILANGUAGE_ENUMPROCW')
UIndicPositionalCategory = Int32
U_INPC_NA: win32more.Windows.Win32.Globalization.UIndicPositionalCategory = 0
U_INPC_BOTTOM: win32more.Windows.Win32.Globalization.UIndicPositionalCategory = 1
U_INPC_BOTTOM_AND_LEFT: win32more.Windows.Win32.Globalization.UIndicPositionalCategory = 2
U_INPC_BOTTOM_AND_RIGHT: win32more.Windows.Win32.Globalization.UIndicPositionalCategory = 3
U_INPC_LEFT: win32more.Windows.Win32.Globalization.UIndicPositionalCategory = 4
U_INPC_LEFT_AND_RIGHT: win32more.Windows.Win32.Globalization.UIndicPositionalCategory = 5
U_INPC_OVERSTRUCK: win32more.Windows.Win32.Globalization.UIndicPositionalCategory = 6
U_INPC_RIGHT: win32more.Windows.Win32.Globalization.UIndicPositionalCategory = 7
U_INPC_TOP: win32more.Windows.Win32.Globalization.UIndicPositionalCategory = 8
U_INPC_TOP_AND_BOTTOM: win32more.Windows.Win32.Globalization.UIndicPositionalCategory = 9
U_INPC_TOP_AND_BOTTOM_AND_RIGHT: win32more.Windows.Win32.Globalization.UIndicPositionalCategory = 10
U_INPC_TOP_AND_LEFT: win32more.Windows.Win32.Globalization.UIndicPositionalCategory = 11
U_INPC_TOP_AND_LEFT_AND_RIGHT: win32more.Windows.Win32.Globalization.UIndicPositionalCategory = 12
U_INPC_TOP_AND_RIGHT: win32more.Windows.Win32.Globalization.UIndicPositionalCategory = 13
U_INPC_VISUAL_ORDER_LEFT: win32more.Windows.Win32.Globalization.UIndicPositionalCategory = 14
U_INPC_TOP_AND_BOTTOM_AND_LEFT: win32more.Windows.Win32.Globalization.UIndicPositionalCategory = 15
UIndicSyllabicCategory = Int32
U_INSC_OTHER: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 0
U_INSC_AVAGRAHA: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 1
U_INSC_BINDU: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 2
U_INSC_BRAHMI_JOINING_NUMBER: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 3
U_INSC_CANTILLATION_MARK: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 4
U_INSC_CONSONANT: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 5
U_INSC_CONSONANT_DEAD: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 6
U_INSC_CONSONANT_FINAL: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 7
U_INSC_CONSONANT_HEAD_LETTER: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 8
U_INSC_CONSONANT_INITIAL_POSTFIXED: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 9
U_INSC_CONSONANT_KILLER: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 10
U_INSC_CONSONANT_MEDIAL: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 11
U_INSC_CONSONANT_PLACEHOLDER: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 12
U_INSC_CONSONANT_PRECEDING_REPHA: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 13
U_INSC_CONSONANT_PREFIXED: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 14
U_INSC_CONSONANT_SUBJOINED: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 15
U_INSC_CONSONANT_SUCCEEDING_REPHA: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 16
U_INSC_CONSONANT_WITH_STACKER: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 17
U_INSC_GEMINATION_MARK: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 18
U_INSC_INVISIBLE_STACKER: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 19
U_INSC_JOINER: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 20
U_INSC_MODIFYING_LETTER: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 21
U_INSC_NON_JOINER: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 22
U_INSC_NUKTA: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 23
U_INSC_NUMBER: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 24
U_INSC_NUMBER_JOINER: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 25
U_INSC_PURE_KILLER: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 26
U_INSC_REGISTER_SHIFTER: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 27
U_INSC_SYLLABLE_MODIFIER: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 28
U_INSC_TONE_LETTER: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 29
U_INSC_TONE_MARK: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 30
U_INSC_VIRAMA: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 31
U_INSC_VISARGA: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 32
U_INSC_VOWEL: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 33
U_INSC_VOWEL_DEPENDENT: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 34
U_INSC_VOWEL_INDEPENDENT: win32more.Windows.Win32.Globalization.UIndicSyllabicCategory = 35
UJoiningGroup = Int32
U_JG_NO_JOINING_GROUP: win32more.Windows.Win32.Globalization.UJoiningGroup = 0
U_JG_AIN: win32more.Windows.Win32.Globalization.UJoiningGroup = 1
U_JG_ALAPH: win32more.Windows.Win32.Globalization.UJoiningGroup = 2
U_JG_ALEF: win32more.Windows.Win32.Globalization.UJoiningGroup = 3
U_JG_BEH: win32more.Windows.Win32.Globalization.UJoiningGroup = 4
U_JG_BETH: win32more.Windows.Win32.Globalization.UJoiningGroup = 5
U_JG_DAL: win32more.Windows.Win32.Globalization.UJoiningGroup = 6
U_JG_DALATH_RISH: win32more.Windows.Win32.Globalization.UJoiningGroup = 7
U_JG_E: win32more.Windows.Win32.Globalization.UJoiningGroup = 8
U_JG_FEH: win32more.Windows.Win32.Globalization.UJoiningGroup = 9
U_JG_FINAL_SEMKATH: win32more.Windows.Win32.Globalization.UJoiningGroup = 10
U_JG_GAF: win32more.Windows.Win32.Globalization.UJoiningGroup = 11
U_JG_GAMAL: win32more.Windows.Win32.Globalization.UJoiningGroup = 12
U_JG_HAH: win32more.Windows.Win32.Globalization.UJoiningGroup = 13
U_JG_TEH_MARBUTA_GOAL: win32more.Windows.Win32.Globalization.UJoiningGroup = 14
U_JG_HAMZA_ON_HEH_GOAL: win32more.Windows.Win32.Globalization.UJoiningGroup = 14
U_JG_HE: win32more.Windows.Win32.Globalization.UJoiningGroup = 15
U_JG_HEH: win32more.Windows.Win32.Globalization.UJoiningGroup = 16
U_JG_HEH_GOAL: win32more.Windows.Win32.Globalization.UJoiningGroup = 17
U_JG_HETH: win32more.Windows.Win32.Globalization.UJoiningGroup = 18
U_JG_KAF: win32more.Windows.Win32.Globalization.UJoiningGroup = 19
U_JG_KAPH: win32more.Windows.Win32.Globalization.UJoiningGroup = 20
U_JG_KNOTTED_HEH: win32more.Windows.Win32.Globalization.UJoiningGroup = 21
U_JG_LAM: win32more.Windows.Win32.Globalization.UJoiningGroup = 22
U_JG_LAMADH: win32more.Windows.Win32.Globalization.UJoiningGroup = 23
U_JG_MEEM: win32more.Windows.Win32.Globalization.UJoiningGroup = 24
U_JG_MIM: win32more.Windows.Win32.Globalization.UJoiningGroup = 25
U_JG_NOON: win32more.Windows.Win32.Globalization.UJoiningGroup = 26
U_JG_NUN: win32more.Windows.Win32.Globalization.UJoiningGroup = 27
U_JG_PE: win32more.Windows.Win32.Globalization.UJoiningGroup = 28
U_JG_QAF: win32more.Windows.Win32.Globalization.UJoiningGroup = 29
U_JG_QAPH: win32more.Windows.Win32.Globalization.UJoiningGroup = 30
U_JG_REH: win32more.Windows.Win32.Globalization.UJoiningGroup = 31
U_JG_REVERSED_PE: win32more.Windows.Win32.Globalization.UJoiningGroup = 32
U_JG_SAD: win32more.Windows.Win32.Globalization.UJoiningGroup = 33
U_JG_SADHE: win32more.Windows.Win32.Globalization.UJoiningGroup = 34
U_JG_SEEN: win32more.Windows.Win32.Globalization.UJoiningGroup = 35
U_JG_SEMKATH: win32more.Windows.Win32.Globalization.UJoiningGroup = 36
U_JG_SHIN: win32more.Windows.Win32.Globalization.UJoiningGroup = 37
U_JG_SWASH_KAF: win32more.Windows.Win32.Globalization.UJoiningGroup = 38
U_JG_SYRIAC_WAW: win32more.Windows.Win32.Globalization.UJoiningGroup = 39
U_JG_TAH: win32more.Windows.Win32.Globalization.UJoiningGroup = 40
U_JG_TAW: win32more.Windows.Win32.Globalization.UJoiningGroup = 41
U_JG_TEH_MARBUTA: win32more.Windows.Win32.Globalization.UJoiningGroup = 42
U_JG_TETH: win32more.Windows.Win32.Globalization.UJoiningGroup = 43
U_JG_WAW: win32more.Windows.Win32.Globalization.UJoiningGroup = 44
U_JG_YEH: win32more.Windows.Win32.Globalization.UJoiningGroup = 45
U_JG_YEH_BARREE: win32more.Windows.Win32.Globalization.UJoiningGroup = 46
U_JG_YEH_WITH_TAIL: win32more.Windows.Win32.Globalization.UJoiningGroup = 47
U_JG_YUDH: win32more.Windows.Win32.Globalization.UJoiningGroup = 48
U_JG_YUDH_HE: win32more.Windows.Win32.Globalization.UJoiningGroup = 49
U_JG_ZAIN: win32more.Windows.Win32.Globalization.UJoiningGroup = 50
U_JG_FE: win32more.Windows.Win32.Globalization.UJoiningGroup = 51
U_JG_KHAPH: win32more.Windows.Win32.Globalization.UJoiningGroup = 52
U_JG_ZHAIN: win32more.Windows.Win32.Globalization.UJoiningGroup = 53
U_JG_BURUSHASKI_YEH_BARREE: win32more.Windows.Win32.Globalization.UJoiningGroup = 54
U_JG_FARSI_YEH: win32more.Windows.Win32.Globalization.UJoiningGroup = 55
U_JG_NYA: win32more.Windows.Win32.Globalization.UJoiningGroup = 56
U_JG_ROHINGYA_YEH: win32more.Windows.Win32.Globalization.UJoiningGroup = 57
U_JG_MANICHAEAN_ALEPH: win32more.Windows.Win32.Globalization.UJoiningGroup = 58
U_JG_MANICHAEAN_AYIN: win32more.Windows.Win32.Globalization.UJoiningGroup = 59
U_JG_MANICHAEAN_BETH: win32more.Windows.Win32.Globalization.UJoiningGroup = 60
U_JG_MANICHAEAN_DALETH: win32more.Windows.Win32.Globalization.UJoiningGroup = 61
U_JG_MANICHAEAN_DHAMEDH: win32more.Windows.Win32.Globalization.UJoiningGroup = 62
U_JG_MANICHAEAN_FIVE: win32more.Windows.Win32.Globalization.UJoiningGroup = 63
U_JG_MANICHAEAN_GIMEL: win32more.Windows.Win32.Globalization.UJoiningGroup = 64
U_JG_MANICHAEAN_HETH: win32more.Windows.Win32.Globalization.UJoiningGroup = 65
U_JG_MANICHAEAN_HUNDRED: win32more.Windows.Win32.Globalization.UJoiningGroup = 66
U_JG_MANICHAEAN_KAPH: win32more.Windows.Win32.Globalization.UJoiningGroup = 67
U_JG_MANICHAEAN_LAMEDH: win32more.Windows.Win32.Globalization.UJoiningGroup = 68
U_JG_MANICHAEAN_MEM: win32more.Windows.Win32.Globalization.UJoiningGroup = 69
U_JG_MANICHAEAN_NUN: win32more.Windows.Win32.Globalization.UJoiningGroup = 70
U_JG_MANICHAEAN_ONE: win32more.Windows.Win32.Globalization.UJoiningGroup = 71
U_JG_MANICHAEAN_PE: win32more.Windows.Win32.Globalization.UJoiningGroup = 72
U_JG_MANICHAEAN_QOPH: win32more.Windows.Win32.Globalization.UJoiningGroup = 73
U_JG_MANICHAEAN_RESH: win32more.Windows.Win32.Globalization.UJoiningGroup = 74
U_JG_MANICHAEAN_SADHE: win32more.Windows.Win32.Globalization.UJoiningGroup = 75
U_JG_MANICHAEAN_SAMEKH: win32more.Windows.Win32.Globalization.UJoiningGroup = 76
U_JG_MANICHAEAN_TAW: win32more.Windows.Win32.Globalization.UJoiningGroup = 77
U_JG_MANICHAEAN_TEN: win32more.Windows.Win32.Globalization.UJoiningGroup = 78
U_JG_MANICHAEAN_TETH: win32more.Windows.Win32.Globalization.UJoiningGroup = 79
U_JG_MANICHAEAN_THAMEDH: win32more.Windows.Win32.Globalization.UJoiningGroup = 80
U_JG_MANICHAEAN_TWENTY: win32more.Windows.Win32.Globalization.UJoiningGroup = 81
U_JG_MANICHAEAN_WAW: win32more.Windows.Win32.Globalization.UJoiningGroup = 82
U_JG_MANICHAEAN_YODH: win32more.Windows.Win32.Globalization.UJoiningGroup = 83
U_JG_MANICHAEAN_ZAYIN: win32more.Windows.Win32.Globalization.UJoiningGroup = 84
U_JG_STRAIGHT_WAW: win32more.Windows.Win32.Globalization.UJoiningGroup = 85
U_JG_AFRICAN_FEH: win32more.Windows.Win32.Globalization.UJoiningGroup = 86
U_JG_AFRICAN_NOON: win32more.Windows.Win32.Globalization.UJoiningGroup = 87
U_JG_AFRICAN_QAF: win32more.Windows.Win32.Globalization.UJoiningGroup = 88
U_JG_MALAYALAM_BHA: win32more.Windows.Win32.Globalization.UJoiningGroup = 89
U_JG_MALAYALAM_JA: win32more.Windows.Win32.Globalization.UJoiningGroup = 90
U_JG_MALAYALAM_LLA: win32more.Windows.Win32.Globalization.UJoiningGroup = 91
U_JG_MALAYALAM_LLLA: win32more.Windows.Win32.Globalization.UJoiningGroup = 92
U_JG_MALAYALAM_NGA: win32more.Windows.Win32.Globalization.UJoiningGroup = 93
U_JG_MALAYALAM_NNA: win32more.Windows.Win32.Globalization.UJoiningGroup = 94
U_JG_MALAYALAM_NNNA: win32more.Windows.Win32.Globalization.UJoiningGroup = 95
U_JG_MALAYALAM_NYA: win32more.Windows.Win32.Globalization.UJoiningGroup = 96
U_JG_MALAYALAM_RA: win32more.Windows.Win32.Globalization.UJoiningGroup = 97
U_JG_MALAYALAM_SSA: win32more.Windows.Win32.Globalization.UJoiningGroup = 98
U_JG_MALAYALAM_TTA: win32more.Windows.Win32.Globalization.UJoiningGroup = 99
U_JG_HANIFI_ROHINGYA_KINNA_YA: win32more.Windows.Win32.Globalization.UJoiningGroup = 100
U_JG_HANIFI_ROHINGYA_PA: win32more.Windows.Win32.Globalization.UJoiningGroup = 101
UJoiningType = Int32
U_JT_NON_JOINING: win32more.Windows.Win32.Globalization.UJoiningType = 0
U_JT_JOIN_CAUSING: win32more.Windows.Win32.Globalization.UJoiningType = 1
U_JT_DUAL_JOINING: win32more.Windows.Win32.Globalization.UJoiningType = 2
U_JT_LEFT_JOINING: win32more.Windows.Win32.Globalization.UJoiningType = 3
U_JT_RIGHT_JOINING: win32more.Windows.Win32.Globalization.UJoiningType = 4
U_JT_TRANSPARENT: win32more.Windows.Win32.Globalization.UJoiningType = 5
ULayoutType = Int32
ULOC_LAYOUT_LTR: win32more.Windows.Win32.Globalization.ULayoutType = 0
ULOC_LAYOUT_RTL: win32more.Windows.Win32.Globalization.ULayoutType = 1
ULOC_LAYOUT_TTB: win32more.Windows.Win32.Globalization.ULayoutType = 2
ULOC_LAYOUT_BTT: win32more.Windows.Win32.Globalization.ULayoutType = 3
ULOC_LAYOUT_UNKNOWN: win32more.Windows.Win32.Globalization.ULayoutType = 4
ULineBreak = Int32
U_LB_UNKNOWN: win32more.Windows.Win32.Globalization.ULineBreak = 0
U_LB_AMBIGUOUS: win32more.Windows.Win32.Globalization.ULineBreak = 1
U_LB_ALPHABETIC: win32more.Windows.Win32.Globalization.ULineBreak = 2
U_LB_BREAK_BOTH: win32more.Windows.Win32.Globalization.ULineBreak = 3
U_LB_BREAK_AFTER: win32more.Windows.Win32.Globalization.ULineBreak = 4
U_LB_BREAK_BEFORE: win32more.Windows.Win32.Globalization.ULineBreak = 5
U_LB_MANDATORY_BREAK: win32more.Windows.Win32.Globalization.ULineBreak = 6
U_LB_CONTINGENT_BREAK: win32more.Windows.Win32.Globalization.ULineBreak = 7
U_LB_CLOSE_PUNCTUATION: win32more.Windows.Win32.Globalization.ULineBreak = 8
U_LB_COMBINING_MARK: win32more.Windows.Win32.Globalization.ULineBreak = 9
U_LB_CARRIAGE_RETURN: win32more.Windows.Win32.Globalization.ULineBreak = 10
U_LB_EXCLAMATION: win32more.Windows.Win32.Globalization.ULineBreak = 11
U_LB_GLUE: win32more.Windows.Win32.Globalization.ULineBreak = 12
U_LB_HYPHEN: win32more.Windows.Win32.Globalization.ULineBreak = 13
U_LB_IDEOGRAPHIC: win32more.Windows.Win32.Globalization.ULineBreak = 14
U_LB_INSEPARABLE: win32more.Windows.Win32.Globalization.ULineBreak = 15
U_LB_INSEPERABLE: win32more.Windows.Win32.Globalization.ULineBreak = 15
U_LB_INFIX_NUMERIC: win32more.Windows.Win32.Globalization.ULineBreak = 16
U_LB_LINE_FEED: win32more.Windows.Win32.Globalization.ULineBreak = 17
U_LB_NONSTARTER: win32more.Windows.Win32.Globalization.ULineBreak = 18
U_LB_NUMERIC: win32more.Windows.Win32.Globalization.ULineBreak = 19
U_LB_OPEN_PUNCTUATION: win32more.Windows.Win32.Globalization.ULineBreak = 20
U_LB_POSTFIX_NUMERIC: win32more.Windows.Win32.Globalization.ULineBreak = 21
U_LB_PREFIX_NUMERIC: win32more.Windows.Win32.Globalization.ULineBreak = 22
U_LB_QUOTATION: win32more.Windows.Win32.Globalization.ULineBreak = 23
U_LB_COMPLEX_CONTEXT: win32more.Windows.Win32.Globalization.ULineBreak = 24
U_LB_SURROGATE: win32more.Windows.Win32.Globalization.ULineBreak = 25
U_LB_SPACE: win32more.Windows.Win32.Globalization.ULineBreak = 26
U_LB_BREAK_SYMBOLS: win32more.Windows.Win32.Globalization.ULineBreak = 27
U_LB_ZWSPACE: win32more.Windows.Win32.Globalization.ULineBreak = 28
U_LB_NEXT_LINE: win32more.Windows.Win32.Globalization.ULineBreak = 29
U_LB_WORD_JOINER: win32more.Windows.Win32.Globalization.ULineBreak = 30
U_LB_H2: win32more.Windows.Win32.Globalization.ULineBreak = 31
U_LB_H3: win32more.Windows.Win32.Globalization.ULineBreak = 32
U_LB_JL: win32more.Windows.Win32.Globalization.ULineBreak = 33
U_LB_JT: win32more.Windows.Win32.Globalization.ULineBreak = 34
U_LB_JV: win32more.Windows.Win32.Globalization.ULineBreak = 35
U_LB_CLOSE_PARENTHESIS: win32more.Windows.Win32.Globalization.ULineBreak = 36
U_LB_CONDITIONAL_JAPANESE_STARTER: win32more.Windows.Win32.Globalization.ULineBreak = 37
U_LB_HEBREW_LETTER: win32more.Windows.Win32.Globalization.ULineBreak = 38
U_LB_REGIONAL_INDICATOR: win32more.Windows.Win32.Globalization.ULineBreak = 39
U_LB_E_BASE: win32more.Windows.Win32.Globalization.ULineBreak = 40
U_LB_E_MODIFIER: win32more.Windows.Win32.Globalization.ULineBreak = 41
U_LB_ZWJ: win32more.Windows.Win32.Globalization.ULineBreak = 42
ULineBreakTag = Int32
UBRK_LINE_SOFT: win32more.Windows.Win32.Globalization.ULineBreakTag = 0
UBRK_LINE_SOFT_LIMIT: win32more.Windows.Win32.Globalization.ULineBreakTag = 100
UBRK_LINE_HARD: win32more.Windows.Win32.Globalization.ULineBreakTag = 100
UBRK_LINE_HARD_LIMIT: win32more.Windows.Win32.Globalization.ULineBreakTag = 200
UListFormatter = IntPtr
UListFormatterField = Int32
ULISTFMT_LITERAL_FIELD: win32more.Windows.Win32.Globalization.UListFormatterField = 0
ULISTFMT_ELEMENT_FIELD: win32more.Windows.Win32.Globalization.UListFormatterField = 1
UListFormatterType = Int32
ULISTFMT_TYPE_AND: win32more.Windows.Win32.Globalization.UListFormatterType = 0
ULISTFMT_TYPE_OR: win32more.Windows.Win32.Globalization.UListFormatterType = 1
ULISTFMT_TYPE_UNITS: win32more.Windows.Win32.Globalization.UListFormatterType = 2
UListFormatterWidth = Int32
ULISTFMT_WIDTH_WIDE: win32more.Windows.Win32.Globalization.UListFormatterWidth = 0
ULISTFMT_WIDTH_SHORT: win32more.Windows.Win32.Globalization.UListFormatterWidth = 1
ULISTFMT_WIDTH_NARROW: win32more.Windows.Win32.Globalization.UListFormatterWidth = 2
ULocAvailableType = Int32
ULOC_AVAILABLE_DEFAULT: win32more.Windows.Win32.Globalization.ULocAvailableType = 0
ULOC_AVAILABLE_ONLY_LEGACY_ALIASES: win32more.Windows.Win32.Globalization.ULocAvailableType = 1
ULOC_AVAILABLE_WITH_LEGACY_ALIASES: win32more.Windows.Win32.Globalization.ULocAvailableType = 2
ULocDataLocaleType = Int32
ULOC_ACTUAL_LOCALE: win32more.Windows.Win32.Globalization.ULocDataLocaleType = 0
ULOC_VALID_LOCALE: win32more.Windows.Win32.Globalization.ULocDataLocaleType = 1
ULocaleData = IntPtr
ULocaleDataDelimiterType = Int32
ULOCDATA_QUOTATION_START: win32more.Windows.Win32.Globalization.ULocaleDataDelimiterType = 0
ULOCDATA_QUOTATION_END: win32more.Windows.Win32.Globalization.ULocaleDataDelimiterType = 1
ULOCDATA_ALT_QUOTATION_START: win32more.Windows.Win32.Globalization.ULocaleDataDelimiterType = 2
ULOCDATA_ALT_QUOTATION_END: win32more.Windows.Win32.Globalization.ULocaleDataDelimiterType = 3
ULocaleDataExemplarSetType = Int32
ULOCDATA_ES_STANDARD: win32more.Windows.Win32.Globalization.ULocaleDataExemplarSetType = 0
ULOCDATA_ES_AUXILIARY: win32more.Windows.Win32.Globalization.ULocaleDataExemplarSetType = 1
ULOCDATA_ES_INDEX: win32more.Windows.Win32.Globalization.ULocaleDataExemplarSetType = 2
ULOCDATA_ES_PUNCTUATION: win32more.Windows.Win32.Globalization.ULocaleDataExemplarSetType = 3
ULocaleDisplayNames = IntPtr
UMeasureFormatWidth = Int32
UMEASFMT_WIDTH_WIDE: win32more.Windows.Win32.Globalization.UMeasureFormatWidth = 0
UMEASFMT_WIDTH_SHORT: win32more.Windows.Win32.Globalization.UMeasureFormatWidth = 1
UMEASFMT_WIDTH_NARROW: win32more.Windows.Win32.Globalization.UMeasureFormatWidth = 2
UMEASFMT_WIDTH_NUMERIC: win32more.Windows.Win32.Globalization.UMeasureFormatWidth = 3
UMEASFMT_WIDTH_COUNT: win32more.Windows.Win32.Globalization.UMeasureFormatWidth = 4
UMeasurementSystem = Int32
UMS_SI: win32more.Windows.Win32.Globalization.UMeasurementSystem = 0
UMS_US: win32more.Windows.Win32.Globalization.UMeasurementSystem = 1
UMS_UK: win32more.Windows.Win32.Globalization.UMeasurementSystem = 2
@cfunctype_pointer
def UMemAllocFn(context: VoidPtr, size: UIntPtr) -> VoidPtr: ...
@cfunctype_pointer
def UMemFreeFn(context: VoidPtr, mem: VoidPtr) -> Void: ...
@cfunctype_pointer
def UMemReallocFn(context: VoidPtr, mem: VoidPtr, size: UIntPtr) -> VoidPtr: ...
UMessagePatternApostropheMode = Int32
UMSGPAT_APOS_DOUBLE_OPTIONAL: win32more.Windows.Win32.Globalization.UMessagePatternApostropheMode = 0
UMSGPAT_APOS_DOUBLE_REQUIRED: win32more.Windows.Win32.Globalization.UMessagePatternApostropheMode = 1
UMessagePatternArgType = Int32
UMSGPAT_ARG_TYPE_NONE: win32more.Windows.Win32.Globalization.UMessagePatternArgType = 0
UMSGPAT_ARG_TYPE_SIMPLE: win32more.Windows.Win32.Globalization.UMessagePatternArgType = 1
UMSGPAT_ARG_TYPE_CHOICE: win32more.Windows.Win32.Globalization.UMessagePatternArgType = 2
UMSGPAT_ARG_TYPE_PLURAL: win32more.Windows.Win32.Globalization.UMessagePatternArgType = 3
UMSGPAT_ARG_TYPE_SELECT: win32more.Windows.Win32.Globalization.UMessagePatternArgType = 4
UMSGPAT_ARG_TYPE_SELECTORDINAL: win32more.Windows.Win32.Globalization.UMessagePatternArgType = 5
UMessagePatternPartType = Int32
UMSGPAT_PART_TYPE_MSG_START: win32more.Windows.Win32.Globalization.UMessagePatternPartType = 0
UMSGPAT_PART_TYPE_MSG_LIMIT: win32more.Windows.Win32.Globalization.UMessagePatternPartType = 1
UMSGPAT_PART_TYPE_SKIP_SYNTAX: win32more.Windows.Win32.Globalization.UMessagePatternPartType = 2
UMSGPAT_PART_TYPE_INSERT_CHAR: win32more.Windows.Win32.Globalization.UMessagePatternPartType = 3
UMSGPAT_PART_TYPE_REPLACE_NUMBER: win32more.Windows.Win32.Globalization.UMessagePatternPartType = 4
UMSGPAT_PART_TYPE_ARG_START: win32more.Windows.Win32.Globalization.UMessagePatternPartType = 5
UMSGPAT_PART_TYPE_ARG_LIMIT: win32more.Windows.Win32.Globalization.UMessagePatternPartType = 6
UMSGPAT_PART_TYPE_ARG_NUMBER: win32more.Windows.Win32.Globalization.UMessagePatternPartType = 7
UMSGPAT_PART_TYPE_ARG_NAME: win32more.Windows.Win32.Globalization.UMessagePatternPartType = 8
UMSGPAT_PART_TYPE_ARG_TYPE: win32more.Windows.Win32.Globalization.UMessagePatternPartType = 9
UMSGPAT_PART_TYPE_ARG_STYLE: win32more.Windows.Win32.Globalization.UMessagePatternPartType = 10
UMSGPAT_PART_TYPE_ARG_SELECTOR: win32more.Windows.Win32.Globalization.UMessagePatternPartType = 11
UMSGPAT_PART_TYPE_ARG_INT: win32more.Windows.Win32.Globalization.UMessagePatternPartType = 12
UMSGPAT_PART_TYPE_ARG_DOUBLE: win32more.Windows.Win32.Globalization.UMessagePatternPartType = 13
UMutableCPTrie = IntPtr
@cfunctype_pointer
def UNESCAPE_CHAR_AT(offset: Int32, context: VoidPtr) -> UInt16: ...
class UNICODERANGE(Structure):
    wcFrom: Char
    wcTo: Char
UNormalization2Mode = Int32
UNORM2_COMPOSE: win32more.Windows.Win32.Globalization.UNormalization2Mode = 0
UNORM2_DECOMPOSE: win32more.Windows.Win32.Globalization.UNormalization2Mode = 1
UNORM2_FCD: win32more.Windows.Win32.Globalization.UNormalization2Mode = 2
UNORM2_COMPOSE_CONTIGUOUS: win32more.Windows.Win32.Globalization.UNormalization2Mode = 3
UNormalizationCheckResult = Int32
UNORM_NO: win32more.Windows.Win32.Globalization.UNormalizationCheckResult = 0
UNORM_YES: win32more.Windows.Win32.Globalization.UNormalizationCheckResult = 1
UNORM_MAYBE: win32more.Windows.Win32.Globalization.UNormalizationCheckResult = 2
UNormalizationMode = Int32
UNORM_NONE: win32more.Windows.Win32.Globalization.UNormalizationMode = 1
UNORM_NFD: win32more.Windows.Win32.Globalization.UNormalizationMode = 2
UNORM_NFKD: win32more.Windows.Win32.Globalization.UNormalizationMode = 3
UNORM_NFC: win32more.Windows.Win32.Globalization.UNormalizationMode = 4
UNORM_DEFAULT: win32more.Windows.Win32.Globalization.UNormalizationMode = 4
UNORM_NFKC: win32more.Windows.Win32.Globalization.UNormalizationMode = 5
UNORM_FCD: win32more.Windows.Win32.Globalization.UNormalizationMode = 6
UNORM_MODE_COUNT: win32more.Windows.Win32.Globalization.UNormalizationMode = 7
UNormalizer2 = IntPtr
UNumberCompactStyle = Int32
UNUM_SHORT: win32more.Windows.Win32.Globalization.UNumberCompactStyle = 0
UNUM_LONG: win32more.Windows.Win32.Globalization.UNumberCompactStyle = 1
UNumberDecimalSeparatorDisplay = Int32
UNUM_DECIMAL_SEPARATOR_AUTO: win32more.Windows.Win32.Globalization.UNumberDecimalSeparatorDisplay = 0
UNUM_DECIMAL_SEPARATOR_ALWAYS: win32more.Windows.Win32.Globalization.UNumberDecimalSeparatorDisplay = 1
UNUM_DECIMAL_SEPARATOR_COUNT: win32more.Windows.Win32.Globalization.UNumberDecimalSeparatorDisplay = 2
UNumberFormatAttribute = Int32
UNUM_PARSE_INT_ONLY: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 0
UNUM_GROUPING_USED: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 1
UNUM_DECIMAL_ALWAYS_SHOWN: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 2
UNUM_MAX_INTEGER_DIGITS: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 3
UNUM_MIN_INTEGER_DIGITS: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 4
UNUM_INTEGER_DIGITS: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 5
UNUM_MAX_FRACTION_DIGITS: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 6
UNUM_MIN_FRACTION_DIGITS: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 7
UNUM_FRACTION_DIGITS: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 8
UNUM_MULTIPLIER: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 9
UNUM_GROUPING_SIZE: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 10
UNUM_ROUNDING_MODE: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 11
UNUM_ROUNDING_INCREMENT: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 12
UNUM_FORMAT_WIDTH: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 13
UNUM_PADDING_POSITION: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 14
UNUM_SECONDARY_GROUPING_SIZE: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 15
UNUM_SIGNIFICANT_DIGITS_USED: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 16
UNUM_MIN_SIGNIFICANT_DIGITS: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 17
UNUM_MAX_SIGNIFICANT_DIGITS: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 18
UNUM_LENIENT_PARSE: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 19
UNUM_PARSE_ALL_INPUT: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 20
UNUM_SCALE: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 21
UNUM_MINIMUM_GROUPING_DIGITS: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 22
UNUM_CURRENCY_USAGE: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 23
UNUM_FORMAT_FAIL_IF_MORE_THAN_MAX_DIGITS: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 4096
UNUM_PARSE_NO_EXPONENT: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 4097
UNUM_PARSE_DECIMAL_MARK_REQUIRED: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 4098
UNUM_PARSE_CASE_SENSITIVE: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 4099
UNUM_SIGN_ALWAYS_SHOWN: win32more.Windows.Win32.Globalization.UNumberFormatAttribute = 4100
UNumberFormatAttributeValue = Int32
UNUM_FORMAT_ATTRIBUTE_VALUE_HIDDEN: win32more.Windows.Win32.Globalization.UNumberFormatAttributeValue = 0
UNumberFormatFields = Int32
UNUM_INTEGER_FIELD: win32more.Windows.Win32.Globalization.UNumberFormatFields = 0
UNUM_FRACTION_FIELD: win32more.Windows.Win32.Globalization.UNumberFormatFields = 1
UNUM_DECIMAL_SEPARATOR_FIELD: win32more.Windows.Win32.Globalization.UNumberFormatFields = 2
UNUM_EXPONENT_SYMBOL_FIELD: win32more.Windows.Win32.Globalization.UNumberFormatFields = 3
UNUM_EXPONENT_SIGN_FIELD: win32more.Windows.Win32.Globalization.UNumberFormatFields = 4
UNUM_EXPONENT_FIELD: win32more.Windows.Win32.Globalization.UNumberFormatFields = 5
UNUM_GROUPING_SEPARATOR_FIELD: win32more.Windows.Win32.Globalization.UNumberFormatFields = 6
UNUM_CURRENCY_FIELD: win32more.Windows.Win32.Globalization.UNumberFormatFields = 7
UNUM_PERCENT_FIELD: win32more.Windows.Win32.Globalization.UNumberFormatFields = 8
UNUM_PERMILL_FIELD: win32more.Windows.Win32.Globalization.UNumberFormatFields = 9
UNUM_SIGN_FIELD: win32more.Windows.Win32.Globalization.UNumberFormatFields = 10
UNUM_MEASURE_UNIT_FIELD: win32more.Windows.Win32.Globalization.UNumberFormatFields = 11
UNUM_COMPACT_FIELD: win32more.Windows.Win32.Globalization.UNumberFormatFields = 12
UNumberFormatPadPosition = Int32
UNUM_PAD_BEFORE_PREFIX: win32more.Windows.Win32.Globalization.UNumberFormatPadPosition = 0
UNUM_PAD_AFTER_PREFIX: win32more.Windows.Win32.Globalization.UNumberFormatPadPosition = 1
UNUM_PAD_BEFORE_SUFFIX: win32more.Windows.Win32.Globalization.UNumberFormatPadPosition = 2
UNUM_PAD_AFTER_SUFFIX: win32more.Windows.Win32.Globalization.UNumberFormatPadPosition = 3
UNumberFormatRoundingMode = Int32
UNUM_ROUND_CEILING: win32more.Windows.Win32.Globalization.UNumberFormatRoundingMode = 0
UNUM_ROUND_FLOOR: win32more.Windows.Win32.Globalization.UNumberFormatRoundingMode = 1
UNUM_ROUND_DOWN: win32more.Windows.Win32.Globalization.UNumberFormatRoundingMode = 2
UNUM_ROUND_UP: win32more.Windows.Win32.Globalization.UNumberFormatRoundingMode = 3
UNUM_ROUND_HALFEVEN: win32more.Windows.Win32.Globalization.UNumberFormatRoundingMode = 4
UNUM_ROUND_HALFDOWN: win32more.Windows.Win32.Globalization.UNumberFormatRoundingMode = 5
UNUM_ROUND_HALFUP: win32more.Windows.Win32.Globalization.UNumberFormatRoundingMode = 6
UNUM_ROUND_UNNECESSARY: win32more.Windows.Win32.Globalization.UNumberFormatRoundingMode = 7
UNumberFormatStyle = Int32
UNUM_PATTERN_DECIMAL: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 0
UNUM_DECIMAL: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 1
UNUM_CURRENCY: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 2
UNUM_PERCENT: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 3
UNUM_SCIENTIFIC: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 4
UNUM_SPELLOUT: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 5
UNUM_ORDINAL: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 6
UNUM_DURATION: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 7
UNUM_NUMBERING_SYSTEM: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 8
UNUM_PATTERN_RULEBASED: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 9
UNUM_CURRENCY_ISO: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 10
UNUM_CURRENCY_PLURAL: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 11
UNUM_CURRENCY_ACCOUNTING: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 12
UNUM_CASH_CURRENCY: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 13
UNUM_DECIMAL_COMPACT_SHORT: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 14
UNUM_DECIMAL_COMPACT_LONG: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 15
UNUM_CURRENCY_STANDARD: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 16
UNUM_DEFAULT: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 1
UNUM_IGNORE: win32more.Windows.Win32.Globalization.UNumberFormatStyle = 0
UNumberFormatSymbol = Int32
UNUM_DECIMAL_SEPARATOR_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 0
UNUM_GROUPING_SEPARATOR_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 1
UNUM_PATTERN_SEPARATOR_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 2
UNUM_PERCENT_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 3
UNUM_ZERO_DIGIT_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 4
UNUM_DIGIT_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 5
UNUM_MINUS_SIGN_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 6
UNUM_PLUS_SIGN_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 7
UNUM_CURRENCY_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 8
UNUM_INTL_CURRENCY_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 9
UNUM_MONETARY_SEPARATOR_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 10
UNUM_EXPONENTIAL_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 11
UNUM_PERMILL_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 12
UNUM_PAD_ESCAPE_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 13
UNUM_INFINITY_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 14
UNUM_NAN_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 15
UNUM_SIGNIFICANT_DIGIT_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 16
UNUM_MONETARY_GROUPING_SEPARATOR_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 17
UNUM_ONE_DIGIT_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 18
UNUM_TWO_DIGIT_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 19
UNUM_THREE_DIGIT_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 20
UNUM_FOUR_DIGIT_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 21
UNUM_FIVE_DIGIT_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 22
UNUM_SIX_DIGIT_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 23
UNUM_SEVEN_DIGIT_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 24
UNUM_EIGHT_DIGIT_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 25
UNUM_NINE_DIGIT_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 26
UNUM_EXPONENT_MULTIPLICATION_SYMBOL: win32more.Windows.Win32.Globalization.UNumberFormatSymbol = 27
UNumberFormatTextAttribute = Int32
UNUM_POSITIVE_PREFIX: win32more.Windows.Win32.Globalization.UNumberFormatTextAttribute = 0
UNUM_POSITIVE_SUFFIX: win32more.Windows.Win32.Globalization.UNumberFormatTextAttribute = 1
UNUM_NEGATIVE_PREFIX: win32more.Windows.Win32.Globalization.UNumberFormatTextAttribute = 2
UNUM_NEGATIVE_SUFFIX: win32more.Windows.Win32.Globalization.UNumberFormatTextAttribute = 3
UNUM_PADDING_CHARACTER: win32more.Windows.Win32.Globalization.UNumberFormatTextAttribute = 4
UNUM_CURRENCY_CODE: win32more.Windows.Win32.Globalization.UNumberFormatTextAttribute = 5
UNUM_DEFAULT_RULESET: win32more.Windows.Win32.Globalization.UNumberFormatTextAttribute = 6
UNUM_PUBLIC_RULESETS: win32more.Windows.Win32.Globalization.UNumberFormatTextAttribute = 7
UNumberFormatter = IntPtr
UNumberGroupingStrategy = Int32
UNUM_GROUPING_OFF: win32more.Windows.Win32.Globalization.UNumberGroupingStrategy = 0
UNUM_GROUPING_MIN2: win32more.Windows.Win32.Globalization.UNumberGroupingStrategy = 1
UNUM_GROUPING_AUTO: win32more.Windows.Win32.Globalization.UNumberGroupingStrategy = 2
UNUM_GROUPING_ON_ALIGNED: win32more.Windows.Win32.Globalization.UNumberGroupingStrategy = 3
UNUM_GROUPING_THOUSANDS: win32more.Windows.Win32.Globalization.UNumberGroupingStrategy = 4
UNumberRangeCollapse = Int32
UNUM_RANGE_COLLAPSE_AUTO: win32more.Windows.Win32.Globalization.UNumberRangeCollapse = 0
UNUM_RANGE_COLLAPSE_NONE: win32more.Windows.Win32.Globalization.UNumberRangeCollapse = 1
UNUM_RANGE_COLLAPSE_UNIT: win32more.Windows.Win32.Globalization.UNumberRangeCollapse = 2
UNUM_RANGE_COLLAPSE_ALL: win32more.Windows.Win32.Globalization.UNumberRangeCollapse = 3
UNumberRangeIdentityFallback = Int32
UNUM_IDENTITY_FALLBACK_SINGLE_VALUE: win32more.Windows.Win32.Globalization.UNumberRangeIdentityFallback = 0
UNUM_IDENTITY_FALLBACK_APPROXIMATELY_OR_SINGLE_VALUE: win32more.Windows.Win32.Globalization.UNumberRangeIdentityFallback = 1
UNUM_IDENTITY_FALLBACK_APPROXIMATELY: win32more.Windows.Win32.Globalization.UNumberRangeIdentityFallback = 2
UNUM_IDENTITY_FALLBACK_RANGE: win32more.Windows.Win32.Globalization.UNumberRangeIdentityFallback = 3
UNumberRangeIdentityResult = Int32
UNUM_IDENTITY_RESULT_EQUAL_BEFORE_ROUNDING: win32more.Windows.Win32.Globalization.UNumberRangeIdentityResult = 0
UNUM_IDENTITY_RESULT_EQUAL_AFTER_ROUNDING: win32more.Windows.Win32.Globalization.UNumberRangeIdentityResult = 1
UNUM_IDENTITY_RESULT_NOT_EQUAL: win32more.Windows.Win32.Globalization.UNumberRangeIdentityResult = 2
UNumberSignDisplay = Int32
UNUM_SIGN_AUTO: win32more.Windows.Win32.Globalization.UNumberSignDisplay = 0
UNUM_SIGN_ALWAYS: win32more.Windows.Win32.Globalization.UNumberSignDisplay = 1
UNUM_SIGN_NEVER: win32more.Windows.Win32.Globalization.UNumberSignDisplay = 2
UNUM_SIGN_ACCOUNTING: win32more.Windows.Win32.Globalization.UNumberSignDisplay = 3
UNUM_SIGN_ACCOUNTING_ALWAYS: win32more.Windows.Win32.Globalization.UNumberSignDisplay = 4
UNUM_SIGN_EXCEPT_ZERO: win32more.Windows.Win32.Globalization.UNumberSignDisplay = 5
UNUM_SIGN_ACCOUNTING_EXCEPT_ZERO: win32more.Windows.Win32.Globalization.UNumberSignDisplay = 6
UNUM_SIGN_COUNT: win32more.Windows.Win32.Globalization.UNumberSignDisplay = 7
UNumberUnitWidth = Int32
UNUM_UNIT_WIDTH_NARROW: win32more.Windows.Win32.Globalization.UNumberUnitWidth = 0
UNUM_UNIT_WIDTH_SHORT: win32more.Windows.Win32.Globalization.UNumberUnitWidth = 1
UNUM_UNIT_WIDTH_FULL_NAME: win32more.Windows.Win32.Globalization.UNumberUnitWidth = 2
UNUM_UNIT_WIDTH_ISO_CODE: win32more.Windows.Win32.Globalization.UNumberUnitWidth = 3
UNUM_UNIT_WIDTH_HIDDEN: win32more.Windows.Win32.Globalization.UNumberUnitWidth = 4
UNUM_UNIT_WIDTH_COUNT: win32more.Windows.Win32.Globalization.UNumberUnitWidth = 5
UNumberingSystem = IntPtr
UNumericType = Int32
U_NT_NONE: win32more.Windows.Win32.Globalization.UNumericType = 0
U_NT_DECIMAL: win32more.Windows.Win32.Globalization.UNumericType = 1
U_NT_DIGIT: win32more.Windows.Win32.Globalization.UNumericType = 2
U_NT_NUMERIC: win32more.Windows.Win32.Globalization.UNumericType = 3
class UParseError(Structure):
    line: Int32
    offset: Int32
    preContext: UInt16 * 16
    postContext: UInt16 * 16
UPluralRules = IntPtr
UPluralType = Int32
UPLURAL_TYPE_CARDINAL: win32more.Windows.Win32.Globalization.UPluralType = 0
UPLURAL_TYPE_ORDINAL: win32more.Windows.Win32.Globalization.UPluralType = 1
UProperty = Int32
UCHAR_ALPHABETIC: win32more.Windows.Win32.Globalization.UProperty = 0
UCHAR_BINARY_START: win32more.Windows.Win32.Globalization.UProperty = 0
UCHAR_ASCII_HEX_DIGIT: win32more.Windows.Win32.Globalization.UProperty = 1
UCHAR_BIDI_CONTROL: win32more.Windows.Win32.Globalization.UProperty = 2
UCHAR_BIDI_MIRRORED: win32more.Windows.Win32.Globalization.UProperty = 3
UCHAR_DASH: win32more.Windows.Win32.Globalization.UProperty = 4
UCHAR_DEFAULT_IGNORABLE_CODE_POINT: win32more.Windows.Win32.Globalization.UProperty = 5
UCHAR_DEPRECATED: win32more.Windows.Win32.Globalization.UProperty = 6
UCHAR_DIACRITIC: win32more.Windows.Win32.Globalization.UProperty = 7
UCHAR_EXTENDER: win32more.Windows.Win32.Globalization.UProperty = 8
UCHAR_FULL_COMPOSITION_EXCLUSION: win32more.Windows.Win32.Globalization.UProperty = 9
UCHAR_GRAPHEME_BASE: win32more.Windows.Win32.Globalization.UProperty = 10
UCHAR_GRAPHEME_EXTEND: win32more.Windows.Win32.Globalization.UProperty = 11
UCHAR_GRAPHEME_LINK: win32more.Windows.Win32.Globalization.UProperty = 12
UCHAR_HEX_DIGIT: win32more.Windows.Win32.Globalization.UProperty = 13
UCHAR_HYPHEN: win32more.Windows.Win32.Globalization.UProperty = 14
UCHAR_ID_CONTINUE: win32more.Windows.Win32.Globalization.UProperty = 15
UCHAR_ID_START: win32more.Windows.Win32.Globalization.UProperty = 16
UCHAR_IDEOGRAPHIC: win32more.Windows.Win32.Globalization.UProperty = 17
UCHAR_IDS_BINARY_OPERATOR: win32more.Windows.Win32.Globalization.UProperty = 18
UCHAR_IDS_TRINARY_OPERATOR: win32more.Windows.Win32.Globalization.UProperty = 19
UCHAR_JOIN_CONTROL: win32more.Windows.Win32.Globalization.UProperty = 20
UCHAR_LOGICAL_ORDER_EXCEPTION: win32more.Windows.Win32.Globalization.UProperty = 21
UCHAR_LOWERCASE: win32more.Windows.Win32.Globalization.UProperty = 22
UCHAR_MATH: win32more.Windows.Win32.Globalization.UProperty = 23
UCHAR_NONCHARACTER_CODE_POINT: win32more.Windows.Win32.Globalization.UProperty = 24
UCHAR_QUOTATION_MARK: win32more.Windows.Win32.Globalization.UProperty = 25
UCHAR_RADICAL: win32more.Windows.Win32.Globalization.UProperty = 26
UCHAR_SOFT_DOTTED: win32more.Windows.Win32.Globalization.UProperty = 27
UCHAR_TERMINAL_PUNCTUATION: win32more.Windows.Win32.Globalization.UProperty = 28
UCHAR_UNIFIED_IDEOGRAPH: win32more.Windows.Win32.Globalization.UProperty = 29
UCHAR_UPPERCASE: win32more.Windows.Win32.Globalization.UProperty = 30
UCHAR_WHITE_SPACE: win32more.Windows.Win32.Globalization.UProperty = 31
UCHAR_XID_CONTINUE: win32more.Windows.Win32.Globalization.UProperty = 32
UCHAR_XID_START: win32more.Windows.Win32.Globalization.UProperty = 33
UCHAR_CASE_SENSITIVE: win32more.Windows.Win32.Globalization.UProperty = 34
UCHAR_S_TERM: win32more.Windows.Win32.Globalization.UProperty = 35
UCHAR_VARIATION_SELECTOR: win32more.Windows.Win32.Globalization.UProperty = 36
UCHAR_NFD_INERT: win32more.Windows.Win32.Globalization.UProperty = 37
UCHAR_NFKD_INERT: win32more.Windows.Win32.Globalization.UProperty = 38
UCHAR_NFC_INERT: win32more.Windows.Win32.Globalization.UProperty = 39
UCHAR_NFKC_INERT: win32more.Windows.Win32.Globalization.UProperty = 40
UCHAR_SEGMENT_STARTER: win32more.Windows.Win32.Globalization.UProperty = 41
UCHAR_PATTERN_SYNTAX: win32more.Windows.Win32.Globalization.UProperty = 42
UCHAR_PATTERN_WHITE_SPACE: win32more.Windows.Win32.Globalization.UProperty = 43
UCHAR_POSIX_ALNUM: win32more.Windows.Win32.Globalization.UProperty = 44
UCHAR_POSIX_BLANK: win32more.Windows.Win32.Globalization.UProperty = 45
UCHAR_POSIX_GRAPH: win32more.Windows.Win32.Globalization.UProperty = 46
UCHAR_POSIX_PRINT: win32more.Windows.Win32.Globalization.UProperty = 47
UCHAR_POSIX_XDIGIT: win32more.Windows.Win32.Globalization.UProperty = 48
UCHAR_CASED: win32more.Windows.Win32.Globalization.UProperty = 49
UCHAR_CASE_IGNORABLE: win32more.Windows.Win32.Globalization.UProperty = 50
UCHAR_CHANGES_WHEN_LOWERCASED: win32more.Windows.Win32.Globalization.UProperty = 51
UCHAR_CHANGES_WHEN_UPPERCASED: win32more.Windows.Win32.Globalization.UProperty = 52
UCHAR_CHANGES_WHEN_TITLECASED: win32more.Windows.Win32.Globalization.UProperty = 53
UCHAR_CHANGES_WHEN_CASEFOLDED: win32more.Windows.Win32.Globalization.UProperty = 54
UCHAR_CHANGES_WHEN_CASEMAPPED: win32more.Windows.Win32.Globalization.UProperty = 55
UCHAR_CHANGES_WHEN_NFKC_CASEFOLDED: win32more.Windows.Win32.Globalization.UProperty = 56
UCHAR_EMOJI: win32more.Windows.Win32.Globalization.UProperty = 57
UCHAR_EMOJI_PRESENTATION: win32more.Windows.Win32.Globalization.UProperty = 58
UCHAR_EMOJI_MODIFIER: win32more.Windows.Win32.Globalization.UProperty = 59
UCHAR_EMOJI_MODIFIER_BASE: win32more.Windows.Win32.Globalization.UProperty = 60
UCHAR_EMOJI_COMPONENT: win32more.Windows.Win32.Globalization.UProperty = 61
UCHAR_REGIONAL_INDICATOR: win32more.Windows.Win32.Globalization.UProperty = 62
UCHAR_PREPENDED_CONCATENATION_MARK: win32more.Windows.Win32.Globalization.UProperty = 63
UCHAR_EXTENDED_PICTOGRAPHIC: win32more.Windows.Win32.Globalization.UProperty = 64
UCHAR_BIDI_CLASS: win32more.Windows.Win32.Globalization.UProperty = 4096
UCHAR_INT_START: win32more.Windows.Win32.Globalization.UProperty = 4096
UCHAR_BLOCK: win32more.Windows.Win32.Globalization.UProperty = 4097
UCHAR_CANONICAL_COMBINING_CLASS: win32more.Windows.Win32.Globalization.UProperty = 4098
UCHAR_DECOMPOSITION_TYPE: win32more.Windows.Win32.Globalization.UProperty = 4099
UCHAR_EAST_ASIAN_WIDTH: win32more.Windows.Win32.Globalization.UProperty = 4100
UCHAR_GENERAL_CATEGORY: win32more.Windows.Win32.Globalization.UProperty = 4101
UCHAR_JOINING_GROUP: win32more.Windows.Win32.Globalization.UProperty = 4102
UCHAR_JOINING_TYPE: win32more.Windows.Win32.Globalization.UProperty = 4103
UCHAR_LINE_BREAK: win32more.Windows.Win32.Globalization.UProperty = 4104
UCHAR_NUMERIC_TYPE: win32more.Windows.Win32.Globalization.UProperty = 4105
UCHAR_SCRIPT: win32more.Windows.Win32.Globalization.UProperty = 4106
UCHAR_HANGUL_SYLLABLE_TYPE: win32more.Windows.Win32.Globalization.UProperty = 4107
UCHAR_NFD_QUICK_CHECK: win32more.Windows.Win32.Globalization.UProperty = 4108
UCHAR_NFKD_QUICK_CHECK: win32more.Windows.Win32.Globalization.UProperty = 4109
UCHAR_NFC_QUICK_CHECK: win32more.Windows.Win32.Globalization.UProperty = 4110
UCHAR_NFKC_QUICK_CHECK: win32more.Windows.Win32.Globalization.UProperty = 4111
UCHAR_LEAD_CANONICAL_COMBINING_CLASS: win32more.Windows.Win32.Globalization.UProperty = 4112
UCHAR_TRAIL_CANONICAL_COMBINING_CLASS: win32more.Windows.Win32.Globalization.UProperty = 4113
UCHAR_GRAPHEME_CLUSTER_BREAK: win32more.Windows.Win32.Globalization.UProperty = 4114
UCHAR_SENTENCE_BREAK: win32more.Windows.Win32.Globalization.UProperty = 4115
UCHAR_WORD_BREAK: win32more.Windows.Win32.Globalization.UProperty = 4116
UCHAR_BIDI_PAIRED_BRACKET_TYPE: win32more.Windows.Win32.Globalization.UProperty = 4117
UCHAR_INDIC_POSITIONAL_CATEGORY: win32more.Windows.Win32.Globalization.UProperty = 4118
UCHAR_INDIC_SYLLABIC_CATEGORY: win32more.Windows.Win32.Globalization.UProperty = 4119
UCHAR_VERTICAL_ORIENTATION: win32more.Windows.Win32.Globalization.UProperty = 4120
UCHAR_GENERAL_CATEGORY_MASK: win32more.Windows.Win32.Globalization.UProperty = 8192
UCHAR_MASK_START: win32more.Windows.Win32.Globalization.UProperty = 8192
UCHAR_NUMERIC_VALUE: win32more.Windows.Win32.Globalization.UProperty = 12288
UCHAR_DOUBLE_START: win32more.Windows.Win32.Globalization.UProperty = 12288
UCHAR_AGE: win32more.Windows.Win32.Globalization.UProperty = 16384
UCHAR_STRING_START: win32more.Windows.Win32.Globalization.UProperty = 16384
UCHAR_BIDI_MIRRORING_GLYPH: win32more.Windows.Win32.Globalization.UProperty = 16385
UCHAR_CASE_FOLDING: win32more.Windows.Win32.Globalization.UProperty = 16386
UCHAR_LOWERCASE_MAPPING: win32more.Windows.Win32.Globalization.UProperty = 16388
UCHAR_NAME: win32more.Windows.Win32.Globalization.UProperty = 16389
UCHAR_SIMPLE_CASE_FOLDING: win32more.Windows.Win32.Globalization.UProperty = 16390
UCHAR_SIMPLE_LOWERCASE_MAPPING: win32more.Windows.Win32.Globalization.UProperty = 16391
UCHAR_SIMPLE_TITLECASE_MAPPING: win32more.Windows.Win32.Globalization.UProperty = 16392
UCHAR_SIMPLE_UPPERCASE_MAPPING: win32more.Windows.Win32.Globalization.UProperty = 16393
UCHAR_TITLECASE_MAPPING: win32more.Windows.Win32.Globalization.UProperty = 16394
UCHAR_UPPERCASE_MAPPING: win32more.Windows.Win32.Globalization.UProperty = 16396
UCHAR_BIDI_PAIRED_BRACKET: win32more.Windows.Win32.Globalization.UProperty = 16397
UCHAR_SCRIPT_EXTENSIONS: win32more.Windows.Win32.Globalization.UProperty = 28672
UCHAR_OTHER_PROPERTY_START: win32more.Windows.Win32.Globalization.UProperty = 28672
UCHAR_INVALID_CODE: win32more.Windows.Win32.Globalization.UProperty = -1
UPropertyNameChoice = Int32
U_SHORT_PROPERTY_NAME: win32more.Windows.Win32.Globalization.UPropertyNameChoice = 0
U_LONG_PROPERTY_NAME: win32more.Windows.Win32.Globalization.UPropertyNameChoice = 1
@cfunctype_pointer
def URegexFindProgressCallback(context: VoidPtr, matchIndex: Int64) -> SByte: ...
@cfunctype_pointer
def URegexMatchCallback(context: VoidPtr, steps: Int32) -> SByte: ...
URegexpFlag = Int32
UREGEX_CASE_INSENSITIVE: win32more.Windows.Win32.Globalization.URegexpFlag = 2
UREGEX_COMMENTS: win32more.Windows.Win32.Globalization.URegexpFlag = 4
UREGEX_DOTALL: win32more.Windows.Win32.Globalization.URegexpFlag = 32
UREGEX_LITERAL: win32more.Windows.Win32.Globalization.URegexpFlag = 16
UREGEX_MULTILINE: win32more.Windows.Win32.Globalization.URegexpFlag = 8
UREGEX_UNIX_LINES: win32more.Windows.Win32.Globalization.URegexpFlag = 1
UREGEX_UWORD: win32more.Windows.Win32.Globalization.URegexpFlag = 256
UREGEX_ERROR_ON_UNKNOWN_ESCAPES: win32more.Windows.Win32.Globalization.URegexpFlag = 512
URegion = IntPtr
URegionType = Int32
URGN_UNKNOWN: win32more.Windows.Win32.Globalization.URegionType = 0
URGN_TERRITORY: win32more.Windows.Win32.Globalization.URegionType = 1
URGN_WORLD: win32more.Windows.Win32.Globalization.URegionType = 2
URGN_CONTINENT: win32more.Windows.Win32.Globalization.URegionType = 3
URGN_SUBCONTINENT: win32more.Windows.Win32.Globalization.URegionType = 4
URGN_GROUPING: win32more.Windows.Win32.Globalization.URegionType = 5
URGN_DEPRECATED: win32more.Windows.Win32.Globalization.URegionType = 6
URegularExpression = IntPtr
URelativeDateTimeFormatter = IntPtr
URelativeDateTimeFormatterField = Int32
UDAT_REL_LITERAL_FIELD: win32more.Windows.Win32.Globalization.URelativeDateTimeFormatterField = 0
UDAT_REL_NUMERIC_FIELD: win32more.Windows.Win32.Globalization.URelativeDateTimeFormatterField = 1
URelativeDateTimeUnit = Int32
UDAT_REL_UNIT_YEAR: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit = 0
UDAT_REL_UNIT_QUARTER: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit = 1
UDAT_REL_UNIT_MONTH: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit = 2
UDAT_REL_UNIT_WEEK: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit = 3
UDAT_REL_UNIT_DAY: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit = 4
UDAT_REL_UNIT_HOUR: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit = 5
UDAT_REL_UNIT_MINUTE: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit = 6
UDAT_REL_UNIT_SECOND: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit = 7
UDAT_REL_UNIT_SUNDAY: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit = 8
UDAT_REL_UNIT_MONDAY: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit = 9
UDAT_REL_UNIT_TUESDAY: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit = 10
UDAT_REL_UNIT_WEDNESDAY: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit = 11
UDAT_REL_UNIT_THURSDAY: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit = 12
UDAT_REL_UNIT_FRIDAY: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit = 13
UDAT_REL_UNIT_SATURDAY: win32more.Windows.Win32.Globalization.URelativeDateTimeUnit = 14
class UReplaceableCallbacks(Structure):
    length: IntPtr
    charAt: IntPtr
    char32At: IntPtr
    replace: IntPtr
    extract: IntPtr
    copy: IntPtr
UResType = Int32
URES_NONE: win32more.Windows.Win32.Globalization.UResType = -1
URES_STRING: win32more.Windows.Win32.Globalization.UResType = 0
URES_BINARY: win32more.Windows.Win32.Globalization.UResType = 1
URES_TABLE: win32more.Windows.Win32.Globalization.UResType = 2
URES_ALIAS: win32more.Windows.Win32.Globalization.UResType = 3
URES_INT: win32more.Windows.Win32.Globalization.UResType = 7
URES_ARRAY: win32more.Windows.Win32.Globalization.UResType = 8
URES_INT_VECTOR: win32more.Windows.Win32.Globalization.UResType = 14
UResourceBundle = IntPtr
URestrictionLevel = Int32
USPOOF_ASCII: win32more.Windows.Win32.Globalization.URestrictionLevel = 268435456
USPOOF_SINGLE_SCRIPT_RESTRICTIVE: win32more.Windows.Win32.Globalization.URestrictionLevel = 536870912
USPOOF_HIGHLY_RESTRICTIVE: win32more.Windows.Win32.Globalization.URestrictionLevel = 805306368
USPOOF_MODERATELY_RESTRICTIVE: win32more.Windows.Win32.Globalization.URestrictionLevel = 1073741824
USPOOF_MINIMALLY_RESTRICTIVE: win32more.Windows.Win32.Globalization.URestrictionLevel = 1342177280
USPOOF_UNRESTRICTIVE: win32more.Windows.Win32.Globalization.URestrictionLevel = 1610612736
USPOOF_RESTRICTION_LEVEL_MASK: win32more.Windows.Win32.Globalization.URestrictionLevel = 2130706432
UScriptCode = Int32
USCRIPT_INVALID_CODE: win32more.Windows.Win32.Globalization.UScriptCode = -1
USCRIPT_COMMON: win32more.Windows.Win32.Globalization.UScriptCode = 0
USCRIPT_INHERITED: win32more.Windows.Win32.Globalization.UScriptCode = 1
USCRIPT_ARABIC: win32more.Windows.Win32.Globalization.UScriptCode = 2
USCRIPT_ARMENIAN: win32more.Windows.Win32.Globalization.UScriptCode = 3
USCRIPT_BENGALI: win32more.Windows.Win32.Globalization.UScriptCode = 4
USCRIPT_BOPOMOFO: win32more.Windows.Win32.Globalization.UScriptCode = 5
USCRIPT_CHEROKEE: win32more.Windows.Win32.Globalization.UScriptCode = 6
USCRIPT_COPTIC: win32more.Windows.Win32.Globalization.UScriptCode = 7
USCRIPT_CYRILLIC: win32more.Windows.Win32.Globalization.UScriptCode = 8
USCRIPT_DESERET: win32more.Windows.Win32.Globalization.UScriptCode = 9
USCRIPT_DEVANAGARI: win32more.Windows.Win32.Globalization.UScriptCode = 10
USCRIPT_ETHIOPIC: win32more.Windows.Win32.Globalization.UScriptCode = 11
USCRIPT_GEORGIAN: win32more.Windows.Win32.Globalization.UScriptCode = 12
USCRIPT_GOTHIC: win32more.Windows.Win32.Globalization.UScriptCode = 13
USCRIPT_GREEK: win32more.Windows.Win32.Globalization.UScriptCode = 14
USCRIPT_GUJARATI: win32more.Windows.Win32.Globalization.UScriptCode = 15
USCRIPT_GURMUKHI: win32more.Windows.Win32.Globalization.UScriptCode = 16
USCRIPT_HAN: win32more.Windows.Win32.Globalization.UScriptCode = 17
USCRIPT_HANGUL: win32more.Windows.Win32.Globalization.UScriptCode = 18
USCRIPT_HEBREW: win32more.Windows.Win32.Globalization.UScriptCode = 19
USCRIPT_HIRAGANA: win32more.Windows.Win32.Globalization.UScriptCode = 20
USCRIPT_KANNADA: win32more.Windows.Win32.Globalization.UScriptCode = 21
USCRIPT_KATAKANA: win32more.Windows.Win32.Globalization.UScriptCode = 22
USCRIPT_KHMER: win32more.Windows.Win32.Globalization.UScriptCode = 23
USCRIPT_LAO: win32more.Windows.Win32.Globalization.UScriptCode = 24
USCRIPT_LATIN: win32more.Windows.Win32.Globalization.UScriptCode = 25
USCRIPT_MALAYALAM: win32more.Windows.Win32.Globalization.UScriptCode = 26
USCRIPT_MONGOLIAN: win32more.Windows.Win32.Globalization.UScriptCode = 27
USCRIPT_MYANMAR: win32more.Windows.Win32.Globalization.UScriptCode = 28
USCRIPT_OGHAM: win32more.Windows.Win32.Globalization.UScriptCode = 29
USCRIPT_OLD_ITALIC: win32more.Windows.Win32.Globalization.UScriptCode = 30
USCRIPT_ORIYA: win32more.Windows.Win32.Globalization.UScriptCode = 31
USCRIPT_RUNIC: win32more.Windows.Win32.Globalization.UScriptCode = 32
USCRIPT_SINHALA: win32more.Windows.Win32.Globalization.UScriptCode = 33
USCRIPT_SYRIAC: win32more.Windows.Win32.Globalization.UScriptCode = 34
USCRIPT_TAMIL: win32more.Windows.Win32.Globalization.UScriptCode = 35
USCRIPT_TELUGU: win32more.Windows.Win32.Globalization.UScriptCode = 36
USCRIPT_THAANA: win32more.Windows.Win32.Globalization.UScriptCode = 37
USCRIPT_THAI: win32more.Windows.Win32.Globalization.UScriptCode = 38
USCRIPT_TIBETAN: win32more.Windows.Win32.Globalization.UScriptCode = 39
USCRIPT_CANADIAN_ABORIGINAL: win32more.Windows.Win32.Globalization.UScriptCode = 40
USCRIPT_UCAS: win32more.Windows.Win32.Globalization.UScriptCode = 40
USCRIPT_YI: win32more.Windows.Win32.Globalization.UScriptCode = 41
USCRIPT_TAGALOG: win32more.Windows.Win32.Globalization.UScriptCode = 42
USCRIPT_HANUNOO: win32more.Windows.Win32.Globalization.UScriptCode = 43
USCRIPT_BUHID: win32more.Windows.Win32.Globalization.UScriptCode = 44
USCRIPT_TAGBANWA: win32more.Windows.Win32.Globalization.UScriptCode = 45
USCRIPT_BRAILLE: win32more.Windows.Win32.Globalization.UScriptCode = 46
USCRIPT_CYPRIOT: win32more.Windows.Win32.Globalization.UScriptCode = 47
USCRIPT_LIMBU: win32more.Windows.Win32.Globalization.UScriptCode = 48
USCRIPT_LINEAR_B: win32more.Windows.Win32.Globalization.UScriptCode = 49
USCRIPT_OSMANYA: win32more.Windows.Win32.Globalization.UScriptCode = 50
USCRIPT_SHAVIAN: win32more.Windows.Win32.Globalization.UScriptCode = 51
USCRIPT_TAI_LE: win32more.Windows.Win32.Globalization.UScriptCode = 52
USCRIPT_UGARITIC: win32more.Windows.Win32.Globalization.UScriptCode = 53
USCRIPT_KATAKANA_OR_HIRAGANA: win32more.Windows.Win32.Globalization.UScriptCode = 54
USCRIPT_BUGINESE: win32more.Windows.Win32.Globalization.UScriptCode = 55
USCRIPT_GLAGOLITIC: win32more.Windows.Win32.Globalization.UScriptCode = 56
USCRIPT_KHAROSHTHI: win32more.Windows.Win32.Globalization.UScriptCode = 57
USCRIPT_SYLOTI_NAGRI: win32more.Windows.Win32.Globalization.UScriptCode = 58
USCRIPT_NEW_TAI_LUE: win32more.Windows.Win32.Globalization.UScriptCode = 59
USCRIPT_TIFINAGH: win32more.Windows.Win32.Globalization.UScriptCode = 60
USCRIPT_OLD_PERSIAN: win32more.Windows.Win32.Globalization.UScriptCode = 61
USCRIPT_BALINESE: win32more.Windows.Win32.Globalization.UScriptCode = 62
USCRIPT_BATAK: win32more.Windows.Win32.Globalization.UScriptCode = 63
USCRIPT_BLISSYMBOLS: win32more.Windows.Win32.Globalization.UScriptCode = 64
USCRIPT_BRAHMI: win32more.Windows.Win32.Globalization.UScriptCode = 65
USCRIPT_CHAM: win32more.Windows.Win32.Globalization.UScriptCode = 66
USCRIPT_CIRTH: win32more.Windows.Win32.Globalization.UScriptCode = 67
USCRIPT_OLD_CHURCH_SLAVONIC_CYRILLIC: win32more.Windows.Win32.Globalization.UScriptCode = 68
USCRIPT_DEMOTIC_EGYPTIAN: win32more.Windows.Win32.Globalization.UScriptCode = 69
USCRIPT_HIERATIC_EGYPTIAN: win32more.Windows.Win32.Globalization.UScriptCode = 70
USCRIPT_EGYPTIAN_HIEROGLYPHS: win32more.Windows.Win32.Globalization.UScriptCode = 71
USCRIPT_KHUTSURI: win32more.Windows.Win32.Globalization.UScriptCode = 72
USCRIPT_SIMPLIFIED_HAN: win32more.Windows.Win32.Globalization.UScriptCode = 73
USCRIPT_TRADITIONAL_HAN: win32more.Windows.Win32.Globalization.UScriptCode = 74
USCRIPT_PAHAWH_HMONG: win32more.Windows.Win32.Globalization.UScriptCode = 75
USCRIPT_OLD_HUNGARIAN: win32more.Windows.Win32.Globalization.UScriptCode = 76
USCRIPT_HARAPPAN_INDUS: win32more.Windows.Win32.Globalization.UScriptCode = 77
USCRIPT_JAVANESE: win32more.Windows.Win32.Globalization.UScriptCode = 78
USCRIPT_KAYAH_LI: win32more.Windows.Win32.Globalization.UScriptCode = 79
USCRIPT_LATIN_FRAKTUR: win32more.Windows.Win32.Globalization.UScriptCode = 80
USCRIPT_LATIN_GAELIC: win32more.Windows.Win32.Globalization.UScriptCode = 81
USCRIPT_LEPCHA: win32more.Windows.Win32.Globalization.UScriptCode = 82
USCRIPT_LINEAR_A: win32more.Windows.Win32.Globalization.UScriptCode = 83
USCRIPT_MANDAIC: win32more.Windows.Win32.Globalization.UScriptCode = 84
USCRIPT_MANDAEAN: win32more.Windows.Win32.Globalization.UScriptCode = 84
USCRIPT_MAYAN_HIEROGLYPHS: win32more.Windows.Win32.Globalization.UScriptCode = 85
USCRIPT_MEROITIC_HIEROGLYPHS: win32more.Windows.Win32.Globalization.UScriptCode = 86
USCRIPT_MEROITIC: win32more.Windows.Win32.Globalization.UScriptCode = 86
USCRIPT_NKO: win32more.Windows.Win32.Globalization.UScriptCode = 87
USCRIPT_ORKHON: win32more.Windows.Win32.Globalization.UScriptCode = 88
USCRIPT_OLD_PERMIC: win32more.Windows.Win32.Globalization.UScriptCode = 89
USCRIPT_PHAGS_PA: win32more.Windows.Win32.Globalization.UScriptCode = 90
USCRIPT_PHOENICIAN: win32more.Windows.Win32.Globalization.UScriptCode = 91
USCRIPT_MIAO: win32more.Windows.Win32.Globalization.UScriptCode = 92
USCRIPT_PHONETIC_POLLARD: win32more.Windows.Win32.Globalization.UScriptCode = 92
USCRIPT_RONGORONGO: win32more.Windows.Win32.Globalization.UScriptCode = 93
USCRIPT_SARATI: win32more.Windows.Win32.Globalization.UScriptCode = 94
USCRIPT_ESTRANGELO_SYRIAC: win32more.Windows.Win32.Globalization.UScriptCode = 95
USCRIPT_WESTERN_SYRIAC: win32more.Windows.Win32.Globalization.UScriptCode = 96
USCRIPT_EASTERN_SYRIAC: win32more.Windows.Win32.Globalization.UScriptCode = 97
USCRIPT_TENGWAR: win32more.Windows.Win32.Globalization.UScriptCode = 98
USCRIPT_VAI: win32more.Windows.Win32.Globalization.UScriptCode = 99
USCRIPT_VISIBLE_SPEECH: win32more.Windows.Win32.Globalization.UScriptCode = 100
USCRIPT_CUNEIFORM: win32more.Windows.Win32.Globalization.UScriptCode = 101
USCRIPT_UNWRITTEN_LANGUAGES: win32more.Windows.Win32.Globalization.UScriptCode = 102
USCRIPT_UNKNOWN: win32more.Windows.Win32.Globalization.UScriptCode = 103
USCRIPT_CARIAN: win32more.Windows.Win32.Globalization.UScriptCode = 104
USCRIPT_JAPANESE: win32more.Windows.Win32.Globalization.UScriptCode = 105
USCRIPT_LANNA: win32more.Windows.Win32.Globalization.UScriptCode = 106
USCRIPT_LYCIAN: win32more.Windows.Win32.Globalization.UScriptCode = 107
USCRIPT_LYDIAN: win32more.Windows.Win32.Globalization.UScriptCode = 108
USCRIPT_OL_CHIKI: win32more.Windows.Win32.Globalization.UScriptCode = 109
USCRIPT_REJANG: win32more.Windows.Win32.Globalization.UScriptCode = 110
USCRIPT_SAURASHTRA: win32more.Windows.Win32.Globalization.UScriptCode = 111
USCRIPT_SIGN_WRITING: win32more.Windows.Win32.Globalization.UScriptCode = 112
USCRIPT_SUNDANESE: win32more.Windows.Win32.Globalization.UScriptCode = 113
USCRIPT_MOON: win32more.Windows.Win32.Globalization.UScriptCode = 114
USCRIPT_MEITEI_MAYEK: win32more.Windows.Win32.Globalization.UScriptCode = 115
USCRIPT_IMPERIAL_ARAMAIC: win32more.Windows.Win32.Globalization.UScriptCode = 116
USCRIPT_AVESTAN: win32more.Windows.Win32.Globalization.UScriptCode = 117
USCRIPT_CHAKMA: win32more.Windows.Win32.Globalization.UScriptCode = 118
USCRIPT_KOREAN: win32more.Windows.Win32.Globalization.UScriptCode = 119
USCRIPT_KAITHI: win32more.Windows.Win32.Globalization.UScriptCode = 120
USCRIPT_MANICHAEAN: win32more.Windows.Win32.Globalization.UScriptCode = 121
USCRIPT_INSCRIPTIONAL_PAHLAVI: win32more.Windows.Win32.Globalization.UScriptCode = 122
USCRIPT_PSALTER_PAHLAVI: win32more.Windows.Win32.Globalization.UScriptCode = 123
USCRIPT_BOOK_PAHLAVI: win32more.Windows.Win32.Globalization.UScriptCode = 124
USCRIPT_INSCRIPTIONAL_PARTHIAN: win32more.Windows.Win32.Globalization.UScriptCode = 125
USCRIPT_SAMARITAN: win32more.Windows.Win32.Globalization.UScriptCode = 126
USCRIPT_TAI_VIET: win32more.Windows.Win32.Globalization.UScriptCode = 127
USCRIPT_MATHEMATICAL_NOTATION: win32more.Windows.Win32.Globalization.UScriptCode = 128
USCRIPT_SYMBOLS: win32more.Windows.Win32.Globalization.UScriptCode = 129
USCRIPT_BAMUM: win32more.Windows.Win32.Globalization.UScriptCode = 130
USCRIPT_LISU: win32more.Windows.Win32.Globalization.UScriptCode = 131
USCRIPT_NAKHI_GEBA: win32more.Windows.Win32.Globalization.UScriptCode = 132
USCRIPT_OLD_SOUTH_ARABIAN: win32more.Windows.Win32.Globalization.UScriptCode = 133
USCRIPT_BASSA_VAH: win32more.Windows.Win32.Globalization.UScriptCode = 134
USCRIPT_DUPLOYAN: win32more.Windows.Win32.Globalization.UScriptCode = 135
USCRIPT_ELBASAN: win32more.Windows.Win32.Globalization.UScriptCode = 136
USCRIPT_GRANTHA: win32more.Windows.Win32.Globalization.UScriptCode = 137
USCRIPT_KPELLE: win32more.Windows.Win32.Globalization.UScriptCode = 138
USCRIPT_LOMA: win32more.Windows.Win32.Globalization.UScriptCode = 139
USCRIPT_MENDE: win32more.Windows.Win32.Globalization.UScriptCode = 140
USCRIPT_MEROITIC_CURSIVE: win32more.Windows.Win32.Globalization.UScriptCode = 141
USCRIPT_OLD_NORTH_ARABIAN: win32more.Windows.Win32.Globalization.UScriptCode = 142
USCRIPT_NABATAEAN: win32more.Windows.Win32.Globalization.UScriptCode = 143
USCRIPT_PALMYRENE: win32more.Windows.Win32.Globalization.UScriptCode = 144
USCRIPT_KHUDAWADI: win32more.Windows.Win32.Globalization.UScriptCode = 145
USCRIPT_SINDHI: win32more.Windows.Win32.Globalization.UScriptCode = 145
USCRIPT_WARANG_CITI: win32more.Windows.Win32.Globalization.UScriptCode = 146
USCRIPT_AFAKA: win32more.Windows.Win32.Globalization.UScriptCode = 147
USCRIPT_JURCHEN: win32more.Windows.Win32.Globalization.UScriptCode = 148
USCRIPT_MRO: win32more.Windows.Win32.Globalization.UScriptCode = 149
USCRIPT_NUSHU: win32more.Windows.Win32.Globalization.UScriptCode = 150
USCRIPT_SHARADA: win32more.Windows.Win32.Globalization.UScriptCode = 151
USCRIPT_SORA_SOMPENG: win32more.Windows.Win32.Globalization.UScriptCode = 152
USCRIPT_TAKRI: win32more.Windows.Win32.Globalization.UScriptCode = 153
USCRIPT_TANGUT: win32more.Windows.Win32.Globalization.UScriptCode = 154
USCRIPT_WOLEAI: win32more.Windows.Win32.Globalization.UScriptCode = 155
USCRIPT_ANATOLIAN_HIEROGLYPHS: win32more.Windows.Win32.Globalization.UScriptCode = 156
USCRIPT_KHOJKI: win32more.Windows.Win32.Globalization.UScriptCode = 157
USCRIPT_TIRHUTA: win32more.Windows.Win32.Globalization.UScriptCode = 158
USCRIPT_CAUCASIAN_ALBANIAN: win32more.Windows.Win32.Globalization.UScriptCode = 159
USCRIPT_MAHAJANI: win32more.Windows.Win32.Globalization.UScriptCode = 160
USCRIPT_AHOM: win32more.Windows.Win32.Globalization.UScriptCode = 161
USCRIPT_HATRAN: win32more.Windows.Win32.Globalization.UScriptCode = 162
USCRIPT_MODI: win32more.Windows.Win32.Globalization.UScriptCode = 163
USCRIPT_MULTANI: win32more.Windows.Win32.Globalization.UScriptCode = 164
USCRIPT_PAU_CIN_HAU: win32more.Windows.Win32.Globalization.UScriptCode = 165
USCRIPT_SIDDHAM: win32more.Windows.Win32.Globalization.UScriptCode = 166
USCRIPT_ADLAM: win32more.Windows.Win32.Globalization.UScriptCode = 167
USCRIPT_BHAIKSUKI: win32more.Windows.Win32.Globalization.UScriptCode = 168
USCRIPT_MARCHEN: win32more.Windows.Win32.Globalization.UScriptCode = 169
USCRIPT_NEWA: win32more.Windows.Win32.Globalization.UScriptCode = 170
USCRIPT_OSAGE: win32more.Windows.Win32.Globalization.UScriptCode = 171
USCRIPT_HAN_WITH_BOPOMOFO: win32more.Windows.Win32.Globalization.UScriptCode = 172
USCRIPT_JAMO: win32more.Windows.Win32.Globalization.UScriptCode = 173
USCRIPT_SYMBOLS_EMOJI: win32more.Windows.Win32.Globalization.UScriptCode = 174
USCRIPT_MASARAM_GONDI: win32more.Windows.Win32.Globalization.UScriptCode = 175
USCRIPT_SOYOMBO: win32more.Windows.Win32.Globalization.UScriptCode = 176
USCRIPT_ZANABAZAR_SQUARE: win32more.Windows.Win32.Globalization.UScriptCode = 177
USCRIPT_DOGRA: win32more.Windows.Win32.Globalization.UScriptCode = 178
USCRIPT_GUNJALA_GONDI: win32more.Windows.Win32.Globalization.UScriptCode = 179
USCRIPT_MAKASAR: win32more.Windows.Win32.Globalization.UScriptCode = 180
USCRIPT_MEDEFAIDRIN: win32more.Windows.Win32.Globalization.UScriptCode = 181
USCRIPT_HANIFI_ROHINGYA: win32more.Windows.Win32.Globalization.UScriptCode = 182
USCRIPT_SOGDIAN: win32more.Windows.Win32.Globalization.UScriptCode = 183
USCRIPT_OLD_SOGDIAN: win32more.Windows.Win32.Globalization.UScriptCode = 184
USCRIPT_ELYMAIC: win32more.Windows.Win32.Globalization.UScriptCode = 185
USCRIPT_NYIAKENG_PUACHUE_HMONG: win32more.Windows.Win32.Globalization.UScriptCode = 186
USCRIPT_NANDINAGARI: win32more.Windows.Win32.Globalization.UScriptCode = 187
USCRIPT_WANCHO: win32more.Windows.Win32.Globalization.UScriptCode = 188
USCRIPT_CHORASMIAN: win32more.Windows.Win32.Globalization.UScriptCode = 189
USCRIPT_DIVES_AKURU: win32more.Windows.Win32.Globalization.UScriptCode = 190
USCRIPT_KHITAN_SMALL_SCRIPT: win32more.Windows.Win32.Globalization.UScriptCode = 191
USCRIPT_YEZIDI: win32more.Windows.Win32.Globalization.UScriptCode = 192
UScriptUsage = Int32
USCRIPT_USAGE_NOT_ENCODED: win32more.Windows.Win32.Globalization.UScriptUsage = 0
USCRIPT_USAGE_UNKNOWN: win32more.Windows.Win32.Globalization.UScriptUsage = 1
USCRIPT_USAGE_EXCLUDED: win32more.Windows.Win32.Globalization.UScriptUsage = 2
USCRIPT_USAGE_LIMITED_USE: win32more.Windows.Win32.Globalization.UScriptUsage = 3
USCRIPT_USAGE_ASPIRATIONAL: win32more.Windows.Win32.Globalization.UScriptUsage = 4
USCRIPT_USAGE_RECOMMENDED: win32more.Windows.Win32.Globalization.UScriptUsage = 5
USearch = IntPtr
USearchAttribute = Int32
USEARCH_OVERLAP: win32more.Windows.Win32.Globalization.USearchAttribute = 0
USEARCH_ELEMENT_COMPARISON: win32more.Windows.Win32.Globalization.USearchAttribute = 2
USearchAttributeValue = Int32
USEARCH_DEFAULT: win32more.Windows.Win32.Globalization.USearchAttributeValue = -1
USEARCH_OFF: win32more.Windows.Win32.Globalization.USearchAttributeValue = 0
USEARCH_ON: win32more.Windows.Win32.Globalization.USearchAttributeValue = 1
USEARCH_STANDARD_ELEMENT_COMPARISON: win32more.Windows.Win32.Globalization.USearchAttributeValue = 2
USEARCH_PATTERN_BASE_WEIGHT_IS_WILDCARD: win32more.Windows.Win32.Globalization.USearchAttributeValue = 3
USEARCH_ANY_BASE_WEIGHT_IS_WILDCARD: win32more.Windows.Win32.Globalization.USearchAttributeValue = 4
USentenceBreak = Int32
U_SB_OTHER: win32more.Windows.Win32.Globalization.USentenceBreak = 0
U_SB_ATERM: win32more.Windows.Win32.Globalization.USentenceBreak = 1
U_SB_CLOSE: win32more.Windows.Win32.Globalization.USentenceBreak = 2
U_SB_FORMAT: win32more.Windows.Win32.Globalization.USentenceBreak = 3
U_SB_LOWER: win32more.Windows.Win32.Globalization.USentenceBreak = 4
U_SB_NUMERIC: win32more.Windows.Win32.Globalization.USentenceBreak = 5
U_SB_OLETTER: win32more.Windows.Win32.Globalization.USentenceBreak = 6
U_SB_SEP: win32more.Windows.Win32.Globalization.USentenceBreak = 7
U_SB_SP: win32more.Windows.Win32.Globalization.USentenceBreak = 8
U_SB_STERM: win32more.Windows.Win32.Globalization.USentenceBreak = 9
U_SB_UPPER: win32more.Windows.Win32.Globalization.USentenceBreak = 10
U_SB_CR: win32more.Windows.Win32.Globalization.USentenceBreak = 11
U_SB_EXTEND: win32more.Windows.Win32.Globalization.USentenceBreak = 12
U_SB_LF: win32more.Windows.Win32.Globalization.USentenceBreak = 13
U_SB_SCONTINUE: win32more.Windows.Win32.Globalization.USentenceBreak = 14
USentenceBreakTag = Int32
UBRK_SENTENCE_TERM: win32more.Windows.Win32.Globalization.USentenceBreakTag = 0
UBRK_SENTENCE_TERM_LIMIT: win32more.Windows.Win32.Globalization.USentenceBreakTag = 100
UBRK_SENTENCE_SEP: win32more.Windows.Win32.Globalization.USentenceBreakTag = 100
UBRK_SENTENCE_SEP_LIMIT: win32more.Windows.Win32.Globalization.USentenceBreakTag = 200
class USerializedSet(Structure):
    array: POINTER(UInt16)
    bmpLength: Int32
    length: Int32
    staticArray: UInt16 * 8
USet = IntPtr
USetSpanCondition = Int32
USET_SPAN_NOT_CONTAINED: win32more.Windows.Win32.Globalization.USetSpanCondition = 0
USET_SPAN_CONTAINED: win32more.Windows.Win32.Globalization.USetSpanCondition = 1
USET_SPAN_SIMPLE: win32more.Windows.Win32.Globalization.USetSpanCondition = 2
USpoofCheckResult = IntPtr
USpoofChecker = IntPtr
USpoofChecks = Int32
USPOOF_SINGLE_SCRIPT_CONFUSABLE: win32more.Windows.Win32.Globalization.USpoofChecks = 1
USPOOF_MIXED_SCRIPT_CONFUSABLE: win32more.Windows.Win32.Globalization.USpoofChecks = 2
USPOOF_WHOLE_SCRIPT_CONFUSABLE: win32more.Windows.Win32.Globalization.USpoofChecks = 4
USPOOF_CONFUSABLE: win32more.Windows.Win32.Globalization.USpoofChecks = 7
USPOOF_RESTRICTION_LEVEL: win32more.Windows.Win32.Globalization.USpoofChecks = 16
USPOOF_INVISIBLE: win32more.Windows.Win32.Globalization.USpoofChecks = 32
USPOOF_CHAR_LIMIT: win32more.Windows.Win32.Globalization.USpoofChecks = 64
USPOOF_MIXED_NUMBERS: win32more.Windows.Win32.Globalization.USpoofChecks = 128
USPOOF_HIDDEN_OVERLAY: win32more.Windows.Win32.Globalization.USpoofChecks = 256
USPOOF_ALL_CHECKS: win32more.Windows.Win32.Globalization.USpoofChecks = 65535
USPOOF_AUX_INFO: win32more.Windows.Win32.Globalization.USpoofChecks = 1073741824
@cfunctype_pointer
def UStringCaseMapper(csm: POINTER(win32more.Windows.Win32.Globalization.UCaseMap), dest: POINTER(UInt16), destCapacity: Int32, src: POINTER(UInt16), srcLength: Int32, pErrorCode: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
UStringPrepProfile = IntPtr
UStringPrepProfileType = Int32
USPREP_RFC3491_NAMEPREP: win32more.Windows.Win32.Globalization.UStringPrepProfileType = 0
USPREP_RFC3530_NFS4_CS_PREP: win32more.Windows.Win32.Globalization.UStringPrepProfileType = 1
USPREP_RFC3530_NFS4_CS_PREP_CI: win32more.Windows.Win32.Globalization.UStringPrepProfileType = 2
USPREP_RFC3530_NFS4_CIS_PREP: win32more.Windows.Win32.Globalization.UStringPrepProfileType = 3
USPREP_RFC3530_NFS4_MIXED_PREP_PREFIX: win32more.Windows.Win32.Globalization.UStringPrepProfileType = 4
USPREP_RFC3530_NFS4_MIXED_PREP_SUFFIX: win32more.Windows.Win32.Globalization.UStringPrepProfileType = 5
USPREP_RFC3722_ISCSI: win32more.Windows.Win32.Globalization.UStringPrepProfileType = 6
USPREP_RFC3920_NODEPREP: win32more.Windows.Win32.Globalization.UStringPrepProfileType = 7
USPREP_RFC3920_RESOURCEPREP: win32more.Windows.Win32.Globalization.UStringPrepProfileType = 8
USPREP_RFC4011_MIB: win32more.Windows.Win32.Globalization.UStringPrepProfileType = 9
USPREP_RFC4013_SASLPREP: win32more.Windows.Win32.Globalization.UStringPrepProfileType = 10
USPREP_RFC4505_TRACE: win32more.Windows.Win32.Globalization.UStringPrepProfileType = 11
USPREP_RFC4518_LDAP: win32more.Windows.Win32.Globalization.UStringPrepProfileType = 12
USPREP_RFC4518_LDAP_CI: win32more.Windows.Win32.Globalization.UStringPrepProfileType = 13
UStringSearch = IntPtr
UStringTrieBuildOption = Int32
USTRINGTRIE_BUILD_FAST: win32more.Windows.Win32.Globalization.UStringTrieBuildOption = 0
USTRINGTRIE_BUILD_SMALL: win32more.Windows.Win32.Globalization.UStringTrieBuildOption = 1
UStringTrieResult = Int32
USTRINGTRIE_NO_MATCH: win32more.Windows.Win32.Globalization.UStringTrieResult = 0
USTRINGTRIE_NO_VALUE: win32more.Windows.Win32.Globalization.UStringTrieResult = 1
USTRINGTRIE_FINAL_VALUE: win32more.Windows.Win32.Globalization.UStringTrieResult = 2
USTRINGTRIE_INTERMEDIATE_VALUE: win32more.Windows.Win32.Globalization.UStringTrieResult = 3
USystemTimeZoneType = Int32
UCAL_ZONE_TYPE_ANY: win32more.Windows.Win32.Globalization.USystemTimeZoneType = 0
UCAL_ZONE_TYPE_CANONICAL: win32more.Windows.Win32.Globalization.USystemTimeZoneType = 1
UCAL_ZONE_TYPE_CANONICAL_LOCATION: win32more.Windows.Win32.Globalization.USystemTimeZoneType = 2
class UText(Structure):
    magic: UInt32
    flags: Int32
    providerProperties: Int32
    sizeOfStruct: Int32
    chunkNativeLimit: Int64
    extraSize: Int32
    nativeIndexingLimit: Int32
    chunkNativeStart: Int64
    chunkOffset: Int32
    chunkLength: Int32
    chunkContents: POINTER(UInt16)
    pFuncs: POINTER(win32more.Windows.Win32.Globalization.UTextFuncs)
    pExtra: VoidPtr
    context: VoidPtr
    p: VoidPtr
    q: VoidPtr
    r: VoidPtr
    privP: VoidPtr
    a: Int64
    b: Int32
    c: Int32
    privA: Int64
    privB: Int32
    privC: Int32
@cfunctype_pointer
def UTextAccess(ut: POINTER(win32more.Windows.Win32.Globalization.UText), nativeIndex: Int64, forward: SByte) -> SByte: ...
@cfunctype_pointer
def UTextClone(dest: POINTER(win32more.Windows.Win32.Globalization.UText), src: POINTER(win32more.Windows.Win32.Globalization.UText), deep: SByte, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> POINTER(win32more.Windows.Win32.Globalization.UText): ...
@cfunctype_pointer
def UTextClose(ut: POINTER(win32more.Windows.Win32.Globalization.UText)) -> Void: ...
@cfunctype_pointer
def UTextCopy(ut: POINTER(win32more.Windows.Win32.Globalization.UText), nativeStart: Int64, nativeLimit: Int64, nativeDest: Int64, move: SByte, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Void: ...
@cfunctype_pointer
def UTextExtract(ut: POINTER(win32more.Windows.Win32.Globalization.UText), nativeStart: Int64, nativeLimit: Int64, dest: POINTER(UInt16), destCapacity: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
class UTextFuncs(Structure):
    tableSize: Int32
    reserved1: Int32
    reserved2: Int32
    reserved3: Int32
    clone: win32more.Windows.Win32.Globalization.UTextClone
    nativeLength: win32more.Windows.Win32.Globalization.UTextNativeLength
    access: win32more.Windows.Win32.Globalization.UTextAccess
    extract: win32more.Windows.Win32.Globalization.UTextExtract
    replace: win32more.Windows.Win32.Globalization.UTextReplace
    copy: win32more.Windows.Win32.Globalization.UTextCopy
    mapOffsetToNative: win32more.Windows.Win32.Globalization.UTextMapOffsetToNative
    mapNativeIndexToUTF16: win32more.Windows.Win32.Globalization.UTextMapNativeIndexToUTF16
    close: win32more.Windows.Win32.Globalization.UTextClose
    spare1: win32more.Windows.Win32.Globalization.UTextClose
    spare2: win32more.Windows.Win32.Globalization.UTextClose
    spare3: win32more.Windows.Win32.Globalization.UTextClose
@cfunctype_pointer
def UTextMapNativeIndexToUTF16(ut: POINTER(win32more.Windows.Win32.Globalization.UText), nativeIndex: Int64) -> Int32: ...
@cfunctype_pointer
def UTextMapOffsetToNative(ut: POINTER(win32more.Windows.Win32.Globalization.UText)) -> Int64: ...
@cfunctype_pointer
def UTextNativeLength(ut: POINTER(win32more.Windows.Win32.Globalization.UText)) -> Int64: ...
@cfunctype_pointer
def UTextReplace(ut: POINTER(win32more.Windows.Win32.Globalization.UText), nativeStart: Int64, nativeLimit: Int64, replacementText: POINTER(UInt16), replacmentLength: Int32, status: POINTER(win32more.Windows.Win32.Globalization.UErrorCode)) -> Int32: ...
UTimeScaleValue = Int32
UTSV_UNITS_VALUE: win32more.Windows.Win32.Globalization.UTimeScaleValue = 0
UTSV_EPOCH_OFFSET_VALUE: win32more.Windows.Win32.Globalization.UTimeScaleValue = 1
UTSV_FROM_MIN_VALUE: win32more.Windows.Win32.Globalization.UTimeScaleValue = 2
UTSV_FROM_MAX_VALUE: win32more.Windows.Win32.Globalization.UTimeScaleValue = 3
UTSV_TO_MIN_VALUE: win32more.Windows.Win32.Globalization.UTimeScaleValue = 4
UTSV_TO_MAX_VALUE: win32more.Windows.Win32.Globalization.UTimeScaleValue = 5
UTimeZoneFormatGMTOffsetPatternType = Int32
UTZFMT_PAT_POSITIVE_HM: win32more.Windows.Win32.Globalization.UTimeZoneFormatGMTOffsetPatternType = 0
UTZFMT_PAT_POSITIVE_HMS: win32more.Windows.Win32.Globalization.UTimeZoneFormatGMTOffsetPatternType = 1
UTZFMT_PAT_NEGATIVE_HM: win32more.Windows.Win32.Globalization.UTimeZoneFormatGMTOffsetPatternType = 2
UTZFMT_PAT_NEGATIVE_HMS: win32more.Windows.Win32.Globalization.UTimeZoneFormatGMTOffsetPatternType = 3
UTZFMT_PAT_POSITIVE_H: win32more.Windows.Win32.Globalization.UTimeZoneFormatGMTOffsetPatternType = 4
UTZFMT_PAT_NEGATIVE_H: win32more.Windows.Win32.Globalization.UTimeZoneFormatGMTOffsetPatternType = 5
UTZFMT_PAT_COUNT: win32more.Windows.Win32.Globalization.UTimeZoneFormatGMTOffsetPatternType = 6
UTimeZoneFormatParseOption = Int32
UTZFMT_PARSE_OPTION_NONE: win32more.Windows.Win32.Globalization.UTimeZoneFormatParseOption = 0
UTZFMT_PARSE_OPTION_ALL_STYLES: win32more.Windows.Win32.Globalization.UTimeZoneFormatParseOption = 1
UTZFMT_PARSE_OPTION_TZ_DATABASE_ABBREVIATIONS: win32more.Windows.Win32.Globalization.UTimeZoneFormatParseOption = 2
UTimeZoneFormatStyle = Int32
UTZFMT_STYLE_GENERIC_LOCATION: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 0
UTZFMT_STYLE_GENERIC_LONG: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 1
UTZFMT_STYLE_GENERIC_SHORT: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 2
UTZFMT_STYLE_SPECIFIC_LONG: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 3
UTZFMT_STYLE_SPECIFIC_SHORT: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 4
UTZFMT_STYLE_LOCALIZED_GMT: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 5
UTZFMT_STYLE_LOCALIZED_GMT_SHORT: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 6
UTZFMT_STYLE_ISO_BASIC_SHORT: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 7
UTZFMT_STYLE_ISO_BASIC_LOCAL_SHORT: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 8
UTZFMT_STYLE_ISO_BASIC_FIXED: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 9
UTZFMT_STYLE_ISO_BASIC_LOCAL_FIXED: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 10
UTZFMT_STYLE_ISO_BASIC_FULL: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 11
UTZFMT_STYLE_ISO_BASIC_LOCAL_FULL: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 12
UTZFMT_STYLE_ISO_EXTENDED_FIXED: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 13
UTZFMT_STYLE_ISO_EXTENDED_LOCAL_FIXED: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 14
UTZFMT_STYLE_ISO_EXTENDED_FULL: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 15
UTZFMT_STYLE_ISO_EXTENDED_LOCAL_FULL: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 16
UTZFMT_STYLE_ZONE_ID: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 17
UTZFMT_STYLE_ZONE_ID_SHORT: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 18
UTZFMT_STYLE_EXEMPLAR_LOCATION: win32more.Windows.Win32.Globalization.UTimeZoneFormatStyle = 19
UTimeZoneFormatTimeType = Int32
UTZFMT_TIME_TYPE_UNKNOWN: win32more.Windows.Win32.Globalization.UTimeZoneFormatTimeType = 0
UTZFMT_TIME_TYPE_STANDARD: win32more.Windows.Win32.Globalization.UTimeZoneFormatTimeType = 1
UTZFMT_TIME_TYPE_DAYLIGHT: win32more.Windows.Win32.Globalization.UTimeZoneFormatTimeType = 2
UTimeZoneNameType = Int32
UTZNM_UNKNOWN: win32more.Windows.Win32.Globalization.UTimeZoneNameType = 0
UTZNM_LONG_GENERIC: win32more.Windows.Win32.Globalization.UTimeZoneNameType = 1
UTZNM_LONG_STANDARD: win32more.Windows.Win32.Globalization.UTimeZoneNameType = 2
UTZNM_LONG_DAYLIGHT: win32more.Windows.Win32.Globalization.UTimeZoneNameType = 4
UTZNM_SHORT_GENERIC: win32more.Windows.Win32.Globalization.UTimeZoneNameType = 8
UTZNM_SHORT_STANDARD: win32more.Windows.Win32.Globalization.UTimeZoneNameType = 16
UTZNM_SHORT_DAYLIGHT: win32more.Windows.Win32.Globalization.UTimeZoneNameType = 32
UTZNM_EXEMPLAR_LOCATION: win32more.Windows.Win32.Globalization.UTimeZoneNameType = 64
UTimeZoneTransitionType = Int32
UCAL_TZ_TRANSITION_NEXT: win32more.Windows.Win32.Globalization.UTimeZoneTransitionType = 0
UCAL_TZ_TRANSITION_NEXT_INCLUSIVE: win32more.Windows.Win32.Globalization.UTimeZoneTransitionType = 1
UCAL_TZ_TRANSITION_PREVIOUS: win32more.Windows.Win32.Globalization.UTimeZoneTransitionType = 2
UCAL_TZ_TRANSITION_PREVIOUS_INCLUSIVE: win32more.Windows.Win32.Globalization.UTimeZoneTransitionType = 3
@cfunctype_pointer
def UTraceData(context: VoidPtr, fnNumber: Int32, level: Int32, fmt: win32more.Windows.Win32.Foundation.PSTR, args: POINTER(SByte)) -> Void: ...
@cfunctype_pointer
def UTraceEntry(context: VoidPtr, fnNumber: Int32) -> Void: ...
@cfunctype_pointer
def UTraceExit(context: VoidPtr, fnNumber: Int32, fmt: win32more.Windows.Win32.Foundation.PSTR, args: POINTER(SByte)) -> Void: ...
UTraceFunctionNumber = Int32
UTRACE_FUNCTION_START: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 0
UTRACE_U_INIT: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 0
UTRACE_U_CLEANUP: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 1
UTRACE_CONVERSION_START: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 4096
UTRACE_UCNV_OPEN: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 4096
UTRACE_UCNV_OPEN_PACKAGE: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 4097
UTRACE_UCNV_OPEN_ALGORITHMIC: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 4098
UTRACE_UCNV_CLONE: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 4099
UTRACE_UCNV_CLOSE: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 4100
UTRACE_UCNV_FLUSH_CACHE: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 4101
UTRACE_UCNV_LOAD: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 4102
UTRACE_UCNV_UNLOAD: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 4103
UTRACE_COLLATION_START: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 8192
UTRACE_UCOL_OPEN: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 8192
UTRACE_UCOL_CLOSE: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 8193
UTRACE_UCOL_STRCOLL: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 8194
UTRACE_UCOL_GET_SORTKEY: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 8195
UTRACE_UCOL_GETLOCALE: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 8196
UTRACE_UCOL_NEXTSORTKEYPART: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 8197
UTRACE_UCOL_STRCOLLITER: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 8198
UTRACE_UCOL_OPEN_FROM_SHORT_STRING: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 8199
UTRACE_UCOL_STRCOLLUTF8: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 8200
UTRACE_UDATA_START: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 12288
UTRACE_UDATA_RESOURCE: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 12288
UTRACE_UDATA_BUNDLE: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 12289
UTRACE_UDATA_DATA_FILE: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 12290
UTRACE_UDATA_RES_FILE: win32more.Windows.Win32.Globalization.UTraceFunctionNumber = 12291
UTraceLevel = Int32
UTRACE_OFF: win32more.Windows.Win32.Globalization.UTraceLevel = -1
UTRACE_ERROR: win32more.Windows.Win32.Globalization.UTraceLevel = 0
UTRACE_WARNING: win32more.Windows.Win32.Globalization.UTraceLevel = 3
UTRACE_OPEN_CLOSE: win32more.Windows.Win32.Globalization.UTraceLevel = 5
UTRACE_INFO: win32more.Windows.Win32.Globalization.UTraceLevel = 7
UTRACE_VERBOSE: win32more.Windows.Win32.Globalization.UTraceLevel = 9
UTransDirection = Int32
UTRANS_FORWARD: win32more.Windows.Win32.Globalization.UTransDirection = 0
UTRANS_REVERSE: win32more.Windows.Win32.Globalization.UTransDirection = 1
class UTransPosition(Structure):
    contextStart: Int32
    contextLimit: Int32
    start: Int32
    limit: Int32
UVerticalOrientation = Int32
U_VO_ROTATED: win32more.Windows.Win32.Globalization.UVerticalOrientation = 0
U_VO_TRANSFORMED_ROTATED: win32more.Windows.Win32.Globalization.UVerticalOrientation = 1
U_VO_TRANSFORMED_UPRIGHT: win32more.Windows.Win32.Globalization.UVerticalOrientation = 2
U_VO_UPRIGHT: win32more.Windows.Win32.Globalization.UVerticalOrientation = 3
UWordBreak = Int32
UBRK_WORD_NONE: win32more.Windows.Win32.Globalization.UWordBreak = 0
UBRK_WORD_NONE_LIMIT: win32more.Windows.Win32.Globalization.UWordBreak = 100
UBRK_WORD_NUMBER: win32more.Windows.Win32.Globalization.UWordBreak = 100
UBRK_WORD_NUMBER_LIMIT: win32more.Windows.Win32.Globalization.UWordBreak = 200
UBRK_WORD_LETTER: win32more.Windows.Win32.Globalization.UWordBreak = 200
UBRK_WORD_LETTER_LIMIT: win32more.Windows.Win32.Globalization.UWordBreak = 300
UBRK_WORD_KANA: win32more.Windows.Win32.Globalization.UWordBreak = 300
UBRK_WORD_KANA_LIMIT: win32more.Windows.Win32.Globalization.UWordBreak = 400
UBRK_WORD_IDEO: win32more.Windows.Win32.Globalization.UWordBreak = 400
UBRK_WORD_IDEO_LIMIT: win32more.Windows.Win32.Globalization.UWordBreak = 500
UWordBreakValues = Int32
U_WB_OTHER: win32more.Windows.Win32.Globalization.UWordBreakValues = 0
U_WB_ALETTER: win32more.Windows.Win32.Globalization.UWordBreakValues = 1
U_WB_FORMAT: win32more.Windows.Win32.Globalization.UWordBreakValues = 2
U_WB_KATAKANA: win32more.Windows.Win32.Globalization.UWordBreakValues = 3
U_WB_MIDLETTER: win32more.Windows.Win32.Globalization.UWordBreakValues = 4
U_WB_MIDNUM: win32more.Windows.Win32.Globalization.UWordBreakValues = 5
U_WB_NUMERIC: win32more.Windows.Win32.Globalization.UWordBreakValues = 6
U_WB_EXTENDNUMLET: win32more.Windows.Win32.Globalization.UWordBreakValues = 7
U_WB_CR: win32more.Windows.Win32.Globalization.UWordBreakValues = 8
U_WB_EXTEND: win32more.Windows.Win32.Globalization.UWordBreakValues = 9
U_WB_LF: win32more.Windows.Win32.Globalization.UWordBreakValues = 10
U_WB_MIDNUMLET: win32more.Windows.Win32.Globalization.UWordBreakValues = 11
U_WB_NEWLINE: win32more.Windows.Win32.Globalization.UWordBreakValues = 12
U_WB_REGIONAL_INDICATOR: win32more.Windows.Win32.Globalization.UWordBreakValues = 13
U_WB_HEBREW_LETTER: win32more.Windows.Win32.Globalization.UWordBreakValues = 14
U_WB_SINGLE_QUOTE: win32more.Windows.Win32.Globalization.UWordBreakValues = 15
U_WB_DOUBLE_QUOTE: win32more.Windows.Win32.Globalization.UWordBreakValues = 16
U_WB_E_BASE: win32more.Windows.Win32.Globalization.UWordBreakValues = 17
U_WB_E_BASE_GAZ: win32more.Windows.Win32.Globalization.UWordBreakValues = 18
U_WB_E_MODIFIER: win32more.Windows.Win32.Globalization.UWordBreakValues = 19
U_WB_GLUE_AFTER_ZWJ: win32more.Windows.Win32.Globalization.UWordBreakValues = 20
U_WB_ZWJ: win32more.Windows.Win32.Globalization.UWordBreakValues = 21
U_WB_WSEGSPACE: win32more.Windows.Win32.Globalization.UWordBreakValues = 22
WORDLIST_TYPE = Int32
WORDLIST_TYPE_IGNORE: win32more.Windows.Win32.Globalization.WORDLIST_TYPE = 0
WORDLIST_TYPE_ADD: win32more.Windows.Win32.Globalization.WORDLIST_TYPE = 1
WORDLIST_TYPE_EXCLUDE: win32more.Windows.Win32.Globalization.WORDLIST_TYPE = 2
WORDLIST_TYPE_AUTOCORRECT: win32more.Windows.Win32.Globalization.WORDLIST_TYPE = 3


make_ready(__name__)
