from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Media
import win32more.Windows.Win32.Media.DirectShow
import win32more.Windows.Win32.Media.KernelStreaming
import win32more.Windows.Win32.Media.MediaFoundation
import win32more.Windows.Win32.System.Com
class ALLOCATOR_PROPERTIES_EX(Structure):
    cBuffers: Int32
    cbBuffer: Int32
    cbAlign: Int32
    cbPrefix: Int32
    MemoryType: Guid
    BusType: Guid
    State: win32more.Windows.Win32.Media.KernelStreaming.PIPE_STATE
    Input: win32more.Windows.Win32.Media.KernelStreaming.PIPE_TERMINATION
    Output: win32more.Windows.Win32.Media.KernelStreaming.PIPE_TERMINATION
    Strategy: UInt32
    Flags: UInt32
    Weight: UInt32
    LogicalMemoryType: win32more.Windows.Win32.Media.KernelStreaming.KS_LogicalMemoryType
    AllocatorPlace: win32more.Windows.Win32.Media.KernelStreaming.PIPE_ALLOCATOR_PLACE
    Dimensions: win32more.Windows.Win32.Media.KernelStreaming.PIPE_DIMENSIONS
    PhysicalRange: win32more.Windows.Win32.Media.KernelStreaming.KS_FRAMING_RANGE
    PrevSegment: win32more.Windows.Win32.Media.KernelStreaming.IKsAllocatorEx
    CountNextSegments: UInt32
    NextSegments: POINTER(win32more.Windows.Win32.Media.KernelStreaming.IKsAllocatorEx)
    InsideFactors: UInt32
    NumberPins: UInt32
APO_CLASS_UUID = Guid('{5989fce8-9cd0-467d-8a6a-5419e31529d4}')
AUDIOENDPOINT_CLASS_UUID = Guid('{c166523c-fe0c-4a94-a586-f1a80cfbbf3e}')
AUDIOPOSTURE_ORIENTATION = Int32
AUDIOPOSTURE_ORIENTATION_NOTROTATED: win32more.Windows.Win32.Media.KernelStreaming.AUDIOPOSTURE_ORIENTATION = 0
AUDIOPOSTURE_ORIENTATION_ROTATED90DEGREESCOUNTERCLOCKWISE: win32more.Windows.Win32.Media.KernelStreaming.AUDIOPOSTURE_ORIENTATION = 1
AUDIOPOSTURE_ORIENTATION_ROTATED180DEGREESCOUNTERCLOCKWISE: win32more.Windows.Win32.Media.KernelStreaming.AUDIOPOSTURE_ORIENTATION = 2
AUDIOPOSTURE_ORIENTATION_ROTATED270DEGREESCOUNTERCLOCKWISE: win32more.Windows.Win32.Media.KernelStreaming.AUDIOPOSTURE_ORIENTATION = 3
class AUDIORESOURCEMANAGEMENT_RESOURCEGROUP(Structure):
    ResourceGroupAcquired: win32more.Windows.Win32.Foundation.BOOL
    ResourceGroupName: Char * 256
AUDIO_CURVE_TYPE = Int32
AUDIO_CURVE_TYPE_NONE: win32more.Windows.Win32.Media.KernelStreaming.AUDIO_CURVE_TYPE = 0
AUDIO_CURVE_TYPE_WINDOWS_FADE: win32more.Windows.Win32.Media.KernelStreaming.AUDIO_CURVE_TYPE = 1
AUDIO_EFFECT_TYPE_ACOUSTIC_ECHO_CANCELLATION = Guid('{6f64adbe-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_AUTOMATIC_GAIN_CONTROL = Guid('{6f64adc0-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_BASS_BOOST = Guid('{6f64adc5-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_BASS_MANAGEMENT = Guid('{6f64adca-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_BEAMFORMING = Guid('{6f64adc1-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_CONSTANT_TONE_REMOVAL = Guid('{6f64adc2-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_DEEP_NOISE_SUPPRESSION = Guid('{6f64add0-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_DYNAMIC_RANGE_COMPRESSION = Guid('{6f64adce-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_ENVIRONMENTAL_EFFECTS = Guid('{6f64adcb-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_EQUALIZER = Guid('{6f64adc3-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_FAR_FIELD_BEAMFORMING = Guid('{6f64adcf-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_LOUDNESS_EQUALIZER = Guid('{6f64adc4-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_NOISE_SUPPRESSION = Guid('{6f64adbf-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_ROOM_CORRECTION = Guid('{6f64adc9-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_SPEAKER_COMPENSATION = Guid('{6f64adcd-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_SPEAKER_FILL = Guid('{6f64adc8-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_SPEAKER_PROTECTION = Guid('{6f64adcc-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_VIRTUAL_HEADPHONES = Guid('{6f64adc7-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_EFFECT_TYPE_VIRTUAL_SURROUND = Guid('{6f64adc6-8211-11e2-8c70-2c27d7f001fa}')
AUDIO_SIGNALPROCESSINGMODE_COMMUNICATIONS = Guid('{98951333-b9cd-48b1-a0a3-ff40682d73f7}')
AUDIO_SIGNALPROCESSINGMODE_DEFAULT = Guid('{c18e2f7e-933d-4965-b7d1-1eef228d2af3}')
AUDIO_SIGNALPROCESSINGMODE_FAR_FIELD_SPEECH = Guid('{28941cba-3be6-4a78-9a76-30fd91559b64}')
AUDIO_SIGNALPROCESSINGMODE_MEDIA = Guid('{4780004e-7133-41d8-8c74-660dadd2c0ee}')
AUDIO_SIGNALPROCESSINGMODE_MOVIE = Guid('{b26feb0d-ec94-477c-9494-d1ab8e753f6e}')
AUDIO_SIGNALPROCESSINGMODE_NOTIFICATION = Guid('{9cf2a70b-f377-403b-bd6b-360863e0355c}')
AUDIO_SIGNALPROCESSINGMODE_RAW = Guid('{9e90ea20-b493-4fd1-a1a8-7e1361a956cf}')
AUDIO_SIGNALPROCESSINGMODE_SPEECH = Guid('{fc1cfc9b-b9d6-4cfa-b5e0-4bb2166878b2}')
IOCTL_KS_PROPERTY: UInt32 = 3080195
IOCTL_KS_ENABLE_EVENT: UInt32 = 3080199
IOCTL_KS_DISABLE_EVENT: UInt32 = 3080203
IOCTL_KS_METHOD: UInt32 = 3080207
IOCTL_KS_WRITE_STREAM: UInt32 = 3112979
IOCTL_KS_READ_STREAM: UInt32 = 3096599
IOCTL_KS_RESET_STATE: UInt32 = 3080219
KSPRIORITY_LOW: UInt32 = 1
KSPRIORITY_NORMAL: UInt32 = 1073741824
KSPRIORITY_HIGH: UInt32 = 2147483648
KSPRIORITY_EXCLUSIVE: UInt32 = 4294967295
KSMETHOD_TYPE_NONE: UInt32 = 0
KSMETHOD_TYPE_READ: UInt32 = 1
KSMETHOD_TYPE_WRITE: UInt32 = 2
KSMETHOD_TYPE_MODIFY: UInt32 = 3
KSMETHOD_TYPE_SOURCE: UInt32 = 4
KSMETHOD_TYPE_SEND: UInt32 = 1
KSMETHOD_TYPE_SETSUPPORT: UInt32 = 256
KSMETHOD_TYPE_BASICSUPPORT: UInt32 = 512
KSMETHOD_TYPE_TOPOLOGY: UInt32 = 268435456
KSPROPERTY_TYPE_GET: UInt32 = 1
KSPROPERTY_TYPE_GETPAYLOADSIZE: UInt32 = 4
KSPROPERTY_TYPE_SET: UInt32 = 2
KSPROPERTY_TYPE_SETSUPPORT: UInt32 = 256
KSPROPERTY_TYPE_BASICSUPPORT: UInt32 = 512
KSPROPERTY_TYPE_RELATIONS: UInt32 = 1024
KSPROPERTY_TYPE_SERIALIZESET: UInt32 = 2048
KSPROPERTY_TYPE_UNSERIALIZESET: UInt32 = 4096
KSPROPERTY_TYPE_SERIALIZERAW: UInt32 = 8192
KSPROPERTY_TYPE_UNSERIALIZERAW: UInt32 = 16384
KSPROPERTY_TYPE_SERIALIZESIZE: UInt32 = 32768
KSPROPERTY_TYPE_DEFAULTVALUES: UInt32 = 65536
KSPROPERTY_TYPE_TOPOLOGY: UInt32 = 268435456
KSPROPERTY_TYPE_HIGHPRIORITY: UInt32 = 134217728
KSPROPERTY_TYPE_FSFILTERSCOPE: UInt32 = 1073741824
KSPROPERTY_TYPE_COPYPAYLOAD: UInt32 = 2147483648
KSPROPERTY_MEMBER_RANGES: UInt32 = 1
KSPROPERTY_MEMBER_STEPPEDRANGES: UInt32 = 2
KSPROPERTY_MEMBER_VALUES: UInt32 = 3
KSPROPERTY_MEMBER_FLAG_DEFAULT: UInt32 = 1
KSPROPERTY_MEMBER_FLAG_BASICSUPPORT_MULTICHANNEL: UInt32 = 2
KSPROPERTY_MEMBER_FLAG_BASICSUPPORT_UNIFORM: UInt32 = 4
KSEVENTF_EVENT_HANDLE: UInt32 = 1
KSEVENTF_SEMAPHORE_HANDLE: UInt32 = 2
KSEVENTF_EVENT_OBJECT: UInt32 = 4
KSEVENTF_SEMAPHORE_OBJECT: UInt32 = 8
KSEVENTF_DPC: UInt32 = 16
KSEVENTF_WORKITEM: UInt32 = 32
KSEVENTF_KSWORKITEM: UInt32 = 128
KSEVENT_TYPE_ENABLE: UInt32 = 1
KSEVENT_TYPE_ONESHOT: UInt32 = 2
KSEVENT_TYPE_ENABLEBUFFERED: UInt32 = 4
KSEVENT_TYPE_SETSUPPORT: UInt32 = 256
KSEVENT_TYPE_BASICSUPPORT: UInt32 = 512
KSEVENT_TYPE_QUERYBUFFER: UInt32 = 1024
KSEVENT_TYPE_TOPOLOGY: UInt32 = 268435456
KSRELATIVEEVENT_FLAG_HANDLE: UInt32 = 1
KSRELATIVEEVENT_FLAG_POINTER: UInt32 = 2
KSMEDIUM_TYPE_ANYINSTANCE: UInt32 = 0
KSMEDIUM_STANDARD_DEVIO: UInt32 = 0
KSPROPERTY_PIN_FLAGS_ATTRIBUTE_RANGE_AWARE: UInt32 = 1
KSPROPERTY_PIN_FLAGS_MASK: UInt32 = 1
KSDATAFORMAT_BIT_TEMPORAL_COMPRESSION: UInt32 = 0
KSDATAFORMAT_BIT_ATTRIBUTES: UInt32 = 1
KSDATARANGE_BIT_ATTRIBUTES: UInt32 = 1
KSDATARANGE_BIT_REQUIRED_ATTRIBUTES: UInt32 = 2
KSATTRIBUTE_REQUIRED: UInt32 = 1
KSSTRING_Filter: String = '{9B365890-165F-11D0-A195-0020AFD156E4}'
KSSTRING_Pin: String = '{146F1A80-4791-11D0-A5D6-28DB04C10000}'
KSSTRING_Clock: String = '{53172480-4791-11D0-A5D6-28DB04C10000}'
KSSTRING_Allocator: String = '{642F5D00-4791-11D0-A5D6-28DB04C10000}'
KSSTRING_AllocatorEx: String = '{091BB63B-603F-11D1-B067-00A0C9062802}'
KSSTRING_TopologyNode: String = '{0621061A-EE75-11D0-B915-00A0C9223196}'
KSALLOCATOR_REQUIREMENTF_INPLACE_MODIFIER: UInt32 = 1
KSALLOCATOR_REQUIREMENTF_SYSTEM_MEMORY: UInt32 = 2
KSALLOCATOR_REQUIREMENTF_FRAME_INTEGRITY: UInt32 = 4
KSALLOCATOR_REQUIREMENTF_MUST_ALLOCATE: UInt32 = 8
KSALLOCATOR_REQUIREMENTF_SYSTEM_MEMORY_CUSTOM_ALLOCATION: UInt32 = 16
KSALLOCATOR_REQUIREMENTF_PREFERENCES_ONLY: UInt32 = 2147483648
KSALLOCATOR_OPTIONF_COMPATIBLE: UInt32 = 1
KSALLOCATOR_OPTIONF_SYSTEM_MEMORY: UInt32 = 2
KSALLOCATOR_OPTIONF_VALID: UInt32 = 3
KSALLOCATOR_FLAG_PARTIAL_READ_SUPPORT: UInt32 = 16
KSALLOCATOR_FLAG_DEVICE_SPECIFIC: UInt32 = 32
KSALLOCATOR_FLAG_CAN_ALLOCATE: UInt32 = 64
KSALLOCATOR_FLAG_INSIST_ON_FRAMESIZE_RATIO: UInt32 = 128
KSALLOCATOR_FLAG_NO_FRAME_INTEGRITY: UInt32 = 256
KSALLOCATOR_FLAG_MULTIPLE_OUTPUT: UInt32 = 512
KSALLOCATOR_FLAG_CYCLE: UInt32 = 1024
KSALLOCATOR_FLAG_ALLOCATOR_EXISTS: UInt32 = 2048
KSALLOCATOR_FLAG_INDEPENDENT_RANGES: UInt32 = 4096
KSALLOCATOR_FLAG_ATTENTION_STEPPING: UInt32 = 8192
KSALLOCATOR_FLAG_ENABLE_CACHED_MDL: UInt32 = 16384
KSALLOCATOR_FLAG_2D_BUFFER_REQUIRED: UInt32 = 32768
KSSTREAM_HEADER_OPTIONSF_SPLICEPOINT: UInt32 = 1
KSSTREAM_HEADER_OPTIONSF_PREROLL: UInt32 = 2
KSSTREAM_HEADER_OPTIONSF_DATADISCONTINUITY: UInt32 = 4
KSSTREAM_HEADER_OPTIONSF_TYPECHANGED: UInt32 = 8
KSSTREAM_HEADER_OPTIONSF_TIMEVALID: UInt32 = 16
KSSTREAM_HEADER_OPTIONSF_TIMEDISCONTINUITY: UInt32 = 64
KSSTREAM_HEADER_OPTIONSF_FLUSHONPAUSE: UInt32 = 128
KSSTREAM_HEADER_OPTIONSF_DURATIONVALID: UInt32 = 256
KSSTREAM_HEADER_OPTIONSF_ENDOFSTREAM: UInt32 = 512
KSSTREAM_HEADER_OPTIONSF_BUFFEREDTRANSFER: UInt32 = 1024
KSSTREAM_HEADER_OPTIONSF_VRAM_DATA_TRANSFER: UInt32 = 2048
KSSTREAM_HEADER_OPTIONSF_METADATA: UInt32 = 4096
KSSTREAM_HEADER_OPTIONSF_ENDOFPHOTOSEQUENCE: UInt32 = 8192
KSSTREAM_HEADER_OPTIONSF_FRAMEINFO: UInt32 = 16384
KSSTREAM_HEADER_OPTIONSF_PERSIST_SAMPLE: UInt32 = 32768
KSSTREAM_HEADER_OPTIONSF_SAMPLE_PERSISTED: UInt32 = 65536
KSSTREAM_HEADER_TRACK_COMPLETION_NUMBERS: UInt32 = 131072
KSSTREAM_HEADER_OPTIONSF_SECUREBUFFERTRANSFER: UInt32 = 262144
KSSTREAM_HEADER_OPTIONSF_LOOPEDDATA: UInt32 = 2147483648
KSSTREAM_UVC_SECURE_ATTRIBUTE_SIZE: UInt32 = 8192
KSFRAMETIME_VARIABLESIZE: UInt32 = 1
KSRATE_NOPRESENTATIONSTART: UInt32 = 1
KSRATE_NOPRESENTATIONDURATION: UInt32 = 2
NANOSECONDS: UInt32 = 10000000
KSPROBE_STREAMREAD: UInt32 = 0
KSPROBE_STREAMWRITE: UInt32 = 1
KSPROBE_ALLOCATEMDL: UInt32 = 16
KSPROBE_PROBEANDLOCK: UInt32 = 32
KSPROBE_SYSTEMADDRESS: UInt32 = 64
KSPROBE_MODIFY: UInt32 = 512
KSPROBE_ALLOWFORMATCHANGE: UInt32 = 128
KSSTREAM_READ: UInt32 = 0
KSSTREAM_WRITE: UInt32 = 1
KSSTREAM_PAGED_DATA: UInt32 = 0
KSSTREAM_NONPAGED_DATA: UInt32 = 256
KSSTREAM_SYNCHRONOUS: UInt32 = 4096
KSSTREAM_FAILUREEXCEPTION: UInt32 = 8192
KSEVENT_ENTRY_DELETED: UInt32 = 1
KSEVENT_ENTRY_ONESHOT: UInt32 = 2
KSEVENT_ENTRY_BUFFERED: UInt32 = 4
KSDISPATCH_FASTIO: UInt32 = 2147483648
KSCREATE_ITEM_SECURITYCHANGED: UInt32 = 1
KSCREATE_ITEM_WILDCARD: UInt32 = 2
KSCREATE_ITEM_NOPARAMETERS: UInt32 = 4
KSCREATE_ITEM_FREEONSTOP: UInt32 = 8
BUS_INTERFACE_REFERENCE_VERSION: UInt32 = 256
IOCTL_KS_HANDSHAKE: UInt32 = 3080223
MIN_DEV_VER_FOR_QI: UInt32 = 256
KSDEVICE_DESCRIPTOR_VERSION: UInt32 = 256
KSDEVICE_DESCRIPTOR_VERSION_2: UInt32 = 272
MIN_DEV_VER_FOR_FLAGS: UInt32 = 272
KSDEVICE_FLAG_ENABLE_REMOTE_WAKEUP: UInt32 = 1
KSDEVICE_FLAG_LOWPOWER_PASSTHROUGH: UInt32 = 2
KSDEVICE_FLAG_ENABLE_QUERYINTERFACE: UInt32 = 4
KSFILTER_FLAG_DISPATCH_LEVEL_PROCESSING: UInt32 = 1
KSFILTER_FLAG_CRITICAL_PROCESSING: UInt32 = 2
KSFILTER_FLAG_HYPERCRITICAL_PROCESSING: UInt32 = 4
KSFILTER_FLAG_RECEIVE_ZERO_LENGTH_SAMPLES: UInt32 = 8
KSFILTER_FLAG_DENY_USERMODE_ACCESS: UInt32 = 2147483648
KSFILTER_FLAG_PRIORITIZE_REFERENCEGUID: UInt32 = 16
KSPIN_FLAG_DISPATCH_LEVEL_PROCESSING: UInt32 = 1
KSPIN_FLAG_CRITICAL_PROCESSING: UInt32 = 2
KSPIN_FLAG_HYPERCRITICAL_PROCESSING: UInt32 = 4
KSPIN_FLAG_ASYNCHRONOUS_PROCESSING: UInt32 = 8
KSPIN_FLAG_DO_NOT_INITIATE_PROCESSING: UInt32 = 16
KSPIN_FLAG_INITIATE_PROCESSING_ON_EVERY_ARRIVAL: UInt32 = 32
KSPIN_FLAG_FRAMES_NOT_REQUIRED_FOR_PROCESSING: UInt32 = 64
KSPIN_FLAG_ENFORCE_FIFO: UInt32 = 128
KSPIN_FLAG_GENERATE_MAPPINGS: UInt32 = 256
KSPIN_FLAG_DISTINCT_TRAILING_EDGE: UInt32 = 512
KSPIN_FLAG_PROCESS_IN_RUN_STATE_ONLY: UInt32 = 65536
KSPIN_FLAG_SPLITTER: UInt32 = 131072
KSPIN_FLAG_USE_STANDARD_TRANSPORT: UInt32 = 262144
KSPIN_FLAG_DO_NOT_USE_STANDARD_TRANSPORT: UInt32 = 524288
KSPIN_FLAG_FIXED_FORMAT: UInt32 = 1048576
KSPIN_FLAG_GENERATE_EOS_EVENTS: UInt32 = 2097152
KSPIN_FLAG_IMPLEMENT_CLOCK: UInt32 = 4194304
KSPIN_FLAG_SOME_FRAMES_REQUIRED_FOR_PROCESSING: UInt32 = 8388608
KSPIN_FLAG_PROCESS_IF_ANY_IN_RUN_STATE: UInt32 = 16777216
KSPIN_FLAG_DENY_USERMODE_ACCESS: UInt32 = 2147483648
RT_STRING: win32more.Windows.Win32.Foundation.PWSTR = 6
RT_RCDATA: win32more.Windows.Win32.Foundation.PWSTR = 10
WAVE_FORMAT_EXTENSIBLE: UInt32 = 65534
KSDSOUND_BUFFER_PRIMARY: UInt32 = 1
KSDSOUND_BUFFER_STATIC: UInt32 = 2
KSDSOUND_BUFFER_LOCHARDWARE: UInt32 = 4
KSDSOUND_BUFFER_LOCSOFTWARE: UInt32 = 8
KSDSOUND_BUFFER_CTRL_3D: UInt32 = 1
KSDSOUND_BUFFER_CTRL_FREQUENCY: UInt32 = 2
KSDSOUND_BUFFER_CTRL_PAN: UInt32 = 4
KSDSOUND_BUFFER_CTRL_VOLUME: UInt32 = 8
KSDSOUND_BUFFER_CTRL_POSITIONNOTIFY: UInt32 = 16
DEVPKEY_KsAudio_PacketSize_Constraints: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{13e004d6-b066-43bd-913b-a415cd13da87}'), pid=2)
DEVPKEY_KsAudio_Controller_DeviceInterface_Path: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{13e004d6-b066-43bd-913b-a415cd13da87}'), pid=3)
DEVPKEY_KsAudio_PacketSize_Constraints2: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{9404f781-7191-409b-8b0b-80bf6ec229ae}'), pid=2)
KSAUDIO_STEREO_SPEAKER_GEOMETRY_HEADPHONE: Int32 = -1
KSAUDIO_STEREO_SPEAKER_GEOMETRY_MIN: UInt32 = 5
KSAUDIO_STEREO_SPEAKER_GEOMETRY_NARROW: UInt32 = 10
KSAUDIO_STEREO_SPEAKER_GEOMETRY_WIDE: UInt32 = 20
KSAUDIO_STEREO_SPEAKER_GEOMETRY_MAX: UInt32 = 180
KSDSOUND_3D_MODE_NORMAL: UInt32 = 0
KSDSOUND_3D_MODE_HEADRELATIVE: UInt32 = 1
KSDSOUND_3D_MODE_DISABLE: UInt32 = 2
KSDSOUND_BUFFER_CTRL_HRTF_3D: UInt32 = 1073741824
KSAUDIO_QUALITY_WORST: UInt32 = 0
KSAUDIO_QUALITY_PC: UInt32 = 1
KSAUDIO_QUALITY_BASIC: UInt32 = 2
KSAUDIO_QUALITY_ADVANCED: UInt32 = 3
KSAUDIO_CPU_RESOURCES_NOT_HOST_CPU: UInt32 = 0
KSAUDIO_CPU_RESOURCES_HOST_CPU: UInt32 = 2147483647
SPEAKER_FRONT_LEFT: UInt32 = 1
SPEAKER_FRONT_RIGHT: UInt32 = 2
SPEAKER_FRONT_CENTER: UInt32 = 4
SPEAKER_LOW_FREQUENCY: UInt32 = 8
SPEAKER_BACK_LEFT: UInt32 = 16
SPEAKER_BACK_RIGHT: UInt32 = 32
SPEAKER_FRONT_LEFT_OF_CENTER: UInt32 = 64
SPEAKER_FRONT_RIGHT_OF_CENTER: UInt32 = 128
SPEAKER_BACK_CENTER: UInt32 = 256
SPEAKER_SIDE_LEFT: UInt32 = 512
SPEAKER_SIDE_RIGHT: UInt32 = 1024
SPEAKER_TOP_CENTER: UInt32 = 2048
SPEAKER_TOP_FRONT_LEFT: UInt32 = 4096
SPEAKER_TOP_FRONT_CENTER: UInt32 = 8192
SPEAKER_TOP_FRONT_RIGHT: UInt32 = 16384
SPEAKER_TOP_BACK_LEFT: UInt32 = 32768
SPEAKER_TOP_BACK_CENTER: UInt32 = 65536
SPEAKER_TOP_BACK_RIGHT: UInt32 = 131072
SPEAKER_RESERVED: UInt32 = 2147221504
SPEAKER_ALL: UInt32 = 2147483648
KSAUDIO_SPEAKER_DIRECTOUT: UInt32 = 0
KSAUDIO_SPEAKER_MONO: UInt32 = 4
KSAUDIO_SPEAKER_GROUND_FRONT_LEFT: UInt32 = 1
KSAUDIO_SPEAKER_GROUND_FRONT_CENTER: UInt32 = 4
KSAUDIO_SPEAKER_GROUND_FRONT_RIGHT: UInt32 = 2
KSAUDIO_SPEAKER_GROUND_REAR_LEFT: UInt32 = 16
KSAUDIO_SPEAKER_GROUND_REAR_RIGHT: UInt32 = 32
KSAUDIO_SPEAKER_TOP_MIDDLE: UInt32 = 2048
KSAUDIO_SPEAKER_SUPER_WOOFER: UInt32 = 8
KSNODEPIN_STANDARD_IN: UInt32 = 1
KSNODEPIN_STANDARD_OUT: UInt32 = 0
KSNODEPIN_SUM_MUX_IN: UInt32 = 1
KSNODEPIN_SUM_MUX_OUT: UInt32 = 0
KSNODEPIN_DEMUX_IN: UInt32 = 0
KSNODEPIN_DEMUX_OUT: UInt32 = 1
KSNODEPIN_AEC_RENDER_IN: UInt32 = 1
KSNODEPIN_AEC_RENDER_OUT: UInt32 = 0
KSNODEPIN_AEC_CAPTURE_IN: UInt32 = 2
KSNODEPIN_AEC_CAPTURE_OUT: UInt32 = 3
AEC_STATUS_FD_HISTORY_UNINITIALIZED: UInt32 = 0
AEC_STATUS_FD_HISTORY_CONTINUOUSLY_CONVERGED: UInt32 = 1
AEC_STATUS_FD_HISTORY_PREVIOUSLY_DIVERGED: UInt32 = 2
AEC_STATUS_FD_CURRENTLY_CONVERGED: UInt32 = 8
AEC_MODE_PASS_THROUGH: UInt32 = 0
AEC_MODE_HALF_DUPLEX: UInt32 = 1
AEC_MODE_FULL_DUPLEX: UInt32 = 2
KSPROPERTY_WAVE_QUEUED_POSITION: UInt32 = 1
KSMETHOD_WAVE_QUEUED_BREAKLOOP: UInt32 = 1
KSWAVE_COMPATCAPS_INPUT: UInt32 = 0
KSWAVE_COMPATCAPS_OUTPUT: UInt32 = 1
KSWAVE_BUFFER_ATTRIBUTEF_LOOPING: UInt32 = 1
KSWAVE_BUFFER_ATTRIBUTEF_STATIC: UInt32 = 2
SYSAUDIO_FLAGS_DONT_COMBINE_PINS: UInt32 = 1
SYSAUDIO_FLAGS_CLEAR_PREFERRED: UInt32 = 2
KSMPEGVIDMODE_PANSCAN: UInt32 = 1
KSMPEGVIDMODE_LTRBOX: UInt32 = 2
KSMPEGVIDMODE_SCALE: UInt32 = 4
KSAC3_ALTERNATE_AUDIO_1: UInt32 = 1
KSAC3_ALTERNATE_AUDIO_2: UInt32 = 2
KSAC3_ALTERNATE_AUDIO_BOTH: UInt32 = 3
KSAC3_SERVICE_MAIN_AUDIO: UInt32 = 0
KSAC3_SERVICE_NO_DIALOG: UInt32 = 1
KSAC3_SERVICE_VISUALLY_IMPAIRED: UInt32 = 2
KSAC3_SERVICE_HEARING_IMPAIRED: UInt32 = 3
KSAC3_SERVICE_DIALOG_ONLY: UInt32 = 4
KSAC3_SERVICE_COMMENTARY: UInt32 = 5
KSAC3_SERVICE_EMERGENCY_FLASH: UInt32 = 6
KSAC3_SERVICE_VOICE_OVER: UInt32 = 7
KSAUDDECOUTMODE_STEREO_ANALOG: UInt32 = 1
KSAUDDECOUTMODE_PCM_51: UInt32 = 2
KSAUDDECOUTMODE_SPDIFF: UInt32 = 4
KS_DVD_CGMS_RESERVED_MASK: UInt32 = 120
KS_DVD_CGMS_COPY_PROTECT_MASK: UInt32 = 24
KS_DVD_CGMS_COPY_PERMITTED: UInt32 = 0
KS_DVD_CGMS_COPY_ONCE: UInt32 = 16
KS_DVD_CGMS_NO_COPY: UInt32 = 24
KS_DVD_COPYRIGHT_MASK: UInt32 = 64
KS_DVD_NOT_COPYRIGHTED: UInt32 = 0
KS_DVD_COPYRIGHTED: UInt32 = 64
KS_DVD_SECTOR_PROTECT_MASK: UInt32 = 32
KS_DVD_SECTOR_NOT_PROTECTED: UInt32 = 0
KS_DVD_SECTOR_PROTECTED: UInt32 = 32
KS_BI_RGB: Int32 = 0
KS_BI_RLE8: Int32 = 1
KS_BI_RLE4: Int32 = 2
KS_BI_BITFIELDS: Int32 = 3
KS_BI_JPEG: Int32 = 4
KS_iPALETTE_COLORS: UInt32 = 256
KS_iEGA_COLORS: UInt32 = 16
KS_iMASK_COLORS: UInt32 = 3
KS_iTRUECOLOR: UInt32 = 16
KS_iRED: UInt32 = 0
KS_iGREEN: UInt32 = 1
KS_iBLUE: UInt32 = 2
KS_iPALETTE: UInt32 = 8
KS_iMAXBITS: UInt32 = 8
KS_VBIDATARATE_NABTS: Int32 = 5727272
KS_VBIDATARATE_CC: Int32 = 503493
KS_TVTUNER_CHANGE_BEGIN_TUNE: Int32 = 1
KS_TVTUNER_CHANGE_END_TUNE: Int32 = 2
KS_INTERLACE_IsInterlaced: UInt32 = 1
KS_INTERLACE_1FieldPerSample: UInt32 = 2
KS_INTERLACE_Field1First: UInt32 = 4
KS_INTERLACE_UNUSED: UInt32 = 8
KS_INTERLACE_FieldPatternMask: UInt32 = 48
KS_INTERLACE_FieldPatField1Only: UInt32 = 0
KS_INTERLACE_FieldPatField2Only: UInt32 = 16
KS_INTERLACE_FieldPatBothRegular: UInt32 = 32
KS_INTERLACE_FieldPatBothIrregular: UInt32 = 48
KS_INTERLACE_DisplayModeMask: UInt32 = 192
KS_INTERLACE_DisplayModeBobOnly: UInt32 = 0
KS_INTERLACE_DisplayModeWeaveOnly: UInt32 = 64
KS_INTERLACE_DisplayModeBobOrWeave: UInt32 = 128
KS_COPYPROTECT_RestrictDuplication: UInt32 = 1
KS_MPEG2_DoPanScan: UInt32 = 1
KS_MPEG2_DVDLine21Field1: UInt32 = 2
KS_MPEG2_DVDLine21Field2: UInt32 = 4
KS_MPEG2_SourceIsLetterboxed: UInt32 = 8
KS_MPEG2_FilmCameraMode: UInt32 = 16
KS_MPEG2_LetterboxAnalogOut: UInt32 = 32
KS_MPEG2_DSS_UserData: UInt32 = 64
KS_MPEG2_DVB_UserData: UInt32 = 128
KS_MPEG2_27MhzTimebase: UInt32 = 256
KS_MPEG2_WidescreenAnalogOut: UInt32 = 512
KS_AMCONTROL_USED: UInt32 = 1
KS_AMCONTROL_PAD_TO_4x3: UInt32 = 2
KS_AMCONTROL_PAD_TO_16x9: UInt32 = 4
KS_AMCONTROL_COLORINFO_PRESENT: UInt32 = 128
KS_MAX_SIZE_MPEG1_SEQUENCE_INFO: UInt32 = 140
KS_MPEGAUDIOINFO_27MhzTimebase: UInt32 = 1
KS_VIDEOSTREAM_PREVIEW: UInt32 = 1
KS_VIDEOSTREAM_CAPTURE: UInt32 = 2
KS_VIDEOSTREAM_VBI: UInt32 = 16
KS_VIDEOSTREAM_NABTS: UInt32 = 32
KS_VIDEOSTREAM_CC: UInt32 = 256
KS_VIDEOSTREAM_EDS: UInt32 = 512
KS_VIDEOSTREAM_TELETEXT: UInt32 = 1024
KS_VIDEOSTREAM_STILL: UInt32 = 4096
KS_VIDEOSTREAM_IS_VPE: UInt32 = 32768
KS_VIDEO_ALLOC_VPE_SYSTEM: UInt32 = 1
KS_VIDEO_ALLOC_VPE_DISPLAY: UInt32 = 2
KS_VIDEO_ALLOC_VPE_AGP: UInt32 = 4
KS_VBICAP_PROTECTION_MV_PRESENT: Int32 = 1
KS_VBICAP_PROTECTION_MV_HARDWARE: Int32 = 2
KS_VBICAP_PROTECTION_MV_DETECTED: Int32 = 4
KS_NABTS_GROUPID_ORIGINAL_CONTENT_BASE: UInt32 = 2048
KS_NABTS_GROUPID_ORIGINAL_CONTENT_ADVERTISER_BASE: UInt32 = 2064
KS_NABTS_GROUPID_PRODUCTION_COMPANY_CONTENT_BASE: UInt32 = 2080
KS_NABTS_GROUPID_PRODUCTION_COMPANY_ADVERTISER_BASE: UInt32 = 2096
KS_NABTS_GROUPID_SYNDICATED_SHOW_CONTENT_BASE: UInt32 = 2112
KS_NABTS_GROUPID_SYNDICATED_SHOW_ADVERTISER_BASE: UInt32 = 2128
KS_NABTS_GROUPID_NETWORK_WIDE_CONTENT_BASE: UInt32 = 2144
KS_NABTS_GROUPID_NETWORK_WIDE_ADVERTISER_BASE: UInt32 = 2160
KS_NABTS_GROUPID_TELEVISION_STATION_CONTENT_BASE: UInt32 = 2176
KS_NABTS_GROUPID_TELEVISION_STATION_ADVERTISER_BASE: UInt32 = 2192
KS_NABTS_GROUPID_LOCAL_CABLE_SYSTEM_CONTENT_BASE: UInt32 = 2208
KS_NABTS_GROUPID_LOCAL_CABLE_SYSTEM_ADVERTISER_BASE: UInt32 = 2224
KS_NABTS_GROUPID_MICROSOFT_RESERVED_TEST_DATA_BASE: UInt32 = 2288
MAX_NABTS_VBI_LINES_PER_FIELD: UInt32 = 11
NABTS_LINES_PER_BUNDLE: UInt32 = 16
NABTS_PAYLOAD_PER_LINE: UInt32 = 28
NABTS_BYTES_PER_LINE: UInt32 = 36
KS_CC_SUBSTREAM_ODD: Int32 = 1
KS_CC_SUBSTREAM_EVEN: Int32 = 2
KS_CC_SUBSTREAM_FIELD1_MASK: Int32 = 240
KS_CC_SUBSTREAM_SERVICE_CC1: Int32 = 16
KS_CC_SUBSTREAM_SERVICE_CC2: Int32 = 32
KS_CC_SUBSTREAM_SERVICE_T1: Int32 = 64
KS_CC_SUBSTREAM_SERVICE_T2: Int32 = 128
KS_CC_SUBSTREAM_FIELD2_MASK: Int32 = 7936
KS_CC_SUBSTREAM_SERVICE_CC3: Int32 = 256
KS_CC_SUBSTREAM_SERVICE_CC4: Int32 = 512
KS_CC_SUBSTREAM_SERVICE_T3: Int32 = 1024
KS_CC_SUBSTREAM_SERVICE_T4: Int32 = 2048
KS_CC_SUBSTREAM_SERVICE_XDS: Int32 = 4096
CC_MAX_HW_DECODE_LINES: UInt32 = 12
NABTS_BUFFER_PICTURENUMBER_SUPPORT: UInt32 = 1
WST_TVTUNER_CHANGE_BEGIN_TUNE: Int32 = 4096
WST_TVTUNER_CHANGE_END_TUNE: Int32 = 8192
MAX_WST_VBI_LINES_PER_FIELD: UInt32 = 17
WST_BYTES_PER_LINE: UInt32 = 42
KS_VIDEO_FLAG_FIELD_MASK: Int32 = 3
KS_VIDEO_FLAG_FRAME: Int32 = 0
KS_VIDEO_FLAG_FIELD1: Int32 = 1
KS_VIDEO_FLAG_FIELD2: Int32 = 2
KS_VIDEO_FLAG_FIELD1FIRST: Int32 = 4
KS_VIDEO_FLAG_WEAVE: Int32 = 8
KS_VIDEO_FLAG_IPB_MASK: Int32 = 48
KS_VIDEO_FLAG_I_FRAME: Int32 = 0
KS_VIDEO_FLAG_P_FRAME: Int32 = 16
KS_VIDEO_FLAG_B_FRAME: Int32 = 32
KS_VIDEO_FLAG_REPEAT_FIELD: Int32 = 64
KS_VBI_FLAG_FRAME: Int32 = 0
KS_VBI_FLAG_FIELD1: Int32 = 1
KS_VBI_FLAG_FIELD2: Int32 = 2
KS_VBI_FLAG_MV_PRESENT: Int32 = 256
KS_VBI_FLAG_MV_HARDWARE: Int32 = 512
KS_VBI_FLAG_MV_DETECTED: Int32 = 1024
KS_VBI_FLAG_TVTUNER_CHANGE: Int32 = 16
KS_VBI_FLAG_VBIINFOHEADER_CHANGE: Int32 = 32
KS_AnalogVideo_NTSC_Mask: UInt32 = 7
KS_AnalogVideo_PAL_Mask: UInt32 = 1052656
KS_AnalogVideo_SECAM_Mask: UInt32 = 1044480
KSPROPERTY_VIDEOPROCAMP_FLAGS_AUTO: Int32 = 1
KSPROPERTY_VIDEOPROCAMP_FLAGS_MANUAL: Int32 = 2
KSPROPERTY_CAMERACONTROL_FLAGS_AUTO: Int32 = 1
KSPROPERTY_CAMERACONTROL_FLAGS_MANUAL: Int32 = 2
KSPROPERTY_CAMERACONTROL_FLAGS_ASYNCHRONOUS: Int32 = 4
KSPROPERTY_CAMERACONTROL_FLAGS_ABSOLUTE: Int32 = 0
KSPROPERTY_CAMERACONTROL_FLAGS_RELATIVE: Int32 = 16
KSPROPERTY_CAMERACONTROL_FLASH_OFF: Int32 = 0
KSPROPERTY_CAMERACONTROL_FLASH_ON: Int32 = 1
KSPROPERTY_CAMERACONTROL_FLASH_AUTO: Int32 = 2
KSPROPERTY_CAMERACONTROL_FLASH_FLAGS_AUTO: Int32 = 1
KSPROPERTY_CAMERACONTROL_FLASH_FLAGS_MANUAL: Int32 = 2
KSPROPERTY_CAMERACONTROL_VIDEOSTABILIZATION_MODE_OFF: Int32 = 0
KSPROPERTY_CAMERACONTROL_VIDEOSTABILIZATION_MODE_HIGH: Int32 = 1
KSPROPERTY_CAMERACONTROL_VIDEOSTABILIZATION_MODE_MEDIUM: Int32 = 2
KSPROPERTY_CAMERACONTROL_VIDEOSTABILIZATION_MODE_LOW: Int32 = 3
KSPROPERTY_CAMERACONTROL_VIDEOSTABILIZATION_MODE_AUTO: Int32 = 4
KSPROPERTY_CAMERACONTROL_VIDEOSTABILIZATION_MODE_FLAGS_AUTO: Int32 = 1
KSPROPERTY_CAMERACONTROL_VIDEOSTABILIZATION_MODE_FLAGS_MANUAL: Int32 = 2
KSPROPERTY_CAMERACONTROL_REGION_OF_INTEREST_FLAGS_AUTO: Int32 = 1
KSPROPERTY_CAMERACONTROL_REGION_OF_INTEREST_FLAGS_MANUAL: Int32 = 2
KSPROPERTY_CAMERACONTROL_REGION_OF_INTEREST_FLAGS_ASYNC: Int32 = -2147483648
KSPROPERTY_CAMERACONTROL_REGION_OF_INTEREST_CONFIG_FOCUS: Int32 = 256
KSPROPERTY_CAMERACONTROL_REGION_OF_INTEREST_CONFIG_EXPOSURE: Int32 = 512
KSPROPERTY_CAMERACONTROL_REGION_OF_INTEREST_CONFIG_WB: Int32 = 1024
KSPROPERTY_CAMERACONTROL_REGION_OF_INTEREST_CONVERGEMODE: Int32 = 1073741824
KSPROPERTY_CAMERACONTROL_IMAGE_PIN_CAPABILITY_EXCLUSIVE_WITH_RECORD: Int32 = 1
KSPROPERTY_CAMERACONTROL_IMAGE_PIN_CAPABILITY_SEQUENCE_EXCLUSIVE_WITH_RECORD: Int32 = 2
KSCAMERA_EXTENDEDPROP_FILTERSCOPE: UInt32 = 4294967295
KSCAMERA_EXTENDEDPROP_CAPS_RESERVED: UInt64 = 18374686479671623680
KSCAMERA_EXTENDEDPROP_CAPS_ASYNCCONTROL: UInt64 = 9223372036854775808
KSCAMERA_EXTENDEDPROP_CAPS_CANCELLABLE: UInt64 = 4611686018427387904
KSCAMERA_EXTENDEDPROP_FLAG_CANCELOPERATION: UInt64 = 9223372036854775808
KSCAMERA_EXTENDEDPROP_CAPS_MASK: UInt64 = 18374686479671623680
KSCAMERA_EXTENDEDPROP_FLAG_MASK: UInt64 = 18374686479671623680
KSCAMERA_EXTENDEDPROP_PHOTOMODE_NORMAL: UInt64 = 0
KSCAMERA_EXTENDEDPROP_PHOTOMODE_SEQUENCE: UInt64 = 1
KSCAMERA_EXTENDEDPROP_WARMSTART_MODE_DISABLED: UInt64 = 0
KSCAMERA_EXTENDEDPROP_WARMSTART_MODE_ENABLED: UInt64 = 1
KSCAMERA_EXTENDEDPROP_PHOTOTHUMBNAIL_DISABLE: UInt64 = 0
KSCAMERA_EXTENDEDPROP_PHOTOTHUMBNAIL_2X: UInt64 = 1
KSCAMERA_EXTENDEDPROP_PHOTOTHUMBNAIL_4X: UInt64 = 2
KSCAMERA_EXTENDEDPROP_PHOTOTHUMBNAIL_8X: UInt64 = 4
KSCAMERA_EXTENDEDPROP_PHOTOTHUMBNAIL_16X: UInt64 = 8
KSCAMERA_EXTENDEDPROP_SCENEMODE_AUTO: UInt64 = 0
KSCAMERA_EXTENDEDPROP_SCENEMODE_MACRO: UInt64 = 1
KSCAMERA_EXTENDEDPROP_SCENEMODE_PORTRAIT: UInt64 = 2
KSCAMERA_EXTENDEDPROP_SCENEMODE_SPORT: UInt64 = 4
KSCAMERA_EXTENDEDPROP_SCENEMODE_SNOW: UInt64 = 8
KSCAMERA_EXTENDEDPROP_SCENEMODE_NIGHT: UInt64 = 16
KSCAMERA_EXTENDEDPROP_SCENEMODE_BEACH: UInt64 = 32
KSCAMERA_EXTENDEDPROP_SCENEMODE_SUNSET: UInt64 = 64
KSCAMERA_EXTENDEDPROP_SCENEMODE_CANDLELIGHT: UInt64 = 128
KSCAMERA_EXTENDEDPROP_SCENEMODE_LANDSCAPE: UInt64 = 256
KSCAMERA_EXTENDEDPROP_SCENEMODE_NIGHTPORTRAIT: UInt64 = 512
KSCAMERA_EXTENDEDPROP_SCENEMODE_BACKLIT: UInt64 = 1024
KSCAMERA_EXTENDEDPROP_SCENEMODE_MANUAL: UInt64 = 36028797018963968
KSCAMERA_EXTENDEDPROP_VIDEOTORCH_OFF: UInt64 = 0
KSCAMERA_EXTENDEDPROP_VIDEOTORCH_ON: UInt64 = 1
KSCAMERA_EXTENDEDPROP_VIDEOTORCH_ON_ADJUSTABLEPOWER: UInt64 = 2
KSCAMERA_EXTENDEDPROP_FLASH_OFF: UInt64 = 0
KSCAMERA_EXTENDEDPROP_FLASH_ON: UInt64 = 1
KSCAMERA_EXTENDEDPROP_FLASH_ON_ADJUSTABLEPOWER: UInt64 = 2
KSCAMERA_EXTENDEDPROP_FLASH_AUTO: UInt64 = 4
KSCAMERA_EXTENDEDPROP_FLASH_AUTO_ADJUSTABLEPOWER: UInt64 = 8
KSCAMERA_EXTENDEDPROP_FLASH_REDEYEREDUCTION: UInt64 = 16
KSCAMERA_EXTENDEDPROP_FLASH_SINGLEFLASH: UInt64 = 32
KSCAMERA_EXTENDEDPROP_FLASH_MULTIFLASHSUPPORTED: UInt64 = 64
KSCAMERA_EXTENDEDPROP_OPTIMIZATION_PHOTO: UInt64 = 1
KSCAMERA_EXTENDEDPROP_OPTIMIZATION_VIDEO: UInt64 = 2
KSCAMERA_EXTENDEDPROP_OPTIMIZATION_DEFAULT: UInt64 = 0
KSCAMERA_EXTENDEDPROP_OPTIMIZATION_QUALITY: UInt64 = 4
KSCAMERA_EXTENDEDPROP_OPTIMIZATION_LATENCY: UInt64 = 8
KSCAMERA_EXTENDEDPROP_OPTIMIZATION_POWER: UInt64 = 16
KSCAMERA_EXTENDEDPROP_VIDEOPROCFLAG_AUTO: UInt64 = 1
KSCAMERA_EXTENDEDPROP_VIDEOPROCFLAG_MANUAL: UInt64 = 2
KSCAMERA_EXTENDEDPROP_VIDEOPROCFLAG_LOCK: UInt64 = 4
KSCAMERA_EXTENDEDPROP_FOCUS_CONTINUOUS: UInt64 = 256
KSCAMERA_EXTENDEDPROP_FOCUS_RANGE_MACRO: UInt64 = 65536
KSCAMERA_EXTENDEDPROP_FOCUS_RANGE_NORMAL: UInt64 = 131072
KSCAMERA_EXTENDEDPROP_FOCUS_RANGE_FULLRANGE: UInt64 = 262144
KSCAMERA_EXTENDEDPROP_FOCUS_RANGE_INFINITY: UInt64 = 524288
KSCAMERA_EXTENDEDPROP_FOCUS_RANGE_HYPERFOCAL: UInt64 = 1048576
KSCAMERA_EXTENDEDPROP_FOCUS_DISTANCE_INFINITY: UInt64 = 16777216
KSCAMERA_EXTENDEDPROP_FOCUS_DISTANCE_HYPERFOCAL: UInt64 = 33554432
KSCAMERA_EXTENDEDPROP_FOCUS_DISTANCE_NEAREST: UInt64 = 67108864
KSCAMERA_EXTENDEDPROP_ISO_AUTO: UInt64 = 1
KSCAMERA_EXTENDEDPROP_ISO_50: UInt64 = 2
KSCAMERA_EXTENDEDPROP_ISO_80: UInt64 = 4
KSCAMERA_EXTENDEDPROP_ISO_100: UInt64 = 8
KSCAMERA_EXTENDEDPROP_ISO_200: UInt64 = 16
KSCAMERA_EXTENDEDPROP_ISO_400: UInt64 = 32
KSCAMERA_EXTENDEDPROP_ISO_800: UInt64 = 64
KSCAMERA_EXTENDEDPROP_ISO_1600: UInt64 = 128
KSCAMERA_EXTENDEDPROP_ISO_3200: UInt64 = 256
KSCAMERA_EXTENDEDPROP_ISO_6400: UInt64 = 512
KSCAMERA_EXTENDEDPROP_ISO_12800: UInt64 = 1024
KSCAMERA_EXTENDEDPROP_ISO_25600: UInt64 = 2048
KSCAMERA_EXTENDEDPROP_FOCUS_CONTINUOUSLOCK: UInt64 = 512
KSCAMERA_EXTENDEDPROP_FOCUS_UNLOCK: UInt64 = 1024
KSCAMERA_EXTENDEDPROP_FOCUS_DRIVERFALLBACK_OFF: UInt64 = 2048
KSCAMERA_EXTENDEDPROP_FOCUS_REGIONBASED: UInt64 = 4096
KSCAMERA_EXTENDEDPROP_ISO_MANUAL: UInt64 = 36028797018963968
KSCAMERA_EXTENDEDPROP_FLASH_ASSISTANT_OFF: UInt64 = 0
KSCAMERA_EXTENDEDPROP_FLASH_ASSISTANT_ON: UInt64 = 128
KSCAMERA_EXTENDEDPROP_FLASH_ASSISTANT_AUTO: UInt64 = 256
KSCAMERA_EXTENDEDPROP_EVCOMP_SIXTHSTEP: UInt64 = 1
KSCAMERA_EXTENDEDPROP_EVCOMP_QUARTERSTEP: UInt64 = 2
KSCAMERA_EXTENDEDPROP_EVCOMP_THIRDSTEP: UInt64 = 4
KSCAMERA_EXTENDEDPROP_EVCOMP_HALFSTEP: UInt64 = 8
KSCAMERA_EXTENDEDPROP_EVCOMP_FULLSTEP: UInt64 = 16
KSCAMERA_EXTENDEDPROP_PHOTOMODE_SEQUENCE_SUB_NONE: UInt32 = 0
KSCAMERA_EXTENDEDPROP_PHOTOMODE_SEQUENCE_SUB_VARIABLE: UInt32 = 1
KSCAMERA_EXTENDEDPROP_METADATA_MEMORYTYPE_MASK: UInt64 = 255
KSCAMERA_EXTENDEDPROP_METADATA_SYSTEMMEMORY: UInt64 = 1
KSCAMERA_EXTENDEDPROP_METADATA_ALIGNMENTREQUIRED: UInt64 = 256
KSCAMERA_METADATA_FRAMEILLUMINATION_FLAG_ON: UInt32 = 1
KSCAMERA_METADATA_CAPTURESTATS_FLAG_EXPOSURETIME: UInt32 = 1
KSCAMERA_METADATA_CAPTURESTATS_FLAG_EXPOSURECOMPENSATION: UInt32 = 2
KSCAMERA_METADATA_CAPTURESTATS_FLAG_ISOSPEED: UInt32 = 4
KSCAMERA_METADATA_CAPTURESTATS_FLAG_FOCUSSTATE: UInt32 = 8
KSCAMERA_METADATA_CAPTURESTATS_FLAG_LENSPOSITION: UInt32 = 16
KSCAMERA_METADATA_CAPTURESTATS_FLAG_WHITEBALANCE: UInt32 = 32
KSCAMERA_METADATA_CAPTURESTATS_FLAG_FLASH: UInt32 = 64
KSCAMERA_METADATA_CAPTURESTATS_FLAG_FLASHPOWER: UInt32 = 128
KSCAMERA_METADATA_CAPTURESTATS_FLAG_ZOOMFACTOR: UInt32 = 256
KSCAMERA_METADATA_CAPTURESTATS_FLAG_SCENEMODE: UInt32 = 512
KSCAMERA_METADATA_CAPTURESTATS_FLAG_SENSORFRAMERATE: UInt32 = 1024
KSCAMERA_EXTENDEDPROP_FOCUSPRIORITY_OFF: UInt64 = 0
KSCAMERA_EXTENDEDPROP_FOCUSPRIORITY_ON: UInt64 = 1
KSCAMERA_EXTENDEDPROP_PHOTOCONFIRMATION_OFF: UInt64 = 0
KSCAMERA_EXTENDEDPROP_PHOTOCONFIRMATION_ON: UInt64 = 1
KSCAMERA_PERFRAMESETTING_AUTO: UInt64 = 4294967296
KSCAMERA_PERFRAMESETTING_MANUAL: UInt64 = 8589934592
KSCAMERA_EXTENDEDPROP_VIDEOSTABILIZATION_OFF: UInt64 = 0
KSCAMERA_EXTENDEDPROP_VIDEOSTABILIZATION_ON: UInt64 = 1
KSCAMERA_EXTENDEDPROP_VIDEOSTABILIZATION_AUTO: UInt64 = 2
KSCAMERA_EXTENDEDPROP_VFR_OFF: UInt64 = 0
KSCAMERA_EXTENDEDPROP_VFR_ON: UInt64 = 1
KSCAMERA_EXTENDEDPROP_FACEDETECTION_OFF: UInt64 = 0
KSCAMERA_EXTENDEDPROP_FACEDETECTION_ON: UInt64 = 1
KSCAMERA_EXTENDEDPROP_FACEDETECTION_PREVIEW: UInt64 = 1
KSCAMERA_EXTENDEDPROP_FACEDETECTION_VIDEO: UInt64 = 2
KSCAMERA_EXTENDEDPROP_FACEDETECTION_PHOTO: UInt64 = 4
KSCAMERA_EXTENDEDPROP_FACEDETECTION_BLINK: UInt64 = 8
KSCAMERA_EXTENDEDPROP_FACEDETECTION_SMILE: UInt64 = 16
KSCAMERA_EXTENDEDPROP_VIDEOHDR_OFF: UInt64 = 0
KSCAMERA_EXTENDEDPROP_VIDEOHDR_ON: UInt64 = 1
KSCAMERA_EXTENDEDPROP_VIDEOHDR_AUTO: UInt64 = 2
KSCAMERA_EXTENDEDPROP_HISTOGRAM_OFF: UInt64 = 0
KSCAMERA_EXTENDEDPROP_HISTOGRAM_ON: UInt64 = 1
KSCAMERA_EXTENDEDPROP_OIS_OFF: UInt64 = 0
KSCAMERA_EXTENDEDPROP_OIS_ON: UInt64 = 1
KSCAMERA_EXTENDEDPROP_OIS_AUTO: UInt64 = 2
KSCAMERA_EXTENDEDPROP_ADVANCEDPHOTO_OFF: UInt64 = 0
KSCAMERA_EXTENDEDPROP_ADVANCEDPHOTO_AUTO: UInt64 = 1
KSCAMERA_EXTENDEDPROP_ADVANCEDPHOTO_HDR: UInt64 = 2
KSCAMERA_EXTENDEDPROP_ADVANCEDPHOTO_FNF: UInt64 = 4
KSCAMERA_EXTENDEDPROP_ADVANCEDPHOTO_ULTRALOWLIGHT: UInt64 = 8
KSCAMERA_EXTENDEDPROP_ZOOM_DEFAULT: UInt64 = 0
KSCAMERA_EXTENDEDPROP_ZOOM_DIRECT: UInt64 = 1
KSCAMERA_EXTENDEDPROP_ZOOM_SMOOTH: UInt64 = 2
KSCAMERA_EXTENDEDPROP_FACEAUTH_MODE_DISABLED: UInt64 = 1
KSCAMERA_EXTENDEDPROP_FACEAUTH_MODE_ALTERNATIVE_FRAME_ILLUMINATION: UInt64 = 2
KSCAMERA_EXTENDEDPROP_FACEAUTH_MODE_BACKGROUND_SUBTRACTION: UInt64 = 4
KSCAMERA_EXTENDEDPROP_SECUREMODE_DISABLED: UInt64 = 1
KSCAMERA_EXTENDEDPROP_SECUREMODE_ENABLED: UInt64 = 2
KSCAMERA_EXTENDEDPROP_VIDEOTEMPORALDENOISING_AUTO: UInt64 = 1
KSCAMERA_EXTENDEDPROP_VIDEOTEMPORALDENOISING_OFF: UInt64 = 2
KSCAMERA_EXTENDEDPROP_VIDEOTEMPORALDENOISING_ON: UInt64 = 4
KSCAMERA_EXTENDEDPROP_IRTORCHMODE_OFF: UInt64 = 1
KSCAMERA_EXTENDEDPROP_IRTORCHMODE_ALWAYS_ON: UInt64 = 2
KSCAMERA_EXTENDEDPROP_IRTORCHMODE_ALTERNATING_FRAME_ILLUMINATION: UInt64 = 4
KSCAMERA_EXTENDEDPROP_RELATIVEPANELOPTIMIZATION_OFF: UInt64 = 0
KSCAMERA_EXTENDEDPROP_RELATIVEPANELOPTIMIZATION_ON: UInt64 = 1
KSCAMERA_EXTENDEDPROP_RELATIVEPANELOPTIMIZATION_DYNAMIC: UInt64 = 2
KSCAMERA_EXTENDEDPROP_EYEGAZECORRECTION_OFF: UInt64 = 0
KSCAMERA_EXTENDEDPROP_EYEGAZECORRECTION_ON: UInt64 = 1
KSCAMERA_EXTENDEDPROP_EYEGAZECORRECTION_STARE: UInt64 = 2
KSCAMERA_EXTENDEDPROP_BACKGROUNDSEGMENTATION_OFF: UInt64 = 0
KSCAMERA_EXTENDEDPROP_BACKGROUNDSEGMENTATION_BLUR: UInt64 = 1
KSCAMERA_EXTENDEDPROP_BACKGROUNDSEGMENTATION_MASK: UInt64 = 2
KSCAMERA_EXTENDEDPROP_BACKGROUNDSEGMENTATION_SHALLOWFOCUS: UInt64 = 4
KSCAMERA_EXTENDEDPROP_DIGITALWINDOW_MANUAL: UInt64 = 0
KSCAMERA_EXTENDEDPROP_DIGITALWINDOW_AUTOFACEFRAMING: UInt64 = 1
KSCAMERAPROFILE_FLAGS_VIDEOSTABLIZATION: UInt64 = 1
KSCAMERAPROFILE_FLAGS_VIDEOHDR: UInt64 = 2
KSCAMERAPROFILE_FLAGS_PHOTOHDR: UInt64 = 4
KSCAMERAPROFILE_FLAGS_FACEDETECTION: UInt64 = 8
KSCAMERAPROFILE_FLAGS_VARIABLEPHOTOSEQUENCE: UInt64 = 16
KSCAMERAPROFILE_FLAGS_PREVIEW_RES_MUSTMATCH: UInt64 = 32
KSDEVICE_PROFILE_TYPE_UNKNOWN: UInt32 = 0
KSDEVICE_PROFILE_TYPE_CAMERA: UInt32 = 1
KSCameraProfileSensorType_RGB: UInt32 = 1
KSCameraProfileSensorType_Infrared: UInt32 = 2
KSCameraProfileSensorType_Depth: UInt32 = 4
KSCameraProfileSensorType_PoseTracking: UInt32 = 8
KSCameraProfileSensorType_ImageSegmentation: UInt32 = 16
KSCameraProfileSensorType_Custom: UInt32 = 128
KS_TVAUDIO_MODE_MONO: UInt32 = 1
KS_TVAUDIO_MODE_STEREO: UInt32 = 2
KS_TVAUDIO_MODE_LANG_A: UInt32 = 16
KS_TVAUDIO_MODE_LANG_B: UInt32 = 32
KS_TVAUDIO_MODE_LANG_C: UInt32 = 64
KS_TVAUDIO_PRESET_STEREO: UInt32 = 512
KS_TVAUDIO_PRESET_LANG_A: UInt32 = 4096
KS_TVAUDIO_PRESET_LANG_B: UInt32 = 8192
KS_TVAUDIO_PRESET_LANG_C: UInt32 = 16384
KS_AM_UseNewCSSKey: Int32 = 1
MAX_SINK_DESCRIPTION_NAME_LENGTH: UInt32 = 32
JACKDESC2_PRESENCE_DETECT_CAPABILITY: UInt32 = 1
JACKDESC2_DYNAMIC_FORMAT_CHANGE_CAPABILITY: UInt32 = 2
KSPROPERTY_AUDIO_BUFFER_DURATION: UInt32 = 1
MAX_RESOURCEGROUPID_LENGTH: UInt32 = 256
AUDIOMODULE_MAX_DATA_SIZE: UInt32 = 64000
AUDIOMODULE_MAX_NAME_CCH_SIZE: UInt32 = 128
AllocatorStrategy_DontCare: UInt32 = 0
AllocatorStrategy_MinimizeNumberOfFrames: UInt32 = 1
AllocatorStrategy_MinimizeFrameSize: UInt32 = 2
AllocatorStrategy_MinimizeNumberOfAllocators: UInt32 = 4
AllocatorStrategy_MaximizeSpeed: UInt32 = 8
PipeFactor_None: UInt32 = 0
PipeFactor_UserModeUpstream: UInt32 = 1
PipeFactor_UserModeDownstream: UInt32 = 2
PipeFactor_MemoryTypes: UInt32 = 4
PipeFactor_Flags: UInt32 = 8
PipeFactor_PhysicalRanges: UInt32 = 16
PipeFactor_OptimalRanges: UInt32 = 32
PipeFactor_FixedCompression: UInt32 = 64
PipeFactor_UnknownCompression: UInt32 = 128
PipeFactor_Buffers: UInt32 = 256
PipeFactor_Align: UInt32 = 512
PipeFactor_PhysicalEnd: UInt32 = 1024
PipeFactor_LogicalEnd: UInt32 = 2048
KSPROPERTY_MEMORY_TRANSPORT: Int32 = 1
@winfunctype('ksuser.dll')
def KsCreateAllocator(ConnectionHandle: win32more.Windows.Win32.Foundation.HANDLE, AllocatorFraming: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSALLOCATOR_FRAMING), AllocatorHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('ksuser.dll')
def KsCreateClock(ConnectionHandle: win32more.Windows.Win32.Foundation.HANDLE, ClockCreate: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSCLOCK_CREATE), ClockHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('ksuser.dll')
def KsCreatePin(FilterHandle: win32more.Windows.Win32.Foundation.HANDLE, Connect: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSPIN_CONNECT), DesiredAccess: UInt32, ConnectionHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('ksuser.dll')
def KsCreateTopologyNode(ParentHandle: win32more.Windows.Win32.Foundation.HANDLE, NodeCreate: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSNODE_CREATE), DesiredAccess: UInt32, NodeHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('ksuser.dll')
def KsCreateAllocator2(ConnectionHandle: win32more.Windows.Win32.Foundation.HANDLE, AllocatorFraming: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSALLOCATOR_FRAMING), AllocatorHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('ksuser.dll')
def KsCreateClock2(ConnectionHandle: win32more.Windows.Win32.Foundation.HANDLE, ClockCreate: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSCLOCK_CREATE), ClockHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('ksuser.dll')
def KsCreatePin2(FilterHandle: win32more.Windows.Win32.Foundation.HANDLE, Connect: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSPIN_CONNECT), DesiredAccess: UInt32, ConnectionHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('ksuser.dll')
def KsCreateTopologyNode2(ParentHandle: win32more.Windows.Win32.Foundation.HANDLE, NodeCreate: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSNODE_CREATE), DesiredAccess: UInt32, NodeHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('ksproxy.ax')
def KsResolveRequiredAttributes(DataRange: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT), Attributes: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSMULTIPLE_ITEM)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('ksproxy.ax')
def KsOpenDefaultDevice(Category: POINTER(Guid), Access: UInt32, DeviceHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('ksproxy.ax')
def KsSynchronousDeviceControl(Handle: win32more.Windows.Win32.Foundation.HANDLE, IoControl: UInt32, InBuffer: VoidPtr, InLength: UInt32, OutBuffer: VoidPtr, OutLength: UInt32, BytesReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('ksproxy.ax')
def KsGetMultiplePinFactoryItems(FilterHandle: win32more.Windows.Win32.Foundation.HANDLE, PinFactoryId: UInt32, PropertyId: UInt32, Items: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('ksproxy.ax')
def KsGetMediaTypeCount(FilterHandle: win32more.Windows.Win32.Foundation.HANDLE, PinFactoryId: UInt32, MediaTypeCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('ksproxy.ax')
def KsGetMediaType(Position: Int32, AmMediaType: POINTER(win32more.Windows.Win32.Media.MediaFoundation.AM_MEDIA_TYPE), FilterHandle: win32more.Windows.Win32.Foundation.HANDLE, PinFactoryId: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
BLUETOOTHLE_MIDI_SERVICE_UUID = Guid('{03b80e5a-ede8-4b33-a751-6ce34ec4c700}')
BLUETOOTH_MIDI_DATAIO_CHARACTERISTIC = Guid('{7772e5db-3868-4112-a1a9-f2669d106bf3}')
CAPTURE_MEMORY_ALLOCATION_FLAGS = Int32
KS_CAPTURE_ALLOC_INVALID: win32more.Windows.Win32.Media.KernelStreaming.CAPTURE_MEMORY_ALLOCATION_FLAGS = 0
KS_CAPTURE_ALLOC_SYSTEM: win32more.Windows.Win32.Media.KernelStreaming.CAPTURE_MEMORY_ALLOCATION_FLAGS = 1
KS_CAPTURE_ALLOC_VRAM: win32more.Windows.Win32.Media.KernelStreaming.CAPTURE_MEMORY_ALLOCATION_FLAGS = 2
KS_CAPTURE_ALLOC_SYSTEM_AGP: win32more.Windows.Win32.Media.KernelStreaming.CAPTURE_MEMORY_ALLOCATION_FLAGS = 4
KS_CAPTURE_ALLOC_VRAM_MAPPED: win32more.Windows.Win32.Media.KernelStreaming.CAPTURE_MEMORY_ALLOCATION_FLAGS = 8
KS_CAPTURE_ALLOC_SECURE_BUFFER: win32more.Windows.Win32.Media.KernelStreaming.CAPTURE_MEMORY_ALLOCATION_FLAGS = 16
class CC_BYTE_PAIR(Structure):
    Decoded: Byte * 2
    Reserved: UInt16
class CC_HW_FIELD(Structure):
    ScanlinesRequested: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_SCANLINES
    fieldFlags: UInt32
    PictureNumber: Int64
    Lines: win32more.Windows.Win32.Media.KernelStreaming.CC_BYTE_PAIR * 12
CLSID_KsIBasicAudioInterfaceHandler = Guid('{b9f8ac3e-0f71-11d2-b72c-00c04fb6bd3d}')
CLSID_Proxy = Guid('{17cca71b-ecd7-11d0-b908-00a0c9223196}')
CONSTRICTOR_OPTION = Int32
CONSTRICTOR_OPTION_DISABLE: win32more.Windows.Win32.Media.KernelStreaming.CONSTRICTOR_OPTION = 0
CONSTRICTOR_OPTION_MUTE: win32more.Windows.Win32.Media.KernelStreaming.CONSTRICTOR_OPTION = 1
class DEVCAPS(Structure):
    CanRecord: Int32
    CanRecordStrobe: Int32
    HasAudio: Int32
    HasVideo: Int32
    UsesFiles: Int32
    CanSave: Int32
    DeviceType: Int32
    TCRead: Int32
    TCWrite: Int32
    CTLRead: Int32
    IndexRead: Int32
    Preroll: Int32
    Postroll: Int32
    SyncAcc: Int32
    NormRate: Int32
    CanPreview: Int32
    CanMonitorSrc: Int32
    CanTest: Int32
    VideoIn: Int32
    AudioIn: Int32
    Calibrate: Int32
    SeekType: Int32
    SimulatedHardware: Int32
class DS3DVECTOR(Structure):
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    Anonymous3: _Anonymous3_e__Union
    class _Anonymous1_e__Union(Union):
        x: Single
        dvX: Single
    class _Anonymous2_e__Union(Union):
        y: Single
        dvY: Single
    class _Anonymous3_e__Union(Union):
        z: Single
        dvZ: Single
EDeviceControlUseType = Int32
eDeviceControlUseMissing: win32more.Windows.Win32.Media.KernelStreaming.EDeviceControlUseType = 0
eDeviceControlUsePrimary: win32more.Windows.Win32.Media.KernelStreaming.EDeviceControlUseType = 1
eDeviceControlUseSecondary: win32more.Windows.Win32.Media.KernelStreaming.EDeviceControlUseType = 2
EPcxConnectionType = Int32
eConnTypeUnknown: win32more.Windows.Win32.Media.KernelStreaming.EPcxConnectionType = 0
eConnType3Point5mm: win32more.Windows.Win32.Media.KernelStreaming.EPcxConnectionType = 1
eConnTypeQuarter: win32more.Windows.Win32.Media.KernelStreaming.EPcxConnectionType = 2
eConnTypeAtapiInternal: win32more.Windows.Win32.Media.KernelStreaming.EPcxConnectionType = 3
eConnTypeRCA: win32more.Windows.Win32.Media.KernelStreaming.EPcxConnectionType = 4
eConnTypeOptical: win32more.Windows.Win32.Media.KernelStreaming.EPcxConnectionType = 5
eConnTypeOtherDigital: win32more.Windows.Win32.Media.KernelStreaming.EPcxConnectionType = 6
eConnTypeOtherAnalog: win32more.Windows.Win32.Media.KernelStreaming.EPcxConnectionType = 7
eConnTypeMultichannelAnalogDIN: win32more.Windows.Win32.Media.KernelStreaming.EPcxConnectionType = 8
eConnTypeXlrProfessional: win32more.Windows.Win32.Media.KernelStreaming.EPcxConnectionType = 9
eConnTypeRJ11Modem: win32more.Windows.Win32.Media.KernelStreaming.EPcxConnectionType = 10
eConnTypeCombination: win32more.Windows.Win32.Media.KernelStreaming.EPcxConnectionType = 11
EPcxGenLocation = Int32
eGenLocPrimaryBox: win32more.Windows.Win32.Media.KernelStreaming.EPcxGenLocation = 0
eGenLocInternal: win32more.Windows.Win32.Media.KernelStreaming.EPcxGenLocation = 1
eGenLocSeparate: win32more.Windows.Win32.Media.KernelStreaming.EPcxGenLocation = 2
eGenLocOther: win32more.Windows.Win32.Media.KernelStreaming.EPcxGenLocation = 3
EPcxGenLocation_enum_count: win32more.Windows.Win32.Media.KernelStreaming.EPcxGenLocation = 4
EPcxGeoLocation = Int32
eGeoLocRear: win32more.Windows.Win32.Media.KernelStreaming.EPcxGeoLocation = 1
eGeoLocFront: win32more.Windows.Win32.Media.KernelStreaming.EPcxGeoLocation = 2
eGeoLocLeft: win32more.Windows.Win32.Media.KernelStreaming.EPcxGeoLocation = 3
eGeoLocRight: win32more.Windows.Win32.Media.KernelStreaming.EPcxGeoLocation = 4
eGeoLocTop: win32more.Windows.Win32.Media.KernelStreaming.EPcxGeoLocation = 5
eGeoLocBottom: win32more.Windows.Win32.Media.KernelStreaming.EPcxGeoLocation = 6
eGeoLocRearPanel: win32more.Windows.Win32.Media.KernelStreaming.EPcxGeoLocation = 7
eGeoLocRiser: win32more.Windows.Win32.Media.KernelStreaming.EPcxGeoLocation = 8
eGeoLocInsideMobileLid: win32more.Windows.Win32.Media.KernelStreaming.EPcxGeoLocation = 9
eGeoLocDrivebay: win32more.Windows.Win32.Media.KernelStreaming.EPcxGeoLocation = 10
eGeoLocHDMI: win32more.Windows.Win32.Media.KernelStreaming.EPcxGeoLocation = 11
eGeoLocOutsideMobileLid: win32more.Windows.Win32.Media.KernelStreaming.EPcxGeoLocation = 12
eGeoLocATAPI: win32more.Windows.Win32.Media.KernelStreaming.EPcxGeoLocation = 13
eGeoLocNotApplicable: win32more.Windows.Win32.Media.KernelStreaming.EPcxGeoLocation = 14
eGeoLocReserved6: win32more.Windows.Win32.Media.KernelStreaming.EPcxGeoLocation = 15
EPcxGeoLocation_enum_count: win32more.Windows.Win32.Media.KernelStreaming.EPcxGeoLocation = 16
EPxcPortConnection = Int32
ePortConnJack: win32more.Windows.Win32.Media.KernelStreaming.EPxcPortConnection = 0
ePortConnIntegratedDevice: win32more.Windows.Win32.Media.KernelStreaming.EPxcPortConnection = 1
ePortConnBothIntegratedAndJack: win32more.Windows.Win32.Media.KernelStreaming.EPxcPortConnection = 2
ePortConnUnknown: win32more.Windows.Win32.Media.KernelStreaming.EPxcPortConnection = 3
EVENTSETID_CROSSBAR = Guid('{6a2e0641-28e4-11d0-a18c-00a0c9118956}')
EVENTSETID_TUNER = Guid('{6a2e0606-28e4-11d0-a18c-00a0c9118956}')
EVENTSETID_VIDCAP_CAMERACONTROL_REGION_OF_INTEREST = Guid('{2fdffc5d-c732-4ba6-b5df-6b4d7fc88b8b}')
EVENTSETID_VIDEODECODER = Guid('{6a2e0621-28e4-11d0-a18c-00a0c9118956}')
FRAMING_CACHE_OPS = Int32
Framing_Cache_Update: win32more.Windows.Win32.Media.KernelStreaming.FRAMING_CACHE_OPS = 0
Framing_Cache_ReadLast: win32more.Windows.Win32.Media.KernelStreaming.FRAMING_CACHE_OPS = 1
Framing_Cache_ReadOrig: win32more.Windows.Win32.Media.KernelStreaming.FRAMING_CACHE_OPS = 2
Framing_Cache_Write: win32more.Windows.Win32.Media.KernelStreaming.FRAMING_CACHE_OPS = 3
FRAMING_PROP = Int32
FramingProp_Uninitialized: win32more.Windows.Win32.Media.KernelStreaming.FRAMING_PROP = 0
FramingProp_None: win32more.Windows.Win32.Media.KernelStreaming.FRAMING_PROP = 1
FramingProp_Old: win32more.Windows.Win32.Media.KernelStreaming.FRAMING_PROP = 2
FramingProp_Ex: win32more.Windows.Win32.Media.KernelStreaming.FRAMING_PROP = 3
GUID_NULL = Guid('{00000000-0000-0000-0000-000000000000}')
class IKsAggregateControl(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7f40eac0-3947-11d2-874e-00a0c9223196}')
    @commethod(3)
    def KsAddAggregate(self, AggregateClass: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def KsRemoveAggregate(self, AggregateClass: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsAllocator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8da64899-c0d9-11d0-8413-0000f822fe8a}')
    @commethod(3)
    def KsGetAllocatorHandle(self) -> win32more.Windows.Win32.Foundation.HANDLE: ...
    @commethod(4)
    def KsGetAllocatorMode(self) -> win32more.Windows.Win32.Media.KernelStreaming.KSALLOCATORMODE: ...
    @commethod(5)
    def KsGetAllocatorStatus(self, AllocatorStatus: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSSTREAMALLOCATOR_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def KsSetAllocatorMode(self, Mode: win32more.Windows.Win32.Media.KernelStreaming.KSALLOCATORMODE) -> Void: ...
class IKsAllocatorEx(ComPtr):
    extends: win32more.Windows.Win32.Media.KernelStreaming.IKsAllocator
    _iid_ = Guid('{091bb63a-603f-11d1-b067-00a0c9062802}')
    @commethod(7)
    def KsGetProperties(self) -> POINTER(win32more.Windows.Win32.Media.KernelStreaming.ALLOCATOR_PROPERTIES_EX): ...
    @commethod(8)
    def KsSetProperties(self, param0: POINTER(win32more.Windows.Win32.Media.KernelStreaming.ALLOCATOR_PROPERTIES_EX)) -> Void: ...
    @commethod(9)
    def KsSetAllocatorHandle(self, AllocatorHandle: win32more.Windows.Win32.Foundation.HANDLE) -> Void: ...
    @commethod(10)
    def KsCreateAllocatorAndGetHandle(self, KsPin: win32more.Windows.Win32.Media.KernelStreaming.IKsPin) -> win32more.Windows.Win32.Foundation.HANDLE: ...
class IKsClockPropertySet(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5c5cbd84-e755-11d0-ac18-00a0c9223196}')
    @commethod(3)
    def KsGetTime(self, Time: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def KsSetTime(self, Time: Int64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def KsGetPhysicalTime(self, Time: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def KsSetPhysicalTime(self, Time: Int64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def KsGetCorrelatedTime(self, CorrelatedTime: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSCORRELATED_TIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def KsSetCorrelatedTime(self, CorrelatedTime: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSCORRELATED_TIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def KsGetCorrelatedPhysicalTime(self, CorrelatedTime: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSCORRELATED_TIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def KsSetCorrelatedPhysicalTime(self, CorrelatedTime: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSCORRELATED_TIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def KsGetResolution(self, Resolution: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSRESOLUTION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def KsGetState(self, State: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSSTATE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsControl(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{28f54685-06fd-11d2-b27a-00a0c9223196}')
    @commethod(3)
    def KsProperty(self, Property: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER), PropertyLength: UInt32, PropertyData: VoidPtr, DataLength: UInt32, BytesReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def KsMethod(self, Method: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER), MethodLength: UInt32, MethodData: VoidPtr, DataLength: UInt32, BytesReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def KsEvent(self, Event: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER), EventLength: UInt32, EventData: VoidPtr, DataLength: UInt32, BytesReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsDataTypeCompletion(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{827d1a0e-0f73-11d2-b27a-00a0c9223196}')
    @commethod(3)
    def KsCompleteMediaType(self, FilterHandle: win32more.Windows.Win32.Foundation.HANDLE, PinFactoryId: UInt32, AmMediaType: POINTER(win32more.Windows.Win32.Media.MediaFoundation.AM_MEDIA_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsDataTypeHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5ffbaa02-49a3-11d0-9f36-00aa00a216a1}')
    @commethod(3)
    def KsCompleteIoOperation(self, Sample: win32more.Windows.Win32.Media.DirectShow.IMediaSample, StreamHeader: VoidPtr, IoOperation: win32more.Windows.Win32.Media.KernelStreaming.KSIOOPERATION, Cancelled: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def KsIsMediaTypeInRanges(self, DataRanges: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def KsPrepareIoOperation(self, Sample: win32more.Windows.Win32.Media.DirectShow.IMediaSample, StreamHeader: VoidPtr, IoOperation: win32more.Windows.Win32.Media.KernelStreaming.KSIOOPERATION) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def KsQueryExtendedSize(self, ExtendedSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def KsSetMediaType(self, AmMediaType: POINTER(win32more.Windows.Win32.Media.MediaFoundation.AM_MEDIA_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsFormatSupport(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3cb4a69d-bb6f-4d2b-95b7-452d2c155db5}')
    @commethod(3)
    def IsFormatSupported(self, pKsFormat: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT), cbFormat: UInt32, pbSupported: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDevicePreferredFormat(self, ppKsFormat: POINTER(POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsInterfaceHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d3abc7e0-9a61-11d0-a40d-00a0c9223196}')
    @commethod(3)
    def KsSetPin(self, KsPin: win32more.Windows.Win32.Media.KernelStreaming.IKsPin) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def KsProcessMediaSamples(self, KsDataTypeHandler: win32more.Windows.Win32.Media.KernelStreaming.IKsDataTypeHandler, SampleList: POINTER(win32more.Windows.Win32.Media.DirectShow.IMediaSample), SampleCount: POINTER(Int32), IoOperation: win32more.Windows.Win32.Media.KernelStreaming.KSIOOPERATION, StreamSegment: POINTER(POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSSTREAM_SEGMENT))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def KsCompleteIo(self, StreamSegment: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSSTREAM_SEGMENT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsJackContainerId(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c99af463-d629-4ec4-8c00-e54d68154248}')
    @commethod(3)
    def GetJackContainerId(self, pJackContainerId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsJackDescription(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4509f757-2d46-4637-8e62-ce7db944f57b}')
    @commethod(3)
    def GetJackCount(self, pcJacks: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetJackDescription(self, nJack: UInt32, pDescription: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSJACK_DESCRIPTION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsJackDescription2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{478f3a9b-e0c9-4827-9228-6f5505ffe76a}')
    @commethod(3)
    def GetJackCount(self, pcJacks: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetJackDescription2(self, nJack: UInt32, pDescription2: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSJACK_DESCRIPTION2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsJackDescription3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e3f6778b-6660-4cc8-a291-ecc4192d9967}')
    @commethod(3)
    def GetJackCount(self, pcJacks: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetJackDescription3(self, nJack: UInt32, pDescription3: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSJACK_DESCRIPTION3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsJackSinkInformation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d9bd72ed-290f-4581-9ff3-61027a8fe532}')
    @commethod(3)
    def GetJackSinkInformation(self, pJackSinkInformation: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSJACK_SINK_INFORMATION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsNodeControl(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{11737c14-24a7-4bb5-81a0-0d003813b0c4}')
    @commethod(3)
    def put_NodeId(self, dwNodeId: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def put_KsControl(self, pKsControl: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsNotifyEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{412bd695-f84b-46c1-ac73-54196dbc8fa7}')
    @commethod(3)
    def KsNotifyEvent(self, Event: UInt32, lParam1: UIntPtr, lParam2: UIntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsObject(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{423c13a2-2070-11d0-9ef7-00aa00a216a1}')
    @commethod(3)
    def KsGetObjectHandle(self) -> win32more.Windows.Win32.Foundation.HANDLE: ...
class IKsPin(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b61178d1-a2d9-11cf-9e53-00aa00a216a1}')
    @commethod(3)
    def KsQueryMediums(self, MediumList: POINTER(POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSMULTIPLE_ITEM))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def KsQueryInterfaces(self, InterfaceList: POINTER(POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSMULTIPLE_ITEM))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def KsCreateSinkPinHandle(self, Interface: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER), Medium: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def KsGetCurrentCommunication(self, Communication: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSPIN_COMMUNICATION), Interface: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER), Medium: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def KsPropagateAcquire(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def KsDeliver(self, Sample: win32more.Windows.Win32.Media.DirectShow.IMediaSample, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def KsMediaSamplesCompleted(self, StreamSegment: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSSTREAM_SEGMENT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def KsPeekAllocator(self, Operation: win32more.Windows.Win32.Media.KernelStreaming.KSPEEKOPERATION) -> win32more.Windows.Win32.Media.DirectShow.IMemAllocator: ...
    @commethod(11)
    def KsReceiveAllocator(self, MemAllocator: win32more.Windows.Win32.Media.DirectShow.IMemAllocator) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def KsRenegotiateAllocator(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def KsIncrementPendingIoCount(self) -> Int32: ...
    @commethod(14)
    def KsDecrementPendingIoCount(self) -> Int32: ...
    @commethod(15)
    def KsQualityNotify(self, Proportion: UInt32, TimeDelta: Int64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsPinEx(ComPtr):
    extends: win32more.Windows.Win32.Media.KernelStreaming.IKsPin
    _iid_ = Guid('{7bb38260-d19c-11d2-b38a-00a0c95ec22e}')
    @commethod(16)
    def KsNotifyError(self, Sample: win32more.Windows.Win32.Media.DirectShow.IMediaSample, hr: win32more.Windows.Win32.Foundation.HRESULT) -> Void: ...
class IKsPinFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{cd5ebe6b-8b6e-11d1-8ae0-00a0c9223196}')
    @commethod(3)
    def KsPinFactory(self, PinFactory: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsPinPipe(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e539cd90-a8b4-11d1-8189-00a0c9062802}')
    @commethod(3)
    def KsGetPinFramingCache(self, FramingEx: POINTER(POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSALLOCATOR_FRAMING_EX)), FramingProp: POINTER(win32more.Windows.Win32.Media.KernelStreaming.FRAMING_PROP), Option: win32more.Windows.Win32.Media.KernelStreaming.FRAMING_CACHE_OPS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def KsSetPinFramingCache(self, FramingEx: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSALLOCATOR_FRAMING_EX), FramingProp: POINTER(win32more.Windows.Win32.Media.KernelStreaming.FRAMING_PROP), Option: win32more.Windows.Win32.Media.KernelStreaming.FRAMING_CACHE_OPS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def KsGetConnectedPin(self) -> win32more.Windows.Win32.Media.DirectShow.IPin: ...
    @commethod(6)
    def KsGetPipe(self, Operation: win32more.Windows.Win32.Media.KernelStreaming.KSPEEKOPERATION) -> win32more.Windows.Win32.Media.KernelStreaming.IKsAllocatorEx: ...
    @commethod(7)
    def KsSetPipe(self, KsAllocator: win32more.Windows.Win32.Media.KernelStreaming.IKsAllocatorEx) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def KsGetPipeAllocatorFlag(self) -> UInt32: ...
    @commethod(9)
    def KsSetPipeAllocatorFlag(self, Flag: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def KsGetPinBusCache(self) -> Guid: ...
    @commethod(11)
    def KsSetPinBusCache(self, Bus: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def KsGetPinName(self) -> win32more.Windows.Win32.Foundation.PWSTR: ...
    @commethod(13)
    def KsGetFilterName(self) -> win32more.Windows.Win32.Foundation.PWSTR: ...
class IKsPropertySet(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{31efac30-515c-11d0-a9aa-00aa0061be93}')
    @commethod(3)
    def Set(self, guidPropSet: POINTER(Guid), dwPropID: UInt32, pInstanceData: VoidPtr, cbInstanceData: UInt32, pPropData: VoidPtr, cbPropData: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Get(self, guidPropSet: POINTER(Guid), dwPropID: UInt32, pInstanceData: VoidPtr, cbInstanceData: UInt32, pPropData: VoidPtr, cbPropData: UInt32, pcbReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def QuerySupported(self, guidPropSet: POINTER(Guid), dwPropID: UInt32, pTypeSupport: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsQualityForwarder(ComPtr):
    extends: win32more.Windows.Win32.Media.KernelStreaming.IKsObject
    _iid_ = Guid('{97ebaacb-95bd-11d0-a3ea-00a0c9223196}')
    @commethod(4)
    def KsFlushClient(self, Pin: win32more.Windows.Win32.Media.KernelStreaming.IKsPin) -> Void: ...
class IKsTopology(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{28f54683-06fd-11d2-b27a-00a0c9223196}')
    @commethod(3)
    def CreateNodeInstance(self, NodeId: UInt32, Flags: UInt32, DesiredAccess: UInt32, UnkOuter: win32more.Windows.Win32.System.Com.IUnknown, InterfaceId: POINTER(Guid), Interface: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IKsTopologyInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{720d4ac0-7533-11d0-a5d6-28db04c10000}')
    @commethod(3)
    def get_NumCategories(self, pdwNumCategories: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_Category(self, dwIndex: UInt32, pCategory: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_NumConnections(self, pdwNumConnections: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def get_ConnectionInfo(self, dwIndex: UInt32, pConnectionInfo: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSTOPOLOGY_CONNECTION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def get_NodeName(self, dwNodeId: UInt32, pwchNodeName: win32more.Windows.Win32.Foundation.PWSTR, dwBufSize: UInt32, pdwNameLen: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_NumNodes(self, pdwNumNodes: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_NodeType(self, dwNodeId: UInt32, pNodeType: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CreateNodeInstance(self, dwNodeId: UInt32, iid: POINTER(Guid), ppvObject: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INTERLEAVED_AUDIO_FORMAT_INFORMATION(Structure):
    Size: UInt32
    PrimaryChannelCount: UInt32
    PrimaryChannelStartPosition: UInt32
    PrimaryChannelMask: UInt32
    InterleavedChannelCount: UInt32
    InterleavedChannelStartPosition: UInt32
    InterleavedChannelMask: UInt32
class KSAC3_ALTERNATE_AUDIO(Structure):
    fStereo: win32more.Windows.Win32.Foundation.BOOL
    DualMode: UInt32
class KSAC3_BIT_STREAM_MODE(Structure):
    BitStreamMode: Int32
class KSAC3_DIALOGUE_LEVEL(Structure):
    DialogueLevel: UInt32
class KSAC3_DOWNMIX(Structure):
    fDownMix: win32more.Windows.Win32.Foundation.BOOL
    fDolbySurround: win32more.Windows.Win32.Foundation.BOOL
class KSAC3_ERROR_CONCEALMENT(Structure):
    fRepeatPreviousBlock: win32more.Windows.Win32.Foundation.BOOL
    fErrorInCurrentBlock: win32more.Windows.Win32.Foundation.BOOL
class KSAC3_ROOM_TYPE(Structure):
    fLargeRoom: win32more.Windows.Win32.Foundation.BOOL
KSALGORITHMINSTANCE_SYSTEM_ACOUSTIC_ECHO_CANCEL = Guid('{1c22c56d-9879-4f5b-a389-27996ddc2810}')
KSALGORITHMINSTANCE_SYSTEM_AGC = Guid('{950e55b9-877c-4c67-be08-e47b5611130a}')
KSALGORITHMINSTANCE_SYSTEM_MICROPHONE_ARRAY_PROCESSOR = Guid('{b6f5a0a0-9e61-4f8c-91e3-76cf0f3c471f}')
KSALGORITHMINSTANCE_SYSTEM_NOISE_SUPPRESS = Guid('{5ab0882e-7274-4516-877d-4eee99ba4fd0}')
KSALLOCATORMODE = Int32
KsAllocatorMode_User: win32more.Windows.Win32.Media.KernelStreaming.KSALLOCATORMODE = 0
KsAllocatorMode_Kernel: win32more.Windows.Win32.Media.KernelStreaming.KSALLOCATORMODE = 1
class KSALLOCATOR_FRAMING(Structure):
    Anonymous1: _Anonymous1_e__Union
    PoolType: UInt32
    Frames: UInt32
    FrameSize: UInt32
    Anonymous2: _Anonymous2_e__Union
    Reserved: UInt32
    class _Anonymous1_e__Union(Union):
        OptionsFlags: UInt32
        RequirementsFlags: UInt32
    class _Anonymous2_e__Union(Union):
        FileAlignment: UInt32
        FramePitch: Int32
class KSALLOCATOR_FRAMING_EX(Structure):
    CountItems: UInt32
    PinFlags: UInt32
    OutputCompression: win32more.Windows.Win32.Media.KernelStreaming.KS_COMPRESSION
    PinWeight: UInt32
    FramingItem: win32more.Windows.Win32.Media.KernelStreaming.KS_FRAMING_ITEM * 1
class KSATTRIBUTE(Structure):
    Size: UInt32
    Flags: UInt32
    Attribute: Guid
KSATTRIBUTEID_AUDIOSIGNALPROCESSING_MODE = Guid('{e1f89eb5-5f46-419b-967b-ff6770b98401}')
class KSATTRIBUTE_AUDIOSIGNALPROCESSING_MODE(Structure):
    AttributeHeader: win32more.Windows.Win32.Media.KernelStreaming.KSATTRIBUTE
    SignalProcessingMode: Guid
KSAUDFNAME_3D_CENTER = Guid('{9f0670b4-991f-11d2-ac4d-00c04f8efb68}')
KSAUDFNAME_3D_DEPTH = Guid('{63ff5747-991f-11d2-ac4d-00c04f8efb68}')
KSAUDFNAME_3D_STEREO = Guid('{185fede2-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_ALTERNATE_MICROPHONE = Guid('{2bc31d6b-96e3-11d2-ac4c-00c04f8efb68}')
KSAUDFNAME_AUX = Guid('{185fedfe-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_AUX_MUTE = Guid('{185fedfd-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_AUX_VOLUME = Guid('{185fedfc-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_BASS = Guid('{185fede0-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_CD_AUDIO = Guid('{185fedfb-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_CD_IN_VOLUME = Guid('{185fedf3-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_CD_MUTE = Guid('{185fedea-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_CD_VOLUME = Guid('{185fede9-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_LINE_IN = Guid('{185fedf9-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_LINE_IN_VOLUME = Guid('{185fedf4-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_LINE_MUTE = Guid('{185fedec-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_LINE_VOLUME = Guid('{185fedeb-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_MASTER_MUTE = Guid('{185fede4-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_MASTER_VOLUME = Guid('{185fede3-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_MICROPHONE_BOOST = Guid('{2bc31d6a-96e3-11d2-ac4c-00c04f8efb68}')
KSAUDFNAME_MIC_IN_VOLUME = Guid('{185fedf5-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_MIC_MUTE = Guid('{185fedee-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_MIC_VOLUME = Guid('{185feded-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_MIDI = Guid('{185fedf8-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_MIDI_IN_VOLUME = Guid('{185fedf2-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_MIDI_MUTE = Guid('{185fede8-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_MIDI_VOLUME = Guid('{185fede7-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_MIDRANGE = Guid('{a2cbe478-ae84-49a1-8b72-4ad09b78ed34}')
KSAUDFNAME_MONO_MIX = Guid('{00dff078-96e3-11d2-ac4c-00c04f8efb68}')
KSAUDFNAME_MONO_MIX_MUTE = Guid('{2bc31d69-96e3-11d2-ac4c-00c04f8efb68}')
KSAUDFNAME_MONO_MIX_VOLUME = Guid('{22b0eafe-96e3-11d2-ac4c-00c04f8efb68}')
KSAUDFNAME_MONO_OUT = Guid('{f9b41dc3-96e2-11d2-ac4c-00c04f8efb68}')
KSAUDFNAME_MONO_OUT_MUTE = Guid('{1ad247ec-96e3-11d2-ac4c-00c04f8efb68}')
KSAUDFNAME_MONO_OUT_VOLUME = Guid('{1ad247eb-96e3-11d2-ac4c-00c04f8efb68}')
KSAUDFNAME_PC_SPEAKER = Guid('{185fedff-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_PC_SPEAKER_MUTE = Guid('{185fedf1-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_PC_SPEAKER_VOLUME = Guid('{185fedf0-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_PEAKMETER = Guid('{57e24340-fc5b-4612-a562-72b11a29dfae}')
KSAUDFNAME_RECORDING_CONTROL = Guid('{185fedfa-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_RECORDING_SOURCE = Guid('{185fedef-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_STEREO_MIX = Guid('{00dff077-96e3-11d2-ac4c-00c04f8efb68}')
KSAUDFNAME_STEREO_MIX_MUTE = Guid('{22b0eafd-96e3-11d2-ac4c-00c04f8efb68}')
KSAUDFNAME_STEREO_MIX_VOLUME = Guid('{1ad247ed-96e3-11d2-ac4c-00c04f8efb68}')
KSAUDFNAME_TREBLE = Guid('{185fede1-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_VIDEO = Guid('{915daec4-a434-11d2-ac52-00c04f8efb68}')
KSAUDFNAME_VIDEO_MUTE = Guid('{9b46e709-992a-11d2-ac4d-00c04f8efb68}')
KSAUDFNAME_VIDEO_VOLUME = Guid('{9b46e708-992a-11d2-ac4d-00c04f8efb68}')
KSAUDFNAME_VOLUME_CONTROL = Guid('{185fedf7-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_WAVE_IN_VOLUME = Guid('{185fedf6-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_WAVE_MUTE = Guid('{185fede6-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_WAVE_OUT_MIX = Guid('{185fee00-9905-11d1-95a9-00c04fb925d3}')
KSAUDFNAME_WAVE_VOLUME = Guid('{185fede5-9905-11d1-95a9-00c04fb925d3}')
class KSAUDIOENGINE_BUFFER_SIZE_RANGE(Structure):
    MinBufferBytes: UInt32
    MaxBufferBytes: UInt32
class KSAUDIOENGINE_DESCRIPTOR(Structure):
    nHostPinId: UInt32
    nOffloadPinId: UInt32
    nLoopbackPinId: UInt32
class KSAUDIOENGINE_DEVICECONTROLS(Structure):
    Volume: win32more.Windows.Win32.Media.KernelStreaming.EDeviceControlUseType
    Mute: win32more.Windows.Win32.Media.KernelStreaming.EDeviceControlUseType
    PeakMeter: win32more.Windows.Win32.Media.KernelStreaming.EDeviceControlUseType
class KSAUDIOENGINE_VOLUMELEVEL(Structure):
    TargetVolume: Int32
    CurveType: win32more.Windows.Win32.Media.KernelStreaming.AUDIO_CURVE_TYPE
    CurveDuration: UInt64
class KSAUDIOMODULE_DESCRIPTOR(Structure):
    ClassId: Guid
    InstanceId: UInt32
    VersionMajor: UInt32
    VersionMinor: UInt32
    Name: Char * 128
class KSAUDIOMODULE_NOTIFICATION(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        ProviderId: _ProviderId_e__Struct
        Alignment: Int64
        class _ProviderId_e__Struct(Structure):
            DeviceId: Guid
            ClassId: Guid
            InstanceId: UInt32
            Reserved: UInt32
class KSAUDIOMODULE_PROPERTY(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    ClassId: Guid
    InstanceId: UInt32
class KSAUDIO_CHANNEL_CONFIG(Structure):
    ActiveSpeakerPositions: Int32
class KSAUDIO_COPY_PROTECTION(Structure):
    fCopyrighted: win32more.Windows.Win32.Foundation.BOOL
    fOriginal: win32more.Windows.Win32.Foundation.BOOL
class KSAUDIO_DYNAMIC_RANGE(Structure):
    QuietCompression: UInt32
    LoudCompression: UInt32
class KSAUDIO_MICROPHONE_COORDINATES(Structure):
    usType: UInt16
    wXCoord: Int16
    wYCoord: Int16
    wZCoord: Int16
    wVerticalAngle: Int16
    wHorizontalAngle: Int16
class KSAUDIO_MIC_ARRAY_GEOMETRY(Structure):
    usVersion: UInt16
    usMicArrayType: UInt16
    wVerticalAngleBegin: Int16
    wVerticalAngleEnd: Int16
    wHorizontalAngleBegin: Int16
    wHorizontalAngleEnd: Int16
    usFrequencyBandLo: UInt16
    usFrequencyBandHi: UInt16
    usNumberOfMicrophones: UInt16
    KsMicCoord: win32more.Windows.Win32.Media.KernelStreaming.KSAUDIO_MICROPHONE_COORDINATES * 1
class KSAUDIO_MIXCAP_TABLE(Structure):
    InputChannels: UInt32
    OutputChannels: UInt32
    Capabilities: win32more.Windows.Win32.Media.KernelStreaming.KSAUDIO_MIX_CAPS * 1
class KSAUDIO_MIXLEVEL(Structure):
    Mute: win32more.Windows.Win32.Foundation.BOOL
    Level: Int32
class KSAUDIO_MIX_CAPS(Structure):
    Mute: win32more.Windows.Win32.Foundation.BOOL
    Minimum: Int32
    Maximum: Int32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Reset: Int32
        Resolution: Int32
class KSAUDIO_PACKETSIZE_CONSTRAINTS(Structure):
    MinPacketPeriodInHns: UInt32
    PacketSizeFileAlignment: UInt32
    Reserved: UInt32
    NumProcessingModeConstraints: UInt32
    ProcessingModeConstraints: win32more.Windows.Win32.Media.KernelStreaming.KSAUDIO_PACKETSIZE_PROCESSINGMODE_CONSTRAINT * 1
class KSAUDIO_PACKETSIZE_CONSTRAINTS2(Structure):
    MinPacketPeriodInHns: UInt32
    PacketSizeFileAlignment: UInt32
    MaxPacketSizeInBytes: UInt32
    NumProcessingModeConstraints: UInt32
    ProcessingModeConstraints: win32more.Windows.Win32.Media.KernelStreaming.KSAUDIO_PACKETSIZE_PROCESSINGMODE_CONSTRAINT * 1
class KSAUDIO_PACKETSIZE_PROCESSINGMODE_CONSTRAINT(Structure):
    ProcessingMode: Guid
    SamplesPerProcessingPacket: UInt32
    ProcessingPacketDurationInHns: UInt32
class KSAUDIO_POSITION(Structure):
    PlayOffset: UInt64
    WriteOffset: UInt64
class KSAUDIO_POSITIONEX(Structure):
    TimerFrequency: Int64
    TimeStamp1: Int64
    Position: win32more.Windows.Win32.Media.KernelStreaming.KSAUDIO_POSITION
    TimeStamp2: Int64
class KSAUDIO_PRESENTATION_POSITION(Structure):
    u64PositionInBlocks: UInt64
    u64QPCPosition: UInt64
KSCAMERAPROFILE_BalancedVideoAndPhoto = Guid('{6b52b017-42c7-4a21-bfe3-23f009149887}')
KSCAMERAPROFILE_CompressedCamera = Guid('{0e34cdc1-27ad-437f-abde-02b629f37b44}')
KSCAMERAPROFILE_FaceAuth_Mode = Guid('{81361b22-700b-4546-a2d4-c52e907bfc27}')
KSCAMERAPROFILE_HDRWithWCGPhoto = Guid('{9bf6f1ff-b555-4625-b326-a46def318fb7}')
KSCAMERAPROFILE_HDRWithWCGVideo = Guid('{4b27c336-4924-4989-b994-fdaf1dc7cd85}')
KSCAMERAPROFILE_HighFrameRate = Guid('{566e6113-8c35-48e7-b89f-d23fdc1219dc}')
KSCAMERAPROFILE_HighQualityPhoto = Guid('{32440725-961b-4ca3-b5b2-854e719d9e1b}')
KSCAMERAPROFILE_Legacy = Guid('{b4894d81-62b7-4eec-8740-80658c4a9d3e}')
KSCAMERAPROFILE_PhotoSequence = Guid('{02399d9d-4ee8-49ba-bc07-5ff156531413}')
KSCAMERAPROFILE_VariablePhotoSequence = Guid('{9ff2cb56-e75a-49b1-a928-9985d5946f87}')
KSCAMERAPROFILE_VideoConferencing = Guid('{c5444a88-e1bf-4597-b2dd-9e1ead864bb8}')
KSCAMERAPROFILE_VideoHDR8 = Guid('{d4f3f4ec-bdff-4314-b1d4-008e281f74e7}')
KSCAMERAPROFILE_VideoRecording = Guid('{a0e517e8-8f8c-4f6f-9a57-46fc2f647ec0}')
class KSCAMERA_EXTENDEDPROP_BACKGROUNDSEGMENTATION_CONFIGCAPS(Structure):
    Resolution: win32more.Windows.Win32.Foundation.SIZE
    MaxFrameRate: _MaxFrameRate_e__Struct
    MaskResolution: win32more.Windows.Win32.Foundation.SIZE
    SubType: Guid
    class _MaxFrameRate_e__Struct(Structure):
        Numerator: Int32
        Denominator: Int32
class KSCAMERA_EXTENDEDPROP_CAMERAOFFSET(Structure):
    PitchAngle: Int32
    YawAngle: Int32
    Flag: UInt32
    Reserved: UInt32
class KSCAMERA_EXTENDEDPROP_DIGITALWINDOW_CONFIGCAPS(Structure):
    ResolutionX: Int32
    ResolutionY: Int32
    PorchTop: Int32
    PorchLeft: Int32
    PorchBottom: Int32
    PorchRight: Int32
    NonUpscalingWindowSize: Int32
    MinWindowSize: Int32
    MaxWindowSize: Int32
    Reserved: Int32
class KSCAMERA_EXTENDEDPROP_DIGITALWINDOW_CONFIGCAPSHEADER(Structure):
    Size: UInt32
    Count: UInt32
class KSCAMERA_EXTENDEDPROP_DIGITALWINDOW_SETTING(Structure):
    OriginX: Int32
    OriginY: Int32
    WindowSize: Int32
    Reserved: UInt32
class KSCAMERA_EXTENDEDPROP_EVCOMPENSATION(Structure):
    Mode: UInt32
    Min: Int32
    Max: Int32
    Value: Int32
    Reserved: UInt64
class KSCAMERA_EXTENDEDPROP_FIELDOFVIEW(Structure):
    NormalizedFocalLengthX: UInt32
    NormalizedFocalLengthY: UInt32
    Flag: UInt32
    Reserved: UInt32
KSCAMERA_EXTENDEDPROP_FOCUSSTATE = Int32
KSCAMERA_EXTENDEDPROP_FOCUSSTATE_UNINITIALIZED: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_FOCUSSTATE = 0
KSCAMERA_EXTENDEDPROP_FOCUSSTATE_LOST: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_FOCUSSTATE = 1
KSCAMERA_EXTENDEDPROP_FOCUSSTATE_SEARCHING: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_FOCUSSTATE = 2
KSCAMERA_EXTENDEDPROP_FOCUSSTATE_FOCUSED: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_FOCUSSTATE = 3
KSCAMERA_EXTENDEDPROP_FOCUSSTATE_FAILED: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_FOCUSSTATE = 4
class KSCAMERA_EXTENDEDPROP_HEADER(Structure):
    Version: UInt32
    PinId: UInt32
    Size: UInt32
    Result: UInt32
    Flags: UInt64
    Capability: UInt64
class KSCAMERA_EXTENDEDPROP_METADATAINFO(Structure):
    BufferAlignment: Int32
    MaxMetadataBufferSize: UInt32
KSCAMERA_EXTENDEDPROP_MetadataAlignment = Int32
KSCAMERA_EXTENDEDPROP_MetadataAlignment_16: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_MetadataAlignment = 4
KSCAMERA_EXTENDEDPROP_MetadataAlignment_32: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_MetadataAlignment = 5
KSCAMERA_EXTENDEDPROP_MetadataAlignment_64: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_MetadataAlignment = 6
KSCAMERA_EXTENDEDPROP_MetadataAlignment_128: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_MetadataAlignment = 7
KSCAMERA_EXTENDEDPROP_MetadataAlignment_256: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_MetadataAlignment = 8
KSCAMERA_EXTENDEDPROP_MetadataAlignment_512: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_MetadataAlignment = 9
KSCAMERA_EXTENDEDPROP_MetadataAlignment_1024: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_MetadataAlignment = 10
KSCAMERA_EXTENDEDPROP_MetadataAlignment_2048: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_MetadataAlignment = 11
KSCAMERA_EXTENDEDPROP_MetadataAlignment_4096: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_MetadataAlignment = 12
KSCAMERA_EXTENDEDPROP_MetadataAlignment_8192: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_MetadataAlignment = 13
class KSCAMERA_EXTENDEDPROP_PHOTOMODE(Structure):
    RequestedHistoryFrames: UInt32
    MaxHistoryFrames: UInt32
    SubMode: UInt32
    Reserved: UInt32
class KSCAMERA_EXTENDEDPROP_PROFILE(Structure):
    ProfileId: Guid
    Index: UInt32
    Reserved: UInt32
KSCAMERA_EXTENDEDPROP_ROITYPE = Int32
KSCAMERA_EXTENDEDPROP_ROITYPE_UNKNOWN: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_ROITYPE = 0
KSCAMERA_EXTENDEDPROP_ROITYPE_FACE: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_ROITYPE = 1
class KSCAMERA_EXTENDEDPROP_ROI_CONFIGCAPS(Structure):
    ControlId: UInt32
    MaxNumberOfROIs: UInt32
    Capability: UInt64
class KSCAMERA_EXTENDEDPROP_ROI_CONFIGCAPSHEADER(Structure):
    Size: UInt32
    ConfigCapCount: UInt32
    Reserved: UInt64
class KSCAMERA_EXTENDEDPROP_ROI_EXPOSURE(Structure):
    ROIInfo: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_ROI_INFO
    Reserved: UInt64
class KSCAMERA_EXTENDEDPROP_ROI_FOCUS(Structure):
    ROIInfo: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_ROI_INFO
    Reserved: UInt64
class KSCAMERA_EXTENDEDPROP_ROI_INFO(Structure):
    Region: win32more.Windows.Win32.Foundation.RECT
    Flags: UInt64
    Weight: Int32
    RegionOfInterestType: Int32
class KSCAMERA_EXTENDEDPROP_ROI_ISPCONTROL(Structure):
    ControlId: UInt32
    ROICount: UInt32
    Result: UInt32
    Reserved: UInt32
class KSCAMERA_EXTENDEDPROP_ROI_ISPCONTROLHEADER(Structure):
    Size: UInt32
    ControlCount: UInt32
    Reserved: UInt64
class KSCAMERA_EXTENDEDPROP_ROI_WHITEBALANCE(Structure):
    ROIInfo: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_ROI_INFO
    Reserved: UInt64
class KSCAMERA_EXTENDEDPROP_VALUE(Structure):
    Value: _Value_e__Union
    class _Value_e__Union(Union):
        dbl: Double
        ull: UInt64
        ul: UInt32
        ratio: UInt64
        l: Int32
        ll: Int64
class KSCAMERA_EXTENDEDPROP_VIDEOPROCSETTING(Structure):
    Mode: UInt32
    Min: Int32
    Max: Int32
    Step: Int32
    VideoProc: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_VALUE
    Reserved: UInt64
KSCAMERA_EXTENDEDPROP_WBPRESET = Int32
KSCAMERA_EXTENDEDPROP_WBPRESET_CLOUDY: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_WBPRESET = 1
KSCAMERA_EXTENDEDPROP_WBPRESET_DAYLIGHT: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_WBPRESET = 2
KSCAMERA_EXTENDEDPROP_WBPRESET_FLASH: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_WBPRESET = 3
KSCAMERA_EXTENDEDPROP_WBPRESET_FLUORESCENT: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_WBPRESET = 4
KSCAMERA_EXTENDEDPROP_WBPRESET_TUNGSTEN: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_WBPRESET = 5
KSCAMERA_EXTENDEDPROP_WBPRESET_CANDLELIGHT: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_WBPRESET = 6
KSCAMERA_EXTENDEDPROP_WHITEBALANCE_MODE = Int32
KSCAMERA_EXTENDEDPROP_WHITEBALANCE_TEMPERATURE: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_WHITEBALANCE_MODE = 1
KSCAMERA_EXTENDEDPROP_WHITEBALANCE_PRESET: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_WHITEBALANCE_MODE = 2
class KSCAMERA_MAXVIDEOFPS_FORPHOTORES(Structure):
    PhotoResWidth: UInt32
    PhotoResHeight: UInt32
    PreviewFPSNum: UInt32
    PreviewFPSDenom: UInt32
    CaptureFPSNum: UInt32
    CaptureFPSDenom: UInt32
class KSCAMERA_METADATA_BACKGROUNDSEGMENTATIONMASK(Structure):
    Header: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_METADATA_ITEMHEADER
    MaskCoverageBoundingBox: win32more.Windows.Win32.Foundation.RECT
    MaskResolution: win32more.Windows.Win32.Foundation.SIZE
    ForegroundBoundingBox: win32more.Windows.Win32.Foundation.RECT
    MaskData: Byte * 1
class KSCAMERA_METADATA_CAPTURESTATS(Structure):
    Header: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_METADATA_ITEMHEADER
    Flags: UInt32
    Reserved: UInt32
    ExposureTime: UInt64
    ExposureCompensationFlags: UInt64
    ExposureCompensationValue: Int32
    IsoSpeed: UInt32
    FocusState: UInt32
    LensPosition: UInt32
    WhiteBalance: UInt32
    Flash: UInt32
    FlashPower: UInt32
    ZoomFactor: UInt32
    SceneMode: UInt64
    SensorFramerate: UInt64
class KSCAMERA_METADATA_DIGITALWINDOW(Structure):
    Header: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_METADATA_ITEMHEADER
    Window: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_EXTENDEDPROP_DIGITALWINDOW_SETTING
class KSCAMERA_METADATA_FRAMEILLUMINATION(Structure):
    Header: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_METADATA_ITEMHEADER
    Flags: UInt32
    Reserved: UInt32
class KSCAMERA_METADATA_ITEMHEADER(Structure):
    MetadataId: UInt32
    Size: UInt32
class KSCAMERA_METADATA_PHOTOCONFIRMATION(Structure):
    Header: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_METADATA_ITEMHEADER
    PhotoConfirmationIndex: UInt32
    Reserved: UInt32
KSCAMERA_MetadataId = Int32
MetadataId_Standard_Start: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_MetadataId = 1
MetadataId_PhotoConfirmation: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_MetadataId = 1
MetadataId_UsbVideoHeader: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_MetadataId = 2
MetadataId_CaptureStats: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_MetadataId = 3
MetadataId_CameraExtrinsics: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_MetadataId = 4
MetadataId_CameraIntrinsics: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_MetadataId = 5
MetadataId_FrameIllumination: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_MetadataId = 6
MetadataId_DigitalWindow: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_MetadataId = 7
MetadataId_BackgroundSegmentationMask: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_MetadataId = 8
MetadataId_Standard_End: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_MetadataId = 8
MetadataId_Custom_Start: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_MetadataId = -2147483648
class KSCAMERA_PERFRAMESETTING_CAP_HEADER(Structure):
    Size: UInt32
    ItemCount: UInt32
    Flags: UInt64
class KSCAMERA_PERFRAMESETTING_CAP_ITEM_HEADER(Structure):
    Size: UInt32
    Type: UInt32
    Flags: UInt64
class KSCAMERA_PERFRAMESETTING_CUSTOM_ITEM(Structure):
    Size: UInt32
    Reserved: UInt32
    Id: Guid
class KSCAMERA_PERFRAMESETTING_FRAME_HEADER(Structure):
    Size: UInt32
    Id: UInt32
    ItemCount: UInt32
    Reserved: UInt32
class KSCAMERA_PERFRAMESETTING_HEADER(Structure):
    Size: UInt32
    FrameCount: UInt32
    Id: Guid
    Flags: UInt64
    LoopCount: UInt32
    Reserved: UInt32
class KSCAMERA_PERFRAMESETTING_ITEM_HEADER(Structure):
    Size: UInt32
    Type: UInt32
    Flags: UInt64
KSCAMERA_PERFRAMESETTING_ITEM_TYPE = Int32
KSCAMERA_PERFRAMESETTING_ITEM_EXPOSURE_TIME: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_PERFRAMESETTING_ITEM_TYPE = 1
KSCAMERA_PERFRAMESETTING_ITEM_FLASH: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_PERFRAMESETTING_ITEM_TYPE = 2
KSCAMERA_PERFRAMESETTING_ITEM_EXPOSURE_COMPENSATION: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_PERFRAMESETTING_ITEM_TYPE = 3
KSCAMERA_PERFRAMESETTING_ITEM_ISO: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_PERFRAMESETTING_ITEM_TYPE = 4
KSCAMERA_PERFRAMESETTING_ITEM_FOCUS: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_PERFRAMESETTING_ITEM_TYPE = 5
KSCAMERA_PERFRAMESETTING_ITEM_PHOTOCONFIRMATION: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_PERFRAMESETTING_ITEM_TYPE = 6
KSCAMERA_PERFRAMESETTING_ITEM_CUSTOM: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_PERFRAMESETTING_ITEM_TYPE = 7
class KSCAMERA_PROFILE_CONCURRENCYINFO(Structure):
    ReferenceGuid: Guid
    Reserved: UInt32
    ProfileCount: UInt32
    Profiles: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_PROFILE_INFO)
class KSCAMERA_PROFILE_INFO(Structure):
    ProfileId: Guid
    Index: UInt32
    PinCount: UInt32
    Pins: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_PROFILE_PININFO)
class KSCAMERA_PROFILE_MEDIAINFO(Structure):
    Resolution: _Resolution_e__Struct
    MaxFrameRate: _MaxFrameRate_e__Struct
    Flags: UInt64
    Data0: UInt32
    Data1: UInt32
    Data2: UInt32
    Data3: UInt32
    class _Resolution_e__Struct(Structure):
        X: UInt32
        Y: UInt32
    class _MaxFrameRate_e__Struct(Structure):
        Numerator: UInt32
        Denominator: UInt32
class KSCAMERA_PROFILE_PININFO(Structure):
    PinCategory: Guid
    Anonymous: _Anonymous_e__Union
    MediaInfoCount: UInt32
    MediaInfos: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_PROFILE_MEDIAINFO)
    class _Anonymous_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        Reserved: UInt32
        class _Anonymous_e__Struct(Structure):
            PinIndex: UInt16
            ProfileSensorType: UInt16
KSCATEGORY_ACOUSTIC_ECHO_CANCEL = Guid('{bf963d80-c559-11d0-8a2b-00a0c9255ac1}')
KSCATEGORY_AUDIO = Guid('{6994ad04-93ef-11d0-a3cc-00a0c9223196}')
KSCATEGORY_BRIDGE = Guid('{085aff00-62ce-11cf-a5d6-28db04c10000}')
KSCATEGORY_CAPTURE = Guid('{65e8773d-8f56-11d0-a3b9-00a0c9223196}')
KSCATEGORY_CLOCK = Guid('{53172480-4791-11d0-a5d6-28db04c10000}')
KSCATEGORY_COMMUNICATIONSTRANSFORM = Guid('{cf1dda2c-9743-11d0-a3ee-00a0c9223196}')
KSCATEGORY_CROSSBAR = Guid('{a799a801-a46d-11d0-a18c-00a02401dcd4}')
KSCATEGORY_DATACOMPRESSOR = Guid('{1e84c900-7e70-11d0-a5d6-28db04c10000}')
KSCATEGORY_DATADECOMPRESSOR = Guid('{2721ae20-7e70-11d0-a5d6-28db04c10000}')
KSCATEGORY_DATATRANSFORM = Guid('{2eb07ea0-7e70-11d0-a5d6-28db04c10000}')
KSCATEGORY_ENCODER = Guid('{19689bf6-c384-48fd-ad51-90e58c79f70b}')
KSCATEGORY_ESCALANTE_PLATFORM_DRIVER = Guid('{74f3aea8-9768-11d1-8e07-00a0c95ec22e}')
KSCATEGORY_FILESYSTEM = Guid('{760fed5e-9357-11d0-a3cc-00a0c9223196}')
KSCATEGORY_INTERFACETRANSFORM = Guid('{cf1dda2d-9743-11d0-a3ee-00a0c9223196}')
KSCATEGORY_MEDIUMTRANSFORM = Guid('{cf1dda2e-9743-11d0-a3ee-00a0c9223196}')
KSCATEGORY_MICROPHONE_ARRAY_PROCESSOR = Guid('{830a44f2-a32d-476b-be97-42845673b35a}')
KSCATEGORY_MIXER = Guid('{ad809c00-7b88-11d0-a5d6-28db04c10000}')
KSCATEGORY_MULTIPLEXER = Guid('{7a5de1d3-01a1-452c-b481-4fa2b96271e8}')
KSCATEGORY_NETWORK = Guid('{67c9cc3c-69c4-11d2-8759-00a0c9223196}')
KSCATEGORY_NETWORK_CAMERA = Guid('{b8238652-b500-41eb-b4f3-4234f7f5ae99}')
KSCATEGORY_PROXY = Guid('{97ebaaca-95bd-11d0-a3ea-00a0c9223196}')
KSCATEGORY_QUALITY = Guid('{97ebaacb-95bd-11d0-a3ea-00a0c9223196}')
KSCATEGORY_REALTIME = Guid('{eb115ffc-10c8-4964-831d-6dcb02e6f23f}')
KSCATEGORY_RENDER = Guid('{65e8773e-8f56-11d0-a3b9-00a0c9223196}')
KSCATEGORY_SENSOR_CAMERA = Guid('{24e552d7-6523-47f7-a647-d3465bf1f5ca}')
KSCATEGORY_SENSOR_GROUP = Guid('{669c7214-0a88-4311-a7f3-4e79820e33bd}')
KSCATEGORY_SPLITTER = Guid('{0a4252a0-7e70-11d0-a5d6-28db04c10000}')
KSCATEGORY_TEXT = Guid('{6994ad06-93ef-11d0-a3cc-00a0c9223196}')
KSCATEGORY_TOPOLOGY = Guid('{dda54a40-1e4c-11d1-a050-405705c10000}')
KSCATEGORY_TVAUDIO = Guid('{a799a802-a46d-11d0-a18c-00a02401dcd4}')
KSCATEGORY_TVTUNER = Guid('{a799a800-a46d-11d0-a18c-00a02401dcd4}')
KSCATEGORY_VBICODEC = Guid('{07dad660-22f1-11d1-a9f4-00c04fbbde8f}')
KSCATEGORY_VIDEO = Guid('{6994ad05-93ef-11d0-a3cc-00a0c9223196}')
KSCATEGORY_VIDEO_CAMERA = Guid('{e5323777-f976-4f5b-9b55-b94699c46e44}')
KSCATEGORY_VIRTUAL = Guid('{3503eac4-1f26-11d1-8ab0-00a0c9223196}')
KSCATEGORY_VPMUX = Guid('{a799a803-a46d-11d0-a18c-00a02401dcd4}')
KSCATEGORY_WDMAUD_USE_PIN_NAME = Guid('{47a4fa20-a251-11d1-a050-0000f8004788}')
class KSCLOCK_CREATE(Structure):
    CreateFlags: UInt32
class KSCOMPONENTID(Structure):
    Manufacturer: Guid
    Product: Guid
    Component: Guid
    Name: Guid
    Version: UInt32
    Revision: UInt32
KSCOMPONENTID_USBAUDIO = Guid('{8f1275f0-26e9-4264-ba4d-39fff01d94aa}')
class KSCORRELATED_TIME(Structure):
    Time: Int64
    SystemTime: Int64
class KSDATAFORMAT(Union):
    Anonymous: _Anonymous_e__Struct
    Alignment: Int64
    class _Anonymous_e__Struct(Structure):
        FormatSize: UInt32
        Flags: UInt32
        SampleSize: UInt32
        Reserved: UInt32
        MajorFormat: Guid
        SubFormat: Guid
        Specifier: Guid
KSDATAFORMAT_SPECIFIER_AC3_AUDIO = Guid('{e06d80e4-db46-11cf-b4d1-00805f6cbbea}')
KSDATAFORMAT_SPECIFIER_ANALOGVIDEO = Guid('{0482dde0-7817-11cf-8a03-00aa006ecb65}')
KSDATAFORMAT_SPECIFIER_DIALECT_AC3_AUDIO = Guid('{36523b35-8ee5-11d1-8ca3-0060b057664a}')
KSDATAFORMAT_SPECIFIER_DIALECT_MPEG1_AUDIO = Guid('{36523b32-8ee5-11d1-8ca3-0060b057664a}')
KSDATAFORMAT_SPECIFIER_DIALECT_MPEG1_VIDEO = Guid('{36523b31-8ee5-11d1-8ca3-0060b057664a}')
KSDATAFORMAT_SPECIFIER_DIALECT_MPEG2_AUDIO = Guid('{36523b34-8ee5-11d1-8ca3-0060b057664a}')
KSDATAFORMAT_SPECIFIER_DIALECT_MPEG2_VIDEO = Guid('{36523b33-8ee5-11d1-8ca3-0060b057664a}')
KSDATAFORMAT_SPECIFIER_DSOUND = Guid('{518590a2-a184-11d0-8522-00c04fd9baf3}')
KSDATAFORMAT_SPECIFIER_FILEHANDLE = Guid('{65e8773c-8f56-11d0-a3b9-00a0c9223196}')
KSDATAFORMAT_SPECIFIER_FILENAME = Guid('{aa797b40-e974-11cf-a5d6-28db04c10000}')
KSDATAFORMAT_SPECIFIER_H264_VIDEO = Guid('{2017be05-6629-4248-aaed-7e1a47bc9b9c}')
KSDATAFORMAT_SPECIFIER_IMAGE = Guid('{692fa379-d3e8-4651-b5b4-0b94b013eeaf}')
KSDATAFORMAT_SPECIFIER_JPEG_IMAGE = Guid('{692fa379-d3e8-4651-b5b4-0b94b013eeaf}')
KSDATAFORMAT_SPECIFIER_LPCM_AUDIO = Guid('{e06d80e6-db46-11cf-b4d1-00805f6cbbea}')
KSDATAFORMAT_SPECIFIER_MPEG1_VIDEO = Guid('{05589f82-c356-11ce-bf01-00aa0055595a}')
KSDATAFORMAT_SPECIFIER_MPEG2_AUDIO = Guid('{e06d80e5-db46-11cf-b4d1-00805f6cbbea}')
KSDATAFORMAT_SPECIFIER_MPEG2_VIDEO = Guid('{e06d80e3-db46-11cf-b4d1-00805f6cbbea}')
KSDATAFORMAT_SPECIFIER_NONE = Guid('{0f6417d6-c318-11d0-a43f-00a0c9223196}')
KSDATAFORMAT_SPECIFIER_VBI = Guid('{f72a76e0-eb0a-11d0-ace4-0000c0cc16ba}')
KSDATAFORMAT_SPECIFIER_VC_ID = Guid('{ad98d184-aac3-11d0-a41c-00a0c9223196}')
KSDATAFORMAT_SPECIFIER_VIDEOINFO = Guid('{05589f80-c356-11ce-bf01-00aa0055595a}')
KSDATAFORMAT_SPECIFIER_VIDEOINFO2 = Guid('{f72a76a0-eb0a-11d0-ace4-0000c0cc16ba}')
KSDATAFORMAT_SPECIFIER_WAVEFORMATEX = Guid('{05589f81-c356-11ce-bf01-00aa0055595a}')
KSDATAFORMAT_SUBTYPE_AC3_AUDIO = Guid('{e06d802c-db46-11cf-b4d1-00805f6cbbea}')
KSDATAFORMAT_SUBTYPE_ANALOG = Guid('{6dba3190-67bd-11cf-a0f7-0020afd156e4}')
KSDATAFORMAT_SUBTYPE_CC = Guid('{33214cc1-011f-11d2-b4b1-00a0d102cfbe}')
KSDATAFORMAT_SUBTYPE_D16 = Guid('{00000050-0004-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_DSS_AUDIO = Guid('{a0af4f82-e163-11d0-bad9-00609744111a}')
KSDATAFORMAT_SUBTYPE_DSS_VIDEO = Guid('{a0af4f81-e163-11d0-bad9-00609744111a}')
KSDATAFORMAT_SUBTYPE_DTS_AUDIO = Guid('{e06d8033-db46-11cf-b4d1-00805f6cbbea}')
KSDATAFORMAT_SUBTYPE_IEC61937_AAC = Guid('{00000006-0cea-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IEC61937_ATRAC = Guid('{00000008-0cea-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IEC61937_DOLBY_DIGITAL = Guid('{00000092-0000-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IEC61937_DOLBY_DIGITAL_PLUS = Guid('{0000000a-0cea-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IEC61937_DOLBY_DIGITAL_PLUS_ATMOS = Guid('{0000010a-0cea-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IEC61937_DOLBY_MAT20 = Guid('{0000010c-0cea-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IEC61937_DOLBY_MAT21 = Guid('{0000030c-0cea-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IEC61937_DOLBY_MLP = Guid('{0000000c-0cea-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IEC61937_DST = Guid('{0000000d-0cea-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IEC61937_DTS = Guid('{00000008-0000-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IEC61937_DTSX_E1 = Guid('{0000010b-0cea-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IEC61937_DTSX_E2 = Guid('{0000030b-0cea-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IEC61937_DTS_HD = Guid('{0000000b-0cea-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IEC61937_MPEG1 = Guid('{00000003-0cea-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IEC61937_MPEG2 = Guid('{00000004-0cea-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IEC61937_MPEG3 = Guid('{00000005-0cea-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IEC61937_ONE_BIT_AUDIO = Guid('{00000009-0cea-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IEC61937_WMA_PRO = Guid('{00000164-0000-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_IMAGE_RGB32 = Guid('{00000016-0000-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_JPEG = Guid('{19e4a5aa-5662-4fc5-a0c0-1758028e1057}')
KSDATAFORMAT_SUBTYPE_L16 = Guid('{00000051-0000-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_L16_CUSTOM = Guid('{00000051-8000-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_L16_IR = Guid('{00000051-0002-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_L8 = Guid('{00000032-0000-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_L8_CUSTOM = Guid('{00000032-8000-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_L8_IR = Guid('{00000032-0002-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_LPCM_AUDIO = Guid('{e06d8032-db46-11cf-b4d1-00805f6cbbea}')
KSDATAFORMAT_SUBTYPE_Line21_BytePair = Guid('{6e8d4a22-310c-11d0-b79a-00aa003767a7}')
KSDATAFORMAT_SUBTYPE_Line21_GOPPacket = Guid('{6e8d4a23-310c-11d0-b79a-00aa003767a7}')
KSDATAFORMAT_SUBTYPE_MIDI = Guid('{1d262760-e957-11cf-a5d6-28db04c10000}')
KSDATAFORMAT_SUBTYPE_MIDI_BUS = Guid('{2ca15fa0-6cfe-11cf-a5d6-28db04c10000}')
KSDATAFORMAT_SUBTYPE_MJPG_CUSTOM = Guid('{47504a4d-8000-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_MJPG_DEPTH = Guid('{47504a4d-0004-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_MJPG_IR = Guid('{47504a4d-0002-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_MPEG1Packet = Guid('{e436eb80-524f-11ce-9f53-0020af0ba770}')
KSDATAFORMAT_SUBTYPE_MPEG1Payload = Guid('{e436eb81-524f-11ce-9f53-0020af0ba770}')
KSDATAFORMAT_SUBTYPE_MPEG1Video = Guid('{e436eb86-524f-11ce-9f53-0020af0ba770}')
KSDATAFORMAT_SUBTYPE_MPEG2_AUDIO = Guid('{e06d802b-db46-11cf-b4d1-00805f6cbbea}')
KSDATAFORMAT_SUBTYPE_MPEG2_VIDEO = Guid('{e06d8026-db46-11cf-b4d1-00805f6cbbea}')
KSDATAFORMAT_SUBTYPE_MPEGLAYER3 = Guid('{00000055-0000-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_MPEG_HEAAC = Guid('{00001610-0000-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_NABTS = Guid('{f72a76e2-eb0a-11d0-ace4-0000c0cc16ba}')
KSDATAFORMAT_SUBTYPE_NABTS_FEC = Guid('{e757bca1-39ac-11d1-a9f5-00c04fbbde8f}')
KSDATAFORMAT_SUBTYPE_NONE = Guid('{e436eb8e-524f-11ce-9f53-0020af0ba770}')
KSDATAFORMAT_SUBTYPE_OVERLAY = Guid('{e436eb7f-524f-11ce-9f53-0020af0ba770}')
KSDATAFORMAT_SUBTYPE_PCM = Guid('{00000001-0000-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_RAW8 = Guid('{ca20d9a0-3e3e-11d1-9bf9-00c04fbbdebf}')
KSDATAFORMAT_SUBTYPE_RIFF = Guid('{4995daee-9ee6-11d0-a40e-00a0c9223196}')
KSDATAFORMAT_SUBTYPE_RIFFMIDI = Guid('{4995daf0-9ee6-11d0-a40e-00a0c9223196}')
KSDATAFORMAT_SUBTYPE_RIFFWAVE = Guid('{e436eb8b-524f-11ce-9f53-0020af0ba770}')
KSDATAFORMAT_SUBTYPE_SDDS_AUDIO = Guid('{e06d8034-db46-11cf-b4d1-00805f6cbbea}')
KSDATAFORMAT_SUBTYPE_STANDARD_AC3_AUDIO = Guid('{36523b25-8ee5-11d1-8ca3-0060b057664a}')
KSDATAFORMAT_SUBTYPE_STANDARD_MPEG1_AUDIO = Guid('{36523b22-8ee5-11d1-8ca3-0060b057664a}')
KSDATAFORMAT_SUBTYPE_STANDARD_MPEG1_VIDEO = Guid('{36523b21-8ee5-11d1-8ca3-0060b057664a}')
KSDATAFORMAT_SUBTYPE_STANDARD_MPEG2_AUDIO = Guid('{36523b24-8ee5-11d1-8ca3-0060b057664a}')
KSDATAFORMAT_SUBTYPE_STANDARD_MPEG2_VIDEO = Guid('{36523b23-8ee5-11d1-8ca3-0060b057664a}')
KSDATAFORMAT_SUBTYPE_SUBPICTURE = Guid('{e06d802d-db46-11cf-b4d1-00805f6cbbea}')
KSDATAFORMAT_SUBTYPE_TELETEXT = Guid('{f72a76e3-eb0a-11d0-ace4-0000c0cc16ba}')
KSDATAFORMAT_SUBTYPE_VPVBI = Guid('{5a9b6a41-1a22-11d1-bad9-00609744111a}')
KSDATAFORMAT_SUBTYPE_VPVideo = Guid('{5a9b6a40-1a22-11d1-bad9-00609744111a}')
KSDATAFORMAT_SUBTYPE_WAVEFORMATEX = Guid('{00000000-0000-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_WMAUDIO2 = Guid('{00000161-0000-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_WMAUDIO3 = Guid('{00000162-0000-0010-8000-00aa00389b71}')
KSDATAFORMAT_SUBTYPE_WMAUDIO_LOSSLESS = Guid('{00000163-0000-0010-8000-00aa00389b71}')
KSDATAFORMAT_TYPE_ANALOGAUDIO = Guid('{0482dee1-7817-11cf-8a03-00aa006ecb65}')
KSDATAFORMAT_TYPE_ANALOGVIDEO = Guid('{0482dde1-7817-11cf-8a03-00aa006ecb65}')
KSDATAFORMAT_TYPE_AUDIO = Guid('{73647561-0000-0010-8000-00aa00389b71}')
KSDATAFORMAT_TYPE_AUXLine21Data = Guid('{670aea80-3a82-11d0-b79b-00aa003767a7}')
KSDATAFORMAT_TYPE_DVD_ENCRYPTED_PACK = Guid('{ed0b916a-044d-11d1-aa78-00c04fc31d60}')
KSDATAFORMAT_TYPE_IMAGE = Guid('{72178c23-e45b-11d5-bc2a-00b0d0f3f4ab}')
KSDATAFORMAT_TYPE_MIDI = Guid('{7364696d-0000-0010-8000-00aa00389b71}')
KSDATAFORMAT_TYPE_MPEG2_PES = Guid('{e06d8020-db46-11cf-b4d1-00805f6cbbea}')
KSDATAFORMAT_TYPE_MPEG2_PROGRAM = Guid('{e06d8022-db46-11cf-b4d1-00805f6cbbea}')
KSDATAFORMAT_TYPE_MPEG2_TRANSPORT = Guid('{e06d8023-db46-11cf-b4d1-00805f6cbbea}')
KSDATAFORMAT_TYPE_MUSIC = Guid('{e725d360-62cc-11cf-a5d6-28db04c10000}')
KSDATAFORMAT_TYPE_NABTS = Guid('{e757bca0-39ac-11d1-a9f5-00c04fbbde8f}')
KSDATAFORMAT_TYPE_STANDARD_ELEMENTARY_STREAM = Guid('{36523b11-8ee5-11d1-8ca3-0060b057664a}')
KSDATAFORMAT_TYPE_STANDARD_PACK_HEADER = Guid('{36523b13-8ee5-11d1-8ca3-0060b057664a}')
KSDATAFORMAT_TYPE_STANDARD_PES_PACKET = Guid('{36523b12-8ee5-11d1-8ca3-0060b057664a}')
KSDATAFORMAT_TYPE_STREAM = Guid('{e436eb83-524f-11ce-9f53-0020af0ba770}')
KSDATAFORMAT_TYPE_TEXT = Guid('{73747874-0000-0010-8000-00aa00389b71}')
KSDATAFORMAT_TYPE_VBI = Guid('{f72a76e1-eb0a-11d0-ace4-0000c0cc16ba}')
KSDATAFORMAT_TYPE_VIDEO = Guid('{73646976-0000-0010-8000-00aa00389b71}')
class KSDATARANGE_AUDIO(Structure):
    DataRange: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    MaximumChannels: UInt32
    MinimumBitsPerSample: UInt32
    MaximumBitsPerSample: UInt32
    MinimumSampleFrequency: UInt32
    MaximumSampleFrequency: UInt32
class KSDATARANGE_MUSIC(Structure):
    DataRange: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    Technology: Guid
    Channels: UInt32
    Notes: UInt32
    ChannelMask: UInt32
KSDEGRADESETID_Standard = Guid('{9f564180-704c-11d0-a5d6-28db04c10000}')
KSDEGRADE_STANDARD = Int32
KSDEGRADE_STANDARD_SAMPLE: win32more.Windows.Win32.Media.KernelStreaming.KSDEGRADE_STANDARD = 0
KSDEGRADE_STANDARD_QUALITY: win32more.Windows.Win32.Media.KernelStreaming.KSDEGRADE_STANDARD = 1
KSDEGRADE_STANDARD_COMPUTATION: win32more.Windows.Win32.Media.KernelStreaming.KSDEGRADE_STANDARD = 2
KSDEGRADE_STANDARD_SKIP: win32more.Windows.Win32.Media.KernelStreaming.KSDEGRADE_STANDARD = 3
class KSDEVICE_PROFILE_INFO(Structure):
    Type: UInt32
    Size: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Camera: _Camera_e__Struct
        class _Camera_e__Struct(Structure):
            Info: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_PROFILE_INFO
            Reserved: UInt32
            ConcurrencyCount: UInt32
            Concurrency: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_PROFILE_CONCURRENCYINFO)
KSDEVICE_THERMAL_STATE = Int32
KSDEVICE_THERMAL_STATE_LOW: win32more.Windows.Win32.Media.KernelStreaming.KSDEVICE_THERMAL_STATE = 0
KSDEVICE_THERMAL_STATE_HIGH: win32more.Windows.Win32.Media.KernelStreaming.KSDEVICE_THERMAL_STATE = 1
class KSDISPLAYCHANGE(Structure):
    PelsWidth: UInt32
    PelsHeight: UInt32
    BitsPerPel: UInt32
    DeviceID: Char * 1
class KSDS3D_BUFFER_ALL(Structure):
    Position: win32more.Windows.Win32.Media.KernelStreaming.DS3DVECTOR
    Velocity: win32more.Windows.Win32.Media.KernelStreaming.DS3DVECTOR
    InsideConeAngle: UInt32
    OutsideConeAngle: UInt32
    ConeOrientation: win32more.Windows.Win32.Media.KernelStreaming.DS3DVECTOR
    ConeOutsideVolume: Int32
    MinDistance: Single
    MaxDistance: Single
    Mode: UInt32
class KSDS3D_BUFFER_CONE_ANGLES(Structure):
    InsideConeAngle: UInt32
    OutsideConeAngle: UInt32
KSDS3D_HRTF_COEFF_FORMAT = Int32
FLOAT_COEFF: win32more.Windows.Win32.Media.KernelStreaming.KSDS3D_HRTF_COEFF_FORMAT = 0
SHORT_COEFF: win32more.Windows.Win32.Media.KernelStreaming.KSDS3D_HRTF_COEFF_FORMAT = 1
KSDS3D_COEFF_COUNT: win32more.Windows.Win32.Media.KernelStreaming.KSDS3D_HRTF_COEFF_FORMAT = 2
class KSDS3D_HRTF_FILTER_FORMAT_MSG(Structure):
    FilterMethod: win32more.Windows.Win32.Media.KernelStreaming.KSDS3D_HRTF_FILTER_METHOD
    CoeffFormat: win32more.Windows.Win32.Media.KernelStreaming.KSDS3D_HRTF_COEFF_FORMAT
    Version: win32more.Windows.Win32.Media.KernelStreaming.KSDS3D_HRTF_FILTER_VERSION
    Reserved: UInt32
KSDS3D_HRTF_FILTER_METHOD = Int32
DIRECT_FORM: win32more.Windows.Win32.Media.KernelStreaming.KSDS3D_HRTF_FILTER_METHOD = 0
CASCADE_FORM: win32more.Windows.Win32.Media.KernelStreaming.KSDS3D_HRTF_FILTER_METHOD = 1
KSDS3D_FILTER_METHOD_COUNT: win32more.Windows.Win32.Media.KernelStreaming.KSDS3D_HRTF_FILTER_METHOD = 2
KSDS3D_HRTF_FILTER_QUALITY = Int32
FULL_FILTER: win32more.Windows.Win32.Media.KernelStreaming.KSDS3D_HRTF_FILTER_QUALITY = 0
LIGHT_FILTER: win32more.Windows.Win32.Media.KernelStreaming.KSDS3D_HRTF_FILTER_QUALITY = 1
KSDS3D_FILTER_QUALITY_COUNT: win32more.Windows.Win32.Media.KernelStreaming.KSDS3D_HRTF_FILTER_QUALITY = 2
KSDS3D_HRTF_FILTER_VERSION = Int32
DS3D_HRTF_VERSION_1: win32more.Windows.Win32.Media.KernelStreaming.KSDS3D_HRTF_FILTER_VERSION = 0
class KSDS3D_HRTF_INIT_MSG(Structure):
    Size: UInt32
    Quality: win32more.Windows.Win32.Media.KernelStreaming.KSDS3D_HRTF_FILTER_QUALITY
    SampleRate: Single
    MaxFilterSize: UInt32
    FilterTransientMuteLength: UInt32
    FilterOverlapBufferLength: UInt32
    OutputOverlapBufferLength: UInt32
    Reserved: UInt32
class KSDS3D_HRTF_PARAMS_MSG(Structure):
    Size: UInt32
    Enabled: UInt32
    SwapChannels: win32more.Windows.Win32.Foundation.BOOL
    ZeroAzimuth: win32more.Windows.Win32.Foundation.BOOL
    CrossFadeOutput: win32more.Windows.Win32.Foundation.BOOL
    FilterSize: UInt32
class KSDS3D_ITD_PARAMS(Structure):
    Channel: Int32
    VolSmoothScale: Single
    TotalDryAttenuation: Single
    TotalWetAttenuation: Single
    SmoothFrequency: Int32
    Delay: Int32
class KSDS3D_ITD_PARAMS_MSG(Structure):
    Enabled: UInt32
    LeftParams: win32more.Windows.Win32.Media.KernelStreaming.KSDS3D_ITD_PARAMS
    RightParams: win32more.Windows.Win32.Media.KernelStreaming.KSDS3D_ITD_PARAMS
    Reserved: UInt32
class KSDS3D_LISTENER_ALL(Structure):
    Position: win32more.Windows.Win32.Media.KernelStreaming.DS3DVECTOR
    Velocity: win32more.Windows.Win32.Media.KernelStreaming.DS3DVECTOR
    OrientFront: win32more.Windows.Win32.Media.KernelStreaming.DS3DVECTOR
    OrientTop: win32more.Windows.Win32.Media.KernelStreaming.DS3DVECTOR
    DistanceFactor: Single
    RolloffFactor: Single
    DopplerFactor: Single
class KSDS3D_LISTENER_ORIENTATION(Structure):
    Front: win32more.Windows.Win32.Media.KernelStreaming.DS3DVECTOR
    Top: win32more.Windows.Win32.Media.KernelStreaming.DS3DVECTOR
class KSERROR(Structure):
    Context: VoidPtr
    Status: UInt32
class KSEVENTDATA(Structure):
    NotificationType: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        EventHandle: _EventHandle_e__Struct
        SemaphoreHandle: _SemaphoreHandle_e__Struct
        Alignment: _Alignment_e__Struct
        class _EventHandle_e__Struct(Structure):
            Event: win32more.Windows.Win32.Foundation.HANDLE
            Reserved: UIntPtr * 2
        class _SemaphoreHandle_e__Struct(Structure):
            Semaphore: win32more.Windows.Win32.Foundation.HANDLE
            Reserved: UInt32
            Adjustment: Int32
        class _Alignment_e__Struct(Structure):
            Unused: VoidPtr
            Alignment: IntPtr * 2
KSEVENTSETID_AudioControlChange = Guid('{e85e9698-fa2f-11d1-95bd-00c04fb925d3}')
KSEVENTSETID_CameraAsyncControl = Guid('{22a11754-9701-4088-b33f-6b9cbc52df5e}')
KSEVENTSETID_CameraEvent = Guid('{7899b2e0-6b43-4964-9d2a-a21f4061f576}')
KSEVENTSETID_Clock = Guid('{364d8e20-62c7-11cf-a5d6-28db04c10000}')
KSEVENTSETID_Connection = Guid('{7f4bcbe0-9ea5-11cf-a5d6-28db04c10000}')
KSEVENTSETID_Device = Guid('{288296ec-9f94-41b4-a153-aa31aeecb33f}')
KSEVENTSETID_DynamicFormatChange = Guid('{162ac456-83d7-4239-96df-c75ffa138bc6}')
KSEVENTSETID_EXTDEV_Command = Guid('{109c7988-b3cb-11d2-b48e-006097b3391b}')
KSEVENTSETID_ExtendedCameraControl = Guid('{571c92c9-13a2-47e3-a649-d2a778166384}')
KSEVENTSETID_LoopedStreaming = Guid('{4682b940-c6ef-11d0-96d8-00aa0051e51d}')
KSEVENTSETID_PinCapsChange = Guid('{dd4f192e-3b78-49ad-a534-2c315b822000}')
KSEVENTSETID_SoundDetector = Guid('{69785c9b-fc2d-49d6-ac32-4799f87de9f6}')
KSEVENTSETID_StreamAllocator = Guid('{75d95571-073c-11d0-a161-0020afd156e4}')
KSEVENTSETID_Telephony = Guid('{b77f12b4-ceb4-4484-8d5e-52c1e7d8762d}')
KSEVENTSETID_VIDCAPTOSTI = Guid('{db47de20-f628-11d1-ba41-00a0c90d2b05}')
KSEVENTSETID_VIDCAP_TVAUDIO = Guid('{6a2e0651-28e4-11d0-a18c-00a0c9118956}')
KSEVENTSETID_VPNotify = Guid('{20c5598e-d3c8-11d0-8dfc-00c04fd7c08b}')
KSEVENTSETID_VPVBINotify = Guid('{ec529b01-1a1f-11d1-bad9-00609744111a}')
KSEVENTSETID_VolumeLimit = Guid('{da168465-3a7c-4858-9d4a-3e8e24701aef}')
KSEVENT_AUDIO_CONTROL_CHANGE = Int32
KSEVENT_CONTROL_CHANGE: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_AUDIO_CONTROL_CHANGE = 0
KSEVENT_CAMERACONTROL = Int32
KSEVENT_CAMERACONTROL_FOCUS: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_CAMERACONTROL = 0
KSEVENT_CAMERACONTROL_ZOOM: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_CAMERACONTROL = 1
KSEVENT_CAMERAEVENT = Int32
KSEVENT_PHOTO_SAMPLE_SCANNED: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_CAMERAEVENT = 0
KSEVENT_CLOCK_POSITION = Int32
KSEVENT_CLOCK_INTERVAL_MARK: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_CLOCK_POSITION = 0
KSEVENT_CLOCK_POSITION_MARK: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_CLOCK_POSITION = 1
KSEVENT_CONNECTION = Int32
KSEVENT_CONNECTION_POSITIONUPDATE: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_CONNECTION = 0
KSEVENT_CONNECTION_DATADISCONTINUITY: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_CONNECTION = 1
KSEVENT_CONNECTION_TIMEDISCONTINUITY: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_CONNECTION = 2
KSEVENT_CONNECTION_PRIORITY: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_CONNECTION = 3
KSEVENT_CONNECTION_ENDOFSTREAM: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_CONNECTION = 4
KSEVENT_CROSSBAR = Int32
KSEVENT_CROSSBAR_CHANGED: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_CROSSBAR = 0
KSEVENT_DEVCMD = Int32
KSEVENT_EXTDEV_COMMAND_NOTIFY_INTERIM_READY: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_DEVCMD = 0
KSEVENT_EXTDEV_COMMAND_CONTROL_INTERIM_READY: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_DEVCMD = 1
KSEVENT_EXTDEV_COMMAND_BUSRESET: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_DEVCMD = 2
KSEVENT_EXTDEV_TIMECODE_UPDATE: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_DEVCMD = 3
KSEVENT_EXTDEV_OPERATION_MODE_UPDATE: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_DEVCMD = 4
KSEVENT_EXTDEV_TRANSPORT_STATE_UPDATE: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_DEVCMD = 5
KSEVENT_EXTDEV_NOTIFY_REMOVAL: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_DEVCMD = 6
KSEVENT_EXTDEV_NOTIFY_MEDIUM_CHANGE: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_DEVCMD = 7
KSEVENT_DEVICE = Int32
KSEVENT_DEVICE_LOST: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_DEVICE = 0
KSEVENT_DEVICE_PREEMPTED: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_DEVICE = 1
KSEVENT_DEVICE_THERMAL_HIGH: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_DEVICE = 2
KSEVENT_DEVICE_THERMAL_LOW: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_DEVICE = 3
KSEVENT_DYNAMICFORMATCHANGE = Int32
KSEVENT_DYNAMIC_FORMAT_CHANGE: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_DYNAMICFORMATCHANGE = 0
KSEVENT_LOOPEDSTREAMING = Int32
KSEVENT_LOOPEDSTREAMING_POSITION: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_LOOPEDSTREAMING = 0
KSEVENT_PINCAPS_CHANGENOTIFICATIONS = Int32
KSEVENT_PINCAPS_FORMATCHANGE: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_PINCAPS_CHANGENOTIFICATIONS = 0
KSEVENT_PINCAPS_JACKINFOCHANGE: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_PINCAPS_CHANGENOTIFICATIONS = 1
KSEVENT_SOUNDDETECTOR = Int32
KSEVENT_SOUNDDETECTOR_MATCHDETECTED: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_SOUNDDETECTOR = 1
KSEVENT_STREAMALLOCATOR = Int32
KSEVENT_STREAMALLOCATOR_INTERNAL_FREEFRAME: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_STREAMALLOCATOR = 0
KSEVENT_STREAMALLOCATOR_FREEFRAME: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_STREAMALLOCATOR = 1
KSEVENT_TELEPHONY = Int32
KSEVENT_TELEPHONY_ENDPOINTPAIRS_CHANGED: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_TELEPHONY = 0
class KSEVENT_TIME_INTERVAL(Structure):
    EventData: win32more.Windows.Win32.Media.KernelStreaming.KSEVENTDATA
    TimeBase: Int64
    Interval: Int64
class KSEVENT_TIME_MARK(Structure):
    EventData: win32more.Windows.Win32.Media.KernelStreaming.KSEVENTDATA
    MarkTime: Int64
KSEVENT_TUNER = Int32
KSEVENT_TUNER_CHANGED: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_TUNER = 0
KSEVENT_TUNER_INITIATE_SCAN: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_TUNER = 1
class KSEVENT_TUNER_INITIATE_SCAN_S(Structure):
    EventData: win32more.Windows.Win32.Media.KernelStreaming.KSEVENTDATA
    StartFrequency: UInt32
    EndFrequency: UInt32
KSEVENT_TVAUDIO = Int32
KSEVENT_TVAUDIO_CHANGED: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_TVAUDIO = 0
KSEVENT_VIDCAPTOSTI = Int32
KSEVENT_VIDCAPTOSTI_EXT_TRIGGER: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_VIDCAPTOSTI = 0
KSEVENT_VIDCAP_AUTO_UPDATE: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_VIDCAPTOSTI = 1
KSEVENT_VIDCAP_SEARCH: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_VIDCAPTOSTI = 2
KSEVENT_VIDEODECODER = Int32
KSEVENT_VIDEODECODER_CHANGED: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_VIDEODECODER = 0
KSEVENT_VOLUMELIMIT = Int32
KSEVENT_VOLUMELIMIT_CHANGED: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_VOLUMELIMIT = 0
KSEVENT_VPNOTIFY = Int32
KSEVENT_VPNOTIFY_FORMATCHANGE: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_VPNOTIFY = 0
KSEVENT_VPVBINOTIFY = Int32
KSEVENT_VPVBINOTIFY_FORMATCHANGE: win32more.Windows.Win32.Media.KernelStreaming.KSEVENT_VPVBINOTIFY = 0
class KSE_NODE(Structure):
    Event: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    NodeId: UInt32
    Reserved: UInt32
class KSE_PIN(Structure):
    Event: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    PinId: UInt32
    Reserved: UInt32
class KSFRAMETIME(Structure):
    Duration: Int64
    FrameFlags: UInt32
    Reserved: UInt32
class KSGOP_USERDATA(Structure):
    sc: UInt32
    reserved1: UInt32
    cFields: Byte
    l21Data: win32more.Windows.Win32.Foundation.CHAR * 3
class KSIDENTIFIER(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        Alignment: Int64
        class _Anonymous_e__Struct(Structure):
            Set: Guid
            Id: UInt32
            Flags: UInt32
KSINTERFACESETID_FileIo = Guid('{8c6f932c-e771-11d0-b8ff-00a0c9223196}')
KSINTERFACESETID_Media = Guid('{3a13eb40-30a7-11d0-a5d6-28db04c10000}')
KSINTERFACESETID_Standard = Guid('{1a8766a0-62ce-11cf-a5d6-28db04c10000}')
KSINTERFACE_FILEIO = Int32
KSINTERFACE_FILEIO_STREAMING: win32more.Windows.Win32.Media.KernelStreaming.KSINTERFACE_FILEIO = 0
KSINTERFACE_MEDIA = Int32
KSINTERFACE_MEDIA_MUSIC: win32more.Windows.Win32.Media.KernelStreaming.KSINTERFACE_MEDIA = 0
KSINTERFACE_MEDIA_WAVE_BUFFERED: win32more.Windows.Win32.Media.KernelStreaming.KSINTERFACE_MEDIA = 1
KSINTERFACE_MEDIA_WAVE_QUEUED: win32more.Windows.Win32.Media.KernelStreaming.KSINTERFACE_MEDIA = 2
KSINTERFACE_STANDARD = Int32
KSINTERFACE_STANDARD_STREAMING: win32more.Windows.Win32.Media.KernelStreaming.KSINTERFACE_STANDARD = 0
KSINTERFACE_STANDARD_LOOPED_STREAMING: win32more.Windows.Win32.Media.KernelStreaming.KSINTERFACE_STANDARD = 1
KSINTERFACE_STANDARD_CONTROL: win32more.Windows.Win32.Media.KernelStreaming.KSINTERFACE_STANDARD = 2
class KSINTERVAL(Structure):
    TimeBase: Int64
    Interval: Int64
KSIOOPERATION = Int32
KsIoOperation_Write: win32more.Windows.Win32.Media.KernelStreaming.KSIOOPERATION = 0
KsIoOperation_Read: win32more.Windows.Win32.Media.KernelStreaming.KSIOOPERATION = 1
class KSJACK_DESCRIPTION(Structure):
    ChannelMapping: UInt32
    Color: UInt32
    ConnectionType: win32more.Windows.Win32.Media.KernelStreaming.EPcxConnectionType
    GeoLocation: win32more.Windows.Win32.Media.KernelStreaming.EPcxGeoLocation
    GenLocation: win32more.Windows.Win32.Media.KernelStreaming.EPcxGenLocation
    PortConnection: win32more.Windows.Win32.Media.KernelStreaming.EPxcPortConnection
    IsConnected: win32more.Windows.Win32.Foundation.BOOL
class KSJACK_DESCRIPTION2(Structure):
    DeviceStateInfo: UInt32
    JackCapabilities: UInt32
class KSJACK_DESCRIPTION3(Structure):
    ConfigId: UInt32
KSJACK_SINK_CONNECTIONTYPE = Int32
KSJACK_SINK_CONNECTIONTYPE_HDMI: win32more.Windows.Win32.Media.KernelStreaming.KSJACK_SINK_CONNECTIONTYPE = 0
KSJACK_SINK_CONNECTIONTYPE_DISPLAYPORT: win32more.Windows.Win32.Media.KernelStreaming.KSJACK_SINK_CONNECTIONTYPE = 1
class KSJACK_SINK_INFORMATION(Structure):
    ConnType: win32more.Windows.Win32.Media.KernelStreaming.KSJACK_SINK_CONNECTIONTYPE
    ManufacturerId: UInt16
    ProductId: UInt16
    AudioLatency: UInt16
    HDCPCapable: win32more.Windows.Win32.Foundation.BOOL
    AICapable: win32more.Windows.Win32.Foundation.BOOL
    SinkDescriptionLength: Byte
    SinkDescription: Char * 32
    PortId: win32more.Windows.Win32.Foundation.LUID
KSMEDIUMSETID_MidiBus = Guid('{05908040-3246-11d0-a5d6-28db04c10000}')
KSMEDIUMSETID_Standard = Guid('{4747b320-62ce-11cf-a5d6-28db04c10000}')
KSMEDIUMSETID_VPBus = Guid('{a18c15ec-ce43-11d0-abe7-00a0c9223196}')
KSMEMORY_TYPE_DEVICE_UNKNOWN = Guid('{091bb639-603f-11d1-b067-00a0c9062802}')
KSMEMORY_TYPE_KERNEL_NONPAGED = Guid('{4a6d5fc4-7895-11d1-b069-00a0c9062802}')
KSMEMORY_TYPE_KERNEL_PAGED = Guid('{d833f8f8-7894-11d1-b069-00a0c9062802}')
KSMEMORY_TYPE_SYSTEM = Guid('{091bb638-603f-11d1-b067-00a0c9062802}')
KSMEMORY_TYPE_USER = Guid('{8cb0fc28-7893-11d1-b069-00a0c9062802}')
KSMETHODSETID_StreamAllocator = Guid('{cf6e4341-ec87-11cf-a130-0020afd156e4}')
KSMETHODSETID_StreamIo = Guid('{65d003ca-1523-11d2-b27a-00a0c9223196}')
KSMETHODSETID_Wavetable = Guid('{dcef31eb-d907-11d0-9583-00c04fb925d3}')
KSMETHOD_STREAMALLOCATOR = Int32
KSMETHOD_STREAMALLOCATOR_ALLOC: win32more.Windows.Win32.Media.KernelStreaming.KSMETHOD_STREAMALLOCATOR = 0
KSMETHOD_STREAMALLOCATOR_FREE: win32more.Windows.Win32.Media.KernelStreaming.KSMETHOD_STREAMALLOCATOR = 1
KSMETHOD_STREAMIO = Int32
KSMETHOD_STREAMIO_READ: win32more.Windows.Win32.Media.KernelStreaming.KSMETHOD_STREAMIO = 0
KSMETHOD_STREAMIO_WRITE: win32more.Windows.Win32.Media.KernelStreaming.KSMETHOD_STREAMIO = 1
KSMETHOD_WAVETABLE = Int32
KSMETHOD_WAVETABLE_WAVE_ALLOC: win32more.Windows.Win32.Media.KernelStreaming.KSMETHOD_WAVETABLE = 0
KSMETHOD_WAVETABLE_WAVE_FREE: win32more.Windows.Win32.Media.KernelStreaming.KSMETHOD_WAVETABLE = 1
KSMETHOD_WAVETABLE_WAVE_FIND: win32more.Windows.Win32.Media.KernelStreaming.KSMETHOD_WAVETABLE = 2
KSMETHOD_WAVETABLE_WAVE_WRITE: win32more.Windows.Win32.Media.KernelStreaming.KSMETHOD_WAVETABLE = 3
KSMFT_CATEGORY_AUDIO_DECODER = Guid('{9ea73fb4-ef7a-4559-8d5d-719d8f0426c7}')
KSMFT_CATEGORY_AUDIO_EFFECT = Guid('{11064c48-3648-4ed0-932e-05ce8ac811b7}')
KSMFT_CATEGORY_AUDIO_ENCODER = Guid('{91c64bd0-f91e-4d8c-9276-db248279d975}')
KSMFT_CATEGORY_DEMULTIPLEXER = Guid('{a8700a7a-939b-44c5-99d7-76226b23b3f1}')
KSMFT_CATEGORY_MULTIPLEXER = Guid('{059c561e-05ae-4b61-b69d-55b61ee54a7b}')
KSMFT_CATEGORY_OTHER = Guid('{90175d57-b7ea-4901-aeb3-933a8747756f}')
KSMFT_CATEGORY_VIDEO_DECODER = Guid('{d6c02d4b-6833-45b4-971a-05a4b04bab91}')
KSMFT_CATEGORY_VIDEO_EFFECT = Guid('{12e17c21-532c-4a6e-8a1c-40825a736397}')
KSMFT_CATEGORY_VIDEO_ENCODER = Guid('{f79eac7d-e545-4387-bdee-d647d7bde42a}')
KSMFT_CATEGORY_VIDEO_PROCESSOR = Guid('{302ea3fc-aa5f-47f9-9f7a-c2188bb16302}')
KSMICARRAY_MICARRAYTYPE = Int32
KSMICARRAY_MICARRAYTYPE_LINEAR: win32more.Windows.Win32.Media.KernelStreaming.KSMICARRAY_MICARRAYTYPE = 0
KSMICARRAY_MICARRAYTYPE_PLANAR: win32more.Windows.Win32.Media.KernelStreaming.KSMICARRAY_MICARRAYTYPE = 1
KSMICARRAY_MICARRAYTYPE_3D: win32more.Windows.Win32.Media.KernelStreaming.KSMICARRAY_MICARRAYTYPE = 2
KSMICARRAY_MICTYPE = Int32
KSMICARRAY_MICTYPE_OMNIDIRECTIONAL: win32more.Windows.Win32.Media.KernelStreaming.KSMICARRAY_MICTYPE = 0
KSMICARRAY_MICTYPE_SUBCARDIOID: win32more.Windows.Win32.Media.KernelStreaming.KSMICARRAY_MICTYPE = 1
KSMICARRAY_MICTYPE_CARDIOID: win32more.Windows.Win32.Media.KernelStreaming.KSMICARRAY_MICTYPE = 2
KSMICARRAY_MICTYPE_SUPERCARDIOID: win32more.Windows.Win32.Media.KernelStreaming.KSMICARRAY_MICTYPE = 3
KSMICARRAY_MICTYPE_HYPERCARDIOID: win32more.Windows.Win32.Media.KernelStreaming.KSMICARRAY_MICTYPE = 4
KSMICARRAY_MICTYPE_8SHAPED: win32more.Windows.Win32.Media.KernelStreaming.KSMICARRAY_MICTYPE = 5
KSMICARRAY_MICTYPE_VENDORDEFINED: win32more.Windows.Win32.Media.KernelStreaming.KSMICARRAY_MICTYPE = 15
class KSMPEGVID_RECT(Structure):
    StartX: UInt32
    StartY: UInt32
    EndX: UInt32
    EndY: UInt32
class KSMULTIPLE_DATA_PROP(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    MultipleItem: win32more.Windows.Win32.Media.KernelStreaming.KSMULTIPLE_ITEM
class KSMULTIPLE_ITEM(Structure):
    Size: UInt32
    Count: UInt32
class KSMUSICFORMAT(Structure):
    TimeDeltaMs: UInt32
    ByteCount: UInt32
KSMUSIC_TECHNOLOGY_FMSYNTH = Guid('{252c5c80-62e9-11cf-a5d6-28db04c10000}')
KSMUSIC_TECHNOLOGY_PORT = Guid('{86c92e60-62e8-11cf-a5d6-28db04c10000}')
KSMUSIC_TECHNOLOGY_SQSYNTH = Guid('{0ecf4380-62e9-11cf-a5d6-28db04c10000}')
KSMUSIC_TECHNOLOGY_SWSYNTH = Guid('{37407736-3620-11d1-85d3-0000f8754380}')
KSMUSIC_TECHNOLOGY_WAVETABLE = Guid('{394ec7c0-62e9-11cf-a5d6-28db04c10000}')
class KSM_NODE(Structure):
    Method: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    NodeId: UInt32
    Reserved: UInt32
KSNAME_Allocator = Guid('{642f5d00-4791-11d0-a5d6-28db04c10000}')
KSNAME_Clock = Guid('{53172480-4791-11d0-a5d6-28db04c10000}')
KSNAME_Filter = Guid('{9b365890-165f-11d0-a195-0020afd156e4}')
KSNAME_Pin = Guid('{146f1a80-4791-11d0-a5d6-28db04c10000}')
KSNAME_TopologyNode = Guid('{0621061a-ee75-11d0-b915-00a0c9223196}')
class KSNODEPROPERTY(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    NodeId: UInt32
    Reserved: UInt32
if ARCH in 'X64,ARM64':
    class KSNODEPROPERTY_AUDIO_3D_LISTENER(Structure):
        NodeProperty: win32more.Windows.Win32.Media.KernelStreaming.KSNODEPROPERTY
        ListenerId: VoidPtr
elif ARCH in 'X86':
    class KSNODEPROPERTY_AUDIO_3D_LISTENER(Structure):
        NodeProperty: win32more.Windows.Win32.Media.KernelStreaming.KSNODEPROPERTY
        ListenerId: VoidPtr
        Reserved: UInt32
class KSNODEPROPERTY_AUDIO_CHANNEL(Structure):
    NodeProperty: win32more.Windows.Win32.Media.KernelStreaming.KSNODEPROPERTY
    Channel: Int32
    Reserved: UInt32
class KSNODEPROPERTY_AUDIO_DEV_SPECIFIC(Structure):
    NodeProperty: win32more.Windows.Win32.Media.KernelStreaming.KSNODEPROPERTY
    DevSpecificId: UInt32
    DeviceInfo: UInt32
    Length: UInt32
if ARCH in 'X64,ARM64':
    class KSNODEPROPERTY_AUDIO_PROPERTY(Structure):
        NodeProperty: win32more.Windows.Win32.Media.KernelStreaming.KSNODEPROPERTY
        AppContext: VoidPtr
        Length: UInt32
elif ARCH in 'X86':
    class KSNODEPROPERTY_AUDIO_PROPERTY(Structure):
        NodeProperty: win32more.Windows.Win32.Media.KernelStreaming.KSNODEPROPERTY
        AppContext: VoidPtr
        Length: UInt32
        Reserved: UInt32
KSNODETYPE_1394_DA_STREAM = Guid('{dff21fe6-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_1394_DV_STREAM_SOUNDTRACK = Guid('{dff21fe7-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_3D_EFFECTS = Guid('{55515860-c559-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_ADC = Guid('{4d837fe0-c555-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_AGC = Guid('{e88c9ba0-c557-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_ANALOG_CONNECTOR = Guid('{dff21fe1-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_ANALOG_TAPE = Guid('{dff220e7-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_AUDIO_ENGINE = Guid('{35caf6e4-f3b3-4168-bb4b-55e77a461c7e}')
KSNODETYPE_AUDIO_KEYWORDDETECTOR = Guid('{3817e0b8-df58-4375-b669-c49634331f9d}')
KSNODETYPE_AUDIO_LOOPBACK = Guid('{8f42c0b2-91ce-4bcf-9ccd-0e599037ab35}')
KSNODETYPE_AUDIO_MODULE = Guid('{45aab42e-caeb-4052-8aa9-b38cb5109619}')
KSNODETYPE_BIDIRECTIONAL_UNDEFINED = Guid('{dff21de0-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_CABLE_TUNER_AUDIO = Guid('{dff220ee-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_CD_PLAYER = Guid('{dff220e3-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_CHORUS = Guid('{20173f20-c559-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_COMMUNICATION_SPEAKER = Guid('{dff21ce6-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_DAC = Guid('{507ae360-c554-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_DAT_IO_DIGITAL_AUDIO_TAPE = Guid('{dff220e4-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_DCC_IO_DIGITAL_COMPACT_CASSETTE = Guid('{dff220e5-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_DELAY = Guid('{144981e0-c558-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_DEMUX = Guid('{c0eb67d4-e807-11d0-958a-00c04fb925d3}')
KSNODETYPE_DESKTOP_MICROPHONE = Guid('{dff21be2-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_DESKTOP_SPEAKER = Guid('{dff21ce4-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_DEV_SPECIFIC = Guid('{941c7ac0-c559-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_DIGITAL_AUDIO_INTERFACE = Guid('{dff21fe2-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_DISPLAYPORT_INTERFACE = Guid('{e47e4031-3ea6-418d-8f9b-b73843ccba97}')
KSNODETYPE_DOWN_LINE_PHONE = Guid('{dff21ee3-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_DRM_DESCRAMBLE = Guid('{ffbb6e3f-ccfe-4d84-90d9-421418b03a8e}')
KSNODETYPE_DSS_AUDIO = Guid('{dff220ef-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_DVD_AUDIO = Guid('{dff220eb-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_DYN_RANGE_COMPRESSOR = Guid('{08c8a6a8-601f-4af8-8793-d905ff4ca97d}')
KSNODETYPE_ECHO_CANCELING_SPEAKERPHONE = Guid('{dff21de5-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_ECHO_SUPPRESSING_SPEAKERPHONE = Guid('{dff21de4-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_EMBEDDED_UNDEFINED = Guid('{dff220e0-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_EQUALIZATION_NOISE = Guid('{dff220e2-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_EQUALIZER = Guid('{9d41b4a0-c557-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_EXTERNAL_UNDEFINED = Guid('{dff21fe0-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_FM_RX = Guid('{834a733c-f485-41c0-a62b-513025014e40}')
KSNODETYPE_HANDSET = Guid('{dff21de1-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_HDMI_INTERFACE = Guid('{d1b9cc2a-f519-417f-91c9-55fa65481001}')
KSNODETYPE_HEADPHONES = Guid('{dff21ce2-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_HEADSET = Guid('{dff21de2-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_HEAD_MOUNTED_DISPLAY_AUDIO = Guid('{dff21ce3-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_INPUT_UNDEFINED = Guid('{dff21be0-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_LEGACY_AUDIO_CONNECTOR = Guid('{dff21fe4-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_LEVEL_CALIBRATION_NOISE_SOURCE = Guid('{dff220e1-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_LINE_CONNECTOR = Guid('{dff21fe3-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_LOUDNESS = Guid('{41887440-c558-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_LOW_FREQUENCY_EFFECTS_SPEAKER = Guid('{dff21ce7-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_MICROPHONE = Guid('{dff21be1-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_MICROPHONE_ARRAY = Guid('{dff21be5-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_MIDI_ELEMENT = Guid('{01c6fe66-6e48-4c65-ac9b-52db5d656c7e}')
KSNODETYPE_MIDI_JACK = Guid('{265e0c3f-fa39-4df3-ab04-be01b91e299a}')
KSNODETYPE_MINIDISK = Guid('{dff220e6-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_MULTITRACK_RECORDER = Guid('{dff220f2-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_MUTE = Guid('{02b223c0-c557-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_MUX = Guid('{2ceaf780-c556-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_NOISE_SUPPRESS = Guid('{e07f903f-62fd-4e60-8cdd-dea7236665b5}')
KSNODETYPE_OMNI_DIRECTIONAL_MICROPHONE = Guid('{dff21be4-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_OUTPUT_UNDEFINED = Guid('{dff21ce0-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_PARAMETRIC_EQUALIZER = Guid('{19bb3a6a-ce2b-4442-87ec-6727c3cab477}')
KSNODETYPE_PEAKMETER = Guid('{a085651e-5f0d-4b36-a869-d195d6ab4b9e}')
KSNODETYPE_PERSONAL_MICROPHONE = Guid('{dff21be3-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_PHONE_LINE = Guid('{dff21ee1-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_PHONOGRAPH = Guid('{dff220e8-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_PROCESSING_MICROPHONE_ARRAY = Guid('{dff21be6-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_PROLOGIC_DECODER = Guid('{831c2c80-c558-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_PROLOGIC_ENCODER = Guid('{8074c5b2-3c66-11d2-b45a-3078302c2030}')
KSNODETYPE_RADIO_RECEIVER = Guid('{dff220f0-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_RADIO_TRANSMITTER = Guid('{dff220f1-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_REVERB = Guid('{ef0328e0-c558-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_ROOM_SPEAKER = Guid('{dff21ce5-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_SATELLITE_RECEIVER_AUDIO = Guid('{dff220ed-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_SPDIF_INTERFACE = Guid('{dff21fe5-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_SPEAKER = Guid('{dff21ce1-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_SPEAKERPHONE_NO_ECHO_REDUCTION = Guid('{dff21de3-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_SPEAKERS_STATIC_JACK = Guid('{28e04f87-4dbe-4f8d-8589-025d209dfb4a}')
KSNODETYPE_SRC = Guid('{9db7b9e0-c555-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_STEREO_WIDE = Guid('{a9e69800-c558-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_SUM = Guid('{da441a60-c556-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_SUPERMIX = Guid('{e573adc0-c555-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_SYNTHESIZER = Guid('{dff220f3-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_TELEPHONE = Guid('{dff21ee2-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_TELEPHONY_BIDI = Guid('{686d7cc0-d903-4258-b443-3a3d3580741c}')
KSNODETYPE_TELEPHONY_UNDEFINED = Guid('{dff21ee0-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_TONE = Guid('{7607e580-c557-11d0-8a2b-00a0c9255ac1}')
KSNODETYPE_TV_TUNER_AUDIO = Guid('{dff220ec-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_UPDOWN_MIX = Guid('{b7edc5cf-7b63-4ee2-a100-29ee2cb6b2de}')
KSNODETYPE_VCR_AUDIO = Guid('{dff220e9-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_VIDEO_CAMERA_TERMINAL = Guid('{dff229e6-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_VIDEO_DISC_AUDIO = Guid('{dff220ea-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_VIDEO_INPUT_MTT = Guid('{dff229e7-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_VIDEO_INPUT_TERMINAL = Guid('{dff229e2-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_VIDEO_OUTPUT_MTT = Guid('{dff229e8-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_VIDEO_OUTPUT_TERMINAL = Guid('{dff229e3-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_VIDEO_PROCESSING = Guid('{dff229e5-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_VIDEO_SELECTOR = Guid('{dff229e4-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_VIDEO_STREAMING = Guid('{dff229e1-f70f-11d0-b917-00a0c9223196}')
KSNODETYPE_VOLUME = Guid('{3a5acc00-c557-11d0-8a2b-00a0c9255ac1}')
class KSNODE_CREATE(Structure):
    CreateFlags: UInt32
    Node: UInt32
KSNOTIFICATIONID_AudioModule = Guid('{9c2220f0-d9a6-4d5c-a036-573857fd50d2}')
KSNOTIFICATIONID_SoundDetector = Guid('{6389d844-bb32-4c4c-a802-f4b4b77afead}')
KSPEEKOPERATION = Int32
KsPeekOperation_PeekOnly: win32more.Windows.Win32.Media.KernelStreaming.KSPEEKOPERATION = 0
KsPeekOperation_AddRef: win32more.Windows.Win32.Media.KernelStreaming.KSPEEKOPERATION = 1
class KSPIN_CINSTANCES(Structure):
    PossibleCount: UInt32
    CurrentCount: UInt32
KSPIN_COMMUNICATION = Int32
KSPIN_COMMUNICATION_NONE: win32more.Windows.Win32.Media.KernelStreaming.KSPIN_COMMUNICATION = 0
KSPIN_COMMUNICATION_SINK: win32more.Windows.Win32.Media.KernelStreaming.KSPIN_COMMUNICATION = 1
KSPIN_COMMUNICATION_SOURCE: win32more.Windows.Win32.Media.KernelStreaming.KSPIN_COMMUNICATION = 2
KSPIN_COMMUNICATION_BOTH: win32more.Windows.Win32.Media.KernelStreaming.KSPIN_COMMUNICATION = 3
KSPIN_COMMUNICATION_BRIDGE: win32more.Windows.Win32.Media.KernelStreaming.KSPIN_COMMUNICATION = 4
class KSPIN_CONNECT(Structure):
    Interface: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Medium: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    PinId: UInt32
    PinToHandle: win32more.Windows.Win32.Foundation.HANDLE
    Priority: win32more.Windows.Win32.Media.KernelStreaming.KSPRIORITY
KSPIN_DATAFLOW = Int32
KSPIN_DATAFLOW_IN: win32more.Windows.Win32.Media.KernelStreaming.KSPIN_DATAFLOW = 1
KSPIN_DATAFLOW_OUT: win32more.Windows.Win32.Media.KernelStreaming.KSPIN_DATAFLOW = 2
KSPIN_MDL_CACHING_EVENT = Int32
KSPIN_MDL_CACHING_NOTIFY_CLEANUP: win32more.Windows.Win32.Media.KernelStreaming.KSPIN_MDL_CACHING_EVENT = 0
KSPIN_MDL_CACHING_NOTIFY_CLEANALL_WAIT: win32more.Windows.Win32.Media.KernelStreaming.KSPIN_MDL_CACHING_EVENT = 1
KSPIN_MDL_CACHING_NOTIFY_CLEANALL_NOWAIT: win32more.Windows.Win32.Media.KernelStreaming.KSPIN_MDL_CACHING_EVENT = 2
KSPIN_MDL_CACHING_NOTIFY_ADDSAMPLE: win32more.Windows.Win32.Media.KernelStreaming.KSPIN_MDL_CACHING_EVENT = 3
class KSPIN_MDL_CACHING_NOTIFICATION(Structure):
    Event: win32more.Windows.Win32.Media.KernelStreaming.KSPIN_MDL_CACHING_EVENT
    Buffer: VoidPtr
class KSPIN_MDL_CACHING_NOTIFICATION32(Structure):
    Event: win32more.Windows.Win32.Media.KernelStreaming.KSPIN_MDL_CACHING_EVENT
    Buffer: UInt32
class KSPIN_PHYSICALCONNECTION(Structure):
    Size: UInt32
    Pin: UInt32
    SymbolicLinkName: Char * 1
KSPPROPERTY_ALLOCATOR_MDLCACHING = Int32
KSPROPERTY_ALLOCATOR_CLEANUP_CACHEDMDLPAGES: win32more.Windows.Win32.Media.KernelStreaming.KSPPROPERTY_ALLOCATOR_MDLCACHING = 1
class KSPRIORITY(Structure):
    PriorityClass: UInt32
    PrioritySubClass: UInt32
KSPROPERTYSETID_ExtendedCameraControl = Guid('{1cb79112-c0d2-4213-9ca6-cd4fdb927972}')
KSPROPERTYSETID_NetworkCameraControl = Guid('{0e780f09-5745-4e3a-bc9f-f226ea43a6ec}')
KSPROPERTYSETID_PerFrameSettingControl = Guid('{f1f3e261-dee6-4537-bff5-ee206db54aac}')
KSPROPERTY_AC3 = Int32
KSPROPERTY_AC3_ERROR_CONCEALMENT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AC3 = 1
KSPROPERTY_AC3_ALTERNATE_AUDIO: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AC3 = 2
KSPROPERTY_AC3_DOWNMIX: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AC3 = 3
KSPROPERTY_AC3_BIT_STREAM_MODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AC3 = 4
KSPROPERTY_AC3_DIALOGUE_LEVEL: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AC3 = 5
KSPROPERTY_AC3_LANGUAGE_CODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AC3 = 6
KSPROPERTY_AC3_ROOM_TYPE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AC3 = 7
KSPROPERTY_ALLOCATOR_CONTROL = Int32
KSPROPERTY_ALLOCATOR_CONTROL_HONOR_COUNT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_ALLOCATOR_CONTROL = 0
KSPROPERTY_ALLOCATOR_CONTROL_SURFACE_SIZE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_ALLOCATOR_CONTROL = 1
KSPROPERTY_ALLOCATOR_CONTROL_CAPTURE_CAPS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_ALLOCATOR_CONTROL = 2
KSPROPERTY_ALLOCATOR_CONTROL_CAPTURE_INTERLEAVE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_ALLOCATOR_CONTROL = 3
class KSPROPERTY_ALLOCATOR_CONTROL_CAPTURE_CAPS_S(Structure):
    InterleavedCapSupported: UInt32
class KSPROPERTY_ALLOCATOR_CONTROL_CAPTURE_INTERLEAVE_S(Structure):
    InterleavedCapPossible: UInt32
class KSPROPERTY_ALLOCATOR_CONTROL_SURFACE_SIZE_S(Structure):
    CX: UInt32
    CY: UInt32
KSPROPERTY_AUDDECOUT = Int32
KSPROPERTY_AUDDECOUT_MODES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDDECOUT = 0
KSPROPERTY_AUDDECOUT_CUR_MODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDDECOUT = 1
KSPROPERTY_AUDIO = Int32
KSPROPERTY_AUDIO_LATENCY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 1
KSPROPERTY_AUDIO_COPY_PROTECTION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 2
KSPROPERTY_AUDIO_CHANNEL_CONFIG: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 3
KSPROPERTY_AUDIO_VOLUMELEVEL: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 4
KSPROPERTY_AUDIO_POSITION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 5
KSPROPERTY_AUDIO_DYNAMIC_RANGE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 6
KSPROPERTY_AUDIO_QUALITY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 7
KSPROPERTY_AUDIO_SAMPLING_RATE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 8
KSPROPERTY_AUDIO_DYNAMIC_SAMPLING_RATE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 9
KSPROPERTY_AUDIO_MIX_LEVEL_TABLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 10
KSPROPERTY_AUDIO_MIX_LEVEL_CAPS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 11
KSPROPERTY_AUDIO_MUX_SOURCE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 12
KSPROPERTY_AUDIO_MUTE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 13
KSPROPERTY_AUDIO_BASS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 14
KSPROPERTY_AUDIO_MID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 15
KSPROPERTY_AUDIO_TREBLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 16
KSPROPERTY_AUDIO_BASS_BOOST: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 17
KSPROPERTY_AUDIO_EQ_LEVEL: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 18
KSPROPERTY_AUDIO_NUM_EQ_BANDS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 19
KSPROPERTY_AUDIO_EQ_BANDS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 20
KSPROPERTY_AUDIO_AGC: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 21
KSPROPERTY_AUDIO_DELAY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 22
KSPROPERTY_AUDIO_LOUDNESS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 23
KSPROPERTY_AUDIO_WIDE_MODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 24
KSPROPERTY_AUDIO_WIDENESS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 25
KSPROPERTY_AUDIO_REVERB_LEVEL: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 26
KSPROPERTY_AUDIO_CHORUS_LEVEL: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 27
KSPROPERTY_AUDIO_DEV_SPECIFIC: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 28
KSPROPERTY_AUDIO_DEMUX_DEST: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 29
KSPROPERTY_AUDIO_STEREO_ENHANCE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 30
KSPROPERTY_AUDIO_MANUFACTURE_GUID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 31
KSPROPERTY_AUDIO_PRODUCT_GUID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 32
KSPROPERTY_AUDIO_CPU_RESOURCES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 33
KSPROPERTY_AUDIO_STEREO_SPEAKER_GEOMETRY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 34
KSPROPERTY_AUDIO_SURROUND_ENCODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 35
KSPROPERTY_AUDIO_3D_INTERFACE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 36
KSPROPERTY_AUDIO_PEAKMETER: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 37
KSPROPERTY_AUDIO_ALGORITHM_INSTANCE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 38
KSPROPERTY_AUDIO_FILTER_STATE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 39
KSPROPERTY_AUDIO_PREFERRED_STATUS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 40
KSPROPERTY_AUDIO_PEQ_MAX_BANDS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 41
KSPROPERTY_AUDIO_PEQ_NUM_BANDS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 42
KSPROPERTY_AUDIO_PEQ_BAND_CENTER_FREQ: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 43
KSPROPERTY_AUDIO_PEQ_BAND_Q_FACTOR: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 44
KSPROPERTY_AUDIO_PEQ_BAND_LEVEL: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 45
KSPROPERTY_AUDIO_CHORUS_MODULATION_RATE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 46
KSPROPERTY_AUDIO_CHORUS_MODULATION_DEPTH: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 47
KSPROPERTY_AUDIO_REVERB_TIME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 48
KSPROPERTY_AUDIO_REVERB_DELAY_FEEDBACK: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 49
KSPROPERTY_AUDIO_POSITIONEX: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 50
KSPROPERTY_AUDIO_MIC_ARRAY_GEOMETRY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 51
KSPROPERTY_AUDIO_PRESENTATION_POSITION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 52
KSPROPERTY_AUDIO_WAVERT_CURRENT_WRITE_POSITION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 53
KSPROPERTY_AUDIO_LINEAR_BUFFER_POSITION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 54
KSPROPERTY_AUDIO_PEAKMETER2: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 55
KSPROPERTY_AUDIO_WAVERT_CURRENT_WRITE_LASTBUFFER_POSITION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 56
KSPROPERTY_AUDIO_VOLUMELIMIT_ENGAGED: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 57
KSPROPERTY_AUDIO_MIC_SENSITIVITY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 58
KSPROPERTY_AUDIO_MIC_SNR: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 59
KSPROPERTY_AUDIO_MIC_SENSITIVITY2: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIO = 60
KSPROPERTY_AUDIOENGINE = Int32
KSPROPERTY_AUDIOENGINE_LFXENABLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIOENGINE = 0
KSPROPERTY_AUDIOENGINE_GFXENABLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIOENGINE = 1
KSPROPERTY_AUDIOENGINE_MIXFORMAT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIOENGINE = 2
KSPROPERTY_AUDIOENGINE_DEVICEFORMAT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIOENGINE = 4
KSPROPERTY_AUDIOENGINE_SUPPORTEDDEVICEFORMATS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIOENGINE = 5
KSPROPERTY_AUDIOENGINE_DESCRIPTOR: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIOENGINE = 6
KSPROPERTY_AUDIOENGINE_BUFFER_SIZE_RANGE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIOENGINE = 7
KSPROPERTY_AUDIOENGINE_LOOPBACK_PROTECTION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIOENGINE = 8
KSPROPERTY_AUDIOENGINE_VOLUMELEVEL: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIOENGINE = 9
KSPROPERTY_AUDIOENGINE_DEVICECONTROLS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIOENGINE = 10
KSPROPERTY_AUDIOMODULE = Int32
KSPROPERTY_AUDIOMODULE_DESCRIPTORS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIOMODULE = 1
KSPROPERTY_AUDIOMODULE_COMMAND: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIOMODULE = 2
KSPROPERTY_AUDIOMODULE_NOTIFICATION_DEVICE_ID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIOMODULE = 3
KSPROPERTY_AUDIOPOSTURE = Int32
KSPROPERTY_AUDIOPOSTURE_ORIENTATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIOPOSTURE = 1
KSPROPERTY_AUDIORESOURCEMANAGEMENT = Int32
KSPROPERTY_AUDIORESOURCEMANAGEMENT_RESOURCEGROUP: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIORESOURCEMANAGEMENT = 0
KSPROPERTY_AUDIOSIGNALPROCESSING = Int32
KSPROPERTY_AUDIOSIGNALPROCESSING_MODES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_AUDIOSIGNALPROCESSING = 0
KSPROPERTY_BIBLIOGRAPHIC = Int32
KSPROPERTY_BIBLIOGRAPHIC_LEADER: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 1380207648
KSPROPERTY_BIBLIOGRAPHIC_LCCN: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808529952
KSPROPERTY_BIBLIOGRAPHIC_ISBN: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808595488
KSPROPERTY_BIBLIOGRAPHIC_ISSN: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 842149920
KSPROPERTY_BIBLIOGRAPHIC_CATALOGINGSOURCE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808726560
KSPROPERTY_BIBLIOGRAPHIC_MAINPERSONALNAME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808464672
KSPROPERTY_BIBLIOGRAPHIC_MAINCORPORATEBODY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808530208
KSPROPERTY_BIBLIOGRAPHIC_MAINMEETINGNAME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 825307424
KSPROPERTY_BIBLIOGRAPHIC_MAINUNIFORMTITLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808661280
KSPROPERTY_BIBLIOGRAPHIC_UNIFORMTITLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808727072
KSPROPERTY_BIBLIOGRAPHIC_TITLESTATEMENT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 892613152
KSPROPERTY_BIBLIOGRAPHIC_VARYINGFORMTITLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 909390368
KSPROPERTY_BIBLIOGRAPHIC_PUBLICATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808858144
KSPROPERTY_BIBLIOGRAPHIC_PHYSICALDESCRIPTION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808465184
KSPROPERTY_BIBLIOGRAPHIC_ADDEDENTRYTITLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808727584
KSPROPERTY_BIBLIOGRAPHIC_SERIESSTATEMENT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 809055264
KSPROPERTY_BIBLIOGRAPHIC_GENERALNOTE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808465696
KSPROPERTY_BIBLIOGRAPHIC_BIBLIOGRAPHYNOTE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 875574560
KSPROPERTY_BIBLIOGRAPHIC_CONTENTSNOTE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 892351776
KSPROPERTY_BIBLIOGRAPHIC_CREATIONCREDIT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 942683424
KSPROPERTY_BIBLIOGRAPHIC_CITATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808531232
KSPROPERTY_BIBLIOGRAPHIC_PARTICIPANT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 825308448
KSPROPERTY_BIBLIOGRAPHIC_SUMMARY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808596768
KSPROPERTY_BIBLIOGRAPHIC_TARGETAUDIENCE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 825373984
KSPROPERTY_BIBLIOGRAPHIC_ADDEDFORMAVAILABLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808662304
KSPROPERTY_BIBLIOGRAPHIC_SYSTEMDETAILS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 942880032
KSPROPERTY_BIBLIOGRAPHIC_AWARDS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 909653280
KSPROPERTY_BIBLIOGRAPHIC_ADDEDENTRYPERSONALNAME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808465952
KSPROPERTY_BIBLIOGRAPHIC_ADDEDENTRYTOPICALTERM: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808793632
KSPROPERTY_BIBLIOGRAPHIC_ADDEDENTRYGEOGRAPHIC: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 825570848
KSPROPERTY_BIBLIOGRAPHIC_INDEXTERMGENRE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 892679712
KSPROPERTY_BIBLIOGRAPHIC_INDEXTERMCURRICULUM: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 943011360
KSPROPERTY_BIBLIOGRAPHIC_ADDEDENTRYUNIFORMTITLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808662816
KSPROPERTY_BIBLIOGRAPHIC_ADDEDENTRYRELATED: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808728352
KSPROPERTY_BIBLIOGRAPHIC_SERIESSTATEMENTPERSONALNAME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808466464
KSPROPERTY_BIBLIOGRAPHIC_SERIESSTATEMENTUNIFORMTITLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BIBLIOGRAPHIC = 808663072
class KSPROPERTY_BOUNDS_LONG(Union):
    Anonymous1: _Anonymous1_e__Struct
    Anonymous2: _Anonymous2_e__Struct
    class _Anonymous1_e__Struct(Structure):
        SignedMinimum: Int32
        SignedMaximum: Int32
    class _Anonymous2_e__Struct(Structure):
        UnsignedMinimum: UInt32
        UnsignedMaximum: UInt32
class KSPROPERTY_BOUNDS_LONGLONG(Union):
    Anonymous1: _Anonymous1_e__Struct
    Anonymous2: _Anonymous2_e__Struct
    class _Anonymous1_e__Struct(Structure):
        SignedMinimum: Int64
        SignedMaximum: Int64
    class _Anonymous2_e__Struct(Structure):
        UnsignedMinimum: UInt64
        UnsignedMaximum: UInt64
KSPROPERTY_BTAUDIO = Int32
KSPROPERTY_ONESHOT_RECONNECT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BTAUDIO = 0
KSPROPERTY_ONESHOT_DISCONNECT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BTAUDIO = 1
KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = Int32
KSPROPERTY_CAMERACONTROL_EXTENDED_PHOTOMODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 0
KSPROPERTY_CAMERACONTROL_EXTENDED_PHOTOFRAMERATE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 1
KSPROPERTY_CAMERACONTROL_EXTENDED_PHOTOMAXFRAMERATE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 2
KSPROPERTY_CAMERACONTROL_EXTENDED_PHOTOTRIGGERTIME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 3
KSPROPERTY_CAMERACONTROL_EXTENDED_WARMSTART: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 4
KSPROPERTY_CAMERACONTROL_EXTENDED_MAXVIDFPS_PHOTORES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 5
KSPROPERTY_CAMERACONTROL_EXTENDED_PHOTOTHUMBNAIL: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 6
KSPROPERTY_CAMERACONTROL_EXTENDED_SCENEMODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 7
KSPROPERTY_CAMERACONTROL_EXTENDED_TORCHMODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 8
KSPROPERTY_CAMERACONTROL_EXTENDED_FLASHMODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 9
KSPROPERTY_CAMERACONTROL_EXTENDED_OPTIMIZATIONHINT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 10
KSPROPERTY_CAMERACONTROL_EXTENDED_WHITEBALANCEMODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 11
KSPROPERTY_CAMERACONTROL_EXTENDED_EXPOSUREMODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 12
KSPROPERTY_CAMERACONTROL_EXTENDED_FOCUSMODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 13
KSPROPERTY_CAMERACONTROL_EXTENDED_ISO: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 14
KSPROPERTY_CAMERACONTROL_EXTENDED_FIELDOFVIEW: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 15
KSPROPERTY_CAMERACONTROL_EXTENDED_EVCOMPENSATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 16
KSPROPERTY_CAMERACONTROL_EXTENDED_CAMERAANGLEOFFSET: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 17
KSPROPERTY_CAMERACONTROL_EXTENDED_METADATA: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 18
KSPROPERTY_CAMERACONTROL_EXTENDED_FOCUSPRIORITY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 19
KSPROPERTY_CAMERACONTROL_EXTENDED_FOCUSSTATE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 20
KSPROPERTY_CAMERACONTROL_EXTENDED_ROI_CONFIGCAPS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 21
KSPROPERTY_CAMERACONTROL_EXTENDED_ROI_ISPCONTROL: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 22
KSPROPERTY_CAMERACONTROL_EXTENDED_PHOTOCONFIRMATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 23
KSPROPERTY_CAMERACONTROL_EXTENDED_ZOOM: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 24
KSPROPERTY_CAMERACONTROL_EXTENDED_MCC: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 25
KSPROPERTY_CAMERACONTROL_EXTENDED_ISO_ADVANCED: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 26
KSPROPERTY_CAMERACONTROL_EXTENDED_VIDEOSTABILIZATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 27
KSPROPERTY_CAMERACONTROL_EXTENDED_VFR: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 28
KSPROPERTY_CAMERACONTROL_EXTENDED_FACEDETECTION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 29
KSPROPERTY_CAMERACONTROL_EXTENDED_VIDEOHDR: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 30
KSPROPERTY_CAMERACONTROL_EXTENDED_HISTOGRAM: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 31
KSPROPERTY_CAMERACONTROL_EXTENDED_OIS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 32
KSPROPERTY_CAMERACONTROL_EXTENDED_ADVANCEDPHOTO: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 33
KSPROPERTY_CAMERACONTROL_EXTENDED_PROFILE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 34
KSPROPERTY_CAMERACONTROL_EXTENDED_FACEAUTH_MODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 35
KSPROPERTY_CAMERACONTROL_EXTENDED_SECURE_MODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 36
KSPROPERTY_CAMERACONTROL_EXTENDED_VIDEOTEMPORALDENOISING: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 37
KSPROPERTY_CAMERACONTROL_EXTENDED_IRTORCHMODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 38
KSPROPERTY_CAMERACONTROL_EXTENDED_RELATIVEPANELOPTIMIZATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 39
KSPROPERTY_CAMERACONTROL_EXTENDED_EYEGAZECORRECTION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 40
KSPROPERTY_CAMERACONTROL_EXTENDED_BACKGROUNDSEGMENTATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 41
KSPROPERTY_CAMERACONTROL_EXTENDED_DIGITALWINDOW_CONFIGCAPS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 42
KSPROPERTY_CAMERACONTROL_EXTENDED_DIGITALWINDOW: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 43
KSPROPERTY_CAMERACONTROL_EXTENDED_END: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 44
KSPROPERTY_CAMERACONTROL_EXTENDED_END2: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_EXTENDED_PROPERTY = 44
KSPROPERTY_CAMERACONTROL_FLASH = Int32
KSPROPERTY_CAMERACONTROL_FLASH_PROPERTY_ID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_FLASH = 0
class KSPROPERTY_CAMERACONTROL_FLASH_S(Structure):
    Flash: UInt32
    Capabilities: UInt32
class KSPROPERTY_CAMERACONTROL_FOCAL_LENGTH_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    lOcularFocalLength: Int32
    lObjectiveFocalLengthMin: Int32
    lObjectiveFocalLengthMax: Int32
KSPROPERTY_CAMERACONTROL_IMAGE_PIN_CAPABILITY = Int32
KSPROPERTY_CAMERACONTROL_IMAGE_PIN_CAPABILITY_PROPERTY_ID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_IMAGE_PIN_CAPABILITY = 0
class KSPROPERTY_CAMERACONTROL_IMAGE_PIN_CAPABILITY_S(Structure):
    Capabilities: UInt32
    Reserved0: UInt32
class KSPROPERTY_CAMERACONTROL_NODE_FOCAL_LENGTH_S(Structure):
    NodeProperty: win32more.Windows.Win32.Media.KernelStreaming.KSNODEPROPERTY
    lOcularFocalLength: Int32
    lObjectiveFocalLengthMin: Int32
    lObjectiveFocalLengthMax: Int32
class KSPROPERTY_CAMERACONTROL_NODE_S(Structure):
    NodeProperty: win32more.Windows.Win32.Media.KernelStreaming.KSP_NODE
    Value: Int32
    Flags: UInt32
    Capabilities: UInt32
class KSPROPERTY_CAMERACONTROL_NODE_S2(Structure):
    NodeProperty: win32more.Windows.Win32.Media.KernelStreaming.KSP_NODE
    Value1: Int32
    Flags: UInt32
    Capabilities: UInt32
    Value2: Int32
KSPROPERTY_CAMERACONTROL_PERFRAMESETTING_PROPERTY = Int32
KSPROPERTY_CAMERACONTROL_PERFRAMESETTING_CAPABILITY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_PERFRAMESETTING_PROPERTY = 0
KSPROPERTY_CAMERACONTROL_PERFRAMESETTING_SET: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_PERFRAMESETTING_PROPERTY = 1
KSPROPERTY_CAMERACONTROL_PERFRAMESETTING_CLEAR: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_PERFRAMESETTING_PROPERTY = 2
KSPROPERTY_CAMERACONTROL_REGION_OF_INTEREST = Int32
KSPROPERTY_CAMERACONTROL_REGION_OF_INTEREST_PROPERTY_ID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_REGION_OF_INTEREST = 0
class KSPROPERTY_CAMERACONTROL_REGION_OF_INTEREST_S(Structure):
    FocusRect: win32more.Windows.Win32.Foundation.RECT
    AutoFocusLock: win32more.Windows.Win32.Foundation.BOOL
    AutoExposureLock: win32more.Windows.Win32.Foundation.BOOL
    AutoWhitebalanceLock: win32more.Windows.Win32.Foundation.BOOL
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Capabilities: UInt32
        Configuration: UInt32
class KSPROPERTY_CAMERACONTROL_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Value: Int32
    Flags: UInt32
    Capabilities: UInt32
class KSPROPERTY_CAMERACONTROL_S2(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Value1: Int32
    Flags: UInt32
    Capabilities: UInt32
    Value2: Int32
class KSPROPERTY_CAMERACONTROL_S_EX(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Value: Int32
    Flags: UInt32
    Capabilities: UInt32
    FocusRect: win32more.Windows.Win32.Foundation.RECT
class KSPROPERTY_CAMERACONTROL_VIDEOSTABILIZATION_MODE_S(Structure):
    VideoStabilizationMode: UInt32
    Capabilities: UInt32
KSPROPERTY_CAMERACONTROL_VIDEO_STABILIZATION_MODE = Int32
KSPROPERTY_CAMERACONTROL_VIDEO_STABILIZATION_MODE_PROPERTY_ID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERACONTROL_VIDEO_STABILIZATION_MODE = 0
KSPROPERTY_CAMERA_PHOTOTRIGGERTIME_FLAGS = Int32
KSPROPERTY_CAMERA_PHOTOTRIGGERTIME_CLEAR: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERA_PHOTOTRIGGERTIME_FLAGS = 0
KSPROPERTY_CAMERA_PHOTOTRIGGERTIME_SET: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CAMERA_PHOTOTRIGGERTIME_FLAGS = 1
KSPROPERTY_CLOCK = Int32
KSPROPERTY_CLOCK_TIME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CLOCK = 0
KSPROPERTY_CLOCK_PHYSICALTIME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CLOCK = 1
KSPROPERTY_CLOCK_CORRELATEDTIME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CLOCK = 2
KSPROPERTY_CLOCK_CORRELATEDPHYSICALTIME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CLOCK = 3
KSPROPERTY_CLOCK_RESOLUTION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CLOCK = 4
KSPROPERTY_CLOCK_STATE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CLOCK = 5
KSPROPERTY_CONNECTION = Int32
KSPROPERTY_CONNECTION_STATE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CONNECTION = 0
KSPROPERTY_CONNECTION_PRIORITY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CONNECTION = 1
KSPROPERTY_CONNECTION_DATAFORMAT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CONNECTION = 2
KSPROPERTY_CONNECTION_ALLOCATORFRAMING: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CONNECTION = 3
KSPROPERTY_CONNECTION_PROPOSEDATAFORMAT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CONNECTION = 4
KSPROPERTY_CONNECTION_ACQUIREORDERING: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CONNECTION = 5
KSPROPERTY_CONNECTION_ALLOCATORFRAMING_EX: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CONNECTION = 6
KSPROPERTY_CONNECTION_STARTAT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CONNECTION = 7
KSPROPERTY_COPYPROT = Int32
KSPROPERTY_DVDCOPY_CHLG_KEY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_COPYPROT = 1
KSPROPERTY_DVDCOPY_DVD_KEY1: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_COPYPROT = 2
KSPROPERTY_DVDCOPY_DEC_KEY2: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_COPYPROT = 3
KSPROPERTY_DVDCOPY_TITLE_KEY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_COPYPROT = 4
KSPROPERTY_COPY_MACROVISION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_COPYPROT = 5
KSPROPERTY_DVDCOPY_REGION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_COPYPROT = 6
KSPROPERTY_DVDCOPY_SET_COPY_STATE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_COPYPROT = 7
KSPROPERTY_DVDCOPY_DISC_KEY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_COPYPROT = 128
class KSPROPERTY_CROSSBAR_ACTIVE_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    IndexInputPin: UInt32
    Active: UInt32
class KSPROPERTY_CROSSBAR_CAPS_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    NumberOfInputs: UInt32
    NumberOfOutputs: UInt32
class KSPROPERTY_CROSSBAR_PININFO_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Direction: win32more.Windows.Win32.Media.KernelStreaming.KSPIN_DATAFLOW
    Index: UInt32
    PinType: UInt32
    RelatedPinIndex: UInt32
    Medium: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
class KSPROPERTY_CROSSBAR_ROUTE_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    IndexInputPin: UInt32
    IndexOutputPin: UInt32
    CanRoute: UInt32
KSPROPERTY_CYCLIC = Int32
KSPROPERTY_CYCLIC_POSITION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_CYCLIC = 0
class KSPROPERTY_DESCRIPTION(Structure):
    AccessFlags: UInt32
    DescriptionSize: UInt32
    PropTypeSet: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    MembersListCount: UInt32
    Reserved: UInt32
KSPROPERTY_DIRECTSOUND3DBUFFER = Int32
KSPROPERTY_DIRECTSOUND3DBUFFER_ALL: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DBUFFER = 0
KSPROPERTY_DIRECTSOUND3DBUFFER_POSITION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DBUFFER = 1
KSPROPERTY_DIRECTSOUND3DBUFFER_VELOCITY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DBUFFER = 2
KSPROPERTY_DIRECTSOUND3DBUFFER_CONEANGLES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DBUFFER = 3
KSPROPERTY_DIRECTSOUND3DBUFFER_CONEORIENTATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DBUFFER = 4
KSPROPERTY_DIRECTSOUND3DBUFFER_CONEOUTSIDEVOLUME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DBUFFER = 5
KSPROPERTY_DIRECTSOUND3DBUFFER_MINDISTANCE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DBUFFER = 6
KSPROPERTY_DIRECTSOUND3DBUFFER_MAXDISTANCE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DBUFFER = 7
KSPROPERTY_DIRECTSOUND3DBUFFER_MODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DBUFFER = 8
KSPROPERTY_DIRECTSOUND3DLISTENER = Int32
KSPROPERTY_DIRECTSOUND3DLISTENER_ALL: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DLISTENER = 0
KSPROPERTY_DIRECTSOUND3DLISTENER_POSITION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DLISTENER = 1
KSPROPERTY_DIRECTSOUND3DLISTENER_VELOCITY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DLISTENER = 2
KSPROPERTY_DIRECTSOUND3DLISTENER_ORIENTATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DLISTENER = 3
KSPROPERTY_DIRECTSOUND3DLISTENER_DISTANCEFACTOR: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DLISTENER = 4
KSPROPERTY_DIRECTSOUND3DLISTENER_ROLLOFFFACTOR: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DLISTENER = 5
KSPROPERTY_DIRECTSOUND3DLISTENER_DOPPLERFACTOR: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DLISTENER = 6
KSPROPERTY_DIRECTSOUND3DLISTENER_BATCH: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DLISTENER = 7
KSPROPERTY_DIRECTSOUND3DLISTENER_ALLOCATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DIRECTSOUND3DLISTENER = 8
KSPROPERTY_DRMAUDIOSTREAM = Int32
KSPROPERTY_DRMAUDIOSTREAM_CONTENTID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DRMAUDIOSTREAM = 0
class KSPROPERTY_DROPPEDFRAMES_CURRENT_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    PictureNumber: Int64
    DropCount: Int64
    AverageFrameSize: UInt32
KSPROPERTY_DVDSUBPIC = Int32
KSPROPERTY_DVDSUBPIC_PALETTE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DVDSUBPIC = 0
KSPROPERTY_DVDSUBPIC_HLI: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DVDSUBPIC = 1
KSPROPERTY_DVDSUBPIC_COMPOSIT_ON: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_DVDSUBPIC = 2
KSPROPERTY_EXTDEVICE = Int32
KSPROPERTY_EXTDEVICE_ID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTDEVICE = 0
KSPROPERTY_EXTDEVICE_VERSION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTDEVICE = 1
KSPROPERTY_EXTDEVICE_POWER_STATE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTDEVICE = 2
KSPROPERTY_EXTDEVICE_PORT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTDEVICE = 3
KSPROPERTY_EXTDEVICE_CAPABILITIES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTDEVICE = 4
class KSPROPERTY_EXTDEVICE_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    u: _u_e__Union
    class _u_e__Union(Union):
        Capabilities: win32more.Windows.Win32.Media.KernelStreaming.DEVCAPS
        DevPort: UInt32
        PowerState: UInt32
        pawchString: Char * 260
        NodeUniqueID: UInt32 * 2
KSPROPERTY_EXTENSION_UNIT = Int32
KSPROPERTY_EXTENSION_UNIT_INFO: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTENSION_UNIT = 0
KSPROPERTY_EXTENSION_UNIT_CONTROL: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTENSION_UNIT = 1
KSPROPERTY_EXTENSION_UNIT_PASS_THROUGH: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTENSION_UNIT = 65535
KSPROPERTY_EXTXPORT = Int32
KSPROPERTY_EXTXPORT_CAPABILITIES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTXPORT = 0
KSPROPERTY_EXTXPORT_INPUT_SIGNAL_MODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTXPORT = 1
KSPROPERTY_EXTXPORT_OUTPUT_SIGNAL_MODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTXPORT = 2
KSPROPERTY_EXTXPORT_LOAD_MEDIUM: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTXPORT = 3
KSPROPERTY_EXTXPORT_MEDIUM_INFO: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTXPORT = 4
KSPROPERTY_EXTXPORT_STATE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTXPORT = 5
KSPROPERTY_EXTXPORT_STATE_NOTIFY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTXPORT = 6
KSPROPERTY_EXTXPORT_TIMECODE_SEARCH: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTXPORT = 7
KSPROPERTY_EXTXPORT_ATN_SEARCH: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTXPORT = 8
KSPROPERTY_EXTXPORT_RTC_SEARCH: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTXPORT = 9
KSPROPERTY_RAW_AVC_CMD: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_EXTXPORT = 10
class KSPROPERTY_EXTXPORT_NODE_S(Structure):
    NodeProperty: win32more.Windows.Win32.Media.KernelStreaming.KSP_NODE
    u: _u_e__Union
    class _u_e__Union(Union):
        Capabilities: UInt32
        SignalMode: UInt32
        LoadMedium: UInt32
        MediumInfo: win32more.Windows.Win32.Media.KernelStreaming.MEDIUM_INFO
        XPrtState: win32more.Windows.Win32.Media.KernelStreaming.TRANSPORT_STATE
        Timecode: _Timecode_e__Struct
        dwTimecode: UInt32
        dwAbsTrackNumber: UInt32
        RawAVC: _RawAVC_e__Struct
        class _Timecode_e__Struct(Structure):
            frame: Byte
            second: Byte
            minute: Byte
            hour: Byte
        class _RawAVC_e__Struct(Structure):
            PayloadSize: UInt32
            Payload: Byte * 512
class KSPROPERTY_EXTXPORT_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    u: _u_e__Union
    class _u_e__Union(Union):
        Capabilities: UInt32
        SignalMode: UInt32
        LoadMedium: UInt32
        MediumInfo: win32more.Windows.Win32.Media.KernelStreaming.MEDIUM_INFO
        XPrtState: win32more.Windows.Win32.Media.KernelStreaming.TRANSPORT_STATE
        Timecode: _Timecode_e__Struct
        dwTimecode: UInt32
        dwAbsTrackNumber: UInt32
        RawAVC: _RawAVC_e__Struct
        class _Timecode_e__Struct(Structure):
            frame: Byte
            second: Byte
            minute: Byte
            hour: Byte
        class _RawAVC_e__Struct(Structure):
            PayloadSize: UInt32
            Payload: Byte * 512
KSPROPERTY_FMRX_CONTROL = Int32
KSPROPERTY_FMRX_STATE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_FMRX_CONTROL = 0
KSPROPERTY_FMRX_TOPOLOGY = Int32
KSPROPERTY_FMRX_ENDPOINTID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_FMRX_TOPOLOGY = 0
KSPROPERTY_FMRX_VOLUME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_FMRX_TOPOLOGY = 1
KSPROPERTY_FMRX_ANTENNAENDPOINTID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_FMRX_TOPOLOGY = 2
KSPROPERTY_GENERAL = Int32
KSPROPERTY_GENERAL_COMPONENTID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_GENERAL = 0
KSPROPERTY_HRTF3D = Int32
KSPROPERTY_HRTF3D_PARAMS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_HRTF3D = 0
KSPROPERTY_HRTF3D_INITIALIZE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_HRTF3D = 1
KSPROPERTY_HRTF3D_FILTER_FORMAT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_HRTF3D = 2
KSPROPERTY_INTERLEAVEDAUDIO = Int32
KSPROPERTY_INTERLEAVEDAUDIO_FORMATINFORMATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_INTERLEAVEDAUDIO = 1
KSPROPERTY_ITD3D = Int32
KSPROPERTY_ITD3D_PARAMS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_ITD3D = 0
KSPROPERTY_JACK = Int32
KSPROPERTY_JACK_DESCRIPTION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_JACK = 1
KSPROPERTY_JACK_DESCRIPTION2: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_JACK = 2
KSPROPERTY_JACK_SINK_INFO: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_JACK = 3
KSPROPERTY_JACK_CONTAINERID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_JACK = 4
KSPROPERTY_JACK_DESCRIPTION3: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_JACK = 5
class KSPROPERTY_MEDIAAVAILABLE(Structure):
    Earliest: Int64
    Latest: Int64
KSPROPERTY_MEDIASEEKING = Int32
KSPROPERTY_MEDIASEEKING_CAPABILITIES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_MEDIASEEKING = 0
KSPROPERTY_MEDIASEEKING_FORMATS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_MEDIASEEKING = 1
KSPROPERTY_MEDIASEEKING_TIMEFORMAT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_MEDIASEEKING = 2
KSPROPERTY_MEDIASEEKING_POSITION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_MEDIASEEKING = 3
KSPROPERTY_MEDIASEEKING_STOPPOSITION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_MEDIASEEKING = 4
KSPROPERTY_MEDIASEEKING_POSITIONS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_MEDIASEEKING = 5
KSPROPERTY_MEDIASEEKING_DURATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_MEDIASEEKING = 6
KSPROPERTY_MEDIASEEKING_AVAILABLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_MEDIASEEKING = 7
KSPROPERTY_MEDIASEEKING_PREROLL: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_MEDIASEEKING = 8
KSPROPERTY_MEDIASEEKING_CONVERTTIMEFORMAT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_MEDIASEEKING = 9
class KSPROPERTY_MEMBERSHEADER(Structure):
    MembersFlags: UInt32
    MembersSize: UInt32
    MembersCount: UInt32
    Flags: UInt32
KSPROPERTY_MPEG2VID = Int32
KSPROPERTY_MPEG2VID_MODES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_MPEG2VID = 0
KSPROPERTY_MPEG2VID_CUR_MODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_MPEG2VID = 1
KSPROPERTY_MPEG2VID_4_3_RECT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_MPEG2VID = 2
KSPROPERTY_MPEG2VID_16_9_RECT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_MPEG2VID = 3
KSPROPERTY_MPEG2VID_16_9_PANSCAN: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_MPEG2VID = 4
KSPROPERTY_MPEG4_MEDIATYPE_ATTRIBUTES = Int32
KSPROPERTY_MPEG4_MEDIATYPE_SD_BOX: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_MPEG4_MEDIATYPE_ATTRIBUTES = 1
class KSPROPERTY_NETWORKCAMERACONTROL_EVENT_INFO(Structure):
    Header: win32more.Windows.Win32.Media.KernelStreaming.KSCAMERA_METADATA_ITEMHEADER
    EventFilter: Char * 1
class KSPROPERTY_NETWORKCAMERACONTROL_METADATA_INFO(Structure):
    MetadataItems: UInt32
    Size: UInt32
    PTZStatus: win32more.Windows.Win32.Foundation.BOOL
    Events: win32more.Windows.Win32.Foundation.BOOL
    Analytics: win32more.Windows.Win32.Foundation.BOOL
    Reserved: win32more.Windows.Win32.Foundation.BOOL
KSPROPERTY_NETWORKCAMERACONTROL_METADATA_TYPE = Int32
KSPROPERTY_NETWORKCAMERACONTROL_METADATA_TYPE_EVENTSINFO: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_NETWORKCAMERACONTROL_METADATA_TYPE = 0
class KSPROPERTY_NETWORKCAMERACONTROL_NTPINFO_HEADER(Structure):
    Size: UInt32
    Type: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_NETWORKCAMERACONTROL_NTPINFO_TYPE
KSPROPERTY_NETWORKCAMERACONTROL_NTPINFO_TYPE = Int32
KSPROPERTY_NETWORKCAMERACONTROL_NTPINFO_TYPE_DISABLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_NETWORKCAMERACONTROL_NTPINFO_TYPE = 0
KSPROPERTY_NETWORKCAMERACONTROL_NTPINFO_TYPE_HOSTNTP: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_NETWORKCAMERACONTROL_NTPINFO_TYPE = 1
KSPROPERTY_NETWORKCAMERACONTROL_NTPINFO_TYPE_CUSTOM: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_NETWORKCAMERACONTROL_NTPINFO_TYPE = 2
KSPROPERTY_NETWORKCAMERACONTROL_PROPERTY = Int32
KSPROPERTY_NETWORKCAMERACONTROL_NTP: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_NETWORKCAMERACONTROL_PROPERTY = 0
KSPROPERTY_NETWORKCAMERACONTROL_URI: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_NETWORKCAMERACONTROL_PROPERTY = 1
KSPROPERTY_NETWORKCAMERACONTROL_METADATA: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_NETWORKCAMERACONTROL_PROPERTY = 2
KSPROPERTY_NETWORKCAMERACONTROL_EVENTTOPICS_XML: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_NETWORKCAMERACONTROL_PROPERTY = 3
KSPROPERTY_OVERLAYUPDATE = Int32
KSPROPERTY_OVERLAYUPDATE_INTERESTS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_OVERLAYUPDATE = 0
KSPROPERTY_OVERLAYUPDATE_CLIPLIST: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_OVERLAYUPDATE = 1
KSPROPERTY_OVERLAYUPDATE_PALETTE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_OVERLAYUPDATE = 2
KSPROPERTY_OVERLAYUPDATE_COLORKEY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_OVERLAYUPDATE = 4
KSPROPERTY_OVERLAYUPDATE_VIDEOPOSITION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_OVERLAYUPDATE = 8
KSPROPERTY_OVERLAYUPDATE_DISPLAYCHANGE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_OVERLAYUPDATE = 16
KSPROPERTY_OVERLAYUPDATE_COLORREF: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_OVERLAYUPDATE = 268435456
KSPROPERTY_PIN = Int32
KSPROPERTY_PIN_CINSTANCES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_PIN = 0
KSPROPERTY_PIN_CTYPES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_PIN = 1
KSPROPERTY_PIN_DATAFLOW: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_PIN = 2
KSPROPERTY_PIN_DATARANGES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_PIN = 3
KSPROPERTY_PIN_DATAINTERSECTION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_PIN = 4
KSPROPERTY_PIN_INTERFACES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_PIN = 5
KSPROPERTY_PIN_MEDIUMS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_PIN = 6
KSPROPERTY_PIN_COMMUNICATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_PIN = 7
KSPROPERTY_PIN_GLOBALCINSTANCES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_PIN = 8
KSPROPERTY_PIN_NECESSARYINSTANCES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_PIN = 9
KSPROPERTY_PIN_PHYSICALCONNECTION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_PIN = 10
KSPROPERTY_PIN_CATEGORY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_PIN = 11
KSPROPERTY_PIN_NAME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_PIN = 12
KSPROPERTY_PIN_CONSTRAINEDDATARANGES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_PIN = 13
KSPROPERTY_PIN_PROPOSEDATAFORMAT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_PIN = 14
KSPROPERTY_PIN_PROPOSEDATAFORMAT2: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_PIN = 15
KSPROPERTY_PIN_MODEDATAFORMATS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_PIN = 16
class KSPROPERTY_POSITIONS(Structure):
    Current: Int64
    Stop: Int64
    CurrentFlags: win32more.Windows.Win32.Media.KernelStreaming.KS_SEEKING_FLAGS
    StopFlags: win32more.Windows.Win32.Media.KernelStreaming.KS_SEEKING_FLAGS
KSPROPERTY_QUALITY = Int32
KSPROPERTY_QUALITY_REPORT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_QUALITY = 0
KSPROPERTY_QUALITY_ERROR: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_QUALITY = 1
KSPROPERTY_RTAUDIO = Int32
KSPROPERTY_RTAUDIO_GETPOSITIONFUNCTION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_RTAUDIO = 0
KSPROPERTY_RTAUDIO_BUFFER: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_RTAUDIO = 1
KSPROPERTY_RTAUDIO_HWLATENCY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_RTAUDIO = 2
KSPROPERTY_RTAUDIO_POSITIONREGISTER: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_RTAUDIO = 3
KSPROPERTY_RTAUDIO_CLOCKREGISTER: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_RTAUDIO = 4
KSPROPERTY_RTAUDIO_BUFFER_WITH_NOTIFICATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_RTAUDIO = 5
KSPROPERTY_RTAUDIO_REGISTER_NOTIFICATION_EVENT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_RTAUDIO = 6
KSPROPERTY_RTAUDIO_UNREGISTER_NOTIFICATION_EVENT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_RTAUDIO = 7
KSPROPERTY_RTAUDIO_QUERY_NOTIFICATION_SUPPORT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_RTAUDIO = 8
KSPROPERTY_RTAUDIO_PACKETCOUNT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_RTAUDIO = 9
KSPROPERTY_RTAUDIO_PRESENTATION_POSITION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_RTAUDIO = 10
KSPROPERTY_RTAUDIO_GETREADPACKET: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_RTAUDIO = 11
KSPROPERTY_RTAUDIO_SETWRITEPACKET: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_RTAUDIO = 12
KSPROPERTY_RTAUDIO_PACKETVREGISTER: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_RTAUDIO = 13
class KSPROPERTY_SELECTOR_NODE_S(Structure):
    NodeProperty: win32more.Windows.Win32.Media.KernelStreaming.KSP_NODE
    Value: Int32
    Flags: UInt32
    Capabilities: UInt32
class KSPROPERTY_SELECTOR_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Value: Int32
    Flags: UInt32
    Capabilities: UInt32
class KSPROPERTY_SERIAL(Structure):
    PropTypeSet: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Id: UInt32
    PropertyLength: UInt32
class KSPROPERTY_SERIALHDR(Structure):
    PropertySet: Guid
    Count: UInt32
    _pack_ = 1
KSPROPERTY_SOUNDDETECTOR = Int32
KSPROPERTY_SOUNDDETECTOR_SUPPORTEDPATTERNS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_SOUNDDETECTOR = 1
KSPROPERTY_SOUNDDETECTOR_PATTERNS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_SOUNDDETECTOR = 2
KSPROPERTY_SOUNDDETECTOR_ARMED: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_SOUNDDETECTOR = 3
KSPROPERTY_SOUNDDETECTOR_MATCHRESULT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_SOUNDDETECTOR = 4
KSPROPERTY_SOUNDDETECTOR_RESET: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_SOUNDDETECTOR = 5
KSPROPERTY_SOUNDDETECTOR_STREAMINGSUPPORT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_SOUNDDETECTOR = 6
class KSPROPERTY_SPHLI(Structure):
    HLISS: UInt16
    Reserved: UInt16
    StartPTM: UInt32
    EndPTM: UInt32
    StartX: UInt16
    StartY: UInt16
    StopX: UInt16
    StopY: UInt16
    ColCon: win32more.Windows.Win32.Media.KernelStreaming.KS_COLCON
class KSPROPERTY_SPPAL(Structure):
    sppal: win32more.Windows.Win32.Media.KernelStreaming.KS_DVD_YUV * 16
class KSPROPERTY_STEPPING_LONG(Structure):
    SteppingDelta: UInt32
    Reserved: UInt32
    Bounds: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BOUNDS_LONG
class KSPROPERTY_STEPPING_LONGLONG(Structure):
    SteppingDelta: UInt64
    Bounds: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_BOUNDS_LONGLONG
KSPROPERTY_STREAM = Int32
KSPROPERTY_STREAM_ALLOCATOR: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_STREAM = 0
KSPROPERTY_STREAM_QUALITY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_STREAM = 1
KSPROPERTY_STREAM_DEGRADATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_STREAM = 2
KSPROPERTY_STREAM_MASTERCLOCK: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_STREAM = 3
KSPROPERTY_STREAM_TIMEFORMAT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_STREAM = 4
KSPROPERTY_STREAM_PRESENTATIONTIME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_STREAM = 5
KSPROPERTY_STREAM_PRESENTATIONEXTENT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_STREAM = 6
KSPROPERTY_STREAM_FRAMETIME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_STREAM = 7
KSPROPERTY_STREAM_RATECAPABILITY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_STREAM = 8
KSPROPERTY_STREAM_RATE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_STREAM = 9
KSPROPERTY_STREAM_PIPE_ID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_STREAM = 10
KSPROPERTY_STREAMINTERFACE = Int32
KSPROPERTY_STREAMINTERFACE_HEADERSIZE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_STREAMINTERFACE = 0
KSPROPERTY_TELEPHONY_CONTROL = Int32
KSPROPERTY_TELEPHONY_PROVIDERID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TELEPHONY_CONTROL = 0
KSPROPERTY_TELEPHONY_CALLINFO: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TELEPHONY_CONTROL = 1
KSPROPERTY_TELEPHONY_CALLCONTROL: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TELEPHONY_CONTROL = 2
KSPROPERTY_TELEPHONY_PROVIDERCHANGE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TELEPHONY_CONTROL = 3
KSPROPERTY_TELEPHONY_CALLHOLD: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TELEPHONY_CONTROL = 4
KSPROPERTY_TELEPHONY_MUTE_TX: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TELEPHONY_CONTROL = 5
KSPROPERTY_TELEPHONY_TOPOLOGY = Int32
KSPROPERTY_TELEPHONY_ENDPOINTIDPAIR: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TELEPHONY_TOPOLOGY = 0
KSPROPERTY_TELEPHONY_VOLUME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TELEPHONY_TOPOLOGY = 1
KSPROPERTY_TIMECODE = Int32
KSPROPERTY_TIMECODE_READER: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TIMECODE = 0
KSPROPERTY_ATN_READER: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TIMECODE = 1
KSPROPERTY_RTC_READER: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TIMECODE = 2
class KSPROPERTY_TIMECODE_NODE_S(Structure):
    NodeProperty: win32more.Windows.Win32.Media.KernelStreaming.KSP_NODE
    TimecodeSamp: win32more.Windows.Win32.Media.TIMECODE_SAMPLE
class KSPROPERTY_TIMECODE_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    TimecodeSamp: win32more.Windows.Win32.Media.TIMECODE_SAMPLE
KSPROPERTY_TOPOLOGY = Int32
KSPROPERTY_TOPOLOGY_CATEGORIES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TOPOLOGY = 0
KSPROPERTY_TOPOLOGY_NODES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TOPOLOGY = 1
KSPROPERTY_TOPOLOGY_CONNECTIONS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TOPOLOGY = 2
KSPROPERTY_TOPOLOGY_NAME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TOPOLOGY = 3
KSPROPERTY_TOPOLOGYNODE = Int32
KSPROPERTY_TOPOLOGYNODE_ENABLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TOPOLOGYNODE = 1
KSPROPERTY_TOPOLOGYNODE_RESET: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TOPOLOGYNODE = 2
KSPROPERTY_TUNER = Int32
KSPROPERTY_TUNER_CAPS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TUNER = 0
KSPROPERTY_TUNER_MODE_CAPS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TUNER = 1
KSPROPERTY_TUNER_MODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TUNER = 2
KSPROPERTY_TUNER_STANDARD: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TUNER = 3
KSPROPERTY_TUNER_FREQUENCY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TUNER = 4
KSPROPERTY_TUNER_INPUT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TUNER = 5
KSPROPERTY_TUNER_STATUS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TUNER = 6
KSPROPERTY_TUNER_IF_MEDIUM: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TUNER = 7
KSPROPERTY_TUNER_SCAN_CAPS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TUNER = 8
KSPROPERTY_TUNER_SCAN_STATUS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TUNER = 9
KSPROPERTY_TUNER_STANDARD_MODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TUNER = 10
KSPROPERTY_TUNER_NETWORKTYPE_SCAN_CAPS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TUNER = 11
class KSPROPERTY_TUNER_CAPS_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    ModesSupported: UInt32
    VideoMedium: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    TVAudioMedium: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    RadioAudioMedium: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
class KSPROPERTY_TUNER_FREQUENCY_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Frequency: UInt32
    LastFrequency: UInt32
    TuningFlags: UInt32
    VideoSubChannel: UInt32
    AudioSubChannel: UInt32
    Channel: UInt32
    Country: UInt32
class KSPROPERTY_TUNER_IF_MEDIUM_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    IFMedium: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
class KSPROPERTY_TUNER_INPUT_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    InputIndex: UInt32
KSPROPERTY_TUNER_MODES = Int32
KSPROPERTY_TUNER_MODE_TV: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TUNER_MODES = 1
KSPROPERTY_TUNER_MODE_FM_RADIO: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TUNER_MODES = 2
KSPROPERTY_TUNER_MODE_AM_RADIO: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TUNER_MODES = 4
KSPROPERTY_TUNER_MODE_DSS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TUNER_MODES = 8
KSPROPERTY_TUNER_MODE_ATSC: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_TUNER_MODES = 16
class KSPROPERTY_TUNER_MODE_CAPS_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Mode: UInt32
    StandardsSupported: UInt32
    MinFrequency: UInt32
    MaxFrequency: UInt32
    TuningGranularity: UInt32
    NumberOfInputs: UInt32
    SettlingTime: UInt32
    Strategy: UInt32
class KSPROPERTY_TUNER_MODE_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Mode: UInt32
class KSPROPERTY_TUNER_NETWORKTYPE_SCAN_CAPS_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    NetworkType: Guid
    BufferSize: UInt32
    NetworkTunerCapabilities: VoidPtr
class KSPROPERTY_TUNER_SCAN_CAPS_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    fSupportsHardwareAssistedScanning: win32more.Windows.Win32.Foundation.BOOL
    SupportedBroadcastStandards: UInt32
    GUIDBucket: VoidPtr
    lengthofBucket: UInt32
class KSPROPERTY_TUNER_SCAN_STATUS_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    LockStatus: win32more.Windows.Win32.Media.KernelStreaming.TunerLockType
    CurrentFrequency: UInt32
class KSPROPERTY_TUNER_STANDARD_MODE_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    AutoDetect: win32more.Windows.Win32.Foundation.BOOL
class KSPROPERTY_TUNER_STANDARD_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Standard: UInt32
class KSPROPERTY_TUNER_STATUS_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    CurrentFrequency: UInt32
    PLLOffset: UInt32
    SignalStrength: UInt32
    Busy: UInt32
class KSPROPERTY_TVAUDIO_CAPS_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Capabilities: UInt32
    InputMedium: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    OutputMedium: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
class KSPROPERTY_TVAUDIO_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Mode: UInt32
KSPROPERTY_VBICAP = Int32
KSPROPERTY_VBICAP_PROPERTIES_PROTECTION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VBICAP = 1
KSPROPERTY_VBICODECFILTERING = Int32
KSPROPERTY_VBICODECFILTERING_SCANLINES_REQUESTED_BIT_ARRAY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VBICODECFILTERING = 1
KSPROPERTY_VBICODECFILTERING_SCANLINES_DISCOVERED_BIT_ARRAY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VBICODECFILTERING = 2
KSPROPERTY_VBICODECFILTERING_SUBSTREAMS_REQUESTED_BIT_ARRAY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VBICODECFILTERING = 3
KSPROPERTY_VBICODECFILTERING_SUBSTREAMS_DISCOVERED_BIT_ARRAY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VBICODECFILTERING = 4
KSPROPERTY_VBICODECFILTERING_STATISTICS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VBICODECFILTERING = 5
class KSPROPERTY_VBICODECFILTERING_CC_SUBSTREAMS_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Substreams: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_CC_SUBSTREAMS
class KSPROPERTY_VBICODECFILTERING_NABTS_SUBSTREAMS_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Substreams: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_NABTS_SUBSTREAMS
class KSPROPERTY_VBICODECFILTERING_SCANLINES_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Scanlines: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_SCANLINES
class KSPROPERTY_VBICODECFILTERING_STATISTICS_CC_PIN_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Statistics: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_STATISTICS_CC_PIN
class KSPROPERTY_VBICODECFILTERING_STATISTICS_CC_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Statistics: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_STATISTICS_CC
class KSPROPERTY_VBICODECFILTERING_STATISTICS_COMMON_PIN_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Statistics: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_STATISTICS_COMMON_PIN
class KSPROPERTY_VBICODECFILTERING_STATISTICS_COMMON_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Statistics: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_STATISTICS_COMMON
class KSPROPERTY_VBICODECFILTERING_STATISTICS_NABTS_PIN_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Statistics: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_STATISTICS_NABTS_PIN
class KSPROPERTY_VBICODECFILTERING_STATISTICS_NABTS_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Statistics: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_STATISTICS_NABTS
KSPROPERTY_VIDCAP_CAMERACONTROL = Int32
KSPROPERTY_CAMERACONTROL_PAN: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 0
KSPROPERTY_CAMERACONTROL_TILT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 1
KSPROPERTY_CAMERACONTROL_ROLL: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 2
KSPROPERTY_CAMERACONTROL_ZOOM: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 3
KSPROPERTY_CAMERACONTROL_EXPOSURE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 4
KSPROPERTY_CAMERACONTROL_IRIS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 5
KSPROPERTY_CAMERACONTROL_FOCUS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 6
KSPROPERTY_CAMERACONTROL_SCANMODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 7
KSPROPERTY_CAMERACONTROL_PRIVACY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 8
KSPROPERTY_CAMERACONTROL_PANTILT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 9
KSPROPERTY_CAMERACONTROL_PAN_RELATIVE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 10
KSPROPERTY_CAMERACONTROL_TILT_RELATIVE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 11
KSPROPERTY_CAMERACONTROL_ROLL_RELATIVE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 12
KSPROPERTY_CAMERACONTROL_ZOOM_RELATIVE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 13
KSPROPERTY_CAMERACONTROL_EXPOSURE_RELATIVE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 14
KSPROPERTY_CAMERACONTROL_IRIS_RELATIVE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 15
KSPROPERTY_CAMERACONTROL_FOCUS_RELATIVE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 16
KSPROPERTY_CAMERACONTROL_PANTILT_RELATIVE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 17
KSPROPERTY_CAMERACONTROL_FOCAL_LENGTH: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 18
KSPROPERTY_CAMERACONTROL_AUTO_EXPOSURE_PRIORITY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CAMERACONTROL = 19
KSPROPERTY_VIDCAP_CROSSBAR = Int32
KSPROPERTY_CROSSBAR_CAPS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CROSSBAR = 0
KSPROPERTY_CROSSBAR_PININFO: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CROSSBAR = 1
KSPROPERTY_CROSSBAR_CAN_ROUTE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CROSSBAR = 2
KSPROPERTY_CROSSBAR_ROUTE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CROSSBAR = 3
KSPROPERTY_CROSSBAR_INPUT_ACTIVE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_CROSSBAR = 4
KSPROPERTY_VIDCAP_DROPPEDFRAMES = Int32
KSPROPERTY_DROPPEDFRAMES_CURRENT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_DROPPEDFRAMES = 0
KSPROPERTY_VIDCAP_SELECTOR = Int32
KSPROPERTY_SELECTOR_SOURCE_NODE_ID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_SELECTOR = 0
KSPROPERTY_SELECTOR_NUM_SOURCES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_SELECTOR = 1
KSPROPERTY_VIDCAP_TVAUDIO = Int32
KSPROPERTY_TVAUDIO_CAPS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_TVAUDIO = 0
KSPROPERTY_TVAUDIO_MODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_TVAUDIO = 1
KSPROPERTY_TVAUDIO_CURRENTLY_AVAILABLE_MODES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_TVAUDIO = 2
KSPROPERTY_VIDCAP_VIDEOCOMPRESSION = Int32
KSPROPERTY_VIDEOCOMPRESSION_GETINFO: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOCOMPRESSION = 0
KSPROPERTY_VIDEOCOMPRESSION_KEYFRAME_RATE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOCOMPRESSION = 1
KSPROPERTY_VIDEOCOMPRESSION_PFRAMES_PER_KEYFRAME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOCOMPRESSION = 2
KSPROPERTY_VIDEOCOMPRESSION_QUALITY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOCOMPRESSION = 3
KSPROPERTY_VIDEOCOMPRESSION_OVERRIDE_KEYFRAME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOCOMPRESSION = 4
KSPROPERTY_VIDEOCOMPRESSION_OVERRIDE_FRAME_SIZE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOCOMPRESSION = 5
KSPROPERTY_VIDEOCOMPRESSION_WINDOWSIZE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOCOMPRESSION = 6
KSPROPERTY_VIDCAP_VIDEOCONTROL = Int32
KSPROPERTY_VIDEOCONTROL_CAPS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOCONTROL = 0
KSPROPERTY_VIDEOCONTROL_ACTUAL_FRAME_RATE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOCONTROL = 1
KSPROPERTY_VIDEOCONTROL_FRAME_RATES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOCONTROL = 2
KSPROPERTY_VIDEOCONTROL_MODE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOCONTROL = 3
KSPROPERTY_VIDCAP_VIDEODECODER = Int32
KSPROPERTY_VIDEODECODER_CAPS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEODECODER = 0
KSPROPERTY_VIDEODECODER_STANDARD: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEODECODER = 1
KSPROPERTY_VIDEODECODER_STATUS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEODECODER = 2
KSPROPERTY_VIDEODECODER_OUTPUT_ENABLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEODECODER = 3
KSPROPERTY_VIDEODECODER_VCR_TIMING: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEODECODER = 4
KSPROPERTY_VIDEODECODER_STATUS2: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEODECODER = 5
KSPROPERTY_VIDCAP_VIDEOENCODER = Int32
KSPROPERTY_VIDEOENCODER_CAPS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOENCODER = 0
KSPROPERTY_VIDEOENCODER_STANDARD: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOENCODER = 1
KSPROPERTY_VIDEOENCODER_COPYPROTECTION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOENCODER = 2
KSPROPERTY_VIDEOENCODER_CC_ENABLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOENCODER = 3
KSPROPERTY_VIDCAP_VIDEOPROCAMP = Int32
KSPROPERTY_VIDEOPROCAMP_BRIGHTNESS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOPROCAMP = 0
KSPROPERTY_VIDEOPROCAMP_CONTRAST: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOPROCAMP = 1
KSPROPERTY_VIDEOPROCAMP_HUE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOPROCAMP = 2
KSPROPERTY_VIDEOPROCAMP_SATURATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOPROCAMP = 3
KSPROPERTY_VIDEOPROCAMP_SHARPNESS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOPROCAMP = 4
KSPROPERTY_VIDEOPROCAMP_GAMMA: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOPROCAMP = 5
KSPROPERTY_VIDEOPROCAMP_COLORENABLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOPROCAMP = 6
KSPROPERTY_VIDEOPROCAMP_WHITEBALANCE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOPROCAMP = 7
KSPROPERTY_VIDEOPROCAMP_BACKLIGHT_COMPENSATION: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOPROCAMP = 8
KSPROPERTY_VIDEOPROCAMP_GAIN: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOPROCAMP = 9
KSPROPERTY_VIDEOPROCAMP_DIGITAL_MULTIPLIER: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOPROCAMP = 10
KSPROPERTY_VIDEOPROCAMP_DIGITAL_MULTIPLIER_LIMIT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOPROCAMP = 11
KSPROPERTY_VIDEOPROCAMP_WHITEBALANCE_COMPONENT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOPROCAMP = 12
KSPROPERTY_VIDEOPROCAMP_POWERLINE_FREQUENCY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDCAP_VIDEOPROCAMP = 13
class KSPROPERTY_VIDEOCOMPRESSION_GETINFO_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    StreamIndex: UInt32
    DefaultKeyFrameRate: Int32
    DefaultPFrameRate: Int32
    DefaultQuality: Int32
    NumberOfQualitySettings: Int32
    Capabilities: Int32
class KSPROPERTY_VIDEOCOMPRESSION_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    StreamIndex: UInt32
    Value: Int32
class KSPROPERTY_VIDEOCOMPRESSION_S1(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    StreamIndex: UInt32
    Value: Int32
    Flags: UInt32
class KSPROPERTY_VIDEOCONTROL_ACTUAL_FRAME_RATE_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    StreamIndex: UInt32
    RangeIndex: UInt32
    Dimensions: win32more.Windows.Win32.Foundation.SIZE
    CurrentActualFrameRate: Int64
    CurrentMaxAvailableFrameRate: Int64
class KSPROPERTY_VIDEOCONTROL_CAPS_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    StreamIndex: UInt32
    VideoControlCaps: UInt32
class KSPROPERTY_VIDEOCONTROL_FRAME_RATES_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    StreamIndex: UInt32
    RangeIndex: UInt32
    Dimensions: win32more.Windows.Win32.Foundation.SIZE
class KSPROPERTY_VIDEOCONTROL_MODE_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    StreamIndex: UInt32
    Mode: Int32
class KSPROPERTY_VIDEODECODER_CAPS_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    StandardsSupported: UInt32
    Capabilities: UInt32
    SettlingTime: UInt32
    HSyncPerVSync: UInt32
class KSPROPERTY_VIDEODECODER_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Value: UInt32
class KSPROPERTY_VIDEODECODER_STATUS2_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    NumberOfLines: UInt32
    SignalLocked: UInt32
    ChromaLock: UInt32
class KSPROPERTY_VIDEODECODER_STATUS_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    NumberOfLines: UInt32
    SignalLocked: UInt32
class KSPROPERTY_VIDEOENCODER_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Value: Int32
    Flags: UInt32
    Capabilities: UInt32
class KSPROPERTY_VIDEOPROCAMP_NODE_S(Structure):
    NodeProperty: win32more.Windows.Win32.Media.KernelStreaming.KSP_NODE
    Value: Int32
    Flags: UInt32
    Capabilities: UInt32
class KSPROPERTY_VIDEOPROCAMP_NODE_S2(Structure):
    NodeProperty: win32more.Windows.Win32.Media.KernelStreaming.KSP_NODE
    Value1: Int32
    Flags: UInt32
    Capabilities: UInt32
    Value2: Int32
class KSPROPERTY_VIDEOPROCAMP_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Value: Int32
    Flags: UInt32
    Capabilities: UInt32
class KSPROPERTY_VIDEOPROCAMP_S2(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Value1: Int32
    Flags: UInt32
    Capabilities: UInt32
    Value2: Int32
KSPROPERTY_VIDMEM_TRANSPORT = Int32
KSPROPERTY_DISPLAY_ADAPTER_GUID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDMEM_TRANSPORT = 1
KSPROPERTY_PREFERRED_CAPTURE_SURFACE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDMEM_TRANSPORT = 2
KSPROPERTY_CURRENT_CAPTURE_SURFACE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDMEM_TRANSPORT = 3
KSPROPERTY_MAP_CAPTURE_HANDLE_TO_VRAM_ADDRESS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VIDMEM_TRANSPORT = 4
KSPROPERTY_VPCONFIG = Int32
KSPROPERTY_VPCONFIG_NUMCONNECTINFO: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VPCONFIG = 0
KSPROPERTY_VPCONFIG_GETCONNECTINFO: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VPCONFIG = 1
KSPROPERTY_VPCONFIG_SETCONNECTINFO: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VPCONFIG = 2
KSPROPERTY_VPCONFIG_VPDATAINFO: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VPCONFIG = 3
KSPROPERTY_VPCONFIG_MAXPIXELRATE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VPCONFIG = 4
KSPROPERTY_VPCONFIG_INFORMVPINPUT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VPCONFIG = 5
KSPROPERTY_VPCONFIG_NUMVIDEOFORMAT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VPCONFIG = 6
KSPROPERTY_VPCONFIG_GETVIDEOFORMAT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VPCONFIG = 7
KSPROPERTY_VPCONFIG_SETVIDEOFORMAT: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VPCONFIG = 8
KSPROPERTY_VPCONFIG_INVERTPOLARITY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VPCONFIG = 9
KSPROPERTY_VPCONFIG_DECIMATIONCAPABILITY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VPCONFIG = 10
KSPROPERTY_VPCONFIG_SCALEFACTOR: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VPCONFIG = 11
KSPROPERTY_VPCONFIG_DDRAWHANDLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VPCONFIG = 12
KSPROPERTY_VPCONFIG_VIDEOPORTID: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VPCONFIG = 13
KSPROPERTY_VPCONFIG_DDRAWSURFACEHANDLE: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VPCONFIG = 14
KSPROPERTY_VPCONFIG_SURFACEPARAMS: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_VPCONFIG = 15
KSPROPERTY_WAVE = Int32
KSPROPERTY_WAVE_COMPATIBLE_CAPABILITIES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_WAVE = 0
KSPROPERTY_WAVE_INPUT_CAPABILITIES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_WAVE = 1
KSPROPERTY_WAVE_OUTPUT_CAPABILITIES: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_WAVE = 2
KSPROPERTY_WAVE_BUFFER: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_WAVE = 3
KSPROPERTY_WAVE_FREQUENCY: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_WAVE = 4
KSPROPERTY_WAVE_VOLUME: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_WAVE = 5
KSPROPERTY_WAVE_PAN: win32more.Windows.Win32.Media.KernelStreaming.KSPROPERTY_WAVE = 6
KSPROPSETID_AC3 = Guid('{bfabe720-6e1f-11d0-bcf2-444553540000}')
KSPROPSETID_Audio = Guid('{45ffaaa0-6e1b-11d0-bcf2-444553540000}')
KSPROPSETID_AudioBufferDuration = Guid('{4e73c07f-23cc-4955-a7ea-3da502496290}')
KSPROPSETID_AudioDecoderOut = Guid('{6ca6e020-43bd-11d0-bd6a-003505c103a9}')
KSPROPSETID_AudioEngine = Guid('{3a2f82dc-886f-4baa-9eb4-082b9025c536}')
KSPROPSETID_AudioModule = Guid('{c034fdb0-ff75-47c8-aa3c-ee46716b50c6}')
KSPROPSETID_AudioPosture = Guid('{a3fb7b0d-474e-4f51-a379-51282dd4fa8f}')
KSPROPSETID_AudioResourceManagement = Guid('{d0b305e1-b2cc-484c-8f23-e5d28ad9cf88}')
KSPROPSETID_AudioSignalProcessing = Guid('{4f67b528-30c9-40de-b2fb-859ddd1f3470}')
KSPROPSETID_Bibliographic = Guid('{07ba150e-e2b1-11d0-ac17-00a0c9223196}')
KSPROPSETID_BtAudio = Guid('{7fa06c40-b8f6-4c7e-8556-e8c33a12e54d}')
KSPROPSETID_Clock = Guid('{df12a4c0-ac17-11cf-a5d6-28db04c10000}')
KSPROPSETID_Connection = Guid('{1d58c920-ac9b-11cf-a5d6-28db04c10000}')
KSPROPSETID_CopyProt = Guid('{0e8a0a40-6aef-11d0-9ed0-00a024ca19b3}')
KSPROPSETID_Cyclic = Guid('{3ffeaea0-2bee-11cf-a5d6-28db04c10000}')
KSPROPSETID_DirectSound3DBuffer = Guid('{437b3411-d060-11d0-8583-00c04fd9baf3}')
KSPROPSETID_DirectSound3DListener = Guid('{437b3414-d060-11d0-8583-00c04fd9baf3}')
KSPROPSETID_DrmAudioStream = Guid('{2f2c8ddd-4198-4fac-ba29-61bb05b7de06}')
KSPROPSETID_DvdSubPic = Guid('{ac390460-43af-11d0-bd6a-003505c103a9}')
KSPROPSETID_FMRXControl = Guid('{947bba3a-e8ee-4786-90c4-8428185f05be}')
KSPROPSETID_FMRXTopology = Guid('{0c46ce8f-dc2d-4204-9dc9-f58963366563}')
KSPROPSETID_General = Guid('{1464eda5-6a8f-11d1-9aa7-00a0c9223196}')
KSPROPSETID_Hrtf3d = Guid('{b66decb0-a083-11d0-851e-00c04fd9baf3}')
KSPROPSETID_InterleavedAudio = Guid('{e9ebe550-d619-4c0a-976b-7062322b3006}')
KSPROPSETID_Itd3d = Guid('{6429f090-9fd9-11d0-a75b-00a0c90365e3}')
KSPROPSETID_Jack = Guid('{4509f757-2d46-4637-8e62-ce7db944f57b}')
KSPROPSETID_MPEG4_MediaType_Attributes = Guid('{ff6c4bfa-07a9-4c7b-a237-672f9d68065f}')
KSPROPSETID_MediaSeeking = Guid('{ee904f0c-d09b-11d0-abe9-00a0c9223196}')
KSPROPSETID_MemoryTransport = Guid('{0a3d1c5d-5243-4819-9ed0-aee8044cee2b}')
KSPROPSETID_Mpeg2Vid = Guid('{c8e11b60-0cc9-11d0-bd69-003505c103a9}')
KSPROPSETID_OverlayUpdate = Guid('{490ea5cf-7681-11d1-a21c-00a0c9223196}')
KSPROPSETID_Pin = Guid('{8c134960-51ad-11cf-878a-94f801c10000}')
KSPROPSETID_PinMDLCacheClearProp = Guid('{bd718a7b-97fc-40c7-88ce-d3ff06f55b16}')
KSPROPSETID_Quality = Guid('{d16ad380-ac1a-11cf-a5d6-28db04c10000}')
KSPROPSETID_RtAudio = Guid('{a855a48c-2f78-4729-9051-1968746b9eef}')
KSPROPSETID_SoundDetector = Guid('{113c425e-fd17-4057-b422-ed4074f1afdf}')
KSPROPSETID_SoundDetector2 = Guid('{fe07e322-450c-4bd5-84ca-a948500ea6aa}')
KSPROPSETID_Stream = Guid('{65aaba60-98ae-11cf-a10d-0020afd156e4}')
KSPROPSETID_StreamAllocator = Guid('{cf6e4342-ec87-11cf-a130-0020afd156e4}')
KSPROPSETID_StreamInterface = Guid('{1fdd8ee1-9cd3-11d0-82aa-0000f822fe8a}')
KSPROPSETID_TSRateChange = Guid('{a503c5c0-1d1d-11d1-ad80-444553540000}')
KSPROPSETID_TelephonyControl = Guid('{b6df7eb1-d099-489f-a6a0-c0106f0887a7}')
KSPROPSETID_TelephonyTopology = Guid('{abf25c7e-0e64-4e32-b190-d0f6d7c53e97}')
KSPROPSETID_Topology = Guid('{720d4ac0-7533-11d0-a5d6-28db04c10000}')
KSPROPSETID_TopologyNode = Guid('{45ffaaa1-6e1b-11d0-bcf2-444553540000}')
KSPROPSETID_VBICAP_PROPERTIES = Guid('{f162c607-7b35-496f-ad7f-2dca3b46b718}')
KSPROPSETID_VBICodecFiltering = Guid('{cafeb0ca-8715-11d0-bd6a-0035c0edbabe}')
KSPROPSETID_VPConfig = Guid('{bc29a660-30e3-11d0-9e69-00c04fd7c15b}')
KSPROPSETID_VPVBIConfig = Guid('{ec529b00-1a1f-11d1-bad9-00609744111a}')
KSPROPSETID_VramCapture = Guid('{e73face3-2880-4902-b799-88d0cd634e0f}')
KSPROPSETID_Wave = Guid('{924e54b0-630f-11cf-ada7-08003e30494a}')
KSPROPTYPESETID_General = Guid('{97e99ba0-bdea-11cf-a5d6-28db04c10000}')
class KSP_NODE(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    NodeId: UInt32
    Reserved: UInt32
class KSP_PIN(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    PinId: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Reserved: UInt32
        Flags: UInt32
class KSP_TIMEFORMAT(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    SourceFormat: Guid
    TargetFormat: Guid
    Time: Int64
class KSQUALITY(Structure):
    Context: VoidPtr
    Proportion: UInt32
    DeltaTime: Int64
class KSQUALITY_MANAGER(Structure):
    QualityManager: win32more.Windows.Win32.Foundation.HANDLE
    Context: VoidPtr
class KSQUERYBUFFER(Structure):
    Event: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    EventData: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSEVENTDATA)
    Reserved: VoidPtr
class KSRATE(Structure):
    PresentationStart: Int64
    Duration: Int64
    Interface: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Rate: Int32
    Flags: UInt32
class KSRATE_CAPABILITY(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Rate: win32more.Windows.Win32.Media.KernelStreaming.KSRATE
class KSRELATIVEEVENT(Structure):
    Size: UInt32
    Flags: UInt32
    Anonymous: _Anonymous_e__Union
    Reserved: VoidPtr
    Event: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    EventData: win32more.Windows.Win32.Media.KernelStreaming.KSEVENTDATA
    class _Anonymous_e__Union(Union):
        ObjectHandle: win32more.Windows.Win32.Foundation.HANDLE
        ObjectPointer: VoidPtr
KSRESET = Int32
KSRESET_BEGIN: win32more.Windows.Win32.Media.KernelStreaming.KSRESET = 0
KSRESET_END: win32more.Windows.Win32.Media.KernelStreaming.KSRESET = 1
class KSRESOLUTION(Structure):
    Granularity: Int64
    Error: Int64
class KSRTAUDIO_BUFFER(Structure):
    BufferAddress: VoidPtr
    ActualBufferSize: UInt32
    CallMemoryBarrier: win32more.Windows.Win32.Foundation.BOOL
class KSRTAUDIO_BUFFER32(Structure):
    BufferAddress: UInt32
    ActualBufferSize: UInt32
    CallMemoryBarrier: win32more.Windows.Win32.Foundation.BOOL
class KSRTAUDIO_BUFFER_PROPERTY(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    BaseAddress: VoidPtr
    RequestedBufferSize: UInt32
class KSRTAUDIO_BUFFER_PROPERTY32(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    BaseAddress: UInt32
    RequestedBufferSize: UInt32
class KSRTAUDIO_BUFFER_PROPERTY_WITH_NOTIFICATION(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    BaseAddress: VoidPtr
    RequestedBufferSize: UInt32
    NotificationCount: UInt32
class KSRTAUDIO_BUFFER_PROPERTY_WITH_NOTIFICATION32(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    BaseAddress: UInt32
    RequestedBufferSize: UInt32
    NotificationCount: UInt32
class KSRTAUDIO_GETREADPACKET_INFO(Structure):
    PacketNumber: UInt32
    Flags: UInt32
    PerformanceCounterValue: UInt64
    MoreData: win32more.Windows.Win32.Foundation.BOOL
class KSRTAUDIO_HWLATENCY(Structure):
    FifoSize: UInt32
    ChipsetDelay: UInt32
    CodecDelay: UInt32
class KSRTAUDIO_HWREGISTER(Structure):
    Register: VoidPtr
    Width: UInt32
    Numerator: UInt64
    Denominator: UInt64
    Accuracy: UInt32
class KSRTAUDIO_HWREGISTER32(Structure):
    Register: UInt32
    Width: UInt32
    Numerator: UInt64
    Denominator: UInt64
    Accuracy: UInt32
class KSRTAUDIO_HWREGISTER_PROPERTY(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    BaseAddress: VoidPtr
class KSRTAUDIO_HWREGISTER_PROPERTY32(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    BaseAddress: UInt32
class KSRTAUDIO_NOTIFICATION_EVENT_PROPERTY(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    NotificationEvent: win32more.Windows.Win32.Foundation.HANDLE
class KSRTAUDIO_NOTIFICATION_EVENT_PROPERTY32(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    NotificationEvent: UInt32
class KSRTAUDIO_PACKETVREGISTER(Structure):
    CompletedPacketCount: POINTER(UInt64)
    CompletedPacketQPC: POINTER(UInt64)
    CompletedPacketHash: POINTER(UInt64)
class KSRTAUDIO_PACKETVREGISTER_PROPERTY(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    BaseAddress: VoidPtr
class KSRTAUDIO_SETWRITEPACKET_INFO(Structure):
    PacketNumber: UInt32
    Flags: UInt32
    EosPacketLength: UInt32
class KSSOUNDDETECTORPROPERTY(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    EventId: Guid
KSSTATE = Int32
KSSTATE_STOP: win32more.Windows.Win32.Media.KernelStreaming.KSSTATE = 0
KSSTATE_ACQUIRE: win32more.Windows.Win32.Media.KernelStreaming.KSSTATE = 1
KSSTATE_PAUSE: win32more.Windows.Win32.Media.KernelStreaming.KSSTATE = 2
KSSTATE_RUN: win32more.Windows.Win32.Media.KernelStreaming.KSSTATE = 3
class KSSTREAMALLOCATOR_STATUS(Structure):
    Framing: win32more.Windows.Win32.Media.KernelStreaming.KSALLOCATOR_FRAMING
    AllocatedFrames: UInt32
    Reserved: UInt32
class KSSTREAMALLOCATOR_STATUS_EX(Structure):
    Framing: win32more.Windows.Win32.Media.KernelStreaming.KSALLOCATOR_FRAMING_EX
    AllocatedFrames: UInt32
    Reserved: UInt32
if ARCH in 'X64,ARM64':
    class KSSTREAM_HEADER(Structure):
        Size: UInt32
        TypeSpecificFlags: UInt32
        PresentationTime: win32more.Windows.Win32.Media.KernelStreaming.KSTIME
        Duration: Int64
        FrameExtent: UInt32
        DataUsed: UInt32
        Data: VoidPtr
        OptionsFlags: UInt32
        Reserved: UInt32
elif ARCH in 'X86':
    class KSSTREAM_HEADER(Structure):
        Size: UInt32
        TypeSpecificFlags: UInt32
        PresentationTime: win32more.Windows.Win32.Media.KernelStreaming.KSTIME
        Duration: Int64
        FrameExtent: UInt32
        DataUsed: UInt32
        Data: VoidPtr
        OptionsFlags: UInt32
class KSSTREAM_METADATA_INFO(Structure):
    BufferSize: UInt32
    UsedSize: UInt32
    Data: VoidPtr
    SystemVa: VoidPtr
    Flags: UInt32
    Reserved: UInt32
class KSSTREAM_SEGMENT(Structure):
    KsInterfaceHandler: win32more.Windows.Win32.Media.KernelStreaming.IKsInterfaceHandler
    KsDataTypeHandler: win32more.Windows.Win32.Media.KernelStreaming.IKsDataTypeHandler
    IoOperation: win32more.Windows.Win32.Media.KernelStreaming.KSIOOPERATION
    CompletionEvent: win32more.Windows.Win32.Foundation.HANDLE
class KSSTREAM_UVC_METADATA(Structure):
    StartOfFrameTimestamp: win32more.Windows.Win32.Media.KernelStreaming.KSSTREAM_UVC_METADATATYPE_TIMESTAMP
    EndOfFrameTimestamp: win32more.Windows.Win32.Media.KernelStreaming.KSSTREAM_UVC_METADATATYPE_TIMESTAMP
class KSSTREAM_UVC_METADATATYPE_TIMESTAMP(Structure):
    PresentationTimeStamp: UInt32
    SourceClockReference: UInt32
    Anonymous: _Anonymous_e__Union
    Reserved0: UInt16
    Reserved1: UInt32
    class _Anonymous_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        SCRToken: UInt16
        class _Anonymous_e__Struct(Structure):
            Counter: Annotated[UInt16, 11]
            Reserved: Annotated[UInt16, 5]
class KSTELEPHONY_CALLCONTROL(Structure):
    CallType: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_CALLTYPE
    CallControlOp: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_CALLCONTROLOP
class KSTELEPHONY_CALLINFO(Structure):
    CallType: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_CALLTYPE
    CallState: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_CALLSTATE
class KSTELEPHONY_PROVIDERCHANGE(Structure):
    CallType: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_CALLTYPE
    ProviderChangeOp: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_PROVIDERCHANGEOP
class KSTIME(Structure):
    Time: Int64
    Numerator: UInt32
    Denominator: UInt32
KSTIME_FORMAT_BYTE = Guid('{7b785571-8c82-11cf-bc0c-00aa00ac74f6}')
KSTIME_FORMAT_FIELD = Guid('{7b785573-8c82-11cf-bc0c-00aa00ac74f6}')
KSTIME_FORMAT_FRAME = Guid('{7b785570-8c82-11cf-bc0c-00aa00ac74f6}')
KSTIME_FORMAT_MEDIA_TIME = Guid('{7b785574-8c82-11cf-bc0c-00aa00ac74f6}')
KSTIME_FORMAT_SAMPLE = Guid('{7b785572-8c82-11cf-bc0c-00aa00ac74f6}')
class KSTOPOLOGY(Structure):
    CategoriesCount: UInt32
    Categories: POINTER(Guid)
    TopologyNodesCount: UInt32
    TopologyNodes: POINTER(Guid)
    TopologyConnectionsCount: UInt32
    TopologyConnections: POINTER(win32more.Windows.Win32.Media.KernelStreaming.KSTOPOLOGY_CONNECTION)
    TopologyNodesNames: POINTER(Guid)
    Reserved: UInt32
class KSTOPOLOGY_CONNECTION(Structure):
    FromNode: UInt32
    FromNodePin: UInt32
    ToNode: UInt32
    ToNodePin: UInt32
class KSTOPOLOGY_ENDPOINTID(Structure):
    TopologyName: Char * 260
    PinId: UInt32
class KSTOPOLOGY_ENDPOINTIDPAIR(Structure):
    RenderEndpoint: win32more.Windows.Win32.Media.KernelStreaming.KSTOPOLOGY_ENDPOINTID
    CaptureEndpoint: win32more.Windows.Win32.Media.KernelStreaming.KSTOPOLOGY_ENDPOINTID
class KSVPMAXPIXELRATE(Structure):
    Size: win32more.Windows.Win32.Media.KernelStreaming.KS_AMVPSIZE
    MaxPixelsPerSecond: UInt32
    Reserved: UInt32
class KSVPSIZE_PROP(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Size: win32more.Windows.Win32.Media.KernelStreaming.KS_AMVPSIZE
class KSVPSURFACEPARAMS(Structure):
    dwPitch: UInt32
    dwXOrigin: UInt32
    dwYOrigin: UInt32
class KSWAVETABLE_WAVE_DESC(Structure):
    Identifier: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    Size: UInt32
    Looped: win32more.Windows.Win32.Foundation.BOOL
    LoopPoint: UInt32
    InROM: win32more.Windows.Win32.Foundation.BOOL
    Format: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
class KSWAVE_BUFFER(Structure):
    Attributes: UInt32
    BufferSize: UInt32
    BufferAddress: VoidPtr
class KSWAVE_COMPATCAPS(Structure):
    ulDeviceType: UInt32
class KSWAVE_INPUT_CAPABILITIES(Structure):
    MaximumChannelsPerConnection: UInt32
    MinimumBitsPerSample: UInt32
    MaximumBitsPerSample: UInt32
    MinimumSampleFrequency: UInt32
    MaximumSampleFrequency: UInt32
    TotalConnections: UInt32
    ActiveConnections: UInt32
class KSWAVE_OUTPUT_CAPABILITIES(Structure):
    MaximumChannelsPerConnection: UInt32
    MinimumBitsPerSample: UInt32
    MaximumBitsPerSample: UInt32
    MinimumSampleFrequency: UInt32
    MaximumSampleFrequency: UInt32
    TotalConnections: UInt32
    StaticConnections: UInt32
    StreamingConnections: UInt32
    ActiveConnections: UInt32
    ActiveStaticConnections: UInt32
    ActiveStreamingConnections: UInt32
    Total3DConnections: UInt32
    Static3DConnections: UInt32
    Streaming3DConnections: UInt32
    Active3DConnections: UInt32
    ActiveStatic3DConnections: UInt32
    ActiveStreaming3DConnections: UInt32
    TotalSampleMemory: UInt32
    FreeSampleMemory: UInt32
    LargestFreeContiguousSampleMemory: UInt32
class KSWAVE_VOLUME(Structure):
    LeftAttenuation: Int32
    RightAttenuation: Int32
KS_AMPixAspectRatio = Int32
KS_PixAspectRatio_NTSC4x3: win32more.Windows.Win32.Media.KernelStreaming.KS_AMPixAspectRatio = 0
KS_PixAspectRatio_NTSC16x9: win32more.Windows.Win32.Media.KernelStreaming.KS_AMPixAspectRatio = 1
KS_PixAspectRatio_PAL4x3: win32more.Windows.Win32.Media.KernelStreaming.KS_AMPixAspectRatio = 2
KS_PixAspectRatio_PAL16x9: win32more.Windows.Win32.Media.KernelStreaming.KS_AMPixAspectRatio = 3
class KS_AMVPDATAINFO(Structure):
    dwSize: UInt32
    dwMicrosecondsPerField: UInt32
    amvpDimInfo: win32more.Windows.Win32.Media.KernelStreaming.KS_AMVPDIMINFO
    dwPictAspectRatioX: UInt32
    dwPictAspectRatioY: UInt32
    bEnableDoubleClock: win32more.Windows.Win32.Foundation.BOOL
    bEnableVACT: win32more.Windows.Win32.Foundation.BOOL
    bDataIsInterlaced: win32more.Windows.Win32.Foundation.BOOL
    lHalfLinesOdd: Int32
    bFieldPolarityInverted: win32more.Windows.Win32.Foundation.BOOL
    dwNumLinesInVREF: UInt32
    lHalfLinesEven: Int32
    dwReserved1: UInt32
class KS_AMVPDIMINFO(Structure):
    dwFieldWidth: UInt32
    dwFieldHeight: UInt32
    dwVBIWidth: UInt32
    dwVBIHeight: UInt32
    rcValidRegion: win32more.Windows.Win32.Foundation.RECT
class KS_AMVPSIZE(Structure):
    dwWidth: UInt32
    dwHeight: UInt32
KS_AMVP_MODE = Int32
KS_AMVP_MODE_WEAVE: win32more.Windows.Win32.Media.KernelStreaming.KS_AMVP_MODE = 0
KS_AMVP_MODE_BOBINTERLEAVED: win32more.Windows.Win32.Media.KernelStreaming.KS_AMVP_MODE = 1
KS_AMVP_MODE_BOBNONINTERLEAVED: win32more.Windows.Win32.Media.KernelStreaming.KS_AMVP_MODE = 2
KS_AMVP_MODE_SKIPEVEN: win32more.Windows.Win32.Media.KernelStreaming.KS_AMVP_MODE = 3
KS_AMVP_MODE_SKIPODD: win32more.Windows.Win32.Media.KernelStreaming.KS_AMVP_MODE = 4
KS_AMVP_SELECTFORMATBY = Int32
KS_AMVP_DO_NOT_CARE: win32more.Windows.Win32.Media.KernelStreaming.KS_AMVP_SELECTFORMATBY = 0
KS_AMVP_BEST_BANDWIDTH: win32more.Windows.Win32.Media.KernelStreaming.KS_AMVP_SELECTFORMATBY = 1
KS_AMVP_INPUT_SAME_AS_OUTPUT: win32more.Windows.Win32.Media.KernelStreaming.KS_AMVP_SELECTFORMATBY = 2
class KS_AM_ExactRateChange(Structure):
    OutputZeroTime: Int64
    Rate: Int32
KS_AM_PROPERTY_TS_RATE_CHANGE = Int32
KS_AM_RATE_SimpleRateChange: win32more.Windows.Win32.Media.KernelStreaming.KS_AM_PROPERTY_TS_RATE_CHANGE = 1
KS_AM_RATE_ExactRateChange: win32more.Windows.Win32.Media.KernelStreaming.KS_AM_PROPERTY_TS_RATE_CHANGE = 2
KS_AM_RATE_MaxFullDataRate: win32more.Windows.Win32.Media.KernelStreaming.KS_AM_PROPERTY_TS_RATE_CHANGE = 3
KS_AM_RATE_Step: win32more.Windows.Win32.Media.KernelStreaming.KS_AM_PROPERTY_TS_RATE_CHANGE = 4
class KS_AM_SimpleRateChange(Structure):
    StartTime: Int64
    Rate: Int32
class KS_ANALOGVIDEOINFO(Structure):
    rcSource: win32more.Windows.Win32.Foundation.RECT
    rcTarget: win32more.Windows.Win32.Foundation.RECT
    dwActiveWidth: UInt32
    dwActiveHeight: UInt32
    AvgTimePerFrame: Int64
KS_AnalogVideoStandard = Int32
KS_AnalogVideo_None: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 0
KS_AnalogVideo_NTSC_M: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 1
KS_AnalogVideo_NTSC_M_J: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 2
KS_AnalogVideo_NTSC_433: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 4
KS_AnalogVideo_PAL_B: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 16
KS_AnalogVideo_PAL_D: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 32
KS_AnalogVideo_PAL_G: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 64
KS_AnalogVideo_PAL_H: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 128
KS_AnalogVideo_PAL_I: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 256
KS_AnalogVideo_PAL_M: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 512
KS_AnalogVideo_PAL_N: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 1024
KS_AnalogVideo_PAL_60: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 2048
KS_AnalogVideo_SECAM_B: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 4096
KS_AnalogVideo_SECAM_D: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 8192
KS_AnalogVideo_SECAM_G: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 16384
KS_AnalogVideo_SECAM_H: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 32768
KS_AnalogVideo_SECAM_K: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 65536
KS_AnalogVideo_SECAM_K1: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 131072
KS_AnalogVideo_SECAM_L: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 262144
KS_AnalogVideo_SECAM_L1: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 524288
KS_AnalogVideo_PAL_N_COMBO: win32more.Windows.Win32.Media.KernelStreaming.KS_AnalogVideoStandard = 1048576
class KS_BITMAPINFOHEADER(Structure):
    biSize: UInt32
    biWidth: Int32
    biHeight: Int32
    biPlanes: UInt16
    biBitCount: UInt16
    biCompression: UInt32
    biSizeImage: UInt32
    biXPelsPerMeter: Int32
    biYPelsPerMeter: Int32
    biClrUsed: UInt32
    biClrImportant: UInt32
class KS_COLCON(Structure):
    emph1col: Annotated[Byte, 4]
    emph2col: Annotated[Byte, 4]
    backcol: Annotated[Byte, 4]
    patcol: Annotated[Byte, 4]
    emph1con: Annotated[Byte, 4]
    emph2con: Annotated[Byte, 4]
    backcon: Annotated[Byte, 4]
    patcon: Annotated[Byte, 4]
class KS_COMPRESSION(Structure):
    RatioNumerator: UInt32
    RatioDenominator: UInt32
    RatioConstantMargin: UInt32
class KS_COPY_MACROVISION(Structure):
    MACROVISIONLevel: UInt32
KS_COPY_MACROVISION_LEVEL = Int32
KS_MACROVISION_DISABLED: win32more.Windows.Win32.Media.KernelStreaming.KS_COPY_MACROVISION_LEVEL = 0
KS_MACROVISION_LEVEL1: win32more.Windows.Win32.Media.KernelStreaming.KS_COPY_MACROVISION_LEVEL = 1
KS_MACROVISION_LEVEL2: win32more.Windows.Win32.Media.KernelStreaming.KS_COPY_MACROVISION_LEVEL = 2
KS_MACROVISION_LEVEL3: win32more.Windows.Win32.Media.KernelStreaming.KS_COPY_MACROVISION_LEVEL = 3
KS_CameraControlAsyncOperation = Int32
KS_CAMERACONTROL_ASYNC_START: win32more.Windows.Win32.Media.KernelStreaming.KS_CameraControlAsyncOperation = 1
KS_CAMERACONTROL_ASYNC_STOP: win32more.Windows.Win32.Media.KernelStreaming.KS_CameraControlAsyncOperation = 2
KS_CAMERACONTROL_ASYNC_RESET: win32more.Windows.Win32.Media.KernelStreaming.KS_CameraControlAsyncOperation = 3
KS_CompressionCaps = Int32
KS_CompressionCaps_CanQuality: win32more.Windows.Win32.Media.KernelStreaming.KS_CompressionCaps = 1
KS_CompressionCaps_CanCrunch: win32more.Windows.Win32.Media.KernelStreaming.KS_CompressionCaps = 2
KS_CompressionCaps_CanKeyFrame: win32more.Windows.Win32.Media.KernelStreaming.KS_CompressionCaps = 4
KS_CompressionCaps_CanBFrame: win32more.Windows.Win32.Media.KernelStreaming.KS_CompressionCaps = 8
KS_CompressionCaps_CanWindow: win32more.Windows.Win32.Media.KernelStreaming.KS_CompressionCaps = 16
class KS_DATAFORMAT_H264VIDEOINFO(Structure):
    DataFormat: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    H264VideoInfoHeader: win32more.Windows.Win32.Media.KernelStreaming.KS_H264VIDEOINFO
class KS_DATAFORMAT_IMAGEINFO(Structure):
    DataFormat: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    ImageInfoHeader: win32more.Windows.Win32.Media.KernelStreaming.KS_BITMAPINFOHEADER
class KS_DATAFORMAT_MPEGVIDEOINFO2(Structure):
    DataFormat: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    MpegVideoInfoHeader2: win32more.Windows.Win32.Media.KernelStreaming.KS_MPEGVIDEOINFO2
class KS_DATAFORMAT_VBIINFOHEADER(Structure):
    DataFormat: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    VBIInfoHeader: win32more.Windows.Win32.Media.KernelStreaming.KS_VBIINFOHEADER
class KS_DATAFORMAT_VIDEOINFOHEADER(Structure):
    DataFormat: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    VideoInfoHeader: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEOINFOHEADER
class KS_DATAFORMAT_VIDEOINFOHEADER2(Structure):
    DataFormat: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    VideoInfoHeader2: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEOINFOHEADER2
class KS_DATAFORMAT_VIDEOINFO_PALETTE(Structure):
    DataFormat: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    VideoInfo: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEOINFO
class KS_DATARANGE_ANALOGVIDEO(Structure):
    DataRange: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    AnalogVideoInfo: win32more.Windows.Win32.Media.KernelStreaming.KS_ANALOGVIDEOINFO
class KS_DATARANGE_H264_VIDEO(Structure):
    DataRange: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    bFixedSizeSamples: win32more.Windows.Win32.Foundation.BOOL
    bTemporalCompression: win32more.Windows.Win32.Foundation.BOOL
    StreamDescriptionFlags: UInt32
    MemoryAllocationFlags: UInt32
    ConfigCaps: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEO_STREAM_CONFIG_CAPS
    VideoInfoHeader: win32more.Windows.Win32.Media.KernelStreaming.KS_H264VIDEOINFO
class KS_DATARANGE_IMAGE(Structure):
    DataRange: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    ConfigCaps: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEO_STREAM_CONFIG_CAPS
    ImageInfoHeader: win32more.Windows.Win32.Media.KernelStreaming.KS_BITMAPINFOHEADER
class KS_DATARANGE_MPEG1_VIDEO(Structure):
    DataRange: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    bFixedSizeSamples: win32more.Windows.Win32.Foundation.BOOL
    bTemporalCompression: win32more.Windows.Win32.Foundation.BOOL
    StreamDescriptionFlags: UInt32
    MemoryAllocationFlags: UInt32
    ConfigCaps: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEO_STREAM_CONFIG_CAPS
    VideoInfoHeader: win32more.Windows.Win32.Media.KernelStreaming.KS_MPEG1VIDEOINFO
class KS_DATARANGE_MPEG2_VIDEO(Structure):
    DataRange: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    bFixedSizeSamples: win32more.Windows.Win32.Foundation.BOOL
    bTemporalCompression: win32more.Windows.Win32.Foundation.BOOL
    StreamDescriptionFlags: UInt32
    MemoryAllocationFlags: UInt32
    ConfigCaps: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEO_STREAM_CONFIG_CAPS
    VideoInfoHeader: win32more.Windows.Win32.Media.KernelStreaming.KS_MPEGVIDEOINFO2
class KS_DATARANGE_VIDEO(Structure):
    DataRange: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    bFixedSizeSamples: win32more.Windows.Win32.Foundation.BOOL
    bTemporalCompression: win32more.Windows.Win32.Foundation.BOOL
    StreamDescriptionFlags: UInt32
    MemoryAllocationFlags: UInt32
    ConfigCaps: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEO_STREAM_CONFIG_CAPS
    VideoInfoHeader: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEOINFOHEADER
class KS_DATARANGE_VIDEO2(Structure):
    DataRange: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    bFixedSizeSamples: win32more.Windows.Win32.Foundation.BOOL
    bTemporalCompression: win32more.Windows.Win32.Foundation.BOOL
    StreamDescriptionFlags: UInt32
    MemoryAllocationFlags: UInt32
    ConfigCaps: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEO_STREAM_CONFIG_CAPS
    VideoInfoHeader: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEOINFOHEADER2
class KS_DATARANGE_VIDEO_PALETTE(Structure):
    DataRange: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    bFixedSizeSamples: win32more.Windows.Win32.Foundation.BOOL
    bTemporalCompression: win32more.Windows.Win32.Foundation.BOOL
    StreamDescriptionFlags: UInt32
    MemoryAllocationFlags: UInt32
    ConfigCaps: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEO_STREAM_CONFIG_CAPS
    VideoInfo: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEOINFO
class KS_DATARANGE_VIDEO_VBI(Structure):
    DataRange: win32more.Windows.Win32.Media.KernelStreaming.KSDATAFORMAT
    bFixedSizeSamples: win32more.Windows.Win32.Foundation.BOOL
    bTemporalCompression: win32more.Windows.Win32.Foundation.BOOL
    StreamDescriptionFlags: UInt32
    MemoryAllocationFlags: UInt32
    ConfigCaps: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEO_STREAM_CONFIG_CAPS
    VBIInfoHeader: win32more.Windows.Win32.Media.KernelStreaming.KS_VBIINFOHEADER
KS_DVDCOPYSTATE = Int32
KS_DVDCOPYSTATE_INITIALIZE: win32more.Windows.Win32.Media.KernelStreaming.KS_DVDCOPYSTATE = 0
KS_DVDCOPYSTATE_INITIALIZE_TITLE: win32more.Windows.Win32.Media.KernelStreaming.KS_DVDCOPYSTATE = 1
KS_DVDCOPYSTATE_AUTHENTICATION_NOT_REQUIRED: win32more.Windows.Win32.Media.KernelStreaming.KS_DVDCOPYSTATE = 2
KS_DVDCOPYSTATE_AUTHENTICATION_REQUIRED: win32more.Windows.Win32.Media.KernelStreaming.KS_DVDCOPYSTATE = 3
KS_DVDCOPYSTATE_DONE: win32more.Windows.Win32.Media.KernelStreaming.KS_DVDCOPYSTATE = 4
class KS_DVDCOPY_BUSKEY(Structure):
    BusKey: Byte * 5
    Reserved: Byte * 1
class KS_DVDCOPY_CHLGKEY(Structure):
    ChlgKey: Byte * 10
    Reserved: Byte * 2
class KS_DVDCOPY_DISCKEY(Structure):
    DiscKey: Byte * 2048
class KS_DVDCOPY_REGION(Structure):
    Reserved: Byte
    RegionData: Byte
    Reserved2: Byte * 2
class KS_DVDCOPY_SET_COPY_STATE(Structure):
    DVDCopyState: UInt32
class KS_DVDCOPY_TITLEKEY(Structure):
    KeyFlags: UInt32
    ReservedNT: UInt32 * 2
    TitleKey: Byte * 6
    Reserved: Byte * 2
class KS_DVD_YCrCb(Structure):
    Reserved: Byte
    Y: Byte
    Cr: Byte
    Cb: Byte
class KS_DVD_YUV(Structure):
    Reserved: Byte
    Y: Byte
    V: Byte
    U: Byte
class KS_FRAME_INFO(Structure):
    ExtendedHeaderSize: UInt32
    dwFrameFlags: UInt32
    PictureNumber: Int64
    DropCount: Int64
    hDirectDraw: win32more.Windows.Win32.Foundation.HANDLE
    hSurfaceHandle: win32more.Windows.Win32.Foundation.HANDLE
    DirectDrawRect: win32more.Windows.Win32.Foundation.RECT
    Anonymous1: _Anonymous1_e__Union
    Reserved2: UInt32
    Anonymous2: _Anonymous2_e__Union
    class _Anonymous1_e__Union(Union):
        lSurfacePitch: Int32
        Reserved1: UInt32
    class _Anonymous2_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        FrameCompletionNumber: UInt64
        class _Anonymous_e__Struct(Structure):
            Reserved3: UInt32
            Reserved4: UInt32
class KS_FRAMING_ITEM(Structure):
    MemoryType: Guid
    BusType: Guid
    MemoryFlags: UInt32
    BusFlags: UInt32
    Flags: UInt32
    Frames: UInt32
    Anonymous: _Anonymous_e__Union
    MemoryTypeWeight: UInt32
    PhysicalRange: win32more.Windows.Win32.Media.KernelStreaming.KS_FRAMING_RANGE
    FramingRange: win32more.Windows.Win32.Media.KernelStreaming.KS_FRAMING_RANGE_WEIGHTED
    class _Anonymous_e__Union(Union):
        FileAlignment: UInt32
        FramePitch: Int32
class KS_FRAMING_RANGE(Structure):
    MinFrameSize: UInt32
    MaxFrameSize: UInt32
    Stepping: UInt32
class KS_FRAMING_RANGE_WEIGHTED(Structure):
    Range: win32more.Windows.Win32.Media.KernelStreaming.KS_FRAMING_RANGE
    InPlaceWeight: UInt32
    NotInPlaceWeight: UInt32
class KS_H264VIDEOINFO(Structure):
    wWidth: UInt16
    wHeight: UInt16
    wSARwidth: UInt16
    wSARheight: UInt16
    wProfile: UInt16
    bLevelIDC: Byte
    wConstrainedToolset: UInt16
    bmSupportedUsages: UInt32
    bmCapabilities: UInt16
    bmSVCCapabilities: UInt32
    bmMVCCapabilities: UInt32
    dwFrameInterval: UInt32
    bMaxCodecConfigDelay: Byte
    bmSupportedSliceModes: Byte
    bmSupportedSyncFrameTypes: Byte
    bResolutionScaling: Byte
    bSimulcastSupport: Byte
    bmSupportedRateControlModes: Byte
    wMaxMBperSecOneResolutionNoScalability: UInt16
    wMaxMBperSecTwoResolutionsNoScalability: UInt16
    wMaxMBperSecThreeResolutionsNoScalability: UInt16
    wMaxMBperSecFourResolutionsNoScalability: UInt16
    wMaxMBperSecOneResolutionTemporalScalability: UInt16
    wMaxMBperSecTwoResolutionsTemporalScalablility: UInt16
    wMaxMBperSecThreeResolutionsTemporalScalability: UInt16
    wMaxMBperSecFourResolutionsTemporalScalability: UInt16
    wMaxMBperSecOneResolutionTemporalQualityScalability: UInt16
    wMaxMBperSecTwoResolutionsTemporalQualityScalability: UInt16
    wMaxMBperSecThreeResolutionsTemporalQualityScalablity: UInt16
    wMaxMBperSecFourResolutionsTemporalQualityScalability: UInt16
    wMaxMBperSecOneResolutionTemporalSpatialScalability: UInt16
    wMaxMBperSecTwoResolutionsTemporalSpatialScalability: UInt16
    wMaxMBperSecThreeResolutionsTemporalSpatialScalablity: UInt16
    wMaxMBperSecFourResolutionsTemporalSpatialScalability: UInt16
    wMaxMBperSecOneResolutionFullScalability: UInt16
    wMaxMBperSecTwoResolutionsFullScalability: UInt16
    wMaxMBperSecThreeResolutionsFullScalability: UInt16
    wMaxMBperSecFourResolutionsFullScalability: UInt16
KS_LogicalMemoryType = Int32
KS_MemoryTypeDontCare: win32more.Windows.Win32.Media.KernelStreaming.KS_LogicalMemoryType = 0
KS_MemoryTypeKernelPaged: win32more.Windows.Win32.Media.KernelStreaming.KS_LogicalMemoryType = 1
KS_MemoryTypeKernelNonPaged: win32more.Windows.Win32.Media.KernelStreaming.KS_LogicalMemoryType = 2
KS_MemoryTypeDeviceHostMapped: win32more.Windows.Win32.Media.KernelStreaming.KS_LogicalMemoryType = 3
KS_MemoryTypeDeviceSpecific: win32more.Windows.Win32.Media.KernelStreaming.KS_LogicalMemoryType = 4
KS_MemoryTypeUser: win32more.Windows.Win32.Media.KernelStreaming.KS_LogicalMemoryType = 5
KS_MemoryTypeAnyHost: win32more.Windows.Win32.Media.KernelStreaming.KS_LogicalMemoryType = 6
class KS_MPEG1VIDEOINFO(Structure):
    hdr: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEOINFOHEADER
    dwStartTimeCode: UInt32
    cbSequenceHeader: UInt32
    bSequenceHeader: Byte * 1
KS_MPEG2Level = Int32
KS_MPEG2Level_Low: win32more.Windows.Win32.Media.KernelStreaming.KS_MPEG2Level = 0
KS_MPEG2Level_Main: win32more.Windows.Win32.Media.KernelStreaming.KS_MPEG2Level = 1
KS_MPEG2Level_High1440: win32more.Windows.Win32.Media.KernelStreaming.KS_MPEG2Level = 2
KS_MPEG2Level_High: win32more.Windows.Win32.Media.KernelStreaming.KS_MPEG2Level = 3
KS_MPEG2Profile = Int32
KS_MPEG2Profile_Simple: win32more.Windows.Win32.Media.KernelStreaming.KS_MPEG2Profile = 0
KS_MPEG2Profile_Main: win32more.Windows.Win32.Media.KernelStreaming.KS_MPEG2Profile = 1
KS_MPEG2Profile_SNRScalable: win32more.Windows.Win32.Media.KernelStreaming.KS_MPEG2Profile = 2
KS_MPEG2Profile_SpatiallyScalable: win32more.Windows.Win32.Media.KernelStreaming.KS_MPEG2Profile = 3
KS_MPEG2Profile_High: win32more.Windows.Win32.Media.KernelStreaming.KS_MPEG2Profile = 4
class KS_MPEGAUDIOINFO(Structure):
    dwFlags: UInt32
    dwReserved1: UInt32
    dwReserved2: UInt32
    dwReserved3: UInt32
class KS_MPEGVIDEOINFO2(Structure):
    hdr: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEOINFOHEADER2
    dwStartTimeCode: UInt32
    cbSequenceHeader: UInt32
    dwProfile: UInt32
    dwLevel: UInt32
    dwFlags: UInt32
    bSequenceHeader: UInt32 * 1
KS_PhysicalConnectorType = Int32
KS_PhysConn_Video_Tuner: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 1
KS_PhysConn_Video_Composite: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 2
KS_PhysConn_Video_SVideo: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 3
KS_PhysConn_Video_RGB: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 4
KS_PhysConn_Video_YRYBY: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 5
KS_PhysConn_Video_SerialDigital: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 6
KS_PhysConn_Video_ParallelDigital: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 7
KS_PhysConn_Video_SCSI: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 8
KS_PhysConn_Video_AUX: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 9
KS_PhysConn_Video_1394: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 10
KS_PhysConn_Video_USB: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 11
KS_PhysConn_Video_VideoDecoder: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 12
KS_PhysConn_Video_VideoEncoder: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 13
KS_PhysConn_Video_SCART: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 14
KS_PhysConn_Audio_Tuner: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 4096
KS_PhysConn_Audio_Line: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 4097
KS_PhysConn_Audio_Mic: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 4098
KS_PhysConn_Audio_AESDigital: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 4099
KS_PhysConn_Audio_SPDIFDigital: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 4100
KS_PhysConn_Audio_SCSI: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 4101
KS_PhysConn_Audio_AUX: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 4102
KS_PhysConn_Audio_1394: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 4103
KS_PhysConn_Audio_USB: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 4104
KS_PhysConn_Audio_AudioDecoder: win32more.Windows.Win32.Media.KernelStreaming.KS_PhysicalConnectorType = 4105
class KS_RGBQUAD(Structure):
    rgbBlue: Byte
    rgbGreen: Byte
    rgbRed: Byte
    rgbReserved: Byte
KS_SECURE_CAMERA_SCENARIO_ID = Guid('{ae53fc6e-8d89-4488-9d2e-4d008731c5fd}')
KS_SEEKING_CAPABILITIES = Int32
KS_SEEKING_CanSeekAbsolute: win32more.Windows.Win32.Media.KernelStreaming.KS_SEEKING_CAPABILITIES = 1
KS_SEEKING_CanSeekForwards: win32more.Windows.Win32.Media.KernelStreaming.KS_SEEKING_CAPABILITIES = 2
KS_SEEKING_CanSeekBackwards: win32more.Windows.Win32.Media.KernelStreaming.KS_SEEKING_CAPABILITIES = 4
KS_SEEKING_CanGetCurrentPos: win32more.Windows.Win32.Media.KernelStreaming.KS_SEEKING_CAPABILITIES = 8
KS_SEEKING_CanGetStopPos: win32more.Windows.Win32.Media.KernelStreaming.KS_SEEKING_CAPABILITIES = 16
KS_SEEKING_CanGetDuration: win32more.Windows.Win32.Media.KernelStreaming.KS_SEEKING_CAPABILITIES = 32
KS_SEEKING_CanPlayBackwards: win32more.Windows.Win32.Media.KernelStreaming.KS_SEEKING_CAPABILITIES = 64
KS_SEEKING_FLAGS = Int32
KS_SEEKING_NoPositioning: win32more.Windows.Win32.Media.KernelStreaming.KS_SEEKING_FLAGS = 0
KS_SEEKING_AbsolutePositioning: win32more.Windows.Win32.Media.KernelStreaming.KS_SEEKING_FLAGS = 1
KS_SEEKING_RelativePositioning: win32more.Windows.Win32.Media.KernelStreaming.KS_SEEKING_FLAGS = 2
KS_SEEKING_IncrementalPositioning: win32more.Windows.Win32.Media.KernelStreaming.KS_SEEKING_FLAGS = 3
KS_SEEKING_PositioningBitsMask: win32more.Windows.Win32.Media.KernelStreaming.KS_SEEKING_FLAGS = 3
KS_SEEKING_SeekToKeyFrame: win32more.Windows.Win32.Media.KernelStreaming.KS_SEEKING_FLAGS = 4
KS_SEEKING_ReturnTime: win32more.Windows.Win32.Media.KernelStreaming.KS_SEEKING_FLAGS = 8
class KS_TRUECOLORINFO(Structure):
    dwBitMasks: UInt32 * 3
    bmiColors: win32more.Windows.Win32.Media.KernelStreaming.KS_RGBQUAD * 256
KS_TUNER_STRATEGY = Int32
KS_TUNER_STRATEGY_PLL: win32more.Windows.Win32.Media.KernelStreaming.KS_TUNER_STRATEGY = 1
KS_TUNER_STRATEGY_SIGNAL_STRENGTH: win32more.Windows.Win32.Media.KernelStreaming.KS_TUNER_STRATEGY = 2
KS_TUNER_STRATEGY_DRIVER_TUNES: win32more.Windows.Win32.Media.KernelStreaming.KS_TUNER_STRATEGY = 4
KS_TUNER_TUNING_FLAGS = Int32
KS_TUNER_TUNING_EXACT: win32more.Windows.Win32.Media.KernelStreaming.KS_TUNER_TUNING_FLAGS = 1
KS_TUNER_TUNING_FINE: win32more.Windows.Win32.Media.KernelStreaming.KS_TUNER_TUNING_FLAGS = 2
KS_TUNER_TUNING_COARSE: win32more.Windows.Win32.Media.KernelStreaming.KS_TUNER_TUNING_FLAGS = 3
class KS_TVTUNER_CHANGE_INFO(Structure):
    dwFlags: UInt32
    dwCountryCode: UInt32
    dwAnalogVideoStandard: UInt32
    dwChannel: UInt32
class KS_VBIINFOHEADER(Structure):
    StartLine: UInt32
    EndLine: UInt32
    SamplingFrequency: UInt32
    MinLineStartTime: UInt32
    MaxLineStartTime: UInt32
    ActualLineStartTime: UInt32
    ActualLineEndTime: UInt32
    VideoStandard: UInt32
    SamplesPerLine: UInt32
    StrideInBytes: UInt32
    BufferSize: UInt32
class KS_VBI_FRAME_INFO(Structure):
    ExtendedHeaderSize: UInt32
    dwFrameFlags: UInt32
    PictureNumber: Int64
    DropCount: Int64
    dwSamplingFrequency: UInt32
    TvTunerChangeInfo: win32more.Windows.Win32.Media.KernelStreaming.KS_TVTUNER_CHANGE_INFO
    VBIInfoHeader: win32more.Windows.Win32.Media.KernelStreaming.KS_VBIINFOHEADER
KS_VIDEODECODER_FLAGS = Int32
KS_VIDEODECODER_FLAGS_CAN_DISABLE_OUTPUT: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEODECODER_FLAGS = 1
KS_VIDEODECODER_FLAGS_CAN_USE_VCR_LOCKING: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEODECODER_FLAGS = 2
KS_VIDEODECODER_FLAGS_CAN_INDICATE_LOCKED: win32more.Windows.Win32.Media.KernelStreaming.KS_VIDEODECODER_FLAGS = 4
class KS_VIDEOINFO(Structure):
    rcSource: win32more.Windows.Win32.Foundation.RECT
    rcTarget: win32more.Windows.Win32.Foundation.RECT
    dwBitRate: UInt32
    dwBitErrorRate: UInt32
    AvgTimePerFrame: Int64
    bmiHeader: win32more.Windows.Win32.Media.KernelStreaming.KS_BITMAPINFOHEADER
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        bmiColors: win32more.Windows.Win32.Media.KernelStreaming.KS_RGBQUAD * 256
        dwBitMasks: UInt32 * 3
        TrueColorInfo: win32more.Windows.Win32.Media.KernelStreaming.KS_TRUECOLORINFO
class KS_VIDEOINFOHEADER(Structure):
    rcSource: win32more.Windows.Win32.Foundation.RECT
    rcTarget: win32more.Windows.Win32.Foundation.RECT
    dwBitRate: UInt32
    dwBitErrorRate: UInt32
    AvgTimePerFrame: Int64
    bmiHeader: win32more.Windows.Win32.Media.KernelStreaming.KS_BITMAPINFOHEADER
class KS_VIDEOINFOHEADER2(Structure):
    rcSource: win32more.Windows.Win32.Foundation.RECT
    rcTarget: win32more.Windows.Win32.Foundation.RECT
    dwBitRate: UInt32
    dwBitErrorRate: UInt32
    AvgTimePerFrame: Int64
    dwInterlaceFlags: UInt32
    dwCopyProtectFlags: UInt32
    dwPictAspectRatioX: UInt32
    dwPictAspectRatioY: UInt32
    Anonymous: _Anonymous_e__Union
    dwReserved2: UInt32
    bmiHeader: win32more.Windows.Win32.Media.KernelStreaming.KS_BITMAPINFOHEADER
    class _Anonymous_e__Union(Union):
        dwControlFlags: UInt32
        dwReserved1: UInt32
class KS_VIDEO_STREAM_CONFIG_CAPS(Structure):
    guid: Guid
    VideoStandard: UInt32
    InputSize: win32more.Windows.Win32.Foundation.SIZE
    MinCroppingSize: win32more.Windows.Win32.Foundation.SIZE
    MaxCroppingSize: win32more.Windows.Win32.Foundation.SIZE
    CropGranularityX: Int32
    CropGranularityY: Int32
    CropAlignX: Int32
    CropAlignY: Int32
    MinOutputSize: win32more.Windows.Win32.Foundation.SIZE
    MaxOutputSize: win32more.Windows.Win32.Foundation.SIZE
    OutputGranularityX: Int32
    OutputGranularityY: Int32
    StretchTapsX: Int32
    StretchTapsY: Int32
    ShrinkTapsX: Int32
    ShrinkTapsY: Int32
    MinFrameInterval: Int64
    MaxFrameInterval: Int64
    MinBitsPerSecond: Int32
    MaxBitsPerSecond: Int32
KS_VideoControlFlags = Int32
KS_VideoControlFlag_FlipHorizontal: win32more.Windows.Win32.Media.KernelStreaming.KS_VideoControlFlags = 1
KS_VideoControlFlag_FlipVertical: win32more.Windows.Win32.Media.KernelStreaming.KS_VideoControlFlags = 2
KS_Obsolete_VideoControlFlag_ExternalTriggerEnable: win32more.Windows.Win32.Media.KernelStreaming.KS_VideoControlFlags = 16
KS_Obsolete_VideoControlFlag_Trigger: win32more.Windows.Win32.Media.KernelStreaming.KS_VideoControlFlags = 32
KS_VideoControlFlag_ExternalTriggerEnable: win32more.Windows.Win32.Media.KernelStreaming.KS_VideoControlFlags = 4
KS_VideoControlFlag_Trigger: win32more.Windows.Win32.Media.KernelStreaming.KS_VideoControlFlags = 8
KS_VideoControlFlag_IndependentImagePin: win32more.Windows.Win32.Media.KernelStreaming.KS_VideoControlFlags = 64
KS_VideoControlFlag_StillCapturePreviewFrame: win32more.Windows.Win32.Media.KernelStreaming.KS_VideoControlFlags = 128
KS_VideoControlFlag_StartPhotoSequenceCapture: win32more.Windows.Win32.Media.KernelStreaming.KS_VideoControlFlags = 256
KS_VideoControlFlag_StopPhotoSequenceCapture: win32more.Windows.Win32.Media.KernelStreaming.KS_VideoControlFlags = 512
KS_VideoStreamingHints = Int32
KS_StreamingHint_FrameInterval: win32more.Windows.Win32.Media.KernelStreaming.KS_VideoStreamingHints = 256
KS_StreamingHint_KeyFrameRate: win32more.Windows.Win32.Media.KernelStreaming.KS_VideoStreamingHints = 512
KS_StreamingHint_PFrameRate: win32more.Windows.Win32.Media.KernelStreaming.KS_VideoStreamingHints = 1024
KS_StreamingHint_CompQuality: win32more.Windows.Win32.Media.KernelStreaming.KS_VideoStreamingHints = 2048
KS_StreamingHint_CompWindowSize: win32more.Windows.Win32.Media.KernelStreaming.KS_VideoStreamingHints = 4096
class LOOPEDSTREAMING_POSITION_EVENT_DATA(Structure):
    KsEventData: win32more.Windows.Win32.Media.KernelStreaming.KSEVENTDATA
    Position: UInt64
class MEDIUM_INFO(Structure):
    MediaPresent: win32more.Windows.Win32.Foundation.BOOL
    MediaType: UInt32
    RecordInhibit: win32more.Windows.Win32.Foundation.BOOL
class MF_MDL_SHARED_PAYLOAD_KEY(Union):
    combined: _combined_e__Struct
    GMDLHandle: Guid
    class _combined_e__Struct(Structure):
        pHandle: UInt32
        fHandle: UInt32
        uPayload: UInt64
class NABTSFEC_BUFFER(Structure):
    dataSize: UInt32
    groupID: UInt16
    Reserved: UInt16
    data: Byte * 448
class NABTS_BUFFER(Structure):
    ScanlinesRequested: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_SCANLINES
    PictureNumber: Int64
    NabtsLines: win32more.Windows.Win32.Media.KernelStreaming.NABTS_BUFFER_LINE * 11
    _pack_ = 1
class NABTS_BUFFER_LINE(Structure):
    Confidence: Byte
    Bytes: Byte * 36
class OPTIMAL_WEIGHT_TOTALS(Structure):
    MinTotalNominator: Int64
    MaxTotalNominator: Int64
    TotalDenominator: Int64
PINNAME_DISPLAYPORT_OUT = Guid('{21fbb329-1a4a-48da-a076-2318a3c59b26}')
PINNAME_HDMI_OUT = Guid('{387bfc03-e7ef-4901-86e0-35b7c32b00ef}')
PINNAME_IMAGE = Guid('{38a0cd98-d49b-4ce8-b48a-344667a17830}')
PINNAME_SPDIF_IN = Guid('{15dc9025-22ad-41b3-8875-f4ceb0299e20}')
PINNAME_SPDIF_OUT = Guid('{3a264481-e52c-4b82-8e7a-c8e2f91dc380}')
PINNAME_VIDEO_ANALOGVIDEOIN = Guid('{fb6c4283-0353-11d1-905f-0000c0cc16ba}')
PINNAME_VIDEO_CAPTURE = Guid('{fb6c4281-0353-11d1-905f-0000c0cc16ba}')
PINNAME_VIDEO_CC = Guid('{fb6c4289-0353-11d1-905f-0000c0cc16ba}')
PINNAME_VIDEO_CC_CAPTURE = Guid('{1aad8061-012d-11d2-b4b1-00a0d102cfbe}')
PINNAME_VIDEO_EDS = Guid('{fb6c4287-0353-11d1-905f-0000c0cc16ba}')
PINNAME_VIDEO_NABTS = Guid('{fb6c4286-0353-11d1-905f-0000c0cc16ba}')
PINNAME_VIDEO_NABTS_CAPTURE = Guid('{29703660-498a-11d2-b4b1-00a0d102cfbe}')
PINNAME_VIDEO_PREVIEW = Guid('{fb6c4282-0353-11d1-905f-0000c0cc16ba}')
PINNAME_VIDEO_STILL = Guid('{fb6c428a-0353-11d1-905f-0000c0cc16ba}')
PINNAME_VIDEO_TELETEXT = Guid('{fb6c4288-0353-11d1-905f-0000c0cc16ba}')
PINNAME_VIDEO_TIMECODE = Guid('{fb6c428b-0353-11d1-905f-0000c0cc16ba}')
PINNAME_VIDEO_VBI = Guid('{fb6c4284-0353-11d1-905f-0000c0cc16ba}')
PINNAME_VIDEO_VIDEOPORT = Guid('{fb6c4285-0353-11d1-905f-0000c0cc16ba}')
PINNAME_VIDEO_VIDEOPORT_VBI = Guid('{fb6c428c-0353-11d1-905f-0000c0cc16ba}')
PIPE_ALLOCATOR_PLACE = Int32
Pipe_Allocator_None: win32more.Windows.Win32.Media.KernelStreaming.PIPE_ALLOCATOR_PLACE = 0
Pipe_Allocator_FirstPin: win32more.Windows.Win32.Media.KernelStreaming.PIPE_ALLOCATOR_PLACE = 1
Pipe_Allocator_LastPin: win32more.Windows.Win32.Media.KernelStreaming.PIPE_ALLOCATOR_PLACE = 2
Pipe_Allocator_MiddlePin: win32more.Windows.Win32.Media.KernelStreaming.PIPE_ALLOCATOR_PLACE = 3
class PIPE_DIMENSIONS(Structure):
    AllocatorPin: win32more.Windows.Win32.Media.KernelStreaming.KS_COMPRESSION
    MaxExpansionPin: win32more.Windows.Win32.Media.KernelStreaming.KS_COMPRESSION
    EndPin: win32more.Windows.Win32.Media.KernelStreaming.KS_COMPRESSION
PIPE_STATE = Int32
PipeState_DontCare: win32more.Windows.Win32.Media.KernelStreaming.PIPE_STATE = 0
PipeState_RangeNotFixed: win32more.Windows.Win32.Media.KernelStreaming.PIPE_STATE = 1
PipeState_RangeFixed: win32more.Windows.Win32.Media.KernelStreaming.PIPE_STATE = 2
PipeState_CompressionUnknown: win32more.Windows.Win32.Media.KernelStreaming.PIPE_STATE = 3
PipeState_Finalized: win32more.Windows.Win32.Media.KernelStreaming.PIPE_STATE = 4
class PIPE_TERMINATION(Structure):
    Flags: UInt32
    OutsideFactors: UInt32
    Weigth: UInt32
    PhysicalRange: win32more.Windows.Win32.Media.KernelStreaming.KS_FRAMING_RANGE
    OptimalRange: win32more.Windows.Win32.Media.KernelStreaming.KS_FRAMING_RANGE_WEIGHTED
    Compression: win32more.Windows.Win32.Media.KernelStreaming.KS_COMPRESSION
PROPSETID_ALLOCATOR_CONTROL = Guid('{53171960-148e-11d2-9979-0000c0cc16ba}')
PROPSETID_EXT_DEVICE = Guid('{b5730a90-1a2c-11cf-8c23-00aa006b6814}')
PROPSETID_EXT_TRANSPORT = Guid('{a03cd5f0-3045-11cf-8c44-00aa006b6814}')
PROPSETID_TIMECODE_READER = Guid('{9b496ce1-811b-11cf-8c77-00aa006b6814}')
PROPSETID_TUNER = Guid('{6a2e0605-28e4-11d0-a18c-00a0c9118956}')
PROPSETID_VIDCAP_CAMERACONTROL = Guid('{c6e13370-30ac-11d0-a18c-00a0c9118956}')
PROPSETID_VIDCAP_CAMERACONTROL_FLASH = Guid('{785e8f49-63a2-4144-ab70-ffb278fa26ce}')
PROPSETID_VIDCAP_CAMERACONTROL_IMAGE_PIN_CAPABILITY = Guid('{9d3d7bbf-5c6d-4138-bb00-584edd20f7c5}')
PROPSETID_VIDCAP_CAMERACONTROL_REGION_OF_INTEREST = Guid('{9d12d198-f86c-4fed-b023-5d87653da793}')
PROPSETID_VIDCAP_CAMERACONTROL_VIDEO_STABILIZATION = Guid('{43964bd3-7716-404e-8be1-d299b20e50fd}')
PROPSETID_VIDCAP_CROSSBAR = Guid('{6a2e0640-28e4-11d0-a18c-00a0c9118956}')
PROPSETID_VIDCAP_DROPPEDFRAMES = Guid('{c6e13344-30ac-11d0-a18c-00a0c9118956}')
PROPSETID_VIDCAP_SELECTOR = Guid('{1abdaeca-68b6-4f83-9371-b413907c7b9f}')
PROPSETID_VIDCAP_TVAUDIO = Guid('{6a2e0650-28e4-11d0-a18c-00a0c9118956}')
PROPSETID_VIDCAP_VIDEOCOMPRESSION = Guid('{c6e13343-30ac-11d0-a18c-00a0c9118956}')
PROPSETID_VIDCAP_VIDEOCONTROL = Guid('{6a2e0670-28e4-11d0-a18c-00a0c9118956}')
PROPSETID_VIDCAP_VIDEODECODER = Guid('{c6e13350-30ac-11d0-a18c-00a0c9118956}')
PROPSETID_VIDCAP_VIDEOENCODER = Guid('{6a2e0610-28e4-11d0-a18c-00a0c9118956}')
PROPSETID_VIDCAP_VIDEOPROCAMP = Guid('{c6e13360-30ac-11d0-a18c-00a0c9118956}')
class SECURE_BUFFER_INFO(Structure):
    guidBufferIdentifier: Guid
    cbBufferSize: UInt32
    cbCaptured: UInt32
    ullReserved: UInt64 * 16
class SOUNDDETECTOR_PATTERNHEADER(Structure):
    Size: UInt32
    PatternType: Guid
TELEPHONY_CALLCONTROLOP = Int32
TELEPHONY_CALLCONTROLOP_DISABLE: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_CALLCONTROLOP = 0
TELEPHONY_CALLCONTROLOP_ENABLE: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_CALLCONTROLOP = 1
TELEPHONY_CALLSTATE = Int32
TELEPHONY_CALLSTATE_DISABLED: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_CALLSTATE = 0
TELEPHONY_CALLSTATE_ENABLED: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_CALLSTATE = 1
TELEPHONY_CALLSTATE_HOLD: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_CALLSTATE = 2
TELEPHONY_CALLSTATE_PROVIDERTRANSITION: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_CALLSTATE = 3
TELEPHONY_CALLTYPE = Int32
TELEPHONY_CALLTYPE_CIRCUITSWITCHED: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_CALLTYPE = 0
TELEPHONY_CALLTYPE_PACKETSWITCHED_LTE: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_CALLTYPE = 1
TELEPHONY_CALLTYPE_PACKETSWITCHED_WLAN: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_CALLTYPE = 2
TELEPHONY_PROVIDERCHANGEOP = Int32
TELEPHONY_PROVIDERCHANGEOP_END: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_PROVIDERCHANGEOP = 0
TELEPHONY_PROVIDERCHANGEOP_BEGIN: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_PROVIDERCHANGEOP = 1
TELEPHONY_PROVIDERCHANGEOP_CANCEL: win32more.Windows.Win32.Media.KernelStreaming.TELEPHONY_PROVIDERCHANGEOP = 2
class TRANSPORTAUDIOPARMS(Structure):
    EnableOutput: Int32
    EnableRecord: Int32
    EnableSelsync: Int32
    Input: Int32
    MonitorSource: Int32
class TRANSPORTBASICPARMS(Structure):
    TimeFormat: Int32
    TimeReference: Int32
    Superimpose: Int32
    EndStopAction: Int32
    RecordFormat: Int32
    StepFrames: Int32
    SetpField: Int32
    Preroll: Int32
    RecPreroll: Int32
    Postroll: Int32
    EditDelay: Int32
    PlayTCDelay: Int32
    RecTCDelay: Int32
    EditField: Int32
    FrameServo: Int32
    ColorFrameServo: Int32
    ServoRef: Int32
    WarnGenlock: Int32
    SetTracking: Int32
    VolumeName: SByte * 40
    Ballistic: Int32 * 20
    Speed: Int32
    CounterFormat: Int32
    TunerChannel: Int32
    TunerNumber: Int32
    TimerEvent: Int32
    TimerStartDay: Int32
    TimerStartTime: Int32
    TimerStopDay: Int32
    TimerStopTime: Int32
class TRANSPORTSTATUS(Structure):
    Mode: Int32
    LastError: Int32
    RecordInhibit: Int32
    ServoLock: Int32
    MediaPresent: Int32
    MediaLength: Int32
    MediaSize: Int32
    MediaTrackCount: Int32
    MediaTrackLength: Int32
    MediaTrackSide: Int32
    MediaType: Int32
    LinkMode: Int32
    NotifyOn: Int32
class TRANSPORTVIDEOPARMS(Structure):
    OutputMode: Int32
    Input: Int32
class TRANSPORT_STATE(Structure):
    Mode: UInt32
    State: UInt32
class TUNER_ANALOG_CAPS_S(Structure):
    Mode: UInt32
    StandardsSupported: UInt32
    MinFrequency: UInt32
    MaxFrequency: UInt32
    TuningGranularity: UInt32
    SettlingTime: UInt32
    ScanSensingRange: UInt32
    FineTuneSensingRange: UInt32
TunerLockType = Int32
Tuner_LockType_None: win32more.Windows.Win32.Media.KernelStreaming.TunerLockType = 0
Tuner_LockType_Within_Scan_Sensing_Range: win32more.Windows.Win32.Media.KernelStreaming.TunerLockType = 1
Tuner_LockType_Locked: win32more.Windows.Win32.Media.KernelStreaming.TunerLockType = 2
class VBICAP_PROPERTIES_PROTECTION_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    StreamIndex: UInt32
    Status: UInt32
class VBICODECFILTERING_CC_SUBSTREAMS(Structure):
    SubstreamMask: UInt32
class VBICODECFILTERING_NABTS_SUBSTREAMS(Structure):
    SubstreamMask: UInt32 * 128
class VBICODECFILTERING_SCANLINES(Structure):
    DwordBitArray: UInt32 * 32
class VBICODECFILTERING_STATISTICS_CC(Structure):
    Common: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_STATISTICS_COMMON
class VBICODECFILTERING_STATISTICS_CC_PIN(Structure):
    Common: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_STATISTICS_COMMON_PIN
class VBICODECFILTERING_STATISTICS_COMMON(Structure):
    InputSRBsProcessed: UInt32
    OutputSRBsProcessed: UInt32
    SRBsIgnored: UInt32
    InputSRBsMissing: UInt32
    OutputSRBsMissing: UInt32
    OutputFailures: UInt32
    InternalErrors: UInt32
    ExternalErrors: UInt32
    InputDiscontinuities: UInt32
    DSPFailures: UInt32
    TvTunerChanges: UInt32
    VBIHeaderChanges: UInt32
    LineConfidenceAvg: UInt32
    BytesOutput: UInt32
class VBICODECFILTERING_STATISTICS_COMMON_PIN(Structure):
    SRBsProcessed: UInt32
    SRBsIgnored: UInt32
    SRBsMissing: UInt32
    InternalErrors: UInt32
    ExternalErrors: UInt32
    Discontinuities: UInt32
    LineConfidenceAvg: UInt32
    BytesOutput: UInt32
class VBICODECFILTERING_STATISTICS_NABTS(Structure):
    Common: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_STATISTICS_COMMON
    FECBundleBadLines: UInt32
    FECQueueOverflows: UInt32
    FECCorrectedLines: UInt32
    FECUncorrectableLines: UInt32
    BundlesProcessed: UInt32
    BundlesSent2IP: UInt32
    FilteredLines: UInt32
class VBICODECFILTERING_STATISTICS_NABTS_PIN(Structure):
    Common: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_STATISTICS_COMMON_PIN
class VBICODECFILTERING_STATISTICS_TELETEXT(Structure):
    Common: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_STATISTICS_COMMON
class VBICODECFILTERING_STATISTICS_TELETEXT_PIN(Structure):
    Common: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_STATISTICS_COMMON_PIN
class VRAM_SURFACE_INFO(Structure):
    hSurface: UIntPtr
    VramPhysicalAddress: Int64
    cbCaptured: UInt32
    dwWidth: UInt32
    dwHeight: UInt32
    dwLinearSize: UInt32
    lPitch: Int32
    ullReserved: UInt64 * 16
class VRAM_SURFACE_INFO_PROPERTY_S(Structure):
    Property: win32more.Windows.Win32.Media.KernelStreaming.KSIDENTIFIER
    pVramSurfaceInfo: POINTER(win32more.Windows.Win32.Media.KernelStreaming.VRAM_SURFACE_INFO)
class WNF_KSCAMERA_STREAMSTATE_INFO(Structure):
    ProcessId: UInt32
    SessionId: UInt32
    StreamState: UInt32
    Reserved: UInt32
class WST_BUFFER(Structure):
    ScanlinesRequested: win32more.Windows.Win32.Media.KernelStreaming.VBICODECFILTERING_SCANLINES
    WstLines: win32more.Windows.Win32.Media.KernelStreaming.WST_BUFFER_LINE * 17
class WST_BUFFER_LINE(Structure):
    Confidence: Byte
    Bytes: Byte * 42


make_ready(__name__)
