from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.Networking.Clustering
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Registry
import win32more.Windows.Win32.System.Services
import win32more.Windows.Win32.System.Variant
import win32more.Windows.Win32.UI.WindowsAndMessaging
CLUSTER_VERSION_FLAG_MIXED_MODE: UInt32 = 1
CLUSTER_VERSION_UNKNOWN: UInt32 = 4294967295
NT4_MAJOR_VERSION: UInt32 = 1
NT4SP4_MAJOR_VERSION: UInt32 = 2
NT5_MAJOR_VERSION: UInt32 = 3
NT51_MAJOR_VERSION: UInt32 = 4
NT6_MAJOR_VERSION: UInt32 = 5
NT7_MAJOR_VERSION: UInt32 = 6
NT8_MAJOR_VERSION: UInt32 = 7
NT9_MAJOR_VERSION: UInt32 = 8
NT10_MAJOR_VERSION: UInt32 = 9
NT11_MAJOR_VERSION: UInt32 = 10
NT12_MAJOR_VERSION: UInt32 = 11
NT13_MAJOR_VERSION: UInt32 = 12
WS2016_TP4_UPGRADE_VERSION: UInt32 = 6
WS2016_TP5_UPGRADE_VERSION: UInt32 = 7
WS2016_RTM_UPGRADE_VERSION: UInt32 = 8
RS3_UPGRADE_VERSION: UInt32 = 1
RS4_UPGRADE_VERSION: UInt32 = 2
RS5_UPGRADE_VERSION: UInt32 = 3
NINETEEN_H1_UPGRADE_VERSION: UInt32 = 1
NINETEEN_H2_UPGRADE_VERSION: UInt32 = 2
MN_UPGRADE_VERSION: UInt32 = 3
FE_UPGRADE_VERSION: UInt32 = 4
CA_UPGRADE_VERSION: UInt32 = 1
NI_UPGRADE_VERSION: UInt32 = 2
HCI_UPGRADE_BIT: UInt32 = 32768
CLUSREG_NAME_MIXED_MODE: String = 'MixedMode'
CLUSAPI_VERSION_SERVER2008: UInt32 = 1536
CLUSAPI_VERSION_SERVER2008R2: UInt32 = 1792
CLUSAPI_VERSION_WINDOWS8: UInt32 = 1793
CLUSAPI_VERSION_WINDOWSBLUE: UInt32 = 1794
CLUSAPI_VERSION_WINTHRESHOLD: UInt32 = 1795
CLUSAPI_VERSION_RS3: UInt32 = 2560
CLUSAPI_VERSION_NI: UInt32 = 2572
CLUSAPI_VERSION: UInt32 = 2572
CREATE_CLUSTER_VERSION: UInt32 = 1536
CREATE_CLUSTER_MAJOR_VERSION_MASK: UInt32 = 4294967040
MAX_CLUSTERNAME_LENGTH: UInt32 = 63
CLUSTER_INSTALLED: UInt32 = 1
CLUSTER_CONFIGURED: UInt32 = 2
CLUSTER_RUNNING: UInt32 = 16
CLUS_HYBRID_QUORUM: UInt32 = 1024
CLUS_NODE_MAJORITY_QUORUM: UInt32 = 0
CLUSCTL_RESOURCE_STATE_CHANGE_REASON_VERSION_1: UInt32 = 1
CLUSREG_DATABASE_SYNC_WRITE_TO_ALL_NODES: UInt32 = 1
CLUSREG_DATABASE_ISOLATE_READ: UInt32 = 2
CLUSTER_ENUM_ITEM_VERSION_1: UInt32 = 1
CLUSTER_ENUM_ITEM_VERSION: UInt32 = 1
CLUSTER_CREATE_GROUP_INFO_VERSION_1: UInt32 = 1
CLUSTER_CREATE_GROUP_INFO_VERSION: UInt32 = 1
GROUPSET_READY_SETTING_DELAY: UInt32 = 1
GROUPSET_READY_SETTING_ONLINE: UInt32 = 2
GROUPSET_READY_SETTING_OS_HEARTBEAT: UInt32 = 3
GROUPSET_READY_SETTING_APPLICATION_READY: UInt32 = 4
CLUS_GRP_MOVE_ALLOWED: UInt32 = 0
CLUS_GRP_MOVE_LOCKED: UInt32 = 1
CLUSAPI_READ_ACCESS: Int32 = 1
CLUSAPI_CHANGE_ACCESS: Int32 = 2
CLUSAPI_NO_ACCESS: Int32 = 4
CLUSTER_SET_ACCESS_TYPE_ALLOWED: UInt32 = 0
CLUSTER_SET_ACCESS_TYPE_DENIED: UInt32 = 1
CLUSTER_DELETE_ACCESS_CONTROL_ENTRY: UInt32 = 2
CLUSGROUPSET_STATUS_GROUPS_PENDING: UInt64 = 1
CLUSGROUPSET_STATUS_GROUPS_ONLINE: UInt64 = 2
CLUSGROUPSET_STATUS_OS_HEARTBEAT: UInt64 = 4
CLUSGROUPSET_STATUS_APPLICATION_READY: UInt64 = 8
CLUSTER_AVAILABILITY_SET_CONFIG_V1: UInt32 = 1
CLUSTER_GROUP_ENUM_ITEM_VERSION_1: UInt32 = 1
CLUSTER_GROUP_ENUM_ITEM_VERSION: UInt32 = 1
CLUSTER_RESOURCE_ENUM_ITEM_VERSION_1: UInt32 = 1
CLUSTER_RESOURCE_ENUM_ITEM_VERSION: UInt32 = 1
CLUSAPI_NODE_PAUSE_REMAIN_ON_PAUSED_NODE_ON_MOVE_ERROR: UInt32 = 1
CLUSAPI_NODE_AVOID_PLACEMENT: UInt32 = 2
CLUSAPI_NODE_PAUSE_RETRY_DRAIN_ON_FAILURE: UInt32 = 4
CLUSAPI_NODE_RESUME_FAILBACK_STORAGE: UInt32 = 1
CLUSAPI_NODE_RESUME_FAILBACK_VMS: UInt32 = 2
CLUSAPI_NODE_RESUME_FAILBACK_PINNED_VMS_ONLY: UInt32 = 4
CLUSGRP_STATUS_LOCKED_MODE: UInt64 = 1
CLUSGRP_STATUS_PREEMPTED: UInt64 = 2
CLUSGRP_STATUS_WAITING_IN_QUEUE_FOR_MOVE: UInt64 = 4
CLUSGRP_STATUS_PHYSICAL_RESOURCES_LACKING: UInt64 = 8
CLUSGRP_STATUS_WAITING_TO_START: UInt64 = 16
CLUSGRP_STATUS_EMBEDDED_FAILURE: UInt64 = 32
CLUSGRP_STATUS_OFFLINE_DUE_TO_ANTIAFFINITY_CONFLICT: UInt64 = 64
CLUSGRP_STATUS_NETWORK_FAILURE: UInt64 = 128
CLUSGRP_STATUS_UNMONITORED: UInt64 = 256
CLUSGRP_STATUS_OS_HEARTBEAT: UInt64 = 512
CLUSGRP_STATUS_APPLICATION_READY: UInt64 = 1024
CLUSGRP_STATUS_OFFLINE_NOT_LOCAL_DISK_OWNER: UInt64 = 2048
CLUSGRP_STATUS_WAITING_FOR_DEPENDENCIES: UInt64 = 4096
CLUSRES_STATUS_LOCKED_MODE: UInt64 = 1
CLUSRES_STATUS_EMBEDDED_FAILURE: UInt64 = 2
CLUSRES_STATUS_FAILED_DUE_TO_INSUFFICIENT_CPU: UInt64 = 4
CLUSRES_STATUS_FAILED_DUE_TO_INSUFFICIENT_MEMORY: UInt64 = 8
CLUSRES_STATUS_FAILED_DUE_TO_INSUFFICIENT_GENERIC_RESOURCES: UInt64 = 16
CLUSRES_STATUS_NETWORK_FAILURE: UInt64 = 32
CLUSRES_STATUS_UNMONITORED: UInt64 = 64
CLUSRES_STATUS_OS_HEARTBEAT: UInt64 = 128
CLUSRES_STATUS_APPLICATION_READY: UInt64 = 256
CLUSRES_STATUS_OFFLINE_NOT_LOCAL_DISK_OWNER: UInt64 = 512
CLUSAPI_GROUP_ONLINE_IGNORE_RESOURCE_STATUS: UInt32 = 1
CLUSAPI_GROUP_ONLINE_SYNCHRONOUS: UInt32 = 2
CLUSAPI_GROUP_ONLINE_BEST_POSSIBLE_NODE: UInt32 = 4
CLUSAPI_GROUP_ONLINE_IGNORE_AFFINITY_RULE: UInt32 = 8
CLUSAPI_GROUP_OFFLINE_IGNORE_RESOURCE_STATUS: UInt32 = 1
CLUSAPI_RESOURCE_ONLINE_IGNORE_RESOURCE_STATUS: UInt32 = 1
CLUSAPI_RESOURCE_ONLINE_DO_NOT_UPDATE_PERSISTENT_STATE: UInt32 = 2
CLUSAPI_RESOURCE_ONLINE_NECESSARY_FOR_QUORUM: UInt32 = 4
CLUSAPI_RESOURCE_ONLINE_BEST_POSSIBLE_NODE: UInt32 = 8
CLUSAPI_RESOURCE_ONLINE_IGNORE_AFFINITY_RULE: UInt32 = 32
CLUSAPI_RESOURCE_OFFLINE_IGNORE_RESOURCE_STATUS: UInt32 = 1
CLUSAPI_RESOURCE_OFFLINE_FORCE_WITH_TERMINATION: UInt32 = 2
CLUSAPI_RESOURCE_OFFLINE_DO_NOT_UPDATE_PERSISTENT_STATE: UInt32 = 4
CLUSAPI_RESOURCE_OFFLINE_REASON_NONE: UInt32 = 0
CLUSAPI_RESOURCE_OFFLINE_REASON_UNKNOWN: UInt32 = 1
CLUSAPI_RESOURCE_OFFLINE_REASON_MOVING: UInt32 = 2
CLUSAPI_RESOURCE_OFFLINE_REASON_USER_REQUESTED: UInt32 = 4
CLUSAPI_RESOURCE_OFFLINE_REASON_BEING_DELETED: UInt32 = 8
CLUSAPI_RESOURCE_OFFLINE_REASON_BEING_RESTARTED: UInt32 = 16
CLUSAPI_RESOURCE_OFFLINE_REASON_PREEMPTED: UInt32 = 32
CLUSAPI_RESOURCE_OFFLINE_REASON_SHUTTING_DOWN: UInt32 = 64
CLUSAPI_GROUP_MOVE_IGNORE_RESOURCE_STATUS: UInt32 = 1
CLUSAPI_GROUP_MOVE_RETURN_TO_SOURCE_NODE_ON_ERROR: UInt32 = 2
CLUSAPI_GROUP_MOVE_QUEUE_ENABLED: UInt32 = 4
CLUSAPI_GROUP_MOVE_HIGH_PRIORITY_START: UInt32 = 8
CLUSAPI_GROUP_MOVE_FAILBACK: UInt32 = 16
CLUSAPI_GROUP_MOVE_IGNORE_AFFINITY_RULE: UInt32 = 32
CLUSAPI_CHANGE_RESOURCE_GROUP_FORCE_MOVE_TO_CSV: UInt64 = 1
CLUSAPI_VALID_CHANGE_RESOURCE_GROUP_FLAGS: UInt64 = 1
GROUP_FAILURE_INFO_VERSION_1: UInt32 = 1
RESOURCE_FAILURE_INFO_VERSION_1: UInt32 = 1
CLUS_ACCESS_ANY: UInt32 = 0
CLUS_ACCESS_READ: UInt32 = 1
CLUS_ACCESS_WRITE: UInt32 = 2
CLUS_NO_MODIFY: UInt32 = 0
CLUS_MODIFY: UInt32 = 1
CLUS_NOT_GLOBAL: UInt32 = 0
CLUS_GLOBAL: UInt32 = 1
CLUSCTL_ACCESS_SHIFT: UInt32 = 0
CLUSCTL_FUNCTION_SHIFT: UInt32 = 2
CLCTL_INTERNAL_SHIFT: UInt32 = 20
CLCTL_USER_SHIFT: UInt32 = 21
CLCTL_MODIFY_SHIFT: UInt32 = 22
CLCTL_GLOBAL_SHIFT: UInt32 = 23
CLUSCTL_OBJECT_SHIFT: UInt32 = 24
CLUSCTL_CONTROL_CODE_MASK: UInt32 = 4194303
CLUSCTL_OBJECT_MASK: UInt32 = 255
CLUSCTL_ACCESS_MODE_MASK: UInt32 = 3
CLCTL_CLUSTER_BASE: UInt32 = 0
BitLockerEnabled: Int32 = 1
BitLockerDecrypted: Int32 = 4
BitlockerEncrypted: Int32 = 8
BitLockerDecrypting: Int32 = 16
BitlockerEncrypting: Int32 = 32
BitLockerPaused: Int32 = 64
BitLockerStopped: Int32 = 128
RedirectedIOReasonUserRequest: UInt64 = 1
RedirectedIOReasonUnsafeFileSystemFilter: UInt64 = 2
RedirectedIOReasonUnsafeVolumeFilter: UInt64 = 4
RedirectedIOReasonFileSystemTiering: UInt64 = 8
RedirectedIOReasonBitLockerInitializing: UInt64 = 16
RedirectedIOReasonReFs: UInt64 = 32
RedirectedIOReasonMax: UInt64 = 9223372036854775808
VolumeRedirectedIOReasonNoDiskConnectivity: UInt64 = 1
VolumeRedirectedIOReasonStorageSpaceNotAttached: UInt64 = 2
VolumeRedirectedIOReasonVolumeReplicationEnabled: UInt64 = 4
VolumeRedirectedIOReasonMax: UInt64 = 9223372036854775808
MAX_OBJECTID: UInt32 = 64
MAX_CO_PASSWORD_LENGTH: UInt32 = 16
GUID_PRESENT: UInt32 = 1
CREATEDC_PRESENT: UInt32 = 2
MAX_CO_PASSWORD_LENGTHEX: UInt32 = 127
MAX_CO_PASSWORD_STORAGEEX: UInt32 = 128
MAX_CREATINGDC_LENGTH: UInt32 = 256
DNS_LENGTH: UInt32 = 64
MAINTENANCE_MODE_V2_SIG: UInt32 = 2881155087
NNLEN: UInt32 = 80
CLUS_RESTYPE_NAME_GENAPP: String = 'Generic Application'
CLUS_RESTYPE_NAME_GENSVC: String = 'Generic Service'
CLUS_RESTYPE_NAME_GENSCRIPT: String = 'Generic Script'
CLUS_RESTYPE_NAME_IPADDR: String = 'IP Address'
CLUS_RESTYPE_NAME_NETNAME: String = 'Network Name'
CLUS_RESTYPE_NAME_DNN: String = 'Distributed Network Name'
CLUS_RESTYPE_NAME_FILESHR: String = 'File Share'
CLUS_RESTYPE_NAME_PRTSPLR: String = 'Print Spooler'
CLUS_RESTYPE_NAME_IPV6_NATIVE: String = 'IPv6 Address'
CLUS_RESTYPE_NAME_IPV6_TUNNEL: String = 'IPv6 Tunnel Address'
CLUS_RESTYPE_NAME_VSSTASK: String = 'Volume Shadow Copy Service Task'
CLUS_RESTYPE_NAME_WINS: String = 'WINS Service'
CLUS_RESTYPE_NAME_DHCP: String = 'DHCP Service'
CLUS_RESTYPE_NAME_MSMQ: String = 'Microsoft Message Queue Server'
CLUS_RESTYPE_NAME_NEW_MSMQ: String = 'MSMQ'
CLUS_RESTYPE_NAME_MSMQ_TRIGGER: String = 'MSMQTriggers'
CLUS_RESTYPE_NAME_MSDTC: String = 'Distributed Transaction Coordinator'
CLUS_RESTYPE_NAME_NFS: String = 'NFS Share'
CLUS_RESTYPE_NAME_NETWORK_FILE_SYSTEM: String = 'Network File System'
CLUS_RESTYPE_NAME_ISNS: String = 'Microsoft iSNS'
CLUS_RESTYPE_NAME_HARDDISK: String = 'Physical Disk'
CLUS_RESTYPE_NAME_PHYS_DISK: String = 'Physical Disk'
CLUS_RESTYPE_NAME_FSWITNESS: String = 'File Share Witness'
CLUS_RESTYPE_NAME_FILESERVER: String = 'File Server'
CLUS_RESTYPE_NAME_SODAFILESERVER: String = 'Scale Out File Server'
CLUS_RESTYPE_NAME_DFS: String = 'Distributed File System'
CLUS_RESTYPE_NAME_DFSR: String = 'DFS Replicated Folder'
CLUS_RESTYPE_NAME_VM: String = 'Virtual Machine'
CLUS_RESTYPE_NAME_VM_CONFIG: String = 'Virtual Machine Configuration'
CLUS_RESTYPE_NAME_ISCSITARGET: String = 'iSCSI Target Server'
CLUS_RESTYPE_NAME_STORAGE_POOL: String = 'Storage Pool'
CLUS_RESTYPE_NAME_TASKSCHEDULER: String = 'Task Scheduler'
CLUS_RESTYPE_NAME_VMREPLICA_BROKER: String = 'Virtual Machine Replication Broker'
CLUS_RESTYPE_NAME_VMREPLICA_COORDINATOR: String = 'Virtual Machine Replication Coordinator'
CLUS_RESTYPE_NAME_NFS_V2: String = 'Network File System'
CLUS_RESTYPE_NAME_NFS_MSNS: String = 'NFS Multi Server Namespace'
CLUS_RESTYPE_NAME_CAU: String = 'ClusterAwareUpdatingResource'
CLUS_RESTYPE_NAME_NV_PROVIDER_ADDRESS: String = 'Provider Address'
CLUS_RESTYPE_NAME_NAT: String = 'Nat'
CLUS_RESTYPE_NAME_STORAGE_POLICIES: String = 'Storage Policies'
CLUS_RESTYPE_NAME_STORQOS: String = 'Storage QoS Policy Manager'
CLUS_RESTYPE_NAME_HEALTH_SERVICE: String = 'Health Service'
CLUS_RESTYPE_NAME_VM_WMI: String = 'Virtual Machine Cluster WMI'
CLUS_RESTYPE_NAME_SDDC_MANAGEMENT: String = 'SDDC Management'
CLUS_RESTYPE_NAME_HCSVM: String = 'HCS Virtual Machine'
CLUS_RESTYPE_NAME_VIRTUAL_IPV4: String = 'Disjoint IPv4 Address'
CLUS_RESTYPE_NAME_VIRTUAL_IPV6: String = 'Disjoint IPv6 Address'
CLUS_RESTYPE_NAME_CLOUD_WITNESS: String = 'Cloud Witness'
CLUS_RESTYPE_NAME_STORAGE_REPLICA: String = 'Storage Replica'
CLUS_RESTYPE_NAME_CROSS_CLUSTER: String = 'Cross Cluster Dependency Orchestrator'
CLUS_RESTYPE_NAME_SCALEOUT_MASTER: String = 'Scaleout Master'
CLUS_RESTYPE_NAME_SCALEOUT_WORKER: String = 'Scaleout Worker'
CLUS_RESTYPE_NAME_CONTAINER: String = 'Container'
CLUS_RES_NAME_SCALEOUT_MASTER: String = 'Scaleout Master'
CLUS_RES_NAME_SCALEOUT_WORKER: String = 'Scaleout Worker'
CLUSREG_NAME_CLUS_DESC: String = 'Description'
CLUSREG_NAME_CLUS_SD: String = 'Security Descriptor'
CLUSREG_NAME_CLUS_DEFAULT_NETWORK_ROLE: String = 'DefaultNetworkRole'
CLUSREG_NAME_QUORUM_ARBITRATION_TIMEOUT: String = 'QuorumArbitrationTimeMax'
CLUSTER_HANG_TIMEOUT_KEYNAME: String = 'ClusSvcHangTimeout'
CLUSTER_HANG_RECOVERY_ACTION_KEYNAME: String = 'HangRecoveryAction'
CLUSTER_CSA_VSS_STATE: String = 'BackupInProgress'
CLUSTER_REQUEST_REPLY_TIMEOUT: String = 'RequestReplyTimeout'
CLUSTER_WITNESS_FAILED_RESTART_INTERVAL: String = 'WitnessRestartInterval'
CLUSTER_WITNESS_DATABASE_WRITE_TIMEOUT: String = 'WitnessDatabaseWriteTimeout'
CLUSTER_ADD_EVICT_DELAY: String = 'AddEvictDelay'
CLUSREG_NAME_FIXQUORUM: String = 'FixQuorum'
CLUSREG_NAME_PREVENTQUORUM: String = 'PreventQuorum'
CLUSREG_NAME_IGNORE_PERSISTENT_STATE: String = 'IgnorePersistentStateOnStartup'
CLUSTER_SHARED_VOLUMES_ROOT: String = 'SharedVolumesRoot'
ENABLE_CLUSTER_SHARED_VOLUMES: String = 'EnableSharedVolumes'
CLUSTER_SHARED_VOLUME_VSS_WRITER_OPERATION_TIMEOUT: String = 'SharedVolumeVssWriterOperationTimeout'
USE_CLIENT_ACCESS_NETWORKS_FOR_CSV: String = 'UseClientAccessNetworksForSharedVolumes'
CLUSTER_CSV_COMPATIBLE_FILTERS: String = 'SharedVolumeCompatibleFilters'
CLUSTER_CSV_INCOMPATIBLE_FILTERS: String = 'SharedVolumeIncompatibleFilters'
CLUSTER_GROUP_WAIT_DELAY: String = 'ClusterGroupWaitDelay'
MINIMUM_PREEMPTOR_PRIORITY: String = 'MinimumPreemptorPriority'
MINIMUM_NEVER_PREEMPT_PRIORITY: String = 'MinimumNeverPreemptPriority'
CLUSTER_ENFORCED_ANTIAFFINITY: String = 'ClusterEnforcedAntiaffinity'
CLUSREG_NAME_SHUTDOWN_TIMEOUT_MINUTES: String = 'ShutdownTimeoutInMinutes'
CLUSREG_NAME_CSV_MDS_SD: String = 'SharedVolumeSecurityDescriptor'
CLUSREG_NAME_FAILOVER_MOVE_MIGRATION_TYPE: String = 'FailoverMoveMigrationType'
CLUSREG_NAME_CSV_BLOCK_CACHE: String = 'BlockCacheSize'
CLUSREG_NAME_ROUTE_HISTORY_LENGTH: String = 'RouteHistoryLength'
CLUSREG_NAME_LAST_RECENT_EVENTS_RESET_TIME: String = 'RecentEventsResetTime'
CLUSREG_NAME_DRAIN_ON_SHUTDOWN: String = 'DrainOnShutdown'
CLUSREG_NAME_NETFT_IPSEC_ENABLED: String = 'NetftIPSecEnabled'
CLUSREG_NAME_WITNESS_DYNAMIC_WEIGHT: String = 'WitnessDynamicWeight'
CLUSREG_NAME_MESSAGE_BUFFER_LENGTH: String = 'MessageBufferLength'
CLUSREG_NAME_DATABASE_READ_WRITE_MODE: String = 'DatabaseReadWriteMode'
CLUSREG_NAME_FUNCTIONAL_LEVEL: String = 'ClusterFunctionalLevel'
CLUSREG_NAME_UPGRADE_VERSION: String = 'ClusterUpgradeVersion'
CLUSREG_NAME_RESILIENCY_LEVEL: String = 'ResiliencyLevel'
CLUSREG_NAME_RESILIENCY_DEFAULT_SECONDS: String = 'ResiliencyDefaultPeriod'
CLUSREG_NAME_QUARANTINE_THRESHOLD: String = 'QuarantineThreshold'
CLUSREG_NAME_QUARANTINE_DURATION: String = 'QuarantineDuration'
CLUSTER_S2D_ENABLED: String = 'S2DEnabled'
CLUSTER_S2D_BUS_TYPES: String = 'S2DBusTypes'
CLUSTER_S2D_CACHE_PAGE_SIZE_KBYTES: String = 'S2DCachePageSizeKBytes'
CLUSTER_S2D_OPTIMIZATIONS: String = 'S2DOptimizations'
CLUSTER_S2D_IO_LATENCY_THRESHOLD: String = 'S2DIOLatencyThreshold'
CLUSTER_S2D_CACHE_DESIRED_STATE: String = 'S2DCacheDesiredState'
CLUSTER_S2D_CACHE_METADATA_RESERVE: String = 'S2DCacheMetadataReserveBytes'
CLUSTER_S2D_CACHE_FLASH_RESERVE_PERCENT: String = 'S2DCacheFlashReservePercent'
CLUSTER_S2D_CACHE_BEHAVIOR_FLAGS: String = 'S2DCacheBehavior'
CLUSTER_NAME_PREFERRED_SITE: String = 'PreferredSite'
CLUSTER_NAME_AUTO_BALANCER_MODE: String = 'AutoBalancerMode'
CLUSTER_NAME_AUTO_BALANCER_LEVEL: String = 'AutoBalancerLevel'
CLUSREG_NAME_GROUP_DEPENDENCY_TIMEOUT: String = 'GroupDependencyTimeout'
CLUSREG_NAME_PLACEMENT_OPTIONS: String = 'PlacementOptions'
CLUSREG_NAME_ENABLED_EVENT_LOGS: String = 'EnabledEventLogs'
CLUSREG_NAME_SAME_SUBNET_DELAY: String = 'SameSubnetDelay'
CLUSREG_NAME_CROSS_SUBNET_DELAY: String = 'CrossSubnetDelay'
CLUSREG_NAME_CROSS_SITE_DELAY: String = 'CrossSiteDelay'
CLUSREG_NAME_SAME_SUBNET_THRESHOLD: String = 'SameSubnetThreshold'
CLUSREG_NAME_CROSS_SUBNET_THRESHOLD: String = 'CrossSubnetThreshold'
CLUSREG_NAME_CROSS_SITE_THRESHOLD: String = 'CrossSiteThreshold'
CLUSREG_NAME_PLUMB_ALL_CROSS_SUBNET_ROUTES: String = 'PlumbAllCrossSubnetRoutes'
CLUSREG_NAME_NODE_NAME: String = 'NodeName'
CLUSREG_NAME_NODE_HIGHEST_VERSION: String = 'NodeHighestVersion'
CLUSREG_NAME_NODE_LOWEST_VERSION: String = 'NodeLowestVersion'
CLUSREG_NAME_NODE_DESC: String = 'Description'
CLUSREG_NAME_NODE_MAJOR_VERSION: String = 'MajorVersion'
CLUSREG_NAME_NODE_MINOR_VERSION: String = 'MinorVersion'
CLUSREG_NAME_NODE_BUILD_NUMBER: String = 'BuildNumber'
CLUSREG_NAME_NODE_CSDVERSION: String = 'CSDVersion'
CLUSREG_NAME_NODE_WEIGHT: String = 'NodeWeight'
CLUSREG_NAME_NODE_DYNAMIC_WEIGHT: String = 'DynamicWeight'
CLUSREG_NAME_NODE_IS_PRIMARY: String = 'IsPrimary'
CLUSREG_NAME_NODE_DRAIN_STATUS: String = 'NodeDrainStatus'
CLUSREG_NAME_NODE_DRAIN_TARGET: String = 'NodeDrainTarget'
CLUSREG_NAME_NODE_NEEDS_PQ: String = 'NeedsPreventQuorum'
CLUSREG_NAME_NODE_FDID: String = 'FaultDomainId'
CLUSREG_NAME_NODE_STATUS_INFO: String = 'StatusInformation'
CLUSREG_NAME_NODE_FAULT_DOMAIN: String = 'FaultDomain'
CLUSREG_NAME_NODE_MODEL: String = 'Model'
CLUSREG_NAME_NODE_SERIALNUMBER: String = 'SerialNumber'
CLUSREG_NAME_NODE_MANUFACTURER: String = 'Manufacturer'
CLUSREG_NAME_NODE_UNIQUEID: String = 'UniqueID'
CLUSREG_NAME_GRP_NAME: String = 'Name'
CLUSREG_NAME_GRP_TYPE: String = 'GroupType'
CLUSREG_NAME_GRP_DESC: String = 'Description'
CLUSREG_NAME_GRP_PERSISTENT_STATE: String = 'PersistentState'
CLUSREG_NAME_GRP_FAILBACK_TYPE: String = 'AutoFailbackType'
CLUSREG_NAME_GRP_FAILBACK_WIN_START: String = 'FailbackWindowStart'
CLUSREG_NAME_GRP_FAILBACK_WIN_END: String = 'FailbackWindowEnd'
CLUSREG_NAME_GRP_FAILOVER_THRESHOLD: String = 'FailoverThreshold'
CLUSREG_NAME_GRP_FAILOVER_PERIOD: String = 'FailoverPeriod'
CLUSREG_NAME_GRP_PRIORITY: String = 'Priority'
CLUSREG_NAME_GRP_DEFAULT_OWNER: String = 'DefaultOwner'
CLUSREG_NAME_GRP_STATUS_INFORMATION: String = 'StatusInformation'
CLUSREG_NAME_GRP_ANTI_AFFINITY_CLASS_NAME: String = 'AntiAffinityClassNames'
CLUSREG_NAME_GRP_START_DELAY: String = 'GroupStartDelay'
CLUSREG_NAME_GRP_CCF_EPOCH: String = 'CCFEpoch'
CLUSREG_NAME_GRP_CCF_EPOCH_HIGH: String = 'CCFEpochHigh'
CLUSREG_NAME_GRP_RESILIENCY_PERIOD: String = 'ResiliencyPeriod'
CLUSREG_NAME_GRP_PREFERRED_SITE: String = 'PreferredSite'
CLUSREG_NAME_GRP_COLD_START_SETTING: String = 'ColdStartSetting'
CLUSREG_NAME_GRP_FAULT_DOMAIN: String = 'FaultDomain'
CLUSREG_NAME_GRP_UPDATE_DOMAIN: String = 'UpdateDomain'
CLUSREG_NAME_GRP_PLACEMENT_OPTIONS: String = 'PlacementOptions'
CLUSREG_NAME_GRP_LOCK_MOVE: String = 'LockedFromMoving'
CLUSREG_NAME_RES_NAME: String = 'Name'
CLUSREG_NAME_RES_TYPE: String = 'Type'
CLUSREG_NAME_RES_DESC: String = 'Description'
CLUSREG_NAME_RES_SEPARATE_MONITOR: String = 'SeparateMonitor'
CLUSREG_NAME_RES_PERSISTENT_STATE: String = 'PersistentState'
CLUSREG_NAME_RES_LOOKS_ALIVE: String = 'LooksAlivePollInterval'
CLUSREG_NAME_RES_IS_ALIVE: String = 'IsAlivePollInterval'
CLUSREG_NAME_RES_RESTART_ACTION: String = 'RestartAction'
CLUSREG_NAME_RES_RESTART_THRESHOLD: String = 'RestartThreshold'
CLUSREG_NAME_RES_RESTART_PERIOD: String = 'RestartPeriod'
CLUSREG_NAME_RES_RESTART_DELAY: String = 'RestartDelay'
CLUSREG_NAME_RES_RETRY_PERIOD_ON_FAILURE: String = 'RetryPeriodOnFailure'
CLUSREG_NAME_RES_EMBEDDED_FAILURE_ACTION: String = 'EmbeddedFailureAction'
CLUSREG_NAME_RES_PENDING_TIMEOUT: String = 'PendingTimeout'
CLUSREG_NAME_RES_DEADLOCK_TIMEOUT: String = 'DeadlockTimeout'
CLUSREG_NAME_RES_MONITOR_PID: String = 'MonitorProcessId'
CLUSREG_NAME_RES_STATUS_INFORMATION: String = 'StatusInformation'
CLUSREG_NAME_RES_LAST_OPERATION_STATUS_CODE: String = 'LastOperationStatusCode'
CLUSREG_NAME_RES_DATA1: String = 'ResourceSpecificData1'
CLUSREG_NAME_RES_DATA2: String = 'ResourceSpecificData2'
CLUSREG_NAME_RES_STATUS: String = 'ResourceSpecificStatus'
CLUSREG_NAME_RESTYPE_NAME: String = 'Name'
CLUSREG_NAME_RESTYPE_DESC: String = 'Description'
CLUSREG_NAME_RESTYPE_DLL_NAME: String = 'DllName'
CLUSREG_NAME_RESTYPE_ADMIN_EXTENSIONS: String = 'AdminExtensions'
CLUSREG_NAME_RESTYPE_LOOKS_ALIVE: String = 'LooksAlivePollInterval'
CLUSREG_NAME_RESTYPE_IS_ALIVE: String = 'IsAlivePollInterval'
CLUSREG_NAME_RESTYPE_PENDING_TIMEOUT: String = 'PendingTimeout'
CLUSREG_NAME_RESTYPE_DEADLOCK_TIMEOUT: String = 'DeadlockTimeout'
CLUSREG_NAME_RESTYPE_DUMP_POLICY: String = 'DumpPolicy'
CLUSREG_NAME_RESTYPE_DUMP_LOG_QUERY: String = 'DumpLogQuery'
CLUSREG_NAME_RESTYPE_DUMP_SERVICES: String = 'DumpServices'
CLUSREG_NAME_RESTYPE_ENABLED_EVENT_LOGS: String = 'EnabledEventLogs'
CLUSREG_NAME_RESTYPE_MAX_MONITORS: String = 'MaximumMonitors'
CLUSREG_NAME_RESTYPE_WPR_START_AFTER: String = 'WprStartAfter'
CLUSREG_NAME_RESTYPE_WPR_PROFILES: String = 'WprProfiles'
CLUSREG_NAME_NET_NAME: String = 'Name'
CLUSREG_NAME_NET_IPV6_ADDRESSES: String = 'IPv6Addresses'
CLUSREG_NAME_NET_IPV6_PREFIXLENGTHS: String = 'IPv6PrefixLengths'
CLUSREG_NAME_NET_IPV4_ADDRESSES: String = 'IPv4Addresses'
CLUSREG_NAME_NET_IPV4_PREFIXLENGTHS: String = 'IPv4PrefixLengths'
CLUSREG_NAME_NET_ADDRESS: String = 'Address'
CLUSREG_NAME_NET_ADDRESS_MASK: String = 'AddressMask'
CLUSREG_NAME_NET_DESC: String = 'Description'
CLUSREG_NAME_NET_ROLE: String = 'Role'
CLUSREG_NAME_NET_SPEED: String = 'LinkSpeed'
CLUSREG_NAME_NET_RDMA_CAPABLE: String = 'RdmaCapable'
CLUSREG_NAME_NET_RSS_CAPABLE: String = 'RssCapable'
CLUSREG_NAME_NET_METRIC: String = 'Metric'
CLUSREG_NAME_NET_AUTOMETRIC: String = 'AutoMetric'
CLUSREG_NAME_NETIFACE_NAME: String = 'Name'
CLUSREG_NAME_NETIFACE_NODE: String = 'Node'
CLUSREG_NAME_NETIFACE_NETWORK: String = 'Network'
CLUSREG_NAME_NETIFACE_ADAPTER_NAME: String = 'Adapter'
CLUSREG_NAME_NETIFACE_ADAPTER_ID: String = 'AdapterId'
CLUSREG_NAME_NETIFACE_DHCP_ENABLED: String = 'DhcpEnabled'
CLUSREG_NAME_NETIFACE_IPV6_ADDRESSES: String = 'IPv6Addresses'
CLUSREG_NAME_NETIFACE_IPV4_ADDRESSES: String = 'IPv4Addresses'
CLUSREG_NAME_NETIFACE_ADDRESS: String = 'Address'
CLUSREG_NAME_NETIFACE_DESC: String = 'Description'
CLUSREG_NAME_GROUPSET_NAME: String = 'Name'
CLUSREG_NAME_GROUPSET_STARTUP_SETTING: String = 'StartupSetting'
CLUSREG_NAME_GROUPSET_STARTUP_COUNT: String = 'StartupCount'
CLUSREG_NAME_GROUPSET_STARTUP_DELAY: String = 'StartupDelay'
CLUSREG_NAME_GROUPSET_IS_GLOBAL: String = 'IsGlobal'
CLUSREG_NAME_GROUPSET_STATUS_INFORMATION: String = 'StatusInformation'
CLUSREG_NAME_GROUPSET_IS_AVAILABILITY_SET: String = 'IsAvailabilitySet'
CLUSREG_NAME_GROUPSET_UPDATE_DOMAINS: String = 'UpdateDomains'
CLUSREG_NAME_GROUPSET_FAULT_DOMAINS: String = 'FaultDomains'
CLUSREG_NAME_GROUPSET_RESERVE_NODE: String = 'ReserveSpareNode'
CLUSREG_NAME_GROUPSET_AVAILABILITY_SET_INDEX_TO_NODE_MAPPING: String = 'NodeDomainInfo'
CLUSREG_NAME_AFFINITYRULE_NAME: String = 'Name'
CLUSREG_NAME_AFFINITYRULE_TYPE: String = 'RuleType'
CLUSREG_NAME_AFFINITYRULE_GROUPS: String = 'Groups'
CLUSREG_NAME_AFFINITYRULE_ENABLED: String = 'Enabled'
CLUSREG_NAME_START_MEMORY: String = 'StartMemory'
CLUSREG_NAME_VIRTUAL_NUMA_COUNT: String = 'VirtualNumaCount'
CLUSREG_NAME_DDA_DEVICE_ALLOCATIONS: String = 'DdaDeviceAllocations'
CLUSREG_NAME_GPUP_DEVICE_ALLOCATIONS: String = 'GpupDeviceAllocations'
CLUSREG_NAME_PHYSDISK_DISKIDTYPE: String = 'DiskIdType'
CLUSREG_NAME_PHYSDISK_DISKSIGNATURE: String = 'DiskSignature'
CLUSREG_NAME_PHYSDISK_DISKIDGUID: String = 'DiskIdGuid'
CLUSREG_NAME_PHYSDISK_DISKRUNCHKDSK: String = 'DiskRunChkDsk'
CLUSREG_NAME_PHYSDISK_DISKUNIQUEIDS: String = 'DiskUniqueIds'
CLUSREG_NAME_PHYSDISK_DISKVOLUMEINFO: String = 'DiskVolumeInfo'
CLUSREG_NAME_PHYSDISK_DISKARBTYPE: String = 'DiskArbType'
CLUSREG_NAME_PHYSDISK_DISKARBINTERVAL: String = 'DiskArbInterval'
CLUSREG_NAME_PHYSDISK_DISKPATH: String = 'DiskPath'
CLUSREG_NAME_PHYSDISK_DISKRELOAD: String = 'DiskReload'
CLUSREG_NAME_PHYSDISK_MAINTMODE: String = 'MaintenanceMode'
CLUSREG_NAME_PHYSDISK_DISKIODELAY: String = 'MaxIoLatency'
CLUSREG_NAME_PHYSDISK_MIGRATEFIXUP: String = 'MigrateDriveLetters'
CLUSREG_NAME_PHYSDISK_CSVWRITETHROUGH: String = 'CsvEnforceWriteThrough'
CLUSREG_NAME_PHYSDISK_CSVBLOCKCACHE: String = 'EnableBlockCache'
CLUSREG_NAME_PHYSDISK_FASTONLINEARBITRATE: String = 'FastOnlineArbitrate'
CLUSREG_NAME_PHYSDISK_SPACEIDGUID: String = 'VirtualDiskId'
CLUSREG_NAME_STORAGESPACE_POOLIDGUID: String = 'PoolId'
CLUSREG_NAME_PHYSDISK_CSVSNAPSHOTDIFFAREASIZE: String = 'SnapshotDiffSize'
CLUSREG_NAME_PHYSDISK_CSVSNAPSHOTAGELIMIT: String = 'SnapshotAgeLimit'
CLUSREG_NAME_PHYSDISK_DISKGUID: String = 'DiskGuid'
CLUSREG_NAME_PHYSDISK_VOLSNAPACTIVATETIMEOUT: String = 'VolsnapActivateTimeout'
CLUSREG_NAME_PHYSDISK_DISKRECOVERYACTION: String = 'DiskRecoveryAction'
CLUSREG_NAME_STORAGESPACE_NAME: String = 'VirtualDiskName'
CLUSREG_NAME_STORAGESPACE_DESCRIPTION: String = 'VirtualDiskDescription'
CLUSREG_NAME_STORAGESPACE_HEALTH: String = 'VirtualDiskHealth'
CLUSREG_NAME_STORAGESPACE_STATE: String = 'VirtualDiskState'
CLUSREG_NAME_STORAGESPACE_PROVISIONING: String = 'VirtualDiskProvisioning'
CLUSREG_NAME_STORAGESPACE_RESILIENCYTYPE: String = 'VirtualDiskResiliencyType'
CLUSREG_NAME_STORAGESPACE_RESILIENCYCOLUMNS: String = 'VirtualDiskResiliencyColumns'
CLUSREG_NAME_STORAGESPACE_RESILIENCYINTERLEAVE: String = 'VirtualDiskResiliencyInterleave'
CLUSREG_NAME_GENAPP_COMMAND_LINE: String = 'CommandLine'
CLUSREG_NAME_GENAPP_CURRENT_DIRECTORY: String = 'CurrentDirectory'
CLUSREG_NAME_GENAPP_USE_NETWORK_NAME: String = 'UseNetworkName'
CLUSREG_NAME_GENSCRIPT_SCRIPT_FILEPATH: String = 'ScriptFilepath'
CLUSREG_NAME_GENSVC_SERVICE_NAME: String = 'ServiceName'
CLUSREG_NAME_GENSVC_STARTUP_PARAMS: String = 'StartupParameters'
CLUSREG_NAME_GENSVC_USE_NETWORK_NAME: String = 'UseNetworkName'
CLUSREG_NAME_IPADDR_NETWORK: String = 'Network'
CLUSREG_NAME_IPADDR_ADDRESS: String = 'Address'
CLUSREG_NAME_IPADDR_SUBNET_MASK: String = 'SubnetMask'
CLUSREG_NAME_IPADDR_ENABLE_NETBIOS: String = 'EnableNetBIOS'
CLUSREG_NAME_IPADDR_OVERRIDE_ADDRMATCH: String = 'OverrideAddressMatch'
CLUSREG_NAME_IPADDR_ENABLE_DHCP: String = 'EnableDhcp'
CLUSREG_NAME_IPADDR_LEASE_OBTAINED_TIME: String = 'LeaseObtainedTime'
CLUSREG_NAME_IPADDR_LEASE_TERMINATES_TIME: String = 'LeaseExpiresTime'
CLUSREG_NAME_IPADDR_T1: String = 'T1'
CLUSREG_NAME_IPADDR_T2: String = 'T2'
CLUSREG_NAME_IPADDR_DHCP_SERVER: String = 'DhcpServer'
CLUSREG_NAME_IPADDR_DHCP_ADDRESS: String = 'DhcpAddress'
CLUSREG_NAME_IPADDR_DHCP_SUBNET_MASK: String = 'DhcpSubnetMask'
CLUSREG_NAME_IPADDR_SHARED_NETNAME: String = 'SharedNetname'
CLUSREG_NAME_IPADDR_PROBE_PORT: String = 'ProbePort'
CLUSREG_NAME_IPADDR_PROBE_FAILURE_THRESHOLD: String = 'ProbeFailureThreshold'
CLUSREG_NAME_IPV6_NATIVE_NETWORK: String = 'Network'
CLUSREG_NAME_IPV6_NATIVE_ADDRESS: String = 'Address'
CLUSREG_NAME_IPV6_NATIVE_PREFIX_LENGTH: String = 'PrefixLength'
CLUSREG_NAME_IPV6_TUNNEL_ADDRESS: String = 'Address'
CLUSREG_NAME_IPV6_TUNNEL_TUNNELTYPE: String = 'TunnelType'
CLUSREG_NAME_NETNAME_NAME: String = 'Name'
CLUSREG_NAME_NETNAME_CREATING_DC: String = 'CreatingDC'
CLUSREG_NAME_NETNAME_OBJECT_ID: String = 'ObjectGUID'
CLUSREG_NAME_NETNAME_DNS_NAME: String = 'DnsName'
CLUSREG_NAME_NETNAME_REMAP_PIPE_NAMES: String = 'RemapPipeNames'
CLUSREG_NAME_NETNAME_RESOURCE_DATA: String = 'ResourceData'
CLUSREG_NAME_NETNAME_STATUS_NETBIOS: String = 'StatusNetBIOS'
CLUSREG_NAME_NETNAME_STATUS_DNS: String = 'StatusDNS'
CLUSREG_NAME_NETNAME_STATUS_KERBEROS: String = 'StatusKerberos'
CLUSREG_NAME_NETNAME_VCO_CONTAINER: String = 'VcoContainer'
CLUSREG_NAME_NETNAME_LAST_DNS_UPDATE: String = 'LastDNSUpdateTime'
CLUSREG_NAME_NETNAME_CONTAINERGUID: String = 'CryptoContainerGUID'
CLUSREG_NAME_NETNAME_HOST_TTL: String = 'HostRecordTTL'
CLUSREG_NAME_NETNAME_PUBLISH_PTR: String = 'PublishPTRRecords'
CLUSREG_NAME_NETNAME_REMOVEVCO_ONDELETE: String = 'DeleteVcoOnResCleanup'
CLUSREG_NAME_NETNAME_REGISTER_ALL_IP: String = 'RegisterAllProvidersIP'
CLUSREG_KEYNAME_OBJECTGUIDS: String = 'ObjectGUIDs'
CLUSREG_NAME_NETNAME_EXCLUDE_NETWORKS: String = 'ExcludeNetworks'
CLUSREG_NAME_NETNAME_ALIASES: String = 'Aliases'
CLUSREG_NAME_NETNAME_IN_USE_NETWORKS: String = 'InUseNetworks'
CLUSREG_NAME_NETNAME_DNS_SUFFIX: String = 'DnsSuffix'
CLUSREG_NAME_NETNAME_AD_AWARE: String = 'ADAware'
CLUSREG_NAME_NETNAME_DNN_DISABLE_CLONES: String = 'DisableClones'
CLUSREG_NAME_PRTSPOOL_DEFAULT_SPOOL_DIR: String = 'DefaultSpoolDirectory'
CLUSREG_NAME_PRTSPOOL_TIMEOUT: String = 'JobCompletionTimeout'
CLUSREG_NAME_FILESHR_SERVER_NAME: String = 'ServerName'
CLUSREG_NAME_FILESHR_SHARE_NAME: String = 'ShareName'
CLUSREG_NAME_FILESHR_PATH: String = 'Path'
CLUSREG_NAME_FILESHR_REMARK: String = 'Remark'
CLUSREG_NAME_FILESHR_MAX_USERS: String = 'MaxUsers'
CLUSREG_NAME_FILESHR_SD: String = 'Security Descriptor'
CLUSREG_NAME_FILESHR_SHARE_SUBDIRS: String = 'ShareSubDirs'
CLUSREG_NAME_FILESHR_HIDE_SUBDIR_SHARES: String = 'HideSubDirShares'
CLUSREG_NAME_FILESHR_IS_DFS_ROOT: String = 'IsDfsRoot'
CLUSREG_NAME_FILESHR_SHARE_FLAGS: String = 'ShareFlags'
CLUSREG_NAME_FILESHR_CA_TIMEOUT: String = 'CATimeout'
CLUSREG_NAME_FILESHR_QOS_FLOWSCOPE: String = 'QosFlowScope'
CLUSREG_NAME_FILESHR_QOS_POLICYID: String = 'QosPolicyId'
CLUSREG_NAME_DHCP_DATABASE_PATH: String = 'DatabasePath'
CLUSREG_NAME_DHCP_BACKUP_PATH: String = 'BackupPath'
CLUSREG_NAME_LOG_FILE_PATH: String = 'LogFilePath'
CLUSREG_NAME_WINS_DATABASE_PATH: String = 'DatabasePath'
CLUSREG_NAME_WINS_BACKUP_PATH: String = 'BackupPath'
CLUSREG_NAME_VSSTASK_CURRENTDIRECTORY: String = 'CurrentDirectory'
CLUSREG_NAME_VSSTASK_APPNAME: String = 'ApplicationName'
CLUSREG_NAME_VSSTASK_APPPARAMS: String = 'ApplicationParams'
CLUSREG_NAME_VSSTASK_TRIGGERARRAY: String = 'TriggerArray'
CLUSREG_NAME_FSWITNESS_SHARE_PATH: String = 'SharePath'
CLUSREG_NAME_FSWITNESS_ARB_DELAY: String = 'ArbitrationDelay'
CLUSREG_NAME_FSWITNESS_IMPERSONATE_CNO: String = 'ImpersonateCNO'
CLUSREG_NAME_STORAGESPACE_POOLNAME: String = 'Name'
CLUSREG_NAME_STORAGESPACE_POOLDESC: String = 'Description'
CLUSREG_NAME_STORAGESPACE_POOLDRIVEIDS: String = 'DriveIds'
CLUSREG_NAME_STORAGESPACE_POOLHEALTH: String = 'Health'
CLUSREG_NAME_STORAGESPACE_POOLSTATE: String = 'State'
CLUSREG_NAME_STORAGESPACE_POOLTOTALCAPACITY: String = 'TotalCapacity'
CLUSREG_NAME_STORAGESPACE_POOLCONSUMEDCAPACITY: String = 'ConsumedCapacity'
CLUSREG_NAME_STORAGESPACE_POOLARBITRATE: String = 'Arbitrate'
CLUSREG_NAME_STORAGESPACE_POOLREEVALTIMEOUT: String = 'ReEvaluatePlacementTimeout'
CLUSREG_NAME_STORAGESPACE_POOLQUORUMSHARE: String = 'PoolQuorumShare'
CLUSREG_NAME_STORAGESPACE_POOLQUORUMUSERACCOUNT: String = 'PoolQuorumUserAccount'
CLUSREG_NAME_SOFS_SMBASYMMETRYMODE: String = 'SmbAsymmetryMode'
CLUSREG_NAME_VIP_PREFIX_LENGTH: String = 'PrefixLength'
CLUSREG_NAME_VIP_ADAPTER_NAME: String = 'AdapterName'
CLUSREG_NAME_VIP_ADDRESS: String = 'Address'
CLUSREG_NAME_VIP_VSID: String = 'VSID'
CLUSREG_NAME_VIP_RDID: String = 'RDID'
CLUSREG_NAME_CLOUDWITNESS_PRIMARY_TOKEN: String = 'PrimaryToken'
CLUSREG_NAME_CLOUDWITNESS_PRIMARY_KEY: String = 'PrimaryKey'
CLUSREG_NAME_CLOUDWITNESS_ACCOUNT_NAME: String = 'AccountName'
CLUSREG_NAME_CLOUDWITNESS_ENDPOINT_INFO: String = 'EndpointInfo'
CLUSREG_NAME_CLOUDWITNESS_CONTAINER_NAME: String = 'ContainerName'
CLOUD_WITNESS_CONTAINER_NAME: String = 'msft-cloud-witness'
CLUS_NAME_RES_TYPE_SOURCE_RESID: String = 'SourceResourceId'
CLUS_NAME_RES_TYPE_TARGET_RESID: String = 'TargetResourceId'
CLUS_NAME_RES_TYPE_SOURCE_VOLUMES: String = 'SourceVolumes'
CLUS_NAME_RES_TYPE_TARGET_VOLUMES: String = 'TargetVolumes'
CLUS_NAME_RES_TYPE_DATA_RESID: String = 'DataResourceId'
CLUS_NAME_RES_TYPE_LOG_RESID: String = 'LogResourceId'
CLUS_NAME_RES_TYPE_LOG_VOLUME: String = 'LogVolume'
CLUS_NAME_RES_TYPE_REPLICATION_GROUPID: String = 'ReplicationGroupId'
CLUS_NAME_RES_TYPE_CLUSTER_GROUPID: String = 'ClusterGroupId'
CLUS_NAME_RES_TYPE_REPLICATION_GROUP_TYPE: String = 'ReplicationClusterGroupType'
CLUS_NAME_RES_TYPE_MINIMUM_LOG_SIZE: String = 'MinimumLogSizeInBytes'
CLUS_NAME_RES_TYPE_UNIT_LOG_SIZE_CHANGE: String = 'UnitOfLogSizeChangeInBytes'
CLUS_NAME_RES_TYPE_LOG_MULTIPLE: String = 'LogSizeMultiple'
SR_REPLICATED_PARTITION_DISALLOW_MULTINODE_IO: UInt32 = 1
CLUSCTL_RESOURCE_TYPE_STORAGE_GET_AVAILABLE_DISKS_EX2_FLAG_ADD_VOLUME_INFO: UInt32 = 1
CLUSCTL_RESOURCE_TYPE_STORAGE_GET_AVAILABLE_DISKS_EX2_FLAG_FILTER_BY_POOL: UInt32 = 2
CLUSCTL_RESOURCE_TYPE_STORAGE_GET_AVAILABLE_DISKS_EX2_FLAG_INCLUDE_NON_SHARED_DISKS: UInt32 = 4
STARTUP_ROUTINE: String = 'Startup'
CLRES_VERSION_V1_00: UInt32 = 256
STARTUP_EX_ROUTINE: String = 'StartupEx'
CLRES_VERSION_V2_00: UInt32 = 512
CLRES_VERSION_V3_00: UInt32 = 768
CLRES_VERSION_V4_00: UInt32 = 1024
CLUSCTL_GET_OPERATION_CONTEXT_PARAMS_VERSION_1: UInt32 = 1
CLUSRES_NAME_GET_OPERATION_CONTEXT_FLAGS: String = 'Flags'
CLUSRESDLL_STATUS_OFFLINE_BUSY: UInt32 = 1
CLUSRESDLL_STATUS_OFFLINE_SOURCE_THROTTLED: UInt32 = 2
CLUSRESDLL_STATUS_OFFLINE_DESTINATION_THROTTLED: UInt32 = 4
CLUSRESDLL_STATUS_OFFLINE_DESTINATION_REJECTED: UInt32 = 8
CLUSRESDLL_STATUS_INSUFFICIENT_MEMORY: UInt32 = 16
CLUSRESDLL_STATUS_INSUFFICIENT_PROCESSOR: UInt32 = 32
CLUSRESDLL_STATUS_INSUFFICIENT_OTHER_RESOURCES: UInt32 = 64
CLUSRESDLL_STATUS_INVALID_PARAMETERS: UInt32 = 128
CLUSRESDLL_STATUS_NETWORK_NOT_AVAILABLE: UInt32 = 256
CLUSRESDLL_STATUS_DO_NOT_COLLECT_WER_REPORT: UInt32 = 1073741824
CLUSRESDLL_STATUS_DUMP_NOW: UInt32 = 2147483648
CLUS_RESDLL_OPEN_RECOVER_MONITOR_STATE: UInt32 = 1
CLUS_RESDLL_ONLINE_RECOVER_MONITOR_STATE: UInt32 = 1
CLUS_RESDLL_ONLINE_IGNORE_RESOURCE_STATUS: UInt32 = 2
CLUS_RESDLL_ONLINE_RETURN_TO_SOURCE_NODE_ON_ERROR: UInt32 = 4
CLUS_RESDLL_ONLINE_RESTORE_ONLINE_STATE: UInt32 = 8
CLUS_RESDLL_ONLINE_IGNORE_NETWORK_CONNECTIVITY: UInt32 = 16
CLUS_RESDLL_OFFLINE_IGNORE_RESOURCE_STATUS: UInt32 = 1
CLUS_RESDLL_OFFLINE_RETURN_TO_SOURCE_NODE_ON_ERROR: UInt32 = 2
CLUS_RESDLL_OFFLINE_QUEUE_ENABLED: UInt32 = 4
CLUS_RESDLL_OFFLINE_RETURNING_TO_SOURCE_NODE_BECAUSE_OF_ERROR: UInt32 = 8
CLUS_RESDLL_OFFLINE_DUE_TO_EMBEDDED_FAILURE: UInt32 = 16
CLUS_RESDLL_OFFLINE_IGNORE_NETWORK_CONNECTIVITY: UInt32 = 32
CLUS_RESDLL_OFFLINE_DO_NOT_UPDATE_PERSISTENT_STATE: UInt32 = 64
CLUS_RESDLL_OPEN_DONT_DELETE_TEMP_DISK: UInt32 = 2
RESTYPE_MONITOR_SHUTTING_DOWN_NODE_STOP: UInt32 = 1
RESTYPE_MONITOR_SHUTTING_DOWN_CLUSSVC_CRASH: UInt32 = 2
RESUTIL_PROPITEM_READ_ONLY: UInt32 = 1
RESUTIL_PROPITEM_REQUIRED: UInt32 = 2
RESUTIL_PROPITEM_SIGNED: UInt32 = 4
RESUTIL_PROPITEM_IN_MEMORY: UInt32 = 8
LOCKED_MODE_FLAGS_DONT_REMOVE_FROM_MOVE_QUEUE: UInt32 = 1
CLUSRES_DISABLE_WPR_WATCHDOG_FOR_ONLINE_CALLS: UInt32 = 1
CLUSRES_DISABLE_WPR_WATCHDOG_FOR_OFFLINE_CALLS: UInt32 = 2
CLUSTER_HEALTH_FAULT_PROPERTY_NAME: String = 'ClusterHealth'
CLUSTER_HEALTH_FAULT_ARGS: UInt32 = 7
CLUSTER_HEALTH_FAULT_ID: UInt32 = 0
CLUSTER_HEALTH_FAULT_ERRORTYPE: UInt32 = 1
CLUSTER_HEALTH_FAULT_ERRORCODE: UInt32 = 2
CLUSTER_HEALTH_FAULT_DESCRIPTION: UInt32 = 3
CLUSTER_HEALTH_FAULT_PROVIDER: UInt32 = 4
CLUSTER_HEALTH_FAULT_FLAGS: UInt32 = 5
CLUSTER_HEALTH_FAULT_RESERVED: UInt32 = 6
CLUSTER_HEALTH_FAULT_ID_LABEL: String = 'Id'
CLUSTER_HEALTH_FAULT_ERRORTYPE_LABEL: String = 'ErrorType'
CLUSTER_HEALTH_FAULT_ERRORCODE_LABEL: String = 'ErrorCode'
CLUSTER_HEALTH_FAULT_DESCRIPTION_LABEL: String = 'Description'
CLUSTER_HEALTH_FAULT_PROVIDER_LABEL: String = 'Provider'
CLUSTER_HEALTH_FAULT_FLAGS_LABEL: String = 'Flags'
CLUSTER_HEALTH_FAULT_RESERVED_LABEL: String = 'Reserved'
CLUS_CREATE_CRYPT_CONTAINER_NOT_FOUND: UInt32 = 1
SET_APPINSTANCE_CSV_FLAGS_VALID_ONLY_IF_CSV_COORDINATOR: UInt32 = 1
@winfunctype('CLUSAPI.dll')
def ClusapiSetReasonHandler(lpHandler: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSAPI_REASON_HANDLER)) -> POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSAPI_REASON_HANDLER): ...
@winfunctype('CLUSAPI.dll')
def GetNodeClusterState(lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR, pdwClusterState: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def OpenCluster(lpszClusterName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype('CLUSAPI.dll')
def OpenClusterEx(lpszClusterName: win32more.Windows.Win32.Foundation.PWSTR, DesiredAccess: UInt32, GrantedAccess: POINTER(UInt32)) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype('CLUSAPI.dll')
def CloseCluster(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('CLUSAPI.dll')
def SetClusterName(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNewClusterName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def SetClusterNameEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNewClusterName: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def GetClusterInformation(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszClusterName: win32more.Windows.Win32.Foundation.PWSTR, lpcchClusterName: POINTER(UInt32), lpClusterInfo: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTERVERSIONINFO)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def GetClusterQuorumResource(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR, lpcchResourceName: POINTER(UInt32), lpszDeviceName: win32more.Windows.Win32.Foundation.PWSTR, lpcchDeviceName: POINTER(UInt32), lpdwMaxQuorumLogSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def SetClusterQuorumResource(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszDeviceName: win32more.Windows.Win32.Foundation.PWSTR, dwMaxQuoLogSize: UInt32) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def SetClusterQuorumResourceEx(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszDeviceName: win32more.Windows.Win32.Foundation.PWSTR, dwMaxQuorumLogSize: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def BackupClusterDatabase(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszPathName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def RestoreClusterDatabase(lpszPathName: win32more.Windows.Win32.Foundation.PWSTR, bForce: win32more.Windows.Win32.Foundation.BOOL, lpszQuorumDriveLetter: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def SetClusterNetworkPriorityOrder(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, NetworkCount: UInt32, NetworkList: POINTER(win32more.Windows.Win32.Networking.Clustering.HNETWORK)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def SetClusterServiceAccountPassword(lpszClusterName: win32more.Windows.Win32.Foundation.PWSTR, lpszNewPassword: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, lpReturnStatusBuffer: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_SET_PASSWORD_STATUS), lpcbReturnStatusBufferSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterControl(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterControlEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterUpgradeFunctionalLevel(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, perform: win32more.Windows.Win32.Foundation.BOOL, pfnProgressCallback: win32more.Windows.Win32.Networking.Clustering.PCLUSTER_UPGRADE_PROGRESS_CALLBACK, pvCallbackArg: VoidPtr) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def CreateClusterNotifyPortV2(hChange: win32more.Windows.Win32.Networking.Clustering.HCHANGE, hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, Filters: POINTER(win32more.Windows.Win32.Networking.Clustering.NOTIFY_FILTER_AND_TYPE), dwFilterCount: UInt32, dwNotifyKey: UIntPtr) -> win32more.Windows.Win32.Networking.Clustering.HCHANGE: ...
@winfunctype('CLUSAPI.dll')
def RegisterClusterNotifyV2(hChange: win32more.Windows.Win32.Networking.Clustering.HCHANGE, Filter: win32more.Windows.Win32.Networking.Clustering.NOTIFY_FILTER_AND_TYPE, hObject: win32more.Windows.Win32.Foundation.HANDLE, dwNotifyKey: UIntPtr) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def GetNotifyEventHandle(hChange: win32more.Windows.Win32.Networking.Clustering.HCHANGE, lphTargetEvent: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def GetClusterNotifyV2(hChange: win32more.Windows.Win32.Networking.Clustering.HCHANGE, lpdwNotifyKey: POINTER(UIntPtr), pFilterAndType: POINTER(win32more.Windows.Win32.Networking.Clustering.NOTIFY_FILTER_AND_TYPE), buffer: POINTER(Byte), lpbBufferSize: POINTER(UInt32), lpszObjectId: win32more.Windows.Win32.Foundation.PWSTR, lpcchObjectId: POINTER(UInt32), lpszParentId: win32more.Windows.Win32.Foundation.PWSTR, lpcchParentId: POINTER(UInt32), lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32), lpszType: win32more.Windows.Win32.Foundation.PWSTR, lpcchType: POINTER(UInt32), dwMilliseconds: UInt32) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def CreateClusterNotifyPort(hChange: win32more.Windows.Win32.Networking.Clustering.HCHANGE, hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, dwFilter: UInt32, dwNotifyKey: UIntPtr) -> win32more.Windows.Win32.Networking.Clustering.HCHANGE: ...
@winfunctype('CLUSAPI.dll')
def RegisterClusterNotify(hChange: win32more.Windows.Win32.Networking.Clustering.HCHANGE, dwFilterType: UInt32, hObject: win32more.Windows.Win32.Foundation.HANDLE, dwNotifyKey: UIntPtr) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def GetClusterNotify(hChange: win32more.Windows.Win32.Networking.Clustering.HCHANGE, lpdwNotifyKey: POINTER(UIntPtr), lpdwFilterType: POINTER(UInt32), lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32), dwMilliseconds: UInt32) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def CloseClusterNotifyPort(hChange: win32more.Windows.Win32.Networking.Clustering.HCHANGE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('CLUSAPI.dll')
def ClusterOpenEnum(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, dwType: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HCLUSENUM: ...
@winfunctype('CLUSAPI.dll')
def ClusterGetEnumCount(hEnum: win32more.Windows.Win32.Networking.Clustering.HCLUSENUM) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterEnum(hEnum: win32more.Windows.Win32.Networking.Clustering.HCLUSENUM, dwIndex: UInt32, lpdwType: POINTER(UInt32), lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterCloseEnum(hEnum: win32more.Windows.Win32.Networking.Clustering.HCLUSENUM) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterOpenEnumEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, dwType: UInt32, pOptions: VoidPtr) -> win32more.Windows.Win32.Networking.Clustering.HCLUSENUMEX: ...
@winfunctype('CLUSAPI.dll')
def ClusterGetEnumCountEx(hClusterEnum: win32more.Windows.Win32.Networking.Clustering.HCLUSENUMEX) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterEnumEx(hClusterEnum: win32more.Windows.Win32.Networking.Clustering.HCLUSENUMEX, dwIndex: UInt32, pItem: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_ENUM_ITEM), cbItem: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterCloseEnumEx(hClusterEnum: win32more.Windows.Win32.Networking.Clustering.HCLUSENUMEX) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def CreateClusterGroupSet(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, groupSetName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HGROUPSET: ...
@winfunctype('CLUSAPI.dll')
def OpenClusterGroupSet(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszGroupSetName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HGROUPSET: ...
@winfunctype('CLUSAPI.dll')
def CloseClusterGroupSet(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('CLUSAPI.dll')
def DeleteClusterGroupSet(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def DeleteClusterGroupSetEx(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterAddGroupToGroupSet(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterAddGroupToGroupSetWithDomains(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, faultDomain: UInt32, updateDomain: UInt32) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterAddGroupToGroupSetWithDomainsEx(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, faultDomain: UInt32, updateDomain: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRemoveGroupFromGroupSet(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRemoveGroupFromGroupSetEx(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterGroupSetControl(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, cbInBufferSize: UInt32, lpOutBuffer: VoidPtr, cbOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterGroupSetControlEx(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, cbInBufferSize: UInt32, lpOutBuffer: VoidPtr, cbOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def AddClusterGroupDependency(hDependentGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hProviderGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def AddClusterGroupDependencyEx(hDependentGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hProviderGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def SetGroupDependencyExpression(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszDependencyExpression: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def SetGroupDependencyExpressionEx(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszDependencyExpression: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def RemoveClusterGroupDependency(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def RemoveClusterGroupDependencyEx(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def AddClusterGroupSetDependency(hDependentGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, hProviderGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def AddClusterGroupSetDependencyEx(hDependentGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, hProviderGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def SetClusterGroupSetDependencyExpression(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpszDependencyExprssion: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def SetClusterGroupSetDependencyExpressionEx(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpszDependencyExpression: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def RemoveClusterGroupSetDependency(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HGROUPSET) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def RemoveClusterGroupSetDependencyEx(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def AddClusterGroupToGroupSetDependency(hDependentGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hProviderGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def AddClusterGroupToGroupSetDependencyEx(hDependentGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hProviderGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def RemoveClusterGroupToGroupSetDependency(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HGROUPSET) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def RemoveClusterGroupToGroupSetDependencyEx(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterGroupSetOpenEnum(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER) -> win32more.Windows.Win32.Networking.Clustering.HGROUPSETENUM: ...
@winfunctype('CLUSAPI.dll')
def ClusterGroupSetGetEnumCount(hGroupSetEnum: win32more.Windows.Win32.Networking.Clustering.HGROUPSETENUM) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterGroupSetEnum(hGroupSetEnum: win32more.Windows.Win32.Networking.Clustering.HGROUPSETENUM, dwIndex: UInt32, lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterGroupSetCloseEnum(hGroupSetEnum: win32more.Windows.Win32.Networking.Clustering.HGROUPSETENUM) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def AddCrossClusterGroupSetDependency(hDependentGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpRemoteClusterName: win32more.Windows.Win32.Foundation.PWSTR, lpRemoteGroupSetName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def RemoveCrossClusterGroupSetDependency(hDependentGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpRemoteClusterName: win32more.Windows.Win32.Foundation.PWSTR, lpRemoteGroupSetName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def CreateClusterAvailabilitySet(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpAvailabilitySetName: win32more.Windows.Win32.Foundation.PWSTR, pAvailabilitySetConfig: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_AVAILABILITY_SET_CONFIG)) -> win32more.Windows.Win32.Networking.Clustering.HGROUPSET: ...
@winfunctype('CLUSAPI.dll')
def ClusterNodeReplacement(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNodeNameCurrent: win32more.Windows.Win32.Foundation.PWSTR, lpszNodeNameNew: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterCreateAffinityRule(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, ruleName: win32more.Windows.Win32.Foundation.PWSTR, ruleType: win32more.Windows.Win32.Networking.Clustering.CLUS_AFFINITY_RULE_TYPE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRemoveAffinityRule(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, ruleName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterAddGroupToAffinityRule(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, ruleName: win32more.Windows.Win32.Foundation.PWSTR, hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRemoveGroupFromAffinityRule(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, ruleName: win32more.Windows.Win32.Foundation.PWSTR, hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterAffinityRuleControl(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, affinityRuleName: win32more.Windows.Win32.Foundation.PWSTR, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, cbInBufferSize: UInt32, lpOutBuffer: VoidPtr, cbOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def OpenClusterNode(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HNODE: ...
@winfunctype('CLUSAPI.dll')
def OpenClusterNodeEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32, lpdwGrantedAccess: POINTER(UInt32)) -> win32more.Windows.Win32.Networking.Clustering.HNODE: ...
@winfunctype('CLUSAPI.dll')
def OpenClusterNodeById(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, nodeId: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HNODE: ...
@winfunctype('CLUSAPI.dll')
def CloseClusterNode(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('CLUSAPI.dll')
def GetClusterNodeState(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_STATE: ...
@winfunctype('CLUSAPI.dll')
def GetClusterNodeId(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, lpszNodeId: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def GetClusterFromNode(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype('CLUSAPI.dll')
def PauseClusterNode(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ResumeClusterNode(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def EvictClusterNode(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterNetInterfaceOpenEnum(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR, lpszNetworkName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HNETINTERFACEENUM: ...
@winfunctype('CLUSAPI.dll')
def ClusterNetInterfaceEnum(hNetInterfaceEnum: win32more.Windows.Win32.Networking.Clustering.HNETINTERFACEENUM, dwIndex: UInt32, lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterNetInterfaceCloseEnum(hNetInterfaceEnum: win32more.Windows.Win32.Networking.Clustering.HNETINTERFACEENUM) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterNodeOpenEnum(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwType: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HNODEENUM: ...
@winfunctype('CLUSAPI.dll')
def ClusterNodeOpenEnumEx(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwType: UInt32, pOptions: VoidPtr) -> win32more.Windows.Win32.Networking.Clustering.HNODEENUMEX: ...
@winfunctype('CLUSAPI.dll')
def ClusterNodeGetEnumCountEx(hNodeEnum: win32more.Windows.Win32.Networking.Clustering.HNODEENUMEX) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterNodeEnumEx(hNodeEnum: win32more.Windows.Win32.Networking.Clustering.HNODEENUMEX, dwIndex: UInt32, pItem: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_ENUM_ITEM), cbItem: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterNodeCloseEnumEx(hNodeEnum: win32more.Windows.Win32.Networking.Clustering.HNODEENUMEX) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterNodeGetEnumCount(hNodeEnum: win32more.Windows.Win32.Networking.Clustering.HNODEENUM) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterNodeCloseEnum(hNodeEnum: win32more.Windows.Win32.Networking.Clustering.HNODEENUM) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterNodeEnum(hNodeEnum: win32more.Windows.Win32.Networking.Clustering.HNODEENUM, dwIndex: UInt32, lpdwType: POINTER(UInt32), lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def EvictClusterNodeEx(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwTimeOut: UInt32, phrCleanupStatus: POINTER(win32more.Windows.Win32.Foundation.HRESULT)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def EvictClusterNodeEx2(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwTimeout: UInt32, phrCleanupStatus: POINTER(win32more.Windows.Win32.Foundation.HRESULT), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def GetClusterResourceTypeKey(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszTypeName: win32more.Windows.Win32.Foundation.PWSTR, samDesired: UInt32) -> win32more.Windows.Win32.System.Registry.HKEY: ...
@winfunctype('CLUSAPI.dll')
def CreateClusterGroup(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszGroupName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HGROUP: ...
@winfunctype('CLUSAPI.dll')
def OpenClusterGroup(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszGroupName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HGROUP: ...
@winfunctype('CLUSAPI.dll')
def OpenClusterGroupEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszGroupName: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32, lpdwGrantedAccess: POINTER(UInt32)) -> win32more.Windows.Win32.Networking.Clustering.HGROUP: ...
@winfunctype('CLUSAPI.dll')
def PauseClusterNodeEx(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, bDrainNode: win32more.Windows.Win32.Foundation.BOOL, dwPauseFlags: UInt32, hNodeDrainTarget: win32more.Windows.Win32.Networking.Clustering.HNODE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def PauseClusterNodeEx2(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, bDrainNode: win32more.Windows.Win32.Foundation.BOOL, dwPauseFlags: UInt32, hNodeDrainTarget: win32more.Windows.Win32.Networking.Clustering.HNODE, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ResumeClusterNodeEx(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, eResumeFailbackType: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_RESUME_FAILBACK_TYPE, dwResumeFlagsReserved: UInt32) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ResumeClusterNodeEx2(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, eResumeFailbackType: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_RESUME_FAILBACK_TYPE, dwResumeFlagsReserved: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def CreateClusterGroupEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszGroupName: win32more.Windows.Win32.Foundation.PWSTR, pGroupInfo: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_CREATE_GROUP_INFO)) -> win32more.Windows.Win32.Networking.Clustering.HGROUP: ...
@winfunctype('CLUSAPI.dll')
def ClusterGroupOpenEnumEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszProperties: win32more.Windows.Win32.Foundation.PWSTR, cbProperties: UInt32, lpszRoProperties: win32more.Windows.Win32.Foundation.PWSTR, cbRoProperties: UInt32, dwFlags: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HGROUPENUMEX: ...
@winfunctype('CLUSAPI.dll')
def ClusterGroupGetEnumCountEx(hGroupEnumEx: win32more.Windows.Win32.Networking.Clustering.HGROUPENUMEX) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterGroupEnumEx(hGroupEnumEx: win32more.Windows.Win32.Networking.Clustering.HGROUPENUMEX, dwIndex: UInt32, pItem: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_ENUM_ITEM), cbItem: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterGroupCloseEnumEx(hGroupEnumEx: win32more.Windows.Win32.Networking.Clustering.HGROUPENUMEX) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceOpenEnumEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszProperties: win32more.Windows.Win32.Foundation.PWSTR, cbProperties: UInt32, lpszRoProperties: win32more.Windows.Win32.Foundation.PWSTR, cbRoProperties: UInt32, dwFlags: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HRESENUMEX: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceGetEnumCountEx(hResourceEnumEx: win32more.Windows.Win32.Networking.Clustering.HRESENUMEX) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceEnumEx(hResourceEnumEx: win32more.Windows.Win32.Networking.Clustering.HRESENUMEX, dwIndex: UInt32, pItem: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_ENUM_ITEM), cbItem: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceCloseEnumEx(hResourceEnumEx: win32more.Windows.Win32.Networking.Clustering.HRESENUMEX) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def OnlineClusterGroupEx(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hDestinationNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwOnlineFlags: UInt32, lpInBuffer: POINTER(Byte), cbInBufferSize: UInt32) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def OfflineClusterGroupEx(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, dwOfflineFlags: UInt32, lpInBuffer: POINTER(Byte), cbInBufferSize: UInt32) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def OnlineClusterGroupEx2(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hDestinationNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwOnlineFlags: UInt32, lpInBuffer: POINTER(Byte), cbInBufferSize: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def OfflineClusterGroupEx2(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, dwOfflineFlags: UInt32, lpInBuffer: POINTER(Byte), cbInBufferSize: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def OnlineClusterResourceEx(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, dwOnlineFlags: UInt32, lpInBuffer: POINTER(Byte), cbInBufferSize: UInt32) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def OnlineClusterResourceEx2(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, dwOnlineFlags: UInt32, lpInBuffer: POINTER(Byte), cbInBufferSize: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def OfflineClusterResourceEx(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, dwOfflineFlags: UInt32, lpInBuffer: POINTER(Byte), cbInBufferSize: UInt32) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def OfflineClusterResourceEx2(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, dwOfflineFlags: UInt32, lpInBuffer: POINTER(Byte), cbInBufferSize: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def MoveClusterGroupEx(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hDestinationNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwMoveFlags: UInt32, lpInBuffer: POINTER(Byte), cbInBufferSize: UInt32) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def MoveClusterGroupEx2(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hDestinationNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwMoveFlags: UInt32, lpInBuffer: POINTER(Byte), cbInBufferSize: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def CancelClusterGroupOperation(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, dwCancelFlags_RESERVED: UInt32) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def RestartClusterResource(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, dwFlags: UInt32) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def RestartClusterResourceEx(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, dwFlags: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def CloseClusterGroup(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('CLUSAPI.dll')
def GetClusterFromGroup(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype('CLUSAPI.dll')
def GetClusterGroupState(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR, lpcchNodeName: POINTER(UInt32)) -> win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_STATE: ...
@winfunctype('CLUSAPI.dll')
def SetClusterGroupName(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszGroupName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def SetClusterGroupNodeList(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, NodeCount: UInt32, NodeList: POINTER(win32more.Windows.Win32.Networking.Clustering.HNODE)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def SetClusterGroupNameEx(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszGroupName: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def SetClusterGroupNodeListEx(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, NodeCount: UInt32, NodeList: POINTER(win32more.Windows.Win32.Networking.Clustering.HNODE), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def OnlineClusterGroup(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hDestinationNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def MoveClusterGroup(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hDestinationNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def OfflineClusterGroup(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def DeleteClusterGroup(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def DestroyClusterGroup(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def DeleteClusterGroupEx(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def DestroyClusterGroupEx(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterGroupOpenEnum(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, dwType: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HGROUPENUM: ...
@winfunctype('CLUSAPI.dll')
def ClusterGroupGetEnumCount(hGroupEnum: win32more.Windows.Win32.Networking.Clustering.HGROUPENUM) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterGroupEnum(hGroupEnum: win32more.Windows.Win32.Networking.Clustering.HGROUPENUM, dwIndex: UInt32, lpdwType: POINTER(UInt32), lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterGroupCloseEnum(hGroupEnum: win32more.Windows.Win32.Networking.Clustering.HGROUPENUM) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def CreateClusterResource(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR, lpszResourceType: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype('CLUSAPI.dll')
def CreateClusterResourceEx(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR, lpszResourceType: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype('CLUSAPI.dll')
def OpenClusterResource(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype('CLUSAPI.dll')
def OpenClusterResourceEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32, lpdwGrantedAccess: POINTER(UInt32)) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype('CLUSAPI.dll')
def CloseClusterResource(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('CLUSAPI.dll')
def GetClusterFromResource(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype('CLUSAPI.dll')
def DeleteClusterResource(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def DeleteClusterResourceEx(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def GetClusterResourceState(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR, lpcchNodeName: POINTER(UInt32), lpszGroupName: win32more.Windows.Win32.Foundation.PWSTR, lpcchGroupName: POINTER(UInt32)) -> win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE: ...
@winfunctype('CLUSAPI.dll')
def SetClusterResourceName(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def SetClusterResourceNameEx(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def FailClusterResource(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def FailClusterResourceEx(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def OnlineClusterResource(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def OfflineClusterResource(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ChangeClusterResourceGroup(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ChangeClusterResourceGroupEx(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, Flags: UInt64) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ChangeClusterResourceGroupEx2(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, Flags: UInt64, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def AddClusterResourceNode(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def RemoveClusterResourceNode(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def AddClusterResourceNodeEx(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def RemoveClusterResourceNodeEx(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def AddClusterResourceDependency(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def RemoveClusterResourceDependency(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def AddClusterResourceDependencyEx(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def RemoveClusterResourceDependencyEx(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def SetClusterResourceDependencyExpression(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszDependencyExpression: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def GetClusterResourceDependencyExpression(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszDependencyExpression: win32more.Windows.Win32.Foundation.PWSTR, lpcchDependencyExpression: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def AddResourceToClusterSharedVolumes(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def RemoveResourceFromClusterSharedVolumes(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def IsFileOnClusterSharedVolume(lpszPathName: win32more.Windows.Win32.Foundation.PWSTR, pbFileIsOnSharedVolume: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterSharedVolumeSetSnapshotState(guidSnapshotSet: Guid, lpszVolumeName: win32more.Windows.Win32.Foundation.PWSTR, state: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_SNAPSHOT_STATE) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def CanResourceBeDependent(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hResourceDependent: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceControl(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, cbInBufferSize: UInt32, lpOutBuffer: VoidPtr, cbOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceControlAsUser(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, cbInBufferSize: UInt32, lpOutBuffer: VoidPtr, cbOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceTypeControl(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceTypeControlAsUser(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterGroupControl(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceControlEx(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, cbInBufferSize: UInt32, lpOutBuffer: VoidPtr, cbOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceControlAsUserEx(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, cbInBufferSize: UInt32, lpOutBuffer: VoidPtr, cbOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceTypeControlEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceTypeControlAsUserEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterGroupControlEx(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterNodeControl(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterNodeControlEx(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def GetClusterResourceNetworkName(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpBuffer: win32more.Windows.Win32.Foundation.PWSTR, nSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceOpenEnum(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, dwType: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HRESENUM: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceGetEnumCount(hResEnum: win32more.Windows.Win32.Networking.Clustering.HRESENUM) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceEnum(hResEnum: win32more.Windows.Win32.Networking.Clustering.HRESENUM, dwIndex: UInt32, lpdwType: POINTER(UInt32), lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceCloseEnum(hResEnum: win32more.Windows.Win32.Networking.Clustering.HRESENUM) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def CreateClusterResourceType(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, lpszDisplayName: win32more.Windows.Win32.Foundation.PWSTR, lpszResourceTypeDll: win32more.Windows.Win32.Foundation.PWSTR, dwLooksAlivePollInterval: UInt32, dwIsAlivePollInterval: UInt32) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def DeleteClusterResourceType(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def CreateClusterResourceTypeEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, lpszDisplayName: win32more.Windows.Win32.Foundation.PWSTR, lpszResourceTypeDll: win32more.Windows.Win32.Foundation.PWSTR, dwLooksAlivePollInterval: UInt32, dwIsAlivePollInterval: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def DeleteClusterResourceTypeEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszTypeName: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceTypeOpenEnum(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, dwType: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HRESTYPEENUM: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceTypeGetEnumCount(hResTypeEnum: win32more.Windows.Win32.Networking.Clustering.HRESTYPEENUM) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceTypeEnum(hResTypeEnum: win32more.Windows.Win32.Networking.Clustering.HRESTYPEENUM, dwIndex: UInt32, lpdwType: POINTER(UInt32), lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterResourceTypeCloseEnum(hResTypeEnum: win32more.Windows.Win32.Networking.Clustering.HRESTYPEENUM) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def OpenClusterNetwork(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNetworkName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HNETWORK: ...
@winfunctype('CLUSAPI.dll')
def OpenClusterNetworkEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNetworkName: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32, lpdwGrantedAccess: POINTER(UInt32)) -> win32more.Windows.Win32.Networking.Clustering.HNETWORK: ...
@winfunctype('CLUSAPI.dll')
def CloseClusterNetwork(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('CLUSAPI.dll')
def GetClusterFromNetwork(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype('CLUSAPI.dll')
def ClusterNetworkOpenEnum(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK, dwType: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HNETWORKENUM: ...
@winfunctype('CLUSAPI.dll')
def ClusterNetworkGetEnumCount(hNetworkEnum: win32more.Windows.Win32.Networking.Clustering.HNETWORKENUM) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterNetworkEnum(hNetworkEnum: win32more.Windows.Win32.Networking.Clustering.HNETWORKENUM, dwIndex: UInt32, lpdwType: POINTER(UInt32), lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterNetworkCloseEnum(hNetworkEnum: win32more.Windows.Win32.Networking.Clustering.HNETWORKENUM) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def GetClusterNetworkState(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK) -> win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETWORK_STATE: ...
@winfunctype('CLUSAPI.dll')
def SetClusterNetworkName(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK, lpszName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def SetClusterNetworkNameEx(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK, lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def GetClusterNetworkId(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK, lpszNetworkId: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterNetworkControl(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterNetworkControlEx(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def OpenClusterNetInterface(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszInterfaceName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HNETINTERFACE: ...
@winfunctype('CLUSAPI.dll')
def OpenClusterNetInterfaceEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszInterfaceName: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32, lpdwGrantedAccess: POINTER(UInt32)) -> win32more.Windows.Win32.Networking.Clustering.HNETINTERFACE: ...
@winfunctype('CLUSAPI.dll')
def GetClusterNetInterface(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR, lpszNetworkName: win32more.Windows.Win32.Foundation.PWSTR, lpszInterfaceName: win32more.Windows.Win32.Foundation.PWSTR, lpcchInterfaceName: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def CloseClusterNetInterface(hNetInterface: win32more.Windows.Win32.Networking.Clustering.HNETINTERFACE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('CLUSAPI.dll')
def GetClusterFromNetInterface(hNetInterface: win32more.Windows.Win32.Networking.Clustering.HNETINTERFACE) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype('CLUSAPI.dll')
def GetClusterNetInterfaceState(hNetInterface: win32more.Windows.Win32.Networking.Clustering.HNETINTERFACE) -> win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETINTERFACE_STATE: ...
@winfunctype('CLUSAPI.dll')
def ClusterNetInterfaceControl(hNetInterface: win32more.Windows.Win32.Networking.Clustering.HNETINTERFACE, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterNetInterfaceControlEx(hNetInterface: win32more.Windows.Win32.Networking.Clustering.HNETINTERFACE, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def GetClusterKey(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, samDesired: UInt32) -> win32more.Windows.Win32.System.Registry.HKEY: ...
@winfunctype('CLUSAPI.dll')
def GetClusterGroupKey(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, samDesired: UInt32) -> win32more.Windows.Win32.System.Registry.HKEY: ...
@winfunctype('CLUSAPI.dll')
def GetClusterResourceKey(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, samDesired: UInt32) -> win32more.Windows.Win32.System.Registry.HKEY: ...
@winfunctype('CLUSAPI.dll')
def GetClusterNodeKey(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, samDesired: UInt32) -> win32more.Windows.Win32.System.Registry.HKEY: ...
@winfunctype('CLUSAPI.dll')
def GetClusterNetworkKey(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK, samDesired: UInt32) -> win32more.Windows.Win32.System.Registry.HKEY: ...
@winfunctype('CLUSAPI.dll')
def GetClusterNetInterfaceKey(hNetInterface: win32more.Windows.Win32.Networking.Clustering.HNETINTERFACE, samDesired: UInt32) -> win32more.Windows.Win32.System.Registry.HKEY: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegCreateKey(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpszSubKey: win32more.Windows.Win32.Foundation.PWSTR, dwOptions: UInt32, samDesired: UInt32, lpSecurityAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES), phkResult: POINTER(win32more.Windows.Win32.System.Registry.HKEY), lpdwDisposition: POINTER(UInt32)) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegCreateKeyEx(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpSubKey: win32more.Windows.Win32.Foundation.PWSTR, dwOptions: UInt32, samDesired: UInt32, lpSecurityAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES), phkResult: POINTER(win32more.Windows.Win32.System.Registry.HKEY), lpdwDisposition: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegOpenKey(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpszSubKey: win32more.Windows.Win32.Foundation.PWSTR, samDesired: UInt32, phkResult: POINTER(win32more.Windows.Win32.System.Registry.HKEY)) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegDeleteKey(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpszSubKey: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegDeleteKeyEx(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpSubKey: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegCloseKey(hKey: win32more.Windows.Win32.System.Registry.HKEY) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegEnumKey(hKey: win32more.Windows.Win32.System.Registry.HKEY, dwIndex: UInt32, lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32), lpftLastWriteTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegSetValue(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpszValueName: win32more.Windows.Win32.Foundation.PWSTR, dwType: UInt32, lpData: POINTER(Byte), cbData: UInt32) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegDeleteValue(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpszValueName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegSetValueEx(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpszValueName: win32more.Windows.Win32.Foundation.PWSTR, dwType: UInt32, lpData: POINTER(Byte), cbData: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegDeleteValueEx(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpszValueName: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegQueryValue(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpszValueName: win32more.Windows.Win32.Foundation.PWSTR, lpdwValueType: POINTER(UInt32), lpData: POINTER(Byte), lpcbData: POINTER(UInt32)) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegEnumValue(hKey: win32more.Windows.Win32.System.Registry.HKEY, dwIndex: UInt32, lpszValueName: win32more.Windows.Win32.Foundation.PWSTR, lpcchValueName: POINTER(UInt32), lpdwType: POINTER(UInt32), lpData: POINTER(Byte), lpcbData: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegQueryInfoKey(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpcSubKeys: POINTER(UInt32), lpcchMaxSubKeyLen: POINTER(UInt32), lpcValues: POINTER(UInt32), lpcchMaxValueNameLen: POINTER(UInt32), lpcbMaxValueLen: POINTER(UInt32), lpcbSecurityDescriptor: POINTER(UInt32), lpftLastWriteTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegGetKeySecurity(hKey: win32more.Windows.Win32.System.Registry.HKEY, RequestedInformation: UInt32, pSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR, lpcbSecurityDescriptor: POINTER(UInt32)) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegSetKeySecurity(hKey: win32more.Windows.Win32.System.Registry.HKEY, SecurityInformation: UInt32, pSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegSetKeySecurityEx(hKey: win32more.Windows.Win32.System.Registry.HKEY, SecurityInformation: win32more.Windows.Win32.Security.OBJECT_SECURITY_INFORMATION, pSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegSyncDatabase(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, flags: UInt32) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegCreateBatch(hKey: win32more.Windows.Win32.System.Registry.HKEY, pHREGBATCH: POINTER(win32more.Windows.Win32.Networking.Clustering.HREGBATCH)) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegBatchAddCommand(hRegBatch: win32more.Windows.Win32.Networking.Clustering.HREGBATCH, dwCommand: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND, wzName: win32more.Windows.Win32.Foundation.PWSTR, dwOptions: UInt32, lpData: VoidPtr, cbData: UInt32) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegCloseBatch(hRegBatch: win32more.Windows.Win32.Networking.Clustering.HREGBATCH, bCommit: win32more.Windows.Win32.Foundation.BOOL, failedCommandNumber: POINTER(Int32)) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegCloseBatchEx(hRegBatch: win32more.Windows.Win32.Networking.Clustering.HREGBATCH, flags: UInt32, failedCommandNumber: POINTER(Int32)) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegBatchReadCommand(hBatchNotification: win32more.Windows.Win32.Networking.Clustering.HREGBATCHNOTIFICATION, pBatchCommand: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_BATCH_COMMAND)) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegBatchCloseNotification(hBatchNotification: win32more.Windows.Win32.Networking.Clustering.HREGBATCHNOTIFICATION) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegCreateBatchNotifyPort(hKey: win32more.Windows.Win32.System.Registry.HKEY, phBatchNotifyPort: POINTER(win32more.Windows.Win32.Networking.Clustering.HREGBATCHPORT)) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegCloseBatchNotifyPort(hBatchNotifyPort: win32more.Windows.Win32.Networking.Clustering.HREGBATCHPORT) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegGetBatchNotification(hBatchNotify: win32more.Windows.Win32.Networking.Clustering.HREGBATCHPORT, phBatchNotification: POINTER(win32more.Windows.Win32.Networking.Clustering.HREGBATCHNOTIFICATION)) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegCreateReadBatch(hKey: win32more.Windows.Win32.System.Registry.HKEY, phRegReadBatch: POINTER(win32more.Windows.Win32.Networking.Clustering.HREGREADBATCH)) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegReadBatchAddCommand(hRegReadBatch: win32more.Windows.Win32.Networking.Clustering.HREGREADBATCH, wzSubkeyName: win32more.Windows.Win32.Foundation.PWSTR, wzValueName: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegCloseReadBatch(hRegReadBatch: win32more.Windows.Win32.Networking.Clustering.HREGREADBATCH, phRegReadBatchReply: POINTER(win32more.Windows.Win32.Networking.Clustering.HREGREADBATCHREPLY)) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegCloseReadBatchEx(hRegReadBatch: win32more.Windows.Win32.Networking.Clustering.HREGREADBATCH, flags: UInt32, phRegReadBatchReply: POINTER(win32more.Windows.Win32.Networking.Clustering.HREGREADBATCHREPLY)) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegReadBatchReplyNextCommand(hRegReadBatchReply: win32more.Windows.Win32.Networking.Clustering.HREGREADBATCHREPLY, pBatchCommand: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_READ_BATCH_COMMAND)) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterRegCloseReadBatchReply(hRegReadBatchReply: win32more.Windows.Win32.Networking.Clustering.HREGREADBATCHREPLY) -> Int32: ...
@winfunctype('CLUSAPI.dll')
def ClusterSetAccountAccess(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, szAccountSID: win32more.Windows.Win32.Foundation.PWSTR, dwAccess: UInt32, dwControlType: UInt32) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def CreateCluster(pConfig: POINTER(win32more.Windows.Win32.Networking.Clustering.CREATE_CLUSTER_CONFIG), pfnProgressCallback: win32more.Windows.Win32.Networking.Clustering.PCLUSTER_SETUP_PROGRESS_CALLBACK, pvCallbackArg: VoidPtr) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype('CLUSAPI.dll')
def CreateClusterNameAccount(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, pConfig: POINTER(win32more.Windows.Win32.Networking.Clustering.CREATE_CLUSTER_NAME_ACCOUNT), pfnProgressCallback: win32more.Windows.Win32.Networking.Clustering.PCLUSTER_SETUP_PROGRESS_CALLBACK, pvCallbackArg: VoidPtr) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def RemoveClusterNameAccount(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, bDeleteComputerObjects: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def DetermineCNOResTypeFromNodelist(cNodes: UInt32, ppszNodeNames: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pCNOResType: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_MGMT_POINT_RESTYPE)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def DetermineCNOResTypeFromCluster(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, pCNOResType: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_MGMT_POINT_RESTYPE)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def DetermineClusterCloudTypeFromNodelist(cNodes: UInt32, ppszNodeNames: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pCloudType: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_CLOUD_TYPE)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def DetermineClusterCloudTypeFromCluster(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, pCloudType: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_CLOUD_TYPE)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def GetNodeCloudTypeDW(ppszNodeName: win32more.Windows.Win32.Foundation.PWSTR, NodeCloudType: POINTER(UInt32)) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def RegisterClusterResourceTypeNotifyV2(hChange: win32more.Windows.Win32.Networking.Clustering.HCHANGE, hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, Flags: Int64, resTypeName: win32more.Windows.Win32.Foundation.PWSTR, dwNotifyKey: UIntPtr) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def AddClusterNode(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR, pfnProgressCallback: win32more.Windows.Win32.Networking.Clustering.PCLUSTER_SETUP_PROGRESS_CALLBACK, pvCallbackArg: VoidPtr) -> win32more.Windows.Win32.Networking.Clustering.HNODE: ...
@winfunctype('CLUSAPI.dll')
def AddClusterStorageNode(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR, pfnProgressCallback: win32more.Windows.Win32.Networking.Clustering.PCLUSTER_SETUP_PROGRESS_CALLBACK, pvCallbackArg: VoidPtr, lpszClusterStorageNodeDescription: win32more.Windows.Win32.Foundation.PWSTR, lpszClusterStorageNodeLocation: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def AddClusterNodeEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, pfnProgressCallback: win32more.Windows.Win32.Networking.Clustering.PCLUSTER_SETUP_PROGRESS_CALLBACK, pvCallbackArg: VoidPtr) -> win32more.Windows.Win32.Networking.Clustering.HNODE: ...
@winfunctype('CLUSAPI.dll')
def RemoveClusterStorageNode(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszClusterStorageEnclosureName: win32more.Windows.Win32.Foundation.PWSTR, dwTimeout: UInt32, dwFlags: UInt32) -> UInt32: ...
@winfunctype('CLUSAPI.dll')
def DestroyCluster(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, pfnProgressCallback: win32more.Windows.Win32.Networking.Clustering.PCLUSTER_SETUP_PROGRESS_CALLBACK, pvCallbackArg: VoidPtr, fdeleteVirtualComputerObjects: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def InitializeClusterHealthFault(clusterHealthFault: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_HEALTH_FAULT)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def InitializeClusterHealthFaultArray(clusterHealthFaultArray: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_HEALTH_FAULT_ARRAY)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def FreeClusterHealthFault(clusterHealthFault: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_HEALTH_FAULT)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def FreeClusterHealthFaultArray(clusterHealthFaultArray: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_HEALTH_FAULT_ARRAY)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ClusGetClusterHealthFaults(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, objects: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_HEALTH_FAULT_ARRAY), flags: UInt32) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ClusRemoveClusterHealthFault(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, id: win32more.Windows.Win32.Foundation.PWSTR, flags: UInt32) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ClusAddClusterHealthFault(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, failure: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_HEALTH_FAULT), param2: UInt32) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilStartResourceService(pszServiceName: win32more.Windows.Win32.Foundation.PWSTR, phServiceHandle: POINTER(win32more.Windows.Win32.System.Services.SC_HANDLE)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilVerifyResourceService(pszServiceName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilStopResourceService(pszServiceName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilVerifyService(hServiceHandle: win32more.Windows.Win32.System.Services.SC_HANDLE) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilStopService(hServiceHandle: win32more.Windows.Win32.System.Services.SC_HANDLE) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilCreateDirectoryTree(pszPath: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilIsPathValid(pszPath: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('RESUTILS.dll')
def ResUtilEnumProperties(pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pszOutProperties: win32more.Windows.Win32.Foundation.PWSTR, cbOutPropertiesSize: UInt32, pcbBytesReturned: POINTER(UInt32), pcbRequired: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilEnumPrivateProperties(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszOutProperties: win32more.Windows.Win32.Foundation.PWSTR, cbOutPropertiesSize: UInt32, pcbBytesReturned: POINTER(UInt32), pcbRequired: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetProperties(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pOutPropertyList: VoidPtr, cbOutPropertyListSize: UInt32, pcbBytesReturned: POINTER(UInt32), pcbRequired: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetAllProperties(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pOutPropertyList: VoidPtr, cbOutPropertyListSize: UInt32, pcbBytesReturned: POINTER(UInt32), pcbRequired: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetPrivateProperties(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pOutPropertyList: VoidPtr, cbOutPropertyListSize: UInt32, pcbBytesReturned: POINTER(UInt32), pcbRequired: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetPropertySize(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTableItem: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pcbOutPropertyListSize: POINTER(UInt32), pnPropertyCount: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetProperty(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTableItem: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pOutPropertyItem: POINTER(VoidPtr), pcbOutPropertyItemSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilVerifyPropertyTable(pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), Reserved: VoidPtr, bAllowUnknownProperties: win32more.Windows.Win32.Foundation.BOOL, pInPropertyList: VoidPtr, cbInPropertyListSize: UInt32, pOutParams: POINTER(Byte)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilSetPropertyTable(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), Reserved: VoidPtr, bAllowUnknownProperties: win32more.Windows.Win32.Foundation.BOOL, pInPropertyList: VoidPtr, cbInPropertyListSize: UInt32, pOutParams: POINTER(Byte)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilSetPropertyTableEx(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), Reserved: VoidPtr, bAllowUnknownProperties: win32more.Windows.Win32.Foundation.BOOL, pInPropertyList: VoidPtr, cbInPropertyListSize: UInt32, bForceWrite: win32more.Windows.Win32.Foundation.BOOL, pOutParams: POINTER(Byte)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilSetPropertyParameterBlock(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), Reserved: VoidPtr, pInParams: POINTER(Byte), pInPropertyList: VoidPtr, cbInPropertyListSize: UInt32, pOutParams: POINTER(Byte)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilSetPropertyParameterBlockEx(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), Reserved: VoidPtr, pInParams: POINTER(Byte), pInPropertyList: VoidPtr, cbInPropertyListSize: UInt32, bForceWrite: win32more.Windows.Win32.Foundation.BOOL, pOutParams: POINTER(Byte)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilSetUnknownProperties(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pInPropertyList: VoidPtr, cbInPropertyListSize: UInt32) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetPropertiesToParameterBlock(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pOutParams: POINTER(Byte), bCheckForRequiredProperties: win32more.Windows.Win32.Foundation.BOOL, pszNameOfPropInError: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilPropertyListFromParameterBlock(pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pOutPropertyList: VoidPtr, pcbOutPropertyListSize: POINTER(UInt32), pInParams: POINTER(Byte), pcbBytesReturned: POINTER(UInt32), pcbRequired: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilDupParameterBlock(pOutParams: POINTER(Byte), pInParams: POINTER(Byte), pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilFreeParameterBlock(pOutParams: POINTER(Byte), pInParams: POINTER(Byte), pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM)) -> Void: ...
@winfunctype('RESUTILS.dll')
def ResUtilAddUnknownProperties(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pOutPropertyList: VoidPtr, pcbOutPropertyListSize: UInt32, pcbBytesReturned: POINTER(UInt32), pcbRequired: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilSetPrivatePropertyList(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pInPropertyList: VoidPtr, cbInPropertyListSize: UInt32) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilVerifyPrivatePropertyList(pInPropertyList: VoidPtr, cbInPropertyListSize: UInt32) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilDupString(pszInString: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.PWSTR: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetBinaryValue(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, ppbOutValue: POINTER(POINTER(Byte)), pcbOutValueSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetSzValue(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.PWSTR: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetDwordValue(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, pdwOutValue: POINTER(UInt32), dwDefaultValue: UInt32) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetQwordValue(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, pqwOutValue: POINTER(UInt64), qwDefaultValue: UInt64) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilSetBinaryValue(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, pbNewValue: POINTER(Byte), cbNewValueSize: UInt32, ppbOutValue: POINTER(POINTER(Byte)), pcbOutValueSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilSetSzValue(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, pszNewValue: win32more.Windows.Win32.Foundation.PWSTR, ppszOutString: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilSetExpandSzValue(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, pszNewValue: win32more.Windows.Win32.Foundation.PWSTR, ppszOutString: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilSetMultiSzValue(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, pszNewValue: win32more.Windows.Win32.Foundation.PWSTR, cbNewValueSize: UInt32, ppszOutValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pcbOutValueSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilSetDwordValue(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, dwNewValue: UInt32, pdwOutValue: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilSetQwordValue(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, qwNewValue: UInt64, pqwOutValue: POINTER(UInt64)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilSetValueEx(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, valueName: win32more.Windows.Win32.Foundation.PWSTR, valueType: UInt32, valueData: POINTER(Byte), valueSize: UInt32, flags: UInt32) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetBinaryProperty(ppbOutValue: POINTER(POINTER(Byte)), pcbOutValueSize: POINTER(UInt32), pValueStruct: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_BINARY), pbOldValue: POINTER(Byte), cbOldValueSize: UInt32, ppPropertyList: POINTER(POINTER(Byte)), pcbPropertyListSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetSzProperty(ppszOutValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pValueStruct: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_SZ), pszOldValue: win32more.Windows.Win32.Foundation.PWSTR, ppPropertyList: POINTER(POINTER(Byte)), pcbPropertyListSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetMultiSzProperty(ppszOutValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pcbOutValueSize: POINTER(UInt32), pValueStruct: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_SZ), pszOldValue: win32more.Windows.Win32.Foundation.PWSTR, cbOldValueSize: UInt32, ppPropertyList: POINTER(POINTER(Byte)), pcbPropertyListSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetDwordProperty(pdwOutValue: POINTER(UInt32), pValueStruct: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_DWORD), dwOldValue: UInt32, dwMinimum: UInt32, dwMaximum: UInt32, ppPropertyList: POINTER(POINTER(Byte)), pcbPropertyListSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetLongProperty(plOutValue: POINTER(Int32), pValueStruct: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_LONG), lOldValue: Int32, lMinimum: Int32, lMaximum: Int32, ppPropertyList: POINTER(POINTER(Byte)), pcbPropertyListSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetFileTimeProperty(pftOutValue: POINTER(win32more.Windows.Win32.Foundation.FILETIME), pValueStruct: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_FILETIME), ftOldValue: win32more.Windows.Win32.Foundation.FILETIME, ftMinimum: win32more.Windows.Win32.Foundation.FILETIME, ftMaximum: win32more.Windows.Win32.Foundation.FILETIME, ppPropertyList: POINTER(POINTER(Byte)), pcbPropertyListSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetEnvironmentWithNetName(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> VoidPtr: ...
@winfunctype('RESUTILS.dll')
def ResUtilFreeEnvironment(lpEnvironment: VoidPtr) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilExpandEnvironmentStrings(pszSrc: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.PWSTR: ...
@winfunctype('RESUTILS.dll')
def ResUtilSetResourceServiceEnvironment(pszServiceName: win32more.Windows.Win32.Foundation.PWSTR, hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, pfnLogEvent: win32more.Windows.Win32.Networking.Clustering.PLOG_EVENT_ROUTINE, hResourceHandle: IntPtr) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilRemoveResourceServiceEnvironment(pszServiceName: win32more.Windows.Win32.Foundation.PWSTR, pfnLogEvent: win32more.Windows.Win32.Networking.Clustering.PLOG_EVENT_ROUTINE, hResourceHandle: IntPtr) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilSetResourceServiceStartParameters(pszServiceName: win32more.Windows.Win32.Foundation.PWSTR, schSCMHandle: win32more.Windows.Win32.System.Services.SC_HANDLE, phService: POINTER(win32more.Windows.Win32.System.Services.SC_HANDLE), pfnLogEvent: win32more.Windows.Win32.Networking.Clustering.PLOG_EVENT_ROUTINE, hResourceHandle: IntPtr) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilFindSzProperty(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, pszPropertyValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilFindExpandSzProperty(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, pszPropertyValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilFindExpandedSzProperty(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, pszPropertyValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilFindDwordProperty(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, pdwPropertyValue: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilFindBinaryProperty(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, pbPropertyValue: POINTER(POINTER(Byte)), pcbPropertyValueSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilFindMultiSzProperty(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, pszPropertyValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pcbPropertyValueSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilFindLongProperty(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, plPropertyValue: POINTER(Int32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilFindULargeIntegerProperty(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, plPropertyValue: POINTER(UInt64)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilFindFileTimeProperty(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, pftPropertyValue: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ClusWorkerCreate(lpWorker: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUS_WORKER), lpStartAddress: win32more.Windows.Win32.Networking.Clustering.PWORKER_START_ROUTINE, lpParameter: VoidPtr) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ClusWorkerCheckTerminate(lpWorker: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUS_WORKER)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('RESUTILS.dll')
def ClusWorkerTerminate(lpWorker: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUS_WORKER)) -> Void: ...
@winfunctype('RESUTILS.dll')
def ClusWorkerTerminateEx(ClusWorker: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUS_WORKER), TimeoutInMilliseconds: UInt32, WaitOnly: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ClusWorkersTerminate(ClusWorkers: POINTER(POINTER(win32more.Windows.Win32.Networking.Clustering.CLUS_WORKER)), ClusWorkersCount: UIntPtr, TimeoutInMilliseconds: UInt32, WaitOnly: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilResourcesEqual(hSelf: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('RESUTILS.dll')
def ResUtilResourceTypesEqual(lpszResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('RESUTILS.dll')
def ResUtilIsResourceClassEqual(prci: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUS_RESOURCE_CLASS_INFO), hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('RESUTILS.dll')
def ResUtilEnumResources(hSelf: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszResTypeName: win32more.Windows.Win32.Foundation.PWSTR, pResCallBack: win32more.Windows.Win32.Networking.Clustering.LPRESOURCE_CALLBACK, pParameter: VoidPtr) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilEnumResourcesEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hSelf: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszResTypeName: win32more.Windows.Win32.Foundation.PWSTR, pResCallBack: win32more.Windows.Win32.Networking.Clustering.LPRESOURCE_CALLBACK_EX, pParameter: VoidPtr) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetResourceDependency(hSelf: win32more.Windows.Win32.Foundation.HANDLE, lpszResourceType: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetResourceDependencyByName(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hSelf: win32more.Windows.Win32.Foundation.HANDLE, lpszResourceType: win32more.Windows.Win32.Foundation.PWSTR, bRecurse: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetResourceDependencyByClass(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hSelf: win32more.Windows.Win32.Foundation.HANDLE, prci: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUS_RESOURCE_CLASS_INFO), bRecurse: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetResourceNameDependency(lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR, lpszResourceType: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetResourceDependentIPAddressProps(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, pszAddress: win32more.Windows.Win32.Foundation.PWSTR, pcchAddress: POINTER(UInt32), pszSubnetMask: win32more.Windows.Win32.Foundation.PWSTR, pcchSubnetMask: POINTER(UInt32), pszNetwork: win32more.Windows.Win32.Foundation.PWSTR, pcchNetwork: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilFindDependentDiskResourceDriveLetter(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, pszDriveLetter: win32more.Windows.Win32.Foundation.PWSTR, pcchDriveLetter: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilTerminateServiceProcessFromResDll(dwServicePid: UInt32, bOffline: win32more.Windows.Win32.Foundation.BOOL, pdwResourceState: POINTER(UInt32), pfnLogEvent: win32more.Windows.Win32.Networking.Clustering.PLOG_EVENT_ROUTINE, hResourceHandle: IntPtr) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetPropertyFormats(pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pOutPropertyFormatList: VoidPtr, cbPropertyFormatListSize: UInt32, pcbBytesReturned: POINTER(UInt32), pcbRequired: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetCoreClusterResources(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, phClusterNameResource: POINTER(win32more.Windows.Win32.Networking.Clustering.HRESOURCE), phClusterIPAddressResource: POINTER(win32more.Windows.Win32.Networking.Clustering.HRESOURCE), phClusterQuorumResource: POINTER(win32more.Windows.Win32.Networking.Clustering.HRESOURCE)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetResourceName(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, pszResourceName: win32more.Windows.Win32.Foundation.PWSTR, pcchResourceNameInOut: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetClusterRoleState(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, eClusterRole: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE) -> win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE_STATE: ...
@winfunctype('RESUTILS.dll')
def ClusterIsPathOnSharedVolume(lpszPathName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('RESUTILS.dll')
def ClusterGetVolumePathName(lpszFileName: win32more.Windows.Win32.Foundation.PWSTR, lpszVolumePathName: win32more.Windows.Win32.Foundation.PWSTR, cchBufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('RESUTILS.dll')
def ClusterGetVolumeNameForVolumeMountPoint(lpszVolumeMountPoint: win32more.Windows.Win32.Foundation.PWSTR, lpszVolumeName: win32more.Windows.Win32.Foundation.PWSTR, cchBufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('RESUTILS.dll')
def ClusterPrepareSharedVolumeForBackup(lpszFileName: win32more.Windows.Win32.Foundation.PWSTR, lpszVolumePathName: win32more.Windows.Win32.Foundation.PWSTR, lpcchVolumePathName: POINTER(UInt32), lpszVolumeName: win32more.Windows.Win32.Foundation.PWSTR, lpcchVolumeName: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ClusterClearBackupStateForSharedVolume(lpszVolumePathName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilSetResourceServiceStartParametersEx(pszServiceName: win32more.Windows.Win32.Foundation.PWSTR, schSCMHandle: win32more.Windows.Win32.System.Services.SC_HANDLE, phService: POINTER(win32more.Windows.Win32.System.Services.SC_HANDLE), dwDesiredAccess: UInt32, pfnLogEvent: win32more.Windows.Win32.Networking.Clustering.PLOG_EVENT_ROUTINE, hResourceHandle: IntPtr) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilEnumResourcesEx2(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hSelf: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszResTypeName: win32more.Windows.Win32.Foundation.PWSTR, pResCallBack: win32more.Windows.Win32.Networking.Clustering.LPRESOURCE_CALLBACK_EX, pParameter: VoidPtr, dwDesiredAccess: UInt32) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetResourceDependencyEx(hSelf: win32more.Windows.Win32.Foundation.HANDLE, lpszResourceType: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetResourceDependencyByNameEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hSelf: win32more.Windows.Win32.Foundation.HANDLE, lpszResourceType: win32more.Windows.Win32.Foundation.PWSTR, bRecurse: win32more.Windows.Win32.Foundation.BOOL, dwDesiredAccess: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetResourceDependencyByClassEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hSelf: win32more.Windows.Win32.Foundation.HANDLE, prci: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUS_RESOURCE_CLASS_INFO), bRecurse: win32more.Windows.Win32.Foundation.BOOL, dwDesiredAccess: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetResourceNameDependencyEx(lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR, lpszResourceType: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetCoreClusterResourcesEx(hClusterIn: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, phClusterNameResourceOut: POINTER(win32more.Windows.Win32.Networking.Clustering.HRESOURCE), phClusterQuorumResourceOut: POINTER(win32more.Windows.Win32.Networking.Clustering.HRESOURCE), dwDesiredAccess: UInt32) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def OpenClusterCryptProvider(lpszResource: win32more.Windows.Win32.Foundation.PWSTR, lpszProvider: POINTER(SByte), dwType: UInt32, dwFlags: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HCLUSCRYPTPROVIDER: ...
@winfunctype('RESUTILS.dll')
def OpenClusterCryptProviderEx(lpszResource: win32more.Windows.Win32.Foundation.PWSTR, lpszKeyname: win32more.Windows.Win32.Foundation.PWSTR, lpszProvider: POINTER(SByte), dwType: UInt32, dwFlags: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HCLUSCRYPTPROVIDER: ...
@winfunctype('RESUTILS.dll')
def CloseClusterCryptProvider(hClusCryptProvider: win32more.Windows.Win32.Networking.Clustering.HCLUSCRYPTPROVIDER) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ClusterEncrypt(hClusCryptProvider: win32more.Windows.Win32.Networking.Clustering.HCLUSCRYPTPROVIDER, pData: POINTER(Byte), cbData: UInt32, ppData: POINTER(POINTER(Byte)), pcbData: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ClusterDecrypt(hClusCryptProvider: win32more.Windows.Win32.Networking.Clustering.HCLUSCRYPTPROVIDER, pCryptInput: POINTER(Byte), cbCryptInput: UInt32, ppCryptOutput: POINTER(POINTER(Byte)), pcbCryptOutput: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def FreeClusterCrypt(pCryptInfo: VoidPtr) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilVerifyShutdownSafe(flags: UInt32, reason: UInt32, pResult: POINTER(UInt32)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilPaxosComparer(left: POINTER(win32more.Windows.Win32.Networking.Clustering.PaxosTagCStruct), right: POINTER(win32more.Windows.Win32.Networking.Clustering.PaxosTagCStruct)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('RESUTILS.dll')
def ResUtilLeftPaxosIsLessThanRight(left: POINTER(win32more.Windows.Win32.Networking.Clustering.PaxosTagCStruct), right: POINTER(win32more.Windows.Win32.Networking.Clustering.PaxosTagCStruct)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('RESUTILS.dll')
def ResUtilsDeleteKeyTree(key: win32more.Windows.Win32.System.Registry.HKEY, keyName: win32more.Windows.Win32.Foundation.PWSTR, treatNoKeyAsError: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGroupsEqual(hSelf: win32more.Windows.Win32.Networking.Clustering.HGROUP, hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, pEqual: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilEnumGroups(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hSelf: win32more.Windows.Win32.Networking.Clustering.HGROUP, pResCallBack: win32more.Windows.Win32.Networking.Clustering.LPGROUP_CALLBACK_EX, pParameter: VoidPtr) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilEnumGroupsEx(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hSelf: win32more.Windows.Win32.Networking.Clustering.HGROUP, groupType: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE, pResCallBack: win32more.Windows.Win32.Networking.Clustering.LPGROUP_CALLBACK_EX, pParameter: VoidPtr) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilDupGroup(group: win32more.Windows.Win32.Networking.Clustering.HGROUP, copy: POINTER(win32more.Windows.Win32.Networking.Clustering.HGROUP)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetClusterGroupType(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, groupType: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetCoreGroup(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER) -> win32more.Windows.Win32.Networking.Clustering.HGROUP: ...
@winfunctype('RESUTILS.dll')
def ResUtilResourceDepEnum(hSelf: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, enumType: UInt32, pResCallBack: win32more.Windows.Win32.Networking.Clustering.LPRESOURCE_CALLBACK_EX, pParameter: VoidPtr) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilDupResource(group: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, copy: POINTER(win32more.Windows.Win32.Networking.Clustering.HRESOURCE)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilGetClusterId(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, guid: POINTER(Guid)) -> UInt32: ...
@winfunctype('RESUTILS.dll')
def ResUtilNodeEnum(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, pNodeCallBack: win32more.Windows.Win32.Networking.Clustering.LPNODE_CALLBACK, pParameter: VoidPtr) -> UInt32: ...
@winfunctype('NTLANMAN.dll')
def RegisterAppInstance(ProcessHandle: win32more.Windows.Win32.Foundation.HANDLE, AppInstanceId: POINTER(Guid), ChildrenInheritAppInstance: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype('NTLANMAN.dll')
def RegisterAppInstanceVersion(AppInstanceId: POINTER(Guid), InstanceVersionHigh: UInt64, InstanceVersionLow: UInt64) -> UInt32: ...
@winfunctype('NTLANMAN.dll')
def QueryAppInstanceVersion(AppInstanceId: POINTER(Guid), InstanceVersionHigh: POINTER(UInt64), InstanceVersionLow: POINTER(UInt64), VersionStatus: POINTER(win32more.Windows.Win32.Foundation.NTSTATUS)) -> UInt32: ...
@winfunctype('NTLANMAN.dll')
def ResetAllAppInstanceVersions() -> UInt32: ...
@winfunctype('NTLANMAN.dll')
def SetAppInstanceCsvFlags(ProcessHandle: win32more.Windows.Win32.Foundation.HANDLE, Mask: UInt32, Flags: UInt32) -> UInt32: ...
CLCTL_CODES = Int32
CLCTL_UNKNOWN: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 0
CLCTL_GET_CHARACTERISTICS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5
CLCTL_GET_FLAGS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 9
CLCTL_GET_CLASS_INFO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 13
CLCTL_GET_REQUIRED_DEPENDENCIES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 17
CLCTL_GET_ARB_TIMEOUT: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 21
CLCTL_GET_FAILURE_INFO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 25
CLCTL_GET_NAME: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 41
CLCTL_GET_RESOURCE_TYPE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 45
CLCTL_GET_NODE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 49
CLCTL_GET_NETWORK: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 53
CLCTL_GET_ID: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 57
CLCTL_GET_FQDN: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 61
CLCTL_GET_CLUSTER_SERVICE_ACCOUNT_NAME: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 65
CLCTL_CHECK_VOTER_EVICT: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 69
CLCTL_CHECK_VOTER_DOWN: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 73
CLCTL_SHUTDOWN: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 77
CLCTL_ENUM_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 81
CLCTL_GET_RO_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 85
CLCTL_GET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 89
CLCTL_SET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194398
CLCTL_VALIDATE_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 97
CLCTL_GET_COMMON_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 101
CLCTL_GET_COMMON_RESOURCE_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 105
CLCTL_CHECK_VOTER_EVICT_WITNESS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 109
CLCTL_CHECK_VOTER_DOWN_WITNESS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 113
CLCTL_ENUM_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 121
CLCTL_GET_RO_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 125
CLCTL_GET_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 129
CLCTL_SET_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194438
CLCTL_VALIDATE_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 137
CLCTL_GET_PRIVATE_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 141
CLCTL_GET_PRIVATE_RESOURCE_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 145
CLCTL_ADD_REGISTRY_CHECKPOINT: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194466
CLCTL_DELETE_REGISTRY_CHECKPOINT: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194470
CLCTL_GET_REGISTRY_CHECKPOINTS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 169
CLCTL_ADD_CRYPTO_CHECKPOINT: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194478
CLCTL_DELETE_CRYPTO_CHECKPOINT: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194482
CLCTL_GET_CRYPTO_CHECKPOINTS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 181
CLCTL_RESOURCE_UPGRADE_DLL: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194490
CLCTL_ADD_REGISTRY_CHECKPOINT_64BIT: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194494
CLCTL_ADD_REGISTRY_CHECKPOINT_32BIT: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194498
CLCTL_GET_LOADBAL_PROCESS_LIST: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 201
CLCTL_SET_ACCOUNT_ACCESS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194546
CLCTL_GET_NETWORK_NAME: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 361
CLCTL_NETNAME_GET_VIRTUAL_SERVER_TOKEN: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 365
CLCTL_NETNAME_REGISTER_DNS_RECORDS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 370
CLCTL_GET_DNS_NAME: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 373
CLCTL_NETNAME_SET_PWD_INFO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 378
CLCTL_NETNAME_DELETE_CO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 382
CLCTL_NETNAME_VALIDATE_VCO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 385
CLCTL_NETNAME_RESET_VCO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 389
CLCTL_NETNAME_REPAIR_VCO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 397
CLCTL_STORAGE_GET_DISK_INFO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 401
CLCTL_STORAGE_GET_AVAILABLE_DISKS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 405
CLCTL_STORAGE_IS_PATH_VALID: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 409
CLCTL_STORAGE_SYNC_CLUSDISK_DB: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194718
CLCTL_STORAGE_GET_DISK_NUMBER_INFO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 417
CLCTL_QUERY_DELETE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 441
CLCTL_IPADDRESS_RENEW_LEASE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194750
CLCTL_IPADDRESS_RELEASE_LEASE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194754
CLCTL_QUERY_MAINTENANCE_MODE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 481
CLCTL_SET_MAINTENANCE_MODE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194790
CLCTL_STORAGE_SET_DRIVELETTER: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194794
CLCTL_STORAGE_GET_DRIVELETTERS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 493
CLCTL_STORAGE_GET_DISK_INFO_EX: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 497
CLCTL_STORAGE_GET_AVAILABLE_DISKS_EX: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 501
CLCTL_STORAGE_GET_DISK_INFO_EX2: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 505
CLCTL_STORAGE_GET_CLUSPORT_DISK_COUNT: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 509
CLCTL_STORAGE_REMAP_DRIVELETTER: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 513
CLCTL_STORAGE_GET_DISKID: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 517
CLCTL_STORAGE_IS_CLUSTERABLE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 521
CLCTL_STORAGE_REMOVE_VM_OWNERSHIP: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194830
CLCTL_STORAGE_GET_MOUNTPOINTS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 529
CLCTL_STORAGE_GET_DIRTY: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 537
CLCTL_STORAGE_GET_SHARED_VOLUME_INFO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 549
CLCTL_STORAGE_IS_CSV_FILE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 553
CLCTL_STORAGE_GET_RESOURCEID: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 557
CLCTL_VALIDATE_PATH: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 561
CLCTL_VALIDATE_NETNAME: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 565
CLCTL_VALIDATE_DIRECTORY: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 569
CLCTL_BATCH_BLOCK_KEY: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 574
CLCTL_BATCH_UNBLOCK_KEY: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 577
CLCTL_FILESERVER_SHARE_ADD: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194886
CLCTL_FILESERVER_SHARE_DEL: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194890
CLCTL_FILESERVER_SHARE_MODIFY: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194894
CLCTL_FILESERVER_SHARE_REPORT: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 593
CLCTL_NETNAME_GET_OU_FOR_VCO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194926
CLCTL_ENABLE_SHARED_VOLUME_DIRECTIO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194954
CLCTL_DISABLE_SHARED_VOLUME_DIRECTIO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194958
CLCTL_GET_SHARED_VOLUME_ID: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 657
CLCTL_SET_CSV_MAINTENANCE_MODE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194966
CLCTL_SET_SHARED_VOLUME_BACKUP_MODE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194970
CLCTL_STORAGE_GET_SHARED_VOLUME_PARTITION_NAMES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 669
CLCTL_STORAGE_GET_SHARED_VOLUME_STATES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194978
CLCTL_STORAGE_IS_SHARED_VOLUME: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 677
CLCTL_GET_CLUSDB_TIMESTAMP: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 681
CLCTL_RW_MODIFY_NOOP: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4194990
CLCTL_IS_QUORUM_BLOCKED: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 689
CLCTL_POOL_GET_DRIVE_INFO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 693
CLCTL_GET_GUM_LOCK_OWNER: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 697
CLCTL_GET_STUCK_NODES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 701
CLCTL_INJECT_GEM_FAULT: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 705
CLCTL_INTRODUCE_GEM_REPAIR_DELAY: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 709
CLCTL_SEND_DUMMY_GEM_MESSAGES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 713
CLCTL_BLOCK_GEM_SEND_RECV: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 717
CLCTL_GET_GEMID_VECTOR: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 721
CLCTL_ADD_CRYPTO_CHECKPOINT_EX: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4195030
CLCTL_GROUP_GET_LAST_MOVE_TIME: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 729
CLCTL_SET_STORAGE_CONFIGURATION: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4195042
CLCTL_GET_STORAGE_CONFIGURATION: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 741
CLCTL_GET_STORAGE_CONFIG_ATTRIBUTES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 745
CLCTL_REMOVE_NODE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4195054
CLCTL_IS_FEATURE_INSTALLED: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 753
CLCTL_IS_S2D_FEATURE_SUPPORTED: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 757
CLCTL_STORAGE_GET_PHYSICAL_DISK_INFO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 761
CLCTL_STORAGE_GET_CLUSBFLT_PATHS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 765
CLCTL_STORAGE_GET_CLUSBFLT_PATHINFO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 769
CLCTL_CLEAR_NODE_CONNECTION_INFO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4195078
CLCTL_SET_DNS_DOMAIN: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4195082
CTCTL_GET_ROUTESTATUS_BASIC: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 781
CTCTL_GET_ROUTESTATUS_EXTENDED: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 785
CTCTL_GET_FAULT_DOMAIN_STATE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 789
CLCTL_NETNAME_SET_PWD_INFOEX: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 794
CLCTL_STORAGE_GET_AVAILABLE_DISKS_EX2_INT: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 8161
CLCTL_CLOUD_WITNESS_RESOURCE_TYPE_VALIDATE_CREDENTIALS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 8417
CLCTL_CLOUD_WITNESS_RESOURCE_UPDATE_TOKEN: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4202726
CLCTL_RESOURCE_PREPARE_UPGRADE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4202730
CLCTL_RESOURCE_UPGRADE_COMPLETED: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4202734
CLCTL_CLOUD_WITNESS_RESOURCE_TYPE_VALIDATE_CREDENTIALS_WITH_KEY: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 8433
CLCTL_CLOUD_WITNESS_RESOURCE_UPDATE_KEY: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4202742
CLCTL_REPLICATION_ADD_REPLICATION_GROUP: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 8514
CLCTL_REPLICATION_GET_LOG_INFO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 8517
CLCTL_REPLICATION_GET_ELIGIBLE_LOGDISKS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 8521
CLCTL_REPLICATION_GET_ELIGIBLE_TARGET_DATADISKS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 8525
CLCTL_REPLICATION_GET_ELIGIBLE_SOURCE_DATADISKS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 8529
CLCTL_REPLICATION_GET_REPLICATED_DISKS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 8533
CLCTL_REPLICATION_GET_REPLICA_VOLUMES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 8537
CLCTL_REPLICATION_GET_LOG_VOLUME: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 8541
CLCTL_REPLICATION_GET_RESOURCE_GROUP: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 8545
CLCTL_REPLICATION_GET_REPLICATED_PARTITION_INFO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 8549
CLCTL_GET_STATE_CHANGE_TIME: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 11613
CLCTL_SET_CLUSTER_S2D_ENABLED: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4205922
CLCTL_SET_CLUSTER_S2D_CACHE_METADATA_RESERVE_BYTES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4205934
CLCTL_GROUPSET_GET_GROUPS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 11633
CLCTL_GROUPSET_GET_PROVIDER_GROUPS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 11637
CLCTL_GROUPSET_GET_PROVIDER_GROUPSETS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 11641
CLCTL_GROUP_GET_PROVIDER_GROUPS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 11645
CLCTL_GROUP_GET_PROVIDER_GROUPSETS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 11649
CLCTL_GROUP_SET_CCF_FROM_MASTER: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4205958
CLCTL_GET_INFRASTRUCTURE_SOFS_BUFFER: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 11657
CLCTL_SET_INFRASTRUCTURE_SOFS_BUFFER: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4205966
CLCTL_NOTIFY_INFRASTRUCTURE_SOFS_CHANGED: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4205970
CLCTL_SCALEOUT_COMMAND: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4205974
CLCTL_SCALEOUT_CONTROL: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4205978
CLCTL_SCALEOUT_GET_CLUSTERS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4205981
CLCTL_RELOAD_AUTOLOGGER_CONFIG: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 11730
CLCTL_STORAGE_RENAME_SHARED_VOLUME: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 11734
CLCTL_STORAGE_RENAME_SHARED_VOLUME_GUID: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 11738
CLCTL_ENUM_AFFINITY_RULE_NAMES: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 11741
CLCTL_GET_NODES_IN_FD: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 11745
CLCTL_FORCE_DB_FLUSH: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 4206054
CLCTL_DELETE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242886
CLCTL_INSTALL_NODE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242890
CLCTL_EVICT_NODE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242894
CLCTL_ADD_DEPENDENCY: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242898
CLCTL_REMOVE_DEPENDENCY: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242902
CLCTL_ADD_OWNER: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242906
CLCTL_REMOVE_OWNER: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242910
CLCTL_SET_NAME: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242918
CLCTL_CLUSTER_NAME_CHANGED: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242922
CLCTL_CLUSTER_VERSION_CHANGED: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242926
CLCTL_FIXUP_ON_UPGRADE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242930
CLCTL_STARTING_PHASE1: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242934
CLCTL_STARTING_PHASE2: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242938
CLCTL_HOLD_IO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242942
CLCTL_RESUME_IO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242946
CLCTL_FORCE_QUORUM: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242950
CLCTL_INITIALIZE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242954
CLCTL_STATE_CHANGE_REASON: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242958
CLCTL_PROVIDER_STATE_CHANGE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242962
CLCTL_LEAVING_GROUP: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242966
CLCTL_JOINING_GROUP: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242970
CLCTL_FSWITNESS_GET_EPOCH_INFO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 1048669
CLCTL_FSWITNESS_SET_EPOCH_INFO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242978
CLCTL_FSWITNESS_RELEASE_LOCK: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242982
CLCTL_NETNAME_CREDS_NOTIFYCAM: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5242986
CLCTL_NOTIFY_QUORUM_STATUS: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5243006
CLCTL_NOTIFY_MONITOR_SHUTTING_DOWN: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 1048705
CLCTL_UNDELETE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5243014
CLCTL_GET_OPERATION_CONTEXT: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 1057001
CLCTL_NOTIFY_OWNER_CHANGE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 5251362
CLCTL_VALIDATE_CHANGE_GROUP: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 1057061
CLCTL_CHECK_DRAIN_VETO: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 1057069
CLCTL_NOTIFY_DRAIN_COMPLETE: win32more.Windows.Win32.Networking.Clustering.CLCTL_CODES = 1057073
class CLRES_CALLBACK_FUNCTION_TABLE(Structure):
    LogEvent: win32more.Windows.Win32.Networking.Clustering.PLOG_EVENT_ROUTINE
    SetResourceStatusEx: win32more.Windows.Win32.Networking.Clustering.PSET_RESOURCE_STATUS_ROUTINE_EX
    SetResourceLockedMode: win32more.Windows.Win32.Networking.Clustering.PSET_RESOURCE_LOCKED_MODE_ROUTINE
    SignalFailure: win32more.Windows.Win32.Networking.Clustering.PSIGNAL_FAILURE_ROUTINE
    SetResourceInMemoryNodeLocalProperties: win32more.Windows.Win32.Networking.Clustering.PSET_RESOURCE_INMEMORY_NODELOCAL_PROPERTIES_ROUTINE
    EndControlCall: win32more.Windows.Win32.Networking.Clustering.PEND_CONTROL_CALL
    EndTypeControlCall: win32more.Windows.Win32.Networking.Clustering.PEND_TYPE_CONTROL_CALL
    ExtendControlCall: win32more.Windows.Win32.Networking.Clustering.PEXTEND_RES_CONTROL_CALL
    ExtendTypeControlCall: win32more.Windows.Win32.Networking.Clustering.PEXTEND_RES_TYPE_CONTROL_CALL
    RaiseResTypeNotification: win32more.Windows.Win32.Networking.Clustering.PRAISE_RES_TYPE_NOTIFICATION
    ChangeResourceProcessForDumps: win32more.Windows.Win32.Networking.Clustering.PCHANGE_RESOURCE_PROCESS_FOR_DUMPS
    ChangeResTypeProcessForDumps: win32more.Windows.Win32.Networking.Clustering.PCHANGE_RES_TYPE_PROCESS_FOR_DUMPS
    SetInternalState: win32more.Windows.Win32.Networking.Clustering.PSET_INTERNAL_STATE
    SetResourceLockedModeEx: win32more.Windows.Win32.Networking.Clustering.PSET_RESOURCE_LOCKED_MODE_EX_ROUTINE
    RequestDump: win32more.Windows.Win32.Networking.Clustering.PREQUEST_DUMP_ROUTINE
    SetResourceWprPolicy: win32more.Windows.Win32.Networking.Clustering.PSET_RESOURCE_WPR_POLICY_ROUTINE
    ArmWprWatchdogForCurrentResourceCall: win32more.Windows.Win32.Networking.Clustering.PARM_WPR_WATCHDOG_FOR_CURRENT_RESOURCE_CALL_ROUTINE
class CLRES_FUNCTION_TABLE(Structure):
    TableSize: UInt32
    Version: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        V1Functions: win32more.Windows.Win32.Networking.Clustering.CLRES_V1_FUNCTIONS
        V2Functions: win32more.Windows.Win32.Networking.Clustering.CLRES_V2_FUNCTIONS
        V3Functions: win32more.Windows.Win32.Networking.Clustering.CLRES_V3_FUNCTIONS
        V4Functions: win32more.Windows.Win32.Networking.Clustering.CLRES_V4_FUNCTIONS
class CLRES_V1_FUNCTIONS(Structure):
    Open: win32more.Windows.Win32.Networking.Clustering.POPEN_ROUTINE
    Close: win32more.Windows.Win32.Networking.Clustering.PCLOSE_ROUTINE
    Online: win32more.Windows.Win32.Networking.Clustering.PONLINE_ROUTINE
    Offline: win32more.Windows.Win32.Networking.Clustering.POFFLINE_ROUTINE
    Terminate: win32more.Windows.Win32.Networking.Clustering.PTERMINATE_ROUTINE
    LooksAlive: win32more.Windows.Win32.Networking.Clustering.PLOOKS_ALIVE_ROUTINE
    IsAlive: win32more.Windows.Win32.Networking.Clustering.PIS_ALIVE_ROUTINE
    Arbitrate: win32more.Windows.Win32.Networking.Clustering.PARBITRATE_ROUTINE
    Release: win32more.Windows.Win32.Networking.Clustering.PRELEASE_ROUTINE
    ResourceControl: win32more.Windows.Win32.Networking.Clustering.PRESOURCE_CONTROL_ROUTINE
    ResourceTypeControl: win32more.Windows.Win32.Networking.Clustering.PRESOURCE_TYPE_CONTROL_ROUTINE
class CLRES_V2_FUNCTIONS(Structure):
    Open: win32more.Windows.Win32.Networking.Clustering.POPEN_V2_ROUTINE
    Close: win32more.Windows.Win32.Networking.Clustering.PCLOSE_ROUTINE
    Online: win32more.Windows.Win32.Networking.Clustering.PONLINE_V2_ROUTINE
    Offline: win32more.Windows.Win32.Networking.Clustering.POFFLINE_V2_ROUTINE
    Terminate: win32more.Windows.Win32.Networking.Clustering.PTERMINATE_ROUTINE
    LooksAlive: win32more.Windows.Win32.Networking.Clustering.PLOOKS_ALIVE_ROUTINE
    IsAlive: win32more.Windows.Win32.Networking.Clustering.PIS_ALIVE_ROUTINE
    Arbitrate: win32more.Windows.Win32.Networking.Clustering.PARBITRATE_ROUTINE
    Release: win32more.Windows.Win32.Networking.Clustering.PRELEASE_ROUTINE
    ResourceControl: win32more.Windows.Win32.Networking.Clustering.PRESOURCE_CONTROL_ROUTINE
    ResourceTypeControl: win32more.Windows.Win32.Networking.Clustering.PRESOURCE_TYPE_CONTROL_ROUTINE
    Cancel: win32more.Windows.Win32.Networking.Clustering.PCANCEL_ROUTINE
class CLRES_V3_FUNCTIONS(Structure):
    Open: win32more.Windows.Win32.Networking.Clustering.POPEN_V2_ROUTINE
    Close: win32more.Windows.Win32.Networking.Clustering.PCLOSE_ROUTINE
    Online: win32more.Windows.Win32.Networking.Clustering.PONLINE_V2_ROUTINE
    Offline: win32more.Windows.Win32.Networking.Clustering.POFFLINE_V2_ROUTINE
    Terminate: win32more.Windows.Win32.Networking.Clustering.PTERMINATE_ROUTINE
    LooksAlive: win32more.Windows.Win32.Networking.Clustering.PLOOKS_ALIVE_ROUTINE
    IsAlive: win32more.Windows.Win32.Networking.Clustering.PIS_ALIVE_ROUTINE
    Arbitrate: win32more.Windows.Win32.Networking.Clustering.PARBITRATE_ROUTINE
    Release: win32more.Windows.Win32.Networking.Clustering.PRELEASE_ROUTINE
    BeginResourceControl: win32more.Windows.Win32.Networking.Clustering.PBEGIN_RESCALL_ROUTINE
    BeginResourceTypeControl: win32more.Windows.Win32.Networking.Clustering.PBEGIN_RESTYPECALL_ROUTINE
    Cancel: win32more.Windows.Win32.Networking.Clustering.PCANCEL_ROUTINE
class CLRES_V4_FUNCTIONS(Structure):
    Open: win32more.Windows.Win32.Networking.Clustering.POPEN_V2_ROUTINE
    Close: win32more.Windows.Win32.Networking.Clustering.PCLOSE_ROUTINE
    Online: win32more.Windows.Win32.Networking.Clustering.PONLINE_V2_ROUTINE
    Offline: win32more.Windows.Win32.Networking.Clustering.POFFLINE_V2_ROUTINE
    Terminate: win32more.Windows.Win32.Networking.Clustering.PTERMINATE_ROUTINE
    LooksAlive: win32more.Windows.Win32.Networking.Clustering.PLOOKS_ALIVE_ROUTINE
    IsAlive: win32more.Windows.Win32.Networking.Clustering.PIS_ALIVE_ROUTINE
    Arbitrate: win32more.Windows.Win32.Networking.Clustering.PARBITRATE_ROUTINE
    Release: win32more.Windows.Win32.Networking.Clustering.PRELEASE_ROUTINE
    BeginResourceControl: win32more.Windows.Win32.Networking.Clustering.PBEGIN_RESCALL_ROUTINE
    BeginResourceTypeControl: win32more.Windows.Win32.Networking.Clustering.PBEGIN_RESTYPECALL_ROUTINE
    Cancel: win32more.Windows.Win32.Networking.Clustering.PCANCEL_ROUTINE
    BeginResourceControlAsUser: win32more.Windows.Win32.Networking.Clustering.PBEGIN_RESCALL_AS_USER_ROUTINE
    BeginResourceTypeControlAsUser: win32more.Windows.Win32.Networking.Clustering.PBEGIN_RESTYPECALL_AS_USER_ROUTINE
CLUADMEX_OBJECT_TYPE = Int32
CLUADMEX_OT_NONE: win32more.Windows.Win32.Networking.Clustering.CLUADMEX_OBJECT_TYPE = 0
CLUADMEX_OT_CLUSTER: win32more.Windows.Win32.Networking.Clustering.CLUADMEX_OBJECT_TYPE = 1
CLUADMEX_OT_NODE: win32more.Windows.Win32.Networking.Clustering.CLUADMEX_OBJECT_TYPE = 2
CLUADMEX_OT_GROUP: win32more.Windows.Win32.Networking.Clustering.CLUADMEX_OBJECT_TYPE = 3
CLUADMEX_OT_RESOURCE: win32more.Windows.Win32.Networking.Clustering.CLUADMEX_OBJECT_TYPE = 4
CLUADMEX_OT_RESOURCETYPE: win32more.Windows.Win32.Networking.Clustering.CLUADMEX_OBJECT_TYPE = 5
CLUADMEX_OT_NETWORK: win32more.Windows.Win32.Networking.Clustering.CLUADMEX_OBJECT_TYPE = 6
CLUADMEX_OT_NETINTERFACE: win32more.Windows.Win32.Networking.Clustering.CLUADMEX_OBJECT_TYPE = 7
class CLUSAPI_REASON_HANDLER(Structure):
    lpParameter: VoidPtr
    pfnHandler: win32more.Windows.Win32.Networking.Clustering.PCLUSAPI_PFN_REASON_HANDLER
CLUSCTL_AFFINITYRULE_CODES = Int32
CLUSCTL_AFFINITYRULE_GET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_AFFINITYRULE_CODES = 150995033
CLUSCTL_AFFINITYRULE_GET_RO_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_AFFINITYRULE_CODES = 150995029
CLUSCTL_AFFINITYRULE_SET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_AFFINITYRULE_CODES = 155189342
CLUSCTL_AFFINITYRULE_GET_ID: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_AFFINITYRULE_CODES = 150995001
CLUSCTL_AFFINITYRULE_GET_GROUPNAMES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_AFFINITYRULE_CODES = 151006577
CLUSCTL_CLUSTER_CODES = Int32
CLUSCTL_CLUSTER_UNKNOWN: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440512
CLUSCTL_CLUSTER_GET_FQDN: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440573
CLUSCTL_CLUSTER_SET_STORAGE_CONFIGURATION: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 121635554
CLUSCTL_CLUSTER_GET_STORAGE_CONFIGURATION: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117441253
CLUSCTL_CLUSTER_GET_STORAGE_CONFIG_ATTRIBUTES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117441257
CLUSCTL_CLUSTER_ENUM_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440593
CLUSCTL_CLUSTER_GET_RO_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440597
CLUSCTL_CLUSTER_GET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440601
CLUSCTL_CLUSTER_SET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 121634910
CLUSCTL_CLUSTER_VALIDATE_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440609
CLUSCTL_CLUSTER_ENUM_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440633
CLUSCTL_CLUSTER_GET_RO_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440637
CLUSCTL_CLUSTER_GET_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440641
CLUSCTL_CLUSTER_SET_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 121634950
CLUSCTL_CLUSTER_VALIDATE_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440649
CLUSCTL_CLUSTER_GET_COMMON_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440613
CLUSCTL_CLUSTER_GET_PRIVATE_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440653
CLUSCTL_CLUSTER_CHECK_VOTER_EVICT: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440581
CLUSCTL_CLUSTER_CHECK_VOTER_DOWN: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440585
CLUSCTL_CLUSTER_SHUTDOWN: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440589
CLUSCTL_CLUSTER_BATCH_BLOCK_KEY: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117441086
CLUSCTL_CLUSTER_BATCH_UNBLOCK_KEY: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117441089
CLUSCTL_CLUSTER_GET_SHARED_VOLUME_ID: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117441169
CLUSCTL_CLUSTER_GET_CLUSDB_TIMESTAMP: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117441193
CLUSCTL_CLUSTER_GET_GUM_LOCK_OWNER: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117441209
CLUSCTL_CLUSTER_REMOVE_NODE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 121635566
CLUSCTL_CLUSTER_SET_ACCOUNT_ACCESS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 121635058
CLUSCTL_CLUSTER_CLEAR_NODE_CONNECTION_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 121635590
CLUSCTL_CLUSTER_SET_DNS_DOMAIN: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 121635594
CLUSCTL_CLUSTER_SET_CLUSTER_S2D_ENABLED: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 121646434
CLUSCTL_CLUSTER_SET_CLUSTER_S2D_CACHE_METADATA_RESERVE_BYTES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 121646446
CLUSCTL_CLUSTER_STORAGE_RENAME_SHARED_VOLUME: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117452246
CLUSCTL_CLUSTER_STORAGE_RENAME_SHARED_VOLUME_GUID: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117452250
CLUSCTL_CLUSTER_RELOAD_AUTOLOGGER_CONFIG: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117452242
CLUSCTL_CLUSTER_ENUM_AFFINITY_RULE_NAMES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117452253
CLUSCTL_CLUSTER_GET_NODES_IN_FD: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117452257
CLUSCTL_CLUSTER_FORCE_FLUSH_DB: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 121646566
CLUSCTL_CLUSTER_GET_CLMUSR_TOKEN: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440877
CLUSCTL_CLUSTER_CHECK_VOTER_EVICT_WITNESS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440621
CLUSCTL_CLUSTER_CHECK_VOTER_DOWN_WITNESS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_CLUSTER_CODES = 117440625
CLUSCTL_GROUPSET_CODES = Int32
CLUSCTL_GROUPSET_GET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUPSET_CODES = 134217817
CLUSCTL_GROUPSET_GET_RO_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUPSET_CODES = 134217813
CLUSCTL_GROUPSET_SET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUPSET_CODES = 138412126
CLUSCTL_GROUPSET_GET_GROUPS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUPSET_CODES = 134229361
CLUSCTL_GROUPSET_GET_PROVIDER_GROUPS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUPSET_CODES = 134229365
CLUSCTL_GROUPSET_GET_PROVIDER_GROUPSETS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUPSET_CODES = 134229369
CLUSCTL_GROUP_GET_PROVIDER_GROUPS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUPSET_CODES = 134229373
CLUSCTL_GROUP_GET_PROVIDER_GROUPSETS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUPSET_CODES = 134229377
CLUSCTL_GROUPSET_GET_ID: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUPSET_CODES = 134217785
CLUSCTL_GROUP_CODES = Int32
CLUSCTL_GROUP_UNKNOWN: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50331648
CLUSCTL_GROUP_GET_CHARACTERISTICS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50331653
CLUSCTL_GROUP_GET_FLAGS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50331657
CLUSCTL_GROUP_GET_NAME: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50331689
CLUSCTL_GROUP_GET_ID: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50331705
CLUSCTL_GROUP_ENUM_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50331729
CLUSCTL_GROUP_GET_RO_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50331733
CLUSCTL_GROUP_GET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50331737
CLUSCTL_GROUP_SET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 54526046
CLUSCTL_GROUP_VALIDATE_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50331745
CLUSCTL_GROUP_ENUM_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50331769
CLUSCTL_GROUP_GET_RO_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50331773
CLUSCTL_GROUP_GET_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50331777
CLUSCTL_GROUP_SET_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 54526086
CLUSCTL_GROUP_VALIDATE_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50331785
CLUSCTL_GROUP_QUERY_DELETE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50332089
CLUSCTL_GROUP_GET_COMMON_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50331749
CLUSCTL_GROUP_GET_PRIVATE_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50331789
CLUSCTL_GROUP_GET_FAILURE_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50331673
CLUSCTL_GROUP_GET_LAST_MOVE_TIME: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 50332377
CLUSCTL_GROUP_SET_CCF_FROM_MASTER: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_GROUP_CODES = 54537606
class CLUSCTL_GROUP_GET_LAST_MOVE_TIME_OUTPUT(Structure):
    GetTickCount64: UInt64
    GetSystemTime: win32more.Windows.Win32.Foundation.SYSTEMTIME
    NodeId: UInt32
CLUSCTL_NETINTERFACE_CODES = Int32
CLUSCTL_NETINTERFACE_UNKNOWN: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 100663296
CLUSCTL_NETINTERFACE_GET_CHARACTERISTICS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 100663301
CLUSCTL_NETINTERFACE_GET_FLAGS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 100663305
CLUSCTL_NETINTERFACE_GET_NAME: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 100663337
CLUSCTL_NETINTERFACE_GET_ID: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 100663353
CLUSCTL_NETINTERFACE_GET_NODE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 100663345
CLUSCTL_NETINTERFACE_GET_NETWORK: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 100663349
CLUSCTL_NETINTERFACE_ENUM_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 100663377
CLUSCTL_NETINTERFACE_GET_RO_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 100663381
CLUSCTL_NETINTERFACE_GET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 100663385
CLUSCTL_NETINTERFACE_SET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 104857694
CLUSCTL_NETINTERFACE_VALIDATE_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 100663393
CLUSCTL_NETINTERFACE_ENUM_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 100663417
CLUSCTL_NETINTERFACE_GET_RO_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 100663421
CLUSCTL_NETINTERFACE_GET_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 100663425
CLUSCTL_NETINTERFACE_SET_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 104857734
CLUSCTL_NETINTERFACE_VALIDATE_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 100663433
CLUSCTL_NETINTERFACE_GET_COMMON_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 100663397
CLUSCTL_NETINTERFACE_GET_PRIVATE_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETINTERFACE_CODES = 100663437
CLUSCTL_NETWORK_CODES = Int32
CLUSCTL_NETWORK_UNKNOWN: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETWORK_CODES = 83886080
CLUSCTL_NETWORK_GET_CHARACTERISTICS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETWORK_CODES = 83886085
CLUSCTL_NETWORK_GET_FLAGS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETWORK_CODES = 83886089
CLUSCTL_NETWORK_GET_NAME: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETWORK_CODES = 83886121
CLUSCTL_NETWORK_GET_ID: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETWORK_CODES = 83886137
CLUSCTL_NETWORK_ENUM_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETWORK_CODES = 83886161
CLUSCTL_NETWORK_GET_RO_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETWORK_CODES = 83886165
CLUSCTL_NETWORK_GET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETWORK_CODES = 83886169
CLUSCTL_NETWORK_SET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETWORK_CODES = 88080478
CLUSCTL_NETWORK_VALIDATE_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETWORK_CODES = 83886177
CLUSCTL_NETWORK_ENUM_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETWORK_CODES = 83886201
CLUSCTL_NETWORK_GET_RO_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETWORK_CODES = 83886205
CLUSCTL_NETWORK_GET_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETWORK_CODES = 83886209
CLUSCTL_NETWORK_SET_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETWORK_CODES = 88080518
CLUSCTL_NETWORK_VALIDATE_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETWORK_CODES = 83886217
CLUSCTL_NETWORK_GET_COMMON_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETWORK_CODES = 83886181
CLUSCTL_NETWORK_GET_PRIVATE_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NETWORK_CODES = 83886221
CLUSCTL_NODE_CODES = Int32
CLUSCTL_NODE_UNKNOWN: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67108864
CLUSCTL_NODE_GET_CHARACTERISTICS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67108869
CLUSCTL_NODE_GET_FLAGS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67108873
CLUSCTL_NODE_GET_NAME: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67108905
CLUSCTL_NODE_GET_ID: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67108921
CLUSCTL_NODE_ENUM_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67108945
CLUSCTL_NODE_GET_RO_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67108949
CLUSCTL_NODE_GET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67108953
CLUSCTL_NODE_SET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 71303262
CLUSCTL_NODE_VALIDATE_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67108961
CLUSCTL_NODE_ENUM_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67108985
CLUSCTL_NODE_GET_RO_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67108989
CLUSCTL_NODE_GET_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67108993
CLUSCTL_NODE_SET_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 71303302
CLUSCTL_NODE_VALIDATE_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67109001
CLUSCTL_NODE_GET_COMMON_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67108965
CLUSCTL_NODE_GET_PRIVATE_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67109005
CLUSCTL_NODE_GET_CLUSTER_SERVICE_ACCOUNT_NAME: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67108929
CLUSCTL_NODE_GET_STUCK_NODES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67109565
CLUSCTL_NODE_INJECT_GEM_FAULT: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67109569
CLUSCTL_NODE_INTRODUCE_GEM_REPAIR_DELAY: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67109573
CLUSCTL_NODE_SEND_DUMMY_GEM_MESSAGES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67109577
CLUSCTL_NODE_BLOCK_GEM_SEND_RECV: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67109581
CLUSCTL_NODE_GET_GEMID_VECTOR: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_NODE_CODES = 67109585
CLUSCTL_RESOURCE_CODES = Int32
CLUSCTL_RESOURCE_UNKNOWN: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777216
CLUSCTL_RESOURCE_GET_CHARACTERISTICS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777221
CLUSCTL_RESOURCE_GET_FLAGS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777225
CLUSCTL_RESOURCE_GET_CLASS_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777229
CLUSCTL_RESOURCE_GET_REQUIRED_DEPENDENCIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777233
CLUSCTL_RESOURCE_GET_NAME: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777257
CLUSCTL_RESOURCE_GET_ID: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777273
CLUSCTL_RESOURCE_GET_RESOURCE_TYPE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777261
CLUSCTL_RESOURCE_ENUM_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777297
CLUSCTL_RESOURCE_GET_RO_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777301
CLUSCTL_RESOURCE_GET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777305
CLUSCTL_RESOURCE_SET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20971614
CLUSCTL_RESOURCE_VALIDATE_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777313
CLUSCTL_RESOURCE_GET_COMMON_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777317
CLUSCTL_RESOURCE_ENUM_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777337
CLUSCTL_RESOURCE_GET_RO_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777341
CLUSCTL_RESOURCE_GET_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777345
CLUSCTL_RESOURCE_SET_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20971654
CLUSCTL_RESOURCE_VALIDATE_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777353
CLUSCTL_RESOURCE_GET_PRIVATE_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777357
CLUSCTL_RESOURCE_ADD_REGISTRY_CHECKPOINT: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20971682
CLUSCTL_RESOURCE_DELETE_REGISTRY_CHECKPOINT: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20971686
CLUSCTL_RESOURCE_GET_REGISTRY_CHECKPOINTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777385
CLUSCTL_RESOURCE_ADD_CRYPTO_CHECKPOINT: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20971694
CLUSCTL_RESOURCE_DELETE_CRYPTO_CHECKPOINT: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20971698
CLUSCTL_RESOURCE_ADD_CRYPTO_CHECKPOINT_EX: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20972246
CLUSCTL_RESOURCE_GET_CRYPTO_CHECKPOINTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777397
CLUSCTL_RESOURCE_GET_LOADBAL_PROCESS_LIST: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777417
CLUSCTL_RESOURCE_GET_NETWORK_NAME: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777577
CLUSCTL_RESOURCE_NETNAME_GET_VIRTUAL_SERVER_TOKEN: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777581
CLUSCTL_RESOURCE_NETNAME_SET_PWD_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777594
CLUSCTL_RESOURCE_NETNAME_SET_PWD_INFOEX: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16778010
CLUSCTL_RESOURCE_NETNAME_DELETE_CO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777598
CLUSCTL_RESOURCE_NETNAME_VALIDATE_VCO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777601
CLUSCTL_RESOURCE_NETNAME_RESET_VCO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777605
CLUSCTL_RESOURCE_NETNAME_REPAIR_VCO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777613
CLUSCTL_RESOURCE_NETNAME_REGISTER_DNS_RECORDS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777586
CLUSCTL_RESOURCE_GET_DNS_NAME: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777589
CLUSCTL_RESOURCE_STORAGE_GET_DISK_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777617
CLUSCTL_RESOURCE_STORAGE_GET_DISK_NUMBER_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777633
CLUSCTL_RESOURCE_STORAGE_IS_PATH_VALID: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777625
CLUSCTL_RESOURCE_QUERY_DELETE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777657
CLUSCTL_RESOURCE_UPGRADE_DLL: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20971706
CLUSCTL_RESOURCE_IPADDRESS_RENEW_LEASE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20971966
CLUSCTL_RESOURCE_IPADDRESS_RELEASE_LEASE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20971970
CLUSCTL_RESOURCE_ADD_REGISTRY_CHECKPOINT_64BIT: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20971710
CLUSCTL_RESOURCE_ADD_REGISTRY_CHECKPOINT_32BIT: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20971714
CLUSCTL_RESOURCE_QUERY_MAINTENANCE_MODE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777697
CLUSCTL_RESOURCE_SET_MAINTENANCE_MODE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20972006
CLUSCTL_RESOURCE_STORAGE_SET_DRIVELETTER: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20972010
CLUSCTL_RESOURCE_STORAGE_GET_DISK_INFO_EX: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777713
CLUSCTL_RESOURCE_STORAGE_GET_DISK_INFO_EX2: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777721
CLUSCTL_RESOURCE_STORAGE_GET_MOUNTPOINTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777745
CLUSCTL_RESOURCE_STORAGE_GET_DIRTY: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777753
CLUSCTL_RESOURCE_STORAGE_GET_SHARED_VOLUME_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777765
CLUSCTL_RESOURCE_SET_CSV_MAINTENANCE_MODE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20972182
CLUSCTL_RESOURCE_ENABLE_SHARED_VOLUME_DIRECTIO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20972170
CLUSCTL_RESOURCE_DISABLE_SHARED_VOLUME_DIRECTIO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20972174
CLUSCTL_RESOURCE_SET_SHARED_VOLUME_BACKUP_MODE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20972186
CLUSCTL_RESOURCE_STORAGE_GET_SHARED_VOLUME_PARTITION_NAMES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777885
CLUSCTL_RESOURCE_GET_FAILURE_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777241
CLUSCTL_RESOURCE_STORAGE_GET_DISKID: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777733
CLUSCTL_RESOURCE_STORAGE_GET_SHARED_VOLUME_STATES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20972194
CLUSCTL_RESOURCE_STORAGE_IS_SHARED_VOLUME: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777893
CLUSCTL_RESOURCE_IS_QUORUM_BLOCKED: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777905
CLUSCTL_RESOURCE_POOL_GET_DRIVE_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777909
CLUSCTL_RESOURCE_RLUA_GET_VIRTUAL_SERVER_TOKEN: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777581
CLUSCTL_RESOURCE_RLUA_SET_PWD_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16777594
CLUSCTL_RESOURCE_RLUA_SET_PWD_INFOEX: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16778010
CLUSCTL_RESOURCE_DELETE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020102
CLUSCTL_RESOURCE_UNDELETE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020230
CLUSCTL_RESOURCE_INSTALL_NODE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020106
CLUSCTL_RESOURCE_EVICT_NODE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020110
CLUSCTL_RESOURCE_ADD_DEPENDENCY: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020114
CLUSCTL_RESOURCE_REMOVE_DEPENDENCY: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020118
CLUSCTL_RESOURCE_ADD_OWNER: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020122
CLUSCTL_RESOURCE_REMOVE_OWNER: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020126
CLUSCTL_RESOURCE_SET_NAME: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020134
CLUSCTL_RESOURCE_CLUSTER_NAME_CHANGED: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020138
CLUSCTL_RESOURCE_CLUSTER_VERSION_CHANGED: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020142
CLUSCTL_RESOURCE_FORCE_QUORUM: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020166
CLUSCTL_RESOURCE_INITIALIZE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020170
CLUSCTL_RESOURCE_STATE_CHANGE_REASON: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020174
CLUSCTL_RESOURCE_PROVIDER_STATE_CHANGE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020178
CLUSCTL_RESOURCE_LEAVING_GROUP: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020182
CLUSCTL_RESOURCE_JOINING_GROUP: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020186
CLUSCTL_RESOURCE_FSWITNESS_GET_EPOCH_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 17825885
CLUSCTL_RESOURCE_FSWITNESS_SET_EPOCH_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020194
CLUSCTL_RESOURCE_FSWITNESS_RELEASE_LOCK: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020198
CLUSCTL_RESOURCE_NETNAME_CREDS_NOTIFYCAM: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020202
CLUSCTL_RESOURCE_GET_OPERATION_CONTEXT: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 17834217
CLUSCTL_RESOURCE_RW_MODIFY_NOOP: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20972206
CLUSCTL_RESOURCE_NOTIFY_QUORUM_STATUS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22020222
CLUSCTL_RESOURCE_NOTIFY_OWNER_CHANGE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 22028578
CLUSCTL_RESOURCE_VALIDATE_CHANGE_GROUP: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 17834277
CLUSCTL_RESOURCE_STORAGE_RENAME_SHARED_VOLUME: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16788950
CLUSCTL_RESOURCE_STORAGE_RENAME_SHARED_VOLUME_GUID: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16788954
CLUSCTL_CLOUD_WITNESS_RESOURCE_UPDATE_TOKEN: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20979942
CLUSCTL_CLOUD_WITNESS_RESOURCE_UPDATE_KEY: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20979958
CLUSCTL_RESOURCE_PREPARE_UPGRADE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20979946
CLUSCTL_RESOURCE_UPGRADE_COMPLETED: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20979950
CLUSCTL_RESOURCE_GET_STATE_CHANGE_TIME: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16788829
CLUSCTL_RESOURCE_GET_INFRASTRUCTURE_SOFS_BUFFER: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16788873
CLUSCTL_RESOURCE_SET_INFRASTRUCTURE_SOFS_BUFFER: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20983182
CLUSCTL_RESOURCE_SCALEOUT_COMMAND: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20983190
CLUSCTL_RESOURCE_SCALEOUT_CONTROL: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20983194
CLUSCTL_RESOURCE_SCALEOUT_GET_CLUSTERS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 20983197
CLUSCTL_RESOURCE_CHECK_DRAIN_VETO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 17834285
CLUSCTL_RESOURCE_NOTIFY_DRAIN_COMPLETE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 17834289
CLUSCTL_RESOURCE_GET_NODES_IN_FD: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_CODES = 16788961
class CLUSCTL_RESOURCE_STATE_CHANGE_REASON_STRUCT(Structure):
    dwSize: UInt32
    dwVersion: UInt32
    eReason: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE_CHANGE_REASON
CLUSCTL_RESOURCE_TYPE_CODES = Int32
CLUSCTL_RESOURCE_TYPE_UNKNOWN: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554432
CLUSCTL_RESOURCE_TYPE_GET_CHARACTERISTICS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554437
CLUSCTL_RESOURCE_TYPE_GET_FLAGS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554441
CLUSCTL_RESOURCE_TYPE_GET_CLASS_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554445
CLUSCTL_RESOURCE_TYPE_GET_REQUIRED_DEPENDENCIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554449
CLUSCTL_RESOURCE_TYPE_GET_ARB_TIMEOUT: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554453
CLUSCTL_RESOURCE_TYPE_ENUM_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554513
CLUSCTL_RESOURCE_TYPE_GET_RO_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554517
CLUSCTL_RESOURCE_TYPE_GET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554521
CLUSCTL_RESOURCE_TYPE_VALIDATE_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554529
CLUSCTL_RESOURCE_TYPE_SET_COMMON_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 37748830
CLUSCTL_RESOURCE_TYPE_GET_COMMON_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554533
CLUSCTL_RESOURCE_TYPE_GET_COMMON_RESOURCE_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554537
CLUSCTL_RESOURCE_TYPE_ENUM_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554553
CLUSCTL_RESOURCE_TYPE_GET_RO_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554557
CLUSCTL_RESOURCE_TYPE_GET_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554561
CLUSCTL_RESOURCE_TYPE_SET_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 37748870
CLUSCTL_RESOURCE_TYPE_VALIDATE_PRIVATE_PROPERTIES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554569
CLUSCTL_RESOURCE_TYPE_GET_PRIVATE_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554573
CLUSCTL_RESOURCE_TYPE_GET_PRIVATE_RESOURCE_PROPERTY_FMTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554577
CLUSCTL_RESOURCE_TYPE_GET_REGISTRY_CHECKPOINTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554601
CLUSCTL_RESOURCE_TYPE_GET_CRYPTO_CHECKPOINTS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554613
CLUSCTL_RESOURCE_TYPE_STORAGE_GET_AVAILABLE_DISKS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554837
CLUSCTL_RESOURCE_TYPE_STORAGE_SYNC_CLUSDISK_DB: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 37749150
CLUSCTL_RESOURCE_TYPE_NETNAME_VALIDATE_NETNAME: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554997
CLUSCTL_RESOURCE_TYPE_NETNAME_GET_OU_FOR_VCO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 37749358
CLUSCTL_RESOURCE_TYPE_GEN_APP_VALIDATE_PATH: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554993
CLUSCTL_RESOURCE_TYPE_GEN_APP_VALIDATE_DIRECTORY: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33555001
CLUSCTL_RESOURCE_TYPE_GEN_SCRIPT_VALIDATE_PATH: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554993
CLUSCTL_RESOURCE_TYPE_QUERY_DELETE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554873
CLUSCTL_RESOURCE_TYPE_STORAGE_GET_DRIVELETTERS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554925
CLUSCTL_RESOURCE_TYPE_STORAGE_GET_AVAILABLE_DISKS_EX: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554933
CLUSCTL_RESOURCE_TYPE_STORAGE_REMAP_DRIVELETTER: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554945
CLUSCTL_RESOURCE_TYPE_STORAGE_GET_DISKID: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554949
CLUSCTL_RESOURCE_TYPE_STORAGE_GET_RESOURCEID: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554989
CLUSCTL_RESOURCE_TYPE_STORAGE_IS_CLUSTERABLE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554953
CLUSCTL_RESOURCE_TYPE_STORAGE_REMOVE_VM_OWNERSHIP: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 37749262
CLUSCTL_RESOURCE_TYPE_STORAGE_IS_CSV_FILE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 16777769
CLUSCTL_RESOURCE_TYPE_WITNESS_VALIDATE_PATH: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33554993
CLUSCTL_RESOURCE_TYPE_INSTALL_NODE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 38797322
CLUSCTL_RESOURCE_TYPE_EVICT_NODE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 38797326
CLUSCTL_RESOURCE_TYPE_CLUSTER_VERSION_CHANGED: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 38797358
CLUSCTL_RESOURCE_TYPE_FIXUP_ON_UPGRADE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 38797362
CLUSCTL_RESOURCE_TYPE_STARTING_PHASE1: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 38797366
CLUSCTL_RESOURCE_TYPE_STARTING_PHASE2: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 38797370
CLUSCTL_RESOURCE_TYPE_HOLD_IO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 38797374
CLUSCTL_RESOURCE_TYPE_RESUME_IO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 38797378
CLUSCTL_RESOURCE_TYPE_STORAGE_GET_AVAILABLE_DISKS_EX2_INT: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33562593
CLUSCTL_RESOURCE_TYPE_REPLICATION_GET_ELIGIBLE_LOGDISKS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33562953
CLUSCTL_RESOURCE_TYPE_REPLICATION_GET_ELIGIBLE_TARGET_DATADISKS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33562957
CLUSCTL_RESOURCE_TYPE_REPLICATION_GET_ELIGIBLE_SOURCE_DATADISKS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33562961
CLUSCTL_RESOURCE_TYPE_REPLICATION_GET_REPLICATED_DISKS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33562965
CLUSCTL_RESOURCE_TYPE_REPLICATION_GET_REPLICA_VOLUMES: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33562969
CLUSCTL_RESOURCE_TYPE_REPLICATION_GET_LOG_VOLUME: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33562973
CLUSCTL_RESOURCE_TYPE_REPLICATION_GET_RESOURCE_GROUP: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33562977
CLUSCTL_RESOURCE_TYPE_REPLICATION_GET_REPLICATED_PARTITION_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33562981
CLUSCTL_RESOURCE_TYPE_REPLICATION_GET_LOG_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33562949
CLUSCTL_RESOURCE_TYPE_REPLICATION_ADD_REPLICATION_GROUP: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33562946
CLUSCTL_CLOUD_WITNESS_RESOURCE_TYPE_VALIDATE_CREDENTIALS: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33562849
CLUSCTL_CLOUD_WITNESS_RESOURCE_TYPE_VALIDATE_CREDENTIALS_WITH_KEY: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 33562865
CLUSCTL_RESOURCE_TYPE_PREPARE_UPGRADE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 37757162
CLUSCTL_RESOURCE_TYPE_UPGRADE_COMPLETED: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 37757166
CLUSCTL_RESOURCE_TYPE_NOTIFY_MONITOR_SHUTTING_DOWN: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 34603137
CLUSCTL_RESOURCE_TYPE_CHECK_DRAIN_VETO: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 34611501
CLUSCTL_RESOURCE_TYPE_NOTIFY_DRAIN_COMPLETE: win32more.Windows.Win32.Networking.Clustering.CLUSCTL_RESOURCE_TYPE_CODES = 34611505
class CLUSCTL_RESOURCE_TYPE_STORAGE_GET_AVAILABLE_DISKS_EX2_INPUT(Structure):
    dwFlags: UInt32
    guidPoolFilter: Guid
CLUSGROUP_TYPE = Int32
ClusGroupTypeCoreCluster: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 1
ClusGroupTypeAvailableStorage: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 2
ClusGroupTypeTemporary: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 3
ClusGroupTypeSharedVolume: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 4
ClusGroupTypeStoragePool: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 5
ClusGroupTypeFileServer: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 100
ClusGroupTypePrintServer: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 101
ClusGroupTypeDhcpServer: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 102
ClusGroupTypeDtc: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 103
ClusGroupTypeMsmq: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 104
ClusGroupTypeWins: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 105
ClusGroupTypeStandAloneDfs: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 106
ClusGroupTypeGenericApplication: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 107
ClusGroupTypeGenericService: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 108
ClusGroupTypeGenericScript: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 109
ClusGroupTypeIScsiNameService: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 110
ClusGroupTypeVirtualMachine: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 111
ClusGroupTypeTsSessionBroker: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 112
ClusGroupTypeIScsiTarget: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 113
ClusGroupTypeScaleoutFileServer: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 114
ClusGroupTypeVMReplicaBroker: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 115
ClusGroupTypeTaskScheduler: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 116
ClusGroupTypeClusterUpdateAgent: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 117
ClusGroupTypeScaleoutCluster: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 118
ClusGroupTypeStorageReplica: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 119
ClusGroupTypeVMReplicaCoordinator: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 120
ClusGroupTypeCrossClusterOrchestrator: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 121
ClusGroupTypeInfrastructureFileServer: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 122
ClusGroupTypeCoreSddc: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 123
ClusGroupTypeUnknown: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE = 9999
class CLUSPROP_BINARY(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_VALUE
    rgb: Byte * 1
class CLUSPROP_BUFFER_HELPER(Union):
    pb: POINTER(Byte)
    pw: POINTER(UInt16)
    pdw: POINTER(UInt32)
    pl: POINTER(Int32)
    psz: win32more.Windows.Win32.Foundation.PWSTR
    pList: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_LIST)
    pSyntax: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_SYNTAX)
    pName: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_SZ)
    pValue: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_VALUE)
    pBinaryValue: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_BINARY)
    pWordValue: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_WORD)
    pDwordValue: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_DWORD)
    pLongValue: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_LONG)
    pULargeIntegerValue: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_ULARGE_INTEGER)
    pLargeIntegerValue: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_LARGE_INTEGER)
    pStringValue: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_SZ)
    pMultiSzValue: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_SZ)
    pSecurityDescriptor: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_SECURITY_DESCRIPTOR)
    pResourceClassValue: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_RESOURCE_CLASS)
    pResourceClassInfoValue: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_RESOURCE_CLASS_INFO)
    pDiskSignatureValue: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_DWORD)
    pScsiAddressValue: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_SCSI_ADDRESS)
    pDiskNumberValue: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_DWORD)
    pPartitionInfoValue: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_PARTITION_INFO)
    pRequiredDependencyValue: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_REQUIRED_DEPENDENCY)
    pPartitionInfoValueEx: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_PARTITION_INFO_EX)
    pPartitionInfoValueEx2: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_PARTITION_INFO_EX2)
    pFileTimeValue: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_FILETIME)
class CLUSPROP_DWORD(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_VALUE
    dw: UInt32
class CLUSPROP_FILETIME(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_VALUE
    ft: win32more.Windows.Win32.Foundation.FILETIME
class CLUSPROP_FTSET_INFO(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_VALUE
    Base2: win32more.Windows.Win32.Networking.Clustering.CLUS_FTSET_INFO
CLUSPROP_IPADDR_ENABLENETBIOS = Int32
CLUSPROP_IPADDR_ENABLENETBIOS_DISABLED: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_IPADDR_ENABLENETBIOS = 0
CLUSPROP_IPADDR_ENABLENETBIOS_ENABLED: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_IPADDR_ENABLENETBIOS = 1
CLUSPROP_IPADDR_ENABLENETBIOS_TRACK_NIC: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_IPADDR_ENABLENETBIOS = 2
class CLUSPROP_LARGE_INTEGER(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_VALUE
    li: Int64
class CLUSPROP_LIST(Structure):
    nPropertyCount: UInt32
    PropertyName: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_SZ
class CLUSPROP_LONG(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_VALUE
    l: Int32
class CLUSPROP_PARTITION_INFO(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_VALUE
    Base2: win32more.Windows.Win32.Networking.Clustering.CLUS_PARTITION_INFO
class CLUSPROP_PARTITION_INFO_EX(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_VALUE
    Base2: win32more.Windows.Win32.Networking.Clustering.CLUS_PARTITION_INFO_EX
class CLUSPROP_PARTITION_INFO_EX2(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_PARTITION_INFO_EX
    Base2: win32more.Windows.Win32.Networking.Clustering.CLUS_PARTITION_INFO_EX2
CLUSPROP_PIFLAGS = Int32
CLUSPROP_PIFLAG_STICKY: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_PIFLAGS = 1
CLUSPROP_PIFLAG_REMOVABLE: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_PIFLAGS = 2
CLUSPROP_PIFLAG_USABLE: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_PIFLAGS = 4
CLUSPROP_PIFLAG_DEFAULT_QUORUM: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_PIFLAGS = 8
CLUSPROP_PIFLAG_USABLE_FOR_CSV: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_PIFLAGS = 16
CLUSPROP_PIFLAG_ENCRYPTION_ENABLED: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_PIFLAGS = 32
CLUSPROP_PIFLAG_RAW: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_PIFLAGS = 64
CLUSPROP_PIFLAG_UNKNOWN: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_PIFLAGS = -2147483648
class CLUSPROP_REQUIRED_DEPENDENCY(Union):
    Value: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_VALUE
    ResClass: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_RESOURCE_CLASS
    ResTypeName: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_SZ
class CLUSPROP_RESOURCE_CLASS(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_VALUE
    rc: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_CLASS
class CLUSPROP_RESOURCE_CLASS_INFO(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_VALUE
    Base2: win32more.Windows.Win32.Networking.Clustering.CLUS_RESOURCE_CLASS_INFO
class CLUSPROP_SCSI_ADDRESS(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_VALUE
    Base2: win32more.Windows.Win32.Networking.Clustering.CLUS_SCSI_ADDRESS
class CLUSPROP_SECURITY_DESCRIPTOR(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_VALUE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        sd: win32more.Windows.Win32.Security.SECURITY_DESCRIPTOR_RELATIVE
        rgbSecurityDescriptor: Byte * 1
class CLUSPROP_SYNTAX(Union):
    dw: UInt32
    Anonymous: _Anonymous_e__Struct
    class _Anonymous_e__Struct(Structure):
        wFormat: UInt16
        wType: UInt16
class CLUSPROP_SZ(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_VALUE
    sz: Char * 1
class CLUSPROP_ULARGE_INTEGER(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_VALUE
    li: UInt64
class CLUSPROP_VALUE(Structure):
    Syntax: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_SYNTAX
    cbLength: UInt32
class CLUSPROP_WORD(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSPROP_VALUE
    w: UInt16
CLUSTERSET_OBJECT_TYPE = Int32
CLUSTERSET_OBJECT_TYPE_NONE: win32more.Windows.Win32.Networking.Clustering.CLUSTERSET_OBJECT_TYPE = 0
CLUSTERSET_OBJECT_TYPE_MEMBER: win32more.Windows.Win32.Networking.Clustering.CLUSTERSET_OBJECT_TYPE = 1
CLUSTERSET_OBJECT_TYPE_WORKLOAD: win32more.Windows.Win32.Networking.Clustering.CLUSTERSET_OBJECT_TYPE = 2
CLUSTERSET_OBJECT_TYPE_DATABASE: win32more.Windows.Win32.Networking.Clustering.CLUSTERSET_OBJECT_TYPE = 3
class CLUSTERVERSIONINFO(Structure):
    dwVersionInfoSize: UInt32
    MajorVersion: UInt16
    MinorVersion: UInt16
    BuildNumber: UInt16
    szVendorId: Char * 64
    szCSDVersion: Char * 64
    dwClusterHighestVersion: UInt32
    dwClusterLowestVersion: UInt32
    dwFlags: UInt32
    dwReserved: UInt32
class CLUSTERVERSIONINFO_NT4(Structure):
    dwVersionInfoSize: UInt32
    MajorVersion: UInt16
    MinorVersion: UInt16
    BuildNumber: UInt16
    szVendorId: Char * 64
    szCSDVersion: Char * 64
class CLUSTER_AVAILABILITY_SET_CONFIG(Structure):
    dwVersion: UInt32
    dwUpdateDomains: UInt32
    dwFaultDomains: UInt32
    bReserveSpareNode: win32more.Windows.Win32.Foundation.BOOL
class CLUSTER_BATCH_COMMAND(Structure):
    Command: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND
    dwOptions: UInt32
    wzName: win32more.Windows.Win32.Foundation.PWSTR
    lpData: POINTER(Byte)
    cbData: UInt32
CLUSTER_CHANGE = Int32
CLUSTER_CHANGE_NODE_STATE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 1
CLUSTER_CHANGE_NODE_DELETED: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 2
CLUSTER_CHANGE_NODE_ADDED: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 4
CLUSTER_CHANGE_NODE_PROPERTY: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 8
CLUSTER_CHANGE_REGISTRY_NAME: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 16
CLUSTER_CHANGE_REGISTRY_ATTRIBUTES: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 32
CLUSTER_CHANGE_REGISTRY_VALUE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 64
CLUSTER_CHANGE_REGISTRY_SUBTREE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 128
CLUSTER_CHANGE_RESOURCE_STATE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 256
CLUSTER_CHANGE_RESOURCE_DELETED: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 512
CLUSTER_CHANGE_RESOURCE_ADDED: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 1024
CLUSTER_CHANGE_RESOURCE_PROPERTY: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 2048
CLUSTER_CHANGE_GROUP_STATE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 4096
CLUSTER_CHANGE_GROUP_DELETED: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 8192
CLUSTER_CHANGE_GROUP_ADDED: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 16384
CLUSTER_CHANGE_GROUP_PROPERTY: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 32768
CLUSTER_CHANGE_RESOURCE_TYPE_DELETED: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 65536
CLUSTER_CHANGE_RESOURCE_TYPE_ADDED: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 131072
CLUSTER_CHANGE_RESOURCE_TYPE_PROPERTY: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 262144
CLUSTER_CHANGE_CLUSTER_RECONNECT: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 524288
CLUSTER_CHANGE_NETWORK_STATE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 1048576
CLUSTER_CHANGE_NETWORK_DELETED: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 2097152
CLUSTER_CHANGE_NETWORK_ADDED: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 4194304
CLUSTER_CHANGE_NETWORK_PROPERTY: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 8388608
CLUSTER_CHANGE_NETINTERFACE_STATE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 16777216
CLUSTER_CHANGE_NETINTERFACE_DELETED: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 33554432
CLUSTER_CHANGE_NETINTERFACE_ADDED: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 67108864
CLUSTER_CHANGE_NETINTERFACE_PROPERTY: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 134217728
CLUSTER_CHANGE_QUORUM_STATE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 268435456
CLUSTER_CHANGE_CLUSTER_STATE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 536870912
CLUSTER_CHANGE_CLUSTER_PROPERTY: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = 1073741824
CLUSTER_CHANGE_HANDLE_CLOSE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = -2147483648
CLUSTER_CHANGE_ALL: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE = -1
CLUSTER_CHANGE_CLUSTER_V2 = Int32
CLUSTER_CHANGE_CLUSTER_RECONNECT_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_CLUSTER_V2 = 1
CLUSTER_CHANGE_CLUSTER_STATE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_CLUSTER_V2 = 2
CLUSTER_CHANGE_CLUSTER_GROUP_ADDED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_CLUSTER_V2 = 4
CLUSTER_CHANGE_CLUSTER_HANDLE_CLOSE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_CLUSTER_V2 = 8
CLUSTER_CHANGE_CLUSTER_NETWORK_ADDED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_CLUSTER_V2 = 16
CLUSTER_CHANGE_CLUSTER_NODE_ADDED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_CLUSTER_V2 = 32
CLUSTER_CHANGE_CLUSTER_RESOURCE_TYPE_ADDED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_CLUSTER_V2 = 64
CLUSTER_CHANGE_CLUSTER_COMMON_PROPERTY_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_CLUSTER_V2 = 128
CLUSTER_CHANGE_CLUSTER_PRIVATE_PROPERTY_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_CLUSTER_V2 = 256
CLUSTER_CHANGE_CLUSTER_LOST_NOTIFICATIONS_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_CLUSTER_V2 = 512
CLUSTER_CHANGE_CLUSTER_RENAME_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_CLUSTER_V2 = 1024
CLUSTER_CHANGE_CLUSTER_MEMBERSHIP_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_CLUSTER_V2 = 2048
CLUSTER_CHANGE_CLUSTER_UPGRADED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_CLUSTER_V2 = 4096
CLUSTER_CHANGE_CLUSTER_ALL_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_CLUSTER_V2 = 8191
CLUSTER_CHANGE_GROUPSET_V2 = Int32
CLUSTER_CHANGE_GROUPSET_DELETED_v2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUPSET_V2 = 1
CLUSTER_CHANGE_GROUPSET_COMMON_PROPERTY_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUPSET_V2 = 2
CLUSTER_CHANGE_GROUPSET_PRIVATE_PROPERTY_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUPSET_V2 = 4
CLUSTER_CHANGE_GROUPSET_STATE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUPSET_V2 = 8
CLUSTER_CHANGE_GROUPSET_GROUP_ADDED: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUPSET_V2 = 16
CLUSTER_CHANGE_GROUPSET_GROUP_REMOVED: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUPSET_V2 = 32
CLUSTER_CHANGE_GROUPSET_DEPENDENCIES_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUPSET_V2 = 64
CLUSTER_CHANGE_GROUPSET_DEPENDENTS_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUPSET_V2 = 128
CLUSTER_CHANGE_GROUPSET_HANDLE_CLOSE_v2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUPSET_V2 = 256
CLUSTER_CHANGE_GROUPSET_ALL_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUPSET_V2 = 511
CLUSTER_CHANGE_GROUP_V2 = Int32
CLUSTER_CHANGE_GROUP_DELETED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUP_V2 = 1
CLUSTER_CHANGE_GROUP_COMMON_PROPERTY_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUP_V2 = 2
CLUSTER_CHANGE_GROUP_PRIVATE_PROPERTY_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUP_V2 = 4
CLUSTER_CHANGE_GROUP_STATE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUP_V2 = 8
CLUSTER_CHANGE_GROUP_OWNER_NODE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUP_V2 = 16
CLUSTER_CHANGE_GROUP_PREFERRED_OWNERS_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUP_V2 = 32
CLUSTER_CHANGE_GROUP_RESOURCE_ADDED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUP_V2 = 64
CLUSTER_CHANGE_GROUP_RESOURCE_GAINED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUP_V2 = 128
CLUSTER_CHANGE_GROUP_RESOURCE_LOST_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUP_V2 = 256
CLUSTER_CHANGE_GROUP_HANDLE_CLOSE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUP_V2 = 512
CLUSTER_CHANGE_GROUP_ALL_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_GROUP_V2 = 1023
CLUSTER_CHANGE_NETINTERFACE_V2 = Int32
CLUSTER_CHANGE_NETINTERFACE_DELETED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NETINTERFACE_V2 = 1
CLUSTER_CHANGE_NETINTERFACE_COMMON_PROPERTY_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NETINTERFACE_V2 = 2
CLUSTER_CHANGE_NETINTERFACE_PRIVATE_PROPERTY_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NETINTERFACE_V2 = 4
CLUSTER_CHANGE_NETINTERFACE_STATE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NETINTERFACE_V2 = 8
CLUSTER_CHANGE_NETINTERFACE_HANDLE_CLOSE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NETINTERFACE_V2 = 16
CLUSTER_CHANGE_NETINTERFACE_ALL_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NETINTERFACE_V2 = 31
CLUSTER_CHANGE_NETWORK_V2 = Int32
CLUSTER_CHANGE_NETWORK_DELETED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NETWORK_V2 = 1
CLUSTER_CHANGE_NETWORK_COMMON_PROPERTY_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NETWORK_V2 = 2
CLUSTER_CHANGE_NETWORK_PRIVATE_PROPERTY_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NETWORK_V2 = 4
CLUSTER_CHANGE_NETWORK_STATE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NETWORK_V2 = 8
CLUSTER_CHANGE_NETWORK_HANDLE_CLOSE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NETWORK_V2 = 16
CLUSTER_CHANGE_NETWORK_ALL_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NETWORK_V2 = 31
CLUSTER_CHANGE_NODE_UPGRADE_PHASE_V2 = Int32
CLUSTER_CHANGE_UPGRADE_NODE_PREPARE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NODE_UPGRADE_PHASE_V2 = 1
CLUSTER_CHANGE_UPGRADE_NODE_COMMIT: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NODE_UPGRADE_PHASE_V2 = 2
CLUSTER_CHANGE_UPGRADE_NODE_POSTCOMMIT: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NODE_UPGRADE_PHASE_V2 = 4
CLUSTER_CHANGE_UPGRADE_ALL: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NODE_UPGRADE_PHASE_V2 = 7
CLUSTER_CHANGE_NODE_V2 = Int32
CLUSTER_CHANGE_NODE_NETINTERFACE_ADDED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NODE_V2 = 1
CLUSTER_CHANGE_NODE_DELETED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NODE_V2 = 2
CLUSTER_CHANGE_NODE_COMMON_PROPERTY_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NODE_V2 = 4
CLUSTER_CHANGE_NODE_PRIVATE_PROPERTY_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NODE_V2 = 8
CLUSTER_CHANGE_NODE_STATE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NODE_V2 = 16
CLUSTER_CHANGE_NODE_GROUP_GAINED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NODE_V2 = 32
CLUSTER_CHANGE_NODE_GROUP_LOST_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NODE_V2 = 64
CLUSTER_CHANGE_NODE_HANDLE_CLOSE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NODE_V2 = 128
CLUSTER_CHANGE_NODE_ALL_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_NODE_V2 = 255
CLUSTER_CHANGE_QUORUM_V2 = Int32
CLUSTER_CHANGE_QUORUM_STATE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_QUORUM_V2 = 1
CLUSTER_CHANGE_QUORUM_ALL_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_QUORUM_V2 = 1
CLUSTER_CHANGE_REGISTRY_V2 = Int32
CLUSTER_CHANGE_REGISTRY_ATTRIBUTES_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_REGISTRY_V2 = 1
CLUSTER_CHANGE_REGISTRY_NAME_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_REGISTRY_V2 = 2
CLUSTER_CHANGE_REGISTRY_SUBTREE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_REGISTRY_V2 = 4
CLUSTER_CHANGE_REGISTRY_VALUE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_REGISTRY_V2 = 8
CLUSTER_CHANGE_REGISTRY_HANDLE_CLOSE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_REGISTRY_V2 = 16
CLUSTER_CHANGE_REGISTRY_ALL_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_REGISTRY_V2 = 31
CLUSTER_CHANGE_RESOURCE_TYPE_V2 = Int32
CLUSTER_CHANGE_RESOURCE_TYPE_DELETED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_TYPE_V2 = 1
CLUSTER_CHANGE_RESOURCE_TYPE_COMMON_PROPERTY_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_TYPE_V2 = 2
CLUSTER_CHANGE_RESOURCE_TYPE_PRIVATE_PROPERTY_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_TYPE_V2 = 4
CLUSTER_CHANGE_RESOURCE_TYPE_POSSIBLE_OWNERS_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_TYPE_V2 = 8
CLUSTER_CHANGE_RESOURCE_TYPE_DLL_UPGRADED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_TYPE_V2 = 16
CLUSTER_RESOURCE_TYPE_SPECIFIC_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_TYPE_V2 = 32
CLUSTER_CHANGE_RESOURCE_TYPE_ALL_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_TYPE_V2 = 63
CLUSTER_CHANGE_RESOURCE_V2 = Int32
CLUSTER_CHANGE_RESOURCE_COMMON_PROPERTY_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_V2 = 1
CLUSTER_CHANGE_RESOURCE_PRIVATE_PROPERTY_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_V2 = 2
CLUSTER_CHANGE_RESOURCE_STATE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_V2 = 4
CLUSTER_CHANGE_RESOURCE_OWNER_GROUP_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_V2 = 8
CLUSTER_CHANGE_RESOURCE_DEPENDENCIES_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_V2 = 16
CLUSTER_CHANGE_RESOURCE_DEPENDENTS_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_V2 = 32
CLUSTER_CHANGE_RESOURCE_POSSIBLE_OWNERS_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_V2 = 64
CLUSTER_CHANGE_RESOURCE_DELETED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_V2 = 128
CLUSTER_CHANGE_RESOURCE_DLL_UPGRADED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_V2 = 256
CLUSTER_CHANGE_RESOURCE_HANDLE_CLOSE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_V2 = 512
CLUSTER_CHANGE_RESOURCE_TERMINAL_STATE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_V2 = 1024
CLUSTER_CHANGE_RESOURCE_ALL_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_RESOURCE_V2 = 2047
CLUSTER_CHANGE_SHARED_VOLUME_V2 = Int32
CLUSTER_CHANGE_SHARED_VOLUME_STATE_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_SHARED_VOLUME_V2 = 1
CLUSTER_CHANGE_SHARED_VOLUME_ADDED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_SHARED_VOLUME_V2 = 2
CLUSTER_CHANGE_SHARED_VOLUME_REMOVED_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_SHARED_VOLUME_V2 = 4
CLUSTER_CHANGE_SHARED_VOLUME_ALL_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_SHARED_VOLUME_V2 = 7
CLUSTER_CHANGE_SPACEPORT_V2 = Int32
CLUSTER_CHANGE_SPACEPORT_CUSTOM_PNP_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CHANGE_SPACEPORT_V2 = 1
CLUSTER_CLOUD_TYPE = Int32
CLUSTER_CLOUD_TYPE_NONE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CLOUD_TYPE = 0
CLUSTER_CLOUD_TYPE_AZURE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CLOUD_TYPE = 1
CLUSTER_CLOUD_TYPE_MIXED: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CLOUD_TYPE = 128
CLUSTER_CLOUD_TYPE_UNKNOWN: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CLOUD_TYPE = -1
CLUSTER_CONTROL_OBJECT = Int32
CLUS_OBJECT_INVALID: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CONTROL_OBJECT = 0
CLUS_OBJECT_RESOURCE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CONTROL_OBJECT = 1
CLUS_OBJECT_RESOURCE_TYPE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CONTROL_OBJECT = 2
CLUS_OBJECT_GROUP: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CONTROL_OBJECT = 3
CLUS_OBJECT_NODE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CONTROL_OBJECT = 4
CLUS_OBJECT_NETWORK: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CONTROL_OBJECT = 5
CLUS_OBJECT_NETINTERFACE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CONTROL_OBJECT = 6
CLUS_OBJECT_CLUSTER: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CONTROL_OBJECT = 7
CLUS_OBJECT_GROUPSET: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CONTROL_OBJECT = 8
CLUS_OBJECT_AFFINITYRULE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CONTROL_OBJECT = 9
CLUS_OBJECT_USER: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CONTROL_OBJECT = 128
class CLUSTER_CREATE_GROUP_INFO(Structure):
    dwVersion: UInt32
    groupType: win32more.Windows.Win32.Networking.Clustering.CLUSGROUP_TYPE
CLUSTER_CSV_VOLUME_FAULT_STATE = Int32
VolumeStateNoFaults: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CSV_VOLUME_FAULT_STATE = 0
VolumeStateNoDirectIO: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CSV_VOLUME_FAULT_STATE = 1
VolumeStateNoAccess: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CSV_VOLUME_FAULT_STATE = 2
VolumeStateInMaintenance: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CSV_VOLUME_FAULT_STATE = 4
VolumeStateDismounted: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CSV_VOLUME_FAULT_STATE = 8
CLUSTER_ENUM = Int32
CLUSTER_ENUM_NODE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ENUM = 1
CLUSTER_ENUM_RESTYPE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ENUM = 2
CLUSTER_ENUM_RESOURCE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ENUM = 4
CLUSTER_ENUM_GROUP: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ENUM = 8
CLUSTER_ENUM_NETWORK: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ENUM = 16
CLUSTER_ENUM_NETINTERFACE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ENUM = 32
CLUSTER_ENUM_SHARED_VOLUME_GROUP: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ENUM = 536870912
CLUSTER_ENUM_SHARED_VOLUME_RESOURCE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ENUM = 1073741824
CLUSTER_ENUM_INTERNAL_NETWORK: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ENUM = -2147483648
CLUSTER_ENUM_ALL: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ENUM = 63
class CLUSTER_ENUM_ITEM(Structure):
    dwVersion: UInt32
    dwType: UInt32
    cbId: UInt32
    lpszId: win32more.Windows.Win32.Foundation.PWSTR
    cbName: UInt32
    lpszName: win32more.Windows.Win32.Foundation.PWSTR
CLUSTER_GROUP_AUTOFAILBACK_TYPE = Int32
ClusterGroupPreventFailback: win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_AUTOFAILBACK_TYPE = 0
ClusterGroupAllowFailback: win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_AUTOFAILBACK_TYPE = 1
ClusterGroupFailbackTypeCount: win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_AUTOFAILBACK_TYPE = 2
CLUSTER_GROUP_ENUM = Int32
CLUSTER_GROUP_ENUM_CONTAINS: win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_ENUM = 1
CLUSTER_GROUP_ENUM_NODES: win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_ENUM = 2
CLUSTER_GROUP_ENUM_ALL: win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_ENUM = 3
class CLUSTER_GROUP_ENUM_ITEM(Structure):
    dwVersion: UInt32
    cbId: UInt32
    lpszId: win32more.Windows.Win32.Foundation.PWSTR
    cbName: UInt32
    lpszName: win32more.Windows.Win32.Foundation.PWSTR
    state: win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_STATE
    cbOwnerNode: UInt32
    lpszOwnerNode: win32more.Windows.Win32.Foundation.PWSTR
    dwFlags: UInt32
    cbProperties: UInt32
    pProperties: VoidPtr
    cbRoProperties: UInt32
    pRoProperties: VoidPtr
CLUSTER_GROUP_PRIORITY = Int32
PriorityDisabled: win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_PRIORITY = 0
PriorityLow: win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_PRIORITY = 1000
PriorityMedium: win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_PRIORITY = 2000
PriorityHigh: win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_PRIORITY = 3000
CLUSTER_GROUP_STATE = Int32
ClusterGroupStateUnknown: win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_STATE = -1
ClusterGroupOnline: win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_STATE = 0
ClusterGroupOffline: win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_STATE = 1
ClusterGroupFailed: win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_STATE = 2
ClusterGroupPartialOnline: win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_STATE = 3
ClusterGroupPending: win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_STATE = 4
class CLUSTER_HEALTH_FAULT(Structure):
    Id: win32more.Windows.Win32.Foundation.PWSTR
    ErrorType: UInt32
    ErrorCode: UInt32
    Description: win32more.Windows.Win32.Foundation.PWSTR
    Provider: win32more.Windows.Win32.Foundation.PWSTR
    Flags: UInt32
    Reserved: UInt32
class CLUSTER_HEALTH_FAULT_ARRAY(Structure):
    numFaults: UInt32
    faults: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_HEALTH_FAULT)
class CLUSTER_IP_ENTRY(Structure):
    lpszIpAddress: win32more.Windows.Win32.Foundation.PWSTR
    dwPrefixLength: UInt32
class CLUSTER_MEMBERSHIP_INFO(Structure):
    HasQuorum: win32more.Windows.Win32.Foundation.BOOL
    UpnodesSize: UInt32
    Upnodes: Byte * 1
CLUSTER_MGMT_POINT_RESTYPE = Int32
CLUSTER_MGMT_POINT_RESTYPE_AUTO: win32more.Windows.Win32.Networking.Clustering.CLUSTER_MGMT_POINT_RESTYPE = 0
CLUSTER_MGMT_POINT_RESTYPE_SNN: win32more.Windows.Win32.Networking.Clustering.CLUSTER_MGMT_POINT_RESTYPE = 1
CLUSTER_MGMT_POINT_RESTYPE_DNN: win32more.Windows.Win32.Networking.Clustering.CLUSTER_MGMT_POINT_RESTYPE = 2
CLUSTER_MGMT_POINT_TYPE = Int32
CLUSTER_MGMT_POINT_TYPE_NONE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_MGMT_POINT_TYPE = 0
CLUSTER_MGMT_POINT_TYPE_CNO: win32more.Windows.Win32.Networking.Clustering.CLUSTER_MGMT_POINT_TYPE = 1
CLUSTER_MGMT_POINT_TYPE_DNS_ONLY: win32more.Windows.Win32.Networking.Clustering.CLUSTER_MGMT_POINT_TYPE = 2
CLUSTER_MGMT_POINT_TYPE_CNO_ONLY: win32more.Windows.Win32.Networking.Clustering.CLUSTER_MGMT_POINT_TYPE = 3
CLUSTER_NETINTERFACE_STATE = Int32
ClusterNetInterfaceStateUnknown: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETINTERFACE_STATE = -1
ClusterNetInterfaceUnavailable: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETINTERFACE_STATE = 0
ClusterNetInterfaceFailed: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETINTERFACE_STATE = 1
ClusterNetInterfaceUnreachable: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETINTERFACE_STATE = 2
ClusterNetInterfaceUp: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETINTERFACE_STATE = 3
CLUSTER_NETWORK_ENUM = Int32
CLUSTER_NETWORK_ENUM_NETINTERFACES: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETWORK_ENUM = 1
CLUSTER_NETWORK_ENUM_ALL: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETWORK_ENUM = 1
CLUSTER_NETWORK_ROLE = Int32
ClusterNetworkRoleNone: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETWORK_ROLE = 0
ClusterNetworkRoleInternalUse: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETWORK_ROLE = 1
ClusterNetworkRoleClientAccess: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETWORK_ROLE = 2
ClusterNetworkRoleInternalAndClient: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETWORK_ROLE = 3
CLUSTER_NETWORK_STATE = Int32
ClusterNetworkStateUnknown: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETWORK_STATE = -1
ClusterNetworkUnavailable: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETWORK_STATE = 0
ClusterNetworkDown: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETWORK_STATE = 1
ClusterNetworkPartitioned: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETWORK_STATE = 2
ClusterNetworkUp: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETWORK_STATE = 3
CLUSTER_NODE_DRAIN_STATUS = Int32
NodeDrainStatusNotInitiated: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_DRAIN_STATUS = 0
NodeDrainStatusInProgress: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_DRAIN_STATUS = 1
NodeDrainStatusCompleted: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_DRAIN_STATUS = 2
NodeDrainStatusFailed: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_DRAIN_STATUS = 3
ClusterNodeDrainStatusCount: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_DRAIN_STATUS = 4
CLUSTER_NODE_ENUM = Int32
CLUSTER_NODE_ENUM_NETINTERFACES: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_ENUM = 1
CLUSTER_NODE_ENUM_GROUPS: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_ENUM = 2
CLUSTER_NODE_ENUM_PREFERRED_GROUPS: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_ENUM = 4
CLUSTER_NODE_ENUM_ALL: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_ENUM = 3
CLUSTER_NODE_RESUME_FAILBACK_TYPE = Int32
DoNotFailbackGroups: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_RESUME_FAILBACK_TYPE = 0
FailbackGroupsImmediately: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_RESUME_FAILBACK_TYPE = 1
FailbackGroupsPerPolicy: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_RESUME_FAILBACK_TYPE = 2
ClusterNodeResumeFailbackTypeCount: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_RESUME_FAILBACK_TYPE = 3
CLUSTER_NODE_STATE = Int32
ClusterNodeStateUnknown: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_STATE = -1
ClusterNodeUp: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_STATE = 0
ClusterNodeDown: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_STATE = 1
ClusterNodePaused: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_STATE = 2
ClusterNodeJoining: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_STATE = 3
CLUSTER_NODE_STATUS = Int32
NodeStatusNormal: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_STATUS = 0
NodeStatusIsolated: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_STATUS = 1
NodeStatusQuarantined: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_STATUS = 2
NodeStatusDrainInProgress: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_STATUS = 4
NodeStatusDrainCompleted: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_STATUS = 8
NodeStatusDrainFailed: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_STATUS = 16
NodeStatusAvoidPlacement: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_STATUS = 32
NodeStatusMax: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_STATUS = 51
CLUSTER_NOTIFICATIONS_VERSION = Int32
CLUSTER_NOTIFICATIONS_V1: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NOTIFICATIONS_VERSION = 1
CLUSTER_NOTIFICATIONS_V2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NOTIFICATIONS_VERSION = 2
CLUSTER_OBJECT_TYPE = Int32
CLUSTER_OBJECT_TYPE_NONE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_OBJECT_TYPE = 0
CLUSTER_OBJECT_TYPE_CLUSTER: win32more.Windows.Win32.Networking.Clustering.CLUSTER_OBJECT_TYPE = 1
CLUSTER_OBJECT_TYPE_GROUP: win32more.Windows.Win32.Networking.Clustering.CLUSTER_OBJECT_TYPE = 2
CLUSTER_OBJECT_TYPE_RESOURCE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_OBJECT_TYPE = 3
CLUSTER_OBJECT_TYPE_RESOURCE_TYPE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_OBJECT_TYPE = 4
CLUSTER_OBJECT_TYPE_NETWORK_INTERFACE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_OBJECT_TYPE = 5
CLUSTER_OBJECT_TYPE_NETWORK: win32more.Windows.Win32.Networking.Clustering.CLUSTER_OBJECT_TYPE = 6
CLUSTER_OBJECT_TYPE_NODE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_OBJECT_TYPE = 7
CLUSTER_OBJECT_TYPE_REGISTRY: win32more.Windows.Win32.Networking.Clustering.CLUSTER_OBJECT_TYPE = 8
CLUSTER_OBJECT_TYPE_QUORUM: win32more.Windows.Win32.Networking.Clustering.CLUSTER_OBJECT_TYPE = 9
CLUSTER_OBJECT_TYPE_SHARED_VOLUME: win32more.Windows.Win32.Networking.Clustering.CLUSTER_OBJECT_TYPE = 10
CLUSTER_OBJECT_TYPE_GROUPSET: win32more.Windows.Win32.Networking.Clustering.CLUSTER_OBJECT_TYPE = 13
CLUSTER_OBJECT_TYPE_AFFINITYRULE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_OBJECT_TYPE = 16
CLUSTER_OBJECT_TYPE_FAULTDOMAIN: win32more.Windows.Win32.Networking.Clustering.CLUSTER_OBJECT_TYPE = 17
CLUSTER_PROPERTY_FORMAT = Int32
CLUSPROP_FORMAT_UNKNOWN: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT = 0
CLUSPROP_FORMAT_BINARY: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT = 1
CLUSPROP_FORMAT_DWORD: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT = 2
CLUSPROP_FORMAT_SZ: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT = 3
CLUSPROP_FORMAT_EXPAND_SZ: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT = 4
CLUSPROP_FORMAT_MULTI_SZ: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT = 5
CLUSPROP_FORMAT_ULARGE_INTEGER: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT = 6
CLUSPROP_FORMAT_LONG: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT = 7
CLUSPROP_FORMAT_EXPANDED_SZ: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT = 8
CLUSPROP_FORMAT_SECURITY_DESCRIPTOR: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT = 9
CLUSPROP_FORMAT_LARGE_INTEGER: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT = 10
CLUSPROP_FORMAT_WORD: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT = 11
CLUSPROP_FORMAT_FILETIME: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT = 12
CLUSPROP_FORMAT_VALUE_LIST: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT = 13
CLUSPROP_FORMAT_PROPERTY_LIST: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT = 14
CLUSPROP_FORMAT_USER: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT = 32768
CLUSTER_PROPERTY_SYNTAX = UInt32
CLUSPROP_SYNTAX_ENDMARK: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 0
CLUSPROP_SYNTAX_NAME: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 262147
CLUSPROP_SYNTAX_RESCLASS: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 131074
CLUSPROP_SYNTAX_LIST_VALUE_SZ: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 65539
CLUSPROP_SYNTAX_LIST_VALUE_EXPAND_SZ: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 65540
CLUSPROP_SYNTAX_LIST_VALUE_DWORD: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 65538
CLUSPROP_SYNTAX_LIST_VALUE_BINARY: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 65537
CLUSPROP_SYNTAX_LIST_VALUE_MULTI_SZ: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 65541
CLUSPROP_SYNTAX_LIST_VALUE_LONG: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 65543
CLUSPROP_SYNTAX_LIST_VALUE_EXPANDED_SZ: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 65544
CLUSPROP_SYNTAX_LIST_VALUE_SECURITY_DESCRIPTOR: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 65545
CLUSPROP_SYNTAX_LIST_VALUE_LARGE_INTEGER: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 65546
CLUSPROP_SYNTAX_LIST_VALUE_ULARGE_INTEGER: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 65542
CLUSPROP_SYNTAX_LIST_VALUE_WORD: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 65547
CLUSPROP_SYNTAX_LIST_VALUE_PROPERTY_LIST: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 65550
CLUSPROP_SYNTAX_LIST_VALUE_FILETIME: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 65548
CLUSPROP_SYNTAX_DISK_SIGNATURE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 327682
CLUSPROP_SYNTAX_SCSI_ADDRESS: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 393218
CLUSPROP_SYNTAX_DISK_NUMBER: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 458754
CLUSPROP_SYNTAX_PARTITION_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 524289
CLUSPROP_SYNTAX_FTSET_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 589825
CLUSPROP_SYNTAX_DISK_SERIALNUMBER: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 655363
CLUSPROP_SYNTAX_DISK_GUID: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 720899
CLUSPROP_SYNTAX_DISK_SIZE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 786438
CLUSPROP_SYNTAX_PARTITION_INFO_EX: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 851969
CLUSPROP_SYNTAX_PARTITION_INFO_EX2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 917505
CLUSPROP_SYNTAX_STORAGE_DEVICE_ID_DESCRIPTOR: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_SYNTAX = 983041
CLUSTER_PROPERTY_TYPE = Int32
CLUSPROP_TYPE_UNKNOWN: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = -1
CLUSPROP_TYPE_ENDMARK: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = 0
CLUSPROP_TYPE_LIST_VALUE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = 1
CLUSPROP_TYPE_RESCLASS: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = 2
CLUSPROP_TYPE_RESERVED1: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = 3
CLUSPROP_TYPE_NAME: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = 4
CLUSPROP_TYPE_SIGNATURE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = 5
CLUSPROP_TYPE_SCSI_ADDRESS: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = 6
CLUSPROP_TYPE_DISK_NUMBER: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = 7
CLUSPROP_TYPE_PARTITION_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = 8
CLUSPROP_TYPE_FTSET_INFO: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = 9
CLUSPROP_TYPE_DISK_SERIALNUMBER: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = 10
CLUSPROP_TYPE_DISK_GUID: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = 11
CLUSPROP_TYPE_DISK_SIZE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = 12
CLUSPROP_TYPE_PARTITION_INFO_EX: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = 13
CLUSPROP_TYPE_PARTITION_INFO_EX2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = 14
CLUSPROP_TYPE_STORAGE_DEVICE_ID_DESCRIPTOR: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = 15
CLUSPROP_TYPE_USER: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE = 32768
CLUSTER_QUORUM_TYPE = Int32
OperationalQuorum: win32more.Windows.Win32.Networking.Clustering.CLUSTER_QUORUM_TYPE = 0
ModifyQuorum: win32more.Windows.Win32.Networking.Clustering.CLUSTER_QUORUM_TYPE = 1
CLUSTER_QUORUM_VALUE = Int32
CLUSTER_QUORUM_MAINTAINED: win32more.Windows.Win32.Networking.Clustering.CLUSTER_QUORUM_VALUE = 0
CLUSTER_QUORUM_LOST: win32more.Windows.Win32.Networking.Clustering.CLUSTER_QUORUM_VALUE = 1
class CLUSTER_READ_BATCH_COMMAND(Structure):
    Command: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND
    dwOptions: UInt32
    wzSubkeyName: win32more.Windows.Win32.Foundation.PWSTR
    wzValueName: win32more.Windows.Win32.Foundation.PWSTR
    lpData: POINTER(Byte)
    cbData: UInt32
CLUSTER_REG_COMMAND = Int32
CLUSREG_COMMAND_NONE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 0
CLUSREG_SET_VALUE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 1
CLUSREG_CREATE_KEY: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 2
CLUSREG_DELETE_KEY: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 3
CLUSREG_DELETE_VALUE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 4
CLUSREG_SET_KEY_SECURITY: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 5
CLUSREG_VALUE_DELETED: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 6
CLUSREG_READ_KEY: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 7
CLUSREG_READ_VALUE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 8
CLUSREG_READ_ERROR: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 9
CLUSREG_CONTROL_COMMAND: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 10
CLUSREG_CONDITION_EXISTS: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 11
CLUSREG_CONDITION_NOT_EXISTS: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 12
CLUSREG_CONDITION_IS_EQUAL: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 13
CLUSREG_CONDITION_IS_NOT_EQUAL: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 14
CLUSREG_CONDITION_IS_GREATER_THAN: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 15
CLUSREG_CONDITION_IS_LESS_THAN: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 16
CLUSREG_CONDITION_KEY_EXISTS: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 17
CLUSREG_CONDITION_KEY_NOT_EXISTS: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 18
CLUSREG_LAST_COMMAND: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND = 19
CLUSTER_RESOURCE_APPLICATION_STATE = Int32
ClusterResourceApplicationStateUnknown: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_APPLICATION_STATE = 1
ClusterResourceApplicationOSHeartBeat: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_APPLICATION_STATE = 2
ClusterResourceApplicationReady: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_APPLICATION_STATE = 3
CLUSTER_RESOURCE_CLASS = Int32
CLUS_RESCLASS_UNKNOWN: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_CLASS = 0
CLUS_RESCLASS_STORAGE: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_CLASS = 1
CLUS_RESCLASS_NETWORK: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_CLASS = 2
CLUS_RESCLASS_USER: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_CLASS = 32768
CLUSTER_RESOURCE_CREATE_FLAGS = Int32
CLUSTER_RESOURCE_DEFAULT_MONITOR: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_CREATE_FLAGS = 0
CLUSTER_RESOURCE_SEPARATE_MONITOR: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_CREATE_FLAGS = 1
CLUSTER_RESOURCE_VALID_FLAGS: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_CREATE_FLAGS = 1
CLUSTER_RESOURCE_EMBEDDED_FAILURE_ACTION = Int32
ClusterResourceEmbeddedFailureActionNone: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_EMBEDDED_FAILURE_ACTION = 0
ClusterResourceEmbeddedFailureActionLogOnly: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_EMBEDDED_FAILURE_ACTION = 1
ClusterResourceEmbeddedFailureActionRecover: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_EMBEDDED_FAILURE_ACTION = 2
CLUSTER_RESOURCE_ENUM = Int32
CLUSTER_RESOURCE_ENUM_DEPENDS: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_ENUM = 1
CLUSTER_RESOURCE_ENUM_PROVIDES: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_ENUM = 2
CLUSTER_RESOURCE_ENUM_NODES: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_ENUM = 4
CLUSTER_RESOURCE_ENUM_ALL: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_ENUM = 7
class CLUSTER_RESOURCE_ENUM_ITEM(Structure):
    dwVersion: UInt32
    cbId: UInt32
    lpszId: win32more.Windows.Win32.Foundation.PWSTR
    cbName: UInt32
    lpszName: win32more.Windows.Win32.Foundation.PWSTR
    cbOwnerGroupName: UInt32
    lpszOwnerGroupName: win32more.Windows.Win32.Foundation.PWSTR
    cbOwnerGroupId: UInt32
    lpszOwnerGroupId: win32more.Windows.Win32.Foundation.PWSTR
    cbProperties: UInt32
    pProperties: VoidPtr
    cbRoProperties: UInt32
    pRoProperties: VoidPtr
CLUSTER_RESOURCE_RESTART_ACTION = Int32
ClusterResourceDontRestart: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_RESTART_ACTION = 0
ClusterResourceRestartNoNotify: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_RESTART_ACTION = 1
ClusterResourceRestartNotify: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_RESTART_ACTION = 2
ClusterResourceRestartActionCount: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_RESTART_ACTION = 3
CLUSTER_RESOURCE_STATE = Int32
ClusterResourceStateUnknown: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE = -1
ClusterResourceInherited: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE = 0
ClusterResourceInitializing: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE = 1
ClusterResourceOnline: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE = 2
ClusterResourceOffline: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE = 3
ClusterResourceFailed: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE = 4
ClusterResourcePending: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE = 128
ClusterResourceOnlinePending: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE = 129
ClusterResourceOfflinePending: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE = 130
CLUSTER_RESOURCE_STATE_CHANGE_REASON = Int32
eResourceStateChangeReasonUnknown: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE_CHANGE_REASON = 0
eResourceStateChangeReasonMove: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE_CHANGE_REASON = 1
eResourceStateChangeReasonFailover: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE_CHANGE_REASON = 2
eResourceStateChangeReasonFailedMove: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE_CHANGE_REASON = 3
eResourceStateChangeReasonShutdown: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE_CHANGE_REASON = 4
eResourceStateChangeReasonRundown: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE_CHANGE_REASON = 5
CLUSTER_RESOURCE_TYPE_ENUM = Int32
CLUSTER_RESOURCE_TYPE_ENUM_NODES: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_TYPE_ENUM = 1
CLUSTER_RESOURCE_TYPE_ENUM_RESOURCES: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_TYPE_ENUM = 2
CLUSTER_RESOURCE_TYPE_ENUM_ALL: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_TYPE_ENUM = 3
CLUSTER_ROLE = Int32
ClusterRoleDHCP: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 0
ClusterRoleDTC: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 1
ClusterRoleFileServer: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 2
ClusterRoleGenericApplication: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 3
ClusterRoleGenericScript: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 4
ClusterRoleGenericService: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 5
ClusterRoleISCSINameServer: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 6
ClusterRoleMSMQ: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 7
ClusterRoleNFS: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 8
ClusterRolePrintServer: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 9
ClusterRoleStandAloneNamespaceServer: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 10
ClusterRoleVolumeShadowCopyServiceTask: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 11
ClusterRoleWINS: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 12
ClusterRoleTaskScheduler: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 13
ClusterRoleNetworkFileSystem: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 14
ClusterRoleDFSReplicatedFolder: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 15
ClusterRoleDistributedFileSystem: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 16
ClusterRoleDistributedNetworkName: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 17
ClusterRoleFileShare: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 18
ClusterRoleFileShareWitness: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 19
ClusterRoleHardDisk: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 20
ClusterRoleIPAddress: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 21
ClusterRoleIPV6Address: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 22
ClusterRoleIPV6TunnelAddress: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 23
ClusterRoleISCSITargetServer: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 24
ClusterRoleNetworkName: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 25
ClusterRolePhysicalDisk: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 26
ClusterRoleSODAFileServer: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 27
ClusterRoleStoragePool: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 28
ClusterRoleVirtualMachine: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 29
ClusterRoleVirtualMachineConfiguration: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 30
ClusterRoleVirtualMachineReplicaBroker: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE = 31
CLUSTER_ROLE_STATE = Int32
ClusterRoleUnknown: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE_STATE = -1
ClusterRoleClustered: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE_STATE = 0
ClusterRoleUnclustered: win32more.Windows.Win32.Networking.Clustering.CLUSTER_ROLE_STATE = 1
CLUSTER_SETUP_PHASE = Int32
ClusterSetupPhaseInitialize: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 1
ClusterSetupPhaseValidateNodeState: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 100
ClusterSetupPhaseValidateNetft: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 102
ClusterSetupPhaseValidateClusDisk: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 103
ClusterSetupPhaseConfigureClusSvc: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 104
ClusterSetupPhaseStartingClusSvc: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 105
ClusterSetupPhaseQueryClusterNameAccount: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 106
ClusterSetupPhaseValidateClusterNameAccount: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 107
ClusterSetupPhaseCreateClusterAccount: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 108
ClusterSetupPhaseConfigureClusterAccount: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 109
ClusterSetupPhaseFormingCluster: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 200
ClusterSetupPhaseAddClusterProperties: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 201
ClusterSetupPhaseCreateResourceTypes: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 202
ClusterSetupPhaseCreateGroups: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 203
ClusterSetupPhaseCreateIPAddressResources: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 204
ClusterSetupPhaseCreateNetworkName: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 205
ClusterSetupPhaseClusterGroupOnline: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 206
ClusterSetupPhaseGettingCurrentMembership: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 300
ClusterSetupPhaseAddNodeToCluster: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 301
ClusterSetupPhaseNodeUp: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 302
ClusterSetupPhaseMoveGroup: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 400
ClusterSetupPhaseDeleteGroup: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 401
ClusterSetupPhaseCleanupCOs: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 402
ClusterSetupPhaseOfflineGroup: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 403
ClusterSetupPhaseEvictNode: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 404
ClusterSetupPhaseCleanupNode: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 405
ClusterSetupPhaseCoreGroupCleanup: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 406
ClusterSetupPhaseFailureCleanup: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE = 999
CLUSTER_SETUP_PHASE_SEVERITY = Int32
ClusterSetupPhaseInformational: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE_SEVERITY = 1
ClusterSetupPhaseWarning: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE_SEVERITY = 2
ClusterSetupPhaseFatal: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE_SEVERITY = 3
CLUSTER_SETUP_PHASE_TYPE = Int32
ClusterSetupPhaseStart: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE_TYPE = 1
ClusterSetupPhaseContinue: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE_TYPE = 2
ClusterSetupPhaseEnd: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE_TYPE = 3
ClusterSetupPhaseReport: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE_TYPE = 4
class CLUSTER_SET_PASSWORD_STATUS(Structure):
    NodeId: UInt32
    SetAttempted: win32more.Windows.Win32.Foundation.BOOLEAN
    ReturnStatus: UInt32
CLUSTER_SHARED_VOLUME_BACKUP_STATE = Int32
VolumeBackupNone: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_BACKUP_STATE = 0
VolumeBackupInProgress: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_BACKUP_STATE = 1
class CLUSTER_SHARED_VOLUME_RENAME_GUID_INPUT(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_RENAME_INPUT_VOLUME
    Base2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_RENAME_INPUT_GUID_NAME
class CLUSTER_SHARED_VOLUME_RENAME_INPUT(Structure):
    Base: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_RENAME_INPUT_VOLUME
    Base2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_RENAME_INPUT_NAME
class CLUSTER_SHARED_VOLUME_RENAME_INPUT_GUID_NAME(Structure):
    NewVolumeName: Char * 260
    NewVolumeGuid: Char * 50
class CLUSTER_SHARED_VOLUME_RENAME_INPUT_NAME(Structure):
    NewVolumeName: Char * 260
CLUSTER_SHARED_VOLUME_RENAME_INPUT_TYPE = Int32
ClusterSharedVolumeRenameInputTypeNone: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_RENAME_INPUT_TYPE = 0
ClusterSharedVolumeRenameInputTypeVolumeOffset: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_RENAME_INPUT_TYPE = 1
ClusterSharedVolumeRenameInputTypeVolumeId: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_RENAME_INPUT_TYPE = 2
ClusterSharedVolumeRenameInputTypeVolumeName: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_RENAME_INPUT_TYPE = 3
ClusterSharedVolumeRenameInputTypeVolumeGuid: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_RENAME_INPUT_TYPE = 4
class CLUSTER_SHARED_VOLUME_RENAME_INPUT_VOLUME(Structure):
    InputType: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_RENAME_INPUT_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        VolumeOffset: UInt64
        VolumeId: Char * 260
        VolumeName: Char * 260
        VolumeGuid: Char * 50
CLUSTER_SHARED_VOLUME_SNAPSHOT_STATE = Int32
ClusterSharedVolumeSnapshotStateUnknown: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_SNAPSHOT_STATE = 0
ClusterSharedVolumePrepareForHWSnapshot: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_SNAPSHOT_STATE = 1
ClusterSharedVolumeHWSnapshotCompleted: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_SNAPSHOT_STATE = 2
ClusterSharedVolumePrepareForFreeze: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_SNAPSHOT_STATE = 3
CLUSTER_SHARED_VOLUME_STATE = Int32
SharedVolumeStateUnavailable: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_STATE = 0
SharedVolumeStatePaused: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_STATE = 1
SharedVolumeStateActive: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_STATE = 2
SharedVolumeStateActiveRedirected: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_STATE = 3
SharedVolumeStateActiveVolumeRedirected: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_STATE = 4
class CLUSTER_SHARED_VOLUME_STATE_INFO(Structure):
    szVolumeName: Char * 260
    szNodeName: Char * 260
    VolumeState: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_STATE
class CLUSTER_SHARED_VOLUME_STATE_INFO_EX(Structure):
    szVolumeName: Char * 260
    szNodeName: Char * 260
    VolumeState: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_STATE
    szVolumeFriendlyName: Char * 260
    RedirectedIOReason: UInt64
    VolumeRedirectedIOReason: UInt64
CLUSTER_STORAGENODE_STATE = Int32
ClusterStorageNodeStateUnknown: win32more.Windows.Win32.Networking.Clustering.CLUSTER_STORAGENODE_STATE = 0
ClusterStorageNodeUp: win32more.Windows.Win32.Networking.Clustering.CLUSTER_STORAGENODE_STATE = 1
ClusterStorageNodeDown: win32more.Windows.Win32.Networking.Clustering.CLUSTER_STORAGENODE_STATE = 2
ClusterStorageNodePaused: win32more.Windows.Win32.Networking.Clustering.CLUSTER_STORAGENODE_STATE = 3
ClusterStorageNodeStarting: win32more.Windows.Win32.Networking.Clustering.CLUSTER_STORAGENODE_STATE = 4
ClusterStorageNodeStopping: win32more.Windows.Win32.Networking.Clustering.CLUSTER_STORAGENODE_STATE = 5
CLUSTER_UPGRADE_PHASE = Int32
ClusterUpgradePhaseInitialize: win32more.Windows.Win32.Networking.Clustering.CLUSTER_UPGRADE_PHASE = 1
ClusterUpgradePhaseValidatingUpgrade: win32more.Windows.Win32.Networking.Clustering.CLUSTER_UPGRADE_PHASE = 2
ClusterUpgradePhaseUpgradingComponents: win32more.Windows.Win32.Networking.Clustering.CLUSTER_UPGRADE_PHASE = 3
ClusterUpgradePhaseInstallingNewComponents: win32more.Windows.Win32.Networking.Clustering.CLUSTER_UPGRADE_PHASE = 4
ClusterUpgradePhaseUpgradeComplete: win32more.Windows.Win32.Networking.Clustering.CLUSTER_UPGRADE_PHASE = 5
class CLUSTER_VALIDATE_CSV_FILENAME(Structure):
    szFileName: Char * 1
class CLUSTER_VALIDATE_DIRECTORY(Structure):
    szPath: Char * 1
class CLUSTER_VALIDATE_NETNAME(Structure):
    szNetworkName: Char * 1
class CLUSTER_VALIDATE_PATH(Structure):
    szPath: Char * 1
CLUS_AFFINITY_RULE_TYPE = Int32
CLUS_AFFINITY_RULE_NONE: win32more.Windows.Win32.Networking.Clustering.CLUS_AFFINITY_RULE_TYPE = 0
CLUS_AFFINITY_RULE_SAME_FAULT_DOMAIN: win32more.Windows.Win32.Networking.Clustering.CLUS_AFFINITY_RULE_TYPE = 1
CLUS_AFFINITY_RULE_SAME_NODE: win32more.Windows.Win32.Networking.Clustering.CLUS_AFFINITY_RULE_TYPE = 2
CLUS_AFFINITY_RULE_DIFFERENT_FAULT_DOMAIN: win32more.Windows.Win32.Networking.Clustering.CLUS_AFFINITY_RULE_TYPE = 3
CLUS_AFFINITY_RULE_DIFFERENT_NODE: win32more.Windows.Win32.Networking.Clustering.CLUS_AFFINITY_RULE_TYPE = 4
CLUS_AFFINITY_RULE_MIN: win32more.Windows.Win32.Networking.Clustering.CLUS_AFFINITY_RULE_TYPE = 0
CLUS_AFFINITY_RULE_MAX: win32more.Windows.Win32.Networking.Clustering.CLUS_AFFINITY_RULE_TYPE = 4
CLUS_CHARACTERISTICS = Int32
CLUS_CHAR_UNKNOWN: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 0
CLUS_CHAR_QUORUM: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 1
CLUS_CHAR_DELETE_REQUIRES_ALL_NODES: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 2
CLUS_CHAR_LOCAL_QUORUM: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 4
CLUS_CHAR_LOCAL_QUORUM_DEBUG: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 8
CLUS_CHAR_REQUIRES_STATE_CHANGE_REASON: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 16
CLUS_CHAR_BROADCAST_DELETE: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 32
CLUS_CHAR_SINGLE_CLUSTER_INSTANCE: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 64
CLUS_CHAR_SINGLE_GROUP_INSTANCE: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 128
CLUS_CHAR_COEXIST_IN_SHARED_VOLUME_GROUP: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 256
CLUS_CHAR_PLACEMENT_DATA: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 512
CLUS_CHAR_MONITOR_DETACH: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 1024
CLUS_CHAR_MONITOR_REATTACH: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 2048
CLUS_CHAR_OPERATION_CONTEXT: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 4096
CLUS_CHAR_CLONES: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 8192
CLUS_CHAR_NOT_PREEMPTABLE: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 16384
CLUS_CHAR_NOTIFY_NEW_OWNER: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 32768
CLUS_CHAR_SUPPORTS_UNMONITORED_STATE: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 65536
CLUS_CHAR_INFRASTRUCTURE: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 131072
CLUS_CHAR_VETO_DRAIN: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 262144
CLUS_CHAR_DRAIN_LOCAL_OFFLINE: win32more.Windows.Win32.Networking.Clustering.CLUS_CHARACTERISTICS = 524288
class CLUS_CHKDSK_INFO(Structure):
    PartitionNumber: UInt32
    ChkdskState: UInt32
    FileIdCount: UInt32
    FileIdList: UInt64 * 1
class CLUS_CREATE_INFRASTRUCTURE_FILESERVER_INPUT(Structure):
    FileServerName: Char * 16
class CLUS_CREATE_INFRASTRUCTURE_FILESERVER_OUTPUT(Structure):
    FileServerName: Char * 260
class CLUS_CSV_MAINTENANCE_MODE_INFO(Structure):
    InMaintenance: win32more.Windows.Win32.Foundation.BOOL
    VolumeName: Char * 260
class CLUS_CSV_VOLUME_INFO(Structure):
    VolumeOffset: UInt64
    PartitionNumber: UInt32
    FaultState: win32more.Windows.Win32.Networking.Clustering.CLUSTER_CSV_VOLUME_FAULT_STATE
    BackupState: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_BACKUP_STATE
    szVolumeFriendlyName: Char * 260
    szVolumeName: Char * 50
class CLUS_CSV_VOLUME_NAME(Structure):
    VolumeOffset: Int64
    szVolumeName: Char * 260
    szRootPath: Char * 263
class CLUS_DISK_NUMBER_INFO(Structure):
    DiskNumber: UInt32
    BytesPerSector: UInt32
class CLUS_DNN_LEADER_STATUS(Structure):
    IsOnline: win32more.Windows.Win32.Foundation.BOOL
    IsFileServerPresent: win32more.Windows.Win32.Foundation.BOOL
class CLUS_DNN_SODAFS_CLONE_STATUS(Structure):
    NodeId: UInt32
    Status: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE
CLUS_FLAGS = Int32
CLUS_FLAG_CORE: win32more.Windows.Win32.Networking.Clustering.CLUS_FLAGS = 1
class CLUS_FORCE_QUORUM_INFO(Structure):
    dwSize: UInt32
    dwNodeBitMask: UInt32
    dwMaxNumberofNodes: UInt32
    multiszNodeList: Char * 1
class CLUS_FTSET_INFO(Structure):
    dwRootSignature: UInt32
    dwFtType: UInt32
CLUS_GROUP_START_SETTING = Int32
CLUS_GROUP_START_ALWAYS: win32more.Windows.Win32.Networking.Clustering.CLUS_GROUP_START_SETTING = 0
CLUS_GROUP_DO_NOT_START: win32more.Windows.Win32.Networking.Clustering.CLUS_GROUP_START_SETTING = 1
CLUS_GROUP_START_ALLOWED: win32more.Windows.Win32.Networking.Clustering.CLUS_GROUP_START_SETTING = 2
class CLUS_MAINTENANCE_MODE_INFO(Structure):
    InMaintenance: win32more.Windows.Win32.Foundation.BOOL
class CLUS_MAINTENANCE_MODE_INFOEX(Structure):
    InMaintenance: win32more.Windows.Win32.Foundation.BOOL
    MaintainenceModeType: win32more.Windows.Win32.Networking.Clustering.MAINTENANCE_MODE_TYPE_ENUM
    InternalState: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE
    Signature: UInt32
class CLUS_NETNAME_IP_INFO_ENTRY(Structure):
    NodeId: UInt32
    AddressSize: UInt32
    Address: Byte * 1
class CLUS_NETNAME_IP_INFO_FOR_MULTICHANNEL(Structure):
    szName: Char * 64
    NumEntries: UInt32
    IpInfo: win32more.Windows.Win32.Networking.Clustering.CLUS_NETNAME_IP_INFO_ENTRY * 1
class CLUS_NETNAME_PWD_INFO(Structure):
    Flags: UInt32
    Password: Char * 16
    CreatingDC: Char * 258
    ObjectGuid: Char * 64
class CLUS_NETNAME_PWD_INFOEX(Structure):
    Flags: UInt32
    Password: Char * 128
    CreatingDC: Char * 258
    ObjectGuid: Char * 64
class CLUS_NETNAME_VS_TOKEN_INFO(Structure):
    ProcessID: UInt32
    DesiredAccess: UInt32
    InheritHandle: win32more.Windows.Win32.Foundation.BOOL
class CLUS_PARTITION_INFO(Structure):
    dwFlags: UInt32
    szDeviceName: Char * 260
    szVolumeLabel: Char * 260
    dwSerialNumber: UInt32
    rgdwMaximumComponentLength: UInt32
    dwFileSystemFlags: UInt32
    szFileSystem: Char * 32
class CLUS_PARTITION_INFO_EX(Structure):
    dwFlags: UInt32
    szDeviceName: Char * 260
    szVolumeLabel: Char * 260
    dwSerialNumber: UInt32
    rgdwMaximumComponentLength: UInt32
    dwFileSystemFlags: UInt32
    szFileSystem: Char * 32
    TotalSizeInBytes: UInt64
    FreeSizeInBytes: UInt64
    DeviceNumber: UInt32
    PartitionNumber: UInt32
    VolumeGuid: Guid
class CLUS_PARTITION_INFO_EX2(Structure):
    GptPartitionId: Guid
    szPartitionName: Char * 260
    EncryptionFlags: UInt32
class CLUS_PROVIDER_STATE_CHANGE_INFO(Structure):
    dwSize: UInt32
    resourceState: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE
    szProviderId: Char * 1
class CLUS_RESOURCE_CLASS_INFO(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        li: UInt64
        class _Anonymous_e__Struct(Structure):
            Anonymous: _Anonymous_e__Union
            SubClass: UInt32
            class _Anonymous_e__Union(Union):
                dw: UInt32
                rc: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_CLASS
CLUS_RESSUBCLASS = Int32
CLUS_RESSUBCLASS_SHARED: win32more.Windows.Win32.Networking.Clustering.CLUS_RESSUBCLASS = -2147483648
CLUS_RESSUBCLASS_NETWORK = Int32
CLUS_RESSUBCLASS_NETWORK_INTERNET_PROTOCOL: win32more.Windows.Win32.Networking.Clustering.CLUS_RESSUBCLASS_NETWORK = -2147483648
CLUS_RESSUBCLASS_STORAGE = Int32
CLUS_RESSUBCLASS_STORAGE_SHARED_BUS: win32more.Windows.Win32.Networking.Clustering.CLUS_RESSUBCLASS_STORAGE = -2147483648
CLUS_RESSUBCLASS_STORAGE_DISK: win32more.Windows.Win32.Networking.Clustering.CLUS_RESSUBCLASS_STORAGE = 1073741824
CLUS_RESSUBCLASS_STORAGE_REPLICATION: win32more.Windows.Win32.Networking.Clustering.CLUS_RESSUBCLASS_STORAGE = 268435456
class CLUS_SCSI_ADDRESS(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        dw: UInt32
        class _Anonymous_e__Struct(Structure):
            PortNumber: Byte
            PathId: Byte
            TargetId: Byte
            Lun: Byte
class CLUS_SET_MAINTENANCE_MODE_INPUT(Structure):
    InMaintenance: win32more.Windows.Win32.Foundation.BOOL
    ExtraParameterSize: UInt32
    ExtraParameter: Byte * 1
class CLUS_SHARED_VOLUME_BACKUP_MODE(Structure):
    BackupState: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_BACKUP_STATE
    DelayTimerInSecs: UInt32
    VolumeName: Char * 260
class CLUS_STARTING_PARAMS(Structure):
    dwSize: UInt32
    bForm: win32more.Windows.Win32.Foundation.BOOL
    bFirst: win32more.Windows.Win32.Foundation.BOOL
class CLUS_STORAGE_GET_AVAILABLE_DRIVELETTERS(Structure):
    AvailDrivelettersMask: UInt32
class CLUS_STORAGE_REMAP_DRIVELETTER(Structure):
    CurrentDriveLetterMask: UInt32
    TargetDriveLetterMask: UInt32
class CLUS_STORAGE_SET_DRIVELETTER(Structure):
    PartitionNumber: UInt32
    DriveLetterMask: UInt32
class CLUS_WORKER(Structure):
    hThread: win32more.Windows.Win32.Foundation.HANDLE
    Terminate: win32more.Windows.Win32.Foundation.BOOL
class CREATE_CLUSTER_CONFIG(Structure):
    dwVersion: UInt32
    lpszClusterName: win32more.Windows.Win32.Foundation.PWSTR
    cNodes: UInt32
    ppszNodeNames: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
    cIpEntries: UInt32
    pIpEntries: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_IP_ENTRY)
    fEmptyCluster: win32more.Windows.Win32.Foundation.BOOLEAN
    managementPointType: win32more.Windows.Win32.Networking.Clustering.CLUSTER_MGMT_POINT_TYPE
    managementPointResType: win32more.Windows.Win32.Networking.Clustering.CLUSTER_MGMT_POINT_RESTYPE
class CREATE_CLUSTER_NAME_ACCOUNT(Structure):
    dwVersion: UInt32
    lpszClusterName: win32more.Windows.Win32.Foundation.PWSTR
    dwFlags: UInt32
    pszUserName: win32more.Windows.Win32.Foundation.PWSTR
    pszPassword: win32more.Windows.Win32.Foundation.PWSTR
    pszDomain: win32more.Windows.Win32.Foundation.PWSTR
    managementPointType: win32more.Windows.Win32.Networking.Clustering.CLUSTER_MGMT_POINT_TYPE
    managementPointResType: win32more.Windows.Win32.Networking.Clustering.CLUSTER_MGMT_POINT_RESTYPE
    bUpgradeVCOs: win32more.Windows.Win32.Foundation.BOOLEAN
ClusApplication = Guid('{f2e606e5-2631-11d1-89f1-00a0c90d061e}')
ClusCryptoKeys = Guid('{f2e6072b-2631-11d1-89f1-00a0c90d061e}')
ClusDisk = Guid('{f2e60723-2631-11d1-89f1-00a0c90d061e}')
ClusDisks = Guid('{f2e60725-2631-11d1-89f1-00a0c90d061e}')
ClusNetInterface = Guid('{f2e606ed-2631-11d1-89f1-00a0c90d061e}')
ClusNetInterfaces = Guid('{f2e606ef-2631-11d1-89f1-00a0c90d061e}')
ClusNetwork = Guid('{f2e606f1-2631-11d1-89f1-00a0c90d061e}')
ClusNetworkNetInterfaces = Guid('{f2e606f5-2631-11d1-89f1-00a0c90d061e}')
ClusNetworks = Guid('{f2e606f3-2631-11d1-89f1-00a0c90d061e}')
ClusNode = Guid('{f2e606f7-2631-11d1-89f1-00a0c90d061e}')
ClusNodeNetInterfaces = Guid('{f2e606fb-2631-11d1-89f1-00a0c90d061e}')
ClusNodes = Guid('{f2e606f9-2631-11d1-89f1-00a0c90d061e}')
ClusPartition = Guid('{f2e6071f-2631-11d1-89f1-00a0c90d061e}')
ClusPartitionEx = Guid('{53d51d26-b51b-4a79-b2c3-5048d93a98fc}')
ClusPartitions = Guid('{f2e60721-2631-11d1-89f1-00a0c90d061e}')
ClusProperties = Guid('{f2e606ff-2631-11d1-89f1-00a0c90d061e}')
ClusProperty = Guid('{f2e606fd-2631-11d1-89f1-00a0c90d061e}')
ClusPropertyValue = Guid('{f2e60719-2631-11d1-89f1-00a0c90d061e}')
ClusPropertyValueData = Guid('{f2e6071d-2631-11d1-89f1-00a0c90d061e}')
ClusPropertyValues = Guid('{f2e6071b-2631-11d1-89f1-00a0c90d061e}')
ClusRefObject = Guid('{f2e60701-2631-11d1-89f1-00a0c90d061e}')
ClusRegistryKeys = Guid('{f2e60729-2631-11d1-89f1-00a0c90d061e}')
ClusResDependencies = Guid('{f2e60703-2631-11d1-89f1-00a0c90d061e}')
ClusResDependents = Guid('{f2e6072d-2631-11d1-89f1-00a0c90d061e}')
ClusResGroup = Guid('{f2e60705-2631-11d1-89f1-00a0c90d061e}')
ClusResGroupPreferredOwnerNodes = Guid('{f2e606e7-2631-11d1-89f1-00a0c90d061e}')
ClusResGroupResources = Guid('{f2e606e9-2631-11d1-89f1-00a0c90d061e}')
ClusResGroups = Guid('{f2e60707-2631-11d1-89f1-00a0c90d061e}')
ClusResPossibleOwnerNodes = Guid('{f2e6070d-2631-11d1-89f1-00a0c90d061e}')
ClusResType = Guid('{f2e6070f-2631-11d1-89f1-00a0c90d061e}')
ClusResTypePossibleOwnerNodes = Guid('{f2e60717-2631-11d1-89f1-00a0c90d061e}')
ClusResTypeResources = Guid('{f2e60713-2631-11d1-89f1-00a0c90d061e}')
ClusResTypes = Guid('{f2e60711-2631-11d1-89f1-00a0c90d061e}')
ClusResource = Guid('{f2e60709-2631-11d1-89f1-00a0c90d061e}')
ClusResources = Guid('{f2e6070b-2631-11d1-89f1-00a0c90d061e}')
ClusScsiAddress = Guid('{f2e60727-2631-11d1-89f1-00a0c90d061e}')
ClusVersion = Guid('{f2e60715-2631-11d1-89f1-00a0c90d061e}')
Cluster = Guid('{f2e606e3-2631-11d1-89f1-00a0c90d061e}')
ClusterNames = Guid('{f2e606eb-2631-11d1-89f1-00a0c90d061e}')
DomainNames = Guid('{f2e606e1-2631-11d1-89f1-00a0c90d061e}')
FAILURE_TYPE = Int32
FAILURE_TYPE_GENERAL: win32more.Windows.Win32.Networking.Clustering.FAILURE_TYPE = 0
FAILURE_TYPE_EMBEDDED: win32more.Windows.Win32.Networking.Clustering.FAILURE_TYPE = 1
FAILURE_TYPE_NETWORK_LOSS: win32more.Windows.Win32.Networking.Clustering.FAILURE_TYPE = 2
class FILESHARE_CHANGE(Structure):
    Change: win32more.Windows.Win32.Networking.Clustering.FILESHARE_CHANGE_ENUM
    ShareName: Char * 84
FILESHARE_CHANGE_ENUM = Int32
FILESHARE_CHANGE_NONE: win32more.Windows.Win32.Networking.Clustering.FILESHARE_CHANGE_ENUM = 0
FILESHARE_CHANGE_ADD: win32more.Windows.Win32.Networking.Clustering.FILESHARE_CHANGE_ENUM = 1
FILESHARE_CHANGE_DEL: win32more.Windows.Win32.Networking.Clustering.FILESHARE_CHANGE_ENUM = 2
FILESHARE_CHANGE_MODIFY: win32more.Windows.Win32.Networking.Clustering.FILESHARE_CHANGE_ENUM = 3
class FILESHARE_CHANGE_LIST(Structure):
    NumEntries: UInt32
    ChangeEntry: win32more.Windows.Win32.Networking.Clustering.FILESHARE_CHANGE * 1
class GET_OPERATION_CONTEXT_PARAMS(Structure):
    Size: UInt32
    Version: UInt32
    Type: win32more.Windows.Win32.Networking.Clustering.RESDLL_CONTEXT_OPERATION_TYPE
    Priority: UInt32
class GROUP_FAILURE_INFO(Structure):
    dwFailoverAttemptsRemaining: UInt32
    dwFailoverPeriodRemaining: UInt32
class GROUP_FAILURE_INFO_BUFFER(Structure):
    dwVersion: UInt32
    Info: win32more.Windows.Win32.Networking.Clustering.GROUP_FAILURE_INFO
GRP_PLACEMENT_OPTIONS = Int32
GRP_PLACEMENT_OPTIONS_MIN_VALUE: win32more.Windows.Win32.Networking.Clustering.GRP_PLACEMENT_OPTIONS = 0
GRP_PLACEMENT_OPTIONS_DEFAULT: win32more.Windows.Win32.Networking.Clustering.GRP_PLACEMENT_OPTIONS = 0
GRP_PLACEMENT_OPTIONS_DISABLE_AUTOBALANCING: win32more.Windows.Win32.Networking.Clustering.GRP_PLACEMENT_OPTIONS = 1
GRP_PLACEMENT_OPTIONS_ALL: win32more.Windows.Win32.Networking.Clustering.GRP_PLACEMENT_OPTIONS = 1
HCHANGE = IntPtr
HCLUSCRYPTPROVIDER = IntPtr
HCLUSENUM = IntPtr
HCLUSENUMEX = IntPtr
HCLUSTER = IntPtr
HGROUP = IntPtr
HGROUPENUM = IntPtr
HGROUPENUMEX = IntPtr
HGROUPSET = IntPtr
HGROUPSETENUM = IntPtr
HNETINTERFACE = IntPtr
HNETINTERFACEENUM = IntPtr
HNETWORK = IntPtr
HNETWORKENUM = IntPtr
HNODE = IntPtr
HNODEENUM = IntPtr
HNODEENUMEX = IntPtr
HREGBATCH = IntPtr
HREGBATCHNOTIFICATION = IntPtr
HREGBATCHPORT = IntPtr
HREGREADBATCH = IntPtr
HREGREADBATCHREPLY = IntPtr
HRESENUM = IntPtr
HRESENUMEX = IntPtr
HRESOURCE = IntPtr
HRESTYPEENUM = IntPtr
class IGetClusterDataInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{97dede51-fc6b-11cf-b5f5-00a0c90ab505}')
    @commethod(3)
    def GetClusterName(self, lpszName: win32more.Windows.Win32.Foundation.BSTR, pcchName: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetClusterHandle(self) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
    @commethod(5)
    def GetObjectCount(self) -> Int32: ...
class IGetClusterGroupInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{97dede54-fc6b-11cf-b5f5-00a0c90ab505}')
    @commethod(3)
    def GetGroupHandle(self, lObjIndex: Int32) -> win32more.Windows.Win32.Networking.Clustering.HGROUP: ...
class IGetClusterNetInterfaceInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{97dede57-fc6b-11cf-b5f5-00a0c90ab505}')
    @commethod(3)
    def GetNetInterfaceHandle(self, lObjIndex: Int32) -> win32more.Windows.Win32.Networking.Clustering.HNETINTERFACE: ...
class IGetClusterNetworkInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{97dede56-fc6b-11cf-b5f5-00a0c90ab505}')
    @commethod(3)
    def GetNetworkHandle(self, lObjIndex: Int32) -> win32more.Windows.Win32.Networking.Clustering.HNETWORK: ...
class IGetClusterNodeInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{97dede53-fc6b-11cf-b5f5-00a0c90ab505}')
    @commethod(3)
    def GetNodeHandle(self, lObjIndex: Int32) -> win32more.Windows.Win32.Networking.Clustering.HNODE: ...
class IGetClusterObjectInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{97dede52-fc6b-11cf-b5f5-00a0c90ab505}')
    @commethod(3)
    def GetObjectName(self, lObjIndex: Int32, lpszName: win32more.Windows.Win32.Foundation.BSTR, pcchName: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetObjectType(self, lObjIndex: Int32) -> win32more.Windows.Win32.Networking.Clustering.CLUADMEX_OBJECT_TYPE: ...
class IGetClusterResourceInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{97dede55-fc6b-11cf-b5f5-00a0c90ab505}')
    @commethod(3)
    def GetResourceHandle(self, lObjIndex: Int32) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
    @commethod(4)
    def GetResourceTypeName(self, lObjIndex: Int32, lpszResTypeName: win32more.Windows.Win32.Foundation.BSTR, pcchResTypeName: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetResourceNetworkName(self, lObjIndex: Int32, lpszNetName: win32more.Windows.Win32.Foundation.BSTR, pcchNetName: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
class IGetClusterUIInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{97dede50-fc6b-11cf-b5f5-00a0c90ab505}')
    @commethod(3)
    def GetClusterName(self, lpszName: win32more.Windows.Win32.Foundation.BSTR, pcchName: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetLocale(self) -> UInt32: ...
    @commethod(5)
    def GetFont(self) -> win32more.Windows.Win32.Graphics.Gdi.HFONT: ...
    @commethod(6)
    def GetIcon(self) -> win32more.Windows.Win32.UI.WindowsAndMessaging.HICON: ...
class ISClusApplication(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e606e6-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_DomainNames(self, ppDomains: POINTER(win32more.Windows.Win32.Networking.Clustering.ISDomainNames)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ClusterNames(self, bstrDomainName: win32more.Windows.Win32.Foundation.BSTR, ppClusters: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusterNames)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def OpenCluster(self, bstrClusterName: win32more.Windows.Win32.Foundation.BSTR, pCluster: POINTER(win32more.Windows.Win32.Networking.Clustering.ISCluster)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusCryptoKeys(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e6072c-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, pbstrCyrptoKey: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def AddItem(self, bstrCryptoKey: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def RemoveItem(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusDisk(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e60724-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Signature(self, plSignature: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ScsiAddress(self, ppScsiAddress: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusScsiAddress)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_DiskNumber(self, plDiskNumber: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Partitions(self, ppPartitions: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusPartitions)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusDisks(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e60726-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppDisk: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusDisk)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusNetInterface(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e606ee-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_CommonProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_PrivateProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_CommonROProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_PrivateROProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_Name(self, pbstrName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_Handle(self, phandle: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_State(self, dwState: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETINTERFACE_STATE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_Cluster(self, ppCluster: POINTER(win32more.Windows.Win32.Networking.Clustering.ISCluster)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusNetInterfaces(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e606f0-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppClusNetInterface: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusNetInterface)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusNetwork(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e606f2-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_CommonProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_PrivateProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_CommonROProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_PrivateROProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_Handle(self, phandle: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_Name(self, pbstrName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_Name(self, bstrNetworkName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_NetworkID(self, pbstrNetworkID: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_State(self, dwState: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETWORK_STATE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_NetInterfaces(self, ppClusNetInterfaces: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusNetworkNetInterfaces)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_Cluster(self, ppCluster: POINTER(win32more.Windows.Win32.Networking.Clustering.ISCluster)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusNetworkNetInterfaces(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e606f6-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppClusNetInterface: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusNetInterface)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusNetworks(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e606f4-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppClusNetwork: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusNetwork)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusNode(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e606f8-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_CommonProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_PrivateProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_CommonROProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_PrivateROProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_Name(self, pbstrName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_Handle(self, phandle: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_NodeID(self, pbstrNodeID: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_State(self, dwState: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_STATE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def Pause(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def Resume(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def Evict(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_ResourceGroups(self, ppResourceGroups: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResGroups)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_Cluster(self, ppCluster: POINTER(win32more.Windows.Win32.Networking.Clustering.ISCluster)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_NetInterfaces(self, ppClusNetInterfaces: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusNodeNetInterfaces)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusNodeNetInterfaces(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e606fc-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppClusNetInterface: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusNetInterface)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusNodes(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e606fa-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppNode: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusPartition(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e60720-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Flags(self, plFlags: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_DeviceName(self, pbstrDeviceName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_VolumeLabel(self, pbstrVolumeLabel: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_SerialNumber(self, plSerialNumber: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_MaximumComponentLength(self, plMaximumComponentLength: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_FileSystemFlags(self, plFileSystemFlags: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_FileSystem(self, pbstrFileSystem: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusPartitionEx(ComPtr):
    extends: win32more.Windows.Win32.Networking.Clustering.ISClusPartition
    _iid_ = Guid('{8802d4fe-b32e-4ad1-9dbd-64f18e1166ce}')
    @commethod(14)
    def get_TotalSize(self, plTotalSize: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_FreeSpace(self, plFreeSpace: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_DeviceNumber(self, plDeviceNumber: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_PartitionNumber(self, plPartitionNumber: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_VolumeGuid(self, pbstrVolumeGuid: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusPartitions(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e60722-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppPartition: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusPartition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusProperties(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e60700-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppClusProperty: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperty)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateItem(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, varValue: win32more.Windows.Win32.System.Variant.VARIANT, pProperty: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperty)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def UseDefaultValue(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SaveChanges(self, pvarStatusCode: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_ReadOnly(self, pvarReadOnly: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_Private(self, pvarPrivate: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_Common(self, pvarCommon: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_Modified(self, pvarModified: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusProperty(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e606fe-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Name(self, pbstrName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Length(self, pLength: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_ValueCount(self, pCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Values(self, ppClusterPropertyValues: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusPropertyValues)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_Value(self, pvarValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_Value(self, varValue: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_Type(self, pType: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_Type(self, Type: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_Format(self, pFormat: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_Format(self, Format: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_ReadOnly(self, pvarReadOnly: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_Private(self, pvarPrivate: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_Common(self, pvarCommon: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_Modified(self, pvarModified: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def UseDefaultValue(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusPropertyValue(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e6071a-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Value(self, pvarValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_Value(self, varValue: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Type(self, pType: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_Type(self, Type: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_TYPE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_Format(self, pFormat: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_Format(self, Format: win32more.Windows.Win32.Networking.Clustering.CLUSTER_PROPERTY_FORMAT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_Length(self, pLength: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_DataCount(self, pCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_Data(self, ppClusterPropertyValueData: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusPropertyValueData)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusPropertyValueData(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e6071e-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, pvarValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CreateItem(self, varValue: win32more.Windows.Win32.System.Variant.VARIANT, pvarData: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def RemoveItem(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusPropertyValues(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e6071c-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppPropertyValue: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusPropertyValue)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CreateItem(self, bstrName: win32more.Windows.Win32.Foundation.BSTR, varValue: win32more.Windows.Win32.System.Variant.VARIANT, ppPropertyValue: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusPropertyValue)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def RemoveItem(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusRefObject(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e60702-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Handle(self, phandle: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusRegistryKeys(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e6072a-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, pbstrRegistryKey: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def AddItem(self, bstrRegistryKey: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def RemoveItem(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusResDependencies(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e60704-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppClusResource: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResource)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateItem(self, bstrResourceName: win32more.Windows.Win32.Foundation.BSTR, bstrResourceType: win32more.Windows.Win32.Foundation.BSTR, dwFlags: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_CREATE_FLAGS, ppClusterResource: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResource)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def DeleteItem(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def AddItem(self, pResource: win32more.Windows.Win32.Networking.Clustering.ISClusResource) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def RemoveItem(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusResDependents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e6072e-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppClusResource: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResource)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateItem(self, bstrResourceName: win32more.Windows.Win32.Foundation.BSTR, bstrResourceType: win32more.Windows.Win32.Foundation.BSTR, dwFlags: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_CREATE_FLAGS, ppClusterResource: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResource)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def DeleteItem(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def AddItem(self, pResource: win32more.Windows.Win32.Networking.Clustering.ISClusResource) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def RemoveItem(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusResGroup(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e60706-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_CommonProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_PrivateProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_CommonROProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_PrivateROProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_Handle(self, phandle: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_Name(self, pbstrName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_Name(self, bstrGroupName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_State(self, dwState: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_STATE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_OwnerNode(self, ppOwnerNode: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_Resources(self, ppClusterGroupResources: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResGroupResources)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_PreferredOwnerNodes(self, ppOwnerNodes: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResGroupPreferredOwnerNodes)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def Delete(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def Online(self, varTimeout: win32more.Windows.Win32.System.Variant.VARIANT, varNode: win32more.Windows.Win32.System.Variant.VARIANT, pvarPending: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def Move(self, varTimeout: win32more.Windows.Win32.System.Variant.VARIANT, varNode: win32more.Windows.Win32.System.Variant.VARIANT, pvarPending: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def Offline(self, varTimeout: win32more.Windows.Win32.System.Variant.VARIANT, pvarPending: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_Cluster(self, ppCluster: POINTER(win32more.Windows.Win32.Networking.Clustering.ISCluster)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusResGroupPreferredOwnerNodes(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e606e8-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppNode: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def InsertItem(self, pNode: win32more.Windows.Win32.Networking.Clustering.ISClusNode, nPosition: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def RemoveItem(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_Modified(self, pvarModified: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SaveChanges(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def AddItem(self, pNode: win32more.Windows.Win32.Networking.Clustering.ISClusNode) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusResGroupResources(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e606ea-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppClusResource: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResource)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateItem(self, bstrResourceName: win32more.Windows.Win32.Foundation.BSTR, bstrResourceType: win32more.Windows.Win32.Foundation.BSTR, dwFlags: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_CREATE_FLAGS, ppClusterResource: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResource)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def DeleteItem(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusResGroups(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e60708-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppClusResGroup: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResGroup)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateItem(self, bstrResourceGroupName: win32more.Windows.Win32.Foundation.BSTR, ppResourceGroup: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResGroup)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def DeleteItem(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusResPossibleOwnerNodes(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e6070e-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppNode: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def AddItem(self, pNode: win32more.Windows.Win32.Networking.Clustering.ISClusNode) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def RemoveItem(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_Modified(self, pvarModified: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusResType(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e60710-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_CommonProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_PrivateProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_CommonROProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_PrivateROProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_Name(self, pbstrName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Delete(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_Cluster(self, ppCluster: POINTER(win32more.Windows.Win32.Networking.Clustering.ISCluster)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_Resources(self, ppClusterResTypeResources: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResTypeResources)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_PossibleOwnerNodes(self, ppOwnerNodes: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResTypePossibleOwnerNodes)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_AvailableDisks(self, ppAvailableDisks: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusDisks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusResTypePossibleOwnerNodes(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e60718-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppNode: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusResTypeResources(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e60714-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppClusResource: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResource)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateItem(self, bstrResourceName: win32more.Windows.Win32.Foundation.BSTR, bstrGroupName: win32more.Windows.Win32.Foundation.BSTR, dwFlags: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_CREATE_FLAGS, ppClusterResource: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResource)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def DeleteItem(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusResTypes(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e60712-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppClusResType: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateItem(self, bstrResourceTypeName: win32more.Windows.Win32.Foundation.BSTR, bstrDisplayName: win32more.Windows.Win32.Foundation.BSTR, bstrResourceTypeDll: win32more.Windows.Win32.Foundation.BSTR, dwLooksAlivePollInterval: Int32, dwIsAlivePollInterval: Int32, ppResourceType: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def DeleteItem(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusResource(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e6070a-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_CommonProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_PrivateProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_CommonROProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_PrivateROProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_Handle(self, phandle: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_Name(self, pbstrName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_Name(self, bstrResourceName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_State(self, dwState: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_CoreFlag(self, dwCoreFlag: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUS_FLAGS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def BecomeQuorumResource(self, bstrDevicePath: win32more.Windows.Win32.Foundation.BSTR, lMaxLogSize: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def Delete(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def Fail(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def Online(self, nTimeout: Int32, pvarPending: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def Offline(self, nTimeout: Int32, pvarPending: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def ChangeResourceGroup(self, pResourceGroup: win32more.Windows.Win32.Networking.Clustering.ISClusResGroup) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def AddResourceNode(self, pNode: win32more.Windows.Win32.Networking.Clustering.ISClusNode) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def RemoveResourceNode(self, pNode: win32more.Windows.Win32.Networking.Clustering.ISClusNode) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def CanResourceBeDependent(self, pResource: win32more.Windows.Win32.Networking.Clustering.ISClusResource, pvarDependent: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_PossibleOwnerNodes(self, ppOwnerNodes: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResPossibleOwnerNodes)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_Dependencies(self, ppResDependencies: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResDependencies)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_Dependents(self, ppResDependents: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResDependents)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_Group(self, ppResGroup: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResGroup)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_OwnerNode(self, ppOwnerNode: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_Cluster(self, ppCluster: POINTER(win32more.Windows.Win32.Networking.Clustering.ISCluster)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_ClassInfo(self, prcClassInfo: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_CLASS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_Disk(self, ppDisk: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusDisk)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_RegistryKeys(self, ppRegistryKeys: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusRegistryKeys)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_CryptoKeys(self, ppCryptoKeys: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusCryptoKeys)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_TypeName(self, pbstrTypeName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_Type(self, ppResourceType: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_MaintenanceMode(self, pbMaintenanceMode: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def put_MaintenanceMode(self, bMaintenanceMode: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusResources(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e6070c-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, ppClusResource: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResource)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateItem(self, bstrResourceName: win32more.Windows.Win32.Foundation.BSTR, bstrResourceType: win32more.Windows.Win32.Foundation.BSTR, bstrGroupName: win32more.Windows.Win32.Foundation.BSTR, dwFlags: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_CREATE_FLAGS, ppClusterResource: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResource)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def DeleteItem(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusScsiAddress(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e60728-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_PortNumber(self, pvarPortNumber: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_PathId(self, pvarPathId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_TargetId(self, pvarTargetId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Lun(self, pvarLun: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusVersion(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e60716-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Name(self, pbstrClusterName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_MajorVersion(self, pnMajorVersion: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_MinorVersion(self, pnMinorVersion: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_BuildNumber(self, pnBuildNumber: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_VendorId(self, pbstrVendorId: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_CSDVersion(self, pbstrCSDVersion: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_ClusterHighestVersion(self, pnClusterHighestVersion: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_ClusterLowestVersion(self, pnClusterLowestVersion: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_Flags(self, pnFlags: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_MixedVersion(self, pvarMixedVersion: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISCluster(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e606e4-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_CommonProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_PrivateProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_CommonROProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_PrivateROProperties(self, ppProperties: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusProperties)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_Handle(self, phandle: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Open(self, bstrClusterName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_Name(self, pbstrName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_Name(self, bstrClusterName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_Version(self, ppClusVersion: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusVersion)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_QuorumResource(self, pClusterResource: win32more.Windows.Win32.Networking.Clustering.ISClusResource) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_QuorumResource(self, pClusterResource: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResource)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_QuorumLogSize(self, pnLogSize: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_QuorumLogSize(self, nLogSize: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_QuorumPath(self, ppPath: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_QuorumPath(self, pPath: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_Nodes(self, ppNodes: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusNodes)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_ResourceGroups(self, ppClusterResourceGroups: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResGroups)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_Resources(self, ppClusterResources: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResources)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_ResourceTypes(self, ppResourceTypes: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusResTypes)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_Networks(self, ppNetworks: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusNetworks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_NetInterfaces(self, ppNetInterfaces: POINTER(win32more.Windows.Win32.Networking.Clustering.ISClusNetInterfaces)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISClusterNames(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e606ec-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, pbstrClusterName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_DomainName(self, pbstrDomainName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISDomainNames(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f2e606e2-2631-11d1-89f1-00a0c90d061e}')
    @commethod(7)
    def get_Count(self, plCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Item(self, varIndex: win32more.Windows.Win32.System.Variant.VARIANT, pbstrDomainName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWCContextMenuCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{97dede64-fc6b-11cf-b5f5-00a0c90ab505}')
    @commethod(3)
    def AddExtensionMenuItem(self, lpszName: win32more.Windows.Win32.Foundation.BSTR, lpszStatusBarText: win32more.Windows.Win32.Foundation.BSTR, nCommandID: UInt32, nSubmenuCommandID: UInt32, uFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWCPropertySheetCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{97dede60-fc6b-11cf-b5f5-00a0c90ab505}')
    @commethod(3)
    def AddPropertySheetPage(self, hpage: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWCWizard97Callback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{97dede67-fc6b-11cf-b5f5-00a0c90ab505}')
    @commethod(3)
    def AddWizard97Page(self, hpage: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EnableNext(self, hpage: POINTER(Int32), bEnable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWCWizardCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{97dede62-fc6b-11cf-b5f5-00a0c90ab505}')
    @commethod(3)
    def AddWizardPage(self, hpage: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EnableNext(self, hpage: POINTER(Int32), bEnable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWEExtendContextMenu(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{97dede65-fc6b-11cf-b5f5-00a0c90ab505}')
    @commethod(3)
    def AddContextMenuItems(self, piData: win32more.Windows.Win32.System.Com.IUnknown, piCallback: win32more.Windows.Win32.Networking.Clustering.IWCContextMenuCallback) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWEExtendPropertySheet(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{97dede61-fc6b-11cf-b5f5-00a0c90ab505}')
    @commethod(3)
    def CreatePropertySheetPages(self, piData: win32more.Windows.Win32.System.Com.IUnknown, piCallback: win32more.Windows.Win32.Networking.Clustering.IWCPropertySheetCallback) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWEExtendWizard(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{97dede63-fc6b-11cf-b5f5-00a0c90ab505}')
    @commethod(3)
    def CreateWizardPages(self, piData: win32more.Windows.Win32.System.Com.IUnknown, piCallback: win32more.Windows.Win32.Networking.Clustering.IWCWizardCallback) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWEExtendWizard97(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{97dede68-fc6b-11cf-b5f5-00a0c90ab505}')
    @commethod(3)
    def CreateWizard97Pages(self, piData: win32more.Windows.Win32.System.Com.IUnknown, piCallback: win32more.Windows.Win32.Networking.Clustering.IWCWizard97Callback) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWEInvokeCommand(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{97dede66-fc6b-11cf-b5f5-00a0c90ab505}')
    @commethod(3)
    def InvokeCommand(self, nCommandID: UInt32, piData: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
LOG_LEVEL = Int32
LOG_INFORMATION: win32more.Windows.Win32.Networking.Clustering.LOG_LEVEL = 0
LOG_WARNING: win32more.Windows.Win32.Networking.Clustering.LOG_LEVEL = 1
LOG_ERROR: win32more.Windows.Win32.Networking.Clustering.LOG_LEVEL = 2
LOG_SEVERE: win32more.Windows.Win32.Networking.Clustering.LOG_LEVEL = 3
@winfunctype_pointer
def LPGROUP_CALLBACK_EX(param0: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, param1: win32more.Windows.Win32.Networking.Clustering.HGROUP, param2: win32more.Windows.Win32.Networking.Clustering.HGROUP, param3: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def LPNODE_CALLBACK(param0: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, param1: win32more.Windows.Win32.Networking.Clustering.HNODE, param2: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_STATE, param3: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def LPRESOURCE_CALLBACK(param0: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, param1: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, param2: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def LPRESOURCE_CALLBACK_EX(param0: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, param1: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, param2: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, param3: VoidPtr) -> UInt32: ...
MAINTENANCE_MODE_TYPE_ENUM = Int32
MaintenanceModeTypeDisableIsAliveCheck: win32more.Windows.Win32.Networking.Clustering.MAINTENANCE_MODE_TYPE_ENUM = 1
MaintenanceModeTypeOfflineResource: win32more.Windows.Win32.Networking.Clustering.MAINTENANCE_MODE_TYPE_ENUM = 2
MaintenanceModeTypeUnclusterResource: win32more.Windows.Win32.Networking.Clustering.MAINTENANCE_MODE_TYPE_ENUM = 3
class MONITOR_STATE(Structure):
    LastUpdate: Int64
    State: win32more.Windows.Win32.Networking.Clustering.RESOURCE_MONITOR_STATE
    ActiveResource: win32more.Windows.Win32.Foundation.HANDLE
    ResmonStop: win32more.Windows.Win32.Foundation.BOOL
NODE_CLUSTER_STATE = Int32
ClusterStateNotInstalled: win32more.Windows.Win32.Networking.Clustering.NODE_CLUSTER_STATE = 0
ClusterStateNotConfigured: win32more.Windows.Win32.Networking.Clustering.NODE_CLUSTER_STATE = 1
ClusterStateNotRunning: win32more.Windows.Win32.Networking.Clustering.NODE_CLUSTER_STATE = 3
ClusterStateRunning: win32more.Windows.Win32.Networking.Clustering.NODE_CLUSTER_STATE = 19
class NOTIFY_FILTER_AND_TYPE(Structure):
    dwObjectType: UInt32
    FilterFlags: Int64
class NodeUtilizationInfoElement(Structure):
    Id: UInt64
    AvailableMemory: UInt64
    AvailableMemoryAfterReclamation: UInt64
@winfunctype_pointer
def PARBITRATE_ROUTINE(Resource: VoidPtr, LostQuorumResource: win32more.Windows.Win32.Networking.Clustering.PQUORUM_RESOURCE_LOST) -> UInt32: ...
@winfunctype_pointer
def PARM_WPR_WATCHDOG_FOR_CURRENT_RESOURCE_CALL_ROUTINE(ResourceHandle: IntPtr, TimeoutInMs: UInt64) -> UInt32: ...
@winfunctype_pointer
def PBEGIN_RESCALL_AS_USER_ROUTINE(Resource: VoidPtr, TokenHandle: win32more.Windows.Win32.Foundation.HANDLE, ControlCode: UInt32, InBuffer: VoidPtr, InBufferSize: UInt32, OutBuffer: VoidPtr, OutBufferSize: UInt32, BytesReturned: POINTER(UInt32), context: Int64, ReturnedAsynchronously: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> UInt32: ...
@winfunctype_pointer
def PBEGIN_RESCALL_ROUTINE(Resource: VoidPtr, ControlCode: UInt32, InBuffer: VoidPtr, InBufferSize: UInt32, OutBuffer: VoidPtr, OutBufferSize: UInt32, BytesReturned: POINTER(UInt32), context: Int64, ReturnedAsynchronously: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> UInt32: ...
@winfunctype_pointer
def PBEGIN_RESTYPECALL_AS_USER_ROUTINE(ResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, TokenHandle: win32more.Windows.Win32.Foundation.HANDLE, ControlCode: UInt32, InBuffer: VoidPtr, InBufferSize: UInt32, OutBuffer: VoidPtr, OutBufferSize: UInt32, BytesReturned: POINTER(UInt32), context: Int64, ReturnedAsynchronously: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> UInt32: ...
@winfunctype_pointer
def PBEGIN_RESTYPECALL_ROUTINE(ResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, ControlCode: UInt32, InBuffer: VoidPtr, InBufferSize: UInt32, OutBuffer: VoidPtr, OutBufferSize: UInt32, BytesReturned: POINTER(UInt32), context: Int64, ReturnedAsynchronously: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> UInt32: ...
@winfunctype_pointer
def PCANCEL_ROUTINE(Resource: VoidPtr, CancelFlags_RESERVED: UInt32) -> UInt32: ...
@winfunctype_pointer
def PCHANGE_RESOURCE_PROCESS_FOR_DUMPS(resource: IntPtr, processName: win32more.Windows.Win32.Foundation.PWSTR, processId: UInt32, isAdd: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype_pointer
def PCHANGE_RES_TYPE_PROCESS_FOR_DUMPS(resourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, processName: win32more.Windows.Win32.Foundation.PWSTR, processId: UInt32, isAdd: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype_pointer
def PCLOSE_CLUSTER_CRYPT_PROVIDER(hClusCryptProvider: win32more.Windows.Win32.Networking.Clustering.HCLUSCRYPTPROVIDER) -> UInt32: ...
@winfunctype_pointer
def PCLOSE_ROUTINE(Resource: VoidPtr) -> Void: ...
@winfunctype_pointer
def PCLUSAPIClusWorkerCheckTerminate(lpWorker: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUS_WORKER)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PCLUSAPI_ADD_CLUSTER_GROUP_DEPENDENCY(hDependentGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hProviderGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_ADD_CLUSTER_GROUP_DEPENDENCY_EX(hDependentGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hProviderGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_ADD_CLUSTER_GROUP_GROUPSET_DEPENDENCY(hDependentGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, hProviderGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_ADD_CLUSTER_GROUP_GROUPSET_DEPENDENCY_EX(hDependentGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, hProviderGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_ADD_CLUSTER_GROUP_TO_GROUP_GROUPSET_DEPENDENCY(hDependentGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hProviderGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_ADD_CLUSTER_GROUP_TO_GROUP_GROUPSET_DEPENDENCY_EX(hDependentGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hProviderGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_ADD_CLUSTER_NODE(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR, pfnProgressCallback: win32more.Windows.Win32.Networking.Clustering.PCLUSTER_SETUP_PROGRESS_CALLBACK, pvCallbackArg: VoidPtr) -> win32more.Windows.Win32.Networking.Clustering.HNODE: ...
@winfunctype_pointer
def PCLUSAPI_ADD_CLUSTER_NODE_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, pfnProgressCallback: win32more.Windows.Win32.Networking.Clustering.PCLUSTER_SETUP_PROGRESS_CALLBACK, pvCallbackArg: VoidPtr) -> win32more.Windows.Win32.Networking.Clustering.HNODE: ...
@winfunctype_pointer
def PCLUSAPI_ADD_CLUSTER_RESOURCE_DEPENDENCY(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_ADD_CLUSTER_RESOURCE_DEPENDENCY_EX(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_ADD_CLUSTER_RESOURCE_NODE(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_ADD_CLUSTER_RESOURCE_NODE_EX(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_ADD_CROSS_CLUSTER_GROUPSET_DEPENDENCY(hDependentGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpRemoteClusterName: win32more.Windows.Win32.Foundation.PWSTR, lpRemoteGroupSetName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_ADD_RESOURCE_TO_CLUSTER_SHARED_VOLUMES(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_BACKUP_CLUSTER_DATABASE(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszPathName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CAN_RESOURCE_BE_DEPENDENT(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hResourceDependent: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PCLUSAPI_CHANGE_CLUSTER_RESOURCE_GROUP(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CHANGE_CLUSTER_RESOURCE_GROUP_EX(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, Flags: UInt64) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CHANGE_CLUSTER_RESOURCE_GROUP_EX2(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, Flags: UInt64, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLOSE_CLUSTER(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PCLUSAPI_CLOSE_CLUSTER_GROUP(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PCLUSAPI_CLOSE_CLUSTER_GROUP_GROUPSET(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PCLUSAPI_CLOSE_CLUSTER_NETWORK(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PCLUSAPI_CLOSE_CLUSTER_NET_INTERFACE(hNetInterface: win32more.Windows.Win32.Networking.Clustering.HNETINTERFACE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PCLUSAPI_CLOSE_CLUSTER_NODE(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PCLUSAPI_CLOSE_CLUSTER_NOTIFY_PORT(hChange: win32more.Windows.Win32.Networking.Clustering.HCHANGE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PCLUSAPI_CLOSE_CLUSTER_RESOURCE(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_ADD_GROUP_TO_AFFINITY_RULE(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, ruleName: win32more.Windows.Win32.Foundation.PWSTR, hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_ADD_GROUP_TO_GROUPSET_WITH_DOMAINS_EX(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, faultDomain: UInt32, updateDomain: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_ADD_GROUP_TO_GROUP_GROUPSET(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_AFFINITY_RULE_CONTROL(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, affinityRuleName: win32more.Windows.Win32.Foundation.PWSTR, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, cbInBufferSize: UInt32, lpOutBuffer: VoidPtr, cbOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_CLOSE_ENUM(hEnum: win32more.Windows.Win32.Networking.Clustering.HCLUSENUM) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_CLOSE_ENUM_EX(hClusterEnum: win32more.Windows.Win32.Networking.Clustering.HCLUSENUMEX) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_CONTROL(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_CONTROL_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_CREATE_AFFINITY_RULE(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, ruleName: win32more.Windows.Win32.Foundation.PWSTR, ruleType: win32more.Windows.Win32.Networking.Clustering.CLUS_AFFINITY_RULE_TYPE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_ENUM(hEnum: win32more.Windows.Win32.Networking.Clustering.HCLUSENUM, dwIndex: UInt32, lpdwType: POINTER(UInt32), lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_ENUM_EX(hClusterEnum: win32more.Windows.Win32.Networking.Clustering.HCLUSENUMEX, dwIndex: UInt32, pItem: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_ENUM_ITEM), cbItem: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_GET_ENUM_COUNT(hEnum: win32more.Windows.Win32.Networking.Clustering.HCLUSENUM) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_GET_ENUM_COUNT_EX(hClusterEnum: win32more.Windows.Win32.Networking.Clustering.HCLUSENUMEX) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_GROUP_CLOSE_ENUM(hGroupEnum: win32more.Windows.Win32.Networking.Clustering.HGROUPENUM) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_GROUP_CLOSE_ENUM_EX(hGroupEnumEx: win32more.Windows.Win32.Networking.Clustering.HGROUPENUMEX) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_GROUP_CONTROL(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_GROUP_CONTROL_EX(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_GROUP_ENUM(hGroupEnum: win32more.Windows.Win32.Networking.Clustering.HGROUPENUM, dwIndex: UInt32, lpdwType: POINTER(UInt32), lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_GROUP_ENUM_EX(hGroupEnumEx: win32more.Windows.Win32.Networking.Clustering.HGROUPENUMEX, dwIndex: UInt32, pItem: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_ENUM_ITEM), cbItem: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_GROUP_GET_ENUM_COUNT(hGroupEnum: win32more.Windows.Win32.Networking.Clustering.HGROUPENUM) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_GROUP_GET_ENUM_COUNT_EX(hGroupEnumEx: win32more.Windows.Win32.Networking.Clustering.HGROUPENUMEX) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_GROUP_GROUPSET_CONTROL(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, cbInBufferSize: UInt32, lpOutBuffer: VoidPtr, cbOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_GROUP_GROUPSET_CONTROL_EX(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, cbInBufferSize: UInt32, lpOutBuffer: VoidPtr, cbOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_GROUP_OPEN_ENUM(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, dwType: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HGROUPENUM: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_GROUP_OPEN_ENUM_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszProperties: win32more.Windows.Win32.Foundation.PWSTR, cbProperties: UInt32, lpszRoProperties: win32more.Windows.Win32.Foundation.PWSTR, cbRoProperties: UInt32, dwFlags: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HGROUPENUMEX: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NETWORK_CLOSE_ENUM(hNetworkEnum: win32more.Windows.Win32.Networking.Clustering.HNETWORKENUM) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NETWORK_CONTROL(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NETWORK_CONTROL_EX(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NETWORK_ENUM(hNetworkEnum: win32more.Windows.Win32.Networking.Clustering.HNETWORKENUM, dwIndex: UInt32, lpdwType: POINTER(UInt32), lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NETWORK_GET_ENUM_COUNT(hNetworkEnum: win32more.Windows.Win32.Networking.Clustering.HNETWORKENUM) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NETWORK_OPEN_ENUM(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK, dwType: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HNETWORKENUM: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NET_INTERFACE_CONTROL(hNetInterface: win32more.Windows.Win32.Networking.Clustering.HNETINTERFACE, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NET_INTERFACE_CONTROL_EX(hNetInterface: win32more.Windows.Win32.Networking.Clustering.HNETINTERFACE, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NODE_CLOSE_ENUM(hNodeEnum: win32more.Windows.Win32.Networking.Clustering.HNODEENUM) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NODE_CLOSE_ENUM_EX(hNodeEnum: win32more.Windows.Win32.Networking.Clustering.HNODEENUMEX) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NODE_CONTROL(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NODE_CONTROL_EX(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NODE_ENUM(hNodeEnum: win32more.Windows.Win32.Networking.Clustering.HNODEENUM, dwIndex: UInt32, lpdwType: POINTER(UInt32), lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NODE_ENUM_EX(hNodeEnum: win32more.Windows.Win32.Networking.Clustering.HNODEENUMEX, dwIndex: UInt32, pItem: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_ENUM_ITEM), cbItem: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NODE_GET_ENUM_COUNT(hNodeEnum: win32more.Windows.Win32.Networking.Clustering.HNODEENUM) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NODE_GET_ENUM_COUNT_EX(hNodeEnum: win32more.Windows.Win32.Networking.Clustering.HNODEENUMEX) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NODE_OPEN_ENUM(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwType: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HNODEENUM: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_NODE_OPEN_ENUM_EX(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwType: UInt32, pOptions: VoidPtr) -> win32more.Windows.Win32.Networking.Clustering.HNODEENUMEX: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_OPEN_ENUM(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, dwType: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HCLUSENUM: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_OPEN_ENUM_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, dwType: UInt32, pOptions: VoidPtr) -> win32more.Windows.Win32.Networking.Clustering.HCLUSENUMEX: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_CLOSE_KEY(hKey: win32more.Windows.Win32.System.Registry.HKEY) -> Int32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_CREATE_BATCH(hKey: win32more.Windows.Win32.System.Registry.HKEY, pHREGBATCH: POINTER(win32more.Windows.Win32.Networking.Clustering.HREGBATCH)) -> Int32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_CREATE_KEY(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpszSubKey: win32more.Windows.Win32.Foundation.PWSTR, dwOptions: UInt32, samDesired: UInt32, lpSecurityAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES), phkResult: POINTER(win32more.Windows.Win32.System.Registry.HKEY), lpdwDisposition: POINTER(UInt32)) -> Int32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_CREATE_KEY_EX(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpszSubKey: win32more.Windows.Win32.Foundation.PWSTR, dwOptions: UInt32, samDesired: UInt32, lpSecurityAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES), phkResult: POINTER(win32more.Windows.Win32.System.Registry.HKEY), lpdwDisposition: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_DELETE_KEY(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpszSubKey: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_DELETE_KEY_EX(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpSubKey: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_DELETE_VALUE(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpszValueName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_DELETE_VALUE_EX(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpszValueName: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_ENUM_KEY(hKey: win32more.Windows.Win32.System.Registry.HKEY, dwIndex: UInt32, lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32), lpftLastWriteTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> Int32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_ENUM_VALUE(hKey: win32more.Windows.Win32.System.Registry.HKEY, dwIndex: UInt32, lpszValueName: win32more.Windows.Win32.Foundation.PWSTR, lpcchValueName: POINTER(UInt32), lpdwType: POINTER(UInt32), lpData: POINTER(Byte), lpcbData: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_GET_KEY_SECURITY(hKey: win32more.Windows.Win32.System.Registry.HKEY, RequestedInformation: UInt32, pSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR, lpcbSecurityDescriptor: POINTER(UInt32)) -> Int32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_OPEN_KEY(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpszSubKey: win32more.Windows.Win32.Foundation.PWSTR, samDesired: UInt32, phkResult: POINTER(win32more.Windows.Win32.System.Registry.HKEY)) -> Int32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_QUERY_INFO_KEY(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpcSubKeys: POINTER(UInt32), lpcbMaxSubKeyLen: POINTER(UInt32), lpcValues: POINTER(UInt32), lpcbMaxValueNameLen: POINTER(UInt32), lpcbMaxValueLen: POINTER(UInt32), lpcbSecurityDescriptor: POINTER(UInt32), lpftLastWriteTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> Int32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_QUERY_VALUE(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpszValueName: win32more.Windows.Win32.Foundation.PWSTR, lpdwValueType: POINTER(UInt32), lpData: POINTER(Byte), lpcbData: POINTER(UInt32)) -> Int32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_SET_KEY_SECURITY(hKey: win32more.Windows.Win32.System.Registry.HKEY, SecurityInformation: UInt32, pSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR) -> Int32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_SET_KEY_SECURITY_EX(hKey: win32more.Windows.Win32.System.Registry.HKEY, SecurityInformation: UInt32, pSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_SET_VALUE(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpszValueName: win32more.Windows.Win32.Foundation.PWSTR, dwType: UInt32, lpData: POINTER(Byte), cbData: UInt32) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_SET_VALUE_EX(hKey: win32more.Windows.Win32.System.Registry.HKEY, lpszValueName: win32more.Windows.Win32.Foundation.PWSTR, dwType: UInt32, lpData: POINTER(Byte), cbData: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REG_SYNC_DATABASE(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, flags: UInt32) -> Int32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REMOVE_AFFINITY_RULE(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, ruleName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REMOVE_GROUP_FROM_AFFINITY_RULE(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, ruleName: win32more.Windows.Win32.Foundation.PWSTR, hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REMOVE_GROUP_FROM_GROUPSET(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_REMOVE_GROUP_FROM_GROUPSET_EX(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_CLOSE_ENUM(hResEnum: win32more.Windows.Win32.Networking.Clustering.HRESENUM) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_CLOSE_ENUM_EX(hResourceEnumEx: win32more.Windows.Win32.Networking.Clustering.HRESENUMEX) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_CONTROL(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, cbInBufferSize: UInt32, lpOutBuffer: VoidPtr, cbOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_CONTROL_AS_USER_EX(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, cbInBufferSize: UInt32, lpOutBuffer: VoidPtr, cbOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_CONTROL_EX(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, cbInBufferSize: UInt32, lpOutBuffer: VoidPtr, cbOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_ENUM(hResEnum: win32more.Windows.Win32.Networking.Clustering.HRESENUM, dwIndex: UInt32, lpdwType: POINTER(UInt32), lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_ENUM_EX(hResourceEnumEx: win32more.Windows.Win32.Networking.Clustering.HRESENUMEX, dwIndex: UInt32, pItem: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_ENUM_ITEM), cbItem: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_GET_ENUM_COUNT(hResEnum: win32more.Windows.Win32.Networking.Clustering.HRESENUM) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_GET_ENUM_COUNT_EX(hResourceEnumEx: win32more.Windows.Win32.Networking.Clustering.HRESENUMEX) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_OPEN_ENUM(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, dwType: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HRESENUM: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_OPEN_ENUM_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszProperties: win32more.Windows.Win32.Foundation.PWSTR, cbProperties: UInt32, lpszRoProperties: win32more.Windows.Win32.Foundation.PWSTR, cbRoProperties: UInt32, dwFlags: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HRESENUMEX: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_TYPE_CLOSE_ENUM(hResTypeEnum: win32more.Windows.Win32.Networking.Clustering.HRESTYPEENUM) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_TYPE_CONTROL(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_TYPE_CONTROL_AS_USER_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_TYPE_CONTROL_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, hHostNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwControlCode: UInt32, lpInBuffer: VoidPtr, nInBufferSize: UInt32, lpOutBuffer: VoidPtr, nOutBufferSize: UInt32, lpBytesReturned: POINTER(UInt32), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_TYPE_ENUM(hResTypeEnum: win32more.Windows.Win32.Networking.Clustering.HRESTYPEENUM, dwIndex: UInt32, lpdwType: POINTER(UInt32), lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_TYPE_GET_ENUM_COUNT(hResTypeEnum: win32more.Windows.Win32.Networking.Clustering.HRESTYPEENUM) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_RESOURCE_TYPE_OPEN_ENUM(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, dwType: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HRESTYPEENUM: ...
@winfunctype_pointer
def PCLUSAPI_CLUSTER_UPGRADE(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, perform: win32more.Windows.Win32.Foundation.BOOL, pfnProgressCallback: win32more.Windows.Win32.Networking.Clustering.PCLUSTER_UPGRADE_PROGRESS_CALLBACK, pvCallbackArg: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUS_WORKER_CREATE(lpWorker: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUS_WORKER), lpStartAddress: win32more.Windows.Win32.Networking.Clustering.PWORKER_START_ROUTINE, lpParameter: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CLUS_WORKER_TERMINATE(lpWorker: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUS_WORKER)) -> Void: ...
@winfunctype_pointer
def PCLUSAPI_CREATE_CLUSTER(pConfig: POINTER(win32more.Windows.Win32.Networking.Clustering.CREATE_CLUSTER_CONFIG), pfnProgressCallback: win32more.Windows.Win32.Networking.Clustering.PCLUSTER_SETUP_PROGRESS_CALLBACK, pvCallbackArg: VoidPtr) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype_pointer
def PCLUSAPI_CREATE_CLUSTER_AVAILABILITY_SET(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpAvailabilitySetName: win32more.Windows.Win32.Foundation.PWSTR, pAvailabilitySetConfig: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_AVAILABILITY_SET_CONFIG)) -> win32more.Windows.Win32.Networking.Clustering.HGROUPSET: ...
@winfunctype_pointer
def PCLUSAPI_CREATE_CLUSTER_CNOLESS(pConfig: POINTER(win32more.Windows.Win32.Networking.Clustering.CREATE_CLUSTER_CONFIG), pfnProgressCallback: win32more.Windows.Win32.Networking.Clustering.PCLUSTER_SETUP_PROGRESS_CALLBACK, pvCallbackArg: VoidPtr) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype_pointer
def PCLUSAPI_CREATE_CLUSTER_GROUP(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszGroupName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HGROUP: ...
@winfunctype_pointer
def PCLUSAPI_CREATE_CLUSTER_GROUPEX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszGroupName: win32more.Windows.Win32.Foundation.PWSTR, pGroupInfo: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_CREATE_GROUP_INFO)) -> win32more.Windows.Win32.Networking.Clustering.HGROUP: ...
@winfunctype_pointer
def PCLUSAPI_CREATE_CLUSTER_GROUP_GROUPSET(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszGroupSetName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HGROUPSET: ...
@winfunctype_pointer
def PCLUSAPI_CREATE_CLUSTER_NAME_ACCOUNT(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, pConfig: POINTER(win32more.Windows.Win32.Networking.Clustering.CREATE_CLUSTER_NAME_ACCOUNT), pfnProgressCallback: win32more.Windows.Win32.Networking.Clustering.PCLUSTER_SETUP_PROGRESS_CALLBACK, pvCallbackArg: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CREATE_CLUSTER_NOTIFY_PORT(hChange: win32more.Windows.Win32.Networking.Clustering.HCHANGE, hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, dwFilter: UInt32, dwNotifyKey: UIntPtr) -> win32more.Windows.Win32.Networking.Clustering.HCHANGE: ...
@winfunctype_pointer
def PCLUSAPI_CREATE_CLUSTER_NOTIFY_PORT_V2(hChange: win32more.Windows.Win32.Networking.Clustering.HCHANGE, hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, Filters: POINTER(win32more.Windows.Win32.Networking.Clustering.NOTIFY_FILTER_AND_TYPE), dwFilterCount: UInt32, dwNotifyKey: UIntPtr) -> win32more.Windows.Win32.Networking.Clustering.HCHANGE: ...
@winfunctype_pointer
def PCLUSAPI_CREATE_CLUSTER_RESOURCE(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR, lpszResourceType: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype_pointer
def PCLUSAPI_CREATE_CLUSTER_RESOURCE_EX(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR, lpszResourceType: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype_pointer
def PCLUSAPI_CREATE_CLUSTER_RESOURCE_TYPE(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, lpszDisplayName: win32more.Windows.Win32.Foundation.PWSTR, lpszResourceTypeDll: win32more.Windows.Win32.Foundation.PWSTR, dwLooksAlivePollInterval: UInt32, dwIsAlivePollInterval: UInt32) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_CREATE_CLUSTER_RESOURCE_TYPE_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, lpszDisplayName: win32more.Windows.Win32.Foundation.PWSTR, lpszResourceTypeDll: win32more.Windows.Win32.Foundation.PWSTR, dwLooksAlivePollInterval: UInt32, dwIsAlivePollInterval: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_DELETE_CLUSTER_GROUP(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_DELETE_CLUSTER_GROUP_EX(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_DELETE_CLUSTER_GROUP_GROUPSET(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_DELETE_CLUSTER_GROUP_GROUPSET_EX(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_DELETE_CLUSTER_RESOURCE(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_DELETE_CLUSTER_RESOURCE_EX(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_DELETE_CLUSTER_RESOURCE_TYPE(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_DELETE_CLUSTER_RESOURCE_TYPE_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszTypeName: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_DESTROY_CLUSTER(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, pfnProgressCallback: win32more.Windows.Win32.Networking.Clustering.PCLUSTER_SETUP_PROGRESS_CALLBACK, pvCallbackArg: VoidPtr, fdeleteVirtualComputerObjects: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_DESTROY_CLUSTER_GROUP(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_DESTROY_CLUSTER_GROUP_EX(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_EVICT_CLUSTER_NODE(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_EVICT_CLUSTER_NODE_EX(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwTimeOut: UInt32, phrCleanupStatus: POINTER(win32more.Windows.Win32.Foundation.HRESULT)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_EVICT_CLUSTER_NODE_EX2(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, dwTimeout: UInt32, phrCleanupStatus: POINTER(win32more.Windows.Win32.Foundation.HRESULT), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_FAIL_CLUSTER_RESOURCE(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_FAIL_CLUSTER_RESOURCE_EX(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_FROM_GROUP(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_FROM_GROUP_GROUPSET(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_FROM_NETWORK(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_FROM_NET_INTERFACE(hNetInterface: win32more.Windows.Win32.Networking.Clustering.HNETINTERFACE) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_FROM_NODE(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_FROM_RESOURCE(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_GROUP_KEY(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, samDesired: UInt32) -> win32more.Windows.Win32.System.Registry.HKEY: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_GROUP_STATE(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR, lpcchNodeName: POINTER(UInt32)) -> win32more.Windows.Win32.Networking.Clustering.CLUSTER_GROUP_STATE: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_INFORMATION(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszClusterName: win32more.Windows.Win32.Foundation.PWSTR, lpcchClusterName: POINTER(UInt32), lpClusterInfo: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTERVERSIONINFO)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_KEY(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, samDesired: UInt32) -> win32more.Windows.Win32.System.Registry.HKEY: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_NETWORK_ID(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK, lpszNetworkId: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_NETWORK_KEY(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK, samDesired: UInt32) -> win32more.Windows.Win32.System.Registry.HKEY: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_NETWORK_STATE(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK) -> win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETWORK_STATE: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_NET_INTERFACE(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR, lpszNetworkName: win32more.Windows.Win32.Foundation.PWSTR, lpszInterfaceName: win32more.Windows.Win32.Foundation.PWSTR, lpcchInterfaceName: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_NET_INTERFACE_KEY(hNetInterface: win32more.Windows.Win32.Networking.Clustering.HNETINTERFACE, samDesired: UInt32) -> win32more.Windows.Win32.System.Registry.HKEY: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_NET_INTERFACE_STATE(hNetInterface: win32more.Windows.Win32.Networking.Clustering.HNETINTERFACE) -> win32more.Windows.Win32.Networking.Clustering.CLUSTER_NETINTERFACE_STATE: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_NODE_ID(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, lpszNodeId: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_NODE_KEY(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, samDesired: UInt32) -> win32more.Windows.Win32.System.Registry.HKEY: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_NODE_STATE(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_STATE: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_NOTIFY(hChange: win32more.Windows.Win32.Networking.Clustering.HCHANGE, lpdwNotifyKey: POINTER(UIntPtr), lpdwFilterType: POINTER(UInt32), lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32), dwMilliseconds: UInt32) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_NOTIFY_V2(hChange: win32more.Windows.Win32.Networking.Clustering.HCHANGE, lpdwNotifyKey: POINTER(UIntPtr), pFilterAndType: POINTER(win32more.Windows.Win32.Networking.Clustering.NOTIFY_FILTER_AND_TYPE), buffer: POINTER(Byte), lpcchBufferSize: POINTER(UInt32), lpszObjectId: win32more.Windows.Win32.Foundation.PWSTR, lpcchObjectId: POINTER(UInt32), lpszParentId: win32more.Windows.Win32.Foundation.PWSTR, lpcchParentId: POINTER(UInt32), lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpcchName: POINTER(UInt32), lpszType: win32more.Windows.Win32.Foundation.PWSTR, lpcchType: POINTER(UInt32), dwMilliseconds: UInt32) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_QUORUM_RESOURCE(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR, lpcchResourceName: POINTER(UInt32), lpszDeviceName: win32more.Windows.Win32.Foundation.PWSTR, lpcchDeviceName: POINTER(UInt32), lpdwMaxQuorumLogSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_RESOURCE_DEPENDENCY_EXPRESSION(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszDependencyExpression: win32more.Windows.Win32.Foundation.PWSTR, lpcchDependencyExpression: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_RESOURCE_KEY(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, samDesired: UInt32) -> win32more.Windows.Win32.System.Registry.HKEY: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_RESOURCE_NETWORK_NAME(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpBuffer: win32more.Windows.Win32.Foundation.PWSTR, nSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_RESOURCE_STATE(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR, lpcchNodeName: POINTER(UInt32), lpszGroupName: win32more.Windows.Win32.Foundation.PWSTR, lpcchGroupName: POINTER(UInt32)) -> win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE: ...
@winfunctype_pointer
def PCLUSAPI_GET_CLUSTER_RESOURCE_TYPE_KEY(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszTypeName: win32more.Windows.Win32.Foundation.PWSTR, samDesired: UInt32) -> win32more.Windows.Win32.System.Registry.HKEY: ...
@winfunctype_pointer
def PCLUSAPI_GET_NODE_CLUSTER_STATE(lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR, pdwClusterState: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_GET_NOTIFY_EVENT_HANDLE_V2(hChange: win32more.Windows.Win32.Networking.Clustering.HCHANGE, lphTargetEvent: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_IS_FILE_ON_CLUSTER_SHARED_VOLUME(lpszPathName: win32more.Windows.Win32.Foundation.PWSTR, pbFileIsOnSharedVolume: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_MOVE_CLUSTER_GROUP(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hDestinationNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_OFFLINE_CLUSTER_GROUP(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_OFFLINE_CLUSTER_RESOURCE(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_ONLINE_CLUSTER_GROUP(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hDestinationNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_ONLINE_CLUSTER_RESOURCE(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_OPEN_CLUSTER(lpszClusterName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype_pointer
def PCLUSAPI_OPEN_CLUSTER_EX(lpszClusterName: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32, lpdwGrantedAccess: POINTER(UInt32)) -> win32more.Windows.Win32.Networking.Clustering.HCLUSTER: ...
@winfunctype_pointer
def PCLUSAPI_OPEN_CLUSTER_GROUP(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszGroupName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HGROUP: ...
@winfunctype_pointer
def PCLUSAPI_OPEN_CLUSTER_GROUP_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszGroupName: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32, lpdwGrantedAccess: POINTER(UInt32)) -> win32more.Windows.Win32.Networking.Clustering.HGROUP: ...
@winfunctype_pointer
def PCLUSAPI_OPEN_CLUSTER_GROUP_GROUPSET(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszGroupSetName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HGROUPSET: ...
@winfunctype_pointer
def PCLUSAPI_OPEN_CLUSTER_NETINTERFACE_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNetInterfaceName: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32, lpdwGrantedAccess: POINTER(UInt32)) -> win32more.Windows.Win32.Networking.Clustering.HNETINTERFACE: ...
@winfunctype_pointer
def PCLUSAPI_OPEN_CLUSTER_NETWORK(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNetworkName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HNETWORK: ...
@winfunctype_pointer
def PCLUSAPI_OPEN_CLUSTER_NETWORK_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNetworkName: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32, lpdwGrantedAccess: POINTER(UInt32)) -> win32more.Windows.Win32.Networking.Clustering.HNETWORK: ...
@winfunctype_pointer
def PCLUSAPI_OPEN_CLUSTER_NET_INTERFACE(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszInterfaceName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HNETINTERFACE: ...
@winfunctype_pointer
def PCLUSAPI_OPEN_CLUSTER_NODE(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HNODE: ...
@winfunctype_pointer
def PCLUSAPI_OPEN_CLUSTER_NODE_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNodeName: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32, lpdwGrantedAccess: POINTER(UInt32)) -> win32more.Windows.Win32.Networking.Clustering.HNODE: ...
@winfunctype_pointer
def PCLUSAPI_OPEN_CLUSTER_RESOURCE(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype_pointer
def PCLUSAPI_OPEN_CLUSTER_RESOURCE_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32, lpdwGrantedAccess: POINTER(UInt32)) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype_pointer
def PCLUSAPI_OPEN_NODE_BY_ID(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, nodeId: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HNODE: ...
@winfunctype_pointer
def PCLUSAPI_PAUSE_CLUSTER_NODE(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_PAUSE_CLUSTER_NODE_EX(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, bDrainNode: win32more.Windows.Win32.Foundation.BOOL, dwPauseFlags: UInt32, hNodeDrainTarget: win32more.Windows.Win32.Networking.Clustering.HNODE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_PAUSE_CLUSTER_NODE_EX2(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, bDrainNode: win32more.Windows.Win32.Foundation.BOOL, dwPauseFlags: UInt32, hNodeDrainTarget: win32more.Windows.Win32.Networking.Clustering.HNODE, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_PFN_REASON_HANDLER(lpParameter: VoidPtr, hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, szReason: win32more.Windows.Win32.Foundation.PWSTR, lpSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PCLUSAPI_REGISTER_CLUSTER_NOTIFY(hChange: win32more.Windows.Win32.Networking.Clustering.HCHANGE, dwFilterType: UInt32, hObject: win32more.Windows.Win32.Foundation.HANDLE, dwNotifyKey: UIntPtr) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_REGISTER_CLUSTER_NOTIFY_V2(hChange: win32more.Windows.Win32.Networking.Clustering.HCHANGE, Filter: win32more.Windows.Win32.Networking.Clustering.NOTIFY_FILTER_AND_TYPE, hObject: win32more.Windows.Win32.Foundation.HANDLE, dwNotifyKey: UIntPtr) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_REMOVE_CLUSTER_GROUP_DEPENDENCY(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HGROUP) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_REMOVE_CLUSTER_GROUP_DEPENDENCY_EX(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_REMOVE_CLUSTER_GROUP_GROUPSET_DEPENDENCY(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HGROUPSET) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_REMOVE_CLUSTER_GROUP_GROUPSET_DEPENDENCY_EX(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_REMOVE_CLUSTER_GROUP_TO_GROUP_GROUPSET_DEPENDENCY(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HGROUPSET) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_REMOVE_CLUSTER_GROUP_TO_GROUP_GROUPSET_DEPENDENCY_EX(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_REMOVE_CLUSTER_NAME_ACCOUNT(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_REMOVE_CLUSTER_RESOURCE_DEPENDENCY(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_REMOVE_CLUSTER_RESOURCE_DEPENDENCY_EX(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hDependsOn: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_REMOVE_CLUSTER_RESOURCE_NODE(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_REMOVE_CLUSTER_RESOURCE_NODE_EX(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_REMOVE_CROSS_CLUSTER_GROUPSET_DEPENDENCY(hDependentGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpRemoteClusterName: win32more.Windows.Win32.Foundation.PWSTR, lpRemoteGroupSetName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_REMOVE_RESOURCE_FROM_CLUSTER_SHARED_VOLUMES(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_RESTART_CLUSTER_RESOURCE(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, dwFlags: UInt32) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_RESTART_CLUSTER_RESOURCE_EX(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, dwFlags: UInt32) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_RESTORE_CLUSTER_DATABASE(lpszPathName: win32more.Windows.Win32.Foundation.PWSTR, bForce: win32more.Windows.Win32.Foundation.BOOL, lpszQuorumDriveLetter: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_RESUME_CLUSTER_NODE(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_RESUME_CLUSTER_NODE_EX(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, eResumeFailbackType: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_RESUME_FAILBACK_TYPE, dwResumeFlagsReserved: UInt32) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_RESUME_CLUSTER_NODE_EX2(hNode: win32more.Windows.Win32.Networking.Clustering.HNODE, eResumeFailbackType: win32more.Windows.Win32.Networking.Clustering.CLUSTER_NODE_RESUME_FAILBACK_TYPE, dwResumeFlagsReserved: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_CLUSTER_GROUP_GROUPSET_DEPENDENCY_EXPRESSION(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpszDependencyExpression: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_CLUSTER_GROUP_GROUPSET_DEPENDENCY_EXPRESSION_EX(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUPSET, lpszDependencyExpression: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_CLUSTER_GROUP_NAME(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszGroupName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_CLUSTER_GROUP_NAME_EX(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszGroupName: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_CLUSTER_GROUP_NODE_LIST(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, NodeCount: UInt32, NodeList: POINTER(win32more.Windows.Win32.Networking.Clustering.HNODE)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_CLUSTER_GROUP_NODE_LIST_EX(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, NodeCount: UInt32, NodeList: POINTER(win32more.Windows.Win32.Networking.Clustering.HNODE), lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_CLUSTER_NAME_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNewClusterName: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_CLUSTER_NETWORK_NAME(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK, lpszName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_CLUSTER_NETWORK_NAME_EX(hNetwork: win32more.Windows.Win32.Networking.Clustering.HNETWORK, lpszName: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_CLUSTER_NETWORK_PRIORITY_ORDER(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, NetworkCount: UInt32, NetworkList: POINTER(win32more.Windows.Win32.Networking.Clustering.HNETWORK)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_CLUSTER_QUORUM_RESOURCE(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszDeviceName: win32more.Windows.Win32.Foundation.PWSTR, dwMaxQuoLogSize: UInt32) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_CLUSTER_QUORUM_RESOURCE_EX(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszDeviceName: win32more.Windows.Win32.Foundation.PWSTR, dwMaxQuorumLogSize: UInt32, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_CLUSTER_RESOURCE_DEPENDENCY_EXPRESSION(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszDependencyExpression: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_CLUSTER_RESOURCE_NAME(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_CLUSTER_RESOURCE_NAME_EX(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_CLUSTER_SERVICE_ACCOUNT_PASSWORD(lpszClusterName: win32more.Windows.Win32.Foundation.PWSTR, lpszNewPassword: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, lpReturnStatusBuffer: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_SET_PASSWORD_STATUS), lpcbReturnStatusBufferSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_GROUP_DEPENDENCY_EXPRESSION(hGroupSet: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszDependencyExpression: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_GROUP_DEPENDENCY_EXPRESSION_EX(hGroup: win32more.Windows.Win32.Networking.Clustering.HGROUP, lpszDependencyExpression: win32more.Windows.Win32.Foundation.PWSTR, lpszReason: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SET_REASON_HANDLER(lpHandler: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSAPI_REASON_HANDLER)) -> POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSAPI_REASON_HANDLER): ...
@winfunctype_pointer
def PCLUSAPI_SHARED_VOLUME_SET_SNAPSHOT_STATE(guidSnapshotSet: Guid, lpszVolumeName: win32more.Windows.Win32.Foundation.PWSTR, state: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SHARED_VOLUME_SNAPSHOT_STATE) -> UInt32: ...
@winfunctype_pointer
def PCLUSAPI_SetClusterName(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, lpszNewClusterName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSTER_CLEAR_BACKUP_STATE_FOR_SHARED_VOLUME(lpszVolumePathName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PCLUSTER_DECRYPT(hClusCryptProvider: win32more.Windows.Win32.Networking.Clustering.HCLUSCRYPTPROVIDER, pCryptInput: POINTER(Byte), cbCryptInput: UInt32, ppCryptOutput: POINTER(POINTER(Byte)), pcbCryptOutput: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSTER_ENCRYPT(hClusCryptProvider: win32more.Windows.Win32.Networking.Clustering.HCLUSCRYPTPROVIDER, pData: POINTER(Byte), cbData: UInt32, ppData: POINTER(POINTER(Byte)), pcbData: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSTER_GET_VOLUME_NAME_FOR_VOLUME_MOUNT_POINT(lpszVolumeMountPoint: win32more.Windows.Win32.Foundation.PWSTR, lpszVolumeName: win32more.Windows.Win32.Foundation.PWSTR, cchBufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PCLUSTER_GET_VOLUME_PATH_NAME(lpszFileName: win32more.Windows.Win32.Foundation.PWSTR, lpszVolumePathName: win32more.Windows.Win32.Foundation.PWSTR, cchBufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PCLUSTER_IS_PATH_ON_SHARED_VOLUME(lpszPathName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PCLUSTER_PREPARE_SHARED_VOLUME_FOR_BACKUP(lpszFileName: win32more.Windows.Win32.Foundation.PWSTR, lpszVolumePathName: win32more.Windows.Win32.Foundation.PWSTR, lpcchVolumePathName: POINTER(UInt32), lpszVolumeName: win32more.Windows.Win32.Foundation.PWSTR, lpcchVolumeName: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PCLUSTER_REG_BATCH_ADD_COMMAND(hRegBatch: win32more.Windows.Win32.Networking.Clustering.HREGBATCH, dwCommand: win32more.Windows.Win32.Networking.Clustering.CLUSTER_REG_COMMAND, wzName: win32more.Windows.Win32.Foundation.PWSTR, dwOptions: UInt32, lpData: VoidPtr, cbData: UInt32) -> Int32: ...
@winfunctype_pointer
def PCLUSTER_REG_BATCH_CLOSE_NOTIFICATION(hBatchNotification: win32more.Windows.Win32.Networking.Clustering.HREGBATCHNOTIFICATION) -> Int32: ...
@winfunctype_pointer
def PCLUSTER_REG_BATCH_READ_COMMAND(hBatchNotification: win32more.Windows.Win32.Networking.Clustering.HREGBATCHNOTIFICATION, pBatchCommand: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_BATCH_COMMAND)) -> Int32: ...
@winfunctype_pointer
def PCLUSTER_REG_CLOSE_BATCH(hRegBatch: win32more.Windows.Win32.Networking.Clustering.HREGBATCH, bCommit: win32more.Windows.Win32.Foundation.BOOL, failedCommandNumber: POINTER(Int32)) -> Int32: ...
@winfunctype_pointer
def PCLUSTER_REG_CLOSE_BATCH_NOTIFY_PORT(hBatchNotifyPort: win32more.Windows.Win32.Networking.Clustering.HREGBATCHPORT) -> Int32: ...
@winfunctype_pointer
def PCLUSTER_REG_CLOSE_READ_BATCH(hRegReadBatch: win32more.Windows.Win32.Networking.Clustering.HREGREADBATCH, phRegReadBatchReply: POINTER(win32more.Windows.Win32.Networking.Clustering.HREGREADBATCHREPLY)) -> Int32: ...
@winfunctype_pointer
def PCLUSTER_REG_CLOSE_READ_BATCH_EX(hRegReadBatch: win32more.Windows.Win32.Networking.Clustering.HREGREADBATCH, flags: UInt32, phRegReadBatchReply: POINTER(win32more.Windows.Win32.Networking.Clustering.HREGREADBATCHREPLY)) -> Int32: ...
@winfunctype_pointer
def PCLUSTER_REG_CLOSE_READ_BATCH_REPLY(hRegReadBatchReply: win32more.Windows.Win32.Networking.Clustering.HREGREADBATCHREPLY) -> Int32: ...
@winfunctype_pointer
def PCLUSTER_REG_CREATE_BATCH_NOTIFY_PORT(hKey: win32more.Windows.Win32.System.Registry.HKEY, phBatchNotifyPort: POINTER(win32more.Windows.Win32.Networking.Clustering.HREGBATCHPORT)) -> Int32: ...
@winfunctype_pointer
def PCLUSTER_REG_CREATE_READ_BATCH(hKey: win32more.Windows.Win32.System.Registry.HKEY, phRegReadBatch: POINTER(win32more.Windows.Win32.Networking.Clustering.HREGREADBATCH)) -> Int32: ...
@winfunctype_pointer
def PCLUSTER_REG_GET_BATCH_NOTIFICATION(hBatchNotify: win32more.Windows.Win32.Networking.Clustering.HREGBATCHPORT, phBatchNotification: POINTER(win32more.Windows.Win32.Networking.Clustering.HREGBATCHNOTIFICATION)) -> Int32: ...
@winfunctype_pointer
def PCLUSTER_REG_READ_BATCH_ADD_COMMAND(hRegReadBatch: win32more.Windows.Win32.Networking.Clustering.HREGREADBATCH, wzSubkeyName: win32more.Windows.Win32.Foundation.PWSTR, wzValueName: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
@winfunctype_pointer
def PCLUSTER_REG_READ_BATCH_REPLY_NEXT_COMMAND(hRegReadBatchReply: win32more.Windows.Win32.Networking.Clustering.HREGREADBATCHREPLY, pBatchCommand: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSTER_READ_BATCH_COMMAND)) -> Int32: ...
@winfunctype_pointer
def PCLUSTER_SETUP_PROGRESS_CALLBACK(pvCallbackArg: VoidPtr, eSetupPhase: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE, ePhaseType: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE_TYPE, ePhaseSeverity: win32more.Windows.Win32.Networking.Clustering.CLUSTER_SETUP_PHASE_SEVERITY, dwPercentComplete: UInt32, lpszObjectName: win32more.Windows.Win32.Foundation.PWSTR, dwStatus: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PCLUSTER_SET_ACCOUNT_ACCESS(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, szAccountSID: win32more.Windows.Win32.Foundation.PWSTR, dwAccess: UInt32, dwControlType: UInt32) -> UInt32: ...
@winfunctype_pointer
def PCLUSTER_UPGRADE_PROGRESS_CALLBACK(pvCallbackArg: VoidPtr, eUpgradePhase: win32more.Windows.Win32.Networking.Clustering.CLUSTER_UPGRADE_PHASE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PEND_CONTROL_CALL(context: Int64, status: UInt32) -> UInt32: ...
@winfunctype_pointer
def PEND_TYPE_CONTROL_CALL(context: Int64, status: UInt32) -> UInt32: ...
@winfunctype_pointer
def PEXTEND_RES_CONTROL_CALL(context: Int64, newTimeoutInMs: UInt32) -> UInt32: ...
@winfunctype_pointer
def PEXTEND_RES_TYPE_CONTROL_CALL(context: Int64, newTimeoutInMs: UInt32) -> UInt32: ...
@winfunctype_pointer
def PFREE_CLUSTER_CRYPT(pCryptInfo: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PIS_ALIVE_ROUTINE(Resource: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
PLACEMENT_OPTIONS = Int32
PLACEMENT_OPTIONS_MIN_VALUE: win32more.Windows.Win32.Networking.Clustering.PLACEMENT_OPTIONS = 0
PLACEMENT_OPTIONS_DEFAULT_PLACEMENT_OPTIONS: win32more.Windows.Win32.Networking.Clustering.PLACEMENT_OPTIONS = 0
PLACEMENT_OPTIONS_DISABLE_CSV_VM_DEPENDENCY: win32more.Windows.Win32.Networking.Clustering.PLACEMENT_OPTIONS = 1
PLACEMENT_OPTIONS_CONSIDER_OFFLINE_VMS: win32more.Windows.Win32.Networking.Clustering.PLACEMENT_OPTIONS = 2
PLACEMENT_OPTIONS_DONT_USE_MEMORY: win32more.Windows.Win32.Networking.Clustering.PLACEMENT_OPTIONS = 4
PLACEMENT_OPTIONS_DONT_USE_CPU: win32more.Windows.Win32.Networking.Clustering.PLACEMENT_OPTIONS = 8
PLACEMENT_OPTIONS_DONT_USE_LOCAL_TEMP_DISK: win32more.Windows.Win32.Networking.Clustering.PLACEMENT_OPTIONS = 16
PLACEMENT_OPTIONS_DONT_RESUME_VMS_WITH_EXISTING_TEMP_DISK: win32more.Windows.Win32.Networking.Clustering.PLACEMENT_OPTIONS = 32
PLACEMENT_OPTIONS_SAVE_VMS_WITH_LOCAL_DISK_ON_DRAIN_OVERWRITE: win32more.Windows.Win32.Networking.Clustering.PLACEMENT_OPTIONS = 64
PLACEMENT_OPTIONS_DONT_RESUME_AVAILABILTY_SET_VMS_WITH_EXISTING_TEMP_DISK: win32more.Windows.Win32.Networking.Clustering.PLACEMENT_OPTIONS = 128
PLACEMENT_OPTIONS_SAVE_AVAILABILTY_SET_VMS_WITH_LOCAL_DISK_ON_DRAIN_OVERWRITE: win32more.Windows.Win32.Networking.Clustering.PLACEMENT_OPTIONS = 256
PLACEMENT_OPTIONS_AVAILABILITY_SET_DOMAIN_AFFINITY: win32more.Windows.Win32.Networking.Clustering.PLACEMENT_OPTIONS = 512
PLACEMENT_OPTIONS_ALL: win32more.Windows.Win32.Networking.Clustering.PLACEMENT_OPTIONS = 1023
@cfunctype_pointer
def PLOG_EVENT_ROUTINE(ResourceHandle: IntPtr, LogLevel: win32more.Windows.Win32.Networking.Clustering.LOG_LEVEL, FormatString: win32more.Windows.Win32.Foundation.PWSTR) -> Void: ...
@winfunctype_pointer
def PLOOKS_ALIVE_ROUTINE(Resource: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def POFFLINE_ROUTINE(Resource: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def POFFLINE_V2_ROUTINE(Resource: VoidPtr, DestinationNodeName: win32more.Windows.Win32.Foundation.PWSTR, OfflineFlags: UInt32, InBuffer: POINTER(Byte), InBufferSize: UInt32, Reserved: UInt32) -> UInt32: ...
@winfunctype_pointer
def PONLINE_ROUTINE(Resource: VoidPtr, EventHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype_pointer
def PONLINE_V2_ROUTINE(Resource: VoidPtr, EventHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE), OnlineFlags: UInt32, InBuffer: POINTER(Byte), InBufferSize: UInt32, Reserved: UInt32) -> UInt32: ...
@winfunctype_pointer
def POPEN_CLUSTER_CRYPT_PROVIDER(lpszResource: win32more.Windows.Win32.Foundation.PWSTR, lpszProvider: POINTER(SByte), dwType: UInt32, dwFlags: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HCLUSCRYPTPROVIDER: ...
@winfunctype_pointer
def POPEN_CLUSTER_CRYPT_PROVIDEREX(lpszResource: win32more.Windows.Win32.Foundation.PWSTR, lpszKeyname: win32more.Windows.Win32.Foundation.PWSTR, lpszProvider: POINTER(SByte), dwType: UInt32, dwFlags: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HCLUSCRYPTPROVIDER: ...
@winfunctype_pointer
def POPEN_ROUTINE(ResourceName: win32more.Windows.Win32.Foundation.PWSTR, ResourceKey: win32more.Windows.Win32.System.Registry.HKEY, ResourceHandle: IntPtr) -> VoidPtr: ...
@winfunctype_pointer
def POPEN_V2_ROUTINE(ResourceName: win32more.Windows.Win32.Foundation.PWSTR, ResourceKey: win32more.Windows.Win32.System.Registry.HKEY, ResourceHandle: IntPtr, OpenFlags: UInt32) -> VoidPtr: ...
class POST_UPGRADE_VERSION_INFO(Structure):
    newMajorVersion: UInt32
    newUpgradeVersion: UInt32
    oldMajorVersion: UInt32
    oldUpgradeVersion: UInt32
    reserved: UInt32
@winfunctype_pointer
def PQUERY_APPINSTANCE_VERSION(AppInstanceId: POINTER(Guid), InstanceVersionHigh: POINTER(UInt64), InstanceVersionLow: POINTER(UInt64), VersionStatus: POINTER(win32more.Windows.Win32.Foundation.NTSTATUS)) -> UInt32: ...
@winfunctype_pointer
def PQUORUM_RESOURCE_LOST(Resource: IntPtr) -> Void: ...
@winfunctype_pointer
def PRAISE_RES_TYPE_NOTIFICATION(ResourceType: win32more.Windows.Win32.Foundation.PWSTR, pPayload: POINTER(Byte), payloadSize: UInt32) -> UInt32: ...
@winfunctype_pointer
def PREGISTER_APPINSTANCE(ProcessHandle: win32more.Windows.Win32.Foundation.HANDLE, AppInstanceId: POINTER(Guid), ChildrenInheritAppInstance: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype_pointer
def PREGISTER_APPINSTANCE_VERSION(AppInstanceId: POINTER(Guid), InstanceVersionHigh: UInt64, InstanceVersionLow: UInt64) -> UInt32: ...
@winfunctype_pointer
def PRELEASE_ROUTINE(Resource: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PREQUEST_DUMP_ROUTINE(ResourceHandle: IntPtr, DumpDueToCallInProgress: win32more.Windows.Win32.Foundation.BOOL, DumpDelayInMs: UInt32) -> UInt32: ...
@winfunctype_pointer
def PRESET_ALL_APPINSTANCE_VERSIONS() -> UInt32: ...
@winfunctype_pointer
def PRESOURCE_CONTROL_ROUTINE(Resource: VoidPtr, ControlCode: UInt32, InBuffer: VoidPtr, InBufferSize: UInt32, OutBuffer: VoidPtr, OutBufferSize: UInt32, BytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESOURCE_TYPE_CONTROL_ROUTINE(ResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, ControlCode: UInt32, InBuffer: VoidPtr, InBufferSize: UInt32, OutBuffer: VoidPtr, OutBufferSize: UInt32, BytesReturned: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_ADD_UNKNOWN_PROPERTIES(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pOutPropertyList: VoidPtr, pcbOutPropertyListSize: UInt32, pcbBytesReturned: POINTER(UInt32), pcbRequired: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_CREATE_DIRECTORY_TREE(pszPath: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_DUP_PARAMETER_BLOCK(pOutParams: POINTER(Byte), pInParams: POINTER(Byte), pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_DUP_STRING(pszInString: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.PWSTR: ...
@winfunctype_pointer
def PRESUTIL_ENUM_PRIVATE_PROPERTIES(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszOutProperties: win32more.Windows.Win32.Foundation.PWSTR, cbOutPropertiesSize: UInt32, pcbBytesReturned: POINTER(UInt32), pcbRequired: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_ENUM_PROPERTIES(pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pszOutProperties: win32more.Windows.Win32.Foundation.PWSTR, cbOutPropertiesSize: UInt32, pcbBytesReturned: POINTER(UInt32), pcbRequired: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_ENUM_RESOURCES(hSelf: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszResTypeName: win32more.Windows.Win32.Foundation.PWSTR, pResCallBack: win32more.Windows.Win32.Networking.Clustering.LPRESOURCE_CALLBACK, pParameter: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_ENUM_RESOURCES_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hSelf: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszResTypeName: win32more.Windows.Win32.Foundation.PWSTR, pResCallBack: win32more.Windows.Win32.Networking.Clustering.LPRESOURCE_CALLBACK_EX, pParameter: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_ENUM_RESOURCES_EX2(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hSelf: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, lpszResTypeName: win32more.Windows.Win32.Foundation.PWSTR, pResCallBack: win32more.Windows.Win32.Networking.Clustering.LPRESOURCE_CALLBACK_EX, pParameter: VoidPtr, dwDesiredAccess: UInt32) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_EXPAND_ENVIRONMENT_STRINGS(pszSrc: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.PWSTR: ...
@winfunctype_pointer
def PRESUTIL_FIND_BINARY_PROPERTY(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, pbPropertyValue: POINTER(POINTER(Byte)), pcbPropertyValueSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_FIND_DEPENDENT_DISK_RESOURCE_DRIVE_LETTER(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, pszDriveLetter: win32more.Windows.Win32.Foundation.PWSTR, pcchDriveLetter: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_FIND_DWORD_PROPERTY(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, pdwPropertyValue: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_FIND_EXPANDED_SZ_PROPERTY(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, pszPropertyValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_FIND_EXPAND_SZ_PROPERTY(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, pszPropertyValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_FIND_FILETIME_PROPERTY(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, pftPropertyValue: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_FIND_LONG_PROPERTY(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, plPropertyValue: POINTER(Int32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_FIND_MULTI_SZ_PROPERTY(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, pszPropertyValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pcbPropertyValueSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_FIND_SZ_PROPERTY(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, pszPropertyValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_FIND_ULARGEINTEGER_PROPERTY(pPropertyList: VoidPtr, cbPropertyListSize: UInt32, pszPropertyName: win32more.Windows.Win32.Foundation.PWSTR, plPropertyValue: POINTER(UInt64)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_FREE_ENVIRONMENT(lpEnvironment: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_FREE_PARAMETER_BLOCK(pOutParams: POINTER(Byte), pInParams: POINTER(Byte), pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM)) -> Void: ...
@winfunctype_pointer
def PRESUTIL_GET_ALL_PROPERTIES(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pOutPropertyList: VoidPtr, cbOutPropertyListSize: UInt32, pcbBytesReturned: POINTER(UInt32), pcbRequired: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_BINARY_PROPERTY(ppbOutValue: POINTER(POINTER(Byte)), pcbOutValueSize: POINTER(UInt32), pValueStruct: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_BINARY), pbOldValue: POINTER(Byte), cbOldValueSize: UInt32, ppPropertyList: POINTER(POINTER(Byte)), pcbPropertyListSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_BINARY_VALUE(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, ppbOutValue: POINTER(POINTER(Byte)), pcbOutValueSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_CORE_CLUSTER_RESOURCES(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, phClusterNameResource: POINTER(win32more.Windows.Win32.Networking.Clustering.HRESOURCE), phClusterIPAddressResource: POINTER(win32more.Windows.Win32.Networking.Clustering.HRESOURCE), phClusterQuorumResource: POINTER(win32more.Windows.Win32.Networking.Clustering.HRESOURCE)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_CORE_CLUSTER_RESOURCES_EX(hClusterIn: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, phClusterNameResourceOut: POINTER(win32more.Windows.Win32.Networking.Clustering.HRESOURCE), phClusterIPAddressResourceOut: POINTER(win32more.Windows.Win32.Networking.Clustering.HRESOURCE), phClusterQuorumResourceOut: POINTER(win32more.Windows.Win32.Networking.Clustering.HRESOURCE), dwDesiredAccess: UInt32) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_DWORD_PROPERTY(pdwOutValue: POINTER(UInt32), pValueStruct: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_DWORD), dwOldValue: UInt32, dwMinimum: UInt32, dwMaximum: UInt32, ppPropertyList: POINTER(POINTER(Byte)), pcbPropertyListSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_DWORD_VALUE(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, pdwOutValue: POINTER(UInt32), dwDefaultValue: UInt32) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_ENVIRONMENT_WITH_NET_NAME(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> VoidPtr: ...
@winfunctype_pointer
def PRESUTIL_GET_EXPAND_SZ_VALUE(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, bExpand: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.PWSTR: ...
@winfunctype_pointer
def PRESUTIL_GET_FILETIME_PROPERTY(pftOutValue: POINTER(win32more.Windows.Win32.Foundation.FILETIME), pValueStruct: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_FILETIME), ftOldValue: win32more.Windows.Win32.Foundation.FILETIME, ftMinimum: win32more.Windows.Win32.Foundation.FILETIME, ftMaximum: win32more.Windows.Win32.Foundation.FILETIME, ppPropertyList: POINTER(POINTER(Byte)), pcbPropertyListSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_LONG_PROPERTY(plOutValue: POINTER(Int32), pValueStruct: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_LONG), lOldValue: Int32, lMinimum: Int32, lMaximum: Int32, ppPropertyList: POINTER(POINTER(Byte)), pcbPropertyListSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_MULTI_SZ_PROPERTY(ppszOutValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pcbOutValueSize: POINTER(UInt32), pValueStruct: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_SZ), pszOldValue: win32more.Windows.Win32.Foundation.PWSTR, cbOldValueSize: UInt32, ppPropertyList: POINTER(POINTER(Byte)), pcbPropertyListSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_PRIVATE_PROPERTIES(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pOutPropertyList: VoidPtr, cbOutPropertyListSize: UInt32, pcbBytesReturned: POINTER(UInt32), pcbRequired: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_PROPERTIES(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pOutPropertyList: VoidPtr, cbOutPropertyListSize: UInt32, pcbBytesReturned: POINTER(UInt32), pcbRequired: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_PROPERTIES_TO_PARAMETER_BLOCK(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pOutParams: POINTER(Byte), bCheckForRequiredProperties: win32more.Windows.Win32.Foundation.BOOL, pszNameOfPropInError: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_PROPERTY(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTableItem: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pOutPropertyItem: POINTER(VoidPtr), pcbOutPropertyItemSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_PROPERTY_FORMATS(pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pOutPropertyFormatList: VoidPtr, cbPropertyFormatListSize: UInt32, pcbBytesReturned: POINTER(UInt32), pcbRequired: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_PROPERTY_SIZE(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTableItem: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pcbOutPropertyListSize: POINTER(UInt32), pnPropertyCount: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_QWORD_VALUE(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, pqwOutValue: POINTER(UInt64), qwDefaultValue: UInt64) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_RESOURCE_DEPENDENCY(hSelf: win32more.Windows.Win32.Foundation.HANDLE, lpszResourceType: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype_pointer
def PRESUTIL_GET_RESOURCE_DEPENDENCY_BY_CLASS(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hSelf: win32more.Windows.Win32.Foundation.HANDLE, prci: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUS_RESOURCE_CLASS_INFO), bRecurse: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype_pointer
def PRESUTIL_GET_RESOURCE_DEPENDENCY_BY_CLASS_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hSelf: win32more.Windows.Win32.Foundation.HANDLE, prci: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUS_RESOURCE_CLASS_INFO), bRecurse: win32more.Windows.Win32.Foundation.BOOL, dwDesiredAccess: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype_pointer
def PRESUTIL_GET_RESOURCE_DEPENDENCY_BY_NAME(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hSelf: win32more.Windows.Win32.Foundation.HANDLE, lpszResourceType: win32more.Windows.Win32.Foundation.PWSTR, bRecurse: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype_pointer
def PRESUTIL_GET_RESOURCE_DEPENDENCY_BY_NAME_EX(hCluster: win32more.Windows.Win32.Networking.Clustering.HCLUSTER, hSelf: win32more.Windows.Win32.Foundation.HANDLE, lpszResourceType: win32more.Windows.Win32.Foundation.PWSTR, bRecurse: win32more.Windows.Win32.Foundation.BOOL, dwDesiredAccess: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype_pointer
def PRESUTIL_GET_RESOURCE_DEPENDENCY_EX(hSelf: win32more.Windows.Win32.Foundation.HANDLE, lpszResourceType: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype_pointer
def PRESUTIL_GET_RESOURCE_DEPENDENTIP_ADDRESS_PROPS(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, pszAddress: win32more.Windows.Win32.Foundation.PWSTR, pcchAddress: POINTER(UInt32), pszSubnetMask: win32more.Windows.Win32.Foundation.PWSTR, pcchSubnetMask: POINTER(UInt32), pszNetwork: win32more.Windows.Win32.Foundation.PWSTR, pcchNetwork: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_RESOURCE_NAME(hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, pszResourceName: win32more.Windows.Win32.Foundation.PWSTR, pcchResourceNameInOut: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_RESOURCE_NAME_DEPENDENCY(lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR, lpszResourceType: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype_pointer
def PRESUTIL_GET_RESOURCE_NAME_DEPENDENCY_EX(lpszResourceName: win32more.Windows.Win32.Foundation.PWSTR, lpszResourceType: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32) -> win32more.Windows.Win32.Networking.Clustering.HRESOURCE: ...
@winfunctype_pointer
def PRESUTIL_GET_SZ_PROPERTY(ppszOutValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pValueStruct: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUSPROP_SZ), pszOldValue: win32more.Windows.Win32.Foundation.PWSTR, ppPropertyList: POINTER(POINTER(Byte)), pcbPropertyListSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_GET_SZ_VALUE(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.PWSTR: ...
@winfunctype_pointer
def PRESUTIL_IS_PATH_VALID(pszPath: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PRESUTIL_IS_RESOURCE_CLASS_EQUAL(prci: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUS_RESOURCE_CLASS_INFO), hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PRESUTIL_PROPERTY_LIST_FROM_PARAMETER_BLOCK(pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pOutPropertyList: VoidPtr, pcbOutPropertyListSize: POINTER(UInt32), pInParams: POINTER(Byte), pcbBytesReturned: POINTER(UInt32), pcbRequired: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_REMOVE_RESOURCE_SERVICE_ENVIRONMENT(pszServiceName: win32more.Windows.Win32.Foundation.PWSTR, pfnLogEvent: win32more.Windows.Win32.Networking.Clustering.PLOG_EVENT_ROUTINE, hResourceHandle: IntPtr) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_RESOURCES_EQUAL(hSelf: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PRESUTIL_RESOURCE_TYPES_EQUAL(lpszResourceTypeName: win32more.Windows.Win32.Foundation.PWSTR, hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PRESUTIL_SET_BINARY_VALUE(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, pbNewValue: POINTER(Byte), cbNewValueSize: UInt32, ppbOutValue: POINTER(POINTER(Byte)), pcbOutValueSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_SET_DWORD_VALUE(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, dwNewValue: UInt32, pdwOutValue: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_SET_EXPAND_SZ_VALUE(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, pszNewValue: win32more.Windows.Win32.Foundation.PWSTR, ppszOutString: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_SET_MULTI_SZ_VALUE(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, pszNewValue: win32more.Windows.Win32.Foundation.PWSTR, cbNewValueSize: UInt32, ppszOutValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pcbOutValueSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_SET_PRIVATE_PROPERTY_LIST(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pInPropertyList: VoidPtr, cbInPropertyListSize: UInt32) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_SET_PROPERTY_PARAMETER_BLOCK(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), Reserved: VoidPtr, pInParams: POINTER(Byte), pInPropertyList: VoidPtr, cbInPropertyListSize: UInt32, pOutParams: POINTER(Byte)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_SET_PROPERTY_PARAMETER_BLOCK_EX(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), Reserved: VoidPtr, pInParams: POINTER(Byte), pInPropertyList: VoidPtr, cbInPropertyListSize: UInt32, bForceWrite: win32more.Windows.Win32.Foundation.BOOL, pOutParams: POINTER(Byte)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_SET_PROPERTY_TABLE(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), Reserved: VoidPtr, bAllowUnknownProperties: win32more.Windows.Win32.Foundation.BOOL, pInPropertyList: VoidPtr, cbInPropertyListSize: UInt32, pOutParams: POINTER(Byte)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_SET_PROPERTY_TABLE_EX(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), Reserved: VoidPtr, bAllowUnknownProperties: win32more.Windows.Win32.Foundation.BOOL, pInPropertyList: VoidPtr, cbInPropertyListSize: UInt32, bForceWrite: win32more.Windows.Win32.Foundation.BOOL, pOutParams: POINTER(Byte)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_SET_QWORD_VALUE(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, qwNewValue: UInt64, pqwOutValue: POINTER(UInt64)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_SET_RESOURCE_SERVICE_ENVIRONMENT(pszServiceName: win32more.Windows.Win32.Foundation.PWSTR, hResource: win32more.Windows.Win32.Networking.Clustering.HRESOURCE, pfnLogEvent: win32more.Windows.Win32.Networking.Clustering.PLOG_EVENT_ROUTINE, hResourceHandle: IntPtr) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_SET_RESOURCE_SERVICE_START_PARAMETERS(pszServiceName: win32more.Windows.Win32.Foundation.PWSTR, schSCMHandle: win32more.Windows.Win32.System.Services.SC_HANDLE, phService: POINTER(win32more.Windows.Win32.System.Services.SC_HANDLE), pfnLogEvent: win32more.Windows.Win32.Networking.Clustering.PLOG_EVENT_ROUTINE, hResourceHandle: IntPtr) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_SET_RESOURCE_SERVICE_START_PARAMETERS_EX(pszServiceName: win32more.Windows.Win32.Foundation.PWSTR, schSCMHandle: win32more.Windows.Win32.System.Services.SC_HANDLE, phService: POINTER(win32more.Windows.Win32.System.Services.SC_HANDLE), dwDesiredAccess: UInt32, pfnLogEvent: win32more.Windows.Win32.Networking.Clustering.PLOG_EVENT_ROUTINE, hResourceHandle: IntPtr) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_SET_SZ_VALUE(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pszValueName: win32more.Windows.Win32.Foundation.PWSTR, pszNewValue: win32more.Windows.Win32.Foundation.PWSTR, ppszOutString: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_SET_UNKNOWN_PROPERTIES(hkeyClusterKey: win32more.Windows.Win32.System.Registry.HKEY, pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), pInPropertyList: VoidPtr, cbInPropertyListSize: UInt32) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_START_RESOURCE_SERVICE(pszServiceName: win32more.Windows.Win32.Foundation.PWSTR, phServiceHandle: POINTER(win32more.Windows.Win32.System.Services.SC_HANDLE)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_STOP_RESOURCE_SERVICE(pszServiceName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_STOP_SERVICE(hServiceHandle: win32more.Windows.Win32.System.Services.SC_HANDLE) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_TERMINATE_SERVICE_PROCESS_FROM_RES_DLL(dwServicePid: UInt32, bOffline: win32more.Windows.Win32.Foundation.BOOL, pdwResourceState: POINTER(UInt32), pfnLogEvent: win32more.Windows.Win32.Networking.Clustering.PLOG_EVENT_ROUTINE, hResourceHandle: IntPtr) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_VERIFY_PRIVATE_PROPERTY_LIST(pInPropertyList: VoidPtr, cbInPropertyListSize: UInt32) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_VERIFY_PROPERTY_TABLE(pPropertyTable: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_PROPERTY_ITEM), Reserved: VoidPtr, bAllowUnknownProperties: win32more.Windows.Win32.Foundation.BOOL, pInPropertyList: VoidPtr, cbInPropertyListSize: UInt32, pOutParams: POINTER(Byte)) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_VERIFY_RESOURCE_SERVICE(pszServiceName: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PRESUTIL_VERIFY_SERVICE(hServiceHandle: win32more.Windows.Win32.System.Services.SC_HANDLE) -> UInt32: ...
@winfunctype_pointer
def PRES_UTIL_VERIFY_SHUTDOWN_SAFE(flags: UInt32, reason: UInt32, pResult: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def PSET_INTERNAL_STATE(param0: IntPtr, stateType: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_APPLICATION_STATE, active: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype_pointer
def PSET_RESOURCE_INMEMORY_NODELOCAL_PROPERTIES_ROUTINE(ResourceHandle: IntPtr, propertyListBuffer: POINTER(Byte), propertyListBufferSize: UInt32) -> UInt32: ...
@winfunctype_pointer
def PSET_RESOURCE_LOCKED_MODE_EX_ROUTINE(ResourceHandle: IntPtr, LockedModeEnabled: win32more.Windows.Win32.Foundation.BOOL, LockedModeReason: UInt32, LockedModeFlags: UInt32) -> UInt32: ...
@winfunctype_pointer
def PSET_RESOURCE_LOCKED_MODE_ROUTINE(ResourceHandle: IntPtr, LockedModeEnabled: win32more.Windows.Win32.Foundation.BOOL, LockedModeReason: UInt32) -> UInt32: ...
@winfunctype_pointer
def PSET_RESOURCE_STATUS_ROUTINE(ResourceHandle: IntPtr, ResourceStatus: POINTER(win32more.Windows.Win32.Networking.Clustering.RESOURCE_STATUS)) -> UInt32: ...
@winfunctype_pointer
def PSET_RESOURCE_STATUS_ROUTINE_EX(ResourceHandle: IntPtr, ResourceStatus: POINTER(win32more.Windows.Win32.Networking.Clustering.RESOURCE_STATUS_EX)) -> UInt32: ...
@winfunctype_pointer
def PSET_RESOURCE_WPR_POLICY_ROUTINE(ResourceHandle: IntPtr, WprPolicyFlags: UInt32) -> UInt32: ...
@winfunctype_pointer
def PSIGNAL_FAILURE_ROUTINE(ResourceHandle: IntPtr, FailureType: win32more.Windows.Win32.Networking.Clustering.FAILURE_TYPE, ApplicationSpecificErrorCode: UInt32) -> UInt32: ...
@winfunctype_pointer
def PSTARTUP_EX_ROUTINE(ResourceType: win32more.Windows.Win32.Foundation.PWSTR, MinVersionSupported: UInt32, MaxVersionSupported: UInt32, MonitorCallbackFunctions: POINTER(win32more.Windows.Win32.Networking.Clustering.CLRES_CALLBACK_FUNCTION_TABLE), ResourceDllInterfaceFunctions: POINTER(POINTER(win32more.Windows.Win32.Networking.Clustering.CLRES_FUNCTION_TABLE))) -> UInt32: ...
@winfunctype_pointer
def PSTARTUP_ROUTINE(ResourceType: win32more.Windows.Win32.Foundation.PWSTR, MinVersionSupported: UInt32, MaxVersionSupported: UInt32, SetResourceStatus: win32more.Windows.Win32.Networking.Clustering.PSET_RESOURCE_STATUS_ROUTINE, LogEvent: win32more.Windows.Win32.Networking.Clustering.PLOG_EVENT_ROUTINE, FunctionTable: POINTER(POINTER(win32more.Windows.Win32.Networking.Clustering.CLRES_FUNCTION_TABLE))) -> UInt32: ...
@winfunctype_pointer
def PTERMINATE_ROUTINE(Resource: VoidPtr) -> Void: ...
@winfunctype_pointer
def PWORKER_START_ROUTINE(pWorker: POINTER(win32more.Windows.Win32.Networking.Clustering.CLUS_WORKER), lpThreadParameter: VoidPtr) -> UInt32: ...
class PaxosTagCStruct(Structure):
    __padding__PaxosTagVtable: UInt64
    __padding__NextEpochVtable: UInt64
    __padding__NextEpoch_DateTimeVtable: UInt64
    NextEpoch_DateTime_ticks: UInt64
    NextEpoch_Value: Int32
    __padding__BoundryNextEpoch: UInt32
    __padding__EpochVtable: UInt64
    __padding__Epoch_DateTimeVtable: UInt64
    Epoch_DateTime_ticks: UInt64
    Epoch_Value: Int32
    __padding__BoundryEpoch: UInt32
    Sequence: Int32
    __padding__BoundrySequence: UInt32
RESDLL_CONTEXT_OPERATION_TYPE = Int32
ResdllContextOperationTypeFailback: win32more.Windows.Win32.Networking.Clustering.RESDLL_CONTEXT_OPERATION_TYPE = 0
ResdllContextOperationTypeDrain: win32more.Windows.Win32.Networking.Clustering.RESDLL_CONTEXT_OPERATION_TYPE = 1
ResdllContextOperationTypeDrainFailure: win32more.Windows.Win32.Networking.Clustering.RESDLL_CONTEXT_OPERATION_TYPE = 2
ResdllContextOperationTypeEmbeddedFailure: win32more.Windows.Win32.Networking.Clustering.RESDLL_CONTEXT_OPERATION_TYPE = 3
ResdllContextOperationTypePreemption: win32more.Windows.Win32.Networking.Clustering.RESDLL_CONTEXT_OPERATION_TYPE = 4
ResdllContextOperationTypeNetworkDisconnect: win32more.Windows.Win32.Networking.Clustering.RESDLL_CONTEXT_OPERATION_TYPE = 5
ResdllContextOperationTypeNetworkDisconnectMoveRetry: win32more.Windows.Win32.Networking.Clustering.RESDLL_CONTEXT_OPERATION_TYPE = 6
RESOURCE_EXIT_STATE = Int32
ResourceExitStateContinue: win32more.Windows.Win32.Networking.Clustering.RESOURCE_EXIT_STATE = 0
ResourceExitStateTerminate: win32more.Windows.Win32.Networking.Clustering.RESOURCE_EXIT_STATE = 1
ResourceExitStateMax: win32more.Windows.Win32.Networking.Clustering.RESOURCE_EXIT_STATE = 2
class RESOURCE_FAILURE_INFO(Structure):
    dwRestartAttemptsRemaining: UInt32
    dwRestartPeriodRemaining: UInt32
class RESOURCE_FAILURE_INFO_BUFFER(Structure):
    dwVersion: UInt32
    Info: win32more.Windows.Win32.Networking.Clustering.RESOURCE_FAILURE_INFO
RESOURCE_MONITOR_STATE = Int32
RmonInitializing: win32more.Windows.Win32.Networking.Clustering.RESOURCE_MONITOR_STATE = 0
RmonIdle: win32more.Windows.Win32.Networking.Clustering.RESOURCE_MONITOR_STATE = 1
RmonStartingResource: win32more.Windows.Win32.Networking.Clustering.RESOURCE_MONITOR_STATE = 2
RmonInitializingResource: win32more.Windows.Win32.Networking.Clustering.RESOURCE_MONITOR_STATE = 3
RmonOnlineResource: win32more.Windows.Win32.Networking.Clustering.RESOURCE_MONITOR_STATE = 4
RmonOfflineResource: win32more.Windows.Win32.Networking.Clustering.RESOURCE_MONITOR_STATE = 5
RmonShutdownResource: win32more.Windows.Win32.Networking.Clustering.RESOURCE_MONITOR_STATE = 6
RmonDeletingResource: win32more.Windows.Win32.Networking.Clustering.RESOURCE_MONITOR_STATE = 7
RmonIsAlivePoll: win32more.Windows.Win32.Networking.Clustering.RESOURCE_MONITOR_STATE = 8
RmonLooksAlivePoll: win32more.Windows.Win32.Networking.Clustering.RESOURCE_MONITOR_STATE = 9
RmonArbitrateResource: win32more.Windows.Win32.Networking.Clustering.RESOURCE_MONITOR_STATE = 10
RmonReleaseResource: win32more.Windows.Win32.Networking.Clustering.RESOURCE_MONITOR_STATE = 11
RmonResourceControl: win32more.Windows.Win32.Networking.Clustering.RESOURCE_MONITOR_STATE = 12
RmonResourceTypeControl: win32more.Windows.Win32.Networking.Clustering.RESOURCE_MONITOR_STATE = 13
RmonTerminateResource: win32more.Windows.Win32.Networking.Clustering.RESOURCE_MONITOR_STATE = 14
RmonDeadlocked: win32more.Windows.Win32.Networking.Clustering.RESOURCE_MONITOR_STATE = 15
class RESOURCE_STATUS(Structure):
    ResourceState: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE
    CheckPoint: UInt32
    WaitHint: UInt32
    EventHandle: win32more.Windows.Win32.Foundation.HANDLE
class RESOURCE_STATUS_EX(Structure):
    ResourceState: win32more.Windows.Win32.Networking.Clustering.CLUSTER_RESOURCE_STATE
    CheckPoint: UInt32
    EventHandle: win32more.Windows.Win32.Foundation.HANDLE
    ApplicationSpecificErrorCode: UInt32
    Flags: UInt32
    WaitHint: UInt32
class RESOURCE_TERMINAL_FAILURE_INFO_BUFFER(Structure):
    isTerminalFailure: win32more.Windows.Win32.Foundation.BOOL
    restartPeriodRemaining: UInt32
class RESUTIL_FILETIME_DATA(Structure):
    Default: win32more.Windows.Win32.Foundation.FILETIME
    Minimum: win32more.Windows.Win32.Foundation.FILETIME
    Maximum: win32more.Windows.Win32.Foundation.FILETIME
class RESUTIL_LARGEINT_DATA(Structure):
    Default: Int64
    Minimum: Int64
    Maximum: Int64
class RESUTIL_PROPERTY_ITEM(Structure):
    Name: win32more.Windows.Win32.Foundation.PWSTR
    KeyName: win32more.Windows.Win32.Foundation.PWSTR
    Format: UInt32
    Anonymous: _Anonymous_e__Union
    Minimum: UInt32
    Maximum: UInt32
    Flags: UInt32
    Offset: UInt32
    class _Anonymous_e__Union(Union):
        DefaultPtr: UIntPtr
        Default: UInt32
        lpDefault: VoidPtr
        LargeIntData: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_LARGEINT_DATA)
        ULargeIntData: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_ULARGEINT_DATA)
        FileTimeData: POINTER(win32more.Windows.Win32.Networking.Clustering.RESUTIL_FILETIME_DATA)
class RESUTIL_ULARGEINT_DATA(Structure):
    Default: UInt64
    Minimum: UInt64
    Maximum: UInt64
class ResourceUtilizationInfoElement(Structure):
    PhysicalNumaId: UInt64
    CurrentMemory: UInt64
@winfunctype_pointer
def SET_APP_INSTANCE_CSV_FLAGS(ProcessHandle: win32more.Windows.Win32.Foundation.HANDLE, Mask: UInt32, Flags: UInt32) -> UInt32: ...
SR_DISK_REPLICATION_ELIGIBLE = Int32
SrDiskReplicationEligibleNone: win32more.Windows.Win32.Networking.Clustering.SR_DISK_REPLICATION_ELIGIBLE = 0
SrDiskReplicationEligibleYes: win32more.Windows.Win32.Networking.Clustering.SR_DISK_REPLICATION_ELIGIBLE = 1
SrDiskReplicationEligibleOffline: win32more.Windows.Win32.Networking.Clustering.SR_DISK_REPLICATION_ELIGIBLE = 2
SrDiskReplicationEligibleNotGpt: win32more.Windows.Win32.Networking.Clustering.SR_DISK_REPLICATION_ELIGIBLE = 3
SrDiskReplicationEligiblePartitionLayoutMismatch: win32more.Windows.Win32.Networking.Clustering.SR_DISK_REPLICATION_ELIGIBLE = 4
SrDiskReplicationEligibleInsufficientFreeSpace: win32more.Windows.Win32.Networking.Clustering.SR_DISK_REPLICATION_ELIGIBLE = 5
SrDiskReplicationEligibleNotInSameSite: win32more.Windows.Win32.Networking.Clustering.SR_DISK_REPLICATION_ELIGIBLE = 6
SrDiskReplicationEligibleInSameSite: win32more.Windows.Win32.Networking.Clustering.SR_DISK_REPLICATION_ELIGIBLE = 7
SrDiskReplicationEligibleFileSystemNotSupported: win32more.Windows.Win32.Networking.Clustering.SR_DISK_REPLICATION_ELIGIBLE = 8
SrDiskReplicationEligibleAlreadyInReplication: win32more.Windows.Win32.Networking.Clustering.SR_DISK_REPLICATION_ELIGIBLE = 9
SrDiskReplicationEligibleSameAsSpecifiedDisk: win32more.Windows.Win32.Networking.Clustering.SR_DISK_REPLICATION_ELIGIBLE = 10
SrDiskReplicationEligibleOther: win32more.Windows.Win32.Networking.Clustering.SR_DISK_REPLICATION_ELIGIBLE = 9999
SR_REPLICATED_DISK_TYPE = Int32
SrReplicatedDiskTypeNone: win32more.Windows.Win32.Networking.Clustering.SR_REPLICATED_DISK_TYPE = 0
SrReplicatedDiskTypeSource: win32more.Windows.Win32.Networking.Clustering.SR_REPLICATED_DISK_TYPE = 1
SrReplicatedDiskTypeLogSource: win32more.Windows.Win32.Networking.Clustering.SR_REPLICATED_DISK_TYPE = 2
SrReplicatedDiskTypeDestination: win32more.Windows.Win32.Networking.Clustering.SR_REPLICATED_DISK_TYPE = 3
SrReplicatedDiskTypeLogDestination: win32more.Windows.Win32.Networking.Clustering.SR_REPLICATED_DISK_TYPE = 4
SrReplicatedDiskTypeNotInParthership: win32more.Windows.Win32.Networking.Clustering.SR_REPLICATED_DISK_TYPE = 5
SrReplicatedDiskTypeLogNotInParthership: win32more.Windows.Win32.Networking.Clustering.SR_REPLICATED_DISK_TYPE = 6
SrReplicatedDiskTypeOther: win32more.Windows.Win32.Networking.Clustering.SR_REPLICATED_DISK_TYPE = 7
class SR_RESOURCE_TYPE_ADD_REPLICATION_GROUP(Structure):
    ReplicationGroupName: Char * 260
    Description: Char * 260
    LogPath: Char * 260
    MaxLogSizeInBytes: UInt64
    LogType: UInt16
    ReplicationMode: UInt32
    MinimumPartnersInSync: UInt32
    EnableWriteConsistency: win32more.Windows.Win32.Foundation.BOOLEAN
    EnableEncryption: win32more.Windows.Win32.Foundation.BOOLEAN
    EnableCompression: win32more.Windows.Win32.Foundation.BOOLEAN
    CertificateThumbprint: Char * 260
    VolumeNameCount: UInt32
    VolumeNames: Char * 260
class SR_RESOURCE_TYPE_ADD_REPLICATION_GROUP_RESULT(Structure):
    Result: UInt32
    ErrorString: Char * 260
class SR_RESOURCE_TYPE_DISK_INFO(Structure):
    Reason: win32more.Windows.Win32.Networking.Clustering.SR_DISK_REPLICATION_ELIGIBLE
    DiskGuid: Guid
class SR_RESOURCE_TYPE_ELIGIBLE_DISKS_RESULT(Structure):
    Count: UInt16
    DiskInfo: win32more.Windows.Win32.Networking.Clustering.SR_RESOURCE_TYPE_DISK_INFO * 1
class SR_RESOURCE_TYPE_QUERY_ELIGIBLE_LOGDISKS(Structure):
    DataDiskGuid: Guid
    IncludeOfflineDisks: win32more.Windows.Win32.Foundation.BOOLEAN
class SR_RESOURCE_TYPE_QUERY_ELIGIBLE_SOURCE_DATADISKS(Structure):
    DataDiskGuid: Guid
    IncludeAvailableStoargeDisks: win32more.Windows.Win32.Foundation.BOOLEAN
class SR_RESOURCE_TYPE_QUERY_ELIGIBLE_TARGET_DATADISKS(Structure):
    SourceDataDiskGuid: Guid
    TargetReplicationGroupGuid: Guid
    SkipConnectivityCheck: win32more.Windows.Win32.Foundation.BOOLEAN
    IncludeOfflineDisks: win32more.Windows.Win32.Foundation.BOOLEAN
class SR_RESOURCE_TYPE_REPLICATED_DISK(Structure):
    Type: win32more.Windows.Win32.Networking.Clustering.SR_REPLICATED_DISK_TYPE
    ClusterDiskResourceGuid: Guid
    ReplicationGroupId: Guid
    ReplicationGroupName: Char * 260
class SR_RESOURCE_TYPE_REPLICATED_DISKS_RESULT(Structure):
    Count: UInt16
    ReplicatedDisks: win32more.Windows.Win32.Networking.Clustering.SR_RESOURCE_TYPE_REPLICATED_DISK * 1
class SR_RESOURCE_TYPE_REPLICATED_PARTITION_ARRAY(Structure):
    Count: UInt32
    PartitionArray: win32more.Windows.Win32.Networking.Clustering.SR_RESOURCE_TYPE_REPLICATED_PARTITION_INFO * 1
class SR_RESOURCE_TYPE_REPLICATED_PARTITION_INFO(Structure):
    PartitionOffset: UInt64
    Capabilities: UInt32
VM_RESDLL_CONTEXT = Int32
VmResdllContextTurnOff: win32more.Windows.Win32.Networking.Clustering.VM_RESDLL_CONTEXT = 0
VmResdllContextSave: win32more.Windows.Win32.Networking.Clustering.VM_RESDLL_CONTEXT = 1
VmResdllContextShutdown: win32more.Windows.Win32.Networking.Clustering.VM_RESDLL_CONTEXT = 2
VmResdllContextShutdownForce: win32more.Windows.Win32.Networking.Clustering.VM_RESDLL_CONTEXT = 3
VmResdllContextLiveMigration: win32more.Windows.Win32.Networking.Clustering.VM_RESDLL_CONTEXT = 4
class WitnessTagHelper(Structure):
    Version: Int32
    paxosToValidate: win32more.Windows.Win32.Networking.Clustering.PaxosTagCStruct
class WitnessTagUpdateHelper(Structure):
    Version: Int32
    paxosToSet: win32more.Windows.Win32.Networking.Clustering.PaxosTagCStruct
    paxosToValidate: win32more.Windows.Win32.Networking.Clustering.PaxosTagCStruct


make_ready(__name__)
