from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Direct3D
import win32more.Windows.Win32.Graphics.Direct3D11
import win32more.Windows.Win32.Graphics.Dxgi
import win32more.Windows.Win32.Graphics.Dxgi.Common
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.System.Com
D3D11_16BIT_INDEX_STRIP_CUT_VALUE: UInt32 = 65535
D3D11_32BIT_INDEX_STRIP_CUT_VALUE: UInt32 = 4294967295
D3D11_8BIT_INDEX_STRIP_CUT_VALUE: UInt32 = 255
D3D11_ARRAY_AXIS_ADDRESS_RANGE_BIT_COUNT: UInt32 = 9
D3D11_CLIP_OR_CULL_DISTANCE_COUNT: UInt32 = 8
D3D11_CLIP_OR_CULL_DISTANCE_ELEMENT_COUNT: UInt32 = 2
D3D11_COMMONSHADER_CONSTANT_BUFFER_API_SLOT_COUNT: UInt32 = 14
D3D11_COMMONSHADER_CONSTANT_BUFFER_COMPONENTS: UInt32 = 4
D3D11_COMMONSHADER_CONSTANT_BUFFER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_COMMONSHADER_CONSTANT_BUFFER_HW_SLOT_COUNT: UInt32 = 15
D3D11_COMMONSHADER_CONSTANT_BUFFER_PARTIAL_UPDATE_EXTENTS_BYTE_ALIGNMENT: UInt32 = 16
D3D11_COMMONSHADER_CONSTANT_BUFFER_REGISTER_COMPONENTS: UInt32 = 4
D3D11_COMMONSHADER_CONSTANT_BUFFER_REGISTER_COUNT: UInt32 = 15
D3D11_COMMONSHADER_CONSTANT_BUFFER_REGISTER_READS_PER_INST: UInt32 = 1
D3D11_COMMONSHADER_CONSTANT_BUFFER_REGISTER_READ_PORTS: UInt32 = 1
D3D11_COMMONSHADER_FLOWCONTROL_NESTING_LIMIT: UInt32 = 64
D3D11_COMMONSHADER_IMMEDIATE_CONSTANT_BUFFER_REGISTER_COMPONENTS: UInt32 = 4
D3D11_COMMONSHADER_IMMEDIATE_CONSTANT_BUFFER_REGISTER_COUNT: UInt32 = 1
D3D11_COMMONSHADER_IMMEDIATE_CONSTANT_BUFFER_REGISTER_READS_PER_INST: UInt32 = 1
D3D11_COMMONSHADER_IMMEDIATE_CONSTANT_BUFFER_REGISTER_READ_PORTS: UInt32 = 1
D3D11_COMMONSHADER_IMMEDIATE_VALUE_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_COMMONSHADER_INPUT_RESOURCE_REGISTER_COMPONENTS: UInt32 = 1
D3D11_COMMONSHADER_INPUT_RESOURCE_REGISTER_COUNT: UInt32 = 128
D3D11_COMMONSHADER_INPUT_RESOURCE_REGISTER_READS_PER_INST: UInt32 = 1
D3D11_COMMONSHADER_INPUT_RESOURCE_REGISTER_READ_PORTS: UInt32 = 1
D3D11_COMMONSHADER_INPUT_RESOURCE_SLOT_COUNT: UInt32 = 128
D3D11_COMMONSHADER_SAMPLER_REGISTER_COMPONENTS: UInt32 = 1
D3D11_COMMONSHADER_SAMPLER_REGISTER_COUNT: UInt32 = 16
D3D11_COMMONSHADER_SAMPLER_REGISTER_READS_PER_INST: UInt32 = 1
D3D11_COMMONSHADER_SAMPLER_REGISTER_READ_PORTS: UInt32 = 1
D3D11_COMMONSHADER_SAMPLER_SLOT_COUNT: UInt32 = 16
D3D11_COMMONSHADER_SUBROUTINE_NESTING_LIMIT: UInt32 = 32
D3D11_COMMONSHADER_TEMP_REGISTER_COMPONENTS: UInt32 = 4
D3D11_COMMONSHADER_TEMP_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_COMMONSHADER_TEMP_REGISTER_COUNT: UInt32 = 4096
D3D11_COMMONSHADER_TEMP_REGISTER_READS_PER_INST: UInt32 = 3
D3D11_COMMONSHADER_TEMP_REGISTER_READ_PORTS: UInt32 = 3
D3D11_COMMONSHADER_TEXCOORD_RANGE_REDUCTION_MAX: UInt32 = 10
D3D11_COMMONSHADER_TEXCOORD_RANGE_REDUCTION_MIN: Int32 = -10
D3D11_COMMONSHADER_TEXEL_OFFSET_MAX_NEGATIVE: Int32 = -8
D3D11_COMMONSHADER_TEXEL_OFFSET_MAX_POSITIVE: UInt32 = 7
D3D11_CS_4_X_BUCKET00_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 256
D3D11_CS_4_X_BUCKET00_MAX_NUM_THREADS_PER_GROUP: UInt32 = 64
D3D11_CS_4_X_BUCKET01_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 240
D3D11_CS_4_X_BUCKET01_MAX_NUM_THREADS_PER_GROUP: UInt32 = 68
D3D11_CS_4_X_BUCKET02_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 224
D3D11_CS_4_X_BUCKET02_MAX_NUM_THREADS_PER_GROUP: UInt32 = 72
D3D11_CS_4_X_BUCKET03_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 208
D3D11_CS_4_X_BUCKET03_MAX_NUM_THREADS_PER_GROUP: UInt32 = 76
D3D11_CS_4_X_BUCKET04_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 192
D3D11_CS_4_X_BUCKET04_MAX_NUM_THREADS_PER_GROUP: UInt32 = 84
D3D11_CS_4_X_BUCKET05_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 176
D3D11_CS_4_X_BUCKET05_MAX_NUM_THREADS_PER_GROUP: UInt32 = 92
D3D11_CS_4_X_BUCKET06_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 160
D3D11_CS_4_X_BUCKET06_MAX_NUM_THREADS_PER_GROUP: UInt32 = 100
D3D11_CS_4_X_BUCKET07_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 144
D3D11_CS_4_X_BUCKET07_MAX_NUM_THREADS_PER_GROUP: UInt32 = 112
D3D11_CS_4_X_BUCKET08_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 128
D3D11_CS_4_X_BUCKET08_MAX_NUM_THREADS_PER_GROUP: UInt32 = 128
D3D11_CS_4_X_BUCKET09_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 112
D3D11_CS_4_X_BUCKET09_MAX_NUM_THREADS_PER_GROUP: UInt32 = 144
D3D11_CS_4_X_BUCKET10_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 96
D3D11_CS_4_X_BUCKET10_MAX_NUM_THREADS_PER_GROUP: UInt32 = 168
D3D11_CS_4_X_BUCKET11_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 80
D3D11_CS_4_X_BUCKET11_MAX_NUM_THREADS_PER_GROUP: UInt32 = 204
D3D11_CS_4_X_BUCKET12_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 64
D3D11_CS_4_X_BUCKET12_MAX_NUM_THREADS_PER_GROUP: UInt32 = 256
D3D11_CS_4_X_BUCKET13_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 48
D3D11_CS_4_X_BUCKET13_MAX_NUM_THREADS_PER_GROUP: UInt32 = 340
D3D11_CS_4_X_BUCKET14_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 32
D3D11_CS_4_X_BUCKET14_MAX_NUM_THREADS_PER_GROUP: UInt32 = 512
D3D11_CS_4_X_BUCKET15_MAX_BYTES_TGSM_WRITABLE_PER_THREAD: UInt32 = 16
D3D11_CS_4_X_BUCKET15_MAX_NUM_THREADS_PER_GROUP: UInt32 = 768
D3D11_CS_4_X_DISPATCH_MAX_THREAD_GROUPS_IN_Z_DIMENSION: UInt32 = 1
D3D11_CS_4_X_RAW_UAV_BYTE_ALIGNMENT: UInt32 = 256
D3D11_CS_4_X_THREAD_GROUP_MAX_THREADS_PER_GROUP: UInt32 = 768
D3D11_CS_4_X_THREAD_GROUP_MAX_X: UInt32 = 768
D3D11_CS_4_X_THREAD_GROUP_MAX_Y: UInt32 = 768
D3D11_CS_4_X_UAV_REGISTER_COUNT: UInt32 = 1
D3D11_CS_DISPATCH_MAX_THREAD_GROUPS_PER_DIMENSION: UInt32 = 65535
D3D11_CS_TGSM_REGISTER_COUNT: UInt32 = 8192
D3D11_CS_TGSM_REGISTER_READS_PER_INST: UInt32 = 1
D3D11_CS_TGSM_RESOURCE_REGISTER_COMPONENTS: UInt32 = 1
D3D11_CS_TGSM_RESOURCE_REGISTER_READ_PORTS: UInt32 = 1
D3D11_CS_THREADGROUPID_REGISTER_COMPONENTS: UInt32 = 3
D3D11_CS_THREADGROUPID_REGISTER_COUNT: UInt32 = 1
D3D11_CS_THREADIDINGROUPFLATTENED_REGISTER_COMPONENTS: UInt32 = 1
D3D11_CS_THREADIDINGROUPFLATTENED_REGISTER_COUNT: UInt32 = 1
D3D11_CS_THREADIDINGROUP_REGISTER_COMPONENTS: UInt32 = 3
D3D11_CS_THREADIDINGROUP_REGISTER_COUNT: UInt32 = 1
D3D11_CS_THREADID_REGISTER_COMPONENTS: UInt32 = 3
D3D11_CS_THREADID_REGISTER_COUNT: UInt32 = 1
D3D11_CS_THREAD_GROUP_MAX_THREADS_PER_GROUP: UInt32 = 1024
D3D11_CS_THREAD_GROUP_MAX_X: UInt32 = 1024
D3D11_CS_THREAD_GROUP_MAX_Y: UInt32 = 1024
D3D11_CS_THREAD_GROUP_MAX_Z: UInt32 = 64
D3D11_CS_THREAD_GROUP_MIN_X: UInt32 = 1
D3D11_CS_THREAD_GROUP_MIN_Y: UInt32 = 1
D3D11_CS_THREAD_GROUP_MIN_Z: UInt32 = 1
D3D11_CS_THREAD_LOCAL_TEMP_REGISTER_POOL: UInt32 = 16384
D3D11_DEFAULT_BLEND_FACTOR_ALPHA: Single = 1
D3D11_DEFAULT_BLEND_FACTOR_BLUE: Single = 1
D3D11_DEFAULT_BLEND_FACTOR_GREEN: Single = 1
D3D11_DEFAULT_BLEND_FACTOR_RED: Single = 1
D3D11_DEFAULT_BORDER_COLOR_COMPONENT: Single = 0
D3D11_DEFAULT_DEPTH_BIAS: UInt32 = 0
D3D11_DEFAULT_DEPTH_BIAS_CLAMP: Single = 0
D3D11_DEFAULT_MAX_ANISOTROPY: UInt32 = 16
D3D11_DEFAULT_MIP_LOD_BIAS: Single = 0
D3D11_DEFAULT_RENDER_TARGET_ARRAY_INDEX: UInt32 = 0
D3D11_DEFAULT_SAMPLE_MASK: UInt32 = 4294967295
D3D11_DEFAULT_SCISSOR_ENDX: UInt32 = 0
D3D11_DEFAULT_SCISSOR_ENDY: UInt32 = 0
D3D11_DEFAULT_SCISSOR_STARTX: UInt32 = 0
D3D11_DEFAULT_SCISSOR_STARTY: UInt32 = 0
D3D11_DEFAULT_SLOPE_SCALED_DEPTH_BIAS: Single = 0
D3D11_DEFAULT_STENCIL_READ_MASK: UInt32 = 255
D3D11_DEFAULT_STENCIL_REFERENCE: UInt32 = 0
D3D11_DEFAULT_STENCIL_WRITE_MASK: UInt32 = 255
D3D11_DEFAULT_VIEWPORT_AND_SCISSORRECT_INDEX: UInt32 = 0
D3D11_DEFAULT_VIEWPORT_HEIGHT: UInt32 = 0
D3D11_DEFAULT_VIEWPORT_MAX_DEPTH: Single = 0
D3D11_DEFAULT_VIEWPORT_MIN_DEPTH: Single = 0
D3D11_DEFAULT_VIEWPORT_TOPLEFTX: UInt32 = 0
D3D11_DEFAULT_VIEWPORT_TOPLEFTY: UInt32 = 0
D3D11_DEFAULT_VIEWPORT_WIDTH: UInt32 = 0
D3D11_DS_INPUT_CONTROL_POINTS_MAX_TOTAL_SCALARS: UInt32 = 3968
D3D11_DS_INPUT_CONTROL_POINT_REGISTER_COMPONENTS: UInt32 = 4
D3D11_DS_INPUT_CONTROL_POINT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_DS_INPUT_CONTROL_POINT_REGISTER_COUNT: UInt32 = 32
D3D11_DS_INPUT_CONTROL_POINT_REGISTER_READS_PER_INST: UInt32 = 2
D3D11_DS_INPUT_CONTROL_POINT_REGISTER_READ_PORTS: UInt32 = 1
D3D11_DS_INPUT_DOMAIN_POINT_REGISTER_COMPONENTS: UInt32 = 3
D3D11_DS_INPUT_DOMAIN_POINT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_DS_INPUT_DOMAIN_POINT_REGISTER_COUNT: UInt32 = 1
D3D11_DS_INPUT_DOMAIN_POINT_REGISTER_READS_PER_INST: UInt32 = 2
D3D11_DS_INPUT_DOMAIN_POINT_REGISTER_READ_PORTS: UInt32 = 1
D3D11_DS_INPUT_PATCH_CONSTANT_REGISTER_COMPONENTS: UInt32 = 4
D3D11_DS_INPUT_PATCH_CONSTANT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_DS_INPUT_PATCH_CONSTANT_REGISTER_COUNT: UInt32 = 32
D3D11_DS_INPUT_PATCH_CONSTANT_REGISTER_READS_PER_INST: UInt32 = 2
D3D11_DS_INPUT_PATCH_CONSTANT_REGISTER_READ_PORTS: UInt32 = 1
D3D11_DS_INPUT_PRIMITIVE_ID_REGISTER_COMPONENTS: UInt32 = 1
D3D11_DS_INPUT_PRIMITIVE_ID_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_DS_INPUT_PRIMITIVE_ID_REGISTER_COUNT: UInt32 = 1
D3D11_DS_INPUT_PRIMITIVE_ID_REGISTER_READS_PER_INST: UInt32 = 2
D3D11_DS_INPUT_PRIMITIVE_ID_REGISTER_READ_PORTS: UInt32 = 1
D3D11_DS_OUTPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D11_DS_OUTPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_DS_OUTPUT_REGISTER_COUNT: UInt32 = 32
D3D11_FLOAT16_FUSED_TOLERANCE_IN_ULP: Double = 0.6
D3D11_FLOAT32_MAX: Single = 3.4028235e+38
D3D11_FLOAT32_TO_INTEGER_TOLERANCE_IN_ULP: Single = 0.6
D3D11_FLOAT_TO_SRGB_EXPONENT_DENOMINATOR: Single = 2.4
D3D11_FLOAT_TO_SRGB_EXPONENT_NUMERATOR: Single = 1
D3D11_FLOAT_TO_SRGB_OFFSET: Single = 0.055
D3D11_FLOAT_TO_SRGB_SCALE_1: Single = 12.92
D3D11_FLOAT_TO_SRGB_SCALE_2: Single = 1.055
D3D11_FLOAT_TO_SRGB_THRESHOLD: Single = 0.0031308
D3D11_FTOI_INSTRUCTION_MAX_INPUT: Single = 2147483600.0
D3D11_FTOI_INSTRUCTION_MIN_INPUT: Single = -2147483600.0
D3D11_FTOU_INSTRUCTION_MAX_INPUT: Single = 4294967300.0
D3D11_FTOU_INSTRUCTION_MIN_INPUT: Single = 0
D3D11_GS_INPUT_INSTANCE_ID_READS_PER_INST: UInt32 = 2
D3D11_GS_INPUT_INSTANCE_ID_READ_PORTS: UInt32 = 1
D3D11_GS_INPUT_INSTANCE_ID_REGISTER_COMPONENTS: UInt32 = 1
D3D11_GS_INPUT_INSTANCE_ID_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_GS_INPUT_INSTANCE_ID_REGISTER_COUNT: UInt32 = 1
D3D11_GS_INPUT_PRIM_CONST_REGISTER_COMPONENTS: UInt32 = 1
D3D11_GS_INPUT_PRIM_CONST_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_GS_INPUT_PRIM_CONST_REGISTER_COUNT: UInt32 = 1
D3D11_GS_INPUT_PRIM_CONST_REGISTER_READS_PER_INST: UInt32 = 2
D3D11_GS_INPUT_PRIM_CONST_REGISTER_READ_PORTS: UInt32 = 1
D3D11_GS_INPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D11_GS_INPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_GS_INPUT_REGISTER_COUNT: UInt32 = 32
D3D11_GS_INPUT_REGISTER_READS_PER_INST: UInt32 = 2
D3D11_GS_INPUT_REGISTER_READ_PORTS: UInt32 = 1
D3D11_GS_INPUT_REGISTER_VERTICES: UInt32 = 32
D3D11_GS_MAX_INSTANCE_COUNT: UInt32 = 32
D3D11_GS_MAX_OUTPUT_VERTEX_COUNT_ACROSS_INSTANCES: UInt32 = 1024
D3D11_GS_OUTPUT_ELEMENTS: UInt32 = 32
D3D11_GS_OUTPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D11_GS_OUTPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_GS_OUTPUT_REGISTER_COUNT: UInt32 = 32
D3D11_HS_CONTROL_POINT_PHASE_INPUT_REGISTER_COUNT: UInt32 = 32
D3D11_HS_CONTROL_POINT_PHASE_OUTPUT_REGISTER_COUNT: UInt32 = 32
D3D11_HS_CONTROL_POINT_REGISTER_COMPONENTS: UInt32 = 4
D3D11_HS_CONTROL_POINT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_HS_CONTROL_POINT_REGISTER_READS_PER_INST: UInt32 = 2
D3D11_HS_CONTROL_POINT_REGISTER_READ_PORTS: UInt32 = 1
D3D11_HS_FORK_PHASE_INSTANCE_COUNT_UPPER_BOUND: UInt32 = 4294967295
D3D11_HS_INPUT_FORK_INSTANCE_ID_REGISTER_COMPONENTS: UInt32 = 1
D3D11_HS_INPUT_FORK_INSTANCE_ID_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_HS_INPUT_FORK_INSTANCE_ID_REGISTER_COUNT: UInt32 = 1
D3D11_HS_INPUT_FORK_INSTANCE_ID_REGISTER_READS_PER_INST: UInt32 = 2
D3D11_HS_INPUT_FORK_INSTANCE_ID_REGISTER_READ_PORTS: UInt32 = 1
D3D11_HS_INPUT_JOIN_INSTANCE_ID_REGISTER_COMPONENTS: UInt32 = 1
D3D11_HS_INPUT_JOIN_INSTANCE_ID_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_HS_INPUT_JOIN_INSTANCE_ID_REGISTER_COUNT: UInt32 = 1
D3D11_HS_INPUT_JOIN_INSTANCE_ID_REGISTER_READS_PER_INST: UInt32 = 2
D3D11_HS_INPUT_JOIN_INSTANCE_ID_REGISTER_READ_PORTS: UInt32 = 1
D3D11_HS_INPUT_PRIMITIVE_ID_REGISTER_COMPONENTS: UInt32 = 1
D3D11_HS_INPUT_PRIMITIVE_ID_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_HS_INPUT_PRIMITIVE_ID_REGISTER_COUNT: UInt32 = 1
D3D11_HS_INPUT_PRIMITIVE_ID_REGISTER_READS_PER_INST: UInt32 = 2
D3D11_HS_INPUT_PRIMITIVE_ID_REGISTER_READ_PORTS: UInt32 = 1
D3D11_HS_JOIN_PHASE_INSTANCE_COUNT_UPPER_BOUND: UInt32 = 4294967295
D3D11_HS_MAXTESSFACTOR_LOWER_BOUND: Single = 1
D3D11_HS_MAXTESSFACTOR_UPPER_BOUND: Single = 64
D3D11_HS_OUTPUT_CONTROL_POINTS_MAX_TOTAL_SCALARS: UInt32 = 3968
D3D11_HS_OUTPUT_CONTROL_POINT_ID_REGISTER_COMPONENTS: UInt32 = 1
D3D11_HS_OUTPUT_CONTROL_POINT_ID_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_HS_OUTPUT_CONTROL_POINT_ID_REGISTER_COUNT: UInt32 = 1
D3D11_HS_OUTPUT_CONTROL_POINT_ID_REGISTER_READS_PER_INST: UInt32 = 2
D3D11_HS_OUTPUT_CONTROL_POINT_ID_REGISTER_READ_PORTS: UInt32 = 1
D3D11_HS_OUTPUT_PATCH_CONSTANT_REGISTER_COMPONENTS: UInt32 = 4
D3D11_HS_OUTPUT_PATCH_CONSTANT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_HS_OUTPUT_PATCH_CONSTANT_REGISTER_COUNT: UInt32 = 32
D3D11_HS_OUTPUT_PATCH_CONSTANT_REGISTER_READS_PER_INST: UInt32 = 2
D3D11_HS_OUTPUT_PATCH_CONSTANT_REGISTER_READ_PORTS: UInt32 = 1
D3D11_HS_OUTPUT_PATCH_CONSTANT_REGISTER_SCALAR_COMPONENTS: UInt32 = 128
D3D11_IA_DEFAULT_INDEX_BUFFER_OFFSET_IN_BYTES: UInt32 = 0
D3D11_IA_DEFAULT_PRIMITIVE_TOPOLOGY: UInt32 = 0
D3D11_IA_DEFAULT_VERTEX_BUFFER_OFFSET_IN_BYTES: UInt32 = 0
D3D11_IA_INDEX_INPUT_RESOURCE_SLOT_COUNT: UInt32 = 1
D3D11_IA_INSTANCE_ID_BIT_COUNT: UInt32 = 32
D3D11_IA_INTEGER_ARITHMETIC_BIT_COUNT: UInt32 = 32
D3D11_IA_PATCH_MAX_CONTROL_POINT_COUNT: UInt32 = 32
D3D11_IA_PRIMITIVE_ID_BIT_COUNT: UInt32 = 32
D3D11_IA_VERTEX_ID_BIT_COUNT: UInt32 = 32
D3D11_IA_VERTEX_INPUT_RESOURCE_SLOT_COUNT: UInt32 = 32
D3D11_IA_VERTEX_INPUT_STRUCTURE_ELEMENTS_COMPONENTS: UInt32 = 128
D3D11_IA_VERTEX_INPUT_STRUCTURE_ELEMENT_COUNT: UInt32 = 32
D3D11_INTEGER_DIVIDE_BY_ZERO_QUOTIENT: UInt32 = 4294967295
D3D11_INTEGER_DIVIDE_BY_ZERO_REMAINDER: UInt32 = 4294967295
D3D11_KEEP_RENDER_TARGETS_AND_DEPTH_STENCIL: UInt32 = 4294967295
D3D11_KEEP_UNORDERED_ACCESS_VIEWS: UInt32 = 4294967295
D3D11_LINEAR_GAMMA: Single = 1
D3D11_MAJOR_VERSION: UInt32 = 11
D3D11_MAX_BORDER_COLOR_COMPONENT: Single = 1
D3D11_MAX_DEPTH: Single = 1
D3D11_MAX_MAXANISOTROPY: UInt32 = 16
D3D11_MAX_MULTISAMPLE_SAMPLE_COUNT: UInt32 = 32
D3D11_MAX_POSITION_VALUE: Single = 3.4028236e+34
D3D11_MAX_TEXTURE_DIMENSION_2_TO_EXP: UInt32 = 17
D3D11_MINOR_VERSION: UInt32 = 0
D3D11_MIN_BORDER_COLOR_COMPONENT: Single = 0
D3D11_MIN_DEPTH: Single = 0
D3D11_MIN_MAXANISOTROPY: UInt32 = 0
D3D11_MIP_LOD_BIAS_MAX: Single = 15.99
D3D11_MIP_LOD_BIAS_MIN: Single = -16
D3D11_MIP_LOD_FRACTIONAL_BIT_COUNT: UInt32 = 8
D3D11_MIP_LOD_RANGE_BIT_COUNT: UInt32 = 8
D3D11_MULTISAMPLE_ANTIALIAS_LINE_WIDTH: Single = 1.4
D3D11_NONSAMPLE_FETCH_OUT_OF_RANGE_ACCESS_RESULT: UInt32 = 0
D3D11_PIXEL_ADDRESS_RANGE_BIT_COUNT: UInt32 = 15
D3D11_PRE_SCISSOR_PIXEL_ADDRESS_RANGE_BIT_COUNT: UInt32 = 16
D3D11_PS_CS_UAV_REGISTER_COMPONENTS: UInt32 = 1
D3D11_PS_CS_UAV_REGISTER_COUNT: UInt32 = 8
D3D11_PS_CS_UAV_REGISTER_READS_PER_INST: UInt32 = 1
D3D11_PS_CS_UAV_REGISTER_READ_PORTS: UInt32 = 1
D3D11_PS_FRONTFACING_DEFAULT_VALUE: UInt32 = 4294967295
D3D11_PS_FRONTFACING_FALSE_VALUE: UInt32 = 0
D3D11_PS_FRONTFACING_TRUE_VALUE: UInt32 = 4294967295
D3D11_PS_INPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D11_PS_INPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_PS_INPUT_REGISTER_COUNT: UInt32 = 32
D3D11_PS_INPUT_REGISTER_READS_PER_INST: UInt32 = 2
D3D11_PS_INPUT_REGISTER_READ_PORTS: UInt32 = 1
D3D11_PS_LEGACY_PIXEL_CENTER_FRACTIONAL_COMPONENT: Single = 0
D3D11_PS_OUTPUT_DEPTH_REGISTER_COMPONENTS: UInt32 = 1
D3D11_PS_OUTPUT_DEPTH_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_PS_OUTPUT_DEPTH_REGISTER_COUNT: UInt32 = 1
D3D11_PS_OUTPUT_MASK_REGISTER_COMPONENTS: UInt32 = 1
D3D11_PS_OUTPUT_MASK_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_PS_OUTPUT_MASK_REGISTER_COUNT: UInt32 = 1
D3D11_PS_OUTPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D11_PS_OUTPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_PS_OUTPUT_REGISTER_COUNT: UInt32 = 8
D3D11_PS_PIXEL_CENTER_FRACTIONAL_COMPONENT: Single = 0.5
D3D11_RAW_UAV_SRV_BYTE_ALIGNMENT: UInt32 = 16
D3D11_REQ_BLEND_OBJECT_COUNT_PER_DEVICE: UInt32 = 4096
D3D11_REQ_BUFFER_RESOURCE_TEXEL_COUNT_2_TO_EXP: UInt32 = 27
D3D11_REQ_CONSTANT_BUFFER_ELEMENT_COUNT: UInt32 = 4096
D3D11_REQ_DEPTH_STENCIL_OBJECT_COUNT_PER_DEVICE: UInt32 = 4096
D3D11_REQ_DRAWINDEXED_INDEX_COUNT_2_TO_EXP: UInt32 = 32
D3D11_REQ_DRAW_VERTEX_COUNT_2_TO_EXP: UInt32 = 32
D3D11_REQ_FILTERING_HW_ADDRESSABLE_RESOURCE_DIMENSION: UInt32 = 16384
D3D11_REQ_GS_INVOCATION_32BIT_OUTPUT_COMPONENT_LIMIT: UInt32 = 1024
D3D11_REQ_IMMEDIATE_CONSTANT_BUFFER_ELEMENT_COUNT: UInt32 = 4096
D3D11_REQ_MAXANISOTROPY: UInt32 = 16
D3D11_REQ_MIP_LEVELS: UInt32 = 15
D3D11_REQ_MULTI_ELEMENT_STRUCTURE_SIZE_IN_BYTES: UInt32 = 2048
D3D11_REQ_RASTERIZER_OBJECT_COUNT_PER_DEVICE: UInt32 = 4096
D3D11_REQ_RENDER_TO_BUFFER_WINDOW_WIDTH: UInt32 = 16384
D3D11_REQ_RESOURCE_SIZE_IN_MEGABYTES_EXPRESSION_A_TERM: UInt32 = 128
D3D11_REQ_RESOURCE_SIZE_IN_MEGABYTES_EXPRESSION_B_TERM: Single = 0.25
D3D11_REQ_RESOURCE_SIZE_IN_MEGABYTES_EXPRESSION_C_TERM: UInt32 = 2048
D3D11_REQ_RESOURCE_VIEW_COUNT_PER_DEVICE_2_TO_EXP: UInt32 = 20
D3D11_REQ_SAMPLER_OBJECT_COUNT_PER_DEVICE: UInt32 = 4096
D3D11_REQ_TEXTURE1D_ARRAY_AXIS_DIMENSION: UInt32 = 2048
D3D11_REQ_TEXTURE1D_U_DIMENSION: UInt32 = 16384
D3D11_REQ_TEXTURE2D_ARRAY_AXIS_DIMENSION: UInt32 = 2048
D3D11_REQ_TEXTURE2D_U_OR_V_DIMENSION: UInt32 = 16384
D3D11_REQ_TEXTURE3D_U_V_OR_W_DIMENSION: UInt32 = 2048
D3D11_REQ_TEXTURECUBE_DIMENSION: UInt32 = 16384
D3D11_RESINFO_INSTRUCTION_MISSING_COMPONENT_RETVAL: UInt32 = 0
D3D11_SHADER_MAJOR_VERSION: UInt32 = 5
D3D11_SHADER_MAX_INSTANCES: UInt32 = 65535
D3D11_SHADER_MAX_INTERFACES: UInt32 = 253
D3D11_SHADER_MAX_INTERFACE_CALL_SITES: UInt32 = 4096
D3D11_SHADER_MAX_TYPES: UInt32 = 65535
D3D11_SHADER_MINOR_VERSION: UInt32 = 0
D3D11_SHIFT_INSTRUCTION_PAD_VALUE: UInt32 = 0
D3D11_SHIFT_INSTRUCTION_SHIFT_VALUE_BIT_COUNT: UInt32 = 5
D3D11_SIMULTANEOUS_RENDER_TARGET_COUNT: UInt32 = 8
D3D11_SO_BUFFER_MAX_STRIDE_IN_BYTES: UInt32 = 2048
D3D11_SO_BUFFER_MAX_WRITE_WINDOW_IN_BYTES: UInt32 = 512
D3D11_SO_BUFFER_SLOT_COUNT: UInt32 = 4
D3D11_SO_DDI_REGISTER_INDEX_DENOTING_GAP: UInt32 = 4294967295
D3D11_SO_NO_RASTERIZED_STREAM: UInt32 = 4294967295
D3D11_SO_OUTPUT_COMPONENT_COUNT: UInt32 = 128
D3D11_SO_STREAM_COUNT: UInt32 = 4
D3D11_SPEC_DATE_DAY: UInt32 = 16
D3D11_SPEC_DATE_MONTH: UInt32 = 5
D3D11_SPEC_DATE_YEAR: UInt32 = 2011
D3D11_SPEC_VERSION: Double = 1.07
D3D11_SRGB_GAMMA: Single = 2.2
D3D11_SRGB_TO_FLOAT_DENOMINATOR_1: Single = 12.92
D3D11_SRGB_TO_FLOAT_DENOMINATOR_2: Single = 1.055
D3D11_SRGB_TO_FLOAT_EXPONENT: Single = 2.4
D3D11_SRGB_TO_FLOAT_OFFSET: Single = 0.055
D3D11_SRGB_TO_FLOAT_THRESHOLD: Single = 0.04045
D3D11_SRGB_TO_FLOAT_TOLERANCE_IN_ULP: Single = 0.5
D3D11_STANDARD_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_STANDARD_COMPONENT_BIT_COUNT_DOUBLED: UInt32 = 64
D3D11_STANDARD_MAXIMUM_ELEMENT_ALIGNMENT_BYTE_MULTIPLE: UInt32 = 4
D3D11_STANDARD_PIXEL_COMPONENT_COUNT: UInt32 = 128
D3D11_STANDARD_PIXEL_ELEMENT_COUNT: UInt32 = 32
D3D11_STANDARD_VECTOR_SIZE: UInt32 = 4
D3D11_STANDARD_VERTEX_ELEMENT_COUNT: UInt32 = 32
D3D11_STANDARD_VERTEX_TOTAL_COMPONENT_COUNT: UInt32 = 64
D3D11_SUBPIXEL_FRACTIONAL_BIT_COUNT: UInt32 = 8
D3D11_SUBTEXEL_FRACTIONAL_BIT_COUNT: UInt32 = 8
D3D11_TESSELLATOR_MAX_EVEN_TESSELLATION_FACTOR: UInt32 = 64
D3D11_TESSELLATOR_MAX_ISOLINE_DENSITY_TESSELLATION_FACTOR: UInt32 = 64
D3D11_TESSELLATOR_MAX_ODD_TESSELLATION_FACTOR: UInt32 = 63
D3D11_TESSELLATOR_MAX_TESSELLATION_FACTOR: UInt32 = 64
D3D11_TESSELLATOR_MIN_EVEN_TESSELLATION_FACTOR: UInt32 = 2
D3D11_TESSELLATOR_MIN_ISOLINE_DENSITY_TESSELLATION_FACTOR: UInt32 = 1
D3D11_TESSELLATOR_MIN_ODD_TESSELLATION_FACTOR: UInt32 = 1
D3D11_TEXEL_ADDRESS_RANGE_BIT_COUNT: UInt32 = 16
D3D11_UNBOUND_MEMORY_ACCESS_RESULT: UInt32 = 0
D3D11_VIEWPORT_AND_SCISSORRECT_MAX_INDEX: UInt32 = 15
D3D11_VIEWPORT_AND_SCISSORRECT_OBJECT_COUNT_PER_PIPELINE: UInt32 = 16
D3D11_VIEWPORT_BOUNDS_MAX: UInt32 = 32767
D3D11_VIEWPORT_BOUNDS_MIN: Int32 = -32768
D3D11_VS_INPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D11_VS_INPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_VS_INPUT_REGISTER_COUNT: UInt32 = 32
D3D11_VS_INPUT_REGISTER_READS_PER_INST: UInt32 = 2
D3D11_VS_INPUT_REGISTER_READ_PORTS: UInt32 = 1
D3D11_VS_OUTPUT_REGISTER_COMPONENTS: UInt32 = 4
D3D11_VS_OUTPUT_REGISTER_COMPONENT_BIT_COUNT: UInt32 = 32
D3D11_VS_OUTPUT_REGISTER_COUNT: UInt32 = 32
D3D11_WHQL_CONTEXT_COUNT_FOR_RESOURCE_LIMIT: UInt32 = 10
D3D11_WHQL_DRAWINDEXED_INDEX_COUNT_2_TO_EXP: UInt32 = 25
D3D11_WHQL_DRAW_VERTEX_COUNT_2_TO_EXP: UInt32 = 25
D3D11_1_UAV_SLOT_COUNT: UInt32 = 64
D3D11_2_TILED_RESOURCE_TILE_SIZE_IN_BYTES: UInt32 = 65536
D3D11_4_VIDEO_DECODER_MAX_HISTOGRAM_COMPONENTS: UInt32 = 4
D3D11_4_VIDEO_DECODER_HISTOGRAM_OFFSET_ALIGNMENT: UInt32 = 256
_FACD3D11: UInt32 = 2172
D3D11_APPEND_ALIGNED_ELEMENT: UInt32 = 4294967295
D3D11_FILTER_REDUCTION_TYPE_MASK: UInt32 = 3
D3D11_FILTER_REDUCTION_TYPE_SHIFT: UInt32 = 7
D3D11_FILTER_TYPE_MASK: UInt32 = 3
D3D11_MIN_FILTER_SHIFT: UInt32 = 4
D3D11_MAG_FILTER_SHIFT: UInt32 = 2
D3D11_MIP_FILTER_SHIFT: UInt32 = 0
D3D11_COMPARISON_FILTERING_BIT: UInt32 = 128
D3D11_ANISOTROPIC_FILTERING_BIT: UInt32 = 64
D3D11_DECODER_PROFILE_MPEG2_MOCOMP: Guid = Guid('{e6a9f44b-61b0-4563-9ea4-63d2a3c6fe66}')
D3D11_DECODER_PROFILE_MPEG2_IDCT: Guid = Guid('{bf22ad00-03ea-4690-8077-473346209b7e}')
D3D11_DECODER_PROFILE_MPEG2_VLD: Guid = Guid('{ee27417f-5e28-4e65-beea-1d26b508adc9}')
D3D11_DECODER_PROFILE_MPEG1_VLD: Guid = Guid('{6f3ec719-3735-42cc-8063-65cc3cb36616}')
D3D11_DECODER_PROFILE_MPEG2and1_VLD: Guid = Guid('{86695f12-340e-4f04-9fd3-9253dd327460}')
D3D11_DECODER_PROFILE_H264_MOCOMP_NOFGT: Guid = Guid('{1b81be64-a0c7-11d3-b984-00c04f2e73c5}')
D3D11_DECODER_PROFILE_H264_MOCOMP_FGT: Guid = Guid('{1b81be65-a0c7-11d3-b984-00c04f2e73c5}')
D3D11_DECODER_PROFILE_H264_IDCT_NOFGT: Guid = Guid('{1b81be66-a0c7-11d3-b984-00c04f2e73c5}')
D3D11_DECODER_PROFILE_H264_IDCT_FGT: Guid = Guid('{1b81be67-a0c7-11d3-b984-00c04f2e73c5}')
D3D11_DECODER_PROFILE_H264_VLD_NOFGT: Guid = Guid('{1b81be68-a0c7-11d3-b984-00c04f2e73c5}')
D3D11_DECODER_PROFILE_H264_VLD_FGT: Guid = Guid('{1b81be69-a0c7-11d3-b984-00c04f2e73c5}')
D3D11_DECODER_PROFILE_H264_VLD_WITHFMOASO_NOFGT: Guid = Guid('{d5f04ff9-3418-45d8-9561-32a76aae2ddd}')
D3D11_DECODER_PROFILE_H264_VLD_STEREO_PROGRESSIVE_NOFGT: Guid = Guid('{d79be8da-0cf1-4c81-b82a-69a4e236f43d}')
D3D11_DECODER_PROFILE_H264_VLD_STEREO_NOFGT: Guid = Guid('{f9aaccbb-c2b6-4cfc-8779-5707b1760552}')
D3D11_DECODER_PROFILE_H264_VLD_MULTIVIEW_NOFGT: Guid = Guid('{705b9d82-76cf-49d6-b7e6-ac8872db013c}')
D3D11_DECODER_PROFILE_WMV8_POSTPROC: Guid = Guid('{1b81be80-a0c7-11d3-b984-00c04f2e73c5}')
D3D11_DECODER_PROFILE_WMV8_MOCOMP: Guid = Guid('{1b81be81-a0c7-11d3-b984-00c04f2e73c5}')
D3D11_DECODER_PROFILE_WMV9_POSTPROC: Guid = Guid('{1b81be90-a0c7-11d3-b984-00c04f2e73c5}')
D3D11_DECODER_PROFILE_WMV9_MOCOMP: Guid = Guid('{1b81be91-a0c7-11d3-b984-00c04f2e73c5}')
D3D11_DECODER_PROFILE_WMV9_IDCT: Guid = Guid('{1b81be94-a0c7-11d3-b984-00c04f2e73c5}')
D3D11_DECODER_PROFILE_VC1_POSTPROC: Guid = Guid('{1b81bea0-a0c7-11d3-b984-00c04f2e73c5}')
D3D11_DECODER_PROFILE_VC1_MOCOMP: Guid = Guid('{1b81bea1-a0c7-11d3-b984-00c04f2e73c5}')
D3D11_DECODER_PROFILE_VC1_IDCT: Guid = Guid('{1b81bea2-a0c7-11d3-b984-00c04f2e73c5}')
D3D11_DECODER_PROFILE_VC1_VLD: Guid = Guid('{1b81bea3-a0c7-11d3-b984-00c04f2e73c5}')
D3D11_DECODER_PROFILE_VC1_D2010: Guid = Guid('{1b81bea4-a0c7-11d3-b984-00c04f2e73c5}')
D3D11_DECODER_PROFILE_MPEG4PT2_VLD_SIMPLE: Guid = Guid('{efd64d74-c9e8-41d7-a5e9-e9b0e39fa319}')
D3D11_DECODER_PROFILE_MPEG4PT2_VLD_ADVSIMPLE_NOGMC: Guid = Guid('{ed418a9f-010d-4eda-9ae3-9a65358d8d2e}')
D3D11_DECODER_PROFILE_MPEG4PT2_VLD_ADVSIMPLE_GMC: Guid = Guid('{ab998b5b-4258-44a9-9feb-94e597a6baae}')
D3D11_DECODER_PROFILE_HEVC_VLD_MAIN: Guid = Guid('{5b11d51b-2f4c-4452-bcc3-09f2a1160cc0}')
D3D11_DECODER_PROFILE_HEVC_VLD_MAIN10: Guid = Guid('{107af0e0-ef1a-4d19-aba8-67a163073d13}')
D3D11_DECODER_PROFILE_VP9_VLD_PROFILE0: Guid = Guid('{463707f8-a1d0-4585-876d-83aa6d60b89e}')
D3D11_DECODER_PROFILE_VP9_VLD_10BIT_PROFILE2: Guid = Guid('{a4c749ef-6ecf-48aa-8448-50a7a1165ff7}')
D3D11_DECODER_PROFILE_VP8_VLD: Guid = Guid('{90b899ea-3a62-4705-88b3-8df04b2744e7}')
D3D11_DECODER_PROFILE_AV1_VLD_PROFILE0: Guid = Guid('{b8be4ccb-cf53-46ba-8d59-d6b8a6da5d2a}')
D3D11_DECODER_PROFILE_AV1_VLD_PROFILE1: Guid = Guid('{6936ff0f-45b1-4163-9cc1-646ef6946108}')
D3D11_DECODER_PROFILE_AV1_VLD_PROFILE2: Guid = Guid('{0c5f2aa1-e541-4089-bb7b-98110a19d7c8}')
D3D11_DECODER_PROFILE_AV1_VLD_12BIT_PROFILE2: Guid = Guid('{17127009-a00f-4ce1-994e-bf4081f6f3f0}')
D3D11_DECODER_PROFILE_AV1_VLD_12BIT_PROFILE2_420: Guid = Guid('{2d80bed6-9cac-4835-9e91-327bbc4f9ee8}')
D3D11_CRYPTO_TYPE_AES128_CTR: Guid = Guid('{9b6bd711-4f74-41c9-9e7b-0be2d7d93b4f}')
D3D11_DECODER_ENCRYPTION_HW_CENC: Guid = Guid('{89d6ac4f-09f2-4229-b2cd-37740a6dfd81}')
D3D11_DECODER_BITSTREAM_ENCRYPTION_TYPE_CENC: Guid = Guid('{b0405235-c13d-44f2-9ae5-dd48e08e5b67}')
D3D11_DECODER_BITSTREAM_ENCRYPTION_TYPE_CBCS: Guid = Guid('{422d9319-9d21-4bb7-9371-faf5a82c3e04}')
D3D11_KEY_EXCHANGE_HW_PROTECTION: Guid = Guid('{b1170d8a-628d-4da3-ad3b-82ddb08b4970}')
D3D11_AUTHENTICATED_QUERY_PROTECTION: Guid = Guid('{a84eb584-c495-48aa-b94d-8bd2d6fbce05}')
D3D11_AUTHENTICATED_QUERY_CHANNEL_TYPE: Guid = Guid('{bc1b18a5-b1fb-42ab-bd94-b5828b4bf7be}')
D3D11_AUTHENTICATED_QUERY_DEVICE_HANDLE: Guid = Guid('{ec1c539d-8cff-4e2a-bcc4-f5692f99f480}')
D3D11_AUTHENTICATED_QUERY_CRYPTO_SESSION: Guid = Guid('{2634499e-d018-4d74-ac17-7f724059528d}')
D3D11_AUTHENTICATED_QUERY_RESTRICTED_SHARED_RESOURCE_PROCESS_COUNT: Guid = Guid('{0db207b3-9450-46a6-82de-1b96d44f9cf2}')
D3D11_AUTHENTICATED_QUERY_RESTRICTED_SHARED_RESOURCE_PROCESS: Guid = Guid('{649bbadb-f0f4-4639-a15b-24393fc3abac}')
D3D11_AUTHENTICATED_QUERY_UNRESTRICTED_PROTECTED_SHARED_RESOURCE_COUNT: Guid = Guid('{012f0bd6-e662-4474-befd-aa53e5143c6d}')
D3D11_AUTHENTICATED_QUERY_OUTPUT_ID_COUNT: Guid = Guid('{2c042b5e-8c07-46d5-aabe-8f75cbad4c31}')
D3D11_AUTHENTICATED_QUERY_OUTPUT_ID: Guid = Guid('{839ddca3-9b4e-41e4-b053-892bd2a11ee7}')
D3D11_AUTHENTICATED_QUERY_ACCESSIBILITY_ATTRIBUTES: Guid = Guid('{6214d9d2-432c-4abb-9fce-216eea269e3b}')
D3D11_AUTHENTICATED_QUERY_ENCRYPTION_WHEN_ACCESSIBLE_GUID_COUNT: Guid = Guid('{b30f7066-203c-4b07-93fc-ceaafd61241e}')
D3D11_AUTHENTICATED_QUERY_ENCRYPTION_WHEN_ACCESSIBLE_GUID: Guid = Guid('{f83a5958-e986-4bda-beb0-411f6a7a01b7}')
D3D11_AUTHENTICATED_QUERY_CURRENT_ENCRYPTION_WHEN_ACCESSIBLE: Guid = Guid('{ec1791c7-dad3-4f15-9ec3-faa93d60d4f0}')
D3D11_AUTHENTICATED_CONFIGURE_INITIALIZE: Guid = Guid('{06114bdb-3523-470a-8dca-fbc2845154f0}')
D3D11_AUTHENTICATED_CONFIGURE_PROTECTION: Guid = Guid('{50455658-3f47-4362-bf99-bfdfcde9ed29}')
D3D11_AUTHENTICATED_CONFIGURE_CRYPTO_SESSION: Guid = Guid('{6346cc54-2cfc-4ad4-8224-d15837de7700}')
D3D11_AUTHENTICATED_CONFIGURE_SHARED_RESOURCE: Guid = Guid('{0772d047-1b40-48e8-9ca6-b5f510de9f01}')
D3D11_AUTHENTICATED_CONFIGURE_ENCRYPTION_WHEN_ACCESSIBLE: Guid = Guid('{41fff286-6ae0-4d43-9d55-a46e9efd158a}')
D3D11_KEY_EXCHANGE_RSAES_OAEP: Guid = Guid('{c1949895-d72a-4a1d-8e5d-ed857d171520}')
D3D11_SDK_VERSION: UInt32 = 7
D3D11_PACKED_TILE: UInt32 = 4294967295
D3D11_SDK_LAYERS_VERSION: UInt32 = 1
D3D11_DEBUG_FEATURE_FLUSH_PER_RENDER_OP: UInt32 = 1
D3D11_DEBUG_FEATURE_FINISH_PER_RENDER_OP: UInt32 = 2
D3D11_DEBUG_FEATURE_PRESENT_PER_RENDER_OP: UInt32 = 4
D3D11_DEBUG_FEATURE_ALWAYS_DISCARD_OFFERED_RESOURCE: UInt32 = 8
D3D11_DEBUG_FEATURE_NEVER_DISCARD_OFFERED_RESOURCE: UInt32 = 16
D3D11_DEBUG_FEATURE_AVOID_BEHAVIOR_CHANGING_DEBUG_AIDS: UInt32 = 64
D3D11_DEBUG_FEATURE_DISABLE_TILED_RESOURCE_MAPPING_TRACKING_AND_VALIDATION: UInt32 = 128
DXGI_DEBUG_D3D11: Guid = Guid('{4b99317b-ac39-4aa6-bb0b-baa04784798f}')
D3D11_REGKEY_PATH: String = 'Software\\Microsoft\\Direct3D'
D3D11_MUTE_DEBUG_OUTPUT: String = 'MuteDebugOutput'
D3D11_ENABLE_BREAK_ON_MESSAGE: String = 'EnableBreakOnMessage'
D3D11_INFOQUEUE_STORAGE_FILTER_OVERRIDE: String = 'InfoQueueStorageFilterOverride'
D3D11_MUTE_CATEGORY: String = 'Mute_CATEGORY_%s'
D3D11_MUTE_SEVERITY: String = 'Mute_SEVERITY_%s'
D3D11_MUTE_ID_STRING: String = 'Mute_ID_%s'
D3D11_MUTE_ID_DECIMAL: String = 'Mute_ID_%d'
D3D11_UNMUTE_SEVERITY_INFO: String = 'Unmute_SEVERITY_INFO'
D3D11_BREAKON_CATEGORY: String = 'BreakOn_CATEGORY_%s'
D3D11_BREAKON_SEVERITY: String = 'BreakOn_SEVERITY_%s'
D3D11_BREAKON_ID_STRING: String = 'BreakOn_ID_%s'
D3D11_BREAKON_ID_DECIMAL: String = 'BreakOn_ID_%d'
D3D11_APPSIZE_STRING: String = 'Size'
D3D11_APPNAME_STRING: String = 'Name'
D3D11_FORCE_DEBUGGABLE: String = 'ForceDebuggable'
D3D11_FORCE_SHADER_SKIP_OPTIMIZATION: String = 'ForceShaderSkipOptimization'
D3D11_INFO_QUEUE_DEFAULT_MESSAGE_COUNT_LIMIT: UInt32 = 1024
D3D_RETURN_PARAMETER_INDEX: Int32 = -1
D3D_SHADER_REQUIRES_DOUBLES: UInt32 = 1
D3D_SHADER_REQUIRES_EARLY_DEPTH_STENCIL: UInt32 = 2
D3D_SHADER_REQUIRES_UAVS_AT_EVERY_STAGE: UInt32 = 4
D3D_SHADER_REQUIRES_64_UAVS: UInt32 = 8
D3D_SHADER_REQUIRES_MINIMUM_PRECISION: UInt32 = 16
D3D_SHADER_REQUIRES_11_1_DOUBLE_EXTENSIONS: UInt32 = 32
D3D_SHADER_REQUIRES_11_1_SHADER_EXTENSIONS: UInt32 = 64
D3D_SHADER_REQUIRES_LEVEL_9_COMPARISON_FILTERING: UInt32 = 128
D3D_SHADER_REQUIRES_TILED_RESOURCES: UInt32 = 256
D3D11_TRACE_COMPONENT_X: UInt32 = 1
D3D11_TRACE_COMPONENT_Y: UInt32 = 2
D3D11_TRACE_COMPONENT_Z: UInt32 = 4
D3D11_TRACE_COMPONENT_W: UInt32 = 8
D3D11_SHADER_TRACE_FLAG_RECORD_REGISTER_WRITES: UInt32 = 1
D3D11_SHADER_TRACE_FLAG_RECORD_REGISTER_READS: UInt32 = 2
D3D11_TRACE_REGISTER_FLAGS_RELATIVE_INDEXING: UInt32 = 1
D3D11_TRACE_MISC_GS_EMIT: UInt32 = 1
D3D11_TRACE_MISC_GS_CUT: UInt32 = 2
D3D11_TRACE_MISC_PS_DISCARD: UInt32 = 4
D3D11_TRACE_MISC_GS_EMIT_STREAM: UInt32 = 8
D3D11_TRACE_MISC_GS_CUT_STREAM: UInt32 = 16
D3D11_TRACE_MISC_HALT: UInt32 = 32
D3D11_TRACE_MISC_MESSAGE: UInt32 = 64
D3DCSX_DLL_W: String = 'd3dcsx_47.dll'
D3DCSX_DLL_A: String = 'd3dcsx_47.dll'
D3DCSX_DLL: String = 'd3dcsx_47.dll'
D3DX11_FFT_MAX_PRECOMPUTE_BUFFERS: UInt32 = 4
D3DX11_FFT_MAX_TEMP_BUFFERS: UInt32 = 4
D3DX11_FFT_MAX_DIMENSIONS: UInt32 = 32
@winfunctype('d3d11.dll')
def D3D11CreateDevice(pAdapter: win32more.Windows.Win32.Graphics.Dxgi.IDXGIAdapter, DriverType: win32more.Windows.Win32.Graphics.Direct3D.D3D_DRIVER_TYPE, Software: win32more.Windows.Win32.Foundation.HMODULE, Flags: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CREATE_DEVICE_FLAG, pFeatureLevels: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL), FeatureLevels: UInt32, SDKVersion: UInt32, ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Device), pFeatureLevel: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL), ppImmediateContext: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3d11.dll')
def D3D11CreateDeviceAndSwapChain(pAdapter: win32more.Windows.Win32.Graphics.Dxgi.IDXGIAdapter, DriverType: win32more.Windows.Win32.Graphics.Direct3D.D3D_DRIVER_TYPE, Software: win32more.Windows.Win32.Foundation.HMODULE, Flags: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CREATE_DEVICE_FLAG, pFeatureLevels: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL), FeatureLevels: UInt32, SDKVersion: UInt32, pSwapChainDesc: POINTER(win32more.Windows.Win32.Graphics.Dxgi.DXGI_SWAP_CHAIN_DESC), ppSwapChain: POINTER(win32more.Windows.Win32.Graphics.Dxgi.IDXGISwapChain), ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Device), pFeatureLevel: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL), ppImmediateContext: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('D3DCOMPILER_47.dll')
def D3DDisassemble11Trace(pSrcData: VoidPtr, SrcDataSize: UIntPtr, pTrace: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderTrace, StartStep: UInt32, NumSteps: UInt32, Flags: UInt32, ppDisassembly: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3dcsx.dll')
def D3DX11CreateScan(pDeviceContext: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext, MaxElementScanSize: UInt32, MaxScanCount: UInt32, ppScan: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3DX11Scan)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3dcsx.dll')
def D3DX11CreateSegmentedScan(pDeviceContext: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext, MaxElementScanSize: UInt32, ppScan: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3DX11SegmentedScan)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3dcsx.dll')
def D3DX11CreateFFT(pDeviceContext: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_FFT_DESC), Flags: UInt32, pBufferInfo: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_FFT_BUFFER_INFO), ppFFT: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3DX11FFT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3dcsx.dll')
def D3DX11CreateFFT1DReal(pDeviceContext: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext, X: UInt32, Flags: UInt32, pBufferInfo: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_FFT_BUFFER_INFO), ppFFT: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3DX11FFT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3dcsx.dll')
def D3DX11CreateFFT1DComplex(pDeviceContext: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext, X: UInt32, Flags: UInt32, pBufferInfo: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_FFT_BUFFER_INFO), ppFFT: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3DX11FFT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3dcsx.dll')
def D3DX11CreateFFT2DReal(pDeviceContext: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext, X: UInt32, Y: UInt32, Flags: UInt32, pBufferInfo: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_FFT_BUFFER_INFO), ppFFT: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3DX11FFT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3dcsx.dll')
def D3DX11CreateFFT2DComplex(pDeviceContext: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext, X: UInt32, Y: UInt32, Flags: UInt32, pBufferInfo: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_FFT_BUFFER_INFO), ppFFT: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3DX11FFT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3dcsx.dll')
def D3DX11CreateFFT3DReal(pDeviceContext: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext, X: UInt32, Y: UInt32, Z: UInt32, Flags: UInt32, pBufferInfo: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_FFT_BUFFER_INFO), ppFFT: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3DX11FFT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('d3dcsx.dll')
def D3DX11CreateFFT3DComplex(pDeviceContext: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext, X: UInt32, Y: UInt32, Z: UInt32, Flags: UInt32, pBufferInfo: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_FFT_BUFFER_INFO), ppFFT: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3DX11FFT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
D3D11_1_CREATE_DEVICE_CONTEXT_STATE_FLAG = Int32
D3D11_1_CREATE_DEVICE_CONTEXT_STATE_SINGLETHREADED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_1_CREATE_DEVICE_CONTEXT_STATE_FLAG = 1
class D3D11_AES_CTR_IV(Structure):
    IV: UInt64
    Count: UInt64
D3D11_ASYNC_GETDATA_FLAG = Int32
D3D11_ASYNC_GETDATA_DONOTFLUSH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_ASYNC_GETDATA_FLAG = 1
D3D11_AUTHENTICATED_CHANNEL_TYPE = Int32
D3D11_AUTHENTICATED_CHANNEL_D3D11: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_CHANNEL_TYPE = 1
D3D11_AUTHENTICATED_CHANNEL_DRIVER_SOFTWARE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_CHANNEL_TYPE = 2
D3D11_AUTHENTICATED_CHANNEL_DRIVER_HARDWARE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_CHANNEL_TYPE = 3
class D3D11_AUTHENTICATED_CONFIGURE_ACCESSIBLE_ENCRYPTION_INPUT(Structure):
    Parameters: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_CONFIGURE_INPUT
    EncryptionGuid: Guid
class D3D11_AUTHENTICATED_CONFIGURE_CRYPTO_SESSION_INPUT(Structure):
    Parameters: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_CONFIGURE_INPUT
    DecoderHandle: win32more.Windows.Win32.Foundation.HANDLE
    CryptoSessionHandle: win32more.Windows.Win32.Foundation.HANDLE
    DeviceHandle: win32more.Windows.Win32.Foundation.HANDLE
class D3D11_AUTHENTICATED_CONFIGURE_INITIALIZE_INPUT(Structure):
    Parameters: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_CONFIGURE_INPUT
    StartSequenceQuery: UInt32
    StartSequenceConfigure: UInt32
class D3D11_AUTHENTICATED_CONFIGURE_INPUT(Structure):
    omac: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_OMAC
    ConfigureType: Guid
    hChannel: win32more.Windows.Win32.Foundation.HANDLE
    SequenceNumber: UInt32
class D3D11_AUTHENTICATED_CONFIGURE_OUTPUT(Structure):
    omac: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_OMAC
    ConfigureType: Guid
    hChannel: win32more.Windows.Win32.Foundation.HANDLE
    SequenceNumber: UInt32
    ReturnCode: win32more.Windows.Win32.Foundation.HRESULT
class D3D11_AUTHENTICATED_CONFIGURE_PROTECTION_INPUT(Structure):
    Parameters: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_CONFIGURE_INPUT
    Protections: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_PROTECTION_FLAGS
class D3D11_AUTHENTICATED_CONFIGURE_SHARED_RESOURCE_INPUT(Structure):
    Parameters: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_CONFIGURE_INPUT
    ProcessType: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_PROCESS_IDENTIFIER_TYPE
    ProcessHandle: win32more.Windows.Win32.Foundation.HANDLE
    AllowAccess: win32more.Windows.Win32.Foundation.BOOL
D3D11_AUTHENTICATED_PROCESS_IDENTIFIER_TYPE = Int32
D3D11_PROCESSIDTYPE_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_PROCESS_IDENTIFIER_TYPE = 0
D3D11_PROCESSIDTYPE_DWM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_PROCESS_IDENTIFIER_TYPE = 1
D3D11_PROCESSIDTYPE_HANDLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_PROCESS_IDENTIFIER_TYPE = 2
class D3D11_AUTHENTICATED_PROTECTION_FLAGS(Union):
    Flags: _Flags_e__Struct
    Value: UInt32
    class _Flags_e__Struct(Structure):
        ProtectionEnabled: Annotated[UInt32, 1]
        OverlayOrFullscreenRequired: Annotated[UInt32, 1]
        Reserved: Annotated[UInt32, 30]
class D3D11_AUTHENTICATED_QUERY_ACCESSIBILITY_ENCRYPTION_GUID_COUNT_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_OUTPUT
    EncryptionGuidCount: UInt32
class D3D11_AUTHENTICATED_QUERY_ACCESSIBILITY_ENCRYPTION_GUID_INPUT(Structure):
    Input: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_INPUT
    EncryptionGuidIndex: UInt32
class D3D11_AUTHENTICATED_QUERY_ACCESSIBILITY_ENCRYPTION_GUID_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_OUTPUT
    EncryptionGuidIndex: UInt32
    EncryptionGuid: Guid
class D3D11_AUTHENTICATED_QUERY_ACCESSIBILITY_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_OUTPUT
    BusType: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUS_TYPE
    AccessibleInContiguousBlocks: win32more.Windows.Win32.Foundation.BOOL
    AccessibleInNonContiguousBlocks: win32more.Windows.Win32.Foundation.BOOL
class D3D11_AUTHENTICATED_QUERY_CHANNEL_TYPE_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_OUTPUT
    ChannelType: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_CHANNEL_TYPE
class D3D11_AUTHENTICATED_QUERY_CRYPTO_SESSION_INPUT(Structure):
    Input: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_INPUT
    DecoderHandle: win32more.Windows.Win32.Foundation.HANDLE
class D3D11_AUTHENTICATED_QUERY_CRYPTO_SESSION_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_OUTPUT
    DecoderHandle: win32more.Windows.Win32.Foundation.HANDLE
    CryptoSessionHandle: win32more.Windows.Win32.Foundation.HANDLE
    DeviceHandle: win32more.Windows.Win32.Foundation.HANDLE
class D3D11_AUTHENTICATED_QUERY_CURRENT_ACCESSIBILITY_ENCRYPTION_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_OUTPUT
    EncryptionGuid: Guid
class D3D11_AUTHENTICATED_QUERY_DEVICE_HANDLE_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_OUTPUT
    DeviceHandle: win32more.Windows.Win32.Foundation.HANDLE
class D3D11_AUTHENTICATED_QUERY_INPUT(Structure):
    QueryType: Guid
    hChannel: win32more.Windows.Win32.Foundation.HANDLE
    SequenceNumber: UInt32
class D3D11_AUTHENTICATED_QUERY_OUTPUT(Structure):
    omac: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_OMAC
    QueryType: Guid
    hChannel: win32more.Windows.Win32.Foundation.HANDLE
    SequenceNumber: UInt32
    ReturnCode: win32more.Windows.Win32.Foundation.HRESULT
class D3D11_AUTHENTICATED_QUERY_OUTPUT_ID_COUNT_INPUT(Structure):
    Input: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_INPUT
    DeviceHandle: win32more.Windows.Win32.Foundation.HANDLE
    CryptoSessionHandle: win32more.Windows.Win32.Foundation.HANDLE
class D3D11_AUTHENTICATED_QUERY_OUTPUT_ID_COUNT_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_OUTPUT
    DeviceHandle: win32more.Windows.Win32.Foundation.HANDLE
    CryptoSessionHandle: win32more.Windows.Win32.Foundation.HANDLE
    OutputIDCount: UInt32
class D3D11_AUTHENTICATED_QUERY_OUTPUT_ID_INPUT(Structure):
    Input: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_INPUT
    DeviceHandle: win32more.Windows.Win32.Foundation.HANDLE
    CryptoSessionHandle: win32more.Windows.Win32.Foundation.HANDLE
    OutputIDIndex: UInt32
class D3D11_AUTHENTICATED_QUERY_OUTPUT_ID_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_OUTPUT
    DeviceHandle: win32more.Windows.Win32.Foundation.HANDLE
    CryptoSessionHandle: win32more.Windows.Win32.Foundation.HANDLE
    OutputIDIndex: UInt32
    OutputID: UInt64
class D3D11_AUTHENTICATED_QUERY_PROTECTION_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_OUTPUT
    ProtectionFlags: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_PROTECTION_FLAGS
class D3D11_AUTHENTICATED_QUERY_RESTRICTED_SHARED_RESOURCE_PROCESS_COUNT_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_OUTPUT
    RestrictedSharedResourceProcessCount: UInt32
class D3D11_AUTHENTICATED_QUERY_RESTRICTED_SHARED_RESOURCE_PROCESS_INPUT(Structure):
    Input: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_INPUT
    ProcessIndex: UInt32
class D3D11_AUTHENTICATED_QUERY_RESTRICTED_SHARED_RESOURCE_PROCESS_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_OUTPUT
    ProcessIndex: UInt32
    ProcessIdentifier: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_PROCESS_IDENTIFIER_TYPE
    ProcessHandle: win32more.Windows.Win32.Foundation.HANDLE
class D3D11_AUTHENTICATED_QUERY_UNRESTRICTED_PROTECTED_SHARED_RESOURCE_COUNT_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_QUERY_OUTPUT
    UnrestrictedProtectedSharedResourceCount: UInt32
D3D11_BIND_FLAG = Int32
D3D11_BIND_VERTEX_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BIND_FLAG = 1
D3D11_BIND_INDEX_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BIND_FLAG = 2
D3D11_BIND_CONSTANT_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BIND_FLAG = 4
D3D11_BIND_SHADER_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BIND_FLAG = 8
D3D11_BIND_STREAM_OUTPUT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BIND_FLAG = 16
D3D11_BIND_RENDER_TARGET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BIND_FLAG = 32
D3D11_BIND_DEPTH_STENCIL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BIND_FLAG = 64
D3D11_BIND_UNORDERED_ACCESS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BIND_FLAG = 128
D3D11_BIND_DECODER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BIND_FLAG = 512
D3D11_BIND_VIDEO_ENCODER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BIND_FLAG = 1024
D3D11_BLEND = Int32
D3D11_BLEND_ZERO: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND = 1
D3D11_BLEND_ONE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND = 2
D3D11_BLEND_SRC_COLOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND = 3
D3D11_BLEND_INV_SRC_COLOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND = 4
D3D11_BLEND_SRC_ALPHA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND = 5
D3D11_BLEND_INV_SRC_ALPHA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND = 6
D3D11_BLEND_DEST_ALPHA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND = 7
D3D11_BLEND_INV_DEST_ALPHA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND = 8
D3D11_BLEND_DEST_COLOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND = 9
D3D11_BLEND_INV_DEST_COLOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND = 10
D3D11_BLEND_SRC_ALPHA_SAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND = 11
D3D11_BLEND_BLEND_FACTOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND = 14
D3D11_BLEND_INV_BLEND_FACTOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND = 15
D3D11_BLEND_SRC1_COLOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND = 16
D3D11_BLEND_INV_SRC1_COLOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND = 17
D3D11_BLEND_SRC1_ALPHA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND = 18
D3D11_BLEND_INV_SRC1_ALPHA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND = 19
class D3D11_BLEND_DESC(Structure):
    AlphaToCoverageEnable: win32more.Windows.Win32.Foundation.BOOL
    IndependentBlendEnable: win32more.Windows.Win32.Foundation.BOOL
    RenderTarget: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RENDER_TARGET_BLEND_DESC * 8
class D3D11_BLEND_DESC1(Structure):
    AlphaToCoverageEnable: win32more.Windows.Win32.Foundation.BOOL
    IndependentBlendEnable: win32more.Windows.Win32.Foundation.BOOL
    RenderTarget: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RENDER_TARGET_BLEND_DESC1 * 8
D3D11_BLEND_OP = Int32
D3D11_BLEND_OP_ADD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND_OP = 1
D3D11_BLEND_OP_SUBTRACT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND_OP = 2
D3D11_BLEND_OP_REV_SUBTRACT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND_OP = 3
D3D11_BLEND_OP_MIN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND_OP = 4
D3D11_BLEND_OP_MAX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND_OP = 5
class D3D11_BOX(Structure):
    left: UInt32
    top: UInt32
    front: UInt32
    right: UInt32
    bottom: UInt32
    back: UInt32
class D3D11_BUFFEREX_SRV(Structure):
    FirstElement: UInt32
    NumElements: UInt32
    Flags: UInt32
D3D11_BUFFEREX_SRV_FLAG = Int32
D3D11_BUFFEREX_SRV_FLAG_RAW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUFFEREX_SRV_FLAG = 1
class D3D11_BUFFER_DESC(Structure):
    ByteWidth: UInt32
    Usage: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_USAGE
    BindFlags: UInt32
    CPUAccessFlags: UInt32
    MiscFlags: UInt32
    StructureByteStride: UInt32
class D3D11_BUFFER_RTV(Structure):
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    class _Anonymous1_e__Union(Union):
        FirstElement: UInt32
        ElementOffset: UInt32
    class _Anonymous2_e__Union(Union):
        NumElements: UInt32
        ElementWidth: UInt32
class D3D11_BUFFER_SRV(Structure):
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    class _Anonymous1_e__Union(Union):
        FirstElement: UInt32
        ElementOffset: UInt32
    class _Anonymous2_e__Union(Union):
        NumElements: UInt32
        ElementWidth: UInt32
class D3D11_BUFFER_UAV(Structure):
    FirstElement: UInt32
    NumElements: UInt32
    Flags: UInt32
D3D11_BUFFER_UAV_FLAG = Int32
D3D11_BUFFER_UAV_FLAG_RAW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUFFER_UAV_FLAG = 1
D3D11_BUFFER_UAV_FLAG_APPEND: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUFFER_UAV_FLAG = 2
D3D11_BUFFER_UAV_FLAG_COUNTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUFFER_UAV_FLAG = 4
D3D11_BUS_TYPE = Int32
D3D11_BUS_TYPE_OTHER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUS_TYPE = 0
D3D11_BUS_TYPE_PCI: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUS_TYPE = 1
D3D11_BUS_TYPE_PCIX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUS_TYPE = 2
D3D11_BUS_TYPE_PCIEXPRESS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUS_TYPE = 3
D3D11_BUS_TYPE_AGP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUS_TYPE = 4
D3D11_BUS_IMPL_MODIFIER_INSIDE_OF_CHIPSET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUS_TYPE = 65536
D3D11_BUS_IMPL_MODIFIER_TRACKS_ON_MOTHER_BOARD_TO_CHIP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUS_TYPE = 131072
D3D11_BUS_IMPL_MODIFIER_TRACKS_ON_MOTHER_BOARD_TO_SOCKET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUS_TYPE = 196608
D3D11_BUS_IMPL_MODIFIER_DAUGHTER_BOARD_CONNECTOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUS_TYPE = 262144
D3D11_BUS_IMPL_MODIFIER_DAUGHTER_BOARD_CONNECTOR_INSIDE_OF_NUAE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUS_TYPE = 327680
D3D11_BUS_IMPL_MODIFIER_NON_STANDARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUS_TYPE = -2147483648
D3D11_CHECK_MULTISAMPLE_QUALITY_LEVELS_FLAG = Int32
D3D11_CHECK_MULTISAMPLE_QUALITY_LEVELS_TILED_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CHECK_MULTISAMPLE_QUALITY_LEVELS_FLAG = 1
class D3D11_CLASS_INSTANCE_DESC(Structure):
    InstanceId: UInt32
    InstanceIndex: UInt32
    TypeId: UInt32
    ConstantBuffer: UInt32
    BaseConstantBufferOffset: UInt32
    BaseTexture: UInt32
    BaseSampler: UInt32
    Created: win32more.Windows.Win32.Foundation.BOOL
D3D11_CLEAR_FLAG = UInt32
D3D11_CLEAR_DEPTH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CLEAR_FLAG = 1
D3D11_CLEAR_STENCIL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CLEAR_FLAG = 2
D3D11_COLOR_WRITE_ENABLE = Int32
D3D11_COLOR_WRITE_ENABLE_RED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COLOR_WRITE_ENABLE = 1
D3D11_COLOR_WRITE_ENABLE_GREEN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COLOR_WRITE_ENABLE = 2
D3D11_COLOR_WRITE_ENABLE_BLUE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COLOR_WRITE_ENABLE = 4
D3D11_COLOR_WRITE_ENABLE_ALPHA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COLOR_WRITE_ENABLE = 8
D3D11_COLOR_WRITE_ENABLE_ALL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COLOR_WRITE_ENABLE = 15
D3D11_COMPARISON_FUNC = Int32
D3D11_COMPARISON_NEVER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COMPARISON_FUNC = 1
D3D11_COMPARISON_LESS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COMPARISON_FUNC = 2
D3D11_COMPARISON_EQUAL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COMPARISON_FUNC = 3
D3D11_COMPARISON_LESS_EQUAL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COMPARISON_FUNC = 4
D3D11_COMPARISON_GREATER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COMPARISON_FUNC = 5
D3D11_COMPARISON_NOT_EQUAL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COMPARISON_FUNC = 6
D3D11_COMPARISON_GREATER_EQUAL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COMPARISON_FUNC = 7
D3D11_COMPARISON_ALWAYS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COMPARISON_FUNC = 8
class D3D11_COMPUTE_SHADER_TRACE_DESC(Structure):
    Invocation: UInt64
    ThreadIDInGroup: UInt32 * 3
    ThreadGroupID: UInt32 * 3
D3D11_CONSERVATIVE_RASTERIZATION_MODE = Int32
D3D11_CONSERVATIVE_RASTERIZATION_MODE_OFF: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONSERVATIVE_RASTERIZATION_MODE = 0
D3D11_CONSERVATIVE_RASTERIZATION_MODE_ON: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONSERVATIVE_RASTERIZATION_MODE = 1
D3D11_CONSERVATIVE_RASTERIZATION_TIER = Int32
D3D11_CONSERVATIVE_RASTERIZATION_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONSERVATIVE_RASTERIZATION_TIER = 0
D3D11_CONSERVATIVE_RASTERIZATION_TIER_1: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONSERVATIVE_RASTERIZATION_TIER = 1
D3D11_CONSERVATIVE_RASTERIZATION_TIER_2: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONSERVATIVE_RASTERIZATION_TIER = 2
D3D11_CONSERVATIVE_RASTERIZATION_TIER_3: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONSERVATIVE_RASTERIZATION_TIER = 3
D3D11_CONTENT_PROTECTION_CAPS = Int32
D3D11_CONTENT_PROTECTION_CAPS_SOFTWARE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTENT_PROTECTION_CAPS = 1
D3D11_CONTENT_PROTECTION_CAPS_HARDWARE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTENT_PROTECTION_CAPS = 2
D3D11_CONTENT_PROTECTION_CAPS_PROTECTION_ALWAYS_ON: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTENT_PROTECTION_CAPS = 4
D3D11_CONTENT_PROTECTION_CAPS_PARTIAL_DECRYPTION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTENT_PROTECTION_CAPS = 8
D3D11_CONTENT_PROTECTION_CAPS_CONTENT_KEY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTENT_PROTECTION_CAPS = 16
D3D11_CONTENT_PROTECTION_CAPS_FRESHEN_SESSION_KEY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTENT_PROTECTION_CAPS = 32
D3D11_CONTENT_PROTECTION_CAPS_ENCRYPTED_READ_BACK: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTENT_PROTECTION_CAPS = 64
D3D11_CONTENT_PROTECTION_CAPS_ENCRYPTED_READ_BACK_KEY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTENT_PROTECTION_CAPS = 128
D3D11_CONTENT_PROTECTION_CAPS_SEQUENTIAL_CTR_IV: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTENT_PROTECTION_CAPS = 256
D3D11_CONTENT_PROTECTION_CAPS_ENCRYPT_SLICEDATA_ONLY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTENT_PROTECTION_CAPS = 512
D3D11_CONTENT_PROTECTION_CAPS_DECRYPTION_BLT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTENT_PROTECTION_CAPS = 1024
D3D11_CONTENT_PROTECTION_CAPS_HARDWARE_PROTECT_UNCOMPRESSED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTENT_PROTECTION_CAPS = 2048
D3D11_CONTENT_PROTECTION_CAPS_HARDWARE_PROTECTED_MEMORY_PAGEABLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTENT_PROTECTION_CAPS = 4096
D3D11_CONTENT_PROTECTION_CAPS_HARDWARE_TEARDOWN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTENT_PROTECTION_CAPS = 8192
D3D11_CONTENT_PROTECTION_CAPS_HARDWARE_DRM_COMMUNICATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTENT_PROTECTION_CAPS = 16384
D3D11_CONTENT_PROTECTION_CAPS_HARDWARE_DRM_COMMUNICATION_MULTI_THREADED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTENT_PROTECTION_CAPS = 32768
D3D11_CONTEXT_TYPE = Int32
D3D11_CONTEXT_TYPE_ALL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTEXT_TYPE = 0
D3D11_CONTEXT_TYPE_3D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTEXT_TYPE = 1
D3D11_CONTEXT_TYPE_COMPUTE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTEXT_TYPE = 2
D3D11_CONTEXT_TYPE_COPY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTEXT_TYPE = 3
D3D11_CONTEXT_TYPE_VIDEO: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTEXT_TYPE = 4
D3D11_COPY_FLAGS = Int32
D3D11_COPY_NO_OVERWRITE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COPY_FLAGS = 1
D3D11_COPY_DISCARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COPY_FLAGS = 2
D3D11_COUNTER = Int32
D3D11_COUNTER_DEVICE_DEPENDENT_0: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COUNTER = 1073741824
class D3D11_COUNTER_DESC(Structure):
    Counter: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COUNTER
    MiscFlags: UInt32
class D3D11_COUNTER_INFO(Structure):
    LastDeviceDependentCounter: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COUNTER
    NumSimultaneousCounters: UInt32
    NumDetectableParallelUnits: Byte
D3D11_COUNTER_TYPE = Int32
D3D11_COUNTER_TYPE_FLOAT32: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COUNTER_TYPE = 0
D3D11_COUNTER_TYPE_UINT16: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COUNTER_TYPE = 1
D3D11_COUNTER_TYPE_UINT32: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COUNTER_TYPE = 2
D3D11_COUNTER_TYPE_UINT64: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COUNTER_TYPE = 3
D3D11_CPU_ACCESS_FLAG = Int32
D3D11_CPU_ACCESS_WRITE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CPU_ACCESS_FLAG = 65536
D3D11_CPU_ACCESS_READ: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CPU_ACCESS_FLAG = 131072
D3D11_CREATE_DEVICE_FLAG = UInt32
D3D11_CREATE_DEVICE_SINGLETHREADED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CREATE_DEVICE_FLAG = 1
D3D11_CREATE_DEVICE_DEBUG: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CREATE_DEVICE_FLAG = 2
D3D11_CREATE_DEVICE_SWITCH_TO_REF: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CREATE_DEVICE_FLAG = 4
D3D11_CREATE_DEVICE_PREVENT_INTERNAL_THREADING_OPTIMIZATIONS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CREATE_DEVICE_FLAG = 8
D3D11_CREATE_DEVICE_BGRA_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CREATE_DEVICE_FLAG = 32
D3D11_CREATE_DEVICE_DEBUGGABLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CREATE_DEVICE_FLAG = 64
D3D11_CREATE_DEVICE_PREVENT_ALTERING_LAYER_SETTINGS_FROM_REGISTRY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CREATE_DEVICE_FLAG = 128
D3D11_CREATE_DEVICE_DISABLE_GPU_TIMEOUT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CREATE_DEVICE_FLAG = 256
D3D11_CREATE_DEVICE_VIDEO_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CREATE_DEVICE_FLAG = 2048
D3D11_CRYPTO_SESSION_KEY_EXCHANGE_FLAGS = Int32
D3D11_CRYPTO_SESSION_KEY_EXCHANGE_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CRYPTO_SESSION_KEY_EXCHANGE_FLAGS = 0
D3D11_CRYPTO_SESSION_STATUS = Int32
D3D11_CRYPTO_SESSION_STATUS_OK: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CRYPTO_SESSION_STATUS = 0
D3D11_CRYPTO_SESSION_STATUS_KEY_LOST: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CRYPTO_SESSION_STATUS = 1
D3D11_CRYPTO_SESSION_STATUS_KEY_AND_CONTENT_LOST: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CRYPTO_SESSION_STATUS = 2
D3D11_CULL_MODE = Int32
D3D11_CULL_NONE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CULL_MODE = 1
D3D11_CULL_FRONT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CULL_MODE = 2
D3D11_CULL_BACK: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CULL_MODE = 3
class D3D11_DEPTH_STENCILOP_DESC(Structure):
    StencilFailOp: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_STENCIL_OP
    StencilDepthFailOp: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_STENCIL_OP
    StencilPassOp: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_STENCIL_OP
    StencilFunc: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COMPARISON_FUNC
class D3D11_DEPTH_STENCIL_DESC(Structure):
    DepthEnable: win32more.Windows.Win32.Foundation.BOOL
    DepthWriteMask: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DEPTH_WRITE_MASK
    DepthFunc: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COMPARISON_FUNC
    StencilEnable: win32more.Windows.Win32.Foundation.BOOL
    StencilReadMask: Byte
    StencilWriteMask: Byte
    FrontFace: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DEPTH_STENCILOP_DESC
    BackFace: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DEPTH_STENCILOP_DESC
class D3D11_DEPTH_STENCIL_VIEW_DESC(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DSV_DIMENSION
    Flags: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Texture1D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX1D_DSV
        Texture1DArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX1D_ARRAY_DSV
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_DSV
        Texture2DArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_ARRAY_DSV
        Texture2DMS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2DMS_DSV
        Texture2DMSArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2DMS_ARRAY_DSV
D3D11_DEPTH_WRITE_MASK = Int32
D3D11_DEPTH_WRITE_MASK_ZERO: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DEPTH_WRITE_MASK = 0
D3D11_DEPTH_WRITE_MASK_ALL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DEPTH_WRITE_MASK = 1
D3D11_DEVICE_CONTEXT_TYPE = Int32
D3D11_DEVICE_CONTEXT_IMMEDIATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DEVICE_CONTEXT_TYPE = 0
D3D11_DEVICE_CONTEXT_DEFERRED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DEVICE_CONTEXT_TYPE = 1
class D3D11_DOMAIN_SHADER_TRACE_DESC(Structure):
    Invocation: UInt64
class D3D11_DRAW_INDEXED_INSTANCED_INDIRECT_ARGS(Structure):
    IndexCountPerInstance: UInt32
    InstanceCount: UInt32
    StartIndexLocation: UInt32
    BaseVertexLocation: Int32
    StartInstanceLocation: UInt32
class D3D11_DRAW_INSTANCED_INDIRECT_ARGS(Structure):
    VertexCountPerInstance: UInt32
    InstanceCount: UInt32
    StartVertexLocation: UInt32
    StartInstanceLocation: UInt32
D3D11_DSV_DIMENSION = Int32
D3D11_DSV_DIMENSION_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DSV_DIMENSION = 0
D3D11_DSV_DIMENSION_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DSV_DIMENSION = 1
D3D11_DSV_DIMENSION_TEXTURE1DARRAY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DSV_DIMENSION = 2
D3D11_DSV_DIMENSION_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DSV_DIMENSION = 3
D3D11_DSV_DIMENSION_TEXTURE2DARRAY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DSV_DIMENSION = 4
D3D11_DSV_DIMENSION_TEXTURE2DMS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DSV_DIMENSION = 5
D3D11_DSV_DIMENSION_TEXTURE2DMSARRAY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DSV_DIMENSION = 6
D3D11_DSV_FLAG = Int32
D3D11_DSV_READ_ONLY_DEPTH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DSV_FLAG = 1
D3D11_DSV_READ_ONLY_STENCIL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DSV_FLAG = 2
class D3D11_ENCRYPTED_BLOCK_INFO(Structure):
    NumEncryptedBytesAtBeginning: UInt32
    NumBytesInSkipPattern: UInt32
    NumBytesInEncryptPattern: UInt32
D3D11_FEATURE = Int32
D3D11_FEATURE_THREADING: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 0
D3D11_FEATURE_DOUBLES: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 1
D3D11_FEATURE_FORMAT_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 2
D3D11_FEATURE_FORMAT_SUPPORT2: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 3
D3D11_FEATURE_D3D10_X_HARDWARE_OPTIONS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 4
D3D11_FEATURE_D3D11_OPTIONS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 5
D3D11_FEATURE_ARCHITECTURE_INFO: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 6
D3D11_FEATURE_D3D9_OPTIONS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 7
D3D11_FEATURE_SHADER_MIN_PRECISION_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 8
D3D11_FEATURE_D3D9_SHADOW_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 9
D3D11_FEATURE_D3D11_OPTIONS1: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 10
D3D11_FEATURE_D3D9_SIMPLE_INSTANCING_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 11
D3D11_FEATURE_MARKER_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 12
D3D11_FEATURE_D3D9_OPTIONS1: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 13
D3D11_FEATURE_D3D11_OPTIONS2: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 14
D3D11_FEATURE_D3D11_OPTIONS3: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 15
D3D11_FEATURE_GPU_VIRTUAL_ADDRESS_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 16
D3D11_FEATURE_D3D11_OPTIONS4: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 17
D3D11_FEATURE_SHADER_CACHE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 18
D3D11_FEATURE_D3D11_OPTIONS5: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 19
D3D11_FEATURE_DISPLAYABLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE = 20
class D3D11_FEATURE_DATA_ARCHITECTURE_INFO(Structure):
    TileBasedDeferredRenderer: win32more.Windows.Win32.Foundation.BOOL
class D3D11_FEATURE_DATA_D3D10_X_HARDWARE_OPTIONS(Structure):
    ComputeShaders_Plus_RawAndStructuredBuffers_Via_Shader_4_x: win32more.Windows.Win32.Foundation.BOOL
class D3D11_FEATURE_DATA_D3D11_OPTIONS(Structure):
    OutputMergerLogicOp: win32more.Windows.Win32.Foundation.BOOL
    UAVOnlyRenderingForcedSampleCount: win32more.Windows.Win32.Foundation.BOOL
    DiscardAPIsSeenByDriver: win32more.Windows.Win32.Foundation.BOOL
    FlagsForUpdateAndCopySeenByDriver: win32more.Windows.Win32.Foundation.BOOL
    ClearView: win32more.Windows.Win32.Foundation.BOOL
    CopyWithOverlap: win32more.Windows.Win32.Foundation.BOOL
    ConstantBufferPartialUpdate: win32more.Windows.Win32.Foundation.BOOL
    ConstantBufferOffsetting: win32more.Windows.Win32.Foundation.BOOL
    MapNoOverwriteOnDynamicConstantBuffer: win32more.Windows.Win32.Foundation.BOOL
    MapNoOverwriteOnDynamicBufferSRV: win32more.Windows.Win32.Foundation.BOOL
    MultisampleRTVWithForcedSampleCountOne: win32more.Windows.Win32.Foundation.BOOL
    SAD4ShaderInstructions: win32more.Windows.Win32.Foundation.BOOL
    ExtendedDoublesShaderInstructions: win32more.Windows.Win32.Foundation.BOOL
    ExtendedResourceSharing: win32more.Windows.Win32.Foundation.BOOL
class D3D11_FEATURE_DATA_D3D11_OPTIONS1(Structure):
    TiledResourcesTier: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILED_RESOURCES_TIER
    MinMaxFiltering: win32more.Windows.Win32.Foundation.BOOL
    ClearViewAlsoSupportsDepthOnlyFormats: win32more.Windows.Win32.Foundation.BOOL
    MapOnDefaultBuffers: win32more.Windows.Win32.Foundation.BOOL
class D3D11_FEATURE_DATA_D3D11_OPTIONS2(Structure):
    PSSpecifiedStencilRefSupported: win32more.Windows.Win32.Foundation.BOOL
    TypedUAVLoadAdditionalFormats: win32more.Windows.Win32.Foundation.BOOL
    ROVsSupported: win32more.Windows.Win32.Foundation.BOOL
    ConservativeRasterizationTier: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONSERVATIVE_RASTERIZATION_TIER
    TiledResourcesTier: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILED_RESOURCES_TIER
    MapOnDefaultTextures: win32more.Windows.Win32.Foundation.BOOL
    StandardSwizzle: win32more.Windows.Win32.Foundation.BOOL
    UnifiedMemoryArchitecture: win32more.Windows.Win32.Foundation.BOOL
class D3D11_FEATURE_DATA_D3D11_OPTIONS3(Structure):
    VPAndRTArrayIndexFromAnyShaderFeedingRasterizer: win32more.Windows.Win32.Foundation.BOOL
class D3D11_FEATURE_DATA_D3D11_OPTIONS4(Structure):
    ExtendedNV12SharedTextureSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D11_FEATURE_DATA_D3D11_OPTIONS5(Structure):
    SharedResourceTier: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHARED_RESOURCE_TIER
class D3D11_FEATURE_DATA_D3D9_OPTIONS(Structure):
    FullNonPow2TextureSupport: win32more.Windows.Win32.Foundation.BOOL
class D3D11_FEATURE_DATA_D3D9_OPTIONS1(Structure):
    FullNonPow2TextureSupported: win32more.Windows.Win32.Foundation.BOOL
    DepthAsTextureWithLessEqualComparisonFilterSupported: win32more.Windows.Win32.Foundation.BOOL
    SimpleInstancingSupported: win32more.Windows.Win32.Foundation.BOOL
    TextureCubeFaceRenderTargetWithNonCubeDepthStencilSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D11_FEATURE_DATA_D3D9_SHADOW_SUPPORT(Structure):
    SupportsDepthAsTextureWithLessEqualComparisonFilter: win32more.Windows.Win32.Foundation.BOOL
class D3D11_FEATURE_DATA_D3D9_SIMPLE_INSTANCING_SUPPORT(Structure):
    SimpleInstancingSupported: win32more.Windows.Win32.Foundation.BOOL
class D3D11_FEATURE_DATA_DISPLAYABLE(Structure):
    DisplayableTexture: win32more.Windows.Win32.Foundation.BOOL
    SharedResourceTier: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHARED_RESOURCE_TIER
class D3D11_FEATURE_DATA_DOUBLES(Structure):
    DoublePrecisionFloatShaderOps: win32more.Windows.Win32.Foundation.BOOL
class D3D11_FEATURE_DATA_FORMAT_SUPPORT(Structure):
    InFormat: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    OutFormatSupport: UInt32
class D3D11_FEATURE_DATA_FORMAT_SUPPORT2(Structure):
    InFormat: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    OutFormatSupport2: UInt32
class D3D11_FEATURE_DATA_GPU_VIRTUAL_ADDRESS_SUPPORT(Structure):
    MaxGPUVirtualAddressBitsPerResource: UInt32
    MaxGPUVirtualAddressBitsPerProcess: UInt32
class D3D11_FEATURE_DATA_MARKER_SUPPORT(Structure):
    Profile: win32more.Windows.Win32.Foundation.BOOL
class D3D11_FEATURE_DATA_SHADER_CACHE(Structure):
    SupportFlags: UInt32
class D3D11_FEATURE_DATA_SHADER_MIN_PRECISION_SUPPORT(Structure):
    PixelShaderMinPrecision: UInt32
    AllOtherShaderStagesMinPrecision: UInt32
class D3D11_FEATURE_DATA_THREADING(Structure):
    DriverConcurrentCreates: win32more.Windows.Win32.Foundation.BOOL
    DriverCommandLists: win32more.Windows.Win32.Foundation.BOOL
class D3D11_FEATURE_DATA_VIDEO_DECODER_HISTOGRAM(Structure):
    DecoderDesc: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_DESC
    Components: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAGS
    BinCount: UInt32
    CounterBitDepth: UInt32
D3D11_FEATURE_VIDEO = Int32
D3D11_FEATURE_VIDEO_DECODER_HISTOGRAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE_VIDEO = 0
D3D11_FENCE_FLAG = Int32
D3D11_FENCE_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FENCE_FLAG = 0
D3D11_FENCE_FLAG_SHARED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FENCE_FLAG = 2
D3D11_FENCE_FLAG_SHARED_CROSS_ADAPTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FENCE_FLAG = 4
D3D11_FENCE_FLAG_NON_MONITORED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FENCE_FLAG = 8
D3D11_FILL_MODE = Int32
D3D11_FILL_WIREFRAME: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILL_MODE = 2
D3D11_FILL_SOLID: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILL_MODE = 3
D3D11_FILTER = Int32
D3D11_FILTER_MIN_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 0
D3D11_FILTER_MIN_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 1
D3D11_FILTER_MIN_POINT_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 4
D3D11_FILTER_MIN_POINT_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 5
D3D11_FILTER_MIN_LINEAR_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 16
D3D11_FILTER_MIN_LINEAR_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 17
D3D11_FILTER_MIN_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 20
D3D11_FILTER_MIN_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 21
D3D11_FILTER_ANISOTROPIC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 85
D3D11_FILTER_COMPARISON_MIN_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 128
D3D11_FILTER_COMPARISON_MIN_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 129
D3D11_FILTER_COMPARISON_MIN_POINT_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 132
D3D11_FILTER_COMPARISON_MIN_POINT_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 133
D3D11_FILTER_COMPARISON_MIN_LINEAR_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 144
D3D11_FILTER_COMPARISON_MIN_LINEAR_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 145
D3D11_FILTER_COMPARISON_MIN_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 148
D3D11_FILTER_COMPARISON_MIN_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 149
D3D11_FILTER_COMPARISON_ANISOTROPIC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 213
D3D11_FILTER_MINIMUM_MIN_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 256
D3D11_FILTER_MINIMUM_MIN_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 257
D3D11_FILTER_MINIMUM_MIN_POINT_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 260
D3D11_FILTER_MINIMUM_MIN_POINT_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 261
D3D11_FILTER_MINIMUM_MIN_LINEAR_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 272
D3D11_FILTER_MINIMUM_MIN_LINEAR_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 273
D3D11_FILTER_MINIMUM_MIN_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 276
D3D11_FILTER_MINIMUM_MIN_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 277
D3D11_FILTER_MINIMUM_ANISOTROPIC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 341
D3D11_FILTER_MAXIMUM_MIN_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 384
D3D11_FILTER_MAXIMUM_MIN_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 385
D3D11_FILTER_MAXIMUM_MIN_POINT_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 388
D3D11_FILTER_MAXIMUM_MIN_POINT_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 389
D3D11_FILTER_MAXIMUM_MIN_LINEAR_MAG_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 400
D3D11_FILTER_MAXIMUM_MIN_LINEAR_MAG_POINT_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 401
D3D11_FILTER_MAXIMUM_MIN_MAG_LINEAR_MIP_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 404
D3D11_FILTER_MAXIMUM_MIN_MAG_MIP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 405
D3D11_FILTER_MAXIMUM_ANISOTROPIC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER = 469
D3D11_FILTER_REDUCTION_TYPE = Int32
D3D11_FILTER_REDUCTION_TYPE_STANDARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER_REDUCTION_TYPE = 0
D3D11_FILTER_REDUCTION_TYPE_COMPARISON: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER_REDUCTION_TYPE = 1
D3D11_FILTER_REDUCTION_TYPE_MINIMUM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER_REDUCTION_TYPE = 2
D3D11_FILTER_REDUCTION_TYPE_MAXIMUM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER_REDUCTION_TYPE = 3
D3D11_FILTER_TYPE = Int32
D3D11_FILTER_TYPE_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER_TYPE = 0
D3D11_FILTER_TYPE_LINEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER_TYPE = 1
D3D11_FORMAT_SUPPORT = Int32
D3D11_FORMAT_SUPPORT_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 1
D3D11_FORMAT_SUPPORT_IA_VERTEX_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 2
D3D11_FORMAT_SUPPORT_IA_INDEX_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 4
D3D11_FORMAT_SUPPORT_SO_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 8
D3D11_FORMAT_SUPPORT_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 16
D3D11_FORMAT_SUPPORT_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 32
D3D11_FORMAT_SUPPORT_TEXTURE3D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 64
D3D11_FORMAT_SUPPORT_TEXTURECUBE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 128
D3D11_FORMAT_SUPPORT_SHADER_LOAD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 256
D3D11_FORMAT_SUPPORT_SHADER_SAMPLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 512
D3D11_FORMAT_SUPPORT_SHADER_SAMPLE_COMPARISON: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 1024
D3D11_FORMAT_SUPPORT_SHADER_SAMPLE_MONO_TEXT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 2048
D3D11_FORMAT_SUPPORT_MIP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 4096
D3D11_FORMAT_SUPPORT_MIP_AUTOGEN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 8192
D3D11_FORMAT_SUPPORT_RENDER_TARGET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 16384
D3D11_FORMAT_SUPPORT_BLENDABLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 32768
D3D11_FORMAT_SUPPORT_DEPTH_STENCIL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 65536
D3D11_FORMAT_SUPPORT_CPU_LOCKABLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 131072
D3D11_FORMAT_SUPPORT_MULTISAMPLE_RESOLVE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 262144
D3D11_FORMAT_SUPPORT_DISPLAY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 524288
D3D11_FORMAT_SUPPORT_CAST_WITHIN_BIT_LAYOUT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 1048576
D3D11_FORMAT_SUPPORT_MULTISAMPLE_RENDERTARGET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 2097152
D3D11_FORMAT_SUPPORT_MULTISAMPLE_LOAD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 4194304
D3D11_FORMAT_SUPPORT_SHADER_GATHER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 8388608
D3D11_FORMAT_SUPPORT_BACK_BUFFER_CAST: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 16777216
D3D11_FORMAT_SUPPORT_TYPED_UNORDERED_ACCESS_VIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 33554432
D3D11_FORMAT_SUPPORT_SHADER_GATHER_COMPARISON: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 67108864
D3D11_FORMAT_SUPPORT_DECODER_OUTPUT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 134217728
D3D11_FORMAT_SUPPORT_VIDEO_PROCESSOR_OUTPUT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 268435456
D3D11_FORMAT_SUPPORT_VIDEO_PROCESSOR_INPUT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 536870912
D3D11_FORMAT_SUPPORT_VIDEO_ENCODER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT = 1073741824
D3D11_FORMAT_SUPPORT2 = Int32
D3D11_FORMAT_SUPPORT2_UAV_ATOMIC_ADD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT2 = 1
D3D11_FORMAT_SUPPORT2_UAV_ATOMIC_BITWISE_OPS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT2 = 2
D3D11_FORMAT_SUPPORT2_UAV_ATOMIC_COMPARE_STORE_OR_COMPARE_EXCHANGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT2 = 4
D3D11_FORMAT_SUPPORT2_UAV_ATOMIC_EXCHANGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT2 = 8
D3D11_FORMAT_SUPPORT2_UAV_ATOMIC_SIGNED_MIN_OR_MAX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT2 = 16
D3D11_FORMAT_SUPPORT2_UAV_ATOMIC_UNSIGNED_MIN_OR_MAX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT2 = 32
D3D11_FORMAT_SUPPORT2_UAV_TYPED_LOAD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT2 = 64
D3D11_FORMAT_SUPPORT2_UAV_TYPED_STORE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT2 = 128
D3D11_FORMAT_SUPPORT2_OUTPUT_MERGER_LOGIC_OP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT2 = 256
D3D11_FORMAT_SUPPORT2_TILED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT2 = 512
D3D11_FORMAT_SUPPORT2_SHAREABLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT2 = 1024
D3D11_FORMAT_SUPPORT2_MULTIPLANE_OVERLAY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT2 = 16384
D3D11_FORMAT_SUPPORT2_DISPLAYABLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FORMAT_SUPPORT2 = 65536
class D3D11_FUNCTION_DESC(Structure):
    Version: UInt32
    Creator: win32more.Windows.Win32.Foundation.PSTR
    Flags: UInt32
    ConstantBuffers: UInt32
    BoundResources: UInt32
    InstructionCount: UInt32
    TempRegisterCount: UInt32
    TempArrayCount: UInt32
    DefCount: UInt32
    DclCount: UInt32
    TextureNormalInstructions: UInt32
    TextureLoadInstructions: UInt32
    TextureCompInstructions: UInt32
    TextureBiasInstructions: UInt32
    TextureGradientInstructions: UInt32
    FloatInstructionCount: UInt32
    IntInstructionCount: UInt32
    UintInstructionCount: UInt32
    StaticFlowControlCount: UInt32
    DynamicFlowControlCount: UInt32
    MacroInstructionCount: UInt32
    ArrayInstructionCount: UInt32
    MovInstructionCount: UInt32
    MovcInstructionCount: UInt32
    ConversionInstructionCount: UInt32
    BitwiseInstructionCount: UInt32
    MinFeatureLevel: win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL
    RequiredFeatureFlags: UInt64
    Name: win32more.Windows.Win32.Foundation.PSTR
    FunctionParameterCount: Int32
    HasReturn: win32more.Windows.Win32.Foundation.BOOL
    Has10Level9VertexShader: win32more.Windows.Win32.Foundation.BOOL
    Has10Level9PixelShader: win32more.Windows.Win32.Foundation.BOOL
class D3D11_GEOMETRY_SHADER_TRACE_DESC(Structure):
    Invocation: UInt64
class D3D11_HULL_SHADER_TRACE_DESC(Structure):
    Invocation: UInt64
class D3D11_INFO_QUEUE_FILTER(Structure):
    AllowList: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_INFO_QUEUE_FILTER_DESC
    DenyList: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_INFO_QUEUE_FILTER_DESC
class D3D11_INFO_QUEUE_FILTER_DESC(Structure):
    NumCategories: UInt32
    pCategoryList: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_CATEGORY)
    NumSeverities: UInt32
    pSeverityList: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_SEVERITY)
    NumIDs: UInt32
    pIDList: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID)
D3D11_INPUT_CLASSIFICATION = Int32
D3D11_INPUT_PER_VERTEX_DATA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_INPUT_CLASSIFICATION = 0
D3D11_INPUT_PER_INSTANCE_DATA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_INPUT_CLASSIFICATION = 1
class D3D11_INPUT_ELEMENT_DESC(Structure):
    SemanticName: win32more.Windows.Win32.Foundation.PSTR
    SemanticIndex: UInt32
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    InputSlot: UInt32
    AlignedByteOffset: UInt32
    InputSlotClass: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_INPUT_CLASSIFICATION
    InstanceDataStepRate: UInt32
class D3D11_KEY_EXCHANGE_HW_PROTECTION_DATA(Structure):
    HWProtectionFunctionID: UInt32
    pInputData: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_KEY_EXCHANGE_HW_PROTECTION_INPUT_DATA)
    pOutputData: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_KEY_EXCHANGE_HW_PROTECTION_OUTPUT_DATA)
    Status: win32more.Windows.Win32.Foundation.HRESULT
class D3D11_KEY_EXCHANGE_HW_PROTECTION_INPUT_DATA(Structure):
    PrivateDataSize: UInt32
    HWProtectionDataSize: UInt32
    pbInput: Byte * 4
class D3D11_KEY_EXCHANGE_HW_PROTECTION_OUTPUT_DATA(Structure):
    PrivateDataSize: UInt32
    MaxHWProtectionDataSize: UInt32
    HWProtectionDataSize: UInt32
    TransportTime: UInt64
    ExecutionTime: UInt64
    pbOutput: Byte * 4
class D3D11_LIBRARY_DESC(Structure):
    Creator: win32more.Windows.Win32.Foundation.PSTR
    Flags: UInt32
    FunctionCount: UInt32
D3D11_LOGIC_OP = Int32
D3D11_LOGIC_OP_CLEAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LOGIC_OP = 0
D3D11_LOGIC_OP_SET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LOGIC_OP = 1
D3D11_LOGIC_OP_COPY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LOGIC_OP = 2
D3D11_LOGIC_OP_COPY_INVERTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LOGIC_OP = 3
D3D11_LOGIC_OP_NOOP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LOGIC_OP = 4
D3D11_LOGIC_OP_INVERT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LOGIC_OP = 5
D3D11_LOGIC_OP_AND: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LOGIC_OP = 6
D3D11_LOGIC_OP_NAND: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LOGIC_OP = 7
D3D11_LOGIC_OP_OR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LOGIC_OP = 8
D3D11_LOGIC_OP_NOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LOGIC_OP = 9
D3D11_LOGIC_OP_XOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LOGIC_OP = 10
D3D11_LOGIC_OP_EQUIV: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LOGIC_OP = 11
D3D11_LOGIC_OP_AND_REVERSE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LOGIC_OP = 12
D3D11_LOGIC_OP_AND_INVERTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LOGIC_OP = 13
D3D11_LOGIC_OP_OR_REVERSE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LOGIC_OP = 14
D3D11_LOGIC_OP_OR_INVERTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LOGIC_OP = 15
D3D11_MAP = Int32
D3D11_MAP_READ: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MAP = 1
D3D11_MAP_WRITE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MAP = 2
D3D11_MAP_READ_WRITE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MAP = 3
D3D11_MAP_WRITE_DISCARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MAP = 4
D3D11_MAP_WRITE_NO_OVERWRITE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MAP = 5
class D3D11_MAPPED_SUBRESOURCE(Structure):
    pData: VoidPtr
    RowPitch: UInt32
    DepthPitch: UInt32
D3D11_MAP_FLAG = Int32
D3D11_MAP_FLAG_DO_NOT_WAIT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MAP_FLAG = 1048576
class D3D11_MESSAGE(Structure):
    Category: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_CATEGORY
    Severity: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_SEVERITY
    ID: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID
    pDescription: POINTER(Byte)
    DescriptionByteLength: UIntPtr
D3D11_MESSAGE_CATEGORY = Int32
D3D11_MESSAGE_CATEGORY_APPLICATION_DEFINED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_CATEGORY = 0
D3D11_MESSAGE_CATEGORY_MISCELLANEOUS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_CATEGORY = 1
D3D11_MESSAGE_CATEGORY_INITIALIZATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_CATEGORY = 2
D3D11_MESSAGE_CATEGORY_CLEANUP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_CATEGORY = 3
D3D11_MESSAGE_CATEGORY_COMPILATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_CATEGORY = 4
D3D11_MESSAGE_CATEGORY_STATE_CREATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_CATEGORY = 5
D3D11_MESSAGE_CATEGORY_STATE_SETTING: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_CATEGORY = 6
D3D11_MESSAGE_CATEGORY_STATE_GETTING: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_CATEGORY = 7
D3D11_MESSAGE_CATEGORY_RESOURCE_MANIPULATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_CATEGORY = 8
D3D11_MESSAGE_CATEGORY_EXECUTION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_CATEGORY = 9
D3D11_MESSAGE_CATEGORY_SHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_CATEGORY = 10
D3D11_MESSAGE_ID = Int32
D3D11_MESSAGE_ID_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 0
D3D11_MESSAGE_ID_DEVICE_IASETVERTEXBUFFERS_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1
D3D11_MESSAGE_ID_DEVICE_IASETINDEXBUFFER_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2
D3D11_MESSAGE_ID_DEVICE_VSSETSHADERRESOURCES_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3
D3D11_MESSAGE_ID_DEVICE_VSSETCONSTANTBUFFERS_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 4
D3D11_MESSAGE_ID_DEVICE_GSSETSHADERRESOURCES_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 5
D3D11_MESSAGE_ID_DEVICE_GSSETCONSTANTBUFFERS_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 6
D3D11_MESSAGE_ID_DEVICE_PSSETSHADERRESOURCES_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 7
D3D11_MESSAGE_ID_DEVICE_PSSETCONSTANTBUFFERS_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 8
D3D11_MESSAGE_ID_DEVICE_OMSETRENDERTARGETS_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 9
D3D11_MESSAGE_ID_DEVICE_SOSETTARGETS_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 10
D3D11_MESSAGE_ID_STRING_FROM_APPLICATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 11
D3D11_MESSAGE_ID_CORRUPTED_THIS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 12
D3D11_MESSAGE_ID_CORRUPTED_PARAMETER1: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 13
D3D11_MESSAGE_ID_CORRUPTED_PARAMETER2: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 14
D3D11_MESSAGE_ID_CORRUPTED_PARAMETER3: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 15
D3D11_MESSAGE_ID_CORRUPTED_PARAMETER4: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 16
D3D11_MESSAGE_ID_CORRUPTED_PARAMETER5: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 17
D3D11_MESSAGE_ID_CORRUPTED_PARAMETER6: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 18
D3D11_MESSAGE_ID_CORRUPTED_PARAMETER7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 19
D3D11_MESSAGE_ID_CORRUPTED_PARAMETER8: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 20
D3D11_MESSAGE_ID_CORRUPTED_PARAMETER9: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 21
D3D11_MESSAGE_ID_CORRUPTED_PARAMETER10: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 22
D3D11_MESSAGE_ID_CORRUPTED_PARAMETER11: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 23
D3D11_MESSAGE_ID_CORRUPTED_PARAMETER12: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 24
D3D11_MESSAGE_ID_CORRUPTED_PARAMETER13: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 25
D3D11_MESSAGE_ID_CORRUPTED_PARAMETER14: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 26
D3D11_MESSAGE_ID_CORRUPTED_PARAMETER15: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 27
D3D11_MESSAGE_ID_CORRUPTED_MULTITHREADING: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 28
D3D11_MESSAGE_ID_MESSAGE_REPORTING_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 29
D3D11_MESSAGE_ID_IASETINPUTLAYOUT_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 30
D3D11_MESSAGE_ID_IASETVERTEXBUFFERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 31
D3D11_MESSAGE_ID_IASETINDEXBUFFER_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 32
D3D11_MESSAGE_ID_VSSETSHADER_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 33
D3D11_MESSAGE_ID_VSSETSHADERRESOURCES_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 34
D3D11_MESSAGE_ID_VSSETCONSTANTBUFFERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 35
D3D11_MESSAGE_ID_VSSETSAMPLERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 36
D3D11_MESSAGE_ID_GSSETSHADER_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 37
D3D11_MESSAGE_ID_GSSETSHADERRESOURCES_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 38
D3D11_MESSAGE_ID_GSSETCONSTANTBUFFERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 39
D3D11_MESSAGE_ID_GSSETSAMPLERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 40
D3D11_MESSAGE_ID_SOSETTARGETS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 41
D3D11_MESSAGE_ID_PSSETSHADER_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 42
D3D11_MESSAGE_ID_PSSETSHADERRESOURCES_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 43
D3D11_MESSAGE_ID_PSSETCONSTANTBUFFERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 44
D3D11_MESSAGE_ID_PSSETSAMPLERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 45
D3D11_MESSAGE_ID_RSSETSTATE_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 46
D3D11_MESSAGE_ID_OMSETBLENDSTATE_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 47
D3D11_MESSAGE_ID_OMSETDEPTHSTENCILSTATE_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 48
D3D11_MESSAGE_ID_OMSETRENDERTARGETS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 49
D3D11_MESSAGE_ID_SETPREDICATION_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 50
D3D11_MESSAGE_ID_GETPRIVATEDATA_MOREDATA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 51
D3D11_MESSAGE_ID_SETPRIVATEDATA_INVALIDFREEDATA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 52
D3D11_MESSAGE_ID_SETPRIVATEDATA_INVALIDIUNKNOWN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 53
D3D11_MESSAGE_ID_SETPRIVATEDATA_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 54
D3D11_MESSAGE_ID_SETPRIVATEDATA_CHANGINGPARAMS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 55
D3D11_MESSAGE_ID_SETPRIVATEDATA_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 56
D3D11_MESSAGE_ID_CREATEBUFFER_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 57
D3D11_MESSAGE_ID_CREATEBUFFER_INVALIDSAMPLES: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 58
D3D11_MESSAGE_ID_CREATEBUFFER_UNRECOGNIZEDUSAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 59
D3D11_MESSAGE_ID_CREATEBUFFER_UNRECOGNIZEDBINDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 60
D3D11_MESSAGE_ID_CREATEBUFFER_UNRECOGNIZEDCPUACCESSFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 61
D3D11_MESSAGE_ID_CREATEBUFFER_UNRECOGNIZEDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 62
D3D11_MESSAGE_ID_CREATEBUFFER_INVALIDCPUACCESSFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 63
D3D11_MESSAGE_ID_CREATEBUFFER_INVALIDBINDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 64
D3D11_MESSAGE_ID_CREATEBUFFER_INVALIDINITIALDATA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 65
D3D11_MESSAGE_ID_CREATEBUFFER_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 66
D3D11_MESSAGE_ID_CREATEBUFFER_INVALIDMIPLEVELS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 67
D3D11_MESSAGE_ID_CREATEBUFFER_INVALIDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 68
D3D11_MESSAGE_ID_CREATEBUFFER_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 69
D3D11_MESSAGE_ID_CREATEBUFFER_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 70
D3D11_MESSAGE_ID_CREATEBUFFER_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 71
D3D11_MESSAGE_ID_CREATEBUFFER_INVALIDCONSTANTBUFFERBINDINGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 72
D3D11_MESSAGE_ID_CREATEBUFFER_LARGEALLOCATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 73
D3D11_MESSAGE_ID_CREATETEXTURE1D_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 74
D3D11_MESSAGE_ID_CREATETEXTURE1D_UNSUPPORTEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 75
D3D11_MESSAGE_ID_CREATETEXTURE1D_INVALIDSAMPLES: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 76
D3D11_MESSAGE_ID_CREATETEXTURE1D_UNRECOGNIZEDUSAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 77
D3D11_MESSAGE_ID_CREATETEXTURE1D_UNRECOGNIZEDBINDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 78
D3D11_MESSAGE_ID_CREATETEXTURE1D_UNRECOGNIZEDCPUACCESSFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 79
D3D11_MESSAGE_ID_CREATETEXTURE1D_UNRECOGNIZEDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 80
D3D11_MESSAGE_ID_CREATETEXTURE1D_INVALIDCPUACCESSFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 81
D3D11_MESSAGE_ID_CREATETEXTURE1D_INVALIDBINDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 82
D3D11_MESSAGE_ID_CREATETEXTURE1D_INVALIDINITIALDATA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 83
D3D11_MESSAGE_ID_CREATETEXTURE1D_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 84
D3D11_MESSAGE_ID_CREATETEXTURE1D_INVALIDMIPLEVELS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 85
D3D11_MESSAGE_ID_CREATETEXTURE1D_INVALIDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 86
D3D11_MESSAGE_ID_CREATETEXTURE1D_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 87
D3D11_MESSAGE_ID_CREATETEXTURE1D_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 88
D3D11_MESSAGE_ID_CREATETEXTURE1D_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 89
D3D11_MESSAGE_ID_CREATETEXTURE1D_LARGEALLOCATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 90
D3D11_MESSAGE_ID_CREATETEXTURE2D_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 91
D3D11_MESSAGE_ID_CREATETEXTURE2D_UNSUPPORTEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 92
D3D11_MESSAGE_ID_CREATETEXTURE2D_INVALIDSAMPLES: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 93
D3D11_MESSAGE_ID_CREATETEXTURE2D_UNRECOGNIZEDUSAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 94
D3D11_MESSAGE_ID_CREATETEXTURE2D_UNRECOGNIZEDBINDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 95
D3D11_MESSAGE_ID_CREATETEXTURE2D_UNRECOGNIZEDCPUACCESSFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 96
D3D11_MESSAGE_ID_CREATETEXTURE2D_UNRECOGNIZEDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 97
D3D11_MESSAGE_ID_CREATETEXTURE2D_INVALIDCPUACCESSFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 98
D3D11_MESSAGE_ID_CREATETEXTURE2D_INVALIDBINDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 99
D3D11_MESSAGE_ID_CREATETEXTURE2D_INVALIDINITIALDATA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 100
D3D11_MESSAGE_ID_CREATETEXTURE2D_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 101
D3D11_MESSAGE_ID_CREATETEXTURE2D_INVALIDMIPLEVELS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 102
D3D11_MESSAGE_ID_CREATETEXTURE2D_INVALIDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 103
D3D11_MESSAGE_ID_CREATETEXTURE2D_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 104
D3D11_MESSAGE_ID_CREATETEXTURE2D_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 105
D3D11_MESSAGE_ID_CREATETEXTURE2D_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 106
D3D11_MESSAGE_ID_CREATETEXTURE2D_LARGEALLOCATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 107
D3D11_MESSAGE_ID_CREATETEXTURE3D_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 108
D3D11_MESSAGE_ID_CREATETEXTURE3D_UNSUPPORTEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 109
D3D11_MESSAGE_ID_CREATETEXTURE3D_INVALIDSAMPLES: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 110
D3D11_MESSAGE_ID_CREATETEXTURE3D_UNRECOGNIZEDUSAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 111
D3D11_MESSAGE_ID_CREATETEXTURE3D_UNRECOGNIZEDBINDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 112
D3D11_MESSAGE_ID_CREATETEXTURE3D_UNRECOGNIZEDCPUACCESSFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 113
D3D11_MESSAGE_ID_CREATETEXTURE3D_UNRECOGNIZEDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 114
D3D11_MESSAGE_ID_CREATETEXTURE3D_INVALIDCPUACCESSFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 115
D3D11_MESSAGE_ID_CREATETEXTURE3D_INVALIDBINDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 116
D3D11_MESSAGE_ID_CREATETEXTURE3D_INVALIDINITIALDATA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 117
D3D11_MESSAGE_ID_CREATETEXTURE3D_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 118
D3D11_MESSAGE_ID_CREATETEXTURE3D_INVALIDMIPLEVELS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 119
D3D11_MESSAGE_ID_CREATETEXTURE3D_INVALIDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 120
D3D11_MESSAGE_ID_CREATETEXTURE3D_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 121
D3D11_MESSAGE_ID_CREATETEXTURE3D_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 122
D3D11_MESSAGE_ID_CREATETEXTURE3D_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 123
D3D11_MESSAGE_ID_CREATETEXTURE3D_LARGEALLOCATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 124
D3D11_MESSAGE_ID_CREATESHADERRESOURCEVIEW_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 125
D3D11_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDDESC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 126
D3D11_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 127
D3D11_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 128
D3D11_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 129
D3D11_MESSAGE_ID_CREATESHADERRESOURCEVIEW_TOOMANYOBJECTS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 130
D3D11_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 131
D3D11_MESSAGE_ID_CREATESHADERRESOURCEVIEW_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 132
D3D11_MESSAGE_ID_CREATERENDERTARGETVIEW_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 133
D3D11_MESSAGE_ID_CREATERENDERTARGETVIEW_UNSUPPORTEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 134
D3D11_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDDESC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 135
D3D11_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 136
D3D11_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 137
D3D11_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 138
D3D11_MESSAGE_ID_CREATERENDERTARGETVIEW_TOOMANYOBJECTS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 139
D3D11_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 140
D3D11_MESSAGE_ID_CREATERENDERTARGETVIEW_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 141
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 142
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_INVALIDDESC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 143
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 144
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 145
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 146
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_TOOMANYOBJECTS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 147
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 148
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 149
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 150
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_TOOMANYELEMENTS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 151
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 152
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_INCOMPATIBLEFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 153
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDSLOT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 154
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDINPUTSLOTCLASS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 155
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_STEPRATESLOTCLASSMISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 156
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDSLOTCLASSCHANGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 157
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDSTEPRATECHANGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 158
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_INVALIDALIGNMENT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 159
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_DUPLICATESEMANTIC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 160
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_UNPARSEABLEINPUTSIGNATURE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 161
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_NULLSEMANTIC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 162
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_MISSINGELEMENT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 163
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 164
D3D11_MESSAGE_ID_CREATEVERTEXSHADER_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 165
D3D11_MESSAGE_ID_CREATEVERTEXSHADER_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 166
D3D11_MESSAGE_ID_CREATEVERTEXSHADER_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 167
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADER_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 168
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADER_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 169
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADER_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 170
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 171
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 172
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 173
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDNUMENTRIES: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 174
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_OUTPUTSTREAMSTRIDEUNUSED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 175
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_UNEXPECTEDDECL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 176
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_EXPECTEDDECL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 177
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_OUTPUTSLOT0EXPECTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 178
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDOUTPUTSLOT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 179
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_ONLYONEELEMENTPERSLOT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 180
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDCOMPONENTCOUNT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 181
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDSTARTCOMPONENTANDCOMPONENTCOUNT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 182
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDGAPDEFINITION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 183
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_REPEATEDOUTPUT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 184
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDOUTPUTSTREAMSTRIDE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 185
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_MISSINGSEMANTIC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 186
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_MASKMISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 187
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_CANTHAVEONLYGAPS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 188
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_DECLTOOCOMPLEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 189
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_MISSINGOUTPUTSIGNATURE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 190
D3D11_MESSAGE_ID_CREATEPIXELSHADER_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 191
D3D11_MESSAGE_ID_CREATEPIXELSHADER_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 192
D3D11_MESSAGE_ID_CREATEPIXELSHADER_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 193
D3D11_MESSAGE_ID_CREATERASTERIZERSTATE_INVALIDFILLMODE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 194
D3D11_MESSAGE_ID_CREATERASTERIZERSTATE_INVALIDCULLMODE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 195
D3D11_MESSAGE_ID_CREATERASTERIZERSTATE_INVALIDDEPTHBIASCLAMP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 196
D3D11_MESSAGE_ID_CREATERASTERIZERSTATE_INVALIDSLOPESCALEDDEPTHBIAS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 197
D3D11_MESSAGE_ID_CREATERASTERIZERSTATE_TOOMANYOBJECTS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 198
D3D11_MESSAGE_ID_CREATERASTERIZERSTATE_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 199
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDDEPTHWRITEMASK: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 200
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDDEPTHFUNC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 201
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDFRONTFACESTENCILFAILOP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 202
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDFRONTFACESTENCILZFAILOP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 203
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDFRONTFACESTENCILPASSOP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 204
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDFRONTFACESTENCILFUNC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 205
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDBACKFACESTENCILFAILOP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 206
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDBACKFACESTENCILZFAILOP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 207
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDBACKFACESTENCILPASSOP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 208
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_INVALIDBACKFACESTENCILFUNC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 209
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_TOOMANYOBJECTS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 210
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 211
D3D11_MESSAGE_ID_CREATEBLENDSTATE_INVALIDSRCBLEND: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 212
D3D11_MESSAGE_ID_CREATEBLENDSTATE_INVALIDDESTBLEND: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 213
D3D11_MESSAGE_ID_CREATEBLENDSTATE_INVALIDBLENDOP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 214
D3D11_MESSAGE_ID_CREATEBLENDSTATE_INVALIDSRCBLENDALPHA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 215
D3D11_MESSAGE_ID_CREATEBLENDSTATE_INVALIDDESTBLENDALPHA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 216
D3D11_MESSAGE_ID_CREATEBLENDSTATE_INVALIDBLENDOPALPHA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 217
D3D11_MESSAGE_ID_CREATEBLENDSTATE_INVALIDRENDERTARGETWRITEMASK: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 218
D3D11_MESSAGE_ID_CREATEBLENDSTATE_TOOMANYOBJECTS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 219
D3D11_MESSAGE_ID_CREATEBLENDSTATE_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 220
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDFILTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 221
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDADDRESSU: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 222
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDADDRESSV: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 223
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDADDRESSW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 224
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDMIPLODBIAS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 225
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDMAXANISOTROPY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 226
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDCOMPARISONFUNC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 227
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDMINLOD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 228
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_INVALIDMAXLOD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 229
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_TOOMANYOBJECTS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 230
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 231
D3D11_MESSAGE_ID_CREATEQUERYORPREDICATE_INVALIDQUERY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 232
D3D11_MESSAGE_ID_CREATEQUERYORPREDICATE_INVALIDMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 233
D3D11_MESSAGE_ID_CREATEQUERYORPREDICATE_UNEXPECTEDMISCFLAG: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 234
D3D11_MESSAGE_ID_CREATEQUERYORPREDICATE_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 235
D3D11_MESSAGE_ID_DEVICE_IASETPRIMITIVETOPOLOGY_TOPOLOGY_UNRECOGNIZED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 236
D3D11_MESSAGE_ID_DEVICE_IASETPRIMITIVETOPOLOGY_TOPOLOGY_UNDEFINED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 237
D3D11_MESSAGE_ID_IASETVERTEXBUFFERS_INVALIDBUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 238
D3D11_MESSAGE_ID_DEVICE_IASETVERTEXBUFFERS_OFFSET_TOO_LARGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 239
D3D11_MESSAGE_ID_DEVICE_IASETVERTEXBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 240
D3D11_MESSAGE_ID_IASETINDEXBUFFER_INVALIDBUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 241
D3D11_MESSAGE_ID_DEVICE_IASETINDEXBUFFER_FORMAT_INVALID: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 242
D3D11_MESSAGE_ID_DEVICE_IASETINDEXBUFFER_OFFSET_TOO_LARGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 243
D3D11_MESSAGE_ID_DEVICE_IASETINDEXBUFFER_OFFSET_UNALIGNED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 244
D3D11_MESSAGE_ID_DEVICE_VSSETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 245
D3D11_MESSAGE_ID_VSSETCONSTANTBUFFERS_INVALIDBUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 246
D3D11_MESSAGE_ID_DEVICE_VSSETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 247
D3D11_MESSAGE_ID_DEVICE_VSSETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 248
D3D11_MESSAGE_ID_DEVICE_GSSETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 249
D3D11_MESSAGE_ID_GSSETCONSTANTBUFFERS_INVALIDBUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 250
D3D11_MESSAGE_ID_DEVICE_GSSETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 251
D3D11_MESSAGE_ID_DEVICE_GSSETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 252
D3D11_MESSAGE_ID_SOSETTARGETS_INVALIDBUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 253
D3D11_MESSAGE_ID_DEVICE_SOSETTARGETS_OFFSET_UNALIGNED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 254
D3D11_MESSAGE_ID_DEVICE_PSSETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 255
D3D11_MESSAGE_ID_PSSETCONSTANTBUFFERS_INVALIDBUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 256
D3D11_MESSAGE_ID_DEVICE_PSSETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 257
D3D11_MESSAGE_ID_DEVICE_PSSETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 258
D3D11_MESSAGE_ID_DEVICE_RSSETVIEWPORTS_INVALIDVIEWPORT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 259
D3D11_MESSAGE_ID_DEVICE_RSSETSCISSORRECTS_INVALIDSCISSOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 260
D3D11_MESSAGE_ID_CLEARRENDERTARGETVIEW_DENORMFLUSH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 261
D3D11_MESSAGE_ID_CLEARDEPTHSTENCILVIEW_DENORMFLUSH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 262
D3D11_MESSAGE_ID_CLEARDEPTHSTENCILVIEW_INVALID: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 263
D3D11_MESSAGE_ID_DEVICE_IAGETVERTEXBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 264
D3D11_MESSAGE_ID_DEVICE_VSGETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 265
D3D11_MESSAGE_ID_DEVICE_VSGETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 266
D3D11_MESSAGE_ID_DEVICE_VSGETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 267
D3D11_MESSAGE_ID_DEVICE_GSGETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 268
D3D11_MESSAGE_ID_DEVICE_GSGETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 269
D3D11_MESSAGE_ID_DEVICE_GSGETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 270
D3D11_MESSAGE_ID_DEVICE_SOGETTARGETS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 271
D3D11_MESSAGE_ID_DEVICE_PSGETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 272
D3D11_MESSAGE_ID_DEVICE_PSGETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 273
D3D11_MESSAGE_ID_DEVICE_PSGETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 274
D3D11_MESSAGE_ID_DEVICE_RSGETVIEWPORTS_VIEWPORTS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 275
D3D11_MESSAGE_ID_DEVICE_RSGETSCISSORRECTS_RECTS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 276
D3D11_MESSAGE_ID_DEVICE_GENERATEMIPS_RESOURCE_INVALID: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 277
D3D11_MESSAGE_ID_COPYSUBRESOURCEREGION_INVALIDDESTINATIONSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 278
D3D11_MESSAGE_ID_COPYSUBRESOURCEREGION_INVALIDSOURCESUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 279
D3D11_MESSAGE_ID_COPYSUBRESOURCEREGION_INVALIDSOURCEBOX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 280
D3D11_MESSAGE_ID_COPYSUBRESOURCEREGION_INVALIDSOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 281
D3D11_MESSAGE_ID_COPYSUBRESOURCEREGION_INVALIDDESTINATIONSTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 282
D3D11_MESSAGE_ID_COPYSUBRESOURCEREGION_INVALIDSOURCESTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 283
D3D11_MESSAGE_ID_COPYRESOURCE_INVALIDSOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 284
D3D11_MESSAGE_ID_COPYRESOURCE_INVALIDDESTINATIONSTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 285
D3D11_MESSAGE_ID_COPYRESOURCE_INVALIDSOURCESTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 286
D3D11_MESSAGE_ID_UPDATESUBRESOURCE_INVALIDDESTINATIONSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 287
D3D11_MESSAGE_ID_UPDATESUBRESOURCE_INVALIDDESTINATIONBOX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 288
D3D11_MESSAGE_ID_UPDATESUBRESOURCE_INVALIDDESTINATIONSTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 289
D3D11_MESSAGE_ID_DEVICE_RESOLVESUBRESOURCE_DESTINATION_INVALID: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 290
D3D11_MESSAGE_ID_DEVICE_RESOLVESUBRESOURCE_DESTINATION_SUBRESOURCE_INVALID: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 291
D3D11_MESSAGE_ID_DEVICE_RESOLVESUBRESOURCE_SOURCE_INVALID: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 292
D3D11_MESSAGE_ID_DEVICE_RESOLVESUBRESOURCE_SOURCE_SUBRESOURCE_INVALID: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 293
D3D11_MESSAGE_ID_DEVICE_RESOLVESUBRESOURCE_FORMAT_INVALID: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 294
D3D11_MESSAGE_ID_BUFFER_MAP_INVALIDMAPTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 295
D3D11_MESSAGE_ID_BUFFER_MAP_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 296
D3D11_MESSAGE_ID_BUFFER_MAP_ALREADYMAPPED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 297
D3D11_MESSAGE_ID_BUFFER_MAP_DEVICEREMOVED_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 298
D3D11_MESSAGE_ID_BUFFER_UNMAP_NOTMAPPED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 299
D3D11_MESSAGE_ID_TEXTURE1D_MAP_INVALIDMAPTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 300
D3D11_MESSAGE_ID_TEXTURE1D_MAP_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 301
D3D11_MESSAGE_ID_TEXTURE1D_MAP_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 302
D3D11_MESSAGE_ID_TEXTURE1D_MAP_ALREADYMAPPED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 303
D3D11_MESSAGE_ID_TEXTURE1D_MAP_DEVICEREMOVED_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 304
D3D11_MESSAGE_ID_TEXTURE1D_UNMAP_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 305
D3D11_MESSAGE_ID_TEXTURE1D_UNMAP_NOTMAPPED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 306
D3D11_MESSAGE_ID_TEXTURE2D_MAP_INVALIDMAPTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 307
D3D11_MESSAGE_ID_TEXTURE2D_MAP_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 308
D3D11_MESSAGE_ID_TEXTURE2D_MAP_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 309
D3D11_MESSAGE_ID_TEXTURE2D_MAP_ALREADYMAPPED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 310
D3D11_MESSAGE_ID_TEXTURE2D_MAP_DEVICEREMOVED_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 311
D3D11_MESSAGE_ID_TEXTURE2D_UNMAP_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 312
D3D11_MESSAGE_ID_TEXTURE2D_UNMAP_NOTMAPPED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 313
D3D11_MESSAGE_ID_TEXTURE3D_MAP_INVALIDMAPTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 314
D3D11_MESSAGE_ID_TEXTURE3D_MAP_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 315
D3D11_MESSAGE_ID_TEXTURE3D_MAP_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 316
D3D11_MESSAGE_ID_TEXTURE3D_MAP_ALREADYMAPPED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 317
D3D11_MESSAGE_ID_TEXTURE3D_MAP_DEVICEREMOVED_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 318
D3D11_MESSAGE_ID_TEXTURE3D_UNMAP_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 319
D3D11_MESSAGE_ID_TEXTURE3D_UNMAP_NOTMAPPED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 320
D3D11_MESSAGE_ID_CHECKFORMATSUPPORT_FORMAT_DEPRECATED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 321
D3D11_MESSAGE_ID_CHECKMULTISAMPLEQUALITYLEVELS_FORMAT_DEPRECATED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 322
D3D11_MESSAGE_ID_SETEXCEPTIONMODE_UNRECOGNIZEDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 323
D3D11_MESSAGE_ID_SETEXCEPTIONMODE_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 324
D3D11_MESSAGE_ID_SETEXCEPTIONMODE_DEVICEREMOVED_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 325
D3D11_MESSAGE_ID_REF_SIMULATING_INFINITELY_FAST_HARDWARE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 326
D3D11_MESSAGE_ID_REF_THREADING_MODE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 327
D3D11_MESSAGE_ID_REF_UMDRIVER_EXCEPTION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 328
D3D11_MESSAGE_ID_REF_KMDRIVER_EXCEPTION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 329
D3D11_MESSAGE_ID_REF_HARDWARE_EXCEPTION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 330
D3D11_MESSAGE_ID_REF_ACCESSING_INDEXABLE_TEMP_OUT_OF_RANGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 331
D3D11_MESSAGE_ID_REF_PROBLEM_PARSING_SHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 332
D3D11_MESSAGE_ID_REF_OUT_OF_MEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 333
D3D11_MESSAGE_ID_REF_INFO: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 334
D3D11_MESSAGE_ID_DEVICE_DRAW_VERTEXPOS_OVERFLOW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 335
D3D11_MESSAGE_ID_DEVICE_DRAWINDEXED_INDEXPOS_OVERFLOW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 336
D3D11_MESSAGE_ID_DEVICE_DRAWINSTANCED_VERTEXPOS_OVERFLOW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 337
D3D11_MESSAGE_ID_DEVICE_DRAWINSTANCED_INSTANCEPOS_OVERFLOW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 338
D3D11_MESSAGE_ID_DEVICE_DRAWINDEXEDINSTANCED_INSTANCEPOS_OVERFLOW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 339
D3D11_MESSAGE_ID_DEVICE_DRAWINDEXEDINSTANCED_INDEXPOS_OVERFLOW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 340
D3D11_MESSAGE_ID_DEVICE_DRAW_VERTEX_SHADER_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 341
D3D11_MESSAGE_ID_DEVICE_SHADER_LINKAGE_SEMANTICNAME_NOT_FOUND: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 342
D3D11_MESSAGE_ID_DEVICE_SHADER_LINKAGE_REGISTERINDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 343
D3D11_MESSAGE_ID_DEVICE_SHADER_LINKAGE_COMPONENTTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 344
D3D11_MESSAGE_ID_DEVICE_SHADER_LINKAGE_REGISTERMASK: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 345
D3D11_MESSAGE_ID_DEVICE_SHADER_LINKAGE_SYSTEMVALUE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 346
D3D11_MESSAGE_ID_DEVICE_SHADER_LINKAGE_NEVERWRITTEN_ALWAYSREADS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 347
D3D11_MESSAGE_ID_DEVICE_DRAW_VERTEX_BUFFER_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 348
D3D11_MESSAGE_ID_DEVICE_DRAW_INPUTLAYOUT_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 349
D3D11_MESSAGE_ID_DEVICE_DRAW_CONSTANT_BUFFER_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 350
D3D11_MESSAGE_ID_DEVICE_DRAW_CONSTANT_BUFFER_TOO_SMALL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 351
D3D11_MESSAGE_ID_DEVICE_DRAW_SAMPLER_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 352
D3D11_MESSAGE_ID_DEVICE_DRAW_SHADERRESOURCEVIEW_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 353
D3D11_MESSAGE_ID_DEVICE_DRAW_VIEW_DIMENSION_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 354
D3D11_MESSAGE_ID_DEVICE_DRAW_VERTEX_BUFFER_STRIDE_TOO_SMALL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 355
D3D11_MESSAGE_ID_DEVICE_DRAW_VERTEX_BUFFER_TOO_SMALL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 356
D3D11_MESSAGE_ID_DEVICE_DRAW_INDEX_BUFFER_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 357
D3D11_MESSAGE_ID_DEVICE_DRAW_INDEX_BUFFER_FORMAT_INVALID: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 358
D3D11_MESSAGE_ID_DEVICE_DRAW_INDEX_BUFFER_TOO_SMALL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 359
D3D11_MESSAGE_ID_DEVICE_DRAW_GS_INPUT_PRIMITIVE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 360
D3D11_MESSAGE_ID_DEVICE_DRAW_RESOURCE_RETURN_TYPE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 361
D3D11_MESSAGE_ID_DEVICE_DRAW_POSITION_NOT_PRESENT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 362
D3D11_MESSAGE_ID_DEVICE_DRAW_OUTPUT_STREAM_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 363
D3D11_MESSAGE_ID_DEVICE_DRAW_BOUND_RESOURCE_MAPPED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 364
D3D11_MESSAGE_ID_DEVICE_DRAW_INVALID_PRIMITIVETOPOLOGY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 365
D3D11_MESSAGE_ID_DEVICE_DRAW_VERTEX_OFFSET_UNALIGNED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 366
D3D11_MESSAGE_ID_DEVICE_DRAW_VERTEX_STRIDE_UNALIGNED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 367
D3D11_MESSAGE_ID_DEVICE_DRAW_INDEX_OFFSET_UNALIGNED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 368
D3D11_MESSAGE_ID_DEVICE_DRAW_OUTPUT_STREAM_OFFSET_UNALIGNED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 369
D3D11_MESSAGE_ID_DEVICE_DRAW_RESOURCE_FORMAT_LD_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 370
D3D11_MESSAGE_ID_DEVICE_DRAW_RESOURCE_FORMAT_SAMPLE_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 371
D3D11_MESSAGE_ID_DEVICE_DRAW_RESOURCE_FORMAT_SAMPLE_C_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 372
D3D11_MESSAGE_ID_DEVICE_DRAW_RESOURCE_MULTISAMPLE_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 373
D3D11_MESSAGE_ID_DEVICE_DRAW_SO_TARGETS_BOUND_WITHOUT_SOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 374
D3D11_MESSAGE_ID_DEVICE_DRAW_SO_STRIDE_LARGER_THAN_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 375
D3D11_MESSAGE_ID_DEVICE_DRAW_OM_RENDER_TARGET_DOES_NOT_SUPPORT_BLENDING: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 376
D3D11_MESSAGE_ID_DEVICE_DRAW_OM_DUAL_SOURCE_BLENDING_CAN_ONLY_HAVE_RENDER_TARGET_0: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 377
D3D11_MESSAGE_ID_DEVICE_REMOVAL_PROCESS_AT_FAULT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 378
D3D11_MESSAGE_ID_DEVICE_REMOVAL_PROCESS_POSSIBLY_AT_FAULT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 379
D3D11_MESSAGE_ID_DEVICE_REMOVAL_PROCESS_NOT_AT_FAULT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 380
D3D11_MESSAGE_ID_DEVICE_OPEN_SHARED_RESOURCE_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 381
D3D11_MESSAGE_ID_DEVICE_OPEN_SHARED_RESOURCE_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 382
D3D11_MESSAGE_ID_DEVICE_OPEN_SHARED_RESOURCE_BADINTERFACE_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 383
D3D11_MESSAGE_ID_DEVICE_DRAW_VIEWPORT_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 384
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_TRAILING_DIGIT_IN_SEMANTIC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 385
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_TRAILING_DIGIT_IN_SEMANTIC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 386
D3D11_MESSAGE_ID_DEVICE_RSSETVIEWPORTS_DENORMFLUSH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 387
D3D11_MESSAGE_ID_OMSETRENDERTARGETS_INVALIDVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 388
D3D11_MESSAGE_ID_DEVICE_SETTEXTFILTERSIZE_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 389
D3D11_MESSAGE_ID_DEVICE_DRAW_SAMPLER_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 390
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_TYPE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 391
D3D11_MESSAGE_ID_BLENDSTATE_GETDESC_LEGACY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 392
D3D11_MESSAGE_ID_SHADERRESOURCEVIEW_GETDESC_LEGACY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 393
D3D11_MESSAGE_ID_CREATEQUERY_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 394
D3D11_MESSAGE_ID_CREATEPREDICATE_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 395
D3D11_MESSAGE_ID_CREATECOUNTER_OUTOFRANGE_COUNTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 396
D3D11_MESSAGE_ID_CREATECOUNTER_SIMULTANEOUS_ACTIVE_COUNTERS_EXHAUSTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 397
D3D11_MESSAGE_ID_CREATECOUNTER_UNSUPPORTED_WELLKNOWN_COUNTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 398
D3D11_MESSAGE_ID_CREATECOUNTER_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 399
D3D11_MESSAGE_ID_CREATECOUNTER_NONEXCLUSIVE_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 400
D3D11_MESSAGE_ID_CREATECOUNTER_NULLDESC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 401
D3D11_MESSAGE_ID_CHECKCOUNTER_OUTOFRANGE_COUNTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 402
D3D11_MESSAGE_ID_CHECKCOUNTER_UNSUPPORTED_WELLKNOWN_COUNTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 403
D3D11_MESSAGE_ID_SETPREDICATION_INVALID_PREDICATE_STATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 404
D3D11_MESSAGE_ID_QUERY_BEGIN_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 405
D3D11_MESSAGE_ID_PREDICATE_BEGIN_DURING_PREDICATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 406
D3D11_MESSAGE_ID_QUERY_BEGIN_DUPLICATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 407
D3D11_MESSAGE_ID_QUERY_BEGIN_ABANDONING_PREVIOUS_RESULTS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 408
D3D11_MESSAGE_ID_PREDICATE_END_DURING_PREDICATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 409
D3D11_MESSAGE_ID_QUERY_END_ABANDONING_PREVIOUS_RESULTS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 410
D3D11_MESSAGE_ID_QUERY_END_WITHOUT_BEGIN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 411
D3D11_MESSAGE_ID_QUERY_GETDATA_INVALID_DATASIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 412
D3D11_MESSAGE_ID_QUERY_GETDATA_INVALID_FLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 413
D3D11_MESSAGE_ID_QUERY_GETDATA_INVALID_CALL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 414
D3D11_MESSAGE_ID_DEVICE_DRAW_PS_OUTPUT_TYPE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 415
D3D11_MESSAGE_ID_DEVICE_DRAW_RESOURCE_FORMAT_GATHER_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 416
D3D11_MESSAGE_ID_DEVICE_DRAW_INVALID_USE_OF_CENTER_MULTISAMPLE_PATTERN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 417
D3D11_MESSAGE_ID_DEVICE_IASETVERTEXBUFFERS_STRIDE_TOO_LARGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 418
D3D11_MESSAGE_ID_DEVICE_IASETVERTEXBUFFERS_INVALIDRANGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 419
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_EMPTY_LAYOUT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 420
D3D11_MESSAGE_ID_DEVICE_DRAW_RESOURCE_SAMPLE_COUNT_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 421
D3D11_MESSAGE_ID_LIVE_OBJECT_SUMMARY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 422
D3D11_MESSAGE_ID_LIVE_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 423
D3D11_MESSAGE_ID_LIVE_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 424
D3D11_MESSAGE_ID_LIVE_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 425
D3D11_MESSAGE_ID_LIVE_TEXTURE3D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 426
D3D11_MESSAGE_ID_LIVE_SHADERRESOURCEVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 427
D3D11_MESSAGE_ID_LIVE_RENDERTARGETVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 428
D3D11_MESSAGE_ID_LIVE_DEPTHSTENCILVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 429
D3D11_MESSAGE_ID_LIVE_VERTEXSHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 430
D3D11_MESSAGE_ID_LIVE_GEOMETRYSHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 431
D3D11_MESSAGE_ID_LIVE_PIXELSHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 432
D3D11_MESSAGE_ID_LIVE_INPUTLAYOUT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 433
D3D11_MESSAGE_ID_LIVE_SAMPLER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 434
D3D11_MESSAGE_ID_LIVE_BLENDSTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 435
D3D11_MESSAGE_ID_LIVE_DEPTHSTENCILSTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 436
D3D11_MESSAGE_ID_LIVE_RASTERIZERSTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 437
D3D11_MESSAGE_ID_LIVE_QUERY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 438
D3D11_MESSAGE_ID_LIVE_PREDICATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 439
D3D11_MESSAGE_ID_LIVE_COUNTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 440
D3D11_MESSAGE_ID_LIVE_DEVICE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 441
D3D11_MESSAGE_ID_LIVE_SWAPCHAIN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 442
D3D11_MESSAGE_ID_D3D10_MESSAGES_END: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 443
D3D11_MESSAGE_ID_D3D10L9_MESSAGES_START: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048576
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILSTATE_STENCIL_NO_TWO_SIDED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048577
D3D11_MESSAGE_ID_CREATERASTERIZERSTATE_DepthBiasClamp_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048578
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_NO_COMPARISON_SUPPORT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048579
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_EXCESSIVE_ANISOTROPY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048580
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_BORDER_OUT_OF_RANGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048581
D3D11_MESSAGE_ID_VSSETSAMPLERS_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048582
D3D11_MESSAGE_ID_VSSETSAMPLERS_TOO_MANY_SAMPLERS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048583
D3D11_MESSAGE_ID_PSSETSAMPLERS_TOO_MANY_SAMPLERS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048584
D3D11_MESSAGE_ID_CREATERESOURCE_NO_ARRAYS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048585
D3D11_MESSAGE_ID_CREATERESOURCE_NO_VB_AND_IB_BIND: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048586
D3D11_MESSAGE_ID_CREATERESOURCE_NO_TEXTURE_1D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048587
D3D11_MESSAGE_ID_CREATERESOURCE_DIMENSION_OUT_OF_RANGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048588
D3D11_MESSAGE_ID_CREATERESOURCE_NOT_BINDABLE_AS_SHADER_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048589
D3D11_MESSAGE_ID_OMSETRENDERTARGETS_TOO_MANY_RENDER_TARGETS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048590
D3D11_MESSAGE_ID_OMSETRENDERTARGETS_NO_DIFFERING_BIT_DEPTHS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048591
D3D11_MESSAGE_ID_IASETVERTEXBUFFERS_BAD_BUFFER_INDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048592
D3D11_MESSAGE_ID_DEVICE_RSSETVIEWPORTS_TOO_MANY_VIEWPORTS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048593
D3D11_MESSAGE_ID_DEVICE_IASETPRIMITIVETOPOLOGY_ADJACENCY_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048594
D3D11_MESSAGE_ID_DEVICE_RSSETSCISSORRECTS_TOO_MANY_SCISSORS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048595
D3D11_MESSAGE_ID_COPYRESOURCE_ONLY_TEXTURE_2D_WITHIN_GPU_MEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048596
D3D11_MESSAGE_ID_COPYRESOURCE_NO_TEXTURE_3D_READBACK: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048597
D3D11_MESSAGE_ID_COPYRESOURCE_NO_TEXTURE_ONLY_READBACK: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048598
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_UNSUPPORTED_FORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048599
D3D11_MESSAGE_ID_CREATEBLENDSTATE_NO_ALPHA_TO_COVERAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048600
D3D11_MESSAGE_ID_CREATERASTERIZERSTATE_DepthClipEnable_MUST_BE_TRUE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048601
D3D11_MESSAGE_ID_DRAWINDEXED_STARTINDEXLOCATION_MUST_BE_POSITIVE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048602
D3D11_MESSAGE_ID_CREATESHADERRESOURCEVIEW_MUST_USE_LOWEST_LOD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048603
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_MINLOD_MUST_NOT_BE_FRACTIONAL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048604
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_MAXLOD_MUST_BE_FLT_MAX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048605
D3D11_MESSAGE_ID_CREATESHADERRESOURCEVIEW_FIRSTARRAYSLICE_MUST_BE_ZERO: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048606
D3D11_MESSAGE_ID_CREATESHADERRESOURCEVIEW_CUBES_MUST_HAVE_6_SIDES: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048607
D3D11_MESSAGE_ID_CREATERESOURCE_NOT_BINDABLE_AS_RENDER_TARGET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048608
D3D11_MESSAGE_ID_CREATERESOURCE_NO_DWORD_INDEX_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048609
D3D11_MESSAGE_ID_CREATERESOURCE_MSAA_PRECLUDES_SHADER_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048610
D3D11_MESSAGE_ID_CREATERESOURCE_PRESENTATION_PRECLUDES_SHADER_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048611
D3D11_MESSAGE_ID_CREATEBLENDSTATE_NO_INDEPENDENT_BLEND_ENABLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048612
D3D11_MESSAGE_ID_CREATEBLENDSTATE_NO_INDEPENDENT_WRITE_MASKS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048613
D3D11_MESSAGE_ID_CREATERESOURCE_NO_STREAM_OUT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048614
D3D11_MESSAGE_ID_CREATERESOURCE_ONLY_VB_IB_FOR_BUFFERS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048615
D3D11_MESSAGE_ID_CREATERESOURCE_NO_AUTOGEN_FOR_VOLUMES: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048616
D3D11_MESSAGE_ID_CREATERESOURCE_DXGI_FORMAT_R8G8B8A8_CANNOT_BE_SHARED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048617
D3D11_MESSAGE_ID_VSSHADERRESOURCES_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048618
D3D11_MESSAGE_ID_GEOMETRY_SHADER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048619
D3D11_MESSAGE_ID_STREAM_OUT_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048620
D3D11_MESSAGE_ID_TEXT_FILTER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048621
D3D11_MESSAGE_ID_CREATEBLENDSTATE_NO_SEPARATE_ALPHA_BLEND: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048622
D3D11_MESSAGE_ID_CREATEBLENDSTATE_NO_MRT_BLEND: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048623
D3D11_MESSAGE_ID_CREATEBLENDSTATE_OPERATION_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048624
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_NO_MIRRORONCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048625
D3D11_MESSAGE_ID_DRAWINSTANCED_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048626
D3D11_MESSAGE_ID_DRAWINDEXEDINSTANCED_NOT_SUPPORTED_BELOW_9_3: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048627
D3D11_MESSAGE_ID_DRAWINDEXED_POINTLIST_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048628
D3D11_MESSAGE_ID_SETBLENDSTATE_SAMPLE_MASK_CANNOT_BE_ZERO: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048629
D3D11_MESSAGE_ID_CREATERESOURCE_DIMENSION_EXCEEDS_FEATURE_LEVEL_DEFINITION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048630
D3D11_MESSAGE_ID_CREATERESOURCE_ONLY_SINGLE_MIP_LEVEL_DEPTH_STENCIL_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048631
D3D11_MESSAGE_ID_DEVICE_RSSETSCISSORRECTS_NEGATIVESCISSOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048632
D3D11_MESSAGE_ID_SLOT_ZERO_MUST_BE_D3D10_INPUT_PER_VERTEX_DATA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048633
D3D11_MESSAGE_ID_CREATERESOURCE_NON_POW_2_MIPMAP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048634
D3D11_MESSAGE_ID_CREATESAMPLERSTATE_BORDER_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048635
D3D11_MESSAGE_ID_OMSETRENDERTARGETS_NO_SRGB_MRT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048636
D3D11_MESSAGE_ID_COPYRESOURCE_NO_3D_MISMATCHED_UPDATES: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048637
D3D11_MESSAGE_ID_D3D10L9_MESSAGES_END: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 1048638
D3D11_MESSAGE_ID_D3D11_MESSAGES_START: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097152
D3D11_MESSAGE_ID_CREATEDEPTHSTENCILVIEW_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097153
D3D11_MESSAGE_ID_CREATEVERTEXSHADER_INVALIDCLASSLINKAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097154
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADER_INVALIDCLASSLINKAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097155
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDNUMSTREAMS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097156
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDSTREAMTORASTERIZER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097157
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_UNEXPECTEDSTREAMS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097158
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDCLASSLINKAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097159
D3D11_MESSAGE_ID_CREATEPIXELSHADER_INVALIDCLASSLINKAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097160
D3D11_MESSAGE_ID_CREATEDEFERREDCONTEXT_INVALID_COMMANDLISTFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097161
D3D11_MESSAGE_ID_CREATEDEFERREDCONTEXT_SINGLETHREADED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097162
D3D11_MESSAGE_ID_CREATEDEFERREDCONTEXT_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097163
D3D11_MESSAGE_ID_CREATEDEFERREDCONTEXT_INVALID_CALL_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097164
D3D11_MESSAGE_ID_CREATEDEFERREDCONTEXT_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097165
D3D11_MESSAGE_ID_FINISHDISPLAYLIST_ONIMMEDIATECONTEXT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097166
D3D11_MESSAGE_ID_FINISHDISPLAYLIST_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097167
D3D11_MESSAGE_ID_FINISHDISPLAYLIST_INVALID_CALL_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097168
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097169
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_UNEXPECTEDENTRIES: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097170
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_UNEXPECTEDSTRIDES: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097171
D3D11_MESSAGE_ID_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_INVALIDNUMSTRIDES: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097172
D3D11_MESSAGE_ID_DEVICE_HSSETSHADERRESOURCES_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097173
D3D11_MESSAGE_ID_DEVICE_HSSETCONSTANTBUFFERS_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097174
D3D11_MESSAGE_ID_HSSETSHADERRESOURCES_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097175
D3D11_MESSAGE_ID_HSSETCONSTANTBUFFERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097176
D3D11_MESSAGE_ID_CREATEHULLSHADER_INVALIDCALL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097177
D3D11_MESSAGE_ID_CREATEHULLSHADER_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097178
D3D11_MESSAGE_ID_CREATEHULLSHADER_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097179
D3D11_MESSAGE_ID_CREATEHULLSHADER_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097180
D3D11_MESSAGE_ID_CREATEHULLSHADER_INVALIDCLASSLINKAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097181
D3D11_MESSAGE_ID_DEVICE_HSSETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097182
D3D11_MESSAGE_ID_HSSETCONSTANTBUFFERS_INVALIDBUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097183
D3D11_MESSAGE_ID_DEVICE_HSSETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097184
D3D11_MESSAGE_ID_DEVICE_HSSETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097185
D3D11_MESSAGE_ID_DEVICE_HSGETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097186
D3D11_MESSAGE_ID_DEVICE_HSGETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097187
D3D11_MESSAGE_ID_DEVICE_HSGETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097188
D3D11_MESSAGE_ID_DEVICE_DSSETSHADERRESOURCES_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097189
D3D11_MESSAGE_ID_DEVICE_DSSETCONSTANTBUFFERS_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097190
D3D11_MESSAGE_ID_DSSETSHADERRESOURCES_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097191
D3D11_MESSAGE_ID_DSSETCONSTANTBUFFERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097192
D3D11_MESSAGE_ID_CREATEDOMAINSHADER_INVALIDCALL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097193
D3D11_MESSAGE_ID_CREATEDOMAINSHADER_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097194
D3D11_MESSAGE_ID_CREATEDOMAINSHADER_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097195
D3D11_MESSAGE_ID_CREATEDOMAINSHADER_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097196
D3D11_MESSAGE_ID_CREATEDOMAINSHADER_INVALIDCLASSLINKAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097197
D3D11_MESSAGE_ID_DEVICE_DSSETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097198
D3D11_MESSAGE_ID_DSSETCONSTANTBUFFERS_INVALIDBUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097199
D3D11_MESSAGE_ID_DEVICE_DSSETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097200
D3D11_MESSAGE_ID_DEVICE_DSSETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097201
D3D11_MESSAGE_ID_DEVICE_DSGETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097202
D3D11_MESSAGE_ID_DEVICE_DSGETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097203
D3D11_MESSAGE_ID_DEVICE_DSGETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097204
D3D11_MESSAGE_ID_DEVICE_DRAW_HS_XOR_DS_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097205
D3D11_MESSAGE_ID_DEFERRED_CONTEXT_REMOVAL_PROCESS_AT_FAULT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097206
D3D11_MESSAGE_ID_DEVICE_DRAWINDIRECT_INVALID_ARG_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097207
D3D11_MESSAGE_ID_DEVICE_DRAWINDIRECT_OFFSET_UNALIGNED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097208
D3D11_MESSAGE_ID_DEVICE_DRAWINDIRECT_OFFSET_OVERFLOW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097209
D3D11_MESSAGE_ID_RESOURCE_MAP_INVALIDMAPTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097210
D3D11_MESSAGE_ID_RESOURCE_MAP_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097211
D3D11_MESSAGE_ID_RESOURCE_MAP_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097212
D3D11_MESSAGE_ID_RESOURCE_MAP_ALREADYMAPPED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097213
D3D11_MESSAGE_ID_RESOURCE_MAP_DEVICEREMOVED_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097214
D3D11_MESSAGE_ID_RESOURCE_MAP_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097215
D3D11_MESSAGE_ID_RESOURCE_MAP_WITHOUT_INITIAL_DISCARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097216
D3D11_MESSAGE_ID_RESOURCE_UNMAP_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097217
D3D11_MESSAGE_ID_RESOURCE_UNMAP_NOTMAPPED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097218
D3D11_MESSAGE_ID_DEVICE_DRAW_RASTERIZING_CONTROL_POINTS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097219
D3D11_MESSAGE_ID_DEVICE_IASETPRIMITIVETOPOLOGY_TOPOLOGY_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097220
D3D11_MESSAGE_ID_DEVICE_DRAW_HS_DS_SIGNATURE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097221
D3D11_MESSAGE_ID_DEVICE_DRAW_HULL_SHADER_INPUT_TOPOLOGY_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097222
D3D11_MESSAGE_ID_DEVICE_DRAW_HS_DS_CONTROL_POINT_COUNT_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097223
D3D11_MESSAGE_ID_DEVICE_DRAW_HS_DS_TESSELLATOR_DOMAIN_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097224
D3D11_MESSAGE_ID_CREATE_CONTEXT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097225
D3D11_MESSAGE_ID_LIVE_CONTEXT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097226
D3D11_MESSAGE_ID_DESTROY_CONTEXT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097227
D3D11_MESSAGE_ID_CREATE_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097228
D3D11_MESSAGE_ID_LIVE_BUFFER_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097229
D3D11_MESSAGE_ID_DESTROY_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097230
D3D11_MESSAGE_ID_CREATE_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097231
D3D11_MESSAGE_ID_LIVE_TEXTURE1D_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097232
D3D11_MESSAGE_ID_DESTROY_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097233
D3D11_MESSAGE_ID_CREATE_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097234
D3D11_MESSAGE_ID_LIVE_TEXTURE2D_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097235
D3D11_MESSAGE_ID_DESTROY_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097236
D3D11_MESSAGE_ID_CREATE_TEXTURE3D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097237
D3D11_MESSAGE_ID_LIVE_TEXTURE3D_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097238
D3D11_MESSAGE_ID_DESTROY_TEXTURE3D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097239
D3D11_MESSAGE_ID_CREATE_SHADERRESOURCEVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097240
D3D11_MESSAGE_ID_LIVE_SHADERRESOURCEVIEW_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097241
D3D11_MESSAGE_ID_DESTROY_SHADERRESOURCEVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097242
D3D11_MESSAGE_ID_CREATE_RENDERTARGETVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097243
D3D11_MESSAGE_ID_LIVE_RENDERTARGETVIEW_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097244
D3D11_MESSAGE_ID_DESTROY_RENDERTARGETVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097245
D3D11_MESSAGE_ID_CREATE_DEPTHSTENCILVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097246
D3D11_MESSAGE_ID_LIVE_DEPTHSTENCILVIEW_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097247
D3D11_MESSAGE_ID_DESTROY_DEPTHSTENCILVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097248
D3D11_MESSAGE_ID_CREATE_VERTEXSHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097249
D3D11_MESSAGE_ID_LIVE_VERTEXSHADER_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097250
D3D11_MESSAGE_ID_DESTROY_VERTEXSHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097251
D3D11_MESSAGE_ID_CREATE_HULLSHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097252
D3D11_MESSAGE_ID_LIVE_HULLSHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097253
D3D11_MESSAGE_ID_DESTROY_HULLSHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097254
D3D11_MESSAGE_ID_CREATE_DOMAINSHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097255
D3D11_MESSAGE_ID_LIVE_DOMAINSHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097256
D3D11_MESSAGE_ID_DESTROY_DOMAINSHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097257
D3D11_MESSAGE_ID_CREATE_GEOMETRYSHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097258
D3D11_MESSAGE_ID_LIVE_GEOMETRYSHADER_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097259
D3D11_MESSAGE_ID_DESTROY_GEOMETRYSHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097260
D3D11_MESSAGE_ID_CREATE_PIXELSHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097261
D3D11_MESSAGE_ID_LIVE_PIXELSHADER_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097262
D3D11_MESSAGE_ID_DESTROY_PIXELSHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097263
D3D11_MESSAGE_ID_CREATE_INPUTLAYOUT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097264
D3D11_MESSAGE_ID_LIVE_INPUTLAYOUT_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097265
D3D11_MESSAGE_ID_DESTROY_INPUTLAYOUT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097266
D3D11_MESSAGE_ID_CREATE_SAMPLER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097267
D3D11_MESSAGE_ID_LIVE_SAMPLER_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097268
D3D11_MESSAGE_ID_DESTROY_SAMPLER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097269
D3D11_MESSAGE_ID_CREATE_BLENDSTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097270
D3D11_MESSAGE_ID_LIVE_BLENDSTATE_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097271
D3D11_MESSAGE_ID_DESTROY_BLENDSTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097272
D3D11_MESSAGE_ID_CREATE_DEPTHSTENCILSTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097273
D3D11_MESSAGE_ID_LIVE_DEPTHSTENCILSTATE_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097274
D3D11_MESSAGE_ID_DESTROY_DEPTHSTENCILSTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097275
D3D11_MESSAGE_ID_CREATE_RASTERIZERSTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097276
D3D11_MESSAGE_ID_LIVE_RASTERIZERSTATE_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097277
D3D11_MESSAGE_ID_DESTROY_RASTERIZERSTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097278
D3D11_MESSAGE_ID_CREATE_QUERY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097279
D3D11_MESSAGE_ID_LIVE_QUERY_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097280
D3D11_MESSAGE_ID_DESTROY_QUERY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097281
D3D11_MESSAGE_ID_CREATE_PREDICATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097282
D3D11_MESSAGE_ID_LIVE_PREDICATE_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097283
D3D11_MESSAGE_ID_DESTROY_PREDICATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097284
D3D11_MESSAGE_ID_CREATE_COUNTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097285
D3D11_MESSAGE_ID_DESTROY_COUNTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097286
D3D11_MESSAGE_ID_CREATE_COMMANDLIST: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097287
D3D11_MESSAGE_ID_LIVE_COMMANDLIST: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097288
D3D11_MESSAGE_ID_DESTROY_COMMANDLIST: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097289
D3D11_MESSAGE_ID_CREATE_CLASSINSTANCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097290
D3D11_MESSAGE_ID_LIVE_CLASSINSTANCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097291
D3D11_MESSAGE_ID_DESTROY_CLASSINSTANCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097292
D3D11_MESSAGE_ID_CREATE_CLASSLINKAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097293
D3D11_MESSAGE_ID_LIVE_CLASSLINKAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097294
D3D11_MESSAGE_ID_DESTROY_CLASSLINKAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097295
D3D11_MESSAGE_ID_LIVE_DEVICE_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097296
D3D11_MESSAGE_ID_LIVE_OBJECT_SUMMARY_WIN7: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097297
D3D11_MESSAGE_ID_CREATE_COMPUTESHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097298
D3D11_MESSAGE_ID_LIVE_COMPUTESHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097299
D3D11_MESSAGE_ID_DESTROY_COMPUTESHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097300
D3D11_MESSAGE_ID_CREATE_UNORDEREDACCESSVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097301
D3D11_MESSAGE_ID_LIVE_UNORDEREDACCESSVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097302
D3D11_MESSAGE_ID_DESTROY_UNORDEREDACCESSVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097303
D3D11_MESSAGE_ID_DEVICE_SETSHADER_INTERFACES_FEATURELEVEL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097304
D3D11_MESSAGE_ID_DEVICE_SETSHADER_INTERFACE_COUNT_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097305
D3D11_MESSAGE_ID_DEVICE_SETSHADER_INVALID_INSTANCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097306
D3D11_MESSAGE_ID_DEVICE_SETSHADER_INVALID_INSTANCE_INDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097307
D3D11_MESSAGE_ID_DEVICE_SETSHADER_INVALID_INSTANCE_TYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097308
D3D11_MESSAGE_ID_DEVICE_SETSHADER_INVALID_INSTANCE_DATA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097309
D3D11_MESSAGE_ID_DEVICE_SETSHADER_UNBOUND_INSTANCE_DATA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097310
D3D11_MESSAGE_ID_DEVICE_SETSHADER_INSTANCE_DATA_BINDINGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097311
D3D11_MESSAGE_ID_DEVICE_CREATESHADER_CLASSLINKAGE_FULL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097312
D3D11_MESSAGE_ID_DEVICE_CHECKFEATURESUPPORT_UNRECOGNIZED_FEATURE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097313
D3D11_MESSAGE_ID_DEVICE_CHECKFEATURESUPPORT_MISMATCHED_DATA_SIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097314
D3D11_MESSAGE_ID_DEVICE_CHECKFEATURESUPPORT_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097315
D3D11_MESSAGE_ID_DEVICE_CSSETSHADERRESOURCES_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097316
D3D11_MESSAGE_ID_DEVICE_CSSETCONSTANTBUFFERS_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097317
D3D11_MESSAGE_ID_CSSETSHADERRESOURCES_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097318
D3D11_MESSAGE_ID_CSSETCONSTANTBUFFERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097319
D3D11_MESSAGE_ID_CREATECOMPUTESHADER_INVALIDCALL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097320
D3D11_MESSAGE_ID_CREATECOMPUTESHADER_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097321
D3D11_MESSAGE_ID_CREATECOMPUTESHADER_INVALIDSHADERBYTECODE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097322
D3D11_MESSAGE_ID_CREATECOMPUTESHADER_INVALIDSHADERTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097323
D3D11_MESSAGE_ID_CREATECOMPUTESHADER_INVALIDCLASSLINKAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097324
D3D11_MESSAGE_ID_DEVICE_CSSETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097325
D3D11_MESSAGE_ID_CSSETCONSTANTBUFFERS_INVALIDBUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097326
D3D11_MESSAGE_ID_DEVICE_CSSETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097327
D3D11_MESSAGE_ID_DEVICE_CSSETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097328
D3D11_MESSAGE_ID_DEVICE_CSGETSHADERRESOURCES_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097329
D3D11_MESSAGE_ID_DEVICE_CSGETCONSTANTBUFFERS_BUFFERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097330
D3D11_MESSAGE_ID_DEVICE_CSGETSAMPLERS_SAMPLERS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097331
D3D11_MESSAGE_ID_DEVICE_CREATEVERTEXSHADER_DOUBLEFLOATOPSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097332
D3D11_MESSAGE_ID_DEVICE_CREATEHULLSHADER_DOUBLEFLOATOPSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097333
D3D11_MESSAGE_ID_DEVICE_CREATEDOMAINSHADER_DOUBLEFLOATOPSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097334
D3D11_MESSAGE_ID_DEVICE_CREATEGEOMETRYSHADER_DOUBLEFLOATOPSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097335
D3D11_MESSAGE_ID_DEVICE_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_DOUBLEFLOATOPSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097336
D3D11_MESSAGE_ID_DEVICE_CREATEPIXELSHADER_DOUBLEFLOATOPSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097337
D3D11_MESSAGE_ID_DEVICE_CREATECOMPUTESHADER_DOUBLEFLOATOPSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097338
D3D11_MESSAGE_ID_CREATEBUFFER_INVALIDSTRUCTURESTRIDE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097339
D3D11_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097340
D3D11_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097341
D3D11_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_INVALIDDESC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097342
D3D11_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097343
D3D11_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_INVALIDDIMENSIONS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097344
D3D11_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_UNRECOGNIZEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097345
D3D11_MESSAGE_ID_DEVICE_OMSETRENDERTARGETSANDUNORDEREDACCESSVIEWS_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097346
D3D11_MESSAGE_ID_DEVICE_OMSETRENDERTARGETSANDUNORDEREDACCESSVIEWS_OVERLAPPING_OLD_SLOTS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097347
D3D11_MESSAGE_ID_DEVICE_OMSETRENDERTARGETSANDUNORDEREDACCESSVIEWS_NO_OP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097348
D3D11_MESSAGE_ID_CSSETUNORDEREDACCESSVIEWS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097349
D3D11_MESSAGE_ID_PSSETUNORDEREDACCESSVIEWS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097350
D3D11_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097351
D3D11_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097352
D3D11_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_TOOMANYOBJECTS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097353
D3D11_MESSAGE_ID_DEVICE_CSSETUNORDEREDACCESSVIEWS_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097354
D3D11_MESSAGE_ID_CLEARUNORDEREDACCESSVIEW_DENORMFLUSH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097355
D3D11_MESSAGE_ID_DEVICE_CSSETUNORDEREDACCESSS_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097356
D3D11_MESSAGE_ID_DEVICE_CSGETUNORDEREDACCESSS_VIEWS_EMPTY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097357
D3D11_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097358
D3D11_MESSAGE_ID_CREATESHADERRESESOURCEVIEW_TOOMANYOBJECTS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097359
D3D11_MESSAGE_ID_DEVICE_DISPATCHINDIRECT_INVALID_ARG_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097360
D3D11_MESSAGE_ID_DEVICE_DISPATCHINDIRECT_OFFSET_UNALIGNED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097361
D3D11_MESSAGE_ID_DEVICE_DISPATCHINDIRECT_OFFSET_OVERFLOW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097362
D3D11_MESSAGE_ID_DEVICE_SETRESOURCEMINLOD_INVALIDCONTEXT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097363
D3D11_MESSAGE_ID_DEVICE_SETRESOURCEMINLOD_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097364
D3D11_MESSAGE_ID_DEVICE_SETRESOURCEMINLOD_INVALIDMINLOD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097365
D3D11_MESSAGE_ID_DEVICE_GETRESOURCEMINLOD_INVALIDCONTEXT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097366
D3D11_MESSAGE_ID_DEVICE_GETRESOURCEMINLOD_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097367
D3D11_MESSAGE_ID_OMSETDEPTHSTENCIL_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097368
D3D11_MESSAGE_ID_CLEARDEPTHSTENCILVIEW_DEPTH_READONLY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097369
D3D11_MESSAGE_ID_CLEARDEPTHSTENCILVIEW_STENCIL_READONLY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097370
D3D11_MESSAGE_ID_CHECKFEATURESUPPORT_FORMAT_DEPRECATED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097371
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_RETURN_TYPE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097372
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097373
D3D11_MESSAGE_ID_DEVICE_DRAW_UNORDEREDACCESSVIEW_RENDERTARGETVIEW_OVERLAP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097374
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_DIMENSION_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097375
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_APPEND_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097376
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_ATOMICS_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097377
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_STRUCTURE_STRIDE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097378
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_BUFFER_TYPE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097379
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_RAW_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097380
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_FORMAT_LD_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097381
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_FORMAT_STORE_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097382
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_ATOMIC_ADD_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097383
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_ATOMIC_BITWISE_OPS_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097384
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_ATOMIC_CMPSTORE_CMPEXCHANGE_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097385
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_ATOMIC_EXCHANGE_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097386
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_ATOMIC_SIGNED_MINMAX_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097387
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_ATOMIC_UNSIGNED_MINMAX_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097388
D3D11_MESSAGE_ID_DEVICE_DISPATCH_BOUND_RESOURCE_MAPPED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097389
D3D11_MESSAGE_ID_DEVICE_DISPATCH_THREADGROUPCOUNT_OVERFLOW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097390
D3D11_MESSAGE_ID_DEVICE_DISPATCH_THREADGROUPCOUNT_ZERO: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097391
D3D11_MESSAGE_ID_DEVICE_SHADERRESOURCEVIEW_STRUCTURE_STRIDE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097392
D3D11_MESSAGE_ID_DEVICE_SHADERRESOURCEVIEW_BUFFER_TYPE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097393
D3D11_MESSAGE_ID_DEVICE_SHADERRESOURCEVIEW_RAW_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097394
D3D11_MESSAGE_ID_DEVICE_DISPATCH_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097395
D3D11_MESSAGE_ID_DEVICE_DISPATCHINDIRECT_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097396
D3D11_MESSAGE_ID_COPYSTRUCTURECOUNT_INVALIDOFFSET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097397
D3D11_MESSAGE_ID_COPYSTRUCTURECOUNT_LARGEOFFSET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097398
D3D11_MESSAGE_ID_COPYSTRUCTURECOUNT_INVALIDDESTINATIONSTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097399
D3D11_MESSAGE_ID_COPYSTRUCTURECOUNT_INVALIDSOURCESTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097400
D3D11_MESSAGE_ID_CHECKFORMATSUPPORT_FORMAT_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097401
D3D11_MESSAGE_ID_DEVICE_CSSETUNORDEREDACCESSVIEWS_INVALIDVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097402
D3D11_MESSAGE_ID_DEVICE_CSSETUNORDEREDACCESSVIEWS_INVALIDOFFSET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097403
D3D11_MESSAGE_ID_DEVICE_CSSETUNORDEREDACCESSVIEWS_TOOMANYVIEWS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097404
D3D11_MESSAGE_ID_CLEARUNORDEREDACCESSVIEWFLOAT_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097405
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_COUNTER_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097406
D3D11_MESSAGE_ID_REF_WARNING: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097407
D3D11_MESSAGE_ID_DEVICE_DRAW_PIXEL_SHADER_WITHOUT_RTV_OR_DSV: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097408
D3D11_MESSAGE_ID_SHADER_ABORT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097409
D3D11_MESSAGE_ID_SHADER_MESSAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097410
D3D11_MESSAGE_ID_SHADER_ERROR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097411
D3D11_MESSAGE_ID_OFFERRESOURCES_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097412
D3D11_MESSAGE_ID_HSSETSAMPLERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097413
D3D11_MESSAGE_ID_DSSETSAMPLERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097414
D3D11_MESSAGE_ID_CSSETSAMPLERS_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097415
D3D11_MESSAGE_ID_HSSETSHADER_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097416
D3D11_MESSAGE_ID_DSSETSHADER_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097417
D3D11_MESSAGE_ID_CSSETSHADER_UNBINDDELETINGOBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097418
D3D11_MESSAGE_ID_ENQUEUESETEVENT_INVALIDARG_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097419
D3D11_MESSAGE_ID_ENQUEUESETEVENT_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097420
D3D11_MESSAGE_ID_ENQUEUESETEVENT_ACCESSDENIED_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097421
D3D11_MESSAGE_ID_DEVICE_OMSETRENDERTARGETSANDUNORDEREDACCESSVIEWS_NUMUAVS_INVALIDRANGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097422
D3D11_MESSAGE_ID_USE_OF_ZERO_REFCOUNT_OBJECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097423
D3D11_MESSAGE_ID_D3D11_MESSAGES_END: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 2097424
D3D11_MESSAGE_ID_D3D11_1_MESSAGES_START: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145728
D3D11_MESSAGE_ID_CREATE_VIDEODECODER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145729
D3D11_MESSAGE_ID_CREATE_VIDEOPROCESSORENUM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145730
D3D11_MESSAGE_ID_CREATE_VIDEOPROCESSOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145731
D3D11_MESSAGE_ID_CREATE_DECODEROUTPUTVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145732
D3D11_MESSAGE_ID_CREATE_PROCESSORINPUTVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145733
D3D11_MESSAGE_ID_CREATE_PROCESSOROUTPUTVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145734
D3D11_MESSAGE_ID_CREATE_DEVICECONTEXTSTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145735
D3D11_MESSAGE_ID_LIVE_VIDEODECODER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145736
D3D11_MESSAGE_ID_LIVE_VIDEOPROCESSORENUM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145737
D3D11_MESSAGE_ID_LIVE_VIDEOPROCESSOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145738
D3D11_MESSAGE_ID_LIVE_DECODEROUTPUTVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145739
D3D11_MESSAGE_ID_LIVE_PROCESSORINPUTVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145740
D3D11_MESSAGE_ID_LIVE_PROCESSOROUTPUTVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145741
D3D11_MESSAGE_ID_LIVE_DEVICECONTEXTSTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145742
D3D11_MESSAGE_ID_DESTROY_VIDEODECODER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145743
D3D11_MESSAGE_ID_DESTROY_VIDEOPROCESSORENUM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145744
D3D11_MESSAGE_ID_DESTROY_VIDEOPROCESSOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145745
D3D11_MESSAGE_ID_DESTROY_DECODEROUTPUTVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145746
D3D11_MESSAGE_ID_DESTROY_PROCESSORINPUTVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145747
D3D11_MESSAGE_ID_DESTROY_PROCESSOROUTPUTVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145748
D3D11_MESSAGE_ID_DESTROY_DEVICECONTEXTSTATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145749
D3D11_MESSAGE_ID_CREATEDEVICECONTEXTSTATE_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145750
D3D11_MESSAGE_ID_CREATEDEVICECONTEXTSTATE_INVALIDFEATURELEVEL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145751
D3D11_MESSAGE_ID_CREATEDEVICECONTEXTSTATE_FEATURELEVELS_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145752
D3D11_MESSAGE_ID_CREATEDEVICECONTEXTSTATE_INVALIDREFIID: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145753
D3D11_MESSAGE_ID_DEVICE_DISCARDVIEW_INVALIDVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145754
D3D11_MESSAGE_ID_COPYSUBRESOURCEREGION1_INVALIDCOPYFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145755
D3D11_MESSAGE_ID_UPDATESUBRESOURCE1_INVALIDCOPYFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145756
D3D11_MESSAGE_ID_CREATERASTERIZERSTATE_INVALIDFORCEDSAMPLECOUNT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145757
D3D11_MESSAGE_ID_CREATEVIDEODECODER_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145758
D3D11_MESSAGE_ID_CREATEVIDEODECODER_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145759
D3D11_MESSAGE_ID_CREATEVIDEODECODER_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145760
D3D11_MESSAGE_ID_CREATEVIDEODECODER_ZEROWIDTHHEIGHT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145761
D3D11_MESSAGE_ID_CREATEVIDEODECODER_DRIVER_INVALIDBUFFERSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145762
D3D11_MESSAGE_ID_CREATEVIDEODECODER_DRIVER_INVALIDBUFFERUSAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145763
D3D11_MESSAGE_ID_GETVIDEODECODERPROFILECOUNT_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145764
D3D11_MESSAGE_ID_GETVIDEODECODERPROFILE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145765
D3D11_MESSAGE_ID_GETVIDEODECODERPROFILE_INVALIDINDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145766
D3D11_MESSAGE_ID_GETVIDEODECODERPROFILE_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145767
D3D11_MESSAGE_ID_CHECKVIDEODECODERFORMAT_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145768
D3D11_MESSAGE_ID_CHECKVIDEODECODERFORMAT_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145769
D3D11_MESSAGE_ID_GETVIDEODECODERCONFIGCOUNT_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145770
D3D11_MESSAGE_ID_GETVIDEODECODERCONFIGCOUNT_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145771
D3D11_MESSAGE_ID_GETVIDEODECODERCONFIG_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145772
D3D11_MESSAGE_ID_GETVIDEODECODERCONFIG_INVALIDINDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145773
D3D11_MESSAGE_ID_GETVIDEODECODERCONFIG_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145774
D3D11_MESSAGE_ID_GETDECODERCREATIONPARAMS_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145775
D3D11_MESSAGE_ID_GETDECODERDRIVERHANDLE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145776
D3D11_MESSAGE_ID_GETDECODERBUFFER_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145777
D3D11_MESSAGE_ID_GETDECODERBUFFER_INVALIDBUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145778
D3D11_MESSAGE_ID_GETDECODERBUFFER_INVALIDTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145779
D3D11_MESSAGE_ID_GETDECODERBUFFER_LOCKED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145780
D3D11_MESSAGE_ID_RELEASEDECODERBUFFER_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145781
D3D11_MESSAGE_ID_RELEASEDECODERBUFFER_INVALIDTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145782
D3D11_MESSAGE_ID_RELEASEDECODERBUFFER_NOTLOCKED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145783
D3D11_MESSAGE_ID_DECODERBEGINFRAME_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145784
D3D11_MESSAGE_ID_DECODERBEGINFRAME_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145785
D3D11_MESSAGE_ID_DECODERENDFRAME_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145786
D3D11_MESSAGE_ID_SUBMITDECODERBUFFERS_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145787
D3D11_MESSAGE_ID_SUBMITDECODERBUFFERS_INVALIDTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145788
D3D11_MESSAGE_ID_DECODEREXTENSION_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145789
D3D11_MESSAGE_ID_DECODEREXTENSION_INVALIDRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145790
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORENUMERATOR_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145791
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORENUMERATOR_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145792
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORENUMERATOR_INVALIDFRAMEFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145793
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORENUMERATOR_INVALIDUSAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145794
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORENUMERATOR_INVALIDINPUTFRAMERATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145795
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORENUMERATOR_INVALIDOUTPUTFRAMERATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145796
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORENUMERATOR_INVALIDWIDTHHEIGHT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145797
D3D11_MESSAGE_ID_GETVIDEOPROCESSORCONTENTDESC_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145798
D3D11_MESSAGE_ID_CHECKVIDEOPROCESSORFORMAT_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145799
D3D11_MESSAGE_ID_GETVIDEOPROCESSORCAPS_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145800
D3D11_MESSAGE_ID_GETVIDEOPROCESSORRATECONVERSIONCAPS_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145801
D3D11_MESSAGE_ID_GETVIDEOPROCESSORRATECONVERSIONCAPS_INVALIDINDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145802
D3D11_MESSAGE_ID_GETVIDEOPROCESSORCUSTOMRATE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145803
D3D11_MESSAGE_ID_GETVIDEOPROCESSORCUSTOMRATE_INVALIDINDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145804
D3D11_MESSAGE_ID_GETVIDEOPROCESSORFILTERRANGE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145805
D3D11_MESSAGE_ID_GETVIDEOPROCESSORFILTERRANGE_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145806
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSOR_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145807
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSOR_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145808
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTTARGETRECT_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145809
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTBACKGROUNDCOLOR_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145810
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTBACKGROUNDCOLOR_INVALIDALPHA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145811
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTCOLORSPACE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145812
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTALPHAFILLMODE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145813
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTALPHAFILLMODE_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145814
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTALPHAFILLMODE_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145815
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTALPHAFILLMODE_INVALIDFILLMODE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145816
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTCONSTRICTION_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145817
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTSTEREOMODE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145818
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTSTEREOMODE_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145819
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTEXTENSION_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145820
D3D11_MESSAGE_ID_VIDEOPROCESSORGETOUTPUTTARGETRECT_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145821
D3D11_MESSAGE_ID_VIDEOPROCESSORGETOUTPUTBACKGROUNDCOLOR_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145822
D3D11_MESSAGE_ID_VIDEOPROCESSORGETOUTPUTCOLORSPACE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145823
D3D11_MESSAGE_ID_VIDEOPROCESSORGETOUTPUTALPHAFILLMODE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145824
D3D11_MESSAGE_ID_VIDEOPROCESSORGETOUTPUTCONSTRICTION_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145825
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTCONSTRICTION_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145826
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTCONSTRICTION_INVALIDSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145827
D3D11_MESSAGE_ID_VIDEOPROCESSORGETOUTPUTSTEREOMODE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145828
D3D11_MESSAGE_ID_VIDEOPROCESSORGETOUTPUTEXTENSION_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145829
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMFRAMEFORMAT_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145830
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMFRAMEFORMAT_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145831
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMFRAMEFORMAT_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145832
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMCOLORSPACE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145833
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMCOLORSPACE_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145834
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMOUTPUTRATE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145835
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMOUTPUTRATE_INVALIDRATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145836
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMOUTPUTRATE_INVALIDFLAG: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145837
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMOUTPUTRATE_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145838
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMSOURCERECT_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145839
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMSOURCERECT_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145840
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMSOURCERECT_INVALIDRECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145841
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMDESTRECT_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145842
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMDESTRECT_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145843
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMDESTRECT_INVALIDRECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145844
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMALPHA_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145845
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMALPHA_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145846
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMALPHA_INVALIDALPHA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145847
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMPALETTE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145848
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMPALETTE_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145849
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMPALETTE_INVALIDCOUNT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145850
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMPALETTE_INVALIDALPHA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145851
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMPIXELASPECTRATIO_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145852
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMPIXELASPECTRATIO_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145853
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMPIXELASPECTRATIO_INVALIDRATIO: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145854
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMLUMAKEY_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145855
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMLUMAKEY_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145856
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMLUMAKEY_INVALIDRANGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145857
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMLUMAKEY_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145858
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMSTEREOFORMAT_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145859
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMSTEREOFORMAT_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145860
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMSTEREOFORMAT_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145861
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMSTEREOFORMAT_FLIPUNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145862
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMSTEREOFORMAT_MONOOFFSETUNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145863
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMSTEREOFORMAT_FORMATUNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145864
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMSTEREOFORMAT_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145865
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMAUTOPROCESSINGMODE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145866
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMAUTOPROCESSINGMODE_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145867
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMFILTER_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145868
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMFILTER_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145869
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMFILTER_INVALIDFILTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145870
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMFILTER_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145871
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMFILTER_INVALIDLEVEL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145872
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMEXTENSION_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145873
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMEXTENSION_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145874
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMFRAMEFORMAT_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145875
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMCOLORSPACE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145876
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMOUTPUTRATE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145877
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMSOURCERECT_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145878
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMDESTRECT_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145879
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMALPHA_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145880
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMPALETTE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145881
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMPIXELASPECTRATIO_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145882
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMLUMAKEY_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145883
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMSTEREOFORMAT_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145884
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMAUTOPROCESSINGMODE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145885
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMFILTER_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145886
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMEXTENSION_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145887
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMEXTENSION_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145888
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145889
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_INVALIDSTREAMCOUNT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145890
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_TARGETRECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145891
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_INVALIDOUTPUT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145892
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_INVALIDPASTFRAMES: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145893
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_INVALIDFUTUREFRAMES: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145894
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_INVALIDSOURCERECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145895
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_INVALIDDESTRECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145896
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_INVALIDINPUTRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145897
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_INVALIDARRAYSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145898
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_INVALIDARRAY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145899
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_RIGHTEXPECTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145900
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_RIGHTNOTEXPECTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145901
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_STEREONOTENABLED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145902
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_INVALIDRIGHTRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145903
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_NOSTEREOSTREAMS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145904
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_INPUTHAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145905
D3D11_MESSAGE_ID_VIDEOPROCESSORBLT_OUTPUTHAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145906
D3D11_MESSAGE_ID_CREATEVIDEODECODEROUTPUTVIEW_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145907
D3D11_MESSAGE_ID_CREATEVIDEODECODEROUTPUTVIEW_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145908
D3D11_MESSAGE_ID_CREATEVIDEODECODEROUTPUTVIEW_INVALIDTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145909
D3D11_MESSAGE_ID_CREATEVIDEODECODEROUTPUTVIEW_INVALIDBIND: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145910
D3D11_MESSAGE_ID_CREATEVIDEODECODEROUTPUTVIEW_UNSUPPORTEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145911
D3D11_MESSAGE_ID_CREATEVIDEODECODEROUTPUTVIEW_INVALIDMIP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145912
D3D11_MESSAGE_ID_CREATEVIDEODECODEROUTPUTVIEW_UNSUPPORTEMIP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145913
D3D11_MESSAGE_ID_CREATEVIDEODECODEROUTPUTVIEW_INVALIDARRAYSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145914
D3D11_MESSAGE_ID_CREATEVIDEODECODEROUTPUTVIEW_INVALIDARRAY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145915
D3D11_MESSAGE_ID_CREATEVIDEODECODEROUTPUTVIEW_INVALIDDIMENSION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145916
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORINPUTVIEW_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145917
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORINPUTVIEW_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145918
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORINPUTVIEW_INVALIDTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145919
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORINPUTVIEW_INVALIDBIND: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145920
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORINPUTVIEW_INVALIDMISC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145921
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORINPUTVIEW_INVALIDUSAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145922
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORINPUTVIEW_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145923
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORINPUTVIEW_INVALIDFOURCC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145924
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORINPUTVIEW_INVALIDMIP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145925
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORINPUTVIEW_UNSUPPORTEDMIP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145926
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORINPUTVIEW_INVALIDARRAYSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145927
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORINPUTVIEW_INVALIDARRAY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145928
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORINPUTVIEW_INVALIDDIMENSION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145929
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSOROUTPUTVIEW_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145930
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSOROUTPUTVIEW_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145931
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSOROUTPUTVIEW_INVALIDTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145932
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSOROUTPUTVIEW_INVALIDBIND: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145933
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSOROUTPUTVIEW_INVALIDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145934
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSOROUTPUTVIEW_INVALIDMIP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145935
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSOROUTPUTVIEW_UNSUPPORTEDMIP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145936
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSOROUTPUTVIEW_UNSUPPORTEDARRAY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145937
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSOROUTPUTVIEW_INVALIDARRAY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145938
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSOROUTPUTVIEW_INVALIDDIMENSION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145939
D3D11_MESSAGE_ID_DEVICE_DRAW_INVALID_USE_OF_FORCED_SAMPLE_COUNT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145940
D3D11_MESSAGE_ID_CREATEBLENDSTATE_INVALIDLOGICOPS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145941
D3D11_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDDARRAYWITHDECODER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145942
D3D11_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_INVALIDDARRAYWITHDECODER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145943
D3D11_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDDARRAYWITHDECODER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145944
D3D11_MESSAGE_ID_DEVICE_LOCKEDOUT_INTERFACE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145945
D3D11_MESSAGE_ID_REF_WARNING_ATOMIC_INCONSISTENT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145946
D3D11_MESSAGE_ID_REF_WARNING_READING_UNINITIALIZED_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145947
D3D11_MESSAGE_ID_REF_WARNING_RAW_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145948
D3D11_MESSAGE_ID_REF_WARNING_WAR_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145949
D3D11_MESSAGE_ID_REF_WARNING_WAW_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145950
D3D11_MESSAGE_ID_CREATECRYPTOSESSION_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145951
D3D11_MESSAGE_ID_CREATECRYPTOSESSION_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145952
D3D11_MESSAGE_ID_GETCRYPTOTYPE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145953
D3D11_MESSAGE_ID_GETDECODERPROFILE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145954
D3D11_MESSAGE_ID_GETCRYPTOSESSIONCERTIFICATESIZE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145955
D3D11_MESSAGE_ID_GETCRYPTOSESSIONCERTIFICATE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145956
D3D11_MESSAGE_ID_GETCRYPTOSESSIONCERTIFICATE_WRONGSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145957
D3D11_MESSAGE_ID_GETCRYPTOSESSIONHANDLE_WRONGSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145958
D3D11_MESSAGE_ID_NEGOTIATECRPYTOSESSIONKEYEXCHANGE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145959
D3D11_MESSAGE_ID_ENCRYPTIONBLT_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145960
D3D11_MESSAGE_ID_ENCRYPTIONBLT_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145961
D3D11_MESSAGE_ID_ENCRYPTIONBLT_SRC_WRONGDEVICE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145962
D3D11_MESSAGE_ID_ENCRYPTIONBLT_DST_WRONGDEVICE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145963
D3D11_MESSAGE_ID_ENCRYPTIONBLT_FORMAT_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145964
D3D11_MESSAGE_ID_ENCRYPTIONBLT_SIZE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145965
D3D11_MESSAGE_ID_ENCRYPTIONBLT_SRC_MULTISAMPLED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145966
D3D11_MESSAGE_ID_ENCRYPTIONBLT_DST_NOT_STAGING: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145967
D3D11_MESSAGE_ID_ENCRYPTIONBLT_SRC_MAPPED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145968
D3D11_MESSAGE_ID_ENCRYPTIONBLT_DST_MAPPED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145969
D3D11_MESSAGE_ID_ENCRYPTIONBLT_SRC_OFFERED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145970
D3D11_MESSAGE_ID_ENCRYPTIONBLT_DST_OFFERED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145971
D3D11_MESSAGE_ID_ENCRYPTIONBLT_SRC_CONTENT_UNDEFINED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145972
D3D11_MESSAGE_ID_DECRYPTIONBLT_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145973
D3D11_MESSAGE_ID_DECRYPTIONBLT_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145974
D3D11_MESSAGE_ID_DECRYPTIONBLT_SRC_WRONGDEVICE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145975
D3D11_MESSAGE_ID_DECRYPTIONBLT_DST_WRONGDEVICE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145976
D3D11_MESSAGE_ID_DECRYPTIONBLT_FORMAT_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145977
D3D11_MESSAGE_ID_DECRYPTIONBLT_SIZE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145978
D3D11_MESSAGE_ID_DECRYPTIONBLT_DST_MULTISAMPLED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145979
D3D11_MESSAGE_ID_DECRYPTIONBLT_SRC_NOT_STAGING: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145980
D3D11_MESSAGE_ID_DECRYPTIONBLT_DST_NOT_RENDER_TARGET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145981
D3D11_MESSAGE_ID_DECRYPTIONBLT_SRC_MAPPED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145982
D3D11_MESSAGE_ID_DECRYPTIONBLT_DST_MAPPED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145983
D3D11_MESSAGE_ID_DECRYPTIONBLT_SRC_OFFERED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145984
D3D11_MESSAGE_ID_DECRYPTIONBLT_DST_OFFERED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145985
D3D11_MESSAGE_ID_DECRYPTIONBLT_SRC_CONTENT_UNDEFINED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145986
D3D11_MESSAGE_ID_STARTSESSIONKEYREFRESH_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145987
D3D11_MESSAGE_ID_STARTSESSIONKEYREFRESH_INVALIDSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145988
D3D11_MESSAGE_ID_FINISHSESSIONKEYREFRESH_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145989
D3D11_MESSAGE_ID_GETENCRYPTIONBLTKEY_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145990
D3D11_MESSAGE_ID_GETENCRYPTIONBLTKEY_INVALIDSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145991
D3D11_MESSAGE_ID_GETCONTENTPROTECTIONCAPS_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145992
D3D11_MESSAGE_ID_CHECKCRYPTOKEYEXCHANGE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145993
D3D11_MESSAGE_ID_CHECKCRYPTOKEYEXCHANGE_INVALIDINDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145994
D3D11_MESSAGE_ID_CREATEAUTHENTICATEDCHANNEL_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145995
D3D11_MESSAGE_ID_CREATEAUTHENTICATEDCHANNEL_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145996
D3D11_MESSAGE_ID_CREATEAUTHENTICATEDCHANNEL_INVALIDTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145997
D3D11_MESSAGE_ID_CREATEAUTHENTICATEDCHANNEL_OUTOFMEMORY_RETURN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145998
D3D11_MESSAGE_ID_GETAUTHENTICATEDCHANNELCERTIFICATESIZE_INVALIDCHANNEL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3145999
D3D11_MESSAGE_ID_GETAUTHENTICATEDCHANNELCERTIFICATESIZE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146000
D3D11_MESSAGE_ID_GETAUTHENTICATEDCHANNELCERTIFICATE_INVALIDCHANNEL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146001
D3D11_MESSAGE_ID_GETAUTHENTICATEDCHANNELCERTIFICATE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146002
D3D11_MESSAGE_ID_GETAUTHENTICATEDCHANNELCERTIFICATE_WRONGSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146003
D3D11_MESSAGE_ID_NEGOTIATEAUTHENTICATEDCHANNELKEYEXCHANGE_INVALIDCHANNEL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146004
D3D11_MESSAGE_ID_NEGOTIATEAUTHENTICATEDCHANNELKEYEXCHANGE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146005
D3D11_MESSAGE_ID_QUERYAUTHENTICATEDCHANNEL_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146006
D3D11_MESSAGE_ID_QUERYAUTHENTICATEDCHANNEL_WRONGCHANNEL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146007
D3D11_MESSAGE_ID_QUERYAUTHENTICATEDCHANNEL_UNSUPPORTEDQUERY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146008
D3D11_MESSAGE_ID_QUERYAUTHENTICATEDCHANNEL_WRONGSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146009
D3D11_MESSAGE_ID_QUERYAUTHENTICATEDCHANNEL_INVALIDPROCESSINDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146010
D3D11_MESSAGE_ID_CONFIGUREAUTHENTICATEDCHANNEL_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146011
D3D11_MESSAGE_ID_CONFIGUREAUTHENTICATEDCHANNEL_WRONGCHANNEL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146012
D3D11_MESSAGE_ID_CONFIGUREAUTHENTICATEDCHANNEL_UNSUPPORTEDCONFIGURE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146013
D3D11_MESSAGE_ID_CONFIGUREAUTHENTICATEDCHANNEL_WRONGSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146014
D3D11_MESSAGE_ID_CONFIGUREAUTHENTICATEDCHANNEL_INVALIDPROCESSIDTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146015
D3D11_MESSAGE_ID_VSSETCONSTANTBUFFERS_INVALIDBUFFEROFFSETORCOUNT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146016
D3D11_MESSAGE_ID_DSSETCONSTANTBUFFERS_INVALIDBUFFEROFFSETORCOUNT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146017
D3D11_MESSAGE_ID_HSSETCONSTANTBUFFERS_INVALIDBUFFEROFFSETORCOUNT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146018
D3D11_MESSAGE_ID_GSSETCONSTANTBUFFERS_INVALIDBUFFEROFFSETORCOUNT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146019
D3D11_MESSAGE_ID_PSSETCONSTANTBUFFERS_INVALIDBUFFEROFFSETORCOUNT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146020
D3D11_MESSAGE_ID_CSSETCONSTANTBUFFERS_INVALIDBUFFEROFFSETORCOUNT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146021
D3D11_MESSAGE_ID_NEGOTIATECRPYTOSESSIONKEYEXCHANGE_INVALIDSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146022
D3D11_MESSAGE_ID_NEGOTIATEAUTHENTICATEDCHANNELKEYEXCHANGE_INVALIDSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146023
D3D11_MESSAGE_ID_OFFERRESOURCES_INVALIDPRIORITY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146024
D3D11_MESSAGE_ID_GETCRYPTOSESSIONHANDLE_OUTOFMEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146025
D3D11_MESSAGE_ID_ACQUIREHANDLEFORCAPTURE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146026
D3D11_MESSAGE_ID_ACQUIREHANDLEFORCAPTURE_INVALIDTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146027
D3D11_MESSAGE_ID_ACQUIREHANDLEFORCAPTURE_INVALIDBIND: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146028
D3D11_MESSAGE_ID_ACQUIREHANDLEFORCAPTURE_INVALIDARRAY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146029
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMROTATION_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146030
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMROTATION_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146031
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMROTATION_INVALID: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146032
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMROTATION_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146033
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMROTATION_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146034
D3D11_MESSAGE_ID_DEVICE_CLEARVIEW_INVALIDVIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146035
D3D11_MESSAGE_ID_DEVICE_CREATEVERTEXSHADER_DOUBLEEXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146036
D3D11_MESSAGE_ID_DEVICE_CREATEVERTEXSHADER_SHADEREXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146037
D3D11_MESSAGE_ID_DEVICE_CREATEHULLSHADER_DOUBLEEXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146038
D3D11_MESSAGE_ID_DEVICE_CREATEHULLSHADER_SHADEREXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146039
D3D11_MESSAGE_ID_DEVICE_CREATEDOMAINSHADER_DOUBLEEXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146040
D3D11_MESSAGE_ID_DEVICE_CREATEDOMAINSHADER_SHADEREXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146041
D3D11_MESSAGE_ID_DEVICE_CREATEGEOMETRYSHADER_DOUBLEEXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146042
D3D11_MESSAGE_ID_DEVICE_CREATEGEOMETRYSHADER_SHADEREXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146043
D3D11_MESSAGE_ID_DEVICE_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_DOUBLEEXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146044
D3D11_MESSAGE_ID_DEVICE_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_SHADEREXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146045
D3D11_MESSAGE_ID_DEVICE_CREATEPIXELSHADER_DOUBLEEXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146046
D3D11_MESSAGE_ID_DEVICE_CREATEPIXELSHADER_SHADEREXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146047
D3D11_MESSAGE_ID_DEVICE_CREATECOMPUTESHADER_DOUBLEEXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146048
D3D11_MESSAGE_ID_DEVICE_CREATECOMPUTESHADER_SHADEREXTENSIONSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146049
D3D11_MESSAGE_ID_DEVICE_SHADER_LINKAGE_MINPRECISION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146050
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMALPHA_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146051
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMPIXELASPECTRATIO_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146052
D3D11_MESSAGE_ID_DEVICE_CREATEVERTEXSHADER_UAVSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146053
D3D11_MESSAGE_ID_DEVICE_CREATEHULLSHADER_UAVSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146054
D3D11_MESSAGE_ID_DEVICE_CREATEDOMAINSHADER_UAVSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146055
D3D11_MESSAGE_ID_DEVICE_CREATEGEOMETRYSHADER_UAVSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146056
D3D11_MESSAGE_ID_DEVICE_CREATEGEOMETRYSHADERWITHSTREAMOUTPUT_UAVSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146057
D3D11_MESSAGE_ID_DEVICE_CREATEPIXELSHADER_UAVSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146058
D3D11_MESSAGE_ID_DEVICE_CREATECOMPUTESHADER_UAVSNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146059
D3D11_MESSAGE_ID_DEVICE_OMSETRENDERTARGETSANDUNORDEREDACCESSVIEWS_INVALIDOFFSET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146060
D3D11_MESSAGE_ID_DEVICE_OMSETRENDERTARGETSANDUNORDEREDACCESSVIEWS_TOOMANYVIEWS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146061
D3D11_MESSAGE_ID_DEVICE_CLEARVIEW_NOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146062
D3D11_MESSAGE_ID_SWAPDEVICECONTEXTSTATE_NOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146063
D3D11_MESSAGE_ID_UPDATESUBRESOURCE_PREFERUPDATESUBRESOURCE1: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146064
D3D11_MESSAGE_ID_GETDC_INACCESSIBLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146065
D3D11_MESSAGE_ID_DEVICE_CLEARVIEW_INVALIDRECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146066
D3D11_MESSAGE_ID_DEVICE_DRAW_SAMPLE_MASK_IGNORED_ON_FL9: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146067
D3D11_MESSAGE_ID_DEVICE_OPEN_SHARED_RESOURCE1_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146068
D3D11_MESSAGE_ID_DEVICE_OPEN_SHARED_RESOURCE_BY_NAME_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146069
D3D11_MESSAGE_ID_ENQUEUESETEVENT_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146070
D3D11_MESSAGE_ID_OFFERRELEASE_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146071
D3D11_MESSAGE_ID_OFFERRESOURCES_INACCESSIBLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146072
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSORINPUTVIEW_INVALIDMSAA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146073
D3D11_MESSAGE_ID_CREATEVIDEOPROCESSOROUTPUTVIEW_INVALIDMSAA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146074
D3D11_MESSAGE_ID_DEVICE_CLEARVIEW_INVALIDSOURCERECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146075
D3D11_MESSAGE_ID_DEVICE_CLEARVIEW_EMPTYRECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146076
D3D11_MESSAGE_ID_UPDATESUBRESOURCE_EMPTYDESTBOX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146077
D3D11_MESSAGE_ID_COPYSUBRESOURCEREGION_EMPTYSOURCEBOX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146078
D3D11_MESSAGE_ID_DEVICE_DRAW_OM_RENDER_TARGET_DOES_NOT_SUPPORT_LOGIC_OPS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146079
D3D11_MESSAGE_ID_DEVICE_DRAW_DEPTHSTENCILVIEW_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146080
D3D11_MESSAGE_ID_DEVICE_DRAW_RENDERTARGETVIEW_NOT_SET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146081
D3D11_MESSAGE_ID_DEVICE_DRAW_RENDERTARGETVIEW_NOT_SET_DUE_TO_FLIP_PRESENT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146082
D3D11_MESSAGE_ID_DEVICE_UNORDEREDACCESSVIEW_NOT_SET_DUE_TO_FLIP_PRESENT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146083
D3D11_MESSAGE_ID_GETDATAFORNEWHARDWAREKEY_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146084
D3D11_MESSAGE_ID_CHECKCRYPTOSESSIONSTATUS_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146085
D3D11_MESSAGE_ID_GETCRYPTOSESSIONPRIVATEDATASIZE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146086
D3D11_MESSAGE_ID_GETVIDEODECODERCAPS_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146087
D3D11_MESSAGE_ID_GETVIDEODECODERCAPS_ZEROWIDTHHEIGHT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146088
D3D11_MESSAGE_ID_CHECKVIDEODECODERDOWNSAMPLING_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146089
D3D11_MESSAGE_ID_CHECKVIDEODECODERDOWNSAMPLING_INVALIDCOLORSPACE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146090
D3D11_MESSAGE_ID_CHECKVIDEODECODERDOWNSAMPLING_ZEROWIDTHHEIGHT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146091
D3D11_MESSAGE_ID_VIDEODECODERENABLEDOWNSAMPLING_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146092
D3D11_MESSAGE_ID_VIDEODECODERENABLEDOWNSAMPLING_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146093
D3D11_MESSAGE_ID_VIDEODECODERUPDATEDOWNSAMPLING_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146094
D3D11_MESSAGE_ID_VIDEODECODERUPDATEDOWNSAMPLING_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146095
D3D11_MESSAGE_ID_CHECKVIDEOPROCESSORFORMATCONVERSION_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146096
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTCOLORSPACE1_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146097
D3D11_MESSAGE_ID_VIDEOPROCESSORGETOUTPUTCOLORSPACE1_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146098
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMCOLORSPACE1_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146099
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMCOLORSPACE1_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146100
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMMIRROR_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146101
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMMIRROR_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146102
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMMIRROR_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146103
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMCOLORSPACE1_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146104
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMMIRROR_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146105
D3D11_MESSAGE_ID_RECOMMENDVIDEODECODERDOWNSAMPLING_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146106
D3D11_MESSAGE_ID_RECOMMENDVIDEODECODERDOWNSAMPLING_INVALIDCOLORSPACE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146107
D3D11_MESSAGE_ID_RECOMMENDVIDEODECODERDOWNSAMPLING_ZEROWIDTHHEIGHT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146108
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTSHADERUSAGE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146109
D3D11_MESSAGE_ID_VIDEOPROCESSORGETOUTPUTSHADERUSAGE_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146110
D3D11_MESSAGE_ID_VIDEOPROCESSORGETBEHAVIORHINTS_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146111
D3D11_MESSAGE_ID_VIDEOPROCESSORGETBEHAVIORHINTS_INVALIDSTREAMCOUNT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146112
D3D11_MESSAGE_ID_VIDEOPROCESSORGETBEHAVIORHINTS_TARGETRECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146113
D3D11_MESSAGE_ID_VIDEOPROCESSORGETBEHAVIORHINTS_INVALIDSOURCERECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146114
D3D11_MESSAGE_ID_VIDEOPROCESSORGETBEHAVIORHINTS_INVALIDDESTRECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146115
D3D11_MESSAGE_ID_GETCRYPTOSESSIONPRIVATEDATASIZE_INVALID_KEY_EXCHANGE_TYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146116
D3D11_MESSAGE_ID_DEVICE_OPEN_SHARED_RESOURCE1_ACCESS_DENIED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146117
D3D11_MESSAGE_ID_D3D11_1_MESSAGES_END: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146118
D3D11_MESSAGE_ID_D3D11_2_MESSAGES_START: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146119
D3D11_MESSAGE_ID_CREATEBUFFER_INVALIDUSAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146120
D3D11_MESSAGE_ID_CREATETEXTURE1D_INVALIDUSAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146121
D3D11_MESSAGE_ID_CREATETEXTURE2D_INVALIDUSAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146122
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_LEVEL9_STEPRATE_NOT_1: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146123
D3D11_MESSAGE_ID_CREATEINPUTLAYOUT_LEVEL9_INSTANCING_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146124
D3D11_MESSAGE_ID_UPDATETILEMAPPINGS_INVALID_PARAMETER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146125
D3D11_MESSAGE_ID_COPYTILEMAPPINGS_INVALID_PARAMETER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146126
D3D11_MESSAGE_ID_COPYTILES_INVALID_PARAMETER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146127
D3D11_MESSAGE_ID_UPDATETILES_INVALID_PARAMETER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146128
D3D11_MESSAGE_ID_RESIZETILEPOOL_INVALID_PARAMETER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146129
D3D11_MESSAGE_ID_TILEDRESOURCEBARRIER_INVALID_PARAMETER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146130
D3D11_MESSAGE_ID_NULL_TILE_MAPPING_ACCESS_WARNING: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146131
D3D11_MESSAGE_ID_NULL_TILE_MAPPING_ACCESS_ERROR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146132
D3D11_MESSAGE_ID_DIRTY_TILE_MAPPING_ACCESS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146133
D3D11_MESSAGE_ID_DUPLICATE_TILE_MAPPINGS_IN_COVERED_AREA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146134
D3D11_MESSAGE_ID_TILE_MAPPINGS_IN_COVERED_AREA_DUPLICATED_OUTSIDE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146135
D3D11_MESSAGE_ID_TILE_MAPPINGS_SHARED_BETWEEN_INCOMPATIBLE_RESOURCES: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146136
D3D11_MESSAGE_ID_TILE_MAPPINGS_SHARED_BETWEEN_INPUT_AND_OUTPUT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146137
D3D11_MESSAGE_ID_CHECKMULTISAMPLEQUALITYLEVELS_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146138
D3D11_MESSAGE_ID_GETRESOURCETILING_NONTILED_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146139
D3D11_MESSAGE_ID_RESIZETILEPOOL_SHRINK_WITH_MAPPINGS_STILL_DEFINED_PAST_END: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146140
D3D11_MESSAGE_ID_NEED_TO_CALL_TILEDRESOURCEBARRIER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146141
D3D11_MESSAGE_ID_CREATEDEVICE_INVALIDARGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146142
D3D11_MESSAGE_ID_CREATEDEVICE_WARNING: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146143
D3D11_MESSAGE_ID_CLEARUNORDEREDACCESSVIEWUINT_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146144
D3D11_MESSAGE_ID_CLEARUNORDEREDACCESSVIEWFLOAT_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146145
D3D11_MESSAGE_ID_TILED_RESOURCE_TIER_1_BUFFER_TEXTURE_MISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146146
D3D11_MESSAGE_ID_CREATE_CRYPTOSESSION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146147
D3D11_MESSAGE_ID_CREATE_AUTHENTICATEDCHANNEL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146148
D3D11_MESSAGE_ID_LIVE_CRYPTOSESSION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146149
D3D11_MESSAGE_ID_LIVE_AUTHENTICATEDCHANNEL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146150
D3D11_MESSAGE_ID_DESTROY_CRYPTOSESSION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146151
D3D11_MESSAGE_ID_DESTROY_AUTHENTICATEDCHANNEL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146152
D3D11_MESSAGE_ID_D3D11_2_MESSAGES_END: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146153
D3D11_MESSAGE_ID_D3D11_3_MESSAGES_START: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146154
D3D11_MESSAGE_ID_CREATERASTERIZERSTATE_INVALID_CONSERVATIVERASTERMODE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146155
D3D11_MESSAGE_ID_DEVICE_DRAW_INVALID_SYSTEMVALUE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146156
D3D11_MESSAGE_ID_CREATEQUERYORPREDICATE_INVALIDCONTEXTTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146157
D3D11_MESSAGE_ID_CREATEQUERYORPREDICATE_DECODENOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146158
D3D11_MESSAGE_ID_CREATEQUERYORPREDICATE_ENCODENOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146159
D3D11_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDPLANEINDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146160
D3D11_MESSAGE_ID_CREATESHADERRESOURCEVIEW_INVALIDVIDEOPLANEINDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146161
D3D11_MESSAGE_ID_CREATESHADERRESOURCEVIEW_AMBIGUOUSVIDEOPLANEINDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146162
D3D11_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDPLANEINDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146163
D3D11_MESSAGE_ID_CREATERENDERTARGETVIEW_INVALIDVIDEOPLANEINDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146164
D3D11_MESSAGE_ID_CREATERENDERTARGETVIEW_AMBIGUOUSVIDEOPLANEINDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146165
D3D11_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_INVALIDPLANEINDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146166
D3D11_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_INVALIDVIDEOPLANEINDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146167
D3D11_MESSAGE_ID_CREATEUNORDEREDACCESSVIEW_AMBIGUOUSVIDEOPLANEINDEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146168
D3D11_MESSAGE_ID_JPEGDECODE_INVALIDSCANDATAOFFSET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146169
D3D11_MESSAGE_ID_JPEGDECODE_NOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146170
D3D11_MESSAGE_ID_JPEGDECODE_DIMENSIONSTOOLARGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146171
D3D11_MESSAGE_ID_JPEGDECODE_INVALIDCOMPONENTS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146172
D3D11_MESSAGE_ID_JPEGDECODE_DESTINATIONNOT2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146173
D3D11_MESSAGE_ID_JPEGDECODE_TILEDRESOURCESUNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146174
D3D11_MESSAGE_ID_JPEGDECODE_GUARDRECTSUNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146175
D3D11_MESSAGE_ID_JPEGDECODE_FORMATUNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146176
D3D11_MESSAGE_ID_JPEGDECODE_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146177
D3D11_MESSAGE_ID_JPEGDECODE_INVALIDMIPLEVEL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146178
D3D11_MESSAGE_ID_JPEGDECODE_EMPTYDESTBOX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146179
D3D11_MESSAGE_ID_JPEGDECODE_DESTBOXNOT2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146180
D3D11_MESSAGE_ID_JPEGDECODE_DESTBOXNOTSUB: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146181
D3D11_MESSAGE_ID_JPEGDECODE_DESTBOXESINTERSECT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146182
D3D11_MESSAGE_ID_JPEGDECODE_XSUBSAMPLEMISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146183
D3D11_MESSAGE_ID_JPEGDECODE_YSUBSAMPLEMISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146184
D3D11_MESSAGE_ID_JPEGDECODE_XSUBSAMPLEODD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146185
D3D11_MESSAGE_ID_JPEGDECODE_YSUBSAMPLEODD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146186
D3D11_MESSAGE_ID_JPEGDECODE_OUTPUTDIMENSIONSTOOLARGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146187
D3D11_MESSAGE_ID_JPEGDECODE_NONPOW2SCALEUNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146188
D3D11_MESSAGE_ID_JPEGDECODE_FRACTIONALDOWNSCALETOLARGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146189
D3D11_MESSAGE_ID_JPEGDECODE_CHROMASIZEMISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146190
D3D11_MESSAGE_ID_JPEGDECODE_LUMACHROMASIZEMISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146191
D3D11_MESSAGE_ID_JPEGDECODE_INVALIDNUMDESTINATIONS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146192
D3D11_MESSAGE_ID_JPEGDECODE_SUBBOXUNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146193
D3D11_MESSAGE_ID_JPEGDECODE_1DESTUNSUPPORTEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146194
D3D11_MESSAGE_ID_JPEGDECODE_3DESTUNSUPPORTEDFORMAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146195
D3D11_MESSAGE_ID_JPEGDECODE_SCALEUNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146196
D3D11_MESSAGE_ID_JPEGDECODE_INVALIDSOURCESIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146197
D3D11_MESSAGE_ID_JPEGDECODE_INVALIDCOPYFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146198
D3D11_MESSAGE_ID_JPEGDECODE_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146199
D3D11_MESSAGE_ID_JPEGDECODE_UNSUPPORTEDSRCBUFFERUSAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146200
D3D11_MESSAGE_ID_JPEGDECODE_UNSUPPORTEDSRCBUFFERMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146201
D3D11_MESSAGE_ID_JPEGDECODE_UNSUPPORTEDDSTTEXTUREUSAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146202
D3D11_MESSAGE_ID_JPEGDECODE_BACKBUFFERNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146203
D3D11_MESSAGE_ID_JPEGDECODE_UNSUPPRTEDCOPYFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146204
D3D11_MESSAGE_ID_JPEGENCODE_NOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146205
D3D11_MESSAGE_ID_JPEGENCODE_INVALIDSCANDATAOFFSET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146206
D3D11_MESSAGE_ID_JPEGENCODE_INVALIDCOMPONENTS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146207
D3D11_MESSAGE_ID_JPEGENCODE_SOURCENOT2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146208
D3D11_MESSAGE_ID_JPEGENCODE_TILEDRESOURCESUNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146209
D3D11_MESSAGE_ID_JPEGENCODE_GUARDRECTSUNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146210
D3D11_MESSAGE_ID_JPEGENCODE_XSUBSAMPLEMISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146211
D3D11_MESSAGE_ID_JPEGENCODE_YSUBSAMPLEMISMATCH: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146212
D3D11_MESSAGE_ID_JPEGENCODE_FORMATUNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146213
D3D11_MESSAGE_ID_JPEGENCODE_INVALIDSUBRESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146214
D3D11_MESSAGE_ID_JPEGENCODE_INVALIDMIPLEVEL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146215
D3D11_MESSAGE_ID_JPEGENCODE_DIMENSIONSTOOLARGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146216
D3D11_MESSAGE_ID_JPEGENCODE_HAZARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146217
D3D11_MESSAGE_ID_JPEGENCODE_UNSUPPORTEDDSTBUFFERUSAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146218
D3D11_MESSAGE_ID_JPEGENCODE_UNSUPPORTEDDSTBUFFERMISCFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146219
D3D11_MESSAGE_ID_JPEGENCODE_UNSUPPORTEDSRCTEXTUREUSAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146220
D3D11_MESSAGE_ID_JPEGENCODE_BACKBUFFERNOTSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146221
D3D11_MESSAGE_ID_CREATEQUERYORPREDICATE_UNSUPPORTEDCONTEXTTTYPEFORQUERY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146222
D3D11_MESSAGE_ID_FLUSH1_INVALIDCONTEXTTYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146223
D3D11_MESSAGE_ID_DEVICE_SETHARDWAREPROTECTION_INVALIDCONTEXT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146224
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTHDRMETADATA_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146225
D3D11_MESSAGE_ID_VIDEOPROCESSORSETOUTPUTHDRMETADATA_INVALIDSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146226
D3D11_MESSAGE_ID_VIDEOPROCESSORGETOUTPUTHDRMETADATA_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146227
D3D11_MESSAGE_ID_VIDEOPROCESSORGETOUTPUTHDRMETADATA_INVALIDSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146228
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMHDRMETADATA_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146229
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMHDRMETADATA_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146230
D3D11_MESSAGE_ID_VIDEOPROCESSORSETSTREAMHDRMETADATA_INVALIDSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146231
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMHDRMETADATA_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146232
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMHDRMETADATA_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146233
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMHDRMETADATA_INVALIDSIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146234
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMFRAMEFORMAT_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146235
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMCOLORSPACE_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146236
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMOUTPUTRATE_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146237
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMSOURCERECT_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146238
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMDESTRECT_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146239
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMALPHA_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146240
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMPALETTE_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146241
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMPIXELASPECTRATIO_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146242
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMLUMAKEY_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146243
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMSTEREOFORMAT_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146244
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMAUTOPROCESSINGMODE_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146245
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMFILTER_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146246
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMROTATION_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146247
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMCOLORSPACE1_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146248
D3D11_MESSAGE_ID_VIDEOPROCESSORGETSTREAMMIRROR_INVALIDSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146249
D3D11_MESSAGE_ID_CREATE_FENCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146250
D3D11_MESSAGE_ID_LIVE_FENCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146251
D3D11_MESSAGE_ID_DESTROY_FENCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146252
D3D11_MESSAGE_ID_CREATE_SYNCHRONIZEDCHANNEL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146253
D3D11_MESSAGE_ID_LIVE_SYNCHRONIZEDCHANNEL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146254
D3D11_MESSAGE_ID_DESTROY_SYNCHRONIZEDCHANNEL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146255
D3D11_MESSAGE_ID_CREATEFENCE_INVALIDFLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146256
D3D11_MESSAGE_ID_D3D11_3_MESSAGES_END: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146257
D3D11_MESSAGE_ID_D3D11_5_MESSAGES_START: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146258
D3D11_MESSAGE_ID_NEGOTIATECRYPTOSESSIONKEYEXCHANGEMT_INVALIDKEYEXCHANGETYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146259
D3D11_MESSAGE_ID_NEGOTIATECRYPTOSESSIONKEYEXCHANGEMT_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146260
D3D11_MESSAGE_ID_DECODERBEGINFRAME_INVALID_HISTOGRAM_COMPONENT_COUNT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146261
D3D11_MESSAGE_ID_DECODERBEGINFRAME_INVALID_HISTOGRAM_COMPONENT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146262
D3D11_MESSAGE_ID_DECODERBEGINFRAME_INVALID_HISTOGRAM_BUFFER_SIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146263
D3D11_MESSAGE_ID_DECODERBEGINFRAME_INVALID_HISTOGRAM_BUFFER_USAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146264
D3D11_MESSAGE_ID_DECODERBEGINFRAME_INVALID_HISTOGRAM_BUFFER_MISC_FLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146265
D3D11_MESSAGE_ID_DECODERBEGINFRAME_INVALID_HISTOGRAM_BUFFER_OFFSET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146266
D3D11_MESSAGE_ID_CREATE_TRACKEDWORKLOAD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146267
D3D11_MESSAGE_ID_LIVE_TRACKEDWORKLOAD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146268
D3D11_MESSAGE_ID_DESTROY_TRACKEDWORKLOAD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146269
D3D11_MESSAGE_ID_CREATE_TRACKED_WORKLOAD_NULLPARAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146270
D3D11_MESSAGE_ID_CREATE_TRACKED_WORKLOAD_INVALID_MAX_INSTANCES: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146271
D3D11_MESSAGE_ID_CREATE_TRACKED_WORKLOAD_INVALID_DEADLINE_TYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146272
D3D11_MESSAGE_ID_CREATE_TRACKED_WORKLOAD_INVALID_ENGINE_TYPE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146273
D3D11_MESSAGE_ID_MULTIPLE_TRACKED_WORKLOADS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146274
D3D11_MESSAGE_ID_MULTIPLE_TRACKED_WORKLOAD_PAIRS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146275
D3D11_MESSAGE_ID_INCOMPLETE_TRACKED_WORKLOAD_PAIR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146276
D3D11_MESSAGE_ID_OUT_OF_ORDER_TRACKED_WORKLOAD_PAIR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146277
D3D11_MESSAGE_ID_CANNOT_ADD_TRACKED_WORKLOAD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146278
D3D11_MESSAGE_ID_TRACKED_WORKLOAD_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146279
D3D11_MESSAGE_ID_TRACKED_WORKLOAD_ENGINE_TYPE_NOT_FOUND: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146280
D3D11_MESSAGE_ID_NO_TRACKED_WORKLOAD_SLOT_AVAILABLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146281
D3D11_MESSAGE_ID_END_TRACKED_WORKLOAD_INVALID_ARG: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146282
D3D11_MESSAGE_ID_TRACKED_WORKLOAD_DISJOINT_FAILURE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146283
D3D11_MESSAGE_ID_D3D11_5_MESSAGES_END: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID = 3146284
D3D11_MESSAGE_SEVERITY = Int32
D3D11_MESSAGE_SEVERITY_CORRUPTION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_SEVERITY = 0
D3D11_MESSAGE_SEVERITY_ERROR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_SEVERITY = 1
D3D11_MESSAGE_SEVERITY_WARNING: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_SEVERITY = 2
D3D11_MESSAGE_SEVERITY_INFO: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_SEVERITY = 3
D3D11_MESSAGE_SEVERITY_MESSAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_SEVERITY = 4
class D3D11_OMAC(Structure):
    Omac: Byte * 16
class D3D11_PACKED_MIP_DESC(Structure):
    NumStandardMips: Byte
    NumPackedMips: Byte
    NumTilesForPackedMips: UInt32
    StartTileIndexInOverallResource: UInt32
class D3D11_PARAMETER_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PSTR
    SemanticName: win32more.Windows.Win32.Foundation.PSTR
    Type: win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_VARIABLE_TYPE
    Class: win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_VARIABLE_CLASS
    Rows: UInt32
    Columns: UInt32
    InterpolationMode: win32more.Windows.Win32.Graphics.Direct3D.D3D_INTERPOLATION_MODE
    Flags: win32more.Windows.Win32.Graphics.Direct3D.D3D_PARAMETER_FLAGS
    FirstInRegister: UInt32
    FirstInComponent: UInt32
    FirstOutRegister: UInt32
    FirstOutComponent: UInt32
class D3D11_PIXEL_SHADER_TRACE_DESC(Structure):
    Invocation: UInt64
    X: Int32
    Y: Int32
    SampleMask: UInt64
D3D11_QUERY = Int32
D3D11_QUERY_EVENT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY = 0
D3D11_QUERY_OCCLUSION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY = 1
D3D11_QUERY_TIMESTAMP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY = 2
D3D11_QUERY_TIMESTAMP_DISJOINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY = 3
D3D11_QUERY_PIPELINE_STATISTICS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY = 4
D3D11_QUERY_OCCLUSION_PREDICATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY = 5
D3D11_QUERY_SO_STATISTICS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY = 6
D3D11_QUERY_SO_OVERFLOW_PREDICATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY = 7
D3D11_QUERY_SO_STATISTICS_STREAM0: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY = 8
D3D11_QUERY_SO_OVERFLOW_PREDICATE_STREAM0: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY = 9
D3D11_QUERY_SO_STATISTICS_STREAM1: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY = 10
D3D11_QUERY_SO_OVERFLOW_PREDICATE_STREAM1: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY = 11
D3D11_QUERY_SO_STATISTICS_STREAM2: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY = 12
D3D11_QUERY_SO_OVERFLOW_PREDICATE_STREAM2: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY = 13
D3D11_QUERY_SO_STATISTICS_STREAM3: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY = 14
D3D11_QUERY_SO_OVERFLOW_PREDICATE_STREAM3: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY = 15
class D3D11_QUERY_DATA_PIPELINE_STATISTICS(Structure):
    IAVertices: UInt64
    IAPrimitives: UInt64
    VSInvocations: UInt64
    GSInvocations: UInt64
    GSPrimitives: UInt64
    CInvocations: UInt64
    CPrimitives: UInt64
    PSInvocations: UInt64
    HSInvocations: UInt64
    DSInvocations: UInt64
    CSInvocations: UInt64
class D3D11_QUERY_DATA_SO_STATISTICS(Structure):
    NumPrimitivesWritten: UInt64
    PrimitivesStorageNeeded: UInt64
class D3D11_QUERY_DATA_TIMESTAMP_DISJOINT(Structure):
    Frequency: UInt64
    Disjoint: win32more.Windows.Win32.Foundation.BOOL
class D3D11_QUERY_DESC(Structure):
    Query: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY
    MiscFlags: UInt32
class D3D11_QUERY_DESC1(Structure):
    Query: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY
    MiscFlags: UInt32
    ContextType: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTEXT_TYPE
D3D11_QUERY_MISC_FLAG = Int32
D3D11_QUERY_MISC_PREDICATEHINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY_MISC_FLAG = 1
D3D11_RAISE_FLAG = Int32
D3D11_RAISE_FLAG_DRIVER_INTERNAL_ERROR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RAISE_FLAG = 1
class D3D11_RASTERIZER_DESC(Structure):
    FillMode: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILL_MODE
    CullMode: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CULL_MODE
    FrontCounterClockwise: win32more.Windows.Win32.Foundation.BOOL
    DepthBias: Int32
    DepthBiasClamp: Single
    SlopeScaledDepthBias: Single
    DepthClipEnable: win32more.Windows.Win32.Foundation.BOOL
    ScissorEnable: win32more.Windows.Win32.Foundation.BOOL
    MultisampleEnable: win32more.Windows.Win32.Foundation.BOOL
    AntialiasedLineEnable: win32more.Windows.Win32.Foundation.BOOL
class D3D11_RASTERIZER_DESC1(Structure):
    FillMode: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILL_MODE
    CullMode: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CULL_MODE
    FrontCounterClockwise: win32more.Windows.Win32.Foundation.BOOL
    DepthBias: Int32
    DepthBiasClamp: Single
    SlopeScaledDepthBias: Single
    DepthClipEnable: win32more.Windows.Win32.Foundation.BOOL
    ScissorEnable: win32more.Windows.Win32.Foundation.BOOL
    MultisampleEnable: win32more.Windows.Win32.Foundation.BOOL
    AntialiasedLineEnable: win32more.Windows.Win32.Foundation.BOOL
    ForcedSampleCount: UInt32
class D3D11_RASTERIZER_DESC2(Structure):
    FillMode: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILL_MODE
    CullMode: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CULL_MODE
    FrontCounterClockwise: win32more.Windows.Win32.Foundation.BOOL
    DepthBias: Int32
    DepthBiasClamp: Single
    SlopeScaledDepthBias: Single
    DepthClipEnable: win32more.Windows.Win32.Foundation.BOOL
    ScissorEnable: win32more.Windows.Win32.Foundation.BOOL
    MultisampleEnable: win32more.Windows.Win32.Foundation.BOOL
    AntialiasedLineEnable: win32more.Windows.Win32.Foundation.BOOL
    ForcedSampleCount: UInt32
    ConservativeRaster: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONSERVATIVE_RASTERIZATION_MODE
class D3D11_RENDER_TARGET_BLEND_DESC(Structure):
    BlendEnable: win32more.Windows.Win32.Foundation.BOOL
    SrcBlend: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND
    DestBlend: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND
    BlendOp: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND_OP
    SrcBlendAlpha: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND
    DestBlendAlpha: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND
    BlendOpAlpha: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND_OP
    RenderTargetWriteMask: Byte
class D3D11_RENDER_TARGET_BLEND_DESC1(Structure):
    BlendEnable: win32more.Windows.Win32.Foundation.BOOL
    LogicOpEnable: win32more.Windows.Win32.Foundation.BOOL
    SrcBlend: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND
    DestBlend: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND
    BlendOp: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND_OP
    SrcBlendAlpha: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND
    DestBlendAlpha: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND
    BlendOpAlpha: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND_OP
    LogicOp: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LOGIC_OP
    RenderTargetWriteMask: Byte
class D3D11_RENDER_TARGET_VIEW_DESC(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RTV_DIMENSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Buffer: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUFFER_RTV
        Texture1D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX1D_RTV
        Texture1DArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX1D_ARRAY_RTV
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_RTV
        Texture2DArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_ARRAY_RTV
        Texture2DMS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2DMS_RTV
        Texture2DMSArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2DMS_ARRAY_RTV
        Texture3D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX3D_RTV
class D3D11_RENDER_TARGET_VIEW_DESC1(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RTV_DIMENSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Buffer: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUFFER_RTV
        Texture1D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX1D_RTV
        Texture1DArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX1D_ARRAY_RTV
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_RTV1
        Texture2DArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_ARRAY_RTV1
        Texture2DMS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2DMS_RTV
        Texture2DMSArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2DMS_ARRAY_RTV
        Texture3D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX3D_RTV
D3D11_RESOURCE_DIMENSION = Int32
D3D11_RESOURCE_DIMENSION_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_DIMENSION = 0
D3D11_RESOURCE_DIMENSION_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_DIMENSION = 1
D3D11_RESOURCE_DIMENSION_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_DIMENSION = 2
D3D11_RESOURCE_DIMENSION_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_DIMENSION = 3
D3D11_RESOURCE_DIMENSION_TEXTURE3D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_DIMENSION = 4
D3D11_RESOURCE_MISC_FLAG = Int32
D3D11_RESOURCE_MISC_GENERATE_MIPS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 1
D3D11_RESOURCE_MISC_SHARED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 2
D3D11_RESOURCE_MISC_TEXTURECUBE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 4
D3D11_RESOURCE_MISC_DRAWINDIRECT_ARGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 16
D3D11_RESOURCE_MISC_BUFFER_ALLOW_RAW_VIEWS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 32
D3D11_RESOURCE_MISC_BUFFER_STRUCTURED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 64
D3D11_RESOURCE_MISC_RESOURCE_CLAMP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 128
D3D11_RESOURCE_MISC_SHARED_KEYEDMUTEX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 256
D3D11_RESOURCE_MISC_GDI_COMPATIBLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 512
D3D11_RESOURCE_MISC_SHARED_NTHANDLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 2048
D3D11_RESOURCE_MISC_RESTRICTED_CONTENT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 4096
D3D11_RESOURCE_MISC_RESTRICT_SHARED_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 8192
D3D11_RESOURCE_MISC_RESTRICT_SHARED_RESOURCE_DRIVER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 16384
D3D11_RESOURCE_MISC_GUARDED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 32768
D3D11_RESOURCE_MISC_TILE_POOL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 131072
D3D11_RESOURCE_MISC_TILED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 262144
D3D11_RESOURCE_MISC_HW_PROTECTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 524288
D3D11_RESOURCE_MISC_SHARED_DISPLAYABLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 1048576
D3D11_RESOURCE_MISC_SHARED_EXCLUSIVE_WRITER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_MISC_FLAG = 2097152
D3D11_RLDO_FLAGS = Int32
D3D11_RLDO_SUMMARY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RLDO_FLAGS = 1
D3D11_RLDO_DETAIL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RLDO_FLAGS = 2
D3D11_RLDO_IGNORE_INTERNAL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RLDO_FLAGS = 4
D3D11_RTV_DIMENSION = Int32
D3D11_RTV_DIMENSION_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RTV_DIMENSION = 0
D3D11_RTV_DIMENSION_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RTV_DIMENSION = 1
D3D11_RTV_DIMENSION_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RTV_DIMENSION = 2
D3D11_RTV_DIMENSION_TEXTURE1DARRAY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RTV_DIMENSION = 3
D3D11_RTV_DIMENSION_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RTV_DIMENSION = 4
D3D11_RTV_DIMENSION_TEXTURE2DARRAY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RTV_DIMENSION = 5
D3D11_RTV_DIMENSION_TEXTURE2DMS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RTV_DIMENSION = 6
D3D11_RTV_DIMENSION_TEXTURE2DMSARRAY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RTV_DIMENSION = 7
D3D11_RTV_DIMENSION_TEXTURE3D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RTV_DIMENSION = 8
class D3D11_SAMPLER_DESC(Structure):
    Filter: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FILTER
    AddressU: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE_ADDRESS_MODE
    AddressV: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE_ADDRESS_MODE
    AddressW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE_ADDRESS_MODE
    MipLODBias: Single
    MaxAnisotropy: UInt32
    ComparisonFunc: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COMPARISON_FUNC
    BorderColor: Single * 4
    MinLOD: Single
    MaxLOD: Single
class D3D11_SHADER_BUFFER_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PSTR
    Type: win32more.Windows.Win32.Graphics.Direct3D.D3D_CBUFFER_TYPE
    Variables: UInt32
    Size: UInt32
    uFlags: UInt32
D3D11_SHADER_CACHE_SUPPORT_FLAGS = Int32
D3D11_SHADER_CACHE_SUPPORT_NONE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_CACHE_SUPPORT_FLAGS = 0
D3D11_SHADER_CACHE_SUPPORT_AUTOMATIC_INPROC_CACHE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_CACHE_SUPPORT_FLAGS = 1
D3D11_SHADER_CACHE_SUPPORT_AUTOMATIC_DISK_CACHE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_CACHE_SUPPORT_FLAGS = 2
class D3D11_SHADER_DESC(Structure):
    Version: UInt32
    Creator: win32more.Windows.Win32.Foundation.PSTR
    Flags: UInt32
    ConstantBuffers: UInt32
    BoundResources: UInt32
    InputParameters: UInt32
    OutputParameters: UInt32
    InstructionCount: UInt32
    TempRegisterCount: UInt32
    TempArrayCount: UInt32
    DefCount: UInt32
    DclCount: UInt32
    TextureNormalInstructions: UInt32
    TextureLoadInstructions: UInt32
    TextureCompInstructions: UInt32
    TextureBiasInstructions: UInt32
    TextureGradientInstructions: UInt32
    FloatInstructionCount: UInt32
    IntInstructionCount: UInt32
    UintInstructionCount: UInt32
    StaticFlowControlCount: UInt32
    DynamicFlowControlCount: UInt32
    MacroInstructionCount: UInt32
    ArrayInstructionCount: UInt32
    CutInstructionCount: UInt32
    EmitInstructionCount: UInt32
    GSOutputTopology: win32more.Windows.Win32.Graphics.Direct3D.D3D_PRIMITIVE_TOPOLOGY
    GSMaxOutputVertexCount: UInt32
    InputPrimitive: win32more.Windows.Win32.Graphics.Direct3D.D3D_PRIMITIVE
    PatchConstantParameters: UInt32
    cGSInstanceCount: UInt32
    cControlPoints: UInt32
    HSOutputPrimitive: win32more.Windows.Win32.Graphics.Direct3D.D3D_TESSELLATOR_OUTPUT_PRIMITIVE
    HSPartitioning: win32more.Windows.Win32.Graphics.Direct3D.D3D_TESSELLATOR_PARTITIONING
    TessellatorDomain: win32more.Windows.Win32.Graphics.Direct3D.D3D_TESSELLATOR_DOMAIN
    cBarrierInstructions: UInt32
    cInterlockedInstructions: UInt32
    cTextureStoreInstructions: UInt32
class D3D11_SHADER_INPUT_BIND_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PSTR
    Type: win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_INPUT_TYPE
    BindPoint: UInt32
    BindCount: UInt32
    uFlags: UInt32
    ReturnType: win32more.Windows.Win32.Graphics.Direct3D.D3D_RESOURCE_RETURN_TYPE
    Dimension: win32more.Windows.Win32.Graphics.Direct3D.D3D_SRV_DIMENSION
    NumSamples: UInt32
D3D11_SHADER_MIN_PRECISION_SUPPORT = Int32
D3D11_SHADER_MIN_PRECISION_10_BIT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_MIN_PRECISION_SUPPORT = 1
D3D11_SHADER_MIN_PRECISION_16_BIT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_MIN_PRECISION_SUPPORT = 2
class D3D11_SHADER_RESOURCE_VIEW_DESC(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D.D3D_SRV_DIMENSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Buffer: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUFFER_SRV
        Texture1D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX1D_SRV
        Texture1DArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX1D_ARRAY_SRV
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_SRV
        Texture2DArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_ARRAY_SRV
        Texture2DMS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2DMS_SRV
        Texture2DMSArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2DMS_ARRAY_SRV
        Texture3D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX3D_SRV
        TextureCube: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXCUBE_SRV
        TextureCubeArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXCUBE_ARRAY_SRV
        BufferEx: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUFFEREX_SRV
class D3D11_SHADER_RESOURCE_VIEW_DESC1(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D.D3D_SRV_DIMENSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Buffer: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUFFER_SRV
        Texture1D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX1D_SRV
        Texture1DArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX1D_ARRAY_SRV
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_SRV1
        Texture2DArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_ARRAY_SRV1
        Texture2DMS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2DMS_SRV
        Texture2DMSArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2DMS_ARRAY_SRV
        Texture3D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX3D_SRV
        TextureCube: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXCUBE_SRV
        TextureCubeArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXCUBE_ARRAY_SRV
        BufferEx: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUFFEREX_SRV
class D3D11_SHADER_TRACE_DESC(Structure):
    Type: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TYPE
    Flags: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        VertexShaderTraceDesc: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VERTEX_SHADER_TRACE_DESC
        HullShaderTraceDesc: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_HULL_SHADER_TRACE_DESC
        DomainShaderTraceDesc: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DOMAIN_SHADER_TRACE_DESC
        GeometryShaderTraceDesc: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_GEOMETRY_SHADER_TRACE_DESC
        PixelShaderTraceDesc: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_PIXEL_SHADER_TRACE_DESC
        ComputeShaderTraceDesc: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COMPUTE_SHADER_TRACE_DESC
D3D11_SHADER_TRACKING_OPTIONS = Int32
D3D11_SHADER_TRACKING_OPTION_IGNORE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_OPTIONS = 0
D3D11_SHADER_TRACKING_OPTION_TRACK_UNINITIALIZED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_OPTIONS = 1
D3D11_SHADER_TRACKING_OPTION_TRACK_RAW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_OPTIONS = 2
D3D11_SHADER_TRACKING_OPTION_TRACK_WAR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_OPTIONS = 4
D3D11_SHADER_TRACKING_OPTION_TRACK_WAW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_OPTIONS = 8
D3D11_SHADER_TRACKING_OPTION_ALLOW_SAME: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_OPTIONS = 16
D3D11_SHADER_TRACKING_OPTION_TRACK_ATOMIC_CONSISTENCY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_OPTIONS = 32
D3D11_SHADER_TRACKING_OPTION_TRACK_RAW_ACROSS_THREADGROUPS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_OPTIONS = 64
D3D11_SHADER_TRACKING_OPTION_TRACK_WAR_ACROSS_THREADGROUPS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_OPTIONS = 128
D3D11_SHADER_TRACKING_OPTION_TRACK_WAW_ACROSS_THREADGROUPS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_OPTIONS = 256
D3D11_SHADER_TRACKING_OPTION_TRACK_ATOMIC_CONSISTENCY_ACROSS_THREADGROUPS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_OPTIONS = 512
D3D11_SHADER_TRACKING_OPTION_UAV_SPECIFIC_FLAGS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_OPTIONS = 960
D3D11_SHADER_TRACKING_OPTION_ALL_HAZARDS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_OPTIONS = 1006
D3D11_SHADER_TRACKING_OPTION_ALL_HAZARDS_ALLOWING_SAME: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_OPTIONS = 1022
D3D11_SHADER_TRACKING_OPTION_ALL_OPTIONS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_OPTIONS = 1023
D3D11_SHADER_TRACKING_RESOURCE_TYPE = Int32
D3D11_SHADER_TRACKING_RESOURCE_TYPE_NONE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_RESOURCE_TYPE = 0
D3D11_SHADER_TRACKING_RESOURCE_TYPE_UAV_DEVICEMEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_RESOURCE_TYPE = 1
D3D11_SHADER_TRACKING_RESOURCE_TYPE_NON_UAV_DEVICEMEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_RESOURCE_TYPE = 2
D3D11_SHADER_TRACKING_RESOURCE_TYPE_ALL_DEVICEMEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_RESOURCE_TYPE = 3
D3D11_SHADER_TRACKING_RESOURCE_TYPE_GROUPSHARED_MEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_RESOURCE_TYPE = 4
D3D11_SHADER_TRACKING_RESOURCE_TYPE_ALL_SHARED_MEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_RESOURCE_TYPE = 5
D3D11_SHADER_TRACKING_RESOURCE_TYPE_GROUPSHARED_NON_UAV: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_RESOURCE_TYPE = 6
D3D11_SHADER_TRACKING_RESOURCE_TYPE_ALL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACKING_RESOURCE_TYPE = 7
D3D11_SHADER_TYPE = Int32
D3D11_VERTEX_SHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TYPE = 1
D3D11_HULL_SHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TYPE = 2
D3D11_DOMAIN_SHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TYPE = 3
D3D11_GEOMETRY_SHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TYPE = 4
D3D11_PIXEL_SHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TYPE = 5
D3D11_COMPUTE_SHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TYPE = 6
class D3D11_SHADER_TYPE_DESC(Structure):
    Class: win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_VARIABLE_CLASS
    Type: win32more.Windows.Win32.Graphics.Direct3D.D3D_SHADER_VARIABLE_TYPE
    Rows: UInt32
    Columns: UInt32
    Elements: UInt32
    Members: UInt32
    Offset: UInt32
    Name: win32more.Windows.Win32.Foundation.PSTR
class D3D11_SHADER_VARIABLE_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PSTR
    StartOffset: UInt32
    Size: UInt32
    uFlags: UInt32
    DefaultValue: VoidPtr
    StartTexture: UInt32
    TextureSize: UInt32
    StartSampler: UInt32
    SamplerSize: UInt32
D3D11_SHADER_VERSION_TYPE = Int32
D3D11_SHVER_PIXEL_SHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_VERSION_TYPE = 0
D3D11_SHVER_VERTEX_SHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_VERSION_TYPE = 1
D3D11_SHVER_GEOMETRY_SHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_VERSION_TYPE = 2
D3D11_SHVER_HULL_SHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_VERSION_TYPE = 3
D3D11_SHVER_DOMAIN_SHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_VERSION_TYPE = 4
D3D11_SHVER_COMPUTE_SHADER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_VERSION_TYPE = 5
D3D11_SHVER_RESERVED0: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_VERSION_TYPE = 65520
D3D11_SHARED_RESOURCE_TIER = Int32
D3D11_SHARED_RESOURCE_TIER_0: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHARED_RESOURCE_TIER = 0
D3D11_SHARED_RESOURCE_TIER_1: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHARED_RESOURCE_TIER = 1
D3D11_SHARED_RESOURCE_TIER_2: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHARED_RESOURCE_TIER = 2
D3D11_SHARED_RESOURCE_TIER_3: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHARED_RESOURCE_TIER = 3
class D3D11_SIGNATURE_PARAMETER_DESC(Structure):
    SemanticName: win32more.Windows.Win32.Foundation.PSTR
    SemanticIndex: UInt32
    Register: UInt32
    SystemValueType: win32more.Windows.Win32.Graphics.Direct3D.D3D_NAME
    ComponentType: win32more.Windows.Win32.Graphics.Direct3D.D3D_REGISTER_COMPONENT_TYPE
    Mask: Byte
    ReadWriteMask: Byte
    Stream: UInt32
    MinPrecision: win32more.Windows.Win32.Graphics.Direct3D.D3D_MIN_PRECISION
class D3D11_SO_DECLARATION_ENTRY(Structure):
    Stream: UInt32
    SemanticName: win32more.Windows.Win32.Foundation.PSTR
    SemanticIndex: UInt32
    StartComponent: Byte
    ComponentCount: Byte
    OutputSlot: Byte
D3D11_STANDARD_MULTISAMPLE_QUALITY_LEVELS = Int32
D3D11_STANDARD_MULTISAMPLE_PATTERN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_STANDARD_MULTISAMPLE_QUALITY_LEVELS = -1
D3D11_CENTER_MULTISAMPLE_PATTERN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_STANDARD_MULTISAMPLE_QUALITY_LEVELS = -2
D3D11_STENCIL_OP = Int32
D3D11_STENCIL_OP_KEEP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_STENCIL_OP = 1
D3D11_STENCIL_OP_ZERO: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_STENCIL_OP = 2
D3D11_STENCIL_OP_REPLACE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_STENCIL_OP = 3
D3D11_STENCIL_OP_INCR_SAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_STENCIL_OP = 4
D3D11_STENCIL_OP_DECR_SAT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_STENCIL_OP = 5
D3D11_STENCIL_OP_INVERT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_STENCIL_OP = 6
D3D11_STENCIL_OP_INCR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_STENCIL_OP = 7
D3D11_STENCIL_OP_DECR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_STENCIL_OP = 8
class D3D11_SUBRESOURCE_DATA(Structure):
    pSysMem: VoidPtr
    SysMemPitch: UInt32
    SysMemSlicePitch: UInt32
class D3D11_SUBRESOURCE_TILING(Structure):
    WidthInTiles: UInt32
    HeightInTiles: UInt16
    DepthInTiles: UInt16
    StartTileIndexInOverallResource: UInt32
class D3D11_TEX1D_ARRAY_DSV(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D11_TEX1D_ARRAY_RTV(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D11_TEX1D_ARRAY_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D11_TEX1D_ARRAY_UAV(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D11_TEX1D_DSV(Structure):
    MipSlice: UInt32
class D3D11_TEX1D_RTV(Structure):
    MipSlice: UInt32
class D3D11_TEX1D_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
class D3D11_TEX1D_UAV(Structure):
    MipSlice: UInt32
class D3D11_TEX2DMS_ARRAY_DSV(Structure):
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D11_TEX2DMS_ARRAY_RTV(Structure):
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D11_TEX2DMS_ARRAY_SRV(Structure):
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D11_TEX2DMS_DSV(Structure):
    UnusedField_NothingToDefine: UInt32
class D3D11_TEX2DMS_RTV(Structure):
    UnusedField_NothingToDefine: UInt32
class D3D11_TEX2DMS_SRV(Structure):
    UnusedField_NothingToDefine: UInt32
class D3D11_TEX2D_ARRAY_DSV(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D11_TEX2D_ARRAY_RTV(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D11_TEX2D_ARRAY_RTV1(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
    PlaneSlice: UInt32
class D3D11_TEX2D_ARRAY_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D11_TEX2D_ARRAY_SRV1(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
    PlaneSlice: UInt32
class D3D11_TEX2D_ARRAY_UAV(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D11_TEX2D_ARRAY_UAV1(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
    PlaneSlice: UInt32
class D3D11_TEX2D_ARRAY_VPOV(Structure):
    MipSlice: UInt32
    FirstArraySlice: UInt32
    ArraySize: UInt32
class D3D11_TEX2D_DSV(Structure):
    MipSlice: UInt32
class D3D11_TEX2D_RTV(Structure):
    MipSlice: UInt32
class D3D11_TEX2D_RTV1(Structure):
    MipSlice: UInt32
    PlaneSlice: UInt32
class D3D11_TEX2D_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
class D3D11_TEX2D_SRV1(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
    PlaneSlice: UInt32
class D3D11_TEX2D_UAV(Structure):
    MipSlice: UInt32
class D3D11_TEX2D_UAV1(Structure):
    MipSlice: UInt32
    PlaneSlice: UInt32
class D3D11_TEX2D_VDOV(Structure):
    ArraySlice: UInt32
class D3D11_TEX2D_VPIV(Structure):
    MipSlice: UInt32
    ArraySlice: UInt32
class D3D11_TEX2D_VPOV(Structure):
    MipSlice: UInt32
class D3D11_TEX3D_RTV(Structure):
    MipSlice: UInt32
    FirstWSlice: UInt32
    WSize: UInt32
class D3D11_TEX3D_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
class D3D11_TEX3D_UAV(Structure):
    MipSlice: UInt32
    FirstWSlice: UInt32
    WSize: UInt32
class D3D11_TEXCUBE_ARRAY_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
    First2DArrayFace: UInt32
    NumCubes: UInt32
class D3D11_TEXCUBE_SRV(Structure):
    MostDetailedMip: UInt32
    MipLevels: UInt32
class D3D11_TEXTURE1D_DESC(Structure):
    Width: UInt32
    MipLevels: UInt32
    ArraySize: UInt32
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    Usage: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_USAGE
    BindFlags: UInt32
    CPUAccessFlags: UInt32
    MiscFlags: UInt32
class D3D11_TEXTURE2D_DESC(Structure):
    Width: UInt32
    Height: UInt32
    MipLevels: UInt32
    ArraySize: UInt32
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    SampleDesc: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_SAMPLE_DESC
    Usage: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_USAGE
    BindFlags: UInt32
    CPUAccessFlags: UInt32
    MiscFlags: UInt32
class D3D11_TEXTURE2D_DESC1(Structure):
    Width: UInt32
    Height: UInt32
    MipLevels: UInt32
    ArraySize: UInt32
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    SampleDesc: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_SAMPLE_DESC
    Usage: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_USAGE
    BindFlags: UInt32
    CPUAccessFlags: UInt32
    MiscFlags: UInt32
    TextureLayout: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE_LAYOUT
class D3D11_TEXTURE3D_DESC(Structure):
    Width: UInt32
    Height: UInt32
    Depth: UInt32
    MipLevels: UInt32
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    Usage: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_USAGE
    BindFlags: UInt32
    CPUAccessFlags: UInt32
    MiscFlags: UInt32
class D3D11_TEXTURE3D_DESC1(Structure):
    Width: UInt32
    Height: UInt32
    Depth: UInt32
    MipLevels: UInt32
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    Usage: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_USAGE
    BindFlags: UInt32
    CPUAccessFlags: UInt32
    MiscFlags: UInt32
    TextureLayout: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE_LAYOUT
D3D11_TEXTURECUBE_FACE = Int32
D3D11_TEXTURECUBE_FACE_POSITIVE_X: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURECUBE_FACE = 0
D3D11_TEXTURECUBE_FACE_NEGATIVE_X: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURECUBE_FACE = 1
D3D11_TEXTURECUBE_FACE_POSITIVE_Y: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURECUBE_FACE = 2
D3D11_TEXTURECUBE_FACE_NEGATIVE_Y: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURECUBE_FACE = 3
D3D11_TEXTURECUBE_FACE_POSITIVE_Z: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURECUBE_FACE = 4
D3D11_TEXTURECUBE_FACE_NEGATIVE_Z: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURECUBE_FACE = 5
D3D11_TEXTURE_ADDRESS_MODE = Int32
D3D11_TEXTURE_ADDRESS_WRAP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE_ADDRESS_MODE = 1
D3D11_TEXTURE_ADDRESS_MIRROR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE_ADDRESS_MODE = 2
D3D11_TEXTURE_ADDRESS_CLAMP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE_ADDRESS_MODE = 3
D3D11_TEXTURE_ADDRESS_BORDER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE_ADDRESS_MODE = 4
D3D11_TEXTURE_ADDRESS_MIRROR_ONCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE_ADDRESS_MODE = 5
D3D11_TEXTURE_LAYOUT = Int32
D3D11_TEXTURE_LAYOUT_UNDEFINED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE_LAYOUT = 0
D3D11_TEXTURE_LAYOUT_ROW_MAJOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE_LAYOUT = 1
D3D11_TEXTURE_LAYOUT_64K_STANDARD_SWIZZLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE_LAYOUT = 2
D3D11_TILED_RESOURCES_TIER = Int32
D3D11_TILED_RESOURCES_NOT_SUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILED_RESOURCES_TIER = 0
D3D11_TILED_RESOURCES_TIER_1: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILED_RESOURCES_TIER = 1
D3D11_TILED_RESOURCES_TIER_2: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILED_RESOURCES_TIER = 2
D3D11_TILED_RESOURCES_TIER_3: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILED_RESOURCES_TIER = 3
class D3D11_TILED_RESOURCE_COORDINATE(Structure):
    X: UInt32
    Y: UInt32
    Z: UInt32
    Subresource: UInt32
D3D11_TILE_COPY_FLAG = Int32
D3D11_TILE_COPY_NO_OVERWRITE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILE_COPY_FLAG = 1
D3D11_TILE_COPY_LINEAR_BUFFER_TO_SWIZZLED_TILED_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILE_COPY_FLAG = 2
D3D11_TILE_COPY_SWIZZLED_TILED_RESOURCE_TO_LINEAR_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILE_COPY_FLAG = 4
D3D11_TILE_MAPPING_FLAG = Int32
D3D11_TILE_MAPPING_NO_OVERWRITE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILE_MAPPING_FLAG = 1
D3D11_TILE_RANGE_FLAG = Int32
D3D11_TILE_RANGE_NULL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILE_RANGE_FLAG = 1
D3D11_TILE_RANGE_SKIP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILE_RANGE_FLAG = 2
D3D11_TILE_RANGE_REUSE_SINGLE_TILE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILE_RANGE_FLAG = 4
class D3D11_TILE_REGION_SIZE(Structure):
    NumTiles: UInt32
    bUseBox: win32more.Windows.Win32.Foundation.BOOL
    Width: UInt32
    Height: UInt16
    Depth: UInt16
class D3D11_TILE_SHAPE(Structure):
    WidthInTexels: UInt32
    HeightInTexels: UInt32
    DepthInTexels: UInt32
D3D11_TRACE_GS_INPUT_PRIMITIVE = Int32
D3D11_TRACE_GS_INPUT_PRIMITIVE_UNDEFINED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_GS_INPUT_PRIMITIVE = 0
D3D11_TRACE_GS_INPUT_PRIMITIVE_POINT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_GS_INPUT_PRIMITIVE = 1
D3D11_TRACE_GS_INPUT_PRIMITIVE_LINE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_GS_INPUT_PRIMITIVE = 2
D3D11_TRACE_GS_INPUT_PRIMITIVE_TRIANGLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_GS_INPUT_PRIMITIVE = 3
D3D11_TRACE_GS_INPUT_PRIMITIVE_LINE_ADJ: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_GS_INPUT_PRIMITIVE = 6
D3D11_TRACE_GS_INPUT_PRIMITIVE_TRIANGLE_ADJ: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_GS_INPUT_PRIMITIVE = 7
class D3D11_TRACE_REGISTER(Structure):
    RegType: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE
    Anonymous: _Anonymous_e__Union
    OperandIndex: Byte
    Flags: Byte
    class _Anonymous_e__Union(Union):
        Index1D: UInt16
        Index2D: UInt16 * 2
D3D11_TRACE_REGISTER_TYPE = Int32
D3D11_TRACE_OUTPUT_NULL_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 0
D3D11_TRACE_INPUT_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 1
D3D11_TRACE_INPUT_PRIMITIVE_ID_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 2
D3D11_TRACE_IMMEDIATE_CONSTANT_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 3
D3D11_TRACE_TEMP_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 4
D3D11_TRACE_INDEXABLE_TEMP_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 5
D3D11_TRACE_OUTPUT_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 6
D3D11_TRACE_OUTPUT_DEPTH_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 7
D3D11_TRACE_CONSTANT_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 8
D3D11_TRACE_IMMEDIATE32: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 9
D3D11_TRACE_SAMPLER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 10
D3D11_TRACE_RESOURCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 11
D3D11_TRACE_RASTERIZER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 12
D3D11_TRACE_OUTPUT_COVERAGE_MASK: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 13
D3D11_TRACE_STREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 14
D3D11_TRACE_THIS_POINTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 15
D3D11_TRACE_OUTPUT_CONTROL_POINT_ID_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 16
D3D11_TRACE_INPUT_FORK_INSTANCE_ID_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 17
D3D11_TRACE_INPUT_JOIN_INSTANCE_ID_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 18
D3D11_TRACE_INPUT_CONTROL_POINT_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 19
D3D11_TRACE_OUTPUT_CONTROL_POINT_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 20
D3D11_TRACE_INPUT_PATCH_CONSTANT_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 21
D3D11_TRACE_INPUT_DOMAIN_POINT_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 22
D3D11_TRACE_UNORDERED_ACCESS_VIEW: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 23
D3D11_TRACE_THREAD_GROUP_SHARED_MEMORY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 24
D3D11_TRACE_INPUT_THREAD_ID_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 25
D3D11_TRACE_INPUT_THREAD_GROUP_ID_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 26
D3D11_TRACE_INPUT_THREAD_ID_IN_GROUP_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 27
D3D11_TRACE_INPUT_COVERAGE_MASK_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 28
D3D11_TRACE_INPUT_THREAD_ID_IN_GROUP_FLATTENED_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 29
D3D11_TRACE_INPUT_GS_INSTANCE_ID_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 30
D3D11_TRACE_OUTPUT_DEPTH_GREATER_EQUAL_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 31
D3D11_TRACE_OUTPUT_DEPTH_LESS_EQUAL_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 32
D3D11_TRACE_IMMEDIATE64: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 33
D3D11_TRACE_INPUT_CYCLE_COUNTER_REGISTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 34
D3D11_TRACE_INTERFACE_POINTER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER_TYPE = 35
class D3D11_TRACE_STATS(Structure):
    TraceDesc: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACE_DESC
    NumInvocationsInStamp: Byte
    TargetStampIndex: Byte
    NumTraceSteps: UInt32
    InputMask: Byte * 32
    OutputMask: Byte * 32
    NumTemps: UInt16
    MaxIndexableTempIndex: UInt16
    IndexableTempSize: UInt16 * 4096
    ImmediateConstantBufferSize: UInt16
    PixelPosition: UInt32 * 8
    PixelCoverageMask: UInt64 * 4
    PixelDiscardedMask: UInt64 * 4
    PixelCoverageMaskAfterShader: UInt64 * 4
    PixelCoverageMaskAfterA2CSampleMask: UInt64 * 4
    PixelCoverageMaskAfterA2CSampleMaskDepth: UInt64 * 4
    PixelCoverageMaskAfterA2CSampleMaskDepthStencil: UInt64 * 4
    PSOutputsDepth: win32more.Windows.Win32.Foundation.BOOL
    PSOutputsMask: win32more.Windows.Win32.Foundation.BOOL
    GSInputPrimitive: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_GS_INPUT_PRIMITIVE
    GSInputsPrimitiveID: win32more.Windows.Win32.Foundation.BOOL
    HSOutputPatchConstantMask: Byte * 32
    DSInputPatchConstantMask: Byte * 32
class D3D11_TRACE_STEP(Structure):
    ID: UInt32
    InstructionActive: win32more.Windows.Win32.Foundation.BOOL
    NumRegistersWritten: Byte
    NumRegistersRead: Byte
    MiscOperations: UInt16
    OpcodeType: UInt32
    CurrentGlobalCycle: UInt64
class D3D11_TRACE_VALUE(Structure):
    Bits: UInt32 * 4
    ValidMask: Byte
D3D11_UAV_DIMENSION = Int32
D3D11_UAV_DIMENSION_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_UAV_DIMENSION = 0
D3D11_UAV_DIMENSION_BUFFER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_UAV_DIMENSION = 1
D3D11_UAV_DIMENSION_TEXTURE1D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_UAV_DIMENSION = 2
D3D11_UAV_DIMENSION_TEXTURE1DARRAY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_UAV_DIMENSION = 3
D3D11_UAV_DIMENSION_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_UAV_DIMENSION = 4
D3D11_UAV_DIMENSION_TEXTURE2DARRAY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_UAV_DIMENSION = 5
D3D11_UAV_DIMENSION_TEXTURE3D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_UAV_DIMENSION = 8
class D3D11_UNORDERED_ACCESS_VIEW_DESC(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_UAV_DIMENSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Buffer: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUFFER_UAV
        Texture1D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX1D_UAV
        Texture1DArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX1D_ARRAY_UAV
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_UAV
        Texture2DArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_ARRAY_UAV
        Texture3D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX3D_UAV
class D3D11_UNORDERED_ACCESS_VIEW_DESC1(Structure):
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_UAV_DIMENSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Buffer: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUFFER_UAV
        Texture1D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX1D_UAV
        Texture1DArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX1D_ARRAY_UAV
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_UAV1
        Texture2DArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_ARRAY_UAV1
        Texture3D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX3D_UAV
D3D11_USAGE = Int32
D3D11_USAGE_DEFAULT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_USAGE = 0
D3D11_USAGE_IMMUTABLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_USAGE = 1
D3D11_USAGE_DYNAMIC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_USAGE = 2
D3D11_USAGE_STAGING: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_USAGE = 3
D3D11_VDOV_DIMENSION = Int32
D3D11_VDOV_DIMENSION_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VDOV_DIMENSION = 0
D3D11_VDOV_DIMENSION_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VDOV_DIMENSION = 1
class D3D11_VERTEX_SHADER_TRACE_DESC(Structure):
    Invocation: UInt64
class D3D11_VIDEO_COLOR(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        YCbCr: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_COLOR_YCbCrA
        RGBA: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_COLOR_RGBA
class D3D11_VIDEO_COLOR_RGBA(Structure):
    R: Single
    G: Single
    B: Single
    A: Single
class D3D11_VIDEO_COLOR_YCbCrA(Structure):
    Y: Single
    Cb: Single
    Cr: Single
    A: Single
class D3D11_VIDEO_CONTENT_PROTECTION_CAPS(Structure):
    Caps: UInt32
    KeyExchangeTypeCount: UInt32
    BlockAlignmentSize: UInt32
    ProtectedMemorySize: UInt64
class D3D11_VIDEO_DECODER_BEGIN_FRAME_CRYPTO_SESSION(Structure):
    pCryptoSession: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11CryptoSession
    BlobSize: UInt32
    pBlob: VoidPtr
    pKeyInfoId: POINTER(Guid)
    PrivateDataSize: UInt32
    pPrivateData: VoidPtr
class D3D11_VIDEO_DECODER_BUFFER_DESC(Structure):
    BufferType: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_BUFFER_TYPE
    BufferIndex: UInt32
    DataOffset: UInt32
    DataSize: UInt32
    FirstMBaddress: UInt32
    NumMBsInBuffer: UInt32
    Width: UInt32
    Height: UInt32
    Stride: UInt32
    ReservedBits: UInt32
    pIV: VoidPtr
    IVSize: UInt32
    PartialEncryption: win32more.Windows.Win32.Foundation.BOOL
    EncryptedBlockInfo: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_ENCRYPTED_BLOCK_INFO
class D3D11_VIDEO_DECODER_BUFFER_DESC1(Structure):
    BufferType: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_BUFFER_TYPE
    DataOffset: UInt32
    DataSize: UInt32
    pIV: VoidPtr
    IVSize: UInt32
    pSubSampleMappingBlock: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_SUB_SAMPLE_MAPPING_BLOCK)
    SubSampleMappingCount: UInt32
class D3D11_VIDEO_DECODER_BUFFER_DESC2(Structure):
    BufferType: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_BUFFER_TYPE
    DataOffset: UInt32
    DataSize: UInt32
    pIV: VoidPtr
    IVSize: UInt32
    pSubSampleMappingBlock: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_SUB_SAMPLE_MAPPING_BLOCK)
    SubSampleMappingCount: UInt32
    cBlocksStripeEncrypted: UInt32
    cBlocksStripeClear: UInt32
D3D11_VIDEO_DECODER_BUFFER_TYPE = Int32
D3D11_VIDEO_DECODER_BUFFER_PICTURE_PARAMETERS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_BUFFER_TYPE = 0
D3D11_VIDEO_DECODER_BUFFER_MACROBLOCK_CONTROL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_BUFFER_TYPE = 1
D3D11_VIDEO_DECODER_BUFFER_RESIDUAL_DIFFERENCE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_BUFFER_TYPE = 2
D3D11_VIDEO_DECODER_BUFFER_DEBLOCKING_CONTROL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_BUFFER_TYPE = 3
D3D11_VIDEO_DECODER_BUFFER_INVERSE_QUANTIZATION_MATRIX: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_BUFFER_TYPE = 4
D3D11_VIDEO_DECODER_BUFFER_SLICE_CONTROL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_BUFFER_TYPE = 5
D3D11_VIDEO_DECODER_BUFFER_BITSTREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_BUFFER_TYPE = 6
D3D11_VIDEO_DECODER_BUFFER_MOTION_VECTOR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_BUFFER_TYPE = 7
D3D11_VIDEO_DECODER_BUFFER_FILM_GRAIN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_BUFFER_TYPE = 8
D3D11_VIDEO_DECODER_CAPS = Int32
D3D11_VIDEO_DECODER_CAPS_DOWNSAMPLE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_CAPS = 1
D3D11_VIDEO_DECODER_CAPS_NON_REAL_TIME: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_CAPS = 2
D3D11_VIDEO_DECODER_CAPS_DOWNSAMPLE_DYNAMIC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_CAPS = 4
D3D11_VIDEO_DECODER_CAPS_DOWNSAMPLE_REQUIRED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_CAPS = 8
D3D11_VIDEO_DECODER_CAPS_UNSUPPORTED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_CAPS = 16
class D3D11_VIDEO_DECODER_CONFIG(Structure):
    guidConfigBitstreamEncryption: Guid
    guidConfigMBcontrolEncryption: Guid
    guidConfigResidDiffEncryption: Guid
    ConfigBitstreamRaw: UInt32
    ConfigMBcontrolRasterOrder: UInt32
    ConfigResidDiffHost: UInt32
    ConfigSpatialResid8: UInt32
    ConfigResid8Subtraction: UInt32
    ConfigSpatialHost8or9Clipping: UInt32
    ConfigSpatialResidInterleaved: UInt32
    ConfigIntraResidUnsigned: UInt32
    ConfigResidDiffAccelerator: UInt32
    ConfigHostInverseScan: UInt32
    ConfigSpecificIDCT: UInt32
    Config4GroupedCoefs: UInt32
    ConfigMinRenderTargetBuffCount: UInt16
    ConfigDecoderSpecific: UInt16
class D3D11_VIDEO_DECODER_DESC(Structure):
    Guid: Guid
    SampleWidth: UInt32
    SampleHeight: UInt32
    OutputFormat: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
class D3D11_VIDEO_DECODER_EXTENSION(Structure):
    Function: UInt32
    pPrivateInputData: VoidPtr
    PrivateInputDataSize: UInt32
    pPrivateOutputData: VoidPtr
    PrivateOutputDataSize: UInt32
    ResourceCount: UInt32
    ppResourceList: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource)
D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT = Int32
D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_Y: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT = 0
D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_U: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT = 1
D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_V: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT = 2
D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_R: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT = 0
D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_G: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT = 1
D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_B: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT = 2
D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_A: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT = 3
D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAGS = Int32
D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAG_NONE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAGS = 0
D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAG_Y: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAGS = 1
D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAG_U: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAGS = 2
D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAG_V: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAGS = 4
D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAG_R: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAGS = 1
D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAG_G: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAGS = 2
D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAG_B: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAGS = 4
D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAG_A: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_HISTOGRAM_COMPONENT_FLAGS = 8
class D3D11_VIDEO_DECODER_OUTPUT_VIEW_DESC(Structure):
    DecodeProfile: Guid
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VDOV_DIMENSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_VDOV
class D3D11_VIDEO_DECODER_SUB_SAMPLE_MAPPING_BLOCK(Structure):
    ClearSize: UInt32
    EncryptedSize: UInt32
D3D11_VIDEO_FRAME_FORMAT = Int32
D3D11_VIDEO_FRAME_FORMAT_PROGRESSIVE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_FRAME_FORMAT = 0
D3D11_VIDEO_FRAME_FORMAT_INTERLACED_TOP_FIELD_FIRST: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_FRAME_FORMAT = 1
D3D11_VIDEO_FRAME_FORMAT_INTERLACED_BOTTOM_FIELD_FIRST: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_FRAME_FORMAT = 2
D3D11_VIDEO_PROCESSOR_ALPHA_FILL_MODE = Int32
D3D11_VIDEO_PROCESSOR_ALPHA_FILL_MODE_OPAQUE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ALPHA_FILL_MODE = 0
D3D11_VIDEO_PROCESSOR_ALPHA_FILL_MODE_BACKGROUND: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ALPHA_FILL_MODE = 1
D3D11_VIDEO_PROCESSOR_ALPHA_FILL_MODE_DESTINATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ALPHA_FILL_MODE = 2
D3D11_VIDEO_PROCESSOR_ALPHA_FILL_MODE_SOURCE_STREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ALPHA_FILL_MODE = 3
D3D11_VIDEO_PROCESSOR_AUTO_STREAM_CAPS = Int32
D3D11_VIDEO_PROCESSOR_AUTO_STREAM_CAPS_DENOISE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_AUTO_STREAM_CAPS = 1
D3D11_VIDEO_PROCESSOR_AUTO_STREAM_CAPS_DERINGING: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_AUTO_STREAM_CAPS = 2
D3D11_VIDEO_PROCESSOR_AUTO_STREAM_CAPS_EDGE_ENHANCEMENT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_AUTO_STREAM_CAPS = 4
D3D11_VIDEO_PROCESSOR_AUTO_STREAM_CAPS_COLOR_CORRECTION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_AUTO_STREAM_CAPS = 8
D3D11_VIDEO_PROCESSOR_AUTO_STREAM_CAPS_FLESH_TONE_MAPPING: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_AUTO_STREAM_CAPS = 16
D3D11_VIDEO_PROCESSOR_AUTO_STREAM_CAPS_IMAGE_STABILIZATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_AUTO_STREAM_CAPS = 32
D3D11_VIDEO_PROCESSOR_AUTO_STREAM_CAPS_SUPER_RESOLUTION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_AUTO_STREAM_CAPS = 64
D3D11_VIDEO_PROCESSOR_AUTO_STREAM_CAPS_ANAMORPHIC_SCALING: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_AUTO_STREAM_CAPS = 128
D3D11_VIDEO_PROCESSOR_BEHAVIOR_HINTS = Int32
D3D11_VIDEO_PROCESSOR_BEHAVIOR_HINT_MULTIPLANE_OVERLAY_ROTATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_BEHAVIOR_HINTS = 1
D3D11_VIDEO_PROCESSOR_BEHAVIOR_HINT_MULTIPLANE_OVERLAY_RESIZE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_BEHAVIOR_HINTS = 2
D3D11_VIDEO_PROCESSOR_BEHAVIOR_HINT_MULTIPLANE_OVERLAY_COLOR_SPACE_CONVERSION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_BEHAVIOR_HINTS = 4
D3D11_VIDEO_PROCESSOR_BEHAVIOR_HINT_TRIPLE_BUFFER_OUTPUT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_BEHAVIOR_HINTS = 8
class D3D11_VIDEO_PROCESSOR_CAPS(Structure):
    DeviceCaps: UInt32
    FeatureCaps: UInt32
    FilterCaps: UInt32
    InputFormatCaps: UInt32
    AutoStreamCaps: UInt32
    StereoCaps: UInt32
    RateConversionCapsCount: UInt32
    MaxInputStreams: UInt32
    MaxStreamStates: UInt32
class D3D11_VIDEO_PROCESSOR_COLOR_SPACE(Structure):
    Usage: Annotated[UInt32, 1]
    RGB_Range: Annotated[UInt32, 1]
    YCbCr_Matrix: Annotated[UInt32, 1]
    YCbCr_xvYCC: Annotated[UInt32, 1]
    Nominal_Range: Annotated[UInt32, 2]
    Reserved: Annotated[UInt32, 26]
class D3D11_VIDEO_PROCESSOR_CONTENT_DESC(Structure):
    InputFrameFormat: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_FRAME_FORMAT
    InputFrameRate: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_RATIONAL
    InputWidth: UInt32
    InputHeight: UInt32
    OutputFrameRate: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_RATIONAL
    OutputWidth: UInt32
    OutputHeight: UInt32
    Usage: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_USAGE
class D3D11_VIDEO_PROCESSOR_CUSTOM_RATE(Structure):
    CustomRate: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_RATIONAL
    OutputFrames: UInt32
    InputInterlaced: win32more.Windows.Win32.Foundation.BOOL
    InputFramesOrFields: UInt32
D3D11_VIDEO_PROCESSOR_DEVICE_CAPS = Int32
D3D11_VIDEO_PROCESSOR_DEVICE_CAPS_LINEAR_SPACE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_DEVICE_CAPS = 1
D3D11_VIDEO_PROCESSOR_DEVICE_CAPS_xvYCC: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_DEVICE_CAPS = 2
D3D11_VIDEO_PROCESSOR_DEVICE_CAPS_RGB_RANGE_CONVERSION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_DEVICE_CAPS = 4
D3D11_VIDEO_PROCESSOR_DEVICE_CAPS_YCbCr_MATRIX_CONVERSION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_DEVICE_CAPS = 8
D3D11_VIDEO_PROCESSOR_DEVICE_CAPS_NOMINAL_RANGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_DEVICE_CAPS = 16
D3D11_VIDEO_PROCESSOR_FEATURE_CAPS = Int32
D3D11_VIDEO_PROCESSOR_FEATURE_CAPS_ALPHA_FILL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FEATURE_CAPS = 1
D3D11_VIDEO_PROCESSOR_FEATURE_CAPS_CONSTRICTION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FEATURE_CAPS = 2
D3D11_VIDEO_PROCESSOR_FEATURE_CAPS_LUMA_KEY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FEATURE_CAPS = 4
D3D11_VIDEO_PROCESSOR_FEATURE_CAPS_ALPHA_PALETTE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FEATURE_CAPS = 8
D3D11_VIDEO_PROCESSOR_FEATURE_CAPS_LEGACY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FEATURE_CAPS = 16
D3D11_VIDEO_PROCESSOR_FEATURE_CAPS_STEREO: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FEATURE_CAPS = 32
D3D11_VIDEO_PROCESSOR_FEATURE_CAPS_ROTATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FEATURE_CAPS = 64
D3D11_VIDEO_PROCESSOR_FEATURE_CAPS_ALPHA_STREAM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FEATURE_CAPS = 128
D3D11_VIDEO_PROCESSOR_FEATURE_CAPS_PIXEL_ASPECT_RATIO: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FEATURE_CAPS = 256
D3D11_VIDEO_PROCESSOR_FEATURE_CAPS_MIRROR: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FEATURE_CAPS = 512
D3D11_VIDEO_PROCESSOR_FEATURE_CAPS_SHADER_USAGE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FEATURE_CAPS = 1024
D3D11_VIDEO_PROCESSOR_FEATURE_CAPS_METADATA_HDR10: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FEATURE_CAPS = 2048
D3D11_VIDEO_PROCESSOR_FILTER = Int32
D3D11_VIDEO_PROCESSOR_FILTER_BRIGHTNESS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER = 0
D3D11_VIDEO_PROCESSOR_FILTER_CONTRAST: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER = 1
D3D11_VIDEO_PROCESSOR_FILTER_HUE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER = 2
D3D11_VIDEO_PROCESSOR_FILTER_SATURATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER = 3
D3D11_VIDEO_PROCESSOR_FILTER_NOISE_REDUCTION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER = 4
D3D11_VIDEO_PROCESSOR_FILTER_EDGE_ENHANCEMENT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER = 5
D3D11_VIDEO_PROCESSOR_FILTER_ANAMORPHIC_SCALING: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER = 6
D3D11_VIDEO_PROCESSOR_FILTER_STEREO_ADJUSTMENT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER = 7
D3D11_VIDEO_PROCESSOR_FILTER_CAPS = Int32
D3D11_VIDEO_PROCESSOR_FILTER_CAPS_BRIGHTNESS: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER_CAPS = 1
D3D11_VIDEO_PROCESSOR_FILTER_CAPS_CONTRAST: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER_CAPS = 2
D3D11_VIDEO_PROCESSOR_FILTER_CAPS_HUE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER_CAPS = 4
D3D11_VIDEO_PROCESSOR_FILTER_CAPS_SATURATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER_CAPS = 8
D3D11_VIDEO_PROCESSOR_FILTER_CAPS_NOISE_REDUCTION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER_CAPS = 16
D3D11_VIDEO_PROCESSOR_FILTER_CAPS_EDGE_ENHANCEMENT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER_CAPS = 32
D3D11_VIDEO_PROCESSOR_FILTER_CAPS_ANAMORPHIC_SCALING: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER_CAPS = 64
D3D11_VIDEO_PROCESSOR_FILTER_CAPS_STEREO_ADJUSTMENT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER_CAPS = 128
class D3D11_VIDEO_PROCESSOR_FILTER_RANGE(Structure):
    Minimum: Int32
    Maximum: Int32
    Default: Int32
    Multiplier: Single
D3D11_VIDEO_PROCESSOR_FORMAT_CAPS = Int32
D3D11_VIDEO_PROCESSOR_FORMAT_CAPS_RGB_INTERLACED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FORMAT_CAPS = 1
D3D11_VIDEO_PROCESSOR_FORMAT_CAPS_RGB_PROCAMP: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FORMAT_CAPS = 2
D3D11_VIDEO_PROCESSOR_FORMAT_CAPS_RGB_LUMA_KEY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FORMAT_CAPS = 4
D3D11_VIDEO_PROCESSOR_FORMAT_CAPS_PALETTE_INTERLACED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FORMAT_CAPS = 8
D3D11_VIDEO_PROCESSOR_FORMAT_SUPPORT = Int32
D3D11_VIDEO_PROCESSOR_FORMAT_SUPPORT_INPUT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FORMAT_SUPPORT = 1
D3D11_VIDEO_PROCESSOR_FORMAT_SUPPORT_OUTPUT: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FORMAT_SUPPORT = 2
class D3D11_VIDEO_PROCESSOR_INPUT_VIEW_DESC(Structure):
    FourCC: UInt32
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VPIV_DIMENSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_VPIV
D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS = Int32
D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS_32: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS = 1
D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS_22: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS = 2
D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS_2224: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS = 4
D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS_2332: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS = 8
D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS_32322: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS = 16
D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS_55: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS = 32
D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS_64: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS = 64
D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS_87: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS = 128
D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS_222222222223: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS = 256
D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS_OTHER: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ITELECINE_CAPS = -2147483648
D3D11_VIDEO_PROCESSOR_NOMINAL_RANGE = Int32
D3D11_VIDEO_PROCESSOR_NOMINAL_RANGE_UNDEFINED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_NOMINAL_RANGE = 0
D3D11_VIDEO_PROCESSOR_NOMINAL_RANGE_16_235: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_NOMINAL_RANGE = 1
D3D11_VIDEO_PROCESSOR_NOMINAL_RANGE_0_255: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_NOMINAL_RANGE = 2
D3D11_VIDEO_PROCESSOR_OUTPUT_RATE = Int32
D3D11_VIDEO_PROCESSOR_OUTPUT_RATE_NORMAL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_OUTPUT_RATE = 0
D3D11_VIDEO_PROCESSOR_OUTPUT_RATE_HALF: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_OUTPUT_RATE = 1
D3D11_VIDEO_PROCESSOR_OUTPUT_RATE_CUSTOM: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_OUTPUT_RATE = 2
class D3D11_VIDEO_PROCESSOR_OUTPUT_VIEW_DESC(Structure):
    ViewDimension: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VPOV_DIMENSION
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Texture2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_VPOV
        Texture2DArray: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEX2D_ARRAY_VPOV
D3D11_VIDEO_PROCESSOR_PROCESSOR_CAPS = Int32
D3D11_VIDEO_PROCESSOR_PROCESSOR_CAPS_DEINTERLACE_BLEND: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_PROCESSOR_CAPS = 1
D3D11_VIDEO_PROCESSOR_PROCESSOR_CAPS_DEINTERLACE_BOB: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_PROCESSOR_CAPS = 2
D3D11_VIDEO_PROCESSOR_PROCESSOR_CAPS_DEINTERLACE_ADAPTIVE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_PROCESSOR_CAPS = 4
D3D11_VIDEO_PROCESSOR_PROCESSOR_CAPS_DEINTERLACE_MOTION_COMPENSATION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_PROCESSOR_CAPS = 8
D3D11_VIDEO_PROCESSOR_PROCESSOR_CAPS_INVERSE_TELECINE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_PROCESSOR_CAPS = 16
D3D11_VIDEO_PROCESSOR_PROCESSOR_CAPS_FRAME_RATE_CONVERSION: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_PROCESSOR_CAPS = 32
class D3D11_VIDEO_PROCESSOR_RATE_CONVERSION_CAPS(Structure):
    PastFrames: UInt32
    FutureFrames: UInt32
    ProcessorCaps: UInt32
    ITelecineCaps: UInt32
    CustomRateCount: UInt32
D3D11_VIDEO_PROCESSOR_ROTATION = Int32
D3D11_VIDEO_PROCESSOR_ROTATION_IDENTITY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ROTATION = 0
D3D11_VIDEO_PROCESSOR_ROTATION_90: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ROTATION = 1
D3D11_VIDEO_PROCESSOR_ROTATION_180: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ROTATION = 2
D3D11_VIDEO_PROCESSOR_ROTATION_270: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ROTATION = 3
D3D11_VIDEO_PROCESSOR_STEREO_CAPS = Int32
D3D11_VIDEO_PROCESSOR_STEREO_CAPS_MONO_OFFSET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_CAPS = 1
D3D11_VIDEO_PROCESSOR_STEREO_CAPS_ROW_INTERLEAVED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_CAPS = 2
D3D11_VIDEO_PROCESSOR_STEREO_CAPS_COLUMN_INTERLEAVED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_CAPS = 4
D3D11_VIDEO_PROCESSOR_STEREO_CAPS_CHECKERBOARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_CAPS = 8
D3D11_VIDEO_PROCESSOR_STEREO_CAPS_FLIP_MODE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_CAPS = 16
D3D11_VIDEO_PROCESSOR_STEREO_FLIP_MODE = Int32
D3D11_VIDEO_PROCESSOR_STEREO_FLIP_NONE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_FLIP_MODE = 0
D3D11_VIDEO_PROCESSOR_STEREO_FLIP_FRAME0: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_FLIP_MODE = 1
D3D11_VIDEO_PROCESSOR_STEREO_FLIP_FRAME1: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_FLIP_MODE = 2
D3D11_VIDEO_PROCESSOR_STEREO_FORMAT = Int32
D3D11_VIDEO_PROCESSOR_STEREO_FORMAT_MONO: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_FORMAT = 0
D3D11_VIDEO_PROCESSOR_STEREO_FORMAT_HORIZONTAL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_FORMAT = 1
D3D11_VIDEO_PROCESSOR_STEREO_FORMAT_VERTICAL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_FORMAT = 2
D3D11_VIDEO_PROCESSOR_STEREO_FORMAT_SEPARATE: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_FORMAT = 3
D3D11_VIDEO_PROCESSOR_STEREO_FORMAT_MONO_OFFSET: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_FORMAT = 4
D3D11_VIDEO_PROCESSOR_STEREO_FORMAT_ROW_INTERLEAVED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_FORMAT = 5
D3D11_VIDEO_PROCESSOR_STEREO_FORMAT_COLUMN_INTERLEAVED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_FORMAT = 6
D3D11_VIDEO_PROCESSOR_STEREO_FORMAT_CHECKERBOARD: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_FORMAT = 7
class D3D11_VIDEO_PROCESSOR_STREAM(Structure):
    Enable: win32more.Windows.Win32.Foundation.BOOL
    OutputIndex: UInt32
    InputFrameOrField: UInt32
    PastFrames: UInt32
    FutureFrames: UInt32
    ppPastSurfaces: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessorInputView)
    pInputSurface: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessorInputView
    ppFutureSurfaces: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessorInputView)
    ppPastSurfacesRight: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessorInputView)
    pInputSurfaceRight: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessorInputView
    ppFutureSurfacesRight: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessorInputView)
class D3D11_VIDEO_PROCESSOR_STREAM_BEHAVIOR_HINT(Structure):
    Enable: win32more.Windows.Win32.Foundation.BOOL
    Width: UInt32
    Height: UInt32
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
class D3D11_VIDEO_SAMPLE_DESC(Structure):
    Width: UInt32
    Height: UInt32
    Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT
    ColorSpace: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_COLOR_SPACE_TYPE
D3D11_VIDEO_USAGE = Int32
D3D11_VIDEO_USAGE_PLAYBACK_NORMAL: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_USAGE = 0
D3D11_VIDEO_USAGE_OPTIMAL_SPEED: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_USAGE = 1
D3D11_VIDEO_USAGE_OPTIMAL_QUALITY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_USAGE = 2
class D3D11_VIEWPORT(Structure):
    TopLeftX: Single
    TopLeftY: Single
    Width: Single
    Height: Single
    MinDepth: Single
    MaxDepth: Single
D3D11_VPIV_DIMENSION = Int32
D3D11_VPIV_DIMENSION_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VPIV_DIMENSION = 0
D3D11_VPIV_DIMENSION_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VPIV_DIMENSION = 1
D3D11_VPOV_DIMENSION = Int32
D3D11_VPOV_DIMENSION_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VPOV_DIMENSION = 0
D3D11_VPOV_DIMENSION_TEXTURE2D: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VPOV_DIMENSION = 1
D3D11_VPOV_DIMENSION_TEXTURE2DARRAY: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VPOV_DIMENSION = 2
class D3DX11_FFT_BUFFER_INFO(Structure):
    NumTempBufferSizes: UInt32
    TempBufferFloatSizes: UInt32 * 4
    NumPrecomputeBufferSizes: UInt32
    PrecomputeBufferFloatSizes: UInt32 * 4
D3DX11_FFT_CREATE_FLAG = Int32
D3DX11_FFT_CREATE_FLAG_NO_PRECOMPUTE_BUFFERS: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_FFT_CREATE_FLAG = 1
D3DX11_FFT_DATA_TYPE = Int32
D3DX11_FFT_DATA_TYPE_REAL: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_FFT_DATA_TYPE = 0
D3DX11_FFT_DATA_TYPE_COMPLEX: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_FFT_DATA_TYPE = 1
class D3DX11_FFT_DESC(Structure):
    NumDimensions: UInt32
    ElementLengths: UInt32 * 32
    DimensionMask: UInt32
    Type: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_FFT_DATA_TYPE
D3DX11_FFT_DIM_MASK = Int32
D3DX11_FFT_DIM_MASK_1D: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_FFT_DIM_MASK = 1
D3DX11_FFT_DIM_MASK_2D: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_FFT_DIM_MASK = 3
D3DX11_FFT_DIM_MASK_3D: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_FFT_DIM_MASK = 7
D3DX11_SCAN_DATA_TYPE = Int32
D3DX11_SCAN_DATA_TYPE_FLOAT: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_DATA_TYPE = 1
D3DX11_SCAN_DATA_TYPE_INT: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_DATA_TYPE = 2
D3DX11_SCAN_DATA_TYPE_UINT: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_DATA_TYPE = 3
D3DX11_SCAN_DIRECTION = Int32
D3DX11_SCAN_DIRECTION_FORWARD: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_DIRECTION = 1
D3DX11_SCAN_DIRECTION_BACKWARD: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_DIRECTION = 2
D3DX11_SCAN_OPCODE = Int32
D3DX11_SCAN_OPCODE_ADD: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_OPCODE = 1
D3DX11_SCAN_OPCODE_MIN: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_OPCODE = 2
D3DX11_SCAN_OPCODE_MAX: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_OPCODE = 3
D3DX11_SCAN_OPCODE_MUL: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_OPCODE = 4
D3DX11_SCAN_OPCODE_AND: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_OPCODE = 5
D3DX11_SCAN_OPCODE_OR: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_OPCODE = 6
D3DX11_SCAN_OPCODE_XOR: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_OPCODE = 7
class ID3D11Asynchronous(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{4b35d0cd-1e15-4258-9c98-1b1333f6dd3b}')
    @commethod(7)
    def GetDataSize(self) -> UInt32: ...
class ID3D11AuthenticatedChannel(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{3015a308-dcbd-47aa-a747-192486d14d4a}')
    @commethod(7)
    def GetCertificateSize(self, pCertificateSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetCertificate(self, CertificateSize: UInt32, pCertificate: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetChannelHandle(self, pChannelHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> Void: ...
class ID3D11BlendState(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{75b68faa-347d-4159-8f45-a0640f01cd9a}')
    @commethod(7)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND_DESC)) -> Void: ...
class ID3D11BlendState1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11BlendState
    _iid_ = Guid('{cc86fabe-da55-401d-85e7-e3c9de2877e9}')
    @commethod(8)
    def GetDesc1(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND_DESC1)) -> Void: ...
class ID3D11Buffer(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource
    _iid_ = Guid('{48570b85-d1ee-4fcd-a250-eb350722b037}')
    @commethod(10)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUFFER_DESC)) -> Void: ...
class ID3D11ClassInstance(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{a6cd7faa-b0b7-4a2f-9436-8662a65797cb}')
    @commethod(7)
    def GetClassLinkage(self, ppLinkage: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassLinkage)) -> Void: ...
    @commethod(8)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CLASS_INSTANCE_DESC)) -> Void: ...
    @commethod(9)
    def GetInstanceName(self, pInstanceName: win32more.Windows.Win32.Foundation.PSTR, pBufferLength: POINTER(UIntPtr)) -> Void: ...
    @commethod(10)
    def GetTypeName(self, pTypeName: win32more.Windows.Win32.Foundation.PSTR, pBufferLength: POINTER(UIntPtr)) -> Void: ...
class ID3D11ClassLinkage(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{ddf57cba-9543-46e4-a12b-f207a0fe7fed}')
    @commethod(7)
    def GetClassInstance(self, pClassInstanceName: win32more.Windows.Win32.Foundation.PSTR, InstanceIndex: UInt32, ppInstance: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassInstance)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateClassInstance(self, pClassTypeName: win32more.Windows.Win32.Foundation.PSTR, ConstantBufferOffset: UInt32, ConstantVectorOffset: UInt32, TextureOffset: UInt32, SamplerOffset: UInt32, ppInstance: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassInstance)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11CommandList(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{a24bc4d1-769e-43f7-8013-98ff566c18e2}')
    @commethod(7)
    def GetContextFlags(self) -> UInt32: ...
class ID3D11ComputeShader(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{4f5b196e-c2bd-495e-bd01-1fded38e4969}')
class ID3D11Counter(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Asynchronous
    _iid_ = Guid('{6e8c49fb-a371-4770-b440-29086022b741}')
    @commethod(8)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COUNTER_DESC)) -> Void: ...
class ID3D11CryptoSession(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{9b32f9ad-bdcc-40a6-a39d-d5c865845720}')
    @commethod(7)
    def GetCryptoType(self, pCryptoType: POINTER(Guid)) -> Void: ...
    @commethod(8)
    def GetDecoderProfile(self, pDecoderProfile: POINTER(Guid)) -> Void: ...
    @commethod(9)
    def GetCertificateSize(self, pCertificateSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetCertificate(self, CertificateSize: UInt32, pCertificate: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetCryptoSessionHandle(self, pCryptoSessionHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> Void: ...
class ID3D11Debug(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{79cf2233-7536-4948-9d36-1e4692dc5760}')
    @commethod(3)
    def SetFeatureMask(self, Mask: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetFeatureMask(self) -> UInt32: ...
    @commethod(5)
    def SetPresentPerRenderOpDelay(self, Milliseconds: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetPresentPerRenderOpDelay(self) -> UInt32: ...
    @commethod(7)
    def SetSwapChain(self, pSwapChain: win32more.Windows.Win32.Graphics.Dxgi.IDXGISwapChain) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetSwapChain(self, ppSwapChain: POINTER(win32more.Windows.Win32.Graphics.Dxgi.IDXGISwapChain)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def ValidateContext(self, pContext: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def ReportLiveDeviceObjects(self, Flags: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RLDO_FLAGS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def ValidateContextForDispatch(self, pContext: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11DepthStencilState(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{03823efb-8d8f-4e1c-9aa2-f64bb2cbfdf1}')
    @commethod(7)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DEPTH_STENCIL_DESC)) -> Void: ...
class ID3D11DepthStencilView(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11View
    _iid_ = Guid('{9fdac92a-1876-48c3-afad-25b94f84a9b6}')
    @commethod(8)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DEPTH_STENCIL_VIEW_DESC)) -> Void: ...
class ID3D11Device(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{db6f6ddb-ac77-4e88-8253-819df9bbf140}')
    @commethod(3)
    def CreateBuffer(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BUFFER_DESC), pInitialData: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SUBRESOURCE_DATA), ppBuffer: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateTexture1D(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE1D_DESC), pInitialData: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SUBRESOURCE_DATA), ppTexture1D: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Texture1D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateTexture2D(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE2D_DESC), pInitialData: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SUBRESOURCE_DATA), ppTexture2D: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Texture2D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateTexture3D(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE3D_DESC), pInitialData: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SUBRESOURCE_DATA), ppTexture3D: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Texture3D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreateShaderResourceView(self, pResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_RESOURCE_VIEW_DESC), ppSRView: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderResourceView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateUnorderedAccessView(self, pResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_UNORDERED_ACCESS_VIEW_DESC), ppUAView: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CreateRenderTargetView(self, pResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RENDER_TARGET_VIEW_DESC), ppRTView: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11RenderTargetView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CreateDepthStencilView(self, pResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DEPTH_STENCIL_VIEW_DESC), ppDepthStencilView: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DepthStencilView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateInputLayout(self, pInputElementDescs: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_INPUT_ELEMENT_DESC), NumElements: UInt32, pShaderBytecodeWithInputSignature: VoidPtr, BytecodeLength: UIntPtr, ppInputLayout: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11InputLayout)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def CreateVertexShader(self, pShaderBytecode: VoidPtr, BytecodeLength: UIntPtr, pClassLinkage: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassLinkage, ppVertexShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VertexShader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateGeometryShader(self, pShaderBytecode: VoidPtr, BytecodeLength: UIntPtr, pClassLinkage: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassLinkage, ppGeometryShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11GeometryShader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateGeometryShaderWithStreamOutput(self, pShaderBytecode: VoidPtr, BytecodeLength: UIntPtr, pSODeclaration: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SO_DECLARATION_ENTRY), NumEntries: UInt32, pBufferStrides: POINTER(UInt32), NumStrides: UInt32, RasterizedStream: UInt32, pClassLinkage: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassLinkage, ppGeometryShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11GeometryShader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def CreatePixelShader(self, pShaderBytecode: VoidPtr, BytecodeLength: UIntPtr, pClassLinkage: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassLinkage, ppPixelShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11PixelShader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def CreateHullShader(self, pShaderBytecode: VoidPtr, BytecodeLength: UIntPtr, pClassLinkage: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassLinkage, ppHullShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11HullShader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def CreateDomainShader(self, pShaderBytecode: VoidPtr, BytecodeLength: UIntPtr, pClassLinkage: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassLinkage, ppDomainShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DomainShader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def CreateComputeShader(self, pShaderBytecode: VoidPtr, BytecodeLength: UIntPtr, pClassLinkage: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassLinkage, ppComputeShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ComputeShader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def CreateClassLinkage(self, ppLinkage: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassLinkage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def CreateBlendState(self, pBlendStateDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND_DESC), ppBlendState: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11BlendState)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def CreateDepthStencilState(self, pDepthStencilDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DEPTH_STENCIL_DESC), ppDepthStencilState: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DepthStencilState)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def CreateRasterizerState(self, pRasterizerDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RASTERIZER_DESC), ppRasterizerState: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11RasterizerState)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def CreateSamplerState(self, pSamplerDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SAMPLER_DESC), ppSamplerState: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11SamplerState)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def CreateQuery(self, pQueryDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY_DESC), ppQuery: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Query)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def CreatePredicate(self, pPredicateDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY_DESC), ppPredicate: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Predicate)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def CreateCounter(self, pCounterDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COUNTER_DESC), ppCounter: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Counter)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def CreateDeferredContext(self, ContextFlags: UInt32, ppDeferredContext: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def OpenSharedResource(self, hResource: win32more.Windows.Win32.Foundation.HANDLE, ReturnedInterface: POINTER(Guid), ppResource: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def CheckFormatSupport(self, Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, pFormatSupport: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def CheckMultisampleQualityLevels(self, Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, SampleCount: UInt32, pNumQualityLevels: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def CheckCounterInfo(self, pCounterInfo: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COUNTER_INFO)) -> Void: ...
    @commethod(32)
    def CheckCounter(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COUNTER_DESC), pType: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_COUNTER_TYPE), pActiveCounters: POINTER(UInt32), szName: win32more.Windows.Win32.Foundation.PSTR, pNameLength: POINTER(UInt32), szUnits: win32more.Windows.Win32.Foundation.PSTR, pUnitsLength: POINTER(UInt32), szDescription: win32more.Windows.Win32.Foundation.PSTR, pDescriptionLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def CheckFeatureSupport(self, Feature: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE, pFeatureSupportData: VoidPtr, FeatureSupportDataSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def GetPrivateData(self, guid: POINTER(Guid), pDataSize: POINTER(UInt32), pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def SetPrivateData(self, guid: POINTER(Guid), DataSize: UInt32, pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def SetPrivateDataInterface(self, guid: POINTER(Guid), pData: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def GetFeatureLevel(self) -> win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL: ...
    @commethod(38)
    def GetCreationFlags(self) -> UInt32: ...
    @commethod(39)
    def GetDeviceRemovedReason(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def GetImmediateContext(self, ppImmediateContext: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext)) -> Void: ...
    @commethod(41)
    def SetExceptionMode(self, RaiseFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def GetExceptionMode(self) -> UInt32: ...
class ID3D11Device1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Device
    _iid_ = Guid('{a04bfb29-08ef-43d6-a49c-a9bdbdcbe686}')
    @commethod(43)
    def GetImmediateContext1(self, ppImmediateContext: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext1)) -> Void: ...
    @commethod(44)
    def CreateDeferredContext1(self, ContextFlags: UInt32, ppDeferredContext: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def CreateBlendState1(self, pBlendStateDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BLEND_DESC1), ppBlendState: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11BlendState1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def CreateRasterizerState1(self, pRasterizerDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RASTERIZER_DESC1), ppRasterizerState: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11RasterizerState1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def CreateDeviceContextState(self, Flags: UInt32, pFeatureLevels: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL), FeatureLevels: UInt32, SDKVersion: UInt32, EmulatedInterface: POINTER(Guid), pChosenFeatureLevel: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL), ppContextState: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3DDeviceContextState)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def OpenSharedResource1(self, hResource: win32more.Windows.Win32.Foundation.HANDLE, returnedInterface: POINTER(Guid), ppResource: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def OpenSharedResourceByName(self, lpName: win32more.Windows.Win32.Foundation.PWSTR, dwDesiredAccess: UInt32, returnedInterface: POINTER(Guid), ppResource: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11Device2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Device1
    _iid_ = Guid('{9d06dffa-d1e5-4d07-83a8-1bb123f2f841}')
    @commethod(50)
    def GetImmediateContext2(self, ppImmediateContext: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext2)) -> Void: ...
    @commethod(51)
    def CreateDeferredContext2(self, ContextFlags: UInt32, ppDeferredContext: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def GetResourceTiling(self, pTiledResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, pNumTilesForEntireResource: POINTER(UInt32), pPackedMipDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_PACKED_MIP_DESC), pStandardTileShapeForNonPackedMips: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILE_SHAPE), pNumSubresourceTilings: POINTER(UInt32), FirstSubresourceTilingToGet: UInt32, pSubresourceTilingsForNonPackedMips: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SUBRESOURCE_TILING)) -> Void: ...
    @commethod(53)
    def CheckMultisampleQualityLevels1(self, Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, SampleCount: UInt32, Flags: UInt32, pNumQualityLevels: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11Device3(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Device2
    _iid_ = Guid('{a05c8c37-d2c6-4732-b3a0-9ce0b0dc9ae6}')
    @commethod(54)
    def CreateTexture2D1(self, pDesc1: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE2D_DESC1), pInitialData: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SUBRESOURCE_DATA), ppTexture2D: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Texture2D1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def CreateTexture3D1(self, pDesc1: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE3D_DESC1), pInitialData: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SUBRESOURCE_DATA), ppTexture3D: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Texture3D1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def CreateRasterizerState2(self, pRasterizerDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RASTERIZER_DESC2), ppRasterizerState: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11RasterizerState2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def CreateShaderResourceView1(self, pResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, pDesc1: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_RESOURCE_VIEW_DESC1), ppSRView1: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderResourceView1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def CreateUnorderedAccessView1(self, pResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, pDesc1: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_UNORDERED_ACCESS_VIEW_DESC1), ppUAView1: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def CreateRenderTargetView1(self, pResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, pDesc1: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RENDER_TARGET_VIEW_DESC1), ppRTView1: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11RenderTargetView1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def CreateQuery1(self, pQueryDesc1: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY_DESC1), ppQuery1: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Query1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def GetImmediateContext3(self, ppImmediateContext: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext3)) -> Void: ...
    @commethod(62)
    def CreateDeferredContext3(self, ContextFlags: UInt32, ppDeferredContext: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def WriteToSubresource(self, pDstResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, DstSubresource: UInt32, pDstBox: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BOX), pSrcData: VoidPtr, SrcRowPitch: UInt32, SrcDepthPitch: UInt32) -> Void: ...
    @commethod(64)
    def ReadFromSubresource(self, pDstData: VoidPtr, DstRowPitch: UInt32, DstDepthPitch: UInt32, pSrcResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, SrcSubresource: UInt32, pSrcBox: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BOX)) -> Void: ...
class ID3D11Device4(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Device3
    _iid_ = Guid('{8992ab71-02e6-4b8d-ba48-b056dcda42c4}')
    @commethod(65)
    def RegisterDeviceRemovedEvent(self, hEvent: win32more.Windows.Win32.Foundation.HANDLE, pdwCookie: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def UnregisterDeviceRemoved(self, dwCookie: UInt32) -> Void: ...
class ID3D11Device5(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Device4
    _iid_ = Guid('{8ffde202-a0e7-45df-9e01-e837801b5ea0}')
    @commethod(67)
    def OpenSharedFence(self, hFence: win32more.Windows.Win32.Foundation.HANDLE, ReturnedInterface: POINTER(Guid), ppFence: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def CreateFence(self, InitialValue: UInt64, Flags: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FENCE_FLAG, ReturnedInterface: POINTER(Guid), ppFence: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11DeviceChild(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1841e5c8-16b0-489b-bcc8-44cfb0d5deae}')
    @commethod(3)
    def GetDevice(self, ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Device)) -> Void: ...
    @commethod(4)
    def GetPrivateData(self, guid: POINTER(Guid), pDataSize: POINTER(UInt32), pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetPrivateData(self, guid: POINTER(Guid), DataSize: UInt32, pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetPrivateDataInterface(self, guid: POINTER(Guid), pData: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11DeviceContext(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{c0bfa96c-e089-44fb-8eaf-26f8796190da}')
    @commethod(7)
    def VSSetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer)) -> Void: ...
    @commethod(8)
    def PSSetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderResourceView)) -> Void: ...
    @commethod(9)
    def PSSetShader(self, pPixelShader: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11PixelShader, ppClassInstances: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassInstance), NumClassInstances: UInt32) -> Void: ...
    @commethod(10)
    def PSSetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11SamplerState)) -> Void: ...
    @commethod(11)
    def VSSetShader(self, pVertexShader: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VertexShader, ppClassInstances: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassInstance), NumClassInstances: UInt32) -> Void: ...
    @commethod(12)
    def DrawIndexed(self, IndexCount: UInt32, StartIndexLocation: UInt32, BaseVertexLocation: Int32) -> Void: ...
    @commethod(13)
    def Draw(self, VertexCount: UInt32, StartVertexLocation: UInt32) -> Void: ...
    @commethod(14)
    def Map(self, pResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, Subresource: UInt32, MapType: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MAP, MapFlags: UInt32, pMappedResource: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MAPPED_SUBRESOURCE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def Unmap(self, pResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, Subresource: UInt32) -> Void: ...
    @commethod(16)
    def PSSetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer)) -> Void: ...
    @commethod(17)
    def IASetInputLayout(self, pInputLayout: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11InputLayout) -> Void: ...
    @commethod(18)
    def IASetVertexBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppVertexBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer), pStrides: POINTER(UInt32), pOffsets: POINTER(UInt32)) -> Void: ...
    @commethod(19)
    def IASetIndexBuffer(self, pIndexBuffer: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer, Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, Offset: UInt32) -> Void: ...
    @commethod(20)
    def DrawIndexedInstanced(self, IndexCountPerInstance: UInt32, InstanceCount: UInt32, StartIndexLocation: UInt32, BaseVertexLocation: Int32, StartInstanceLocation: UInt32) -> Void: ...
    @commethod(21)
    def DrawInstanced(self, VertexCountPerInstance: UInt32, InstanceCount: UInt32, StartVertexLocation: UInt32, StartInstanceLocation: UInt32) -> Void: ...
    @commethod(22)
    def GSSetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer)) -> Void: ...
    @commethod(23)
    def GSSetShader(self, pShader: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11GeometryShader, ppClassInstances: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassInstance), NumClassInstances: UInt32) -> Void: ...
    @commethod(24)
    def IASetPrimitiveTopology(self, Topology: win32more.Windows.Win32.Graphics.Direct3D.D3D_PRIMITIVE_TOPOLOGY) -> Void: ...
    @commethod(25)
    def VSSetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderResourceView)) -> Void: ...
    @commethod(26)
    def VSSetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11SamplerState)) -> Void: ...
    @commethod(27)
    def Begin(self, pAsync: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Asynchronous) -> Void: ...
    @commethod(28)
    def End(self, pAsync: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Asynchronous) -> Void: ...
    @commethod(29)
    def GetData(self, pAsync: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Asynchronous, pData: VoidPtr, DataSize: UInt32, GetDataFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def SetPredication(self, pPredicate: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Predicate, PredicateValue: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
    @commethod(31)
    def GSSetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderResourceView)) -> Void: ...
    @commethod(32)
    def GSSetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11SamplerState)) -> Void: ...
    @commethod(33)
    def OMSetRenderTargets(self, NumViews: UInt32, ppRenderTargetViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11RenderTargetView), pDepthStencilView: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DepthStencilView) -> Void: ...
    @commethod(34)
    def OMSetRenderTargetsAndUnorderedAccessViews(self, NumRTVs: UInt32, ppRenderTargetViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11RenderTargetView), pDepthStencilView: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DepthStencilView, UAVStartSlot: UInt32, NumUAVs: UInt32, ppUnorderedAccessViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView), pUAVInitialCounts: POINTER(UInt32)) -> Void: ...
    @commethod(35)
    def OMSetBlendState(self, pBlendState: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11BlendState, BlendFactor: POINTER(Single), SampleMask: UInt32) -> Void: ...
    @commethod(36)
    def OMSetDepthStencilState(self, pDepthStencilState: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DepthStencilState, StencilRef: UInt32) -> Void: ...
    @commethod(37)
    def SOSetTargets(self, NumBuffers: UInt32, ppSOTargets: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer), pOffsets: POINTER(UInt32)) -> Void: ...
    @commethod(38)
    def DrawAuto(self) -> Void: ...
    @commethod(39)
    def DrawIndexedInstancedIndirect(self, pBufferForArgs: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer, AlignedByteOffsetForArgs: UInt32) -> Void: ...
    @commethod(40)
    def DrawInstancedIndirect(self, pBufferForArgs: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer, AlignedByteOffsetForArgs: UInt32) -> Void: ...
    @commethod(41)
    def Dispatch(self, ThreadGroupCountX: UInt32, ThreadGroupCountY: UInt32, ThreadGroupCountZ: UInt32) -> Void: ...
    @commethod(42)
    def DispatchIndirect(self, pBufferForArgs: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer, AlignedByteOffsetForArgs: UInt32) -> Void: ...
    @commethod(43)
    def RSSetState(self, pRasterizerState: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11RasterizerState) -> Void: ...
    @commethod(44)
    def RSSetViewports(self, NumViewports: UInt32, pViewports: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIEWPORT)) -> Void: ...
    @commethod(45)
    def RSSetScissorRects(self, NumRects: UInt32, pRects: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> Void: ...
    @commethod(46)
    def CopySubresourceRegion(self, pDstResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, DstSubresource: UInt32, DstX: UInt32, DstY: UInt32, DstZ: UInt32, pSrcResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, SrcSubresource: UInt32, pSrcBox: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BOX)) -> Void: ...
    @commethod(47)
    def CopyResource(self, pDstResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, pSrcResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource) -> Void: ...
    @commethod(48)
    def UpdateSubresource(self, pDstResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, DstSubresource: UInt32, pDstBox: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BOX), pSrcData: VoidPtr, SrcRowPitch: UInt32, SrcDepthPitch: UInt32) -> Void: ...
    @commethod(49)
    def CopyStructureCount(self, pDstBuffer: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer, DstAlignedByteOffset: UInt32, pSrcView: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView) -> Void: ...
    @commethod(50)
    def ClearRenderTargetView(self, pRenderTargetView: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11RenderTargetView, ColorRGBA: POINTER(Single)) -> Void: ...
    @commethod(51)
    def ClearUnorderedAccessViewUint(self, pUnorderedAccessView: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView, Values: POINTER(UInt32)) -> Void: ...
    @commethod(52)
    def ClearUnorderedAccessViewFloat(self, pUnorderedAccessView: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView, Values: POINTER(Single)) -> Void: ...
    @commethod(53)
    def ClearDepthStencilView(self, pDepthStencilView: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DepthStencilView, ClearFlags: UInt32, Depth: Single, Stencil: Byte) -> Void: ...
    @commethod(54)
    def GenerateMips(self, pShaderResourceView: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderResourceView) -> Void: ...
    @commethod(55)
    def SetResourceMinLOD(self, pResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, MinLOD: Single) -> Void: ...
    @commethod(56)
    def GetResourceMinLOD(self, pResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource) -> Single: ...
    @commethod(57)
    def ResolveSubresource(self, pDstResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, DstSubresource: UInt32, pSrcResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, SrcSubresource: UInt32, Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT) -> Void: ...
    @commethod(58)
    def ExecuteCommandList(self, pCommandList: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11CommandList, RestoreContextState: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
    @commethod(59)
    def HSSetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderResourceView)) -> Void: ...
    @commethod(60)
    def HSSetShader(self, pHullShader: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11HullShader, ppClassInstances: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassInstance), NumClassInstances: UInt32) -> Void: ...
    @commethod(61)
    def HSSetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11SamplerState)) -> Void: ...
    @commethod(62)
    def HSSetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer)) -> Void: ...
    @commethod(63)
    def DSSetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderResourceView)) -> Void: ...
    @commethod(64)
    def DSSetShader(self, pDomainShader: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DomainShader, ppClassInstances: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassInstance), NumClassInstances: UInt32) -> Void: ...
    @commethod(65)
    def DSSetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11SamplerState)) -> Void: ...
    @commethod(66)
    def DSSetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer)) -> Void: ...
    @commethod(67)
    def CSSetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderResourceView)) -> Void: ...
    @commethod(68)
    def CSSetUnorderedAccessViews(self, StartSlot: UInt32, NumUAVs: UInt32, ppUnorderedAccessViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView), pUAVInitialCounts: POINTER(UInt32)) -> Void: ...
    @commethod(69)
    def CSSetShader(self, pComputeShader: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ComputeShader, ppClassInstances: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassInstance), NumClassInstances: UInt32) -> Void: ...
    @commethod(70)
    def CSSetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11SamplerState)) -> Void: ...
    @commethod(71)
    def CSSetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer)) -> Void: ...
    @commethod(72)
    def VSGetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer)) -> Void: ...
    @commethod(73)
    def PSGetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderResourceView)) -> Void: ...
    @commethod(74)
    def PSGetShader(self, ppPixelShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11PixelShader), ppClassInstances: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassInstance), pNumClassInstances: POINTER(UInt32)) -> Void: ...
    @commethod(75)
    def PSGetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11SamplerState)) -> Void: ...
    @commethod(76)
    def VSGetShader(self, ppVertexShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VertexShader), ppClassInstances: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassInstance), pNumClassInstances: POINTER(UInt32)) -> Void: ...
    @commethod(77)
    def PSGetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer)) -> Void: ...
    @commethod(78)
    def IAGetInputLayout(self, ppInputLayout: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11InputLayout)) -> Void: ...
    @commethod(79)
    def IAGetVertexBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppVertexBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer), pStrides: POINTER(UInt32), pOffsets: POINTER(UInt32)) -> Void: ...
    @commethod(80)
    def IAGetIndexBuffer(self, pIndexBuffer: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer), Format: POINTER(win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT), Offset: POINTER(UInt32)) -> Void: ...
    @commethod(81)
    def GSGetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer)) -> Void: ...
    @commethod(82)
    def GSGetShader(self, ppGeometryShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11GeometryShader), ppClassInstances: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassInstance), pNumClassInstances: POINTER(UInt32)) -> Void: ...
    @commethod(83)
    def IAGetPrimitiveTopology(self, pTopology: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_PRIMITIVE_TOPOLOGY)) -> Void: ...
    @commethod(84)
    def VSGetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderResourceView)) -> Void: ...
    @commethod(85)
    def VSGetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11SamplerState)) -> Void: ...
    @commethod(86)
    def GetPredication(self, ppPredicate: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Predicate), pPredicateValue: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> Void: ...
    @commethod(87)
    def GSGetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderResourceView)) -> Void: ...
    @commethod(88)
    def GSGetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11SamplerState)) -> Void: ...
    @commethod(89)
    def OMGetRenderTargets(self, NumViews: UInt32, ppRenderTargetViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11RenderTargetView), ppDepthStencilView: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DepthStencilView)) -> Void: ...
    @commethod(90)
    def OMGetRenderTargetsAndUnorderedAccessViews(self, NumRTVs: UInt32, ppRenderTargetViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11RenderTargetView), ppDepthStencilView: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DepthStencilView), UAVStartSlot: UInt32, NumUAVs: UInt32, ppUnorderedAccessViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView)) -> Void: ...
    @commethod(91)
    def OMGetBlendState(self, ppBlendState: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11BlendState), BlendFactor: POINTER(Single), pSampleMask: POINTER(UInt32)) -> Void: ...
    @commethod(92)
    def OMGetDepthStencilState(self, ppDepthStencilState: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DepthStencilState), pStencilRef: POINTER(UInt32)) -> Void: ...
    @commethod(93)
    def SOGetTargets(self, NumBuffers: UInt32, ppSOTargets: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer)) -> Void: ...
    @commethod(94)
    def RSGetState(self, ppRasterizerState: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11RasterizerState)) -> Void: ...
    @commethod(95)
    def RSGetViewports(self, pNumViewports: POINTER(UInt32), pViewports: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIEWPORT)) -> Void: ...
    @commethod(96)
    def RSGetScissorRects(self, pNumRects: POINTER(UInt32), pRects: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> Void: ...
    @commethod(97)
    def HSGetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderResourceView)) -> Void: ...
    @commethod(98)
    def HSGetShader(self, ppHullShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11HullShader), ppClassInstances: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassInstance), pNumClassInstances: POINTER(UInt32)) -> Void: ...
    @commethod(99)
    def HSGetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11SamplerState)) -> Void: ...
    @commethod(100)
    def HSGetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer)) -> Void: ...
    @commethod(101)
    def DSGetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderResourceView)) -> Void: ...
    @commethod(102)
    def DSGetShader(self, ppDomainShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DomainShader), ppClassInstances: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassInstance), pNumClassInstances: POINTER(UInt32)) -> Void: ...
    @commethod(103)
    def DSGetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11SamplerState)) -> Void: ...
    @commethod(104)
    def DSGetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer)) -> Void: ...
    @commethod(105)
    def CSGetShaderResources(self, StartSlot: UInt32, NumViews: UInt32, ppShaderResourceViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderResourceView)) -> Void: ...
    @commethod(106)
    def CSGetUnorderedAccessViews(self, StartSlot: UInt32, NumUAVs: UInt32, ppUnorderedAccessViews: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView)) -> Void: ...
    @commethod(107)
    def CSGetShader(self, ppComputeShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ComputeShader), ppClassInstances: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ClassInstance), pNumClassInstances: POINTER(UInt32)) -> Void: ...
    @commethod(108)
    def CSGetSamplers(self, StartSlot: UInt32, NumSamplers: UInt32, ppSamplers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11SamplerState)) -> Void: ...
    @commethod(109)
    def CSGetConstantBuffers(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer)) -> Void: ...
    @commethod(110)
    def ClearState(self) -> Void: ...
    @commethod(111)
    def Flush(self) -> Void: ...
    @commethod(112)
    def GetType(self) -> win32more.Windows.Win32.Graphics.Direct3D11.D3D11_DEVICE_CONTEXT_TYPE: ...
    @commethod(113)
    def GetContextFlags(self) -> UInt32: ...
    @commethod(114)
    def FinishCommandList(self, RestoreDeferredContextState: win32more.Windows.Win32.Foundation.BOOL, ppCommandList: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11CommandList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11DeviceContext1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext
    _iid_ = Guid('{bb2c6faa-b5fb-4082-8e6b-388b8cfa90e1}')
    @commethod(115)
    def CopySubresourceRegion1(self, pDstResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, DstSubresource: UInt32, DstX: UInt32, DstY: UInt32, DstZ: UInt32, pSrcResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, SrcSubresource: UInt32, pSrcBox: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BOX), CopyFlags: UInt32) -> Void: ...
    @commethod(116)
    def UpdateSubresource1(self, pDstResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, DstSubresource: UInt32, pDstBox: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_BOX), pSrcData: VoidPtr, SrcRowPitch: UInt32, SrcDepthPitch: UInt32, CopyFlags: UInt32) -> Void: ...
    @commethod(117)
    def DiscardResource(self, pResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource) -> Void: ...
    @commethod(118)
    def DiscardView(self, pResourceView: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11View) -> Void: ...
    @commethod(119)
    def VSSetConstantBuffers1(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer), pFirstConstant: POINTER(UInt32), pNumConstants: POINTER(UInt32)) -> Void: ...
    @commethod(120)
    def HSSetConstantBuffers1(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer), pFirstConstant: POINTER(UInt32), pNumConstants: POINTER(UInt32)) -> Void: ...
    @commethod(121)
    def DSSetConstantBuffers1(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer), pFirstConstant: POINTER(UInt32), pNumConstants: POINTER(UInt32)) -> Void: ...
    @commethod(122)
    def GSSetConstantBuffers1(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer), pFirstConstant: POINTER(UInt32), pNumConstants: POINTER(UInt32)) -> Void: ...
    @commethod(123)
    def PSSetConstantBuffers1(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer), pFirstConstant: POINTER(UInt32), pNumConstants: POINTER(UInt32)) -> Void: ...
    @commethod(124)
    def CSSetConstantBuffers1(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer), pFirstConstant: POINTER(UInt32), pNumConstants: POINTER(UInt32)) -> Void: ...
    @commethod(125)
    def VSGetConstantBuffers1(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer), pFirstConstant: POINTER(UInt32), pNumConstants: POINTER(UInt32)) -> Void: ...
    @commethod(126)
    def HSGetConstantBuffers1(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer), pFirstConstant: POINTER(UInt32), pNumConstants: POINTER(UInt32)) -> Void: ...
    @commethod(127)
    def DSGetConstantBuffers1(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer), pFirstConstant: POINTER(UInt32), pNumConstants: POINTER(UInt32)) -> Void: ...
    @commethod(128)
    def GSGetConstantBuffers1(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer), pFirstConstant: POINTER(UInt32), pNumConstants: POINTER(UInt32)) -> Void: ...
    @commethod(129)
    def PSGetConstantBuffers1(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer), pFirstConstant: POINTER(UInt32), pNumConstants: POINTER(UInt32)) -> Void: ...
    @commethod(130)
    def CSGetConstantBuffers1(self, StartSlot: UInt32, NumBuffers: UInt32, ppConstantBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer), pFirstConstant: POINTER(UInt32), pNumConstants: POINTER(UInt32)) -> Void: ...
    @commethod(131)
    def SwapDeviceContextState(self, pState: win32more.Windows.Win32.Graphics.Direct3D11.ID3DDeviceContextState, ppPreviousState: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3DDeviceContextState)) -> Void: ...
    @commethod(132)
    def ClearView(self, pView: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11View, Color: POINTER(Single), pRect: POINTER(win32more.Windows.Win32.Foundation.RECT), NumRects: UInt32) -> Void: ...
    @commethod(133)
    def DiscardView1(self, pResourceView: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11View, pRects: POINTER(win32more.Windows.Win32.Foundation.RECT), NumRects: UInt32) -> Void: ...
class ID3D11DeviceContext2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext1
    _iid_ = Guid('{420d5b32-b90c-4da4-bef0-359f6a24a83a}')
    @commethod(134)
    def UpdateTileMappings(self, pTiledResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, NumTiledResourceRegions: UInt32, pTiledResourceRegionStartCoordinates: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILED_RESOURCE_COORDINATE), pTiledResourceRegionSizes: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILE_REGION_SIZE), pTilePool: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer, NumRanges: UInt32, pRangeFlags: POINTER(UInt32), pTilePoolStartOffsets: POINTER(UInt32), pRangeTileCounts: POINTER(UInt32), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(135)
    def CopyTileMappings(self, pDestTiledResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, pDestRegionStartCoordinate: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILED_RESOURCE_COORDINATE), pSourceTiledResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, pSourceRegionStartCoordinate: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILED_RESOURCE_COORDINATE), pTileRegionSize: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILE_REGION_SIZE), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(136)
    def CopyTiles(self, pTiledResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, pTileRegionStartCoordinate: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILED_RESOURCE_COORDINATE), pTileRegionSize: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILE_REGION_SIZE), pBuffer: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer, BufferStartOffsetInBytes: UInt64, Flags: UInt32) -> Void: ...
    @commethod(137)
    def UpdateTiles(self, pDestTiledResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, pDestTileRegionStartCoordinate: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILED_RESOURCE_COORDINATE), pDestTileRegionSize: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TILE_REGION_SIZE), pSourceTileData: VoidPtr, Flags: UInt32) -> Void: ...
    @commethod(138)
    def ResizeTilePool(self, pTilePool: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer, NewSizeInBytes: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(139)
    def TiledResourceBarrier(self, pTiledResourceOrViewAccessBeforeBarrier: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild, pTiledResourceOrViewAccessAfterBarrier: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild) -> Void: ...
    @commethod(140)
    def IsAnnotationEnabled(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(141)
    def SetMarkerInt(self, pLabel: win32more.Windows.Win32.Foundation.PWSTR, Data: Int32) -> Void: ...
    @commethod(142)
    def BeginEventInt(self, pLabel: win32more.Windows.Win32.Foundation.PWSTR, Data: Int32) -> Void: ...
    @commethod(143)
    def EndEvent(self) -> Void: ...
class ID3D11DeviceContext3(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext2
    _iid_ = Guid('{b4e3c01d-e79e-4637-91b2-510e9f4c9b8f}')
    @commethod(144)
    def Flush1(self, ContextType: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CONTEXT_TYPE, hEvent: win32more.Windows.Win32.Foundation.HANDLE) -> Void: ...
    @commethod(145)
    def SetHardwareProtectionState(self, HwProtectionEnable: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
    @commethod(146)
    def GetHardwareProtectionState(self, pHwProtectionEnable: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> Void: ...
class ID3D11DeviceContext4(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext3
    _iid_ = Guid('{917600da-f58c-4c33-98d8-3e15b390fa24}')
    @commethod(147)
    def Signal(self, pFence: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Fence, Value: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(148)
    def Wait(self, pFence: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Fence, Value: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11DomainShader(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{f582c508-0f36-490c-9977-31eece268cfa}')
class ID3D11Fence(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{affde9d1-1df7-4bb7-8a34-0f46251dab80}')
    @commethod(7)
    def CreateSharedHandle(self, pAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES), dwAccess: UInt32, lpName: win32more.Windows.Win32.Foundation.PWSTR, pHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetCompletedValue(self) -> UInt64: ...
    @commethod(9)
    def SetEventOnCompletion(self, Value: UInt64, hEvent: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11FunctionLinkingGraph(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{54133220-1ce8-43d3-8236-9855c5ceecff}')
    @commethod(3)
    def CreateModuleInstance(self, ppModuleInstance: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ModuleInstance), ppErrorBuffer: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetInputSignature(self, pInputParameters: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_PARAMETER_DESC), cInputParameters: UInt32, ppInputNode: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11LinkingNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetOutputSignature(self, pOutputParameters: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_PARAMETER_DESC), cOutputParameters: UInt32, ppOutputNode: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11LinkingNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CallFunction(self, pModuleInstanceNamespace: win32more.Windows.Win32.Foundation.PSTR, pModuleWithFunctionPrototype: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Module, pFunctionName: win32more.Windows.Win32.Foundation.PSTR, ppCallNode: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11LinkingNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def PassValue(self, pSrcNode: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11LinkingNode, SrcParameterIndex: Int32, pDstNode: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11LinkingNode, DstParameterIndex: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def PassValueWithSwizzle(self, pSrcNode: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11LinkingNode, SrcParameterIndex: Int32, pSrcSwizzle: win32more.Windows.Win32.Foundation.PSTR, pDstNode: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11LinkingNode, DstParameterIndex: Int32, pDstSwizzle: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetLastError(self, ppErrorBuffer: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GenerateHlsl(self, uFlags: UInt32, ppBuffer: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11FunctionParameterReflection(ComPtr):
    extends: None
    _iid_ = Guid('{42757488-334f-47fe-982e-1a65d08cc462}')
    @commethod(0)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_PARAMETER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11FunctionReflection(ComPtr):
    extends: None
    _iid_ = Guid('{207bcecb-d683-4a06-a8a3-9b149b9f73a4}')
    @commethod(0)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FUNCTION_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(1)
    def GetConstantBufferByIndex(self, BufferIndex: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionConstantBuffer: ...
    @commethod(2)
    def GetConstantBufferByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionConstantBuffer: ...
    @commethod(3)
    def GetResourceBindingDesc(self, ResourceIndex: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_INPUT_BIND_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetVariableByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionVariable: ...
    @commethod(5)
    def GetResourceBindingDescByName(self, Name: win32more.Windows.Win32.Foundation.PSTR, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_INPUT_BIND_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetFunctionParameter(self, ParameterIndex: Int32) -> win32more.Windows.Win32.Graphics.Direct3D11.ID3D11FunctionParameterReflection: ...
class ID3D11GeometryShader(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{38325b96-effb-4022-ba02-2e795b70275c}')
class ID3D11HullShader(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{8e5c6061-628a-4c8e-8264-bbe45cb3d5dd}')
class ID3D11InfoQueue(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6543dbb6-1b48-42f5-ab82-e97ec74326f6}')
    @commethod(3)
    def SetMessageCountLimit(self, MessageCountLimit: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ClearStoredMessages(self) -> Void: ...
    @commethod(5)
    def GetMessage(self, MessageIndex: UInt64, pMessage: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE), pMessageByteLength: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetNumMessagesAllowedByStorageFilter(self) -> UInt64: ...
    @commethod(7)
    def GetNumMessagesDeniedByStorageFilter(self) -> UInt64: ...
    @commethod(8)
    def GetNumStoredMessages(self) -> UInt64: ...
    @commethod(9)
    def GetNumStoredMessagesAllowedByRetrievalFilter(self) -> UInt64: ...
    @commethod(10)
    def GetNumMessagesDiscardedByMessageCountLimit(self) -> UInt64: ...
    @commethod(11)
    def GetMessageCountLimit(self) -> UInt64: ...
    @commethod(12)
    def AddStorageFilterEntries(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_INFO_QUEUE_FILTER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetStorageFilter(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_INFO_QUEUE_FILTER), pFilterByteLength: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def ClearStorageFilter(self) -> Void: ...
    @commethod(15)
    def PushEmptyStorageFilter(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def PushCopyOfStorageFilter(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def PushStorageFilter(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_INFO_QUEUE_FILTER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def PopStorageFilter(self) -> Void: ...
    @commethod(19)
    def GetStorageFilterStackSize(self) -> UInt32: ...
    @commethod(20)
    def AddRetrievalFilterEntries(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_INFO_QUEUE_FILTER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetRetrievalFilter(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_INFO_QUEUE_FILTER), pFilterByteLength: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def ClearRetrievalFilter(self) -> Void: ...
    @commethod(23)
    def PushEmptyRetrievalFilter(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def PushCopyOfRetrievalFilter(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def PushRetrievalFilter(self, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_INFO_QUEUE_FILTER)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def PopRetrievalFilter(self) -> Void: ...
    @commethod(27)
    def GetRetrievalFilterStackSize(self) -> UInt32: ...
    @commethod(28)
    def AddMessage(self, Category: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_CATEGORY, Severity: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_SEVERITY, ID: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID, pDescription: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def AddApplicationMessage(self, Severity: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_SEVERITY, pDescription: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def SetBreakOnCategory(self, Category: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_CATEGORY, bEnable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def SetBreakOnSeverity(self, Severity: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_SEVERITY, bEnable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetBreakOnID(self, ID: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID, bEnable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetBreakOnCategory(self, Category: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_CATEGORY) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(34)
    def GetBreakOnSeverity(self, Severity: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_SEVERITY) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(35)
    def GetBreakOnID(self, ID: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_MESSAGE_ID) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(36)
    def SetMuteDebugOutput(self, bMute: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
    @commethod(37)
    def GetMuteDebugOutput(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
class ID3D11InputLayout(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{e4819ddc-4cf0-4025-bd26-5de82a3e07b7}')
class ID3D11LibraryReflection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{54384f1b-5b3e-4bb7-ae01-60ba3097cbb6}')
    @commethod(3)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_LIBRARY_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetFunctionByIndex(self, FunctionIndex: Int32) -> win32more.Windows.Win32.Graphics.Direct3D11.ID3D11FunctionReflection: ...
class ID3D11Linker(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{59a6cd0e-e10d-4c1f-88c0-63aba1daf30e}')
    @commethod(3)
    def Link(self, pEntry: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ModuleInstance, pEntryName: win32more.Windows.Win32.Foundation.PSTR, pTargetName: win32more.Windows.Win32.Foundation.PSTR, uFlags: UInt32, ppShaderBlob: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob), ppErrorBuffer: POINTER(win32more.Windows.Win32.Graphics.Direct3D.ID3DBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def UseLibrary(self, pLibraryMI: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ModuleInstance) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def AddClipPlaneFromCBuffer(self, uCBufferSlot: UInt32, uCBufferEntry: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11LinkingNode(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d80dd70c-8d2f-4751-94a1-03c79b3556db}')
class ID3D11Module(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{cac701ee-80fc-4122-8242-10b39c8cec34}')
    @commethod(3)
    def CreateInstance(self, pNamespace: win32more.Windows.Win32.Foundation.PSTR, ppModuleInstance: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ModuleInstance)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11ModuleInstance(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{469e07f7-045a-48d5-aa12-68a478cdf75d}')
    @commethod(3)
    def BindConstantBuffer(self, uSrcSlot: UInt32, uDstSlot: UInt32, cbDstOffset: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def BindConstantBufferByName(self, pName: win32more.Windows.Win32.Foundation.PSTR, uDstSlot: UInt32, cbDstOffset: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def BindResource(self, uSrcSlot: UInt32, uDstSlot: UInt32, uCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def BindResourceByName(self, pName: win32more.Windows.Win32.Foundation.PSTR, uDstSlot: UInt32, uCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def BindSampler(self, uSrcSlot: UInt32, uDstSlot: UInt32, uCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def BindSamplerByName(self, pName: win32more.Windows.Win32.Foundation.PSTR, uDstSlot: UInt32, uCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def BindUnorderedAccessView(self, uSrcSlot: UInt32, uDstSlot: UInt32, uCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def BindUnorderedAccessViewByName(self, pName: win32more.Windows.Win32.Foundation.PSTR, uDstSlot: UInt32, uCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def BindResourceAsUnorderedAccessView(self, uSrcSrvSlot: UInt32, uDstUavSlot: UInt32, uCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def BindResourceAsUnorderedAccessViewByName(self, pSrvName: win32more.Windows.Win32.Foundation.PSTR, uDstUavSlot: UInt32, uCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11Multithread(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9b7e4e00-342c-4106-a19f-4f2704f689f0}')
    @commethod(3)
    def Enter(self) -> Void: ...
    @commethod(4)
    def Leave(self) -> Void: ...
    @commethod(5)
    def SetMultithreadProtected(self, bMTProtect: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(6)
    def GetMultithreadProtected(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
class ID3D11PixelShader(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{ea82e40d-51dc-4f33-93d4-db7c9125ae8c}')
class ID3D11Predicate(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Query
    _iid_ = Guid('{9eb576dd-9f77-4d86-81aa-8bab5fe490e2}')
class ID3D11Query(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Asynchronous
    _iid_ = Guid('{d6c00747-87b7-425e-b84d-44d108560afd}')
    @commethod(8)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY_DESC)) -> Void: ...
class ID3D11Query1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Query
    _iid_ = Guid('{631b4766-36dc-461d-8db6-c47e13e60916}')
    @commethod(9)
    def GetDesc1(self, pDesc1: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_QUERY_DESC1)) -> Void: ...
class ID3D11RasterizerState(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{9bb4ab81-ab1a-4d8f-b506-fc04200b6ee7}')
    @commethod(7)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RASTERIZER_DESC)) -> Void: ...
class ID3D11RasterizerState1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11RasterizerState
    _iid_ = Guid('{1217d7a6-5039-418c-b042-9cbe256afd6e}')
    @commethod(8)
    def GetDesc1(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RASTERIZER_DESC1)) -> Void: ...
class ID3D11RasterizerState2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11RasterizerState1
    _iid_ = Guid('{6fbd02fb-209f-46c4-b059-2ed15586a6ac}')
    @commethod(9)
    def GetDesc2(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RASTERIZER_DESC2)) -> Void: ...
class ID3D11RefDefaultTrackingOptions(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{03916615-c644-418c-9bf4-75db5be63ca0}')
    @commethod(3)
    def SetTrackingOptions(self, ResourceTypeFlags: UInt32, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11RefTrackingOptions(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{193dacdf-0db2-4c05-a55c-ef06cac56fd9}')
    @commethod(3)
    def SetTrackingOptions(self, uOptions: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11RenderTargetView(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11View
    _iid_ = Guid('{dfdba067-0b8d-4865-875b-d7b4516cc164}')
    @commethod(8)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RENDER_TARGET_VIEW_DESC)) -> Void: ...
class ID3D11RenderTargetView1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11RenderTargetView
    _iid_ = Guid('{ffbe2e23-f011-418a-ac56-5ceed7c5b94b}')
    @commethod(9)
    def GetDesc1(self, pDesc1: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RENDER_TARGET_VIEW_DESC1)) -> Void: ...
class ID3D11Resource(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{dc8e63f3-d12b-4952-b47b-5e45026a862d}')
    @commethod(7)
    def GetType(self, pResourceDimension: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_RESOURCE_DIMENSION)) -> Void: ...
    @commethod(8)
    def SetEvictionPriority(self, EvictionPriority: UInt32) -> Void: ...
    @commethod(9)
    def GetEvictionPriority(self) -> UInt32: ...
class ID3D11SamplerState(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{da6fea51-564c-4487-9810-f0d0f9b4e3a5}')
    @commethod(7)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SAMPLER_DESC)) -> Void: ...
class ID3D11ShaderReflection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8d536ca1-0cca-4956-a837-786963755584}')
    @commethod(3)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetConstantBufferByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionConstantBuffer: ...
    @commethod(5)
    def GetConstantBufferByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionConstantBuffer: ...
    @commethod(6)
    def GetResourceBindingDesc(self, ResourceIndex: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_INPUT_BIND_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetInputParameterDesc(self, ParameterIndex: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SIGNATURE_PARAMETER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetOutputParameterDesc(self, ParameterIndex: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SIGNATURE_PARAMETER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetPatchConstantParameterDesc(self, ParameterIndex: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SIGNATURE_PARAMETER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetVariableByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionVariable: ...
    @commethod(11)
    def GetResourceBindingDescByName(self, Name: win32more.Windows.Win32.Foundation.PSTR, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_INPUT_BIND_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetMovInstructionCount(self) -> UInt32: ...
    @commethod(13)
    def GetMovcInstructionCount(self) -> UInt32: ...
    @commethod(14)
    def GetConversionInstructionCount(self) -> UInt32: ...
    @commethod(15)
    def GetBitwiseInstructionCount(self) -> UInt32: ...
    @commethod(16)
    def GetGSInputPrimitive(self) -> win32more.Windows.Win32.Graphics.Direct3D.D3D_PRIMITIVE: ...
    @commethod(17)
    def IsSampleFrequencyShader(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(18)
    def GetNumInterfaceSlots(self) -> UInt32: ...
    @commethod(19)
    def GetMinFeatureLevel(self, pLevel: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetThreadGroupSize(self, pSizeX: POINTER(UInt32), pSizeY: POINTER(UInt32), pSizeZ: POINTER(UInt32)) -> UInt32: ...
    @commethod(21)
    def GetRequiresFlags(self) -> UInt64: ...
class ID3D11ShaderReflectionConstantBuffer(ComPtr):
    extends: None
    _iid_ = Guid('{eb62d63d-93dd-4318-8ae8-c6f83ad371b8}')
    @commethod(0)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_BUFFER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(1)
    def GetVariableByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionVariable: ...
    @commethod(2)
    def GetVariableByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionVariable: ...
class ID3D11ShaderReflectionType(ComPtr):
    extends: None
    _iid_ = Guid('{6e6ffa6a-9bae-4613-a51e-91652d508c21}')
    @commethod(0)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TYPE_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(1)
    def GetMemberTypeByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionType: ...
    @commethod(2)
    def GetMemberTypeByName(self, Name: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionType: ...
    @commethod(3)
    def GetMemberTypeName(self, Index: UInt32) -> win32more.Windows.Win32.Foundation.PSTR: ...
    @commethod(4)
    def IsEqual(self, pType: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionType) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetSubType(self) -> win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionType: ...
    @commethod(6)
    def GetBaseClass(self) -> win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionType: ...
    @commethod(7)
    def GetNumInterfaces(self) -> UInt32: ...
    @commethod(8)
    def GetInterfaceByIndex(self, uIndex: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionType: ...
    @commethod(9)
    def IsOfType(self, pType: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionType) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def ImplementsInterface(self, pBase: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionType) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11ShaderReflectionVariable(ComPtr):
    extends: None
    _iid_ = Guid('{51f23923-f3e5-4bd1-91cb-606177d8db4c}')
    @commethod(0)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_VARIABLE_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(1)
    def GetType(self) -> win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionType: ...
    @commethod(2)
    def GetBuffer(self) -> win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderReflectionConstantBuffer: ...
    @commethod(3)
    def GetInterfaceSlot(self, uArrayIndex: UInt32) -> UInt32: ...
class ID3D11ShaderResourceView(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11View
    _iid_ = Guid('{b0e06fe0-8192-4e1a-b1ca-36d7414710b2}')
    @commethod(8)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_RESOURCE_VIEW_DESC)) -> Void: ...
class ID3D11ShaderResourceView1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderResourceView
    _iid_ = Guid('{91308b87-9040-411d-8c67-c39253ce3802}')
    @commethod(9)
    def GetDesc1(self, pDesc1: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_RESOURCE_VIEW_DESC1)) -> Void: ...
class ID3D11ShaderTrace(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{36b013e6-2811-4845-baa7-d623fe0df104}')
    @commethod(3)
    def TraceReady(self, pTestCount: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ResetTrace(self) -> Void: ...
    @commethod(5)
    def GetTraceStats(self, pTraceStats: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_STATS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def PSSelectStamp(self, stampIndex: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetInitialRegisterContents(self, pRegister: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER), pValue: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetStep(self, stepIndex: UInt32, pTraceStep: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_STEP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetWrittenRegister(self, stepIndex: UInt32, writtenRegisterIndex: UInt32, pRegister: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER), pValue: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetReadRegister(self, stepIndex: UInt32, readRegisterIndex: UInt32, pRegister: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_REGISTER), pValue: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TRACE_VALUE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11ShaderTraceFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1fbad429-66ab-41cc-9617-667ac10e4459}')
    @commethod(3)
    def CreateShaderTrace(self, pShader: win32more.Windows.Win32.System.Com.IUnknown, pTraceDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_SHADER_TRACE_DESC), ppShaderTrace: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11ShaderTrace)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11SwitchToRef(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1ef337e3-58e7-4f83-a692-db221f5ed47e}')
    @commethod(3)
    def SetUseRef(self, UseRef: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(4)
    def GetUseRef(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
class ID3D11Texture1D(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource
    _iid_ = Guid('{f8fb5c27-c6b3-4f75-a4c8-439af2ef564c}')
    @commethod(10)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE1D_DESC)) -> Void: ...
class ID3D11Texture2D(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource
    _iid_ = Guid('{6f15aaf2-d208-4e89-9ab4-489535d34f9c}')
    @commethod(10)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE2D_DESC)) -> Void: ...
class ID3D11Texture2D1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Texture2D
    _iid_ = Guid('{51218251-1e33-4617-9ccb-4d3a4367e7bb}')
    @commethod(11)
    def GetDesc1(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE2D_DESC1)) -> Void: ...
class ID3D11Texture3D(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource
    _iid_ = Guid('{037e866e-f56d-4357-a8af-9dabbe6e250e}')
    @commethod(10)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE3D_DESC)) -> Void: ...
class ID3D11Texture3D1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Texture3D
    _iid_ = Guid('{0c711683-2853-4846-9bb0-f3e60639e46a}')
    @commethod(11)
    def GetDesc1(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_TEXTURE3D_DESC1)) -> Void: ...
class ID3D11TracingDevice(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1911c771-1587-413e-a7e0-fb26c3de0268}')
    @commethod(3)
    def SetShaderTrackingOptionsByType(self, ResourceTypeFlags: UInt32, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetShaderTrackingOptions(self, pShader: win32more.Windows.Win32.System.Com.IUnknown, Options: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11UnorderedAccessView(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11View
    _iid_ = Guid('{28acf509-7f5c-48f6-8611-f316010a6380}')
    @commethod(8)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_UNORDERED_ACCESS_VIEW_DESC)) -> Void: ...
class ID3D11UnorderedAccessView1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView
    _iid_ = Guid('{7b3b6153-a886-4544-ab37-6537c8500403}')
    @commethod(9)
    def GetDesc1(self, pDesc1: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_UNORDERED_ACCESS_VIEW_DESC1)) -> Void: ...
class ID3D11VertexShader(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{3b301d64-d678-4289-8897-22f8928b72f3}')
class ID3D11VideoContext(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{61f21c45-3c0e-4a74-9cea-67100d9ad5e4}')
    @commethod(7)
    def GetDecoderBuffer(self, pDecoder: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoDecoder, Type: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_BUFFER_TYPE, pBufferSize: POINTER(UInt32), ppBuffer: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def ReleaseDecoderBuffer(self, pDecoder: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoDecoder, Type: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_BUFFER_TYPE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def DecoderBeginFrame(self, pDecoder: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoDecoder, pView: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoDecoderOutputView, ContentKeySize: UInt32, pContentKey: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def DecoderEndFrame(self, pDecoder: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoDecoder) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SubmitDecoderBuffers(self, pDecoder: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoDecoder, NumBuffers: UInt32, pBufferDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_BUFFER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def DecoderExtension(self, pDecoder: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoDecoder, pExtensionData: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_EXTENSION)) -> Int32: ...
    @commethod(13)
    def VideoProcessorSetOutputTargetRect(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, Enable: win32more.Windows.Win32.Foundation.BOOL, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> Void: ...
    @commethod(14)
    def VideoProcessorSetOutputBackgroundColor(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, YCbCr: win32more.Windows.Win32.Foundation.BOOL, pColor: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_COLOR)) -> Void: ...
    @commethod(15)
    def VideoProcessorSetOutputColorSpace(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, pColorSpace: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_COLOR_SPACE)) -> Void: ...
    @commethod(16)
    def VideoProcessorSetOutputAlphaFillMode(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, AlphaFillMode: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ALPHA_FILL_MODE, StreamIndex: UInt32) -> Void: ...
    @commethod(17)
    def VideoProcessorSetOutputConstriction(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, Enable: win32more.Windows.Win32.Foundation.BOOL, Size: win32more.Windows.Win32.Foundation.SIZE) -> Void: ...
    @commethod(18)
    def VideoProcessorSetOutputStereoMode(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, Enable: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
    @commethod(19)
    def VideoProcessorSetOutputExtension(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, pExtensionGuid: POINTER(Guid), DataSize: UInt32, pData: VoidPtr) -> Int32: ...
    @commethod(20)
    def VideoProcessorGetOutputTargetRect(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, Enabled: POINTER(win32more.Windows.Win32.Foundation.BOOL), pRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> Void: ...
    @commethod(21)
    def VideoProcessorGetOutputBackgroundColor(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, pYCbCr: POINTER(win32more.Windows.Win32.Foundation.BOOL), pColor: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_COLOR)) -> Void: ...
    @commethod(22)
    def VideoProcessorGetOutputColorSpace(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, pColorSpace: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_COLOR_SPACE)) -> Void: ...
    @commethod(23)
    def VideoProcessorGetOutputAlphaFillMode(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, pAlphaFillMode: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ALPHA_FILL_MODE), pStreamIndex: POINTER(UInt32)) -> Void: ...
    @commethod(24)
    def VideoProcessorGetOutputConstriction(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, pEnabled: POINTER(win32more.Windows.Win32.Foundation.BOOL), pSize: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> Void: ...
    @commethod(25)
    def VideoProcessorGetOutputStereoMode(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, pEnabled: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> Void: ...
    @commethod(26)
    def VideoProcessorGetOutputExtension(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, pExtensionGuid: POINTER(Guid), DataSize: UInt32, pData: VoidPtr) -> Int32: ...
    @commethod(27)
    def VideoProcessorSetStreamFrameFormat(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, FrameFormat: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_FRAME_FORMAT) -> Void: ...
    @commethod(28)
    def VideoProcessorSetStreamColorSpace(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, pColorSpace: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_COLOR_SPACE)) -> Void: ...
    @commethod(29)
    def VideoProcessorSetStreamOutputRate(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, OutputRate: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_OUTPUT_RATE, RepeatFrame: win32more.Windows.Win32.Foundation.BOOL, pCustomRate: POINTER(win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_RATIONAL)) -> Void: ...
    @commethod(30)
    def VideoProcessorSetStreamSourceRect(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, Enable: win32more.Windows.Win32.Foundation.BOOL, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> Void: ...
    @commethod(31)
    def VideoProcessorSetStreamDestRect(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, Enable: win32more.Windows.Win32.Foundation.BOOL, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> Void: ...
    @commethod(32)
    def VideoProcessorSetStreamAlpha(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, Enable: win32more.Windows.Win32.Foundation.BOOL, Alpha: Single) -> Void: ...
    @commethod(33)
    def VideoProcessorSetStreamPalette(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, Count: UInt32, pEntries: POINTER(UInt32)) -> Void: ...
    @commethod(34)
    def VideoProcessorSetStreamPixelAspectRatio(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, Enable: win32more.Windows.Win32.Foundation.BOOL, pSourceAspectRatio: POINTER(win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_RATIONAL), pDestinationAspectRatio: POINTER(win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_RATIONAL)) -> Void: ...
    @commethod(35)
    def VideoProcessorSetStreamLumaKey(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, Enable: win32more.Windows.Win32.Foundation.BOOL, Lower: Single, Upper: Single) -> Void: ...
    @commethod(36)
    def VideoProcessorSetStreamStereoFormat(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, Enable: win32more.Windows.Win32.Foundation.BOOL, Format: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_FORMAT, LeftViewFrame0: win32more.Windows.Win32.Foundation.BOOL, BaseViewFrame0: win32more.Windows.Win32.Foundation.BOOL, FlipMode: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_FLIP_MODE, MonoOffset: Int32) -> Void: ...
    @commethod(37)
    def VideoProcessorSetStreamAutoProcessingMode(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, Enable: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
    @commethod(38)
    def VideoProcessorSetStreamFilter(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, Filter: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER, Enable: win32more.Windows.Win32.Foundation.BOOL, Level: Int32) -> Void: ...
    @commethod(39)
    def VideoProcessorSetStreamExtension(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, pExtensionGuid: POINTER(Guid), DataSize: UInt32, pData: VoidPtr) -> Int32: ...
    @commethod(40)
    def VideoProcessorGetStreamFrameFormat(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, pFrameFormat: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_FRAME_FORMAT)) -> Void: ...
    @commethod(41)
    def VideoProcessorGetStreamColorSpace(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, pColorSpace: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_COLOR_SPACE)) -> Void: ...
    @commethod(42)
    def VideoProcessorGetStreamOutputRate(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, pOutputRate: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_OUTPUT_RATE), pRepeatFrame: POINTER(win32more.Windows.Win32.Foundation.BOOL), pCustomRate: POINTER(win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_RATIONAL)) -> Void: ...
    @commethod(43)
    def VideoProcessorGetStreamSourceRect(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, pEnabled: POINTER(win32more.Windows.Win32.Foundation.BOOL), pRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> Void: ...
    @commethod(44)
    def VideoProcessorGetStreamDestRect(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, pEnabled: POINTER(win32more.Windows.Win32.Foundation.BOOL), pRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> Void: ...
    @commethod(45)
    def VideoProcessorGetStreamAlpha(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, pEnabled: POINTER(win32more.Windows.Win32.Foundation.BOOL), pAlpha: POINTER(Single)) -> Void: ...
    @commethod(46)
    def VideoProcessorGetStreamPalette(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, Count: UInt32, pEntries: POINTER(UInt32)) -> Void: ...
    @commethod(47)
    def VideoProcessorGetStreamPixelAspectRatio(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, pEnabled: POINTER(win32more.Windows.Win32.Foundation.BOOL), pSourceAspectRatio: POINTER(win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_RATIONAL), pDestinationAspectRatio: POINTER(win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_RATIONAL)) -> Void: ...
    @commethod(48)
    def VideoProcessorGetStreamLumaKey(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, pEnabled: POINTER(win32more.Windows.Win32.Foundation.BOOL), pLower: POINTER(Single), pUpper: POINTER(Single)) -> Void: ...
    @commethod(49)
    def VideoProcessorGetStreamStereoFormat(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, pEnable: POINTER(win32more.Windows.Win32.Foundation.BOOL), pFormat: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_FORMAT), pLeftViewFrame0: POINTER(win32more.Windows.Win32.Foundation.BOOL), pBaseViewFrame0: POINTER(win32more.Windows.Win32.Foundation.BOOL), pFlipMode: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STEREO_FLIP_MODE), MonoOffset: POINTER(Int32)) -> Void: ...
    @commethod(50)
    def VideoProcessorGetStreamAutoProcessingMode(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, pEnabled: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> Void: ...
    @commethod(51)
    def VideoProcessorGetStreamFilter(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, Filter: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER, pEnabled: POINTER(win32more.Windows.Win32.Foundation.BOOL), pLevel: POINTER(Int32)) -> Void: ...
    @commethod(52)
    def VideoProcessorGetStreamExtension(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, pExtensionGuid: POINTER(Guid), DataSize: UInt32, pData: VoidPtr) -> Int32: ...
    @commethod(53)
    def VideoProcessorBlt(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, pView: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessorOutputView, OutputFrame: UInt32, StreamCount: UInt32, pStreams: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STREAM)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def NegotiateCryptoSessionKeyExchange(self, pCryptoSession: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11CryptoSession, DataSize: UInt32, pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def EncryptionBlt(self, pCryptoSession: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11CryptoSession, pSrcSurface: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Texture2D, pDstSurface: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Texture2D, IVSize: UInt32, pIV: VoidPtr) -> Void: ...
    @commethod(56)
    def DecryptionBlt(self, pCryptoSession: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11CryptoSession, pSrcSurface: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Texture2D, pDstSurface: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Texture2D, pEncryptedBlockInfo: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_ENCRYPTED_BLOCK_INFO), ContentKeySize: UInt32, pContentKey: VoidPtr, IVSize: UInt32, pIV: VoidPtr) -> Void: ...
    @commethod(57)
    def StartSessionKeyRefresh(self, pCryptoSession: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11CryptoSession, RandomNumberSize: UInt32, pRandomNumber: VoidPtr) -> Void: ...
    @commethod(58)
    def FinishSessionKeyRefresh(self, pCryptoSession: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11CryptoSession) -> Void: ...
    @commethod(59)
    def GetEncryptionBltKey(self, pCryptoSession: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11CryptoSession, KeySize: UInt32, pReadbackKey: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def NegotiateAuthenticatedChannelKeyExchange(self, pChannel: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11AuthenticatedChannel, DataSize: UInt32, pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def QueryAuthenticatedChannel(self, pChannel: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11AuthenticatedChannel, InputSize: UInt32, pInput: VoidPtr, OutputSize: UInt32, pOutput: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def ConfigureAuthenticatedChannel(self, pChannel: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11AuthenticatedChannel, InputSize: UInt32, pInput: VoidPtr, pOutput: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_CONFIGURE_OUTPUT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def VideoProcessorSetStreamRotation(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, Enable: win32more.Windows.Win32.Foundation.BOOL, Rotation: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ROTATION) -> Void: ...
    @commethod(64)
    def VideoProcessorGetStreamRotation(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, pEnable: POINTER(win32more.Windows.Win32.Foundation.BOOL), pRotation: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_ROTATION)) -> Void: ...
class ID3D11VideoContext1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoContext
    _iid_ = Guid('{a7f026da-a5f8-4487-a564-15e34357651e}')
    @commethod(65)
    def SubmitDecoderBuffers1(self, pDecoder: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoDecoder, NumBuffers: UInt32, pBufferDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_BUFFER_DESC1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def GetDataForNewHardwareKey(self, pCryptoSession: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11CryptoSession, PrivateInputSize: UInt32, pPrivatInputData: VoidPtr, pPrivateOutputData: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def CheckCryptoSessionStatus(self, pCryptoSession: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11CryptoSession, pStatus: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CRYPTO_SESSION_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def DecoderEnableDownsampling(self, pDecoder: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoDecoder, InputColorSpace: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_COLOR_SPACE_TYPE, pOutputDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_SAMPLE_DESC), ReferenceFrameCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def DecoderUpdateDownsampling(self, pDecoder: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoDecoder, pOutputDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_SAMPLE_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def VideoProcessorSetOutputColorSpace1(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, ColorSpace: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_COLOR_SPACE_TYPE) -> Void: ...
    @commethod(71)
    def VideoProcessorSetOutputShaderUsage(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, ShaderUsage: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
    @commethod(72)
    def VideoProcessorGetOutputColorSpace1(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, pColorSpace: POINTER(win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_COLOR_SPACE_TYPE)) -> Void: ...
    @commethod(73)
    def VideoProcessorGetOutputShaderUsage(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, pShaderUsage: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> Void: ...
    @commethod(74)
    def VideoProcessorSetStreamColorSpace1(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, ColorSpace: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_COLOR_SPACE_TYPE) -> Void: ...
    @commethod(75)
    def VideoProcessorSetStreamMirror(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, Enable: win32more.Windows.Win32.Foundation.BOOL, FlipHorizontal: win32more.Windows.Win32.Foundation.BOOL, FlipVertical: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
    @commethod(76)
    def VideoProcessorGetStreamColorSpace1(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, pColorSpace: POINTER(win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_COLOR_SPACE_TYPE)) -> Void: ...
    @commethod(77)
    def VideoProcessorGetStreamMirror(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, pEnable: POINTER(win32more.Windows.Win32.Foundation.BOOL), pFlipHorizontal: POINTER(win32more.Windows.Win32.Foundation.BOOL), pFlipVertical: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> Void: ...
    @commethod(78)
    def VideoProcessorGetBehaviorHints(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, OutputWidth: UInt32, OutputHeight: UInt32, OutputFormat: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, StreamCount: UInt32, pStreams: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_STREAM_BEHAVIOR_HINT), pBehaviorHints: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11VideoContext2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoContext1
    _iid_ = Guid('{c4e7374c-6243-4d1b-ae87-52b4f740e261}')
    @commethod(79)
    def VideoProcessorSetOutputHDRMetaData(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, Type: win32more.Windows.Win32.Graphics.Dxgi.DXGI_HDR_METADATA_TYPE, Size: UInt32, pHDRMetaData: VoidPtr) -> Void: ...
    @commethod(80)
    def VideoProcessorGetOutputHDRMetaData(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, pType: POINTER(win32more.Windows.Win32.Graphics.Dxgi.DXGI_HDR_METADATA_TYPE), Size: UInt32, pMetaData: VoidPtr) -> Void: ...
    @commethod(81)
    def VideoProcessorSetStreamHDRMetaData(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, Type: win32more.Windows.Win32.Graphics.Dxgi.DXGI_HDR_METADATA_TYPE, Size: UInt32, pHDRMetaData: VoidPtr) -> Void: ...
    @commethod(82)
    def VideoProcessorGetStreamHDRMetaData(self, pVideoProcessor: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor, StreamIndex: UInt32, pType: POINTER(win32more.Windows.Win32.Graphics.Dxgi.DXGI_HDR_METADATA_TYPE), Size: UInt32, pMetaData: VoidPtr) -> Void: ...
class ID3D11VideoContext3(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoContext2
    _iid_ = Guid('{a9e2faa0-cb39-418f-a0b7-d8aad4de672e}')
    @commethod(83)
    def DecoderBeginFrame1(self, pDecoder: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoDecoder, pView: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoDecoderOutputView, ContentKeySize: UInt32, pContentKey: VoidPtr, NumComponentHistograms: UInt32, pHistogramOffsets: POINTER(UInt32), ppHistogramBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Buffer)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def SubmitDecoderBuffers2(self, pDecoder: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoDecoder, NumBuffers: UInt32, pBufferDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_BUFFER_DESC2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11VideoDecoder(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{3c9c5b51-995d-48d1-9b8d-fa5caeded65c}')
    @commethod(7)
    def GetCreationParameters(self, pVideoDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_DESC), pConfig: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_CONFIG)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetDriverHandle(self, pDriverHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11VideoDecoderOutputView(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11View
    _iid_ = Guid('{c2931aea-2a85-4f20-860f-fba1fd256e18}')
    @commethod(8)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_OUTPUT_VIEW_DESC)) -> Void: ...
class ID3D11VideoDevice(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{10ec4d5b-975a-4689-b9e4-d0aac30fe333}')
    @commethod(3)
    def CreateVideoDecoder(self, pVideoDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_DESC), pConfig: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_CONFIG), ppDecoder: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoDecoder)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateVideoProcessor(self, pEnum: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessorEnumerator, RateConversionIndex: UInt32, ppVideoProcessor: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessor)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateAuthenticatedChannel(self, ChannelType: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_AUTHENTICATED_CHANNEL_TYPE, ppAuthenticatedChannel: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11AuthenticatedChannel)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateCryptoSession(self, pCryptoType: POINTER(Guid), pDecoderProfile: POINTER(Guid), pKeyExchangeType: POINTER(Guid), ppCryptoSession: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11CryptoSession)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreateVideoDecoderOutputView(self, pResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_OUTPUT_VIEW_DESC), ppVDOVView: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoDecoderOutputView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateVideoProcessorInputView(self, pResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, pEnum: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessorEnumerator, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_INPUT_VIEW_DESC), ppVPIView: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessorInputView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CreateVideoProcessorOutputView(self, pResource: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, pEnum: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessorEnumerator, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_OUTPUT_VIEW_DESC), ppVPOView: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessorOutputView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CreateVideoProcessorEnumerator(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_CONTENT_DESC), ppEnum: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessorEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetVideoDecoderProfileCount(self) -> UInt32: ...
    @commethod(12)
    def GetVideoDecoderProfile(self, Index: UInt32, pDecoderProfile: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CheckVideoDecoderFormat(self, pDecoderProfile: POINTER(Guid), Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, pSupported: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetVideoDecoderConfigCount(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_DESC), pCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetVideoDecoderConfig(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_DESC), Index: UInt32, pConfig: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_CONFIG)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetContentProtectionCaps(self, pCryptoType: POINTER(Guid), pDecoderProfile: POINTER(Guid), pCaps: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_CONTENT_PROTECTION_CAPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def CheckCryptoKeyExchange(self, pCryptoType: POINTER(Guid), pDecoderProfile: POINTER(Guid), Index: UInt32, pKeyExchangeType: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetPrivateData(self, guid: POINTER(Guid), DataSize: UInt32, pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def SetPrivateDataInterface(self, guid: POINTER(Guid), pData: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11VideoDevice1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoDevice
    _iid_ = Guid('{29da1d51-1321-4454-804b-f5fc9f861f0f}')
    @commethod(20)
    def GetCryptoSessionPrivateDataSize(self, pCryptoType: POINTER(Guid), pDecoderProfile: POINTER(Guid), pKeyExchangeType: POINTER(Guid), pPrivateInputSize: POINTER(UInt32), pPrivateOutputSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetVideoDecoderCaps(self, pDecoderProfile: POINTER(Guid), SampleWidth: UInt32, SampleHeight: UInt32, pFrameRate: POINTER(win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_RATIONAL), BitRate: UInt32, pCryptoType: POINTER(Guid), pDecoderCaps: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def CheckVideoDecoderDownsampling(self, pInputDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_DESC), InputColorSpace: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_COLOR_SPACE_TYPE, pInputConfig: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_CONFIG), pFrameRate: POINTER(win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_RATIONAL), pOutputDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_SAMPLE_DESC), pSupported: POINTER(win32more.Windows.Win32.Foundation.BOOL), pRealTimeHint: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def RecommendVideoDecoderDownsampleParameters(self, pInputDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_DESC), InputColorSpace: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_COLOR_SPACE_TYPE, pInputConfig: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_DECODER_CONFIG), pFrameRate: POINTER(win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_RATIONAL), pRecommendedOutputDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_SAMPLE_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11VideoDevice2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoDevice1
    _iid_ = Guid('{59c0cb01-35f0-4a70-8f67-87905c906a53}')
    @commethod(24)
    def CheckFeatureSupport(self, Feature: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_FEATURE_VIDEO, pFeatureSupportData: VoidPtr, FeatureSupportDataSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def NegotiateCryptoSessionKeyExchangeMT(self, pCryptoSession: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11CryptoSession, flags: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_CRYPTO_SESSION_KEY_EXCHANGE_FLAGS, DataSize: UInt32, pData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11VideoProcessor(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{1d7b0652-185f-41c6-85ce-0c5be3d4ae6c}')
    @commethod(7)
    def GetContentDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_CONTENT_DESC)) -> Void: ...
    @commethod(8)
    def GetRateConversionCaps(self, pCaps: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_RATE_CONVERSION_CAPS)) -> Void: ...
class ID3D11VideoProcessorEnumerator(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{31627037-53ab-4200-9061-05faa9ab45f9}')
    @commethod(7)
    def GetVideoProcessorContentDesc(self, pContentDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_CONTENT_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CheckVideoProcessorFormat(self, Format: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, pFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetVideoProcessorCaps(self, pCaps: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_CAPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetVideoProcessorRateConversionCaps(self, TypeIndex: UInt32, pCaps: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_RATE_CONVERSION_CAPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetVideoProcessorCustomRate(self, TypeIndex: UInt32, CustomRateIndex: UInt32, pRate: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_CUSTOM_RATE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetVideoProcessorFilterRange(self, Filter: win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER, pRange: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_FILTER_RANGE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11VideoProcessorEnumerator1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11VideoProcessorEnumerator
    _iid_ = Guid('{465217f2-5568-43cf-b5b9-f61d54531ca1}')
    @commethod(13)
    def CheckVideoProcessorFormatConversion(self, InputFormat: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, InputColorSpace: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_COLOR_SPACE_TYPE, OutputFormat: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, OutputColorSpace: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_COLOR_SPACE_TYPE, pSupported: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11VideoProcessorInputView(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11View
    _iid_ = Guid('{11ec5a5f-51dc-4945-ab34-6e8c21300ea5}')
    @commethod(8)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_INPUT_VIEW_DESC)) -> Void: ...
class ID3D11VideoProcessorOutputView(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11View
    _iid_ = Guid('{a048285e-25a9-4527-bd93-d68b68c44254}')
    @commethod(8)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.D3D11_VIDEO_PROCESSOR_OUTPUT_VIEW_DESC)) -> Void: ...
class ID3D11View(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{839d1216-bb2e-412b-b7f4-a9dbebe08ed1}')
    @commethod(7)
    def GetResource(self, ppResource: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource)) -> Void: ...
class ID3DDeviceContextState(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceChild
    _iid_ = Guid('{5c1e0d8a-7c23-48f9-8c59-a92958ceff11}')
class ID3DUserDefinedAnnotation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b2daad8b-03d4-4dbf-95eb-32ab4b63d0ab}')
    @commethod(3)
    def BeginEvent(self, Name: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
    @commethod(4)
    def EndEvent(self) -> Int32: ...
    @commethod(5)
    def SetMarker(self, Name: win32more.Windows.Win32.Foundation.PWSTR) -> Void: ...
    @commethod(6)
    def GetStatus(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
class ID3DX11FFT(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b3f7a938-4c93-4310-a675-b30d6de50553}')
    @commethod(3)
    def SetForwardScale(self, ForwardScale: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetForwardScale(self) -> Single: ...
    @commethod(5)
    def SetInverseScale(self, InverseScale: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetInverseScale(self) -> Single: ...
    @commethod(7)
    def AttachBuffersAndPrecompute(self, NumTempBuffers: UInt32, ppTempBuffers: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView), NumPrecomputeBuffers: UInt32, ppPrecomputeBufferSizes: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def ForwardTransform(self, pInputBuffer: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView, ppOutputBuffer: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def InverseTransform(self, pInputBuffer: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView, ppOutputBuffer: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3DX11Scan(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5089b68f-e71d-4d38-be8e-f363b95a9405}')
    @commethod(3)
    def SetScanDirection(self, Direction: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_DIRECTION) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Scan(self, ElementType: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_DATA_TYPE, OpCode: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_OPCODE, ElementScanSize: UInt32, pSrc: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView, pDst: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Multiscan(self, ElementType: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_DATA_TYPE, OpCode: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_OPCODE, ElementScanSize: UInt32, ElementScanPitch: UInt32, ScanCount: UInt32, pSrc: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView, pDst: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3DX11SegmentedScan(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a915128c-d954-4c79-bfe1-64db923194d6}')
    @commethod(3)
    def SetScanDirection(self, Direction: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_DIRECTION) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SegScan(self, ElementType: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_DATA_TYPE, OpCode: win32more.Windows.Win32.Graphics.Direct3D11.D3DX11_SCAN_OPCODE, ElementScanSize: UInt32, pSrc: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView, pSrcElementFlags: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView, pDst: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11UnorderedAccessView) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFN_D3D11_CREATE_DEVICE(param0: win32more.Windows.Win32.Graphics.Dxgi.IDXGIAdapter, param1: win32more.Windows.Win32.Graphics.Direct3D.D3D_DRIVER_TYPE, param2: win32more.Windows.Win32.Foundation.HMODULE, param3: UInt32, param4: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL), FeatureLevels: UInt32, param6: UInt32, param7: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Device), param8: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL), param9: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFN_D3D11_CREATE_DEVICE_AND_SWAP_CHAIN(param0: win32more.Windows.Win32.Graphics.Dxgi.IDXGIAdapter, param1: win32more.Windows.Win32.Graphics.Direct3D.D3D_DRIVER_TYPE, param2: win32more.Windows.Win32.Foundation.HMODULE, param3: UInt32, param4: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL), FeatureLevels: UInt32, param6: UInt32, param7: POINTER(win32more.Windows.Win32.Graphics.Dxgi.DXGI_SWAP_CHAIN_DESC), param8: POINTER(win32more.Windows.Win32.Graphics.Dxgi.IDXGISwapChain), param9: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Device), param10: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL), param11: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext)) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)
